<-- This file is part 8 of the GNU version of
    The Collaborative International Dictionary of English (GCIDE)

    Copyright (C) 1992-2012 Patrick J. Cassidy
    Copyright (C) 2012-2024 Sergey Poznyakoff

    GCIDE is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.

    GCIDE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this copy of GCIDE.  If not, see <http://www.gnu.org/licenses/>.
-->

<p><centered><point26>H.</point26></centered><br/
[<source>1913 Webster</source>]</p>

<p><ent>H</ent><br/
<hw>H</hw> <pr>(<amac/ch)</pr>, <def>the eighth letter of the English
alphabet, is classed among the consonants, and is formed with the mouth
organs in the same position as that of the succeeding vowel. It is used
with certain consonants to form digraphs representing sounds which are
not found in the alphabet, as <it>sh</it>, <it>th</it>, <it><th/</it>,
as in <it>shall</it>, <it>thing</it>, <it><th/ine</it> (for <it>zh</it>
see <sect/274); also, to modify the sounds of some other letters, as
when placed after c and p, with the former of which it represents a
compound sound like that of <it>tsh</it>, as in <it>charm</it> (written
also <it>tch</it> as in <it>catch</it>), with the latter, the sound of
<it>f</it>, as in <it>phase</it>, <it>phantom</it>. In some words,
mostly derived or introduced from foreign languages, <it>h</it>
following <it>c</it> and <it>g</it> indicates that those consonants have
the hard sound before <it>e</it>, <it>i</it>, and <it>y</it>, as in
<xex>chemistry</xex>, <xex>chiromancy</xex>, <xex>chyle</xex>,
<xex>Ghent</xex>, <xex>Ghibelline</xex>, etc.; in some others,
<it>ch</it> has the sound of <it>sh</it>, as in <xex>chicane</xex>. See
<xex>Guide to Pronunciation</xex>, <sect/<sect/ 153, 179, 181-3,
237-8.</def><br/
[<source>1913 Webster</source>]</p>

<p><note> The name (aitch) is from the French <it>ache</it>; its form is
from the Latin, and this from the Greek H, which was used as the sign of
the spiritus asper (rough breathing) before it came to represent the
long vowel, Gr. <eta/. The Greek H is from Ph<oe/nician, the ultimate
origin probably being Egyptian. Etymologically H is most closely related
to <it>c</it>; as in E. <it>h</it>orn, L. <it>c</it>ornu, Gr.
<grk>ke`ras</grk>; E. <it>h</it>ele, <pos>v. t.</pos>, con<it>c</it>eal;
E. <it>h</it>ide, L. <it>c</it>utis, Gr. <grk>ky`tos</grk>; E.
<it>h</it>undred, L. <it>c</it>entum, Gr. <grk>"e-kat-on</grk>, Skr.
<it><csdot/</it>ata.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>H piece</b></col> <fld>(Mining)</fld>, <cd>the part of a
plunger pump which contains the valve.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>H</ent><br/
<hw>H</hw> <pr>(h<aum/)</pr>. <fld>(Mus.)</fld> <def>The seventh degree
in the diatonic scale, being used by the Germans for B natural. See
<er>B</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>H2O</ent><br/
<hw>H2O</hw> <pos>n.</pos> <pr>(<amac/ch`t<oomac/`<omac/")</pr>,
<def>The chemical formula for <er>water</er>.</def><br/
<syn><b>Syn. --</b> water, hydrogen oxide.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ha</ent><br/
<hw>Ha</hw> <pr>(h<aum/)</pr>, <pos>interj.</pos> <ety>[AS.]</ety>
<def>An exclamation denoting surprise, joy, or grief. Both as uttered
and as written, it expresses a great variety of emotions, determined by
the tone or the context. When repeated, <ex>ha, ha</ex>, it is an
expression of laughter, satisfaction, or triumph, sometimes of derisive
laughter; or sometimes it is equivalent to <ldquo/Well, it is
so.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Ha-has</qex>, and inarticulate hootings of satirical
rebuke.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haaf</ent><br/
<hw>Haaf</hw> <pr>(h<aum/f)</pr>, <pos>n.</pos> <ety>[Of Scand. origin;
cf. Icel. & Sw. <ets>haf</ets> the sea, Dan. <ets>hav</ets>, perh. akin
to E. <ets>haven</ets>.]</ety> <def>The deep-sea fishing for cod, ling,
and tusk, off the Shetland Isles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haak</ent><br/
<hw>Haak</hw> <pr>(h<amac/k)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A sea fish. See <er>Hake</er>.</def> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haar</ent><br/
<hw>Haar</hw> <pr>(h<aum/r)</pr>, <pos>n.</pos> <ety>[See
<er>Hoar</er>.]</ety> <def>A fog; esp., a fog or mist with a chill
wind.</def> <mark>[Scot.]</mark> <rj><au>T. Chalmers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habeas corpus</ent><br/
\'d8<hw>Ha"be*as cor"pus</hw> <pr>(h<amac/"b<esl/*<acr/s
k<ocir/r"p<ucr/s)</pr>. <ety>[L. you may have the body.]</ety>
<fld>(Law)</fld> <def>A writ having for its object to bring a party
before a court or judge; especially, one to inquire into the cause of a
person's imprisonment or detention by another, with the view to protect
the right to personal liberty; also, one to bring a prisoner into court
to testify in a pending trial.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habendum</ent><br/
\'d8<hw>Ha*ben"dum</hw> <pr>(h<adot/*b<ecr/n"d<ucr/m)</pr>,
<pos>n.</pos> <ety>[L., that must be had.]</ety> <fld>(Law)</fld>
<def>That part of a deed which follows the part called the
<xex>premises</xex>, and determines the extent of the interest or estate
granted; -- so called because it begins with the word
<ex>Habendum</ex>.</def> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haberdash</ent><br/
<hw>Hab"er*dash</hw> <pr>(h<acr/b"<etil/r*d<acr/sh)</pr>, <pos>v.
i.</pos> <ety>[See <er>Haberdasher</er>.]</ety> <def>To deal in small
wares.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>haberdash</qex> in earth's base ware.</q>
<rj><qau>Quarles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haberdasher</ent><br/
<hw>Hab"er*dash`er</hw> <pr>(h<acr/b"<etil/r*d<acr/sh`<etil/r)</pr>,
<pos>n.</pos> <ety>[Prob. fr. Icel. <ets>hapurtask</ets> trumpery,
trifles, perh. through French. It is possibly akin to E.
<ets>haversack</ets>, and to Icel. <ets>taska</ets> trunk, chest,
pocket, G. <ets>tasche</ets> pocket, and the orig. sense was perh.,
peddler's wares.]</ety> <sn>1.</sn> <def>A dealer in small wares, as
tapes, pins, needles, and thread.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dealer in items of men's clothing, such as hats,
gloves, neckties, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>haberdasher</qex> heapeth wealth by hats.</q>
<rj><qau>Gascoigne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dealer in drapery goods of various descriptions,
as laces, silks, trimmings, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haberdashery</ent><br/
<hw>Hab"er*dash`er*y</hw>
<pr>(h<acr/b"<etil/r*d<acr/sh`<etil/r*<ycr/)</pr>, <pos>n.</pos>
<def>The goods and wares sold by a haberdasher; also
<mark>(Fig.)</mark>, trifles.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haberdine</ent><br/
<hw>Hab`er*dine"</hw> <pr>(h<acr/b`<etil/r*d<emac/n" <or/
h<acr/"b<etil/r*d<icr/n)</pr>, <pos>n.</pos> <ety>[D.
<ets>abberdaan</ets>, <ets>labberdaan</ets>; or a French form, cf. OF.
<ets>habordeau</ets>, from the name of a Basque district, cf. F.
<ets>Labourd</ets>, adj. <ets>Labourdin.</ets> The <it>l</it> was
misunderstood as the French article.]</ety> <def>A cod salted and
dried.</def> <rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habergeon</ent><br/
<hw>Ha*ber"ge*on</hw> <pr>(h<adot/*b<etil/r"j<esl/*<ocr/n <or/
h<acr/b"<etil/r*j<ucr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>haubergeon</ets> a small hauberk, dim. of OF. <ets>hauberc</ets>,
F. <ets>haubert</ets>. See <er>Hauberk</er>.]</ety> <def>Properly, a
short hauberk, but often used loosely for the hauberk.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habenaria</ent><br/
<hw>Habenaria</hw> <pos>prop. n.</pos> <def>A genus of chiefly
terrestrial orchids with tubers or fleshy roots often having long
slender spurs and petals and lip lobes; it includes species formerly
placed in the genus <gen>Gymnadeniopsis</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Habenaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Habilatory</ent><br/
<hw>Hab"i*la*to*ry</hw> <pr>(h<acr/b"<icr/*l<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Of or pertaining to clothing; wearing clothes.</def>
<rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habile</ent><br/
<hw>Hab"ile</hw> <pr>(h<acr/b"<icr/l)</pr>, <pos>a.</pos> <ety>[F.
<ets>habile</ets>, L. <ets>habilis</ets>. See <er>Able</er>,
<er>Habit</er>.]</ety> <def>Fit; qualified; also, apt.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habiliment</ent><br/
<hw>Ha*bil"i*ment</hw> <pr>(h<adot/*b<icr/l"<icr/*m<eit/nt)</pr>,
<pos>n.</pos> <ety>[F. <ets>habillement</ets>, fr. <ets>habiller</ets>
to dress, clothe, orig., to make fit, make ready, fr. <ets>habile</ets>
apt, skillful, L. <ets>habilis</ets>. See <er>Habile</er>.]</ety>
<sn>1.</sn> <def>A garment; an article of clothing.</def>
<rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Dress, in general.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habilimented</ent><br/
<hw>Ha*bil"i*ment*ed</hw>, <pos>a.</pos> <def>Clothed.</def>
<rj><au>Taylor (1630).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habilitate</ent><br/
<hw>Ha*bil"i*tate</hw> <pr>(h<adot/*b<icr/l"<icr/*t<asl/t)</pr>,
<pos>a.</pos> <ety>[LL. <ets>habilitatus</ets>, p. p. of
<ets>habilitare</ets> to enable.]</ety> <def>Qualified or
entitled.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habilitate</ent><br/
<hw>Ha*bil"i*tate</hw> <pr>(h<adot/*b<icr/l"<icr/*t<amac/t)</pr>,
<pos>v. t.</pos> <def>To fit out; to equip; to qualify; to
entitle.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habilitation</ent><br/
<hw>Ha*bil`i*ta"tion</hw>
<pr>(h<adot/*b<icr/l`<icr/*t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[LL. <ets>habilitatio</ets>: cf. F. <ets>habilitation</ets>.]</ety>
<def>Equipment; qualification.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hability</ent><br/
<hw>Ha*bil"i*ty</hw> <pr>(h<adot/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[See <er>Ability</er>.]</ety> <def>Ability;
aptitude.</def> <mark>[Obs.]</mark> <rj><au>Robynson (More's
Utopia).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habit</ent><br/
<hw>Hab"it</hw> <pr>(h<acr/b"<icr/t)</pr> <pos>n.</pos> <ety>[OE.
<ets>habit</ets>, <ets>abit</ets>, F. <ets>habit</ets>, fr. L.
<ets>habitus</ets> state, appearance, dress, fr. <ets>habere</ets> to
have, be in a condition; prob. akin to E. <ets>have.</ets> See
<er>Have</er>, and cf. <er>Able</er>, <er>Binnacle</er>, <er>Debt</er>,
<er>Due</er>, <er>Exhibit</er>, <er>Malady.</er>]</ety> <sn>1.</sn>
<def>The usual condition or state of a person or thing, either natural
or acquired, regarded as something had, possessed, and firmly retained;
<as>as, a religious <ex>habit</ex>; his <ex>habit</ex> is morose; elms
have a spreading <ex>habit</ex></as>; esp., physical temperament or
constitution; <as>as, a full <ex>habit</ex> of body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The general appearance and manner
of life of a living organism.</def> <specif>Specifically,</specif> the
tendency of a plant or animal to grow in a certain way; <as>as, the
deciduous <ex>habit</ex> of certain trees.</as><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>Fixed or established custom; ordinary course of
conduct; practice; usage; hence, prominently, the involuntary tendency
or aptitude to perform certain actions which is acquired by their
frequent repetition; <as>as, <ex>habit</ex> is second nature</as>; also,
peculiar ways of acting; characteristic forms of behavior.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of very shy, retired <qex>habits</qex>.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Outward appearance; attire; dress; hence, a garment;
esp., a closely fitting garment or dress worn by ladies; <as>as, a
riding <ex>habit</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Costly thy <qex>habit</qex> as thy purse can buy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There are, among the statues, several of Venus, in different
<qex>habits</qex>.</q> <rj><qau>Addison.</qau></rj></p>

<p><sn>5.</sn> <specif>Hence:</specif> <def>The distinctive clothing
worn commonly by nuns or monks; <as>as, in the late 1900's many orders
of nuns discarded their <ex>habits</ex> and began to dress as ordinary
lay women</as>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Practice; mode; manner; way; custom;
fashion.</syn> <usage> -- <er>Habit</er>, <er>Custom</er>.
<xex>Habit</xex> is a disposition or tendency leading us to do easily,
naturally, and with growing certainty, what we do often;
<xex>custom</xex> is external, being habitual use or the frequent
repetition of the same act. The two operate reciprocally on each other.
The <xex>custom</xex> of giving produces a <xex>habit</xex> of
liberality; <xex>habits</xex> of devotion promote the <xex>custom</xex>
of going to church. <xex>Custom</xex> also supposes an act of the will,
selecting given modes of procedure; <xex>habit</xex> is a law of our
being, a kind of <ldquo/second nature<rdquo/ which grows up within
us.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>How use doth breed a <qex>habit</qex> in a man!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He who reigns . . . upheld by old repute,<br/
Consent, or <qex>custom</qex></q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habit</ent><br/
<hw>Hab"it</hw> <pr>(h<acr/b"<icr/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Habited</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Habiting</conjf>.]</vmorph> <ety>[OE.
<ets>habiten</ets> to dwell, F. <ets>habiter</ets>, fr. L.
<ets>habitare</ets> to have frequently, to dwell, intens. fr.
<ets>habere</ets> to have. See <er>Habit</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To inhabit.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In thilke places as they [birds] <qex>habiten</qex>.</q>
<rj><qau>Rom. of R. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dress; to clothe; to array.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>habited</qex> themselves like those rural deities.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To accustom; to habituate.</def> <mark>[Obs.]</mark>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitability</ent><br/
<hw>Hab`it*a*bil"i*ty</hw>
<pr>(h<acr/b`<icr/t*<adot/*b<icr/l"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<def>Habitableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitable</ent><br/
<hw>Hab"it*a*ble</hw> <pr>(h<acr/b"<icr/t*<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[F. <er>habitable</er>, L.
<ets>habitabilis</ets>.]</ety> <def>Capable of being inhabited; that may
be inhabited or dwelt in; <as>as, the <ex>habitable</ex>
world</as>.</def> -- <wordforms><wf>Hab"it*a*ble*ness</wf>,
<pos>n.</pos> -- <wf>Hab"it*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 662 pr=JMD --></p>

<p><ent>Habitacle</ent><br/
<hw>Hab"it*a*cle</hw> <pr>(h<acr/b"<icr/t*<adot/*k'l)</pr>,
<pos>n.</pos> <ety>[F. <ets>habitacle</ets> dwelling place, binnacle, L.
<ets>habitaculum</ets> dwelling place. See <er>Binnacle</er>,
<er>Habit</er>, <pos>v.</pos>]</ety> <def>A dwelling place.</def>
<rj><au>Chaucer.</au> <au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitan</ent><br/
<hw>Ha`bi`tan"</hw> <pr>(<adot/`b<esl/`t<aum/N")</pr>, <pos>n.</pos>
<def>Same as <er>Habitant</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>General Arnold met an emissary . . . sent . . . to ascertain the
feelings of the <qex>habitans</qex> or French yeomanry.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitance</ent><br/
<hw>Hab"it*ance</hw> <pr>(h<acr/b"<icr/t*<ait/ns)</pr>, <pos>n.</pos>
<ety>[OF. <ets>habitance</ets>, LL. <ets>habitantia</ets>.]</ety>
<def>Dwelling; abode; residence.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitancy</ent><br/
<hw>Hab"it*an*cy</hw> <pr>(h<acr/b"<icr/t*<ait/n*s<ycr/)</pr>,
<pos>n.</pos> <def>Same as <er>Inhabitancy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitant</ent><br/
<hw>Hab"it*ant</hw> <pr>(h<acr/b"<icr/t*<ait/nt)</pr>, <pos>n.</pos>
<ety>[F. <ets>habitant</ets>. See <er>Habit</er>, <pos>v.
t.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An inhabitant; a dweller.</def> <rj><au>Milton.</au>
<au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F. <it>pron.</it>
<pr><adot/`b<esl/`t<aum/N"</pr>]</ety> <def>An inhabitant or resident;
-- a name applied to and denoting farmers of French descent or origin in
Canada, especially in the Province of Quebec; -- usually in the
plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>habitants</qex> or cultivators of the soil.</q>
<rj><qau>Parkman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitat</ent><br/
<hw>Hab"i*tat</hw> <pr>(h<acr/b"<icr/*t<acr/t)</pr>, <pos>n.</pos>
<ety>[L., it dwells, fr. <ets>habitare</ets>. See <er>Habit</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>The natural
abode, locality or region of an animal or plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Place where anything is commonly found.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This word has its <qex>habitat</qex> in Oxfordshire.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitation</ent><br/
<hw>Hab`i*ta"tion</hw> <pr>(h<acr/b"<icr/*t<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[F. <ets>habitation</ets>, L.
<ets>habitatio</ets>.]</ety> <sn>1.</sn> <def>The act of inhabiting;
state of inhabiting or dwelling, or of being inhabited; occupancy.</def>
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Place of abode; settled dwelling; residence;
house.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord . . . blesseth the <qex>habitation</qex> of the just.</q>
<rj><qau>Prov. iii. 33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitator</ent><br/
<hw>Hab"i*ta`tor</hw> <pr>(h<acr/b"<icr/*t<amac/`t<etil/r)</pr>,
<pos>n.</pos> <ety>[L.]</ety> <def>A dweller; an inhabitant.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habited</ent><br/
<hw>Hab"it*ed</hw> <pr>(h<acr/b"<icr/t*<ecr/d)</pr>, <pos>p. p. &
a.</pos> <sn>1.</sn> <def>Clothed; arrayed; dressed; <as>as, he was
<ex>habited</ex> like a shepherd</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fixed by habit; accustomed.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>habited</qex> he was in sobriety.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Inhabited.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Another world, which is <qex>habited</qex> by the ghosts of men
and women.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitual</ent><br/
<hw>Ha*bit"ual</hw> <pr>(h<adot/*b<icr/t"<usl/*<ait/l; 135)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>habituel</ets>, LL.
<ets>habitualis</ets>. See <er>Habit</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>Formed or acquired by habit or use.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An <qex>habitual</qex> knowledge of certain rules and maxims.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>According to habit; established by habit; customary;
constant; <as>as, the <ex>habitual</ex> practice of sin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the distinguishing mark of <qex>habitual</qex> piety to be
grateful for the most common and ordinary blessings.</q>
<rj><qau>Buckminster.</qau></rj></p>

<p><syn><b>Syn.</b> -- Customary; accustomed; usual; common; wonted;
ordinary; regular; familiar.</syn></p>

<p>-- <wordforms><wf>Ha*bit"u*al*ly</wf>, <pos>adv.</pos> --
<wf>Ha*bit"u*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habituate</ent><br/
<hw>Ha*bit"u*ate</hw> <pr>(h<adot/*b<icr/t"<usl/*<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Habituated</conjf>
<pr>(h<adot/*b<icr/t"<usl/*<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Habituating</conjf>
<pr>(h<adot/*b<icr/t"<usl/*<amac/`t<icr/ng)</pr>.]</vmorph> <ety>[L.
<ets>habituatus</ets>, p. p. of <ets>habituare</ets> to bring into a
condition or habit of body: cf. F. <ets>habituer</ets>. See
<er>Habit</er>.]</ety> <sn>1.</sn> <def>To make accustomed; to accustom;
to familiarize.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our English dogs, who were <qex>habituated</qex> to a colder
clime.</q> <rj><qau>Sir K. Digby.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men are first corrupted . . . and next they <qex>habituate</qex>
themselves to their vicious practices.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To settle as an inhabitant.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habituate</ent><br/
<hw>Ha*bit"u*ate</hw> <pr>(h<adot/*b<icr/t"<usl/*<asl/t)</pr>,
<pos>a.</pos> <def>Firmly established by custom; formed by habit;
habitual.</def> <mark>[R.]</mark> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habituation</ent><br/
<hw>Ha*bit`u*a"tion</hw>
<pr>(h<adot/*b<icr/t"<usl/*<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>habituation</ets>.]</ety> <def>The act of habituating,
or accustoming; the state of being habituated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitude</ent><br/
<hw>Hab"i*tude</hw> <pr>(h<acr/b"<icr/*t<umac/d)</pr>, <pos>n.</pos>
<ety>[F., fr. L. <ets>habitudo</ets> condition. See
<er>Habit</er>.]</ety> <sn>1.</sn> <def>Habitual attitude; usual or
accustomed state with reference to something else; established or usual
relations.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The same ideas having immutably the same <qex>habitudes</qex> one
to another.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The verdict of the judges was biased by nothing else than their
<qex>habitudes</qex> of thinking.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Habitual association, intercourse, or
familiarity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To write well, one must have frequent <qex>habitudes</qex> with
the best company.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Habit of body or of action.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is impossible to gain an exact <qex>habitude</qex> without an
infinite number of acts and perpetual practice.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitue</ent><br/
\'d8<hw>Ha`bi`tu`<eacute/"</hw>
<pr>(<adot/`b<esl/`t<usdot/`<asl/")</pr>, <pos>n.</pos> <ety>[F., p. p.
of <ets>habituer</ets>. See <er>Habituate</er>.]</ety> <def>One who
habitually frequents a place; <as>as, an <ex>habitu<eacute/</ex> of a
theater</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habiture</ent><br/
<hw>Hab"i*ture</hw> <pr>(h<acr/b"<icr/*t<usl/r; 135)</pr>, <pos>n.</pos>
<def>Habitude.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habitus</ent><br/
\'d8<hw>Hab"i*tus</hw> <pr>(h<acr/b"<icr/*t<ucr/s)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <fld>(Zool.)</fld> <def>Habitude; mode of life; general
appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hable</ent><br/
<hw>Ha"ble</hw> <pr>(h<amac/"b'l)</pr>, <pos>a.</pos> <def>See
<er>Habile</er>.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Habnab</ent><br/
<hw>Hab"nab</hw> <pr>(h<acr/b"n<acr/b)</pr>, <pos>adv.</pos>
<ety>[<er>Hobnob</er>.]</ety> <def>By chance.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hachure</ent><br/
<hw>Hach"ure</hw> <pr>(h<acr/ch"<usl/r)</pr>, <pos>n.</pos> <ety>[F.,
fr. <ets>hacher</ets> to hack. See <er>Hatching</er>.]</ety> <fld>(Fine
Arts)</fld> <def>A short line used in drawing and engraving, especially
in shading and denoting different surfaces, as in map drawing. See
<er>Hatching</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hacienda</ent><br/
\'d8<hw>Ha`ci*en"da</hw> <pr>(<aum/`th<esl/*<asl/n"d<adot/ <it>or</it>
h<aum/`s<icr/*<ecr/n"d<adot/)</pr>, <pos>n.</pos> <ety>[Sp., fr. OSp.
<ets>facienda</ets> employment, estate, fr. L. <ets>facienda</ets>, pl.
of <ets>faciendum</ets> what is to be done, fr. <ets>facere</ets> to do.
See <er>Fact</er>.]</ety> <sn>1.</sn> <def>A large estate where work of
any kind is done, as agriculture, manufacturing, mining, or raising of
animals; a cultivated farm, with a good house, in distinction from a
farming establishment with rude huts for herdsmen, etc.; -- a word used
in Spanish-American regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The main residence of a hacienda{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw> <pr>(h<acr/k)</pr>, <pos>n.</pos> <ety>[See <er>Hatch</er>
a half door.]</ety> <sn>1.</sn> <def>A frame or grating of various
kinds; as, a frame for drying bricks, fish, or cheese; a rack for
feeding cattle; a grating in a mill race, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unburned brick or tile, stacked up for
drying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hacked</conjf> <pr>(h<acr/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hacking</conjf>.]</vmorph> <ety>[OE. <ets>hakken</ets>, AS.
<ets>haccian</ets>; akin to D. <ets>hakken</ets>, G. <ets>hacken</ets>,
Dan. <ets>hakke</ets>, Sw. <ets>hacka</ets>, and perh. to E.
<ets>hew</ets>. Cf. <er>Hew</er> to cut, <er>Haggle</er>.]</ety>
<sn>1.</sn> <def>To cut irregulary, without skill or definite purpose;
to notch; to mangle by repeated strokes of a cutting instrument; <as>as,
to <ex>hack</ex> a post</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My sword <qex>hacked</qex> like a handsaw.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To mangle in speaking.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>To program (a computer) for
pleasure or compulsively; especially, to try to defeat the security
systems and gain unauthorized access to a computer.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>To bear, physically or emotionally; <as>as, he left
the job because he couldn't <ex>hack</ex> the pressure</as>.</def>
<mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>v. t.</pos> <fld>(Football)</fld> <def>To kick the
shins of (an opposing payer).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>v. i.</pos> <def>To cough faintly and frequently, or
in a short, broken manner; <as>as, a <ex>hacking</ex>
cough</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>n.</pos> <sn>1.</sn> <def>A notch; a cut.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An implement for cutting a notch; a large pick used
in breaking stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A hacking; a catch in speaking; a short, broken
cough.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Football)</fld> <def>A kick on the shins, or a cut
from a kick.</def> <rj><au>T. Hughes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Computers)</fld> <def>A clever computer program or
routine within a program to accomplish an objective in a non-obvious
fashion.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <fld>(Computers)</fld> <def>A quick and inelegant, though
functional solution to a programming problem.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>A <er>taxicab</er>.</def>
<mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Hack saw</b></col>, <cd>a handsaw having a narrow blade
stretched in an iron frame, for cutting metal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw> <pr>(h<acr/k)</pr>, <pos>n.</pos> <ety>[Shortened fr.
<ets>hackney</ets>. See <er>Hackney</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A horse, hackneyed or let out for common hire; also,
a horse used in all kinds of work, or a saddle horse, as distinguished
from hunting and carriage horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coach or carriage let for hire; a hackney coach;
formerly, a coach with two seats inside facing each other; now, usually
a taxicab.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>On horse, on foot, in <qex>hacks</qex> and gilded chariots.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>The driver of a hack; a taxi
driver; a hackman.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A bookmaker who hires himself out for any sort of
literary work; an overworked man; a drudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here lies poor Ned Purdon, from misery freed,<br/
Who long was a bookseller's <qex>hack</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A procuress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>v. i.</pos> <def>To ride or drive as one does with a
hack horse; to ride at an ordinary pace, or over the roads, as
distinguished from riding across country or in military
fashion.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>a.</pos> <def>Hackneyed; hired; mercenary.</def>
<rj><au>Wakefield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hack writer</b></col>, <cd>a hack; one who writes for
hire.</cd> <ldquo/A vulgar <xex>hack writer</xex>.<rdquo/
<rj><au>Macaulay.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To use as a hack; to
let out for hire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To use frequently and indiscriminately, so as to
render trite and commonplace.</def><-- = hackney? --><br/
[<source>1913 Webster</source>]</p>

<p><q>The word <ldquo/remarkable<rdquo/ has been so <qex>hacked</qex> of
late.</q> <rj><qau>J. H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hack</ent><br/
<hw>Hack</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be exposed or
offered to common use for hire; to turn prostitute.</def>
<rj><au>Hanmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To live the life of a drudge or hack.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackamore</ent><br/
<hw>Hack"a*more</hw> <pr>(h<acr/k"<adot/*m<omac/r)</pr>, <pos>n.</pos>
<ety>[Cf. Sp. <ets>jaquima</ets> headstall of a halter.]</ety> <def>A
halter consisting of a long leather or rope strap and headstall, -- used
for leading or tieing a pack animal.</def> <mark>[Western U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackberry</ent><br/
<hw>Hack"ber`ry</hw> <pr>(h<acr/k"b<ecr/r`r<ycr/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A genus of trees (<gen>Celtis</gen>) related to
the elm, but bearing drupes with scanty, but often edible, pulp.
<spn>Celtis occidentalis</spn> is common in the Eastern United
States.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackbolt</ent><br/
<hw>Hack"bolt`</hw> <pr>(h<acr/k"b<omac/lt`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The greater shearwater or hagdon. See
<er>Hagdon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackbuss</ent><br/
<hw>Hack"buss</hw> <pr>(h<acr/k"b<ucr/s)</pr>, <pos>n.</pos> <def>Same
as <er>Hagbut</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackee</ent><br/
<hw>Hack"ee</hw> <pr>(h<acr/k"<emac/)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The chipmunk; also, the chickaree or red
squirrel.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackelia</ent><br/
<hw>Hackelia</hw> <pos>prop. n.</pos> <def>A genus of plants with seeds
that stick to clothing, including stickseed and some of the beggar's
lice.</def><br/
<syn><b>Syn. --</b> genus <gen>Hackelia</gen>, Lappula, genus
<gen>Lappula</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hacker</ent><br/
<hw>hack"er</hw> <pr>(h<acr/k"<etil/r)</pr>, <pos>n.</pos> <def>One who,
or that which, hacks.</def> <specif>Specifically:</specif> <def>A
cutting instrument for making notches; esp., one used for notching pine
trees in collecting turpentine; a hack.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hackery</ent><br/
<hw>hack"er*y</hw> <pr>(h<acr/k"<etil/r*<ycr/)</pr>, <pos>n.</pos>
<ety>[Hind. <ets>chhakr<amac/</ets>.]</ety> <def>A cart with wooden
wheels, drawn by bullocks.</def> <mark>[Bengal]</mark>
<rj><au>Malcom.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hackie</ent><br/
<hw>hack"ie</hw> <pr>(h<acr/k"<emac/)</pr>, <pos>n.</pos> <def>The
driver of a taxicab; a hackman.</def> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>hackle</ent><br/
<hw>hac"kle</hw> <pr>(h<acr/k"k'l)</pr>, <pos>n.</pos> <ety>[See
<er>Heckle</er>, and cf. <er>Hatchel</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A comb for dressing flax, raw silk, etc.; a
hatchel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any flimsy substance unspun, as raw silk.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One of the peculiar, long, narrow feathers on the
neck of fowls, most noticeable on the cock, -- often used in making
artificial flies; hence, any feather so used.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An artificial fly for angling, made of
feathers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackle</ent><br/
<hw>Hac"kle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hackled</conjf> <pr>(h<acr/k"k'ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hackling</conjf> <pr>(h<acr/k"kl<icr/ng)</pr>.]</vmorph>
<sn>1.</sn> <def>To separate, as the coarse part of flax or hemp from
the fine, by drawing it through the teeth of a hackle or
hatchel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tear asunder; to break in pieces.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The other divisions of the kingdom being <qex>hackled</qex> and
torn to pieces.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackly</ent><br/
<hw>Hac"kly</hw> <pr>(h<acr/k"l<ycr/)</pr>, <pos>a.</pos> <ety>[From
<er>Hackle</er>.]</ety> <sn>1.</sn> <def>Rough or broken, as if
hacked.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>Having fine, short, and sharp
points on the surface; <as>as, the <ex>hackly</ex> fracture of metallic
iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackman</ent><br/
<hw>Hack"man</hw> <pr>(h<acr/k"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hackmen</plw> <pr>(h<acr/k"m<eit/n)</pr>.</plu>
<def>The driver of a hack or carriage for public hire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackmatack</ent><br/
<hw>Hack"ma*tack`</hw> <pr>(h<acr/k"m<adot/*t<acr/k`)</pr>,
<pos>n.</pos> <ety>[Of American Indian origin.]</ety> <fld>(Bot.)</fld>
<def>The American larch (<spn>Larix Americana</spn>), a coniferous tree
with slender deciduous leaves; also, its heavy, close-grained timber.
Called also <altname>tamarack</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackney</ent><br/
<hw>Hack"ney</hw> <pr>(-n<ycr/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hackneys</plw> <pr>(-n<icr/z)</pr>.</plu> <ety>[OE.
<ets>hakeney</ets>, <ets>hakenay</ets>; cf. F.
<ets>haguen<eacute/e</ets> a pacing horse, an ambling nag, OF. also
<ets>haquen<eacute/e</ets>, Sp. <ets>hacanea</ets>, OSp.
<ets>facanea</ets>, D. <ets>hakkenei</ets>, also OF. <ets>haque</ets>
horse, Sp. <ets>haca</ets>, OSp. <ets>faca</ets>; perh. akin to E.
<ets>hack</ets> to cut, and <ets>nag</ets>, and orig. meaning, a jolting
horse. Cf. <er>Hack</er> a horse, <er>Nag</er>.]</ety> <sn>1.</sn>
<def>A horse for riding or driving; a nag; a pony.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A horse or pony kept for hire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A carriage kept for hire; a hack; a hackney
coach.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A hired drudge; a hireling; a prostitute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackney</ent><br/
<hw>Hack"ney</hw>, <pos>a.</pos> <def>Let out for hire; devoted to
common use; hence, much used; trite; mean; <as>as, <ex>hackney</ex>
coaches; <ex>hackney</ex> authors.</as></def> <ldquo/<xex>Hackney</xex>
tongue.<rdquo/ <rj><au>Roscommon.</au></rj></p>

<p><-- also hackneyed --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackney</ent><br/
<hw>Hack"ney</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hackneyed</conjf> <pr>(-n<icr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hackneying</conjf>.]</vmorph> <sn>1.</sn> <def>To devote to
common or frequent use, as a horse or carriage; to wear out in common
service; to make trite or commonplace; <as>as, a <ex>hackneyed</ex>
metaphor or quotation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had I so lavish of my presence been,<br/
So common-<qex>hackneyed</qex> in the eyes of men.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To carry in a hackney coach.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackneyman</ent><br/
<hw>Hack"ney*man</hw> <pr>(-m<acr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hackneymen</plw> <pr>(-m<ecr/n)</pr>.</plu>
<def>A man who lets horses and carriages for hire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hackster</ent><br/
<hw>Hack"ster</hw> <pr>(-st<etil/r)</pr>, <pos>n.</pos> <ety>[From
<er>Hack</er> to cut.]</ety> <def>A bully; a bravo; a ruffian; an
assassin.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hacqueton</ent><br/
<hw>Hac"que*ton</hw> <pr>(h<acr/k"k<esl/*t<ocr/n)</pr>, <pos>n.</pos>
<def>Same as <er>Acton</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Had</ent><br/
<hw>Had</hw> <pr>(h<acr/d)</pr>, <pos>imp. & p. p.</pos> of
<er>Have</er>. <ety>[OE. <ets>had</ets>, <ets>hafde</ets>,
<ets>hefde</ets>, AS. <ets>h<ae/fde</ets>.]</ety> <def>See
<er>Have</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Had as lief</b></col>, <col><b>Had
rather</b></col>, <col><b>Had better</b></col>, <col><b>Had as
soon</b></col>, etc.</mcol>, <cd>with a nominative and followed by the
infinitive without <xex>to</xex>, are well established idiomatic forms.
The original construction was that of the dative with forms of
<xex>be</xex>, followed by the infinitive. See <cref>Had better</cref>,
under <er>Better</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>lever me is</qex> be pore and trewe.<br/
[And more agreeable to me it is to be poor and true.]</q> <rj><qau>C.
Mundi (Trans.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Him had been lever</qex> to be syke.<br/
[To him it had been preferable to be sick.]</q>
<rj><qau>Fabian.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For <qex>him was lever</qex> have at his bed's head<br/
Twenty bookes, clad in black or red, . . . <br/
Than robes rich, or fithel, or gay sawtrie.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>Gradually the nominative was substituted for the dative, and
<xex>had</xex> for the forms of <xex>be</xex>. During the process of
transition, the nominative with <xex>was</xex> or <xex>were</xex>, and
the dative with <xex>had</xex>, are found.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Poor lady, <qex>she were better</qex> love a dream.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>You were best</qex> hang yourself.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Me rather had</qex> my heart might feel your love<br/
Than my unpleased eye see your courtesy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>I hadde levere</qex> than my scherte,<br/
That ye hadde rad his legende, as have I.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>I had as lief</qex> not be as live to be<br/
In awe of such a thing as I myself.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>I had rather</qex> be a dog and bay the moon,<br/
Than such a Roman.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>I had rather</qex> be a doorkeeper in the house of my God,
than to dwell in the tents of wickedness.</q> <rj><qau>Ps. lxxxiv.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hadder</ent><br/
<hw>Had"der</hw> <pr>(h<acr/d"d<etil/r)</pr>, <pos>n.</pos>
<def>Heather; heath.</def> <mark>[Obs.]</mark> <au>Burton.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haddie</ent><br/
<hw>Had"die</hw> <pr>(-d<icr/)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The haddock.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haddock</ent><br/
<hw>Had"dock</hw> <pr>(-d<ucr/k)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hadok</ets>, <ets>haddok</ets>, of unknown origin; cf. Ir.
<ets>codog</ets>, Gael. <ets>adag</ets>, F. <ets>hadot</ets>.]</ety>
<fld>(Zool.)</fld> <def>A marine food fish (<spn>Melanogrammus
aeglefinus</spn>), allied to the cod, inhabiting the northern coasts of
Europe and America. It has a dark lateral line and a black spot on each
side of the body, just back of the gills. Galled also
<altname>haddie</altname>, and <altname>dickie</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Norway haddock</b></col>, <cd>a marine edible fish
(<spn>Sebastes marinus</spn>) of Northern Europe and America. See
<er>Rose fish</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hade</ent><br/
<hw>Hade</hw> <pr>(h<amac/d)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>heald</ets> inclined, bowed down, G. <ets>halde</ets>
declivity.]</ety> <sn>1.</sn> <def>The descent of a hill.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>The inclination or deviation
from the vertical of any mineral vein.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol. & Mining)</fld> <def>The deviation of a fault
plane from the vertical.</def></p>

<p><note><hand/ The <xex>direction of the hade</xex> is the direction
toward which the fault plane descends from an intersecting vertical
line.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hade</ent><br/
<hw>Hade</hw>, <pos>v. i.</pos> <fld>(Mining)</fld> <def>To deviate from
the vertical; -- said of a vein, fault, or lode.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hades</ent><br/
<hw>Ha"des</hw> <pr>(h<amac/"d<emac/z)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"a`,dhs</grk>, <grk>"A'idhs</grk>; <grk>'a</grk> priv. +
<grk>'idei^n</grk> to see. Cf. <er>Un-</er>, <er>Wit</er>.]</ety>
<def>The nether world (according to classical mythology, the abode of
the shades, ruled over by Hades or Pluto); the invisible world; the
grave.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And death and <qex>Hades</qex> gave up the dead which were in
them.</q> <rj><qau>Rev. xx. 13 (Rev. Ver.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither was he left in <qex>Hades</qex>, nor did his flesh see
corruption.</q> <rj><qau>Acts ii. 31 (Rev. Ver.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And in <qex>Hades</qex> he lifted up his eyes, being in
torments.</q> <rj><qau>Luke xvi. 23 (Rev. Ver.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hadj</ent><br/
\'d8<hw>Hadj</hw> <pr>(h<acr/j)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>hajj</ets>, fr. <ets>hajja</ets> to set out, walk, go on a
pilgrimage.]</ety> <def>The pilgrimage to Mecca, performed by Muslims.
It is the duty of Moslems to make a journey to Mecca at least once ina
lifetime, or if that is not possible, three journeys to one of the
alternate sacred sites.</def> <altsp>[Also spelled <asp>haj</asp> and
<asp>hajj</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hadji</ent><br/
<hw>Hadj"i</hw> <pr>(-<icr/)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>h<amac/jj<imac/</ets>. See <er>Hadj</er>.]</ety> <altsp>[Also
spelled <asp>hajji</asp> and <asp>haji</asp>.]</altsp> <sn>1.</sn>
<def>A Muslim who has made a pilgrimage to Mecca; -- used among
Orientals as a respectful salutation or a title of honor.</def>
<rj><au>G. W. Curtis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A Greek or Armenian who has visited the holy
sepulcher at Jerusalem.</def> <rj><au>Heyse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hadron</ent><br/
<hw>hadron</hw> <pos>n.</pos> <fld>(Physics)</fld> <def>any elementary
particle that interacts strongly with other particles.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hadrosaur</ent><br/
<hw>hadrosaur</hw> <pos>n.</pos> <def>Any member of the genus
<gen>Hadrosaurus</gen> or family <fam>Hadrosauridae</fam>, an extinct
family of heavy bipedal partly aquatic dinosaurs with duck-billed skull
and webbed feet; of the Upper Cretaceous in North America.</def><br/
<syn><b>Syn. --</b> hadrosaurus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hadrosauridae</ent><br/
<hw>Hadrosauridae</hw> <pos>prop. n.</pos> <def>A natural family of
extinct reptiles including the duck-billed dinosaurs.</def><br/
<syn><b>Syn. --</b> family <fam>Hadrosauridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hadrosaurus</ent><br/
\'d8<hw>Had`ro*sau"rus</hw> <pr>(h<acr/d`r<osl/*s<add/"r<ucr/s)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>"adro`s</grk> thick +
<grk>say^ros</grk> lizard.]</ety> <fld>(Paleon.)</fld> <def>An American
herbivorous dinosaur of great size, allied to the iguanodon. It is found
in the Cretaceous formation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haecceity</ent><br/
<hw>Haec*ce"i*ty</hw> <pr>(h<ecr/k*s<emac/"<icr/*t<ycr/)</pr>, <ety>[L.
<ets>h<ae/cce</ets> this.]</ety> <fld>(Logic)</fld> <def>Literally,
<sig>this-ness</sig>. A scholastic term to express individuality or
singleness; as, <xex>this</xex> book.</def><-- ?? sic. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemo-</ent><br/
<ent>Haemato-</ent><br/
<ent>Haema-</ent><br/
<mhw><hw>Haem"a-</hw> <pr>(h<ecr/m"<adot/- <or/ h<emac/"m<adot/-)</pr>,
<hw>Haem"a*to-</hw> <pr>(h<ecr/m"<adot/*t<osl/- <or/
h<emac/"m<adot/*t<osl/-)</pr>, <hw>Haem"o-</hw> <pr>(h<ecr/m"<osl/- <or/
h<emac/"m<osl/-)</pr></mhw>. <ety>[Gr. <grk>a"i^ma</grk>,
<grk>a"i`matos</grk>, blood.]</ety> <def>Combining forms indicating
<sig>relation or resemblance to blood</sig>, <sig>association with
blood</sig>; <as>as, <ex>haema</ex>pod, <ex>haemato</ex>genesis,
<ex>haemo</ex>scope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Words from Gr. <grk>a"i^ma</grk> are written
<xex>hema-</xex>, <xex>hemato-</xex>, <xex>hemo-</xex>, as well as
<xex>haema-</xex>, <xex>haemato-</xex>, <xex>haemo-</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemachrome</ent><br/
<hw>Haem"a*chrome</hw> <pr>(h<ecr/m"<adot/*kr<omac/m <or/
h<emac/"m<adot/-)</pr>, <pos>n.</pos> <ety>[<ets>Haema-</ets> + Gr.
<grk>chrw^ma</grk> color.]</ety> <fld>(Physiol. Chem.)</fld>
<def>Hematin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemacyanin</ent><br/
<hw>Haem`a*cy"a*nin</hw> <pr>(-s<imac/"<adot/*n<icr/n)</pr>,
<pos>n.</pos> <ety>[<ets>Haema-</ets> + Gr. <grk>ky`anos</grk> a dark
blue substance.]</ety> <fld>(Physiol. Chem.)</fld> <def>A substance
found in the blood of the octopus, which gives to it its blue
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When deprived of oxygen it is colorless, but becomes
quickly blue in contact with oxygen, and is then generally called
<xex>oxyhaemacyanin</xex>. A similar blue coloring matter has been
detected in small quantity in the blood of other animals and in the
bile.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemacytometer</ent><br/
<hw>Haem`a*cy*tom"e*ter</hw> <pr>(-s<isl/*t<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Haema</ets> + Gr. <grk>ky`tos</grk> a hollow
vessel + <ets>-meter</ets>.]</ety> <fld>(Physiol.)</fld> <def>An
apparatus for determining the number of corpuscles in a given quantity
of blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemad</ent><br/
<hw>Hae"mad</hw> <pr>(h<emac/"m<acr/d)</pr>, <pos>adv.</pos>
<ety>[<ets>Haema-</ets> + L. <ets>ad</ets> toward.]</ety>
<fld>(Anat.)</fld> <def>Toward the haemal side; on the haemal side of;
-- opposed to <xex>neurad</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemadromometer</ent><br/
<ent>Haemadrometer</ent><br/
<mhw>{ <hw>Haem`a*drom"e*ter</hw>
<pr>(h<ecr/m`<adot/*dr<ocr/m"<esl/*t<etil/r <or/ h<emac/`m<adot/-)</pr>,
<hw>Haem`a*dro*mom"e*ter</hw>
<pr>(-dr<osl/*m<ocr/m"<esl/*t<etil/r)</pr>, }</mhw> <pos>n.</pos>
<def>Same as <er>Hemadrometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemadromometry</ent><br/
<ent>Haemadrometry</ent><br/
<mhw>{ <hw>Haem`a*drom"e*try</hw>
<pr>(-dr<ocr/m"<esl/*tr<ycr/)</pr>,<hw>Haem`a*dro*mom"e*try</hw>
<pr>(-dr<osl/*m<ocr/m"<esl/*tr<ycr/)</pr>, }</mhw> <pos>n.</pos>
<def>Same as <er>Hemadrometry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemadromograph</ent><br/
<hw>Haem`a*drom"o*graph</hw> <pr>(-dr<ocr/m"<osl/*gr<adot/f)</pr>,
<pos>n.</pos> <ety>[<ets>Haema-</ets> + Gr. <grk>dro`mos</grk> course +
<ets>-graph</ets>.]</ety> <fld>(Physiol.)</fld> <def>An instrument for
registering the velocity of the blood.</def></p>

<p><ent>Haemadynamometer</ent><br/
<ent>Haemadynameter</ent><br/
<mhw><hw>Hae`ma*dy*nam"e*ter</hw>
<pr>(h<emac/`m<adot/*d<isl/*n<acr/m"<esl/*t<etil/r <or/
h<ecr/m`<adot/*d<icr/-)</pr> <hw>Hae`ma*dy`na*mom"e*ter</hw>
<pr>(h<emac/`m<adot/*d<imac/`n<adot/*m<ocr/m"<esl/*t<etil/r <or/
h<ecr/m`<adot/*d<icr/n`<adot/-)</pr></mhw>, <def>Same as
<er>Hemadynamometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemadynamics</ent><br/
<hw>Haema*dy*nam"ics</hw> <pr>(h<emac/`m<adot/*d<isl/*n<acr/m"<icr/ks
<or/ h<ecr/m`<adot/*d<icr/-</pr>, <pos>n.</pos> <def>Same as
<er>Hemadynamics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemal</ent><br/
<hw>Hae"mal</hw> <pr>(h<emac/"m<ait/l)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>a"i^ma</grk> blood.]</ety> <def>Pertaining to the blood or blood
vessels; also, ventral. See <er>Hemal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemaphaein</ent><br/
<hw>Haem`a*phae"in</hw> <pr>(h<ecr/m`<adot/*f<emac/"<icr/n <or/
h<emac/`m<adot/-)</pr>, <pos>n.</pos> <ety>[<ets>Haema-</ets> + Gr.
<grk>faio`s</grk> dusky.]</ety> <fld>(Physiol.)</fld> <def>A brownish
substance sometimes found in the blood, in cases of jaundice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemapod</ent><br/
<hw>Haem"a*pod</hw> <pr>(h<ecr/m"<adot/*p<ocr/d <or/
h<emac/"m<adot/*p<ocr/d)</pr>, <pos>n.</pos> <ety>[<ets>Haema</ets> +
<ets>-pod</ets>.]</ety> <fld>(Zool.)</fld> <def>An haemapodous
animal.</def> <rj><au>G. Rolleston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 663 pr=JMD --></p>

<p><ent>Haemapodous</ent><br/
<hw>Hae*map"o*dous</hw> <pr>(h<esl/*m<acr/p"<osl/*d<ucr/s)</pr>,
<pos>a.</pos> <fld>(Anat.)</fld> <def>Having the limbs on, or directed
toward, the ventral or hemal side, as in vertebrates; -- opposed to
<contr>neuropodous</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemapoietic</ent><br/
<hw>Haem`a*poi*et"ic</hw> <pr>(h<ecr/m`<adot/*poi*<ecr/t"<icr/k <or/
h<emac/`m<adot/-)</pr>, <pos>a.</pos> <ety>[<ets>Haema-</ets> + Gr.
<grk>poihtiko`s</grk> productive.]</ety> <fld>(Physiol.)</fld>
<def>Blood-forming; <as>as, the <ex>haemapoietic</ex> function of the
spleen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemapophysis</ent><br/
\'d8<hw>Haem`a*poph"y*sis</hw> <pr>(-p<ocr/f"<icr/*s<icr/s)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <def>Same as <er>Hemapophysis</er>.</def>
-- <wordforms><wf>Haem`a*po*phys"i*al</wf>
<pr>(-p<osl/*f<icr/z"<icr/*<ait/l)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemastatics</ent><br/
<hw>Haem`a*stat"ics</hw>, <pos>n.</pos> <def>Same as
<er>Hemastatics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematachometer</ent><br/
<hw>Haem`a*ta*chom"e*ter</hw>
<pr>(-t<adot/*k<ocr/m"<esl/*t<etil/r)</pr>, <pos>n.</pos>
<ety>[<ets>Haema-</ets> + Gr. <grk>tachy`s</grk> swift +
<ets>-meter</ets>.]</ety> <fld>(Physiol.)</fld> <def>A form of apparatus
(somewhat different from the <xex>hemadrometer</xex>) for measuring the
velocity of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematachometry</ent><br/
<hw>Haem`a*ta*chom"e*try</hw> <pr>(-tr<ycr/)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>The measurement of the velocity of the
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematemesis</ent><br/
<hw>Haem`a*tem"e*sis</hw>, <pos>n.</pos> <def>Same as
<er>Hematemesis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematic</ent><br/
<hw>Hae*mat"ic</hw> <pr>(h<esl/*m<acr/t"<icr/k)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>a"imatiko`s</grk>]</ety> <def>Of or pertaining to the
blood; sanguine; brownish red.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Haematic acid</b></col> <fld>(Physiol.)</fld>, <cd>a
hypothetical acid, supposed to be formed from hemoglobin during its
oxidation in the lungs, and to have the power of freeing carbonic acid
from the sodium carbonate of the serum.</cd>
<rj><au>Thudichum.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematin</ent><br/
<hw>Haem"a*tin</hw>, <pos>n.</pos> <def>Same as
<er>Hematin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematinometer</ent><br/
<hw>Haem`a*ti*nom"e*ter</hw>, <pos>n.</pos> <def>Same as
<er>Hematinometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematinometric</ent><br/
<hw>Haem`a*tin`o*met"ric</hw>, <pos>a.</pos> <def>Same as
<er>Hematinometric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematite</ent><br/
<hw>Haem"a*tite</hw>, <pos>n.</pos> <def>Same as
<er>Hematite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematitic</ent><br/
<hw>Haem`a*tit"ic</hw> <pr>(h<ecr/m`<adot/*t<icr/t"<icr/k)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <def>Of a blood-red color; crimson;
<fld>(Bot.)</fld> brownish red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemato-</ent><br/
<hw>Haem"a*to-</hw> <pr>(h<ecr/m"<adot/*t<osl/- <or/ h<emac/"-)</pr>,
<pos>prefix.</pos> <def>See <er>Haema-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoblast</ent><br/
<hw>Haem"a*to*blast</hw> <pr>(-bl<acr/st`)</pr>, <pos>n.</pos>
<ety>[<ets>Haemato-</ets> + <ets>-blast</ets>.]</ety> <fld>(Anat.)</fld>
<def>One of the very minute, disk-shaped bodies found in blood with the
ordinary red corpuscles and white corpuscles; a third kind of blood
corpuscle, supposed by some to be an early stage in the development of
the red corpuscles; -- called also <altname>blood plaque</altname>, and
<altname>blood plate</altname>.</def><-- = hemocytoblast,
hematocytoblast. Precursor of erythroblasts, lymphoblasts, and
myeloblasts, found mostly in bone marrow. Hayem's hematoblast = a
platelet --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematocrya</ent><br/
\'d8<hw>Haem`a*toc"ry*a</hw> <pr>(t<ocr/k"r<icr/*<adot/)</pr>, <pos>n.
pl.</pos> <fld>(Zool.)</fld> <def>The cold-blooded vertebrates. Same as
<er>Hematocrya</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematocryal</ent><br/
<hw>Haem`a*toc"ry*al</hw> <pr>(-<ait/l)</pr>, <pos>a.</pos>
<def>Cold-blooded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematocrystallin</ent><br/
<hw>Haem`a*to*crys"tal*lin</hw>, <pos>n.</pos> <def>Same as
<er>Hematocrystallin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematodynamometer</ent><br/
<hw>Hae`ma*to*dy`na*mom"e*ter</hw>
<pr>(h<emac/`m<adot/*t<osl/*d<imac/`n<adot/*m<ocr/m"<esl/*t<etil/r <or/
h<ecr/m`<adot/*t<osl/*d<icr/n`<adot/-)</pr>, <pos>n.</pos> <def>Same as
<er>Hemadynamometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematogenesis</ent><br/
<hw>Haem`a*to*gen"e*sis</hw>
<pr>(h<ecr/m`<adot/*t<osl/*j<ecr/n"<esl/*s<icr/s <or/
h<emac/`m<adot/*t<osl/-)</pr>, <pos>n.</pos> <ety>[<ets>Haemato-</ets> +
<ets>genesis</ets>.]</ety> <fld>(Physiol.)</fld> <sd>(a)</sd> <def>The
origin and development of blood.</def> <sd>(b)</sd> <def>The
transformation of venous into arterial blood by respiration;
hematosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematogenic</ent><br/
<hw>Haem`a*to*gen"ic</hw> <pr>(-j<ecr/n"<icr/k)</pr>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Relating to haematogenesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematogenous</ent><br/
<hw>Haem`a*tog"e*nous</hw> <pr>(-t<ocr/j"<esl/*n<ucr/s)</pr>,
<pos>a.</pos> <fld>(Physiol.)</fld> <def>Originating in the
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoglobulin</ent><br/
<hw>Haem`a*to*glob"u*lin</hw>, <pos>n.</pos> <def>Same as
<er>Hematoglobulin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoid</ent><br/
<hw>Haem"a*toid</hw>, <pos>a.</pos> <def>Same as
<er>Hematoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoidin</ent><br/
<hw>Haem`a*toid"in</hw>, <pos>n.</pos> <def>Same as
<er>Hematoidin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoin</ent><br/
<hw>Hae*mat"o*in</hw> <pr>(h<esl/*m<acr/t"<osl/*<icr/n)</pr>,
<pos>n.</pos> <ety>[<ets>Haemato-</ets> + <ets>-in</ets>.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A substance formed from the hematin of
blood, by removal of the iron through the action of concentrated
sulphuric acid. Two like bodies, called respectively
<xex>haematoporphyrin</xex> and <xex>haematolin</xex>, are formed in a
similar manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematolin</ent><br/
<hw>Hae*mat"o*lin</hw> <pr>(-l<icr/n)</pr>, <pos>n.</pos> <def>See
<er>Haematoin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematology</ent><br/
<hw>Haem`a*tol"o*gy</hw> <pr>(h<ecr/m`<adot/*t<ocr/l"<osl/*j<ycr/ <or/
h<emac/`m<adot/-)</pr>, <pos>n.</pos> <def>The science which treats of
the blood. Same as <er>Hematology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematolysis</ent><br/
\'d8<hw>Haem`a*tol"y*sis</hw> <pr>(h<ecr/m`<adot/*t<ocr/l"<icr/*s<icr/s
<it>or</it> h<ecr/`m<adot/-)</pr>, <pos>n.</pos> <ety>[NL.;
<ets>haemato-</ets> + Gr. <grk>ly`sis</grk> a loosing, dissolving, fr.
<grk>ly`ein</grk> to loose, dissolve.]</ety> <fld>(Physiol.)</fld>
<def>Dissolution of the red blood corpuscles with diminished
coagulability of the blood; haemolysis.</def> --
<wordforms><wf>Haem`a*to*lyt"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Haematometer</ent><br/
<hw>Haem`a*tom"e*ter</hw> <pr>(-t<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Haemato-</ets> + <ets>-meter</ets>.]</ety>
<fld>(Physiol.)</fld> <sd>(a)</sd> <def>Same as
<er>Hemadynamometer</er>.</def> <sd>(b)</sd> <def>An instrument for
determining the number of blood corpuscles in a given quantity of
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematophilina</ent><br/
\'d8<hw>Haem`a*to*phi*li"na</hw>
<pr>(-t<osl/*f<icr/*l<imac/"n<adot/)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood +
<grk>filei^n</grk> to love.]</ety> <fld>(Zool.)</fld> <def>A division of
<ord>Chiroptera</ord>, including the bloodsucking bats. See
<er>Vampire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoplast</ent><br/
<hw>Haem"a*to*plast`</hw> <pr>(-pl<acr/st`)</pr>, <pos>n.</pos>
<ety>[<ets>Haemato-</ets> + Gr. <grk>pla`ssein</grk> to mold.]</ety>
<fld>(Anat.)</fld> <def>Same as <er>Haematoblast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoplastic</ent><br/
<hw>Haem`a*to*plas"tic</hw> <pr>(-pl<acr/s"t<icr/k)</pr>, <pos>a.</pos>
<ety>[<ets>Haemato-</ets> + <ets>-plastic</ets>.]</ety>
<fld>(Physiol.)</fld> <def>Blood formative; -- applied to a substance in
early fetal life, which breaks up gradually into blood
vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoporphyrin</ent><br/
<hw>Haem`a*to*por"phy*rin</hw> <pr>(-p<ocir/r"f<icr/*r<icr/n)</pr>,
<pos>n.</pos> <ety>[<ets>Haemato-</ets> + Gr. <grk>porfy`ra</grk>
purple.]</ety> <fld>(Physiol. Chem.)</fld> <def>See
<er>Haematoin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematosac</ent><br/
<hw>Haem"a*to*sac`</hw> <pr>(-s<acr/k`)</pr>, <pos>n.</pos>
<ety>[<ets>Haemato-</ets> + <ets>sac</ets>.]</ety> <fld>(Anat.)</fld>
<def>A vascular sac connected, beneath the brain, in many fishes, with
the infundibulum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoscope</ent><br/
<hw>Haem"a*to*scope`</hw> <pr>(-sk<omac/p`)</pr>, <pos>n.</pos> <def>A
haemoscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematosin</ent><br/
<hw>Haem`a*to"sin</hw> <pr>(h<ecr/m`<adot/*t<omac/"s<icr/n <or/
h<esl/*m<acr/t"<osl/*s<icr/n)</pr>, <pos>n.</pos> <fld>(Physiol.
Chem.)</fld> <def>Hematin.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematosis</ent><br/
\'d8<hw>Haem`a*to"sis</hw>, <pos>n.</pos> <def>Same as
<er>Hematosis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematotherma</ent><br/
\'d8<hw>Haem`a*to*ther"ma</hw>
<pr>(h<ecr/m`<adot/*t<osl/*th<etil/r"m<adot/ <or/
h<emac/`m<adot/-)</pr>, <pos>n. pl.</pos> <fld>(Zool.)</fld> <def>Same
as <er>Hematotherma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematothermal</ent><br/
<hw>Haem`a*to*ther"mal</hw> <pr>(-m<ait/l)</pr>, <pos>a.</pos>
<def>Warm-blooded; homoiothermal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematothorax</ent><br/
<hw>Haem`a*to*tho"rax</hw>, <pos>n.</pos> <def>Same as
<er>Hemothorax</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoxylin</ent><br/
<hw>Haem`a*tox"y*lin</hw> <pr>(-t<ocr/ks"<icr/*l<icr/n)</pr>,
<pos>n.</pos> <ety>[See <er>Haematoxylon</er>.]</ety> <fld>(Chem.)</fld>
<def>The coloring principle of logwood. It is obtained as a yellow
crystalline substance, <chform>C16H14O6</chform>, with a sweetish taste.
Formerly called also <altname>hematin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematoxylon</ent><br/
\'d8<hw>Haem`a*tox"y*lon</hw> <pr>(-l<ocr/n)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>a"i^ma</grk> blood + <grk>xy`lon</grk>
wood.]</ety> <fld>(Bot.)</fld> <def>A genus of leguminous plants
containing but a single species, the <spn>Haematoxylon
Campechianum</spn> or logwood tree, native in Yucatan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haematozoon</ent><br/
\'d8<hw>Haem`a*to*zo"on</hw> <pr>(-t<osl/*z<omac/"<ocr/n)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Haematozoa</plw>
<pr>(-<adot/)</pr>.</plu> <ety>[NL., fr. Gr. <grk>a"i^ma</grk>,
<grk>a"i`matos</grk>, blood + <grk>zw^,on</grk> animal.]</ety>
<fld>(Zool.)</fld> <def>A parasite inhabiting the blood</def>; esp.:
<sd>(a)</sd> <def>Certain species of nematodes of the genus
<gen>Filaria</gen>, sometimes found in the blood of man, the horse, the
dog, etc.</def> <sd>(b)</sd> <def>The trematode, <spn>Bilharzia
haematobia</spn>, which infests the inhabitants of Egypt and other parts
of Africa, often causing death.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemic</ent><br/
<hw>Hae"mic</hw> <pr>(h<emac/"m<icr/k <or/ h<ecr/m"<icr/k)</pr>,
<pos>a.</pos> <def>Pertaining to the blood; hemal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemin</ent><br/
<hw>Hae"min</hw> <pr>(h<amac/"m<icr/n)</pr>, <pos>n.</pos> <def>Same as
<er>Hemin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemo-</ent><br/
<hw>Haem"o-</hw> <pr>(h<ecr/m"<osl/- <or/ h<emac/"m<osl/-)</pr>,
<pos>prefix.</pos> <def>See <er>Haema-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemochrome</ent><br/
<hw>Haem"o*chrome</hw> <pr>(-kr<omac/m)</pr>, <pos>n.</pos> <def>Same as
<er>Haemachrome</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemochromogen</ent><br/
<hw>Haem`o*chro"mo*gen</hw> <pr>(-kr<omac/"m<osl/*j<ecr/n)</pr>,
<pos>n.</pos> <ety>[<ets>Haemochrome</ets> + <ets>-gen</ets>.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A body obtained from hemoglobin, by the
action of reducing agents in the absence of oxygen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemochromometer</ent><br/
<hw>Haem`o*chro*mom"e*ter</hw>
<pr>(-kr<osl/*m<ocr/m"<esl/*t<etil/r)</pr>, <pos>n.</pos>
<ety>[<ets>Haemochrome</ets> + <ets>-meter</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>An apparatus for measuring the amount of hemoglobin in
a fluid, by comparing it with a solution of known strength and of normal
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemocyanin</ent><br/
<hw>Haem`o*cy"a*nin</hw> <pr>(-s<imac/"<adot/*n<icr/n)</pr>,
<pos>n.</pos> <def>Same as <er>Haemacyanin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemocytolysis</ent><br/
\'d8<hw>Haem`o*cy*tol"y*sis</hw>
<pr>(-s<isl/*t<ocr/l"<icr/*s<icr/s)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>a"i^ma</grk> blood + <grk>ky`tos</grk> hollow vessel +
<grk>ly`ein</grk> to loosen, dissolve.]</ety> <fld>(Physiol.)</fld>
<def>See <er>Haemocytotrypsis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemocytometer</ent><br/
<hw>Haem`o*cy*tom"e*ter</hw>, <pos>n.</pos> <def>See
<er>Haemacytometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemocytotrypsis</ent><br/
\'d8<hw>Haem`o*cy`to*tryp"sis</hw>
<pr>(-s<imac/`t<osl/*tr<icr/p"s<icr/s)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>a"i^ma</grk> blood + <grk>ky`tos</grk> hollow vessel +
<grk>tri`bein</grk> to rub, grind.]</ety> <fld>(Physiol.)</fld> <def>A
breaking up of the blood corpuscles, as by pressure, in distinction from
solution of the corpuscles, or <contr>haemocytolysis</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemodromograph</ent><br/
<hw>Haem`o*drom"o*graph</hw> <pr>(-dr<osl/*m<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <def>Same as <er>Haemadromograph</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemodromometer</ent><br/
<hw>Haem`o*dro*mom"e*ter</hw><pr>(-dr<osl/*m<ocr/m"<esl/*t<etil/r)</pr>,<pos>n.</pos><def>Same
as <er>Hemadrometer</er>.</def></p>

<p><ent>Haemodynameter</ent><br/
<hw>Hae`mo*dy*nam"e*ter</hw>
<pr>(h<emac/`m<osl/*d<isl/*n<acr/m"<esl/*t<etil/r <or/
h<ecr/m`<osl/*d<icr/-)</pr>, <pos>n.</pos> <def>Same as
<er>Hemadynamics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemoglobin</ent><br/
<hw>Haem`o*glo"bin</hw>, <pos>n.</pos> <def>Same as
<er>Hemoglobin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemoglobinometer</ent><br/
<hw>Haem`o*glo`bin*om"e*ter</hw> <pr>(-<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Haemoglobin</ets> + <ets>-meter</ets>.]</ety>
<def>Same as <er>Hemochromometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemol</ent><br/
<hw>Hae"mol</hw> <pr>(h<emac/"m<omac/l)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>a"i^ma</grk> blood.]</ety> <fld>(Chem.)</fld> <def>A dark brown
powder containing iron, prepared by the action of zinc dust as a
reducing agent upon the coloring matter of the blood, used medicinally
as a hematinic.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Haemolutein</ent><br/
<hw>Haem`o*lu"te*in</hw> <pr>(-l<umac/"t<esl/*<icr/n)</pr>,
<pos>n.</pos> <ety>[<ets>Haemo-</ets> + corpus <ets>lute</ets>um.]</ety>
<fld>(Physiol.)</fld> <def>See <er>Hematoidin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemolytic</ent><br/
<ent>Haemolysis</ent><br/
<mhw>\'d8<hw>Hae*mol"y*sis</hw> <pr>(h<esl/*m<ocr/l"<icr/*s<icr/s)</pr>,
<pos>n.</pos>, <hw>Haem`o*lyt"ic</hw> <pr>(h<ecr/m`<osl/*l<icr/t"*<icr/c
<it>or</it> h<emac/`m<osl/-)</pr></mhw>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Same as <er>Haematolysis</er>,
<er>Haematolytic</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Haemomanometer</ent><br/
<hw>Haem`o*ma*nom"e*ter</hw> <pr>(-m<adot/*n<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Haemo-</ets> + <ets>manometer</ets>.]</ety>
<def>Same as <er>Hemadynamometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemometer</ent><br/
<hw>Hae*mom"e*ter</hw> <pr>(h<esl/*m<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Haemo-</ets> + <ets>-meter</ets>.]</ety>
<fld>(Physiol.)</fld> <def>Same as <er>Hemadynamometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemony</ent><br/
<hw>Hae"mo*ny</hw> <pr>(h<emac/"m<osl/*n<ycr/)</pr>, <pos>n.</pos>
<ety>[L. <ets>Haemonia</ets> a name of Thessaly, the land of
magic.]</ety> <def>A plant described by Milton as <ldquo/of sovereign
use against all enchantments.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemoplastic</ent><br/
<hw>Hae`mo*plas"tic</hw>, <pos>a.</pos> <def>Same as
<er>Haematoplastic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemorrhoidal</ent><br/
<hw>Haem"or*rhoid"al</hw>, <pos>a.</pos> <def>Same as
<er>Hemorrhoidal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemoscope</ent><br/
<hw>Haem"o*scope</hw> <pr>(h<ecr/m"<osl/*sk<omac/p <or/
h<emac/"m<osl/-)</pr>, <pos>n.</pos> <ety>[<ets>Haemo-</ets> +
<ets>-scope</ets>.]</ety> <fld>(Physiol.)</fld> <def>An instrument
devised by Hermann, for regulating and measuring the thickness of a
layer of blood for spectroscopic examination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemostatic</ent><br/
<hw>Haem`o*stat"ic</hw> <pr>(-st<acr/t"<icr/k)</pr>, <pos>a.</pos>
<def>Same as <er>Hemostatic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemotachometer</ent><br/
<hw>Haem`o*ta*chom"e*ter</hw>
<pr>(-t<adot/*k<ocr/m"<esl/*t<etil/r)</pr>, <pos>n.</pos> <def>Same as
<er>Haematachometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haemotachometry</ent><br/
<hw>Haem`o*ta*chom"e*try</hw> <pr>(-tr<ycr/)</pr>, <pos>n.</pos>
<def>Same as <er>Haematachometry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haf</ent><br/
<hw>Haf</hw> <pr>(h<aum/f)</pr>, <pos>imp.</pos> <mord>of
<er>Heave</er></mord>. <def>Hove.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haffle</ent><br/
<hw>Haf"fle</hw> <pr>(h<acr/f"f'l)</pr>, <pos>v. i.</pos> <ety>[Cf. G.
<ets>haften</ets> to cling, stick to, Prov. G., to stop, stammer.]</ety>
<def>To stammer; to speak unintelligibly; to prevaricate.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hafnium</ent><br/
<hw>haf"ni*um</hw> <pr>(h<acr/f"n<emac/*<ucr/m or
h<aum/f"n<emac/*<ucr/m)</pr>, <pos>n.</pos> <def>A metallic element of
atomic number 72 present together with zirconium to the extent of 1% to
5% in zirconium minerals. It is a poisonous, ductile metal with a
brilliant silver luster, has an atomic weight of 178.49, and has a high
melting point (2227<deg/ C). It is used in nuclear reactors, and
incandescent lamps as a scavenger of oxygen and nitrogen. See also
<er>norium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haft</ent><br/
<hw>Haft</hw> <pr>(h<adot/ft)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<ae/ft</ets>; akin to D. & G. <ets>heft</ets>, Icel.
<ets>hepti</ets>, and to E. <ets>heave</ets>, or <ets>have</ets>. Cf.
<er>Heft</er>.]</ety> <sn>1.</sn> <def>A handle; that part of an
instrument or vessel taken into the hand, and by which it is held and
used; -- said chiefly of a knife, sword, or dagger; the hilt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This brandish'd dagger<br/
I'll bury to the <qex>haft</qex> in her fair breast.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dwelling.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haft</ent><br/
<hw>Haft</hw>, <pos>v. t.</pos> <def>To set in, or furnish with, a haft;
<as>as, to <ex>haft</ex> a dagger</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hafter</ent><br/
<hw>Haft"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>haften</ets> to cling or stick to, and E. <ets>haffle</ets>.]</ety>
<def>A caviler; a wrangler.</def> <mark>[Obs.]</mark>
<rj><au>Baret.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hag</ent><br/
<hw>Hag</hw> <pr>(h<acr/g)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hagge</ets>, <ets>hegge</ets>, witch, hag, AS.
<ets>h<ae/gtesse</ets>; akin to OHG. <ets>hagazussa</ets>, G.
<ets>hexe</ets>, D. <ets>heks</ets>, Dan. <ets>hex</ets>, Sw.
<ets>h<aum/xa</ets>. The first part of the word is prob. the same as E.
<ets>haw</ets>, <ets>hedge</ets>, and the orig. meaning was perh., wood
woman, wild woman. <root/12.]</ety> <sn>1.</sn> <def>A witch, sorceress,
or enchantress; also, a wizard.</def> <mark>[Obs.]</mark>
<ldquo/[Silenus] that old <xex>hag</xex>.<rdquo/
<rj><au>Golding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ugly old woman.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fury; a she-monster.</def>
<rj><au>Crashaw.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>An eel-like marine marsipobranch
(<spn>Myxine glutinosa</spn>), allied to the lamprey. It has a suctorial
mouth, with labial appendages, and a single pair of gill openings. It is
the type of the order <ord>Hyperotreta</ord>. Called also
<altname>hagfish</altname>, <altname>borer</altname>, <altname>slime
eel</altname>, <altname>sucker</altname>, and
<altname>sleepmarken</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>The hagdon or
shearwater.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An appearance of light and fire on a horse's mane or
a man's hair.</def> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hag moth</b></col> <fld>(Zool.)</fld>, <cd>a moth
(<spn>Phobetron pithecium</spn>), the larva of which has curious side
appendages, and feeds on fruit trees.</cd> -- <col><b>Hag's
tooth</b></col> <fld>(Naut.)</fld>, <cd>an ugly irregularity in the
pattern of matting or pointing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hag</ent><br/
<hw>Hag</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hagged</conjf> <pr>(h<acr/gd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hagging</conjf>.]</vmorph> <def>To harass; to weary with
vexation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How are superstitious men <qex>hagged</qex> out of their wits with
the fancy of omens.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hag</ent><br/
<hw>Hag</hw>, <pos>n.</pos> <ety>[Scot. <ets>hag</ets> to cut; cf. E.
<ets>hack</ets>.]</ety> <sn>1.</sn> <def>A small wood, or part of a wood
or copse, which is marked off or inclosed for felling, or which has been
felled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This said, he led me over hoults and <qex>hags</qex>;<br/
Through thorns and bushes scant my legs I drew.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A quagmire; mossy ground where peat or turf has been
cut.</def> <rj><au>Dugdale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagberry</ent><br/
<hw>Hag"ber`ry</hw> <pr>(h<acr/g"b<ecr/r`r<ycr/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A plant of the genus <gen>Prunus</gen>
(<spn>Prunus Padus</spn>); the bird cherry.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagborn</ent><br/
<hw>Hag"born`</hw> <pr>(-b<ocir/rn`)</pr>, <pos>a.</pos> <def>Born of a
hag or witch.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagbut</ent><br/
<hw>Hag"but</hw> <pr>(-b<ucr/t)</pr>, <pos>n.</pos> <ety>[OF.
<ets>haquebute</ets>, prob. a corruption of D. <ets>haakbus</ets>;
<ets>haak</ets> hook + <ets>bus</ets> gun barrel. See <er>Hook</er>, and
2d <er>Box</er>, and cf. <er>Arquebus</er>.]</ety> <def>A harquebus, of
which the but was bent down or hooked for convenience in taking
aim.</def> <altsp>[Written also <asp>haguebut</asp> and
<asp>hackbuss</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagbutter</ent><br/
<hw>Hag"but*ter</hw> <pr>(h<acr/g"b<ucr/t*t<etil/r)</pr>, <pos>n.</pos>
<def>A soldier armed with a hagbut or arquebus.</def> <altsp>[Written
also <asp>hackbutter</asp>.]</altsp> <rj><au>Froude.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagdon</ent><br/
<hw>Hag"don</hw> <pr>(h<acr/g"d<ocr/n)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>One of several species of sea birds of the genus
<gen>Puffinus</gen>; esp., <spn>Puffinus major</spn>, the greater
shearwarter, and <spn>Puffinus Stricklandi</spn>, the black hagdon or
sooty shearwater; -- called also <altname>hagdown</altname>,
<altname>haglin</altname>, and <altname>hag</altname>. See
<er>Shearwater</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagfish</ent><br/
<hw>Hag"fish`</hw><pr>(-f<icr/sh`)</pr>,<pos>n.</pos><fld>(Zo<oum/l.)</fld>
<def>See <er>Hag</er>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggada</ent><br/
<hw>Hag*ga"da</hw> <pr>(h<acr/g*g<aum/"d<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Haggadoth</plw> <pr>(-d<omac/th)</pr>.</plu>
<ety>[Rabbinic <ets>hagg<amac/dh<amac/</ets>, fr. Heb.
<ets>higg<imac/dh</ets> to relate.]</ety> <def>A story, anecdote, or
legend in the Talmud, to explain or illustrate the text of the Old
Testament.</def> <altsp>[Written also <asp>hagada</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggard</ent><br/
<hw>Hag"gard</hw> <pr>(h<acr/g"g<etil/rd)</pr>, <pos>a.</pos> <ety>[F.
<ets>hagard</ets>; of German origin, and prop. meaning, of the hegde or
woods, wild, untamed. See <er>Hedge</er>, 1st <er>Haw</er>, and
<er>-ard</er>.]</ety> <sn>1.</sn> <def>Wild or intractable; disposed to
break away from duty; untamed; <as>as, a <ex>haggard</ex> or refractory
hawk</as>.</def> <mark>[Obs.]</mark> <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[For <ets>hagged</ets>, fr. <ets>hag</ets> a witch,
influenced by <ets>haggard</ets> wild.]</ety> <def>Having the expression
of one wasted by want or suffering; hollow-eyed; having the features
distorted or wasted by pain; wild and wasted, or anxious in appearance;
<as>as, <ex>haggard</ex> features, eyes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Staring his eyes, and <qex>haggard</qex> was his look.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggard</ent><br/
<hw>Hag"gard</hw>, <pos>n.</pos> <ety>[See <er>Haggard</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <fld>(Falconry)</fld> <def>A young or
untrained hawk or falcon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fierce, intractable creature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have loved this proud disdainful <qex>haggard</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[See <er>Haggard</er>, <pos>a.</pos>, 2.]</ety>
<def>A hag.</def> <mark>[Obs.]</mark> <rj><au>Garth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggard</ent><br/
<hw>Hag"gard</hw>, <pos>n.</pos> <ety>[See 1st <er>Haw</er>,
<er>Hedge</er>, and <er>Yard</er> an inclosed space.]</ety> <def>A
stackyard.</def> <mark>[Prov. Eng.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggardly</ent><br/
<hw>Hag"gard*ly</hw>, <pos>adv.</pos> <def>In a haggard manner.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagged</ent><br/
<hw>Hag"ged</hw> <pr>(-g<ecr/d)</pr>, <pos>a.</pos> <def>Like a hag;
lean; ugly.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggis</ent><br/
<hw>Hag"gis</hw> <pr>(-g<icr/s)</pr>, <pos>n.</pos> <ety>[Scot.
<ets>hag</ets> to hack, chop, E. <ets>hack</ets>. Formed, perhaps, in
imitation of the F. <ets>hachis</ets> (E. <ets>hash</ets>), fr.
<ets>hacher</ets>.]</ety> <def>A Scotch pudding made of the heart,
liver, lights, etc., of a sheep or lamb, minced with suet, onions,
oatmeal, etc., highly seasoned, and boiled in the stomach of the same
animal; minced head and pluck.</def> <altsp>[Written also
<asp>haggiss</asp>, <asp>haggess</asp>, and
<asp>haggies</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggish</ent><br/
<hw>Hag"gish</hw> <pr>(-g<icr/sh)</pr>, <pos>a.</pos> <def>Like a hag;
ugly; wrinkled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But on us both did <qex>haggish</qex> age steal on.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggishly</ent><br/
<hw>Hag"gish*ly</hw>, <pos>adv.</pos> <def>In the manner of a
hag.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggle</ent><br/
<hw>Hag"gle</hw> <pr>(h<acr/g"g'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Haggled</conjf>
<pr>(-g'ld)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Haggling</conjf>
<pr>(-gl<icr/ng)</pr>.]</vmorph> <ety>[Freq. of Scot. <ets>hag</ets>, E.
<ets>hack</ets>. See <er>Hack</er> to cut.]</ety> <def>To cut roughly or
hack; to cut into small pieces; to notch or cut in an unskillful manner;
to make rough or mangle by cutting; <as>as, a boy <ex>haggles</ex> a
stick of wood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Suffolk first died, and York, all <qex>haggled</qex> o'er,<br/
Comes to him, where in gore he lay insteeped.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggle</ent><br/
<hw>Hag"gle</hw>, <pos>v. i.</pos> <def>To be difficult in bargaining;
to stick at small matters; to chaffer; to higgle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Royalty and science never <qex>haggled</qex> about the value of
blood.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggle</ent><br/
<hw>Hag"gle</hw>, <pos>n.</pos> <def>The act or process of
haggling.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haggler</ent><br/
<hw>Hag"gler</hw> <pr>(h<acr/g"gl<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who haggles or is difficult in
bargaining.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who forestalls a market; a middleman between
producer and dealer in London vegetable markets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiarchy</ent><br/
<hw>Ha"gi*ar`chy</hw> <pr>(h<amac/"j<icr/*<aum/r`k<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"a`gios</grk> sacred, holy +
<ets>-archy</ets>.]</ety> <def>A sacred government; government by holy
orders of men.</def> <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiocracy</ent><br/
<hw>Ha`gi*oc"ra*cy</hw> <pr>(-<ocr/k"r<adot/*s<ycr/)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"a`gios</grk> holy, and <grk>kratei^n</grk> to
govern.]</ety> <def>Government by a priesthood; hierarchy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiographa</ent><br/
\'d8<hw>Ha`gi*og"ra*pha</hw> <pr>(h<acr/`g<esl/*<ocr/g"r<adot/*f<adot/
<it>or</it> h<amac/`j<icr/*<ocr/g"r<adot/*f<adot/)</pr>, <pos>n.
pl.</pos> <ety>[L., fr. Gr. <grk>"agio`grafa</grk> (sc.
<grk>bibli`a</grk>), fr. <grk>"agio`grafos</grk> written by inspiration;
<grk>"a`gios</grk> sacred, holy + <grk>gra`fein</grk> to write.]</ety>
<sn>1.</sn> <def>The last of the three Jewish divisions of the Old
Testament, comprising Psalms, Proverbs, Job, Canticles, Ruth,
Lamentations, Ecclesiastes, Esther, Daniel, Ezra, Nehemiah, and
Chronicles, or that portion of the Old Testament not contained in the
Law (<contr>Tora</contr>) and the Prophets (<contr>Nevi'im</contr>) --
it is also called in Hebrew the <altname>Ketuvim</altname>. Together
with the Tora and Nevi'im, it comprises the Hebrew Bible, which is
called in Hebrew the <er>Tanach</er>, a vocalization of the first
letters of its three parts.</def><br/
[<source>1913 Webster</source> + <source>RP</source>]</p>

<p><sn>2.</sn> <fld>(R. C. Ch.)</fld> <def>The lives of the
saints.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiographal</ent><br/
<hw>Ha`gi*og"ra*phal</hw> <pr>(-f<ait/l)</pr>, <def>Pertaining to the
hagiographa, or to sacred writings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiographer</ent><br/
<hw>Ha`gi*og"ra*pher</hw> <pr>(-f<etil/r)</pr>, <pos>n.</pos> <def>One
of the writers of the hagiographa; a writer of lives of the
saints.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hagiographical</ent><br/
<ent>hagiographic</ent><br/
<mhw><hw>ha`gi*o*graph"ic</hw>
<pr>(h<acr/`g<esl/*<ocr/*gr<adot/f"<icr/k)</pr>,
<hw>ha`gi*o*graph"ic*al</hw></mhw>
<pr>(h<acr/`g<esl/*<ocr/*gr<adot/f"<icr/k*<ait/l)</pr>, <sn>1.</sn>
<def>of or pertaining to the Hagiographa, or to sacred writings; -- same
as <altname>hagiographal</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to hagiography.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hagiography</ent><br/
<hw>Ha`gi*og"ra*phy</hw> <pr>(-f<ycr/; 277)</pr>, <pos>n.</pos>
<def>Same as <er>Hagiographa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiolatry</ent><br/
<hw>Ha`gi*ol"a*try</hw> <pr>(-<ocr/l"<adot/*tr<ycr/)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"a`gios</grk> sacred + <?/ worship.]</ety> <def>The
invocation or worship of saints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiologist</ent><br/
<hw>Ha`gi*ol"o*gist</hw> <pr>(-<osl/*j<icr/st)</pr>, <pos>n.</pos>
<def>One who treats of the sacred writings; a writer of the lives of the
saints; a hagiographer.</def> <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hagiologists</qex> have related it without scruple.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagiology</ent><br/
<hw>Ha`gi*ol"o*gy</hw> <pr>(-j<ycr/)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"a`gios</grk> sacred + <ets>-logy</ets>.]</ety> <def>The history or
description of the sacred writings or of sacred persons; a narrative of
the lives of the saints; a catalogue of saints.</def> <rj><au>J. H.
Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagioscope</ent><br/
<hw>Ha"gi*o*scope`</hw> <pr>(h<amac/"j<icr/*<osl/*sk<omac/p`)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"a`gios</grk> sacred +
<ets>-scope</ets>.]</ety> <def>An opening made in the interior walls of
a cruciform church to afford a view of the altar to those in the
transepts; -- called, in architecture, a <xex>squint</xex>.</def>
<rj><au>Hook.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hagridden</ent><br/
<ent>hag-ridden</ent><br/
<mhw><hw>hag"-rid`den</hw>, <hw>hag"rid`den</hw></mhw>
<pr>(h<acr/g"r<icr/d`d'n)</pr>, <pos>a.</pos> <def>Ridden by a hag or
witch;</def> <specif>hence,</specif> <def>afflicted with nightmares;
tormented or harassed by nightmares or unreasonable fears.</def>
<rj><au>Beattie.</au> <au>Cheyne.</au></rj><br/
<syn><b>Syn. --</b> tormented.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q><qex>hagridden</qex> . . . by visions of an imminent heaven or
hell upon earth</q> <qau>C. S. Lewis</qau></p>

<p><-- p. 664 pr=JMD --></p>

<p><ent>Hagseed</ent><br/
<hw>Hag"seed`</hw> <pr>(h<acr/g"s<emac/d)</pr>, <pos>n.</pos> <def>The
offspring of a hag.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hagship</ent><br/
<hw>Hag"ship</hw>, <pos>n.</pos> <def>The state or title of a hag.</def>
<rj><au>Middleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hag-taper</ent><br/
<hw>Hag"-ta`per</hw> <pr>(-t<amac/`p<etil/r)</pr>, <pos>n.</pos>
<ety>[Cf. 1st <er>Hag</er>, and <er>Hig-taper</er>.]</ety>
<fld>(Bot.)</fld> <def>The great woolly mullein (<spn>Verbascum
Thapsus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haguebut</ent><br/
<hw>Hague"but</hw> <pr>(h<acr/g"b<ucr/t)</pr>, <pos>n.</pos> <def>See
<er>Hagbut</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hague Tribunal</ent><br/
<hw>Hague Tribunal</hw> <pr>(h<amac/g)</pr>. <def>The permanent court of
arbitration created by the <ldquo/International Convention for the
Pacific Settle of International Disputes.<rdquo/, adopted by the
International Peace Conference of 1899. It is composed of persons of
known competency in questions of international law, nominated by the
signatory powers. From these persons an arbitration tribunal is chosen
by the parties to a difference submitted to the court. On the failure of
the parties to agree directly on the arbitrators, each chooses two
arbitrators, an umpire is selected by them, by a third power, or by two
powers selected by the parties.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hah</ent><br/
<hw>Hah</hw> <pr>(h<aum/)</pr>, <pos>interj.</pos> <def>Same as
<er>Ha</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ha-ha</ent><br/
<hw>Ha-ha"</hw> <pr>(h<aum/*h<aum/")</pr>, <pos>n.</pos> <ety>[See
<er>Haw-haw</er>.]</ety> <def>A sunk fence; a fence, wall, or ditch, not
visible till one is close upon it.</def> <altsp>[Written also
<asp>haw-haw</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haidingerite</ent><br/
<hw>Hai"ding*er*ite</hw> <pr>(h<imac/"d<icr/ng*<etil/r*<imac/t)</pr>,
<pos>n.</pos> <fld>(Min.)</fld> <def>A mineral consisting chiefly of the
arseniate of lime; -- so named in honor of W. <etsep>Haidinger</etsep>,
of Vienna.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haiduck</ent><br/
<hw>Hai"duck</hw> <pr>(h<imac/"d<usdot/k)</pr>, <pos>n.</pos> <ety>[G.
<ets>haiduck</ets>, <ets>heiduck</ets>, fr. Hung.
<ets>hajdu</ets>.]</ety> <def>Formerly, a mercenary foot soldier in
Hungary, now, a halberdier of a Hungarian noble, or an attendant in
German or Hungarian courts.</def> <altsp>[Written also
<asp>hayduck</asp>, <asp>haiduk</asp>, <asp>heiduc</asp>,
<asp>heyduck</asp>, and <asp>heyduk</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haik</ent><br/
\'d8<hw>Haik</hw> <pr>(h<amac/k; Ar. h<aum/*<esl/k)</pr>, <pos>n.</pos>
<ety>[Ar. <ets>h<amac/<ium/k</ets>, fr. <ets>h<amac/ka</ets> to
weave.]</ety> <def>A large piece of woolen or cotton cloth worn by Arabs
as an outer garment.</def> <altsp>[Written also
<asp>hyke</asp>.]</altsp> <rj><au>Heyse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haikal</ent><br/
\'d8<hw>Hai"kal</hw> <pr>(h<imac/"k<ait/l)</pr>, <pos>n.</pos> <def>The
central chapel of the three forming the sanctuary of a Coptic church. It
contains the high altar, and is usually closed by an embroidered
curtain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haikwan</ent><br/
<hw>Hai"kwan"</hw> <pr>(h<imac/"kw<aum/n")</pr>, <pos>n.</pos>
<ety>[Chin. <ets>'hai-kuan</ets>.]</ety> <def>Chinese maritime
customs.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Haikwan tael</ent><br/
<hw>Haikwan tael</hw>. <def>A Chinese weight (<frac1x10/ catty)
equivalent to 1<frac13/ oz. or 37.801 g.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw> <pr>(h<amac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hail</ets>, <ets>ha<yogh/el</ets>, AS. <ets>h<ae/gel</ets>,
<ets>hagol</ets>; akin to D., G., Dan., & Sw. <ets>hagel</ets>; Icel.
<ets>hagl</ets>; cf. Gr. <grk>ka`chlhx</grk> pebble.]</ety> <def>Small
roundish masses of ice precipitated from the clouds, where they are
formed by the congelation of vapor. The separate masses or grains are
called <part>hailstones</part>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thunder mixed with <qex>hail</qex>,<br/
<qex>Hail</qex> mixed with fire, must rend the Egyptian sky.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hailed</conjf> <pr>(h<amac/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hailing</conjf>.]</vmorph> <ety>[OE. <ets>hailen</ets>, AS.
<ets>hagalian</ets>.]</ety> <def>To pour down particles of ice, or
frozen vapors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>v. t.</pos> <def>To pour forcibly down, as
hail.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>a.</pos> <def>Healthy. See <er>Hale</er> (the
preferable spelling).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>v. t.</pos> <ety>[OE. <ets>hailen</ets>,
<ets>heilen</ets>, Icel. <ets>heill</ets> hale, sound, used in greeting.
See <er>Hale</er> sound.]</ety> <sn>1.</sn> <def>To call loudly to, or
after; to accost; to salute; to address.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To name; to designate; to call.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And such a son as all men <qex>hailed</qex> me happy.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To declare, by hailing,
the port from which a vessel sails or where she is registered; hence, to
sail; to come; -- used with <xex>from</xex>; <as>as, the steamer
<ex>hails</ex> from New York</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To report as one's home or the place from whence one
comes; to come; -- with <ptcl>from</ptcl>.</def> <mark>[Colloq.]</mark>
<rj><au>C. G. Halpine.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>interj.</pos> <ety>[See <er>Hail</er>, <pos>v.
t.</pos>]</ety> <def>An exclamation of respectful or reverent
salutation, or, occasionally, of familiar greeting.</def>
<ldquo/<xex>Hail</xex>, brave friend.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>All hail</b></col>. <cd>See in the Vocabulary.</cd> --
<col><b>Hail Mary</b></col>, <cd>a form of prayer made use of in the
Roman Catholic Church in invocation of the Virgin. See <er>Ave
Maria</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail</ent><br/
<hw>Hail</hw>, <pos>n.</pos> <def>A wish of health; a salutation; a loud
call.</def> <ldquo/Their puissant <xex>hail</xex>.<rdquo/ <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The angel <qex>hail</qex> bestowed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hail-fellow</ent><br/
<hw>Hail"-fel`low</hw> <pr>(-f<ecr/l`l<osl/)</pr>, <pos>n.</pos> <def>An
intimate companion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hail-fellow</qex> well met.</q> <rj><qau>Lyly.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hailse</ent><br/
<hw>Hailse</hw> <pr>(h<amac/ls)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>hailsen</ets>, Icel. <ets>heilsa</ets>. Cf. <er>Hail</er> to call
to.]</ety> <def>To greet; to salute.</def> <mark>[Obs.]</mark>
<rj><au>P. Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hailshot</ent><br/
<hw>Hail"shot`</hw> <pr>(h<amac/l"sh<ocr/t`)</pr>, <pos>n. pl.</pos>
<def>Small shot which scatter like hailstones.</def> <mark>[Obs.]</mark>
<rj><au>Hayward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hailstone</ent><br/
<hw>Hail"stone`</hw> <pr>(-st<omac/n`)</pr>, <pos>n.</pos> <def>A single
particle of ice falling from a cloud; a frozen raindrop; a pellet of
hail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hailstorm</ent><br/
<hw>Hail"storm`</hw> <pr>(-st<ocir/rm`)</pr>, <pos>n.</pos> <def>A storm
accompanied with hail; a shower of hail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haily</ent><br/
<hw>Hail"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <def>Of hail.</def>
<ldquo/<xex>Haily</xex> showers.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hain</ent><br/
<hw>Hain</hw> <pr>(h<amac/n)</pr>, <pos>v. t.</pos> <ety>[Cf. Sw.
<ets>h<aum/gn</ets> hedge, inclosure, Dan. <ets>hegn</ets> hedge, fence.
See <er>Hedge</er>.]</ety> <def>To inclose for mowing; to set aside for
grass.</def> <ldquo/A ground . . . <xex>hained</xex> in.<rdquo/
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hain't</ent><br/
<hw>Hain't</hw> <pr>(h<amac/nt)</pr>. <def>A contraction of <sig>have
not</sig> or <sig>has not</sig>; <as>as, I <ex>hain't</ex>, he
<ex>hain't</ex>, we <ex>hain't</ex></as>.</def> <mark>[Colloq. or
illiterate speech.]</mark> <altsp>[Written also
<asp>han't</asp>.]</altsp><-- now ain't --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hair</ent><br/
<hw>Hair</hw> <pr>(h<acir/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>her</ets>, <ets>heer</ets>, <ets>h<ae/r</ets>, AS.
<ets>h<aemac/r</ets>; akin to OFries. <ets>h<emac/r</ets>, D. & G.
<ets>haar</ets>, OHG. & Icel. <ets>h<amac/r</ets>, Dan. <ets>haar</ets>,
Sw. <ets>h<aring/r</ets>; cf. Lith. <ets>kasa</ets>.]</ety> <sn>1.</sn>
<def>The collection or mass of filaments growing from the skin of an
animal, and forming a covering for a part of the head or for any part or
the whole of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One the above-mentioned filaments, consisting, in
vertebrate animals, of a long, tubular part which is free and flexible,
and a bulbous root imbedded in the skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then read he me how Sampson lost his <qex>hairs</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And draweth new delights with hoary <qex>hairs</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hair (human or animal) used for various purposes;
<as>as, <ex>hair</ex> for stuffing cushions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A slender outgrowth from the
chitinous cuticle of insects, spiders, crustaceans, and other
invertebrates. Such hairs are totally unlike those of vertebrates in
structure, composition, and mode of growth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Bot.)</fld> <def>An outgrowth of the epidermis,
consisting of one or of several cells, whether pointed, hooked, knobbed,
or stellated. Internal hairs occur in the flower stalk of the yellow
frog lily (<gen>Nuphar</gen>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A spring device used in a hair-trigger
firearm.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A haircloth.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Any very small distance, or degree; a
hairbreadth.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hairs</xex> is often used adjectively or in
combination; as, <xex>hair</xex>brush or <xex>hair</xex> brush,
<xex>hair</xex> dye, <xex>hair</xex> oil, <xex>hair</xex>pin,
<xex>hair</xex> powder, a brush, a dye, etc., for the hair.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Against the hair</b></col>, <cd>in a rough and
disagreeable manner; against the grain.</cd> <mark>[Obs.]</mark>
<ldquo/You go <xex>against the hair</xex> of your professions.<rdquo/
<au>Shak.</au> -- <col><b>Hair bracket</b></col> <fld>(Ship
Carp.)</fld>, <cd>a molding which comes in at the back of, or runs aft
from, the figurehead.</cd> -- <col><b>Hair cells</b></col>
<fld>(Anat.)</fld>, <cd>cells with hairlike processes in the sensory
epithelium of certain parts of the internal ear.</cd> --
<mcol><col><b>Hair compass</b></col>, <col><b>Hair
divider</b></col></mcol>, <cd>a compass or divider capable of delicate
adjustment by means of a screw.</cd> -- <col><b>Hair glove</b></col>,
<cd>a glove of horsehair for rubbing the skin.</cd> -- <col><b>Hair
lace</b></col>, <cd>a netted fillet for tying up the hair of the
head.</cd> <au>Swift.</au> -- <col><b>Hair line</b></col>, <cd>a line
made of hair; a very slender line.</cd> -- <col><b>Hair moth</b></col>
<fld>(Zool.)</fld>, <cd>any moth which destroys goods made of hair, esp.
<spn>Tinea biselliella</spn>.</cd> -- <col><b>Hair pencil</b></col>,
<cd>a brush or pencil made of fine hair, for painting; -- generally
called by the name of the hair used; <as>as, a camel's <ex>hair
pencil</ex>, a sable's <ex>hair pencil</ex>, etc.</as></cd> --
<col><b>Hair plate</b></col>, <cd>an iron plate forming the back of the
hearth of a bloomery fire.</cd> -- <col><b>Hair powder</b></col>, <cd>a
white perfumed powder, as of flour or starch, formerly much used for
sprinkling on the hair of the head, or on wigs.</cd> -- <col><b>Hair
seal</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of
eared seals which do not produce fur; a sea lion.</cd> -- <col><b>Hair
seating</b></col>, <cd>haircloth for seats of chairs, etc.</cd> --
<col><b>Hair shirt</b></col>, <cd>a shirt, or a band for the loins, made
of horsehair, and worn as a penance.</cd> -- <col><b>Hair
sieve</b></col>, <cd>a strainer with a haircloth bottom.</cd> --
<col><b>Hair snake</b></col>. <cd>See <er>Gordius</er>.</cd> --
<col><b>Hair space</b></col> <fld>(Printing)</fld>, <cd>the thinnest
metal space used in lines of type.</cd> -- <col><b>Hair
stroke</b></col>, <cd>a delicate stroke in writing.</cd> -- <col><b>Hair
trigger</b></col>, <cd>a trigger so constructed as to discharge a
firearm by a very slight pressure, as by the touch of a hair.</cd>
<au>Farrow.</au> -- <col><b>Not worth a hair</b></col>, <cd>of no
value.</cd> -- <col><b>To a hair</b></col>, <cd>with the nicest
distinction.</cd> -- <col><b>To split hairs</b></col>, <cd>to make
distinctions of useless nicety.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hair ball</ent><br/
<ent>hairball</ent><br/
<mhw><hw>hair"ball`</hw>, <hw>hair" ball`</hw></mhw>
<pr>(h<acir/r"b<ecr/l`)</pr>, <pos>n.</pos> <def>a compact mass of hair
that forms in the stomach of animals as a result of licking fur; <as>as,
the cat coughed up a <ex>hairball</ex> right on the new rug</as>.</def>
<wns>[wns=1 + 2]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hairbell</ent><br/
<hw>Hair"bell`</hw> <pr>(h<acir/r"b<ecr/l`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>See <er>Harebell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairbird</ent><br/
<hw>Hair"bird`</hw> <pr>(h<acir/r"b<etil/rd`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The chipping sparrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairbrained</ent><br/
<hw>Hair"brained`</hw> <pr>(h<acir/r"br<amac/nd`)</pr>, <pos>a.</pos>
<def>See <er>Harebrained</er>.</def></p>

<p><ent>Hair's breadth</ent><br/
<ent>Hairbreadth</ent><br/
<mhw><hw>Hair"breadth`</hw> <pr>(-br<ecr/dth)</pr>, <hw>Hair's"
breadth`</hw> <pr>(h<acir/rz"-)</pr></mhw>. <def>The diameter or breadth
of a hair; a very small distance; sometimes, definitely, the
forty-eighth part of an inch.</def> <altsp>[Also spelled
<asp>hairsbreadth</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Every one could sling stones at an <qex>hairbreadth</qex> and not
miss.</q> <rj><qau>Judg. xx. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairbreadth</ent><br/
<hw>Hair"breadth`</hw>, <pos>a.</pos> <def>Having the breadth of a hair;
very narrow; <as>as, a <ex>hairbreadth</ex> escape</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hair-brown</ent><br/
<hw>Hair"-brown`</hw> <pr>(-broun`)</pr>, <pos>a.</pos> <def>Of a clear
tint of brown, resembling brown human hair. It is composed of equal
proportions of red and green.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairbrush</ent><br/
<hw>Hair"brush`</hw> <pr>(-br<ucr/sh`)</pr>, <pos>n.</pos> <def>A brush
for cleansing and smoothing the hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haircloth</ent><br/
<hw>Hair"cloth`</hw> <pr>(-kl<ocr/th`)</pr>, <pos>n.</pos> <def>Stuff or
cloth made wholly or in part of hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairdresser</ent><br/
<hw>Hair"dress`er</hw> <pr>(-dr<ecr/s`<etil/r)</pr>, <pos>n.</pos>
<def>One who dresses or cuts hair; a barber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hairdressing</ent><br/
<hw>hairdressing</hw> <pos>n.</pos> <def>a toiletry for the
hair.</def><br/
<syn><b>Syn. --</b> hairtonic, hair oil, hair grease.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haired</ent><br/
<hw>Haired</hw> <pr>(h<acir/rd)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having hair.</def> <ldquo/A beast <xex>haired</xex> like a
bear.<rdquo/ <rj><au>Purchas.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In composition: Having (such) hair; <as>as,
red-<ex>haired</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairen</ent><br/
<hw>Hai"ren</hw> <pr>(h<acir/r"<eit/n)</pr>, <pos>a.</pos> <ety>[AS.
<ets>h<aemac/ren</ets>.]</ety> <def>Hairy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>hairen</qex> shirt and his ascetic diet.</q> <rj><qau>J.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hair grass</ent><br/
<hw>Hair" grass`</hw> <pr>(gr<adot/s`)</pr>. <fld>(Bot.)</fld> <def>A
grass with very slender leaves or branches; as the <spn>Agrostis
scabra</spn>, and several species of <gen>Aira</gen> or
<gen>Deschampsia</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairiness</ent><br/
<hw>Hair"i*ness</hw> <pr>(-<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The state of abounding, or being covered, with
hair.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of being hairy.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hairless</ent><br/
<hw>Hair"less</hw>, <pos>a.</pos> <def>Destitute of hair; bald.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hairlike</ent><br/
<hw>hairlike</hw> <pos>adj.</pos> <sn>1.</sn> <def>shaped like a hair;
long and slender.</def><br/
<syn><b>Syn. --</b> capillary.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>long and slender with a very fine internal
diameter.</def><br/
<syn><b>Syn. --</b> capillary.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>hairline</ent><br/
<hw>hairline</hw> <pos>n.</pos> <sn>1.</sn> <def>a very thin
line.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the natural margin formed by hair on the head,
especially the edge of growth of hair on the forehead; <as>as, a
<ex>receding</ex> hairline</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hairnet</ent><br/
<hw>hair"net`</hw> <pos>n.</pos> <def>a small net that some women wear
over their hair to keep it in place.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hairpiece</ent><br/
<hw>hair"piece`</hw> <pos>n.</pos> <def>a covering or bunch of human or
artificial hair used for disguise or adornment; a toupee.</def><br/
<syn><b>Syn. --</b> false hair, postiche, toupee.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hairpin</ent><br/
<hw>Hair"pin`</hw> <pr>(-p<icr/n`)</pr>, <pos>n.</pos> <def>A pin,
usually forked, or of bent wire, for fastening the hair in place, --
used by women.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hair-salt</ent><br/
<hw>Hair"-salt`</hw> <pr>(-s<add/lt`)</pr>, <pos>n.</pos> <ety>[A
translation of G. <ets>haarsalz</ets>.]</ety> <fld>(Min.)</fld> <def>A
variety of native Epsom salt occurring in silky fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairsplitter</ent><br/
<hw>Hair"split`ter</hw> <pr>(-spl<icr/t`t<etil/r)</pr>, <pos>n.</pos>
<def>One who makes excessively fine or needless distinctions in
reasoning; one who quibbles.</def> <ldquo/The caviling
<xex>hairsplitter</xex>.<rdquo/ <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairsplitting</ent><br/
<hw>Hair"split`ting</hw> <pr>(-t<icr/ng)</pr>, <pos>a.</pos> <def>Making
excessively fine or trivial distinctions in reasoning; overly
subtle.</def> -- <def2><pos>n.</pos> <def>The act or practice of making
trivial distinctions.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>The ancient <qex>hairsplitting</qex> technicalities of special
pleading.</q> <rj><qau>Charles Sumner.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairspring</ent><br/
<hw>Hair"spring`</hw> <pr>(-spr<icr/ng`)</pr>, <pos>n.</pos>
<fld>(Horology)</fld> <def>The slender recoil spring which regulates the
motion of the balance in a timepiece.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairstreak</ent><br/
<hw>Hair"streak`</hw> <pr>(-str<emac/k`)</pr>, <pos>n.</pos> <def>A
butterfly of the genus <gen>Thecla</gen>; <as>as, the green
<ex>hairstreak</ex> (<spn>Thecla rubi</spn>).</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairtail</ent><br/
<hw>Hair"tail`</hw> <pr>(-t<amac/l`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any species of marine fishes of the genus
<gen>Trichiurus</gen>; esp., <spn>Trichiurus lepturus</spn> of Europe
and America. They are long and like a band, with a slender, pointed
tail. Called also <altname>bladefish</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hair worm</ent><br/
<hw>Hair" worm`</hw> <pr>(w<ucir/rm`)</pr>. <fld>(Zool.)</fld> <def>A
nematoid worm of the genus <gen>Gordius</gen>, resembling a hair. See
<er>Gordius</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hairy</ent><br/
<hw>Hair"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Bearing or covered with hair; made of or resembling hair; rough
with hair; hirsute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His mantle <qex>hairy</qex>, and his bonnet sedge.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Very complicated, difficult, or involved; <as>as, a
<ex>hairy</ex> problem; a <ex>hairy</ex> equation</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Dangerous or frightening; <as>as, a <ex>hairy</ex>
encounter with a mugger</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Haiti</ent><br/
<hw>Haiti</hw> <pos>n.</pos> <sn>1.</sn> <def>a country on the island of
Hispaniola.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>an island in the West Indies.</def><br/
<syn><b>Syn. --</b> Hispaniola, Hayti.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haitian</ent><br/
<hw>Hai"ti*an</hw> <pr>(h<amac/"t<icr/*<ait/n)</pr>, <pos>a. & n.</pos>
<def>Same as <er>Haytian</er>; -- now the preferred spelling.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hajj</ent><br/
<ent>haj</ent><br/
<mhw><hw>haj</hw>, <hw>hajj</hw></mhw> <pos>n.</pos> <def>A pilgrimage
to Mecca; every Muslim must make this journey at least once.</def>
<altsp>[Also spelled <asp>hadj</asp>.]</altsp><br/
<syn><b>Syn. --</b> hadj, haj.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hajji</ent><br/
<ent>haji</ent><br/
<mhw><hw>haj"i</hw>, <hw>haj"ji</hw></mhw> <pr>(h<aum/"j<esl/)</pr>,
<pos>n.</pos> <def>One who has made a journey to Mecca; Same as
<er>hadji</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Haje</ent><br/
<hw>Ha"je</hw> <pr>(h<aum/"j<esl/)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>hayya</ets> snake.]</ety> <fld>(Zool.)</fld> <def>The Egyptian asp
or cobra (<spn>Naja haje</spn>.) It is related to the cobra of India,
and like the latter has the power of inflating its neck into a hood. Its
bite is very venomous. It is supposed to be the snake by means of whose
bite Cleopatra committed suicide, and hence is sometimes called
<altname>Cleopatra's snake</altname> or <altname>asp</altname>. See
<er>Asp</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hake</ent><br/
<hw>Hake</hw> <pr>(h<amac/k)</pr>, <pos>n.</pos> <ety>[See
<er>Hatch</er> a half door.]</ety> <def>A drying shed, as for unburned
tile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hake</ent><br/
<hw>Hake</hw>, <pos>n.</pos> <altsp>[Also <asp>haak</asp>.]</altsp>
<ety>[Akin to Norweg. <ets>hake</ets>fisk, lit., hook fish, Prov. E.
<ets>hake</ets> hook, G. <ets>hecht</ets> pike. See
<er>Hook</er>.]</ety> <fld>(Zool.)</fld> <def>One of several species of
marine gadoid fishes, of the genera <gen>Phycis</gen>,
<gen>Merlucius</gen>, and allies. The common European hake is
<spn>Merlucius vulgaris</spn>; the American silver hake or whiting is
<spn>Merlucius bilinearis</spn>. Two American species (<spn>Phycis
chuss</spn> and <spn>Phycis tenius</spn>) are important food fishes, and
are also valued for their oil and sounds. Called also <altname>squirrel
hake</altname>, and <altname>codling</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hake</ent><br/
<hw>Hake</hw> <pr>(h<amac/k)</pr>, <pos>v. i.</pos> <def>To loiter; to
sneak.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hake's-dame</ent><br/
<hw>Hake's"-dame`</hw> <pr>(h<amac/ks"d<amac/m`)</pr>, <pos>n.</pos>
<def>See <er>Forkbeard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haketon</ent><br/
<hw>Hak"e*ton</hw> <pr>(h<acr/k"<esl/*t<ocr/n)</pr>, <pos>n.</pos>
<def>Same as <er>Acton</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hakim</ent><br/
\'d8<hw>Ha*kim"</hw> <pr>(h<adot/*k<emac/m")</pr>, <pos>n.</pos>
<ety>[Ar. <ets>hak<imac/m</ets>.]</ety> <def>A wise man; a physician,
esp. a Muslim.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hakim</ent><br/
\'d8<hw>Ha"kim</hw> <pr>(h<aum/"k<emac/m)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>h<amac/kim</ets>.]</ety> <def>A Muslim title for a ruler; a
judge.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hal</ent><br/
<hw>Hal</hw> <pr>(h<acir/l)</pr>, <pos>prop. n.</pos> <def>Harold; -- a
nickname.</def><br/
[<source>PJC</source>]</p>

<p><ent>HAL</ent><br/
<hw>HAL</hw> <pr>(h<acir/l)</pr>, <pos>prop. n.</pos> <def>The name of
an intelligent computer in the movie <film>2001</film>, directed by
<person>Stanley Kubrick</person>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Halacha</ent><br/
<hw>Ha*la"cha</hw> <pr>(h<adot/*l<aum/"k<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Halachoth</plw> <pr>(-k<omac/th)</pr>.</plu>
<ety>[Heb. <ets>hal<amac/ch<amac/h</ets>.]</ety> <def>The general term
for the Hebrew oral or traditional law; one of two branches of
exposition in the Midrash. See <er>Midrash</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halation</ent><br/
<hw>Ha*la"tion</hw> <pr>(h<asl/*l<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<fld>(Photog.)</fld> <def>An appearance as of a halo of light,
surrounding the edges of dark objects in a photographic
picture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halberd</ent><br/
<hw>Hal"berd</hw> <pr>(h<ocr/l"b<etil/rd; 277)</pr>, <pos>n.</pos>
<ety>[F. <ets>hallebarde</ets>; of German origin; cf. MHG.
<ets>helmbarte</ets>, G. <ets>hellebarte</ets>; prob. orig., an ax to
split a helmet, fr. G. <ets>barte</ets> a broad ax (orig. from the same
source as E. <ets>beard</ets>; cf. Icel. <ets>bar<edh/a</ets>, a kind of
ax, <ets>skegg</ets> beard, <ets>skeggja</ets> a kind of halberd) +
<ets>helm</ets> helmet; but cf. also MHG. <ets>helm</ets>,
<ets>halm</ets>, handle, and E. <ets>helve</ets>. See <er>Beard</er>,
<er>Helmet</er>.]</ety> <fld>(Mil.)</fld> <def>An ancient long-handled
weapon, of which the head had a point and several long, sharp edges,
curved or straight, and sometimes additional points. The heads were
sometimes of very elaborate form.</def> <altsp>[Written also
<asp>halbert</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halberdier</ent><br/
<hw>Hal`berd*ier"</hw> <pr>(h<ocr/`b<etil/rd*<emac/r")</pr>,
<pos>n.</pos> <ety>[F. <ets>hallebardier</ets>.]</ety> <def>One who is
armed with a halberd.</def> <rj><au>Strype.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halberd-shaped</ent><br/
<hw>Hal"berd-shaped`</hw> <pr>(-sh<amac/pt`)</pr>, <pos>a.</pos>
<def>Hastate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halcyon</ent><br/
<hw>Hal"cy*on</hw> <pr>(h<acr/l"s<icr/*<ocr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>halcyon</ets>, <ets>alcyon</ets>, Gr. <grk>"alkyw`n</grk>,
<grk>'alkyw`n</grk>: cf. F. <ets>halcyon</ets>.]</ety>
<fld>(Zool.)</fld> <def>A kingfisher. By modern ornithologists
restricted to a genus including a limited number of species having
omnivorous habits, as the sacred kingfisher (<spn>Halcyon sancta</spn>)
of Australia.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Amidst our arms as quiet you shall be<br/
As <qex>halcyons</qex> brooding on a winter sea.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halcyon</ent><br/
<hw>Hal"cy*on</hw>, <pos>a.</pos> <sn>1.</sn> <def>Pertaining to, or
resembling, the halcyon, which was anciently said to lay her eggs in
nests on or near the sea during the calm weather about the winter
solstice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Calm; quiet; peaceful; undisturbed;
happy.</def> <ldquo/Deep, <xex>halcyon</xex> repose.<rdquo/ <rj><au>De
Quincy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halcyonian</ent><br/
<hw>Hal`cy*o"ni*an</hw> <pr>(h<acr/l`s<icr/*<omac/"n<icr/*<ait/n)</pr>,
<pos>a.</pos> <def>Halcyon; calm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halcyonoid</ent><br/
<hw>Hal"cy*o*noid</hw> <pr>(h<acr/l"s<icr/*<osl/*noid)</pr>, <pos>a. &
n.</pos> <ety>[<ets>Halcyon</ets> + <ets>-oid</ets>.]</ety>
<fld>(Zool.)</fld> <def>See <er>Alcyonoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hale</ent><br/
<hw>Hale</hw> <pr>(h<amac/l)</pr>, <pos>a.</pos> <altsp>[Written also
<asp>hail</asp>.]</altsp> <ety>[OE. <ets>heil</ets>, Icel.
<ets>heill</ets>; akin to E. <ets>whole</ets>. See
<er>Whole</er>.]</ety> <def>Sound; entire; healthy; robust; not
impaired; <as>as, a <ex>hale</ex> body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Last year we thought him strong and <qex>hale</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hale</ent><br/
<hw>Hale</hw>, <pos>n.</pos> <def>Welfare.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All heedless of his dearest <qex>hale</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hale</ent><br/
<hw>Hale</hw> <pr>(h<amac/l <or/ h<add/l; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Haled</conjf> <pr>(h<amac/ld
<it>or</it> h<add/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Haling</conjf>.]</vmorph> <ety>[OE. <ets>halen</ets>,
<ets>halien</ets>; cf. AS. <ets>holian</ets>, to acquire, get. See
<er>Haul</er>.]</ety> <def>To pull; to drag; to haul.</def> See
<er>Haul</er>. <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Easier both to freight, and to <qex>hale</qex> ashore.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As some dark priest <qex>hales</qex> the reluctant victim.</q>
<rj><qau>Shelley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halenia</ent><br/
<hw>Halenia</hw> <pos>n.</pos> <def>A genus of herbs of Eurasia and the
Americas: spurred gentians.</def><br/
<syn><b>Syn. --</b> genus <gen>Halenia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Halesia</ent><br/
\'d8<hw>Ha*le"si*a</hw> <pr>(h<adot/*l<emac/"zh<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <fld>(Bot.)</fld> <def>A genus of
American shrubs containing several species, called <altname>snowdrop
trees</altname>, or silver-bell trees. They have showy, white flowers,
drooping on slender pedicels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half</ent><br/
<hw>Half</hw> <pr>(h<aum/f)</pr>, <pos>a.</pos> <ety>[AS.
<ets>healf</ets>, <ets>half</ets>, half; as a noun, half, side, part;
akin to OS., OFries., & D. <ets>half</ets>, G. <ets>halb</ets>, Sw.
<ets>half</ets>, Dan. <ets>halv</ets>, Icel. <ets>h<amac/lfr</ets>,
Goth. <ets>halbs</ets>. Cf. <er>Halve</er>, <er>Behalf</er>.]</ety>
<sn>1.</sn> <def>Consisting of a moiety, or half; <as>as, a
<ex>half</ex> bushel; a <ex>half</ex> hour; a <ex>half</ex> dollar; a
<ex>half</ex> view.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The adjective and noun are often united to form a
compound.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of some indefinite portion resembling a
half; approximately a half, whether more or less; partial; imperfect;
<as>as, a <ex>half</ex> dream; <ex>half</ex> knowledge.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Assumed from thence a <qex>half</qex> consent.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Half ape</b></col> <fld>(Zool.)</fld>, <cd>a lemur.</cd>
-- <col><b>Half back</b></col>. <fld>(Football)</fld> <cd>See under 2d
<er>Back</er>.</cd> -- <col><b>Half bent</b></col>, <cd>the first notch,
for the sear point to enter, in the tumbler of a gunlock; the halfcock
notch.</cd> -- <col><b>Half binding</b></col>, <cd>a style of
bookbinding in which only the back and corners are in leather.</cd> --
<col><b>Half boarder</b></col>, <cd>one who boards in part;
specifically, a scholar at a boarding school who takes dinner only.</cd>
-- <col><b>Half-breadth plan</b></col> <fld>(Shipbuilding)</fld>, <cd>a
horizontal plan of one half a vessel, divided lengthwise, showing the
lines.</cd> -- <col><b>Half cadence</b></col> <fld>(Mus.)</fld>, <cd>a
cadence on the dominant.</cd> -- <col><b>Half cap</b></col>, <cd>a
slight salute with the cap.</cd> <mark>[Obs.]</mark> <au>Shak.</au> --
<col><b>At half cock</b></col>, <cd>the position of the cock of a gun
when retained by the first notch.</cd><-- half cocked: see below,
halfcocked: = unprepared, lacking forethought; -- as in go off half
cocked --> -- <col><b>Half hitch</b></col>, <cd>a sailor's knot in a
rope; half of a clove hitch.</cd> -- <col><b>Half hose</b></col>,
<cd>short stockings; socks.</cd> -- <col><b>Half measure</b></col>,
<cd>an imperfect or weak line of action.</cd> -- <col><b>Half
note</b></col> <fld>(Mus.)</fld>, <cd>a minim, one half of a
semibreve.</cd> -- <col><b>Half pay</b></col>, <cd>half of the wages or
salary; reduced pay; as, an officer on <xex>half pay</xex>.</cd> --
<col><b>Half price</b></col>, <cd>half the ordinary price; or a price
much reduced.</cd> -- <col><b>Half round</b></col>. <sd>(a)</sd>
<fld>(Arch.)</fld> <cd>A molding of semicircular section.</cd>
<sd>(b)</sd> <fld>(Mech.)</fld> <cd>Having one side flat and the other
rounded; -- said of a file.</cd> -- <col><b>Half shift</b></col>
<fld>(Mus.)</fld>, <cd>a position of the hand, between the open position
and the first shift, in playing on the violin and kindred instruments.
See <er>Shift</er>.</cd> -- <col><b>Half step</b></col>
<fld>(Mus.)</fld>, <cd>a semitone; the smallest difference of pitch or
interval, used in music.</cd> -- <col><b>Half tide</b></col>, <cd>the
time or state of the tide equally distant from ebb and flood.</cd> --
<col><b>Half time</b></col>, <cd>half the ordinary time for work or
attendance; as, the <xex>half-time</xex> system.</cd> -- <col><b>Half
tint</b></col> <fld>(Fine Arts)</fld>, <cd>a middle or intermediate
tint, as in drawing or painting. See <er>Demitint</er>.</cd> --
<col><b>Half truth</b></col>, <cd>a statement only partially true, or
which gives only a part of the truth.</cd> <au>Mrs. Browning.</au> --
<col><b>Half year</b></col>, <cd>the space of six months; one term of a
school when there are two terms in a year.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 665 pr=JMD --></p>

<p><ent>Half</ent><br/
<hw>Half</hw>, <pos>adv.</pos> <def>In an equal part or degree; in some
part approximating a half; partially; imperfectly; <as>as,
<ex>half</ex>-colored, <ex>half</ex> done, <ex>half</ex>-hearted,
<ex>half</ex> persuaded, <ex>half</ex> conscious</as>.</def>
<ldquo/<xex>Half</xex> loth and <xex>half</xex> consenting.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their children spoke <qex>half</qex>in the speech of Ashdod.</q>
<rj><qau>Neh. xiii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half</ent><br/
<hw>Half</hw> <pr>(h<aum/f)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Halves</plw> <pr>(h<aum/vz)</pr>.</plu> <ety>[AS. <ets>healf</ets>.
See <er>Half</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>Part; side;
behalf.</def> <mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The four <qex>halves</qex> of the house.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of two equal parts into which anything may be
divided, or considered as divided; -- sometimes followed by
<xex>of</xex>; <as>as, a <ex>half</ex> of an apple</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>half</qex> his riches known, and yet despised.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A friendship so complete<br/
Portioned in <qex>halves</qex> between us.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Better half</b></col>. <cd>See under
<er>Better</er>.</cd> -- <col><b>In half</b></col>, <cd>in two; an
expression sometimes used improperly instead of <altname>in
halves</altname> or <altname>into halves</altname>; <as>as, to cut
<ex>in half</ex></as>.</cd> <mark>[Colloq.]</mark> <au>Dickens.</au> --
<mcol><col><b>In one's half</b></col> <it>or</it> <col><b>On one's
half</b></col></mcol>, <cd>in one's behalf; on one's part.</cd>
<mark>[Obs.]</mark> -- <col><b>To cry halves</b></col>, <cd>to claim an
equal share with another.</cd> -- <col><b>To go halves</b></col>, <cd>to
share equally between two.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half</ent><br/
<hw>Half</hw>, <pos>v. t.</pos> <def>To halve. <mark>[Obs.]</mark> See
<er>Halve</er>.</def> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-and-half</ent><br/
<hw>Half`-and-half"</hw>, <pos>n.</pos> <def>A mixture of two malt
liquors, esp. porter and ale, in about equal parts.</def>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>halfback</ent><br/
<hw>halfback</hw> <pos>n.</pos> <fld>(Football)</fld> <def>A person who
plays the position of halfback{2} on a football team.</def><br/
<syn><b>Syn. --</b> running back.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The position of either of two players on a football
team who typically begins each play behind the line and on either side
of the quarterback.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>half-baked</ent><br/
<hw>half-baked</hw> <pos>a.</pos> <sn>1.</sn> <def>Insufficiently or
poorly planned or thought out; impractical or unrealistic; <as>as, a
<ex>half-baked</ex> proposal; <ex>half-baked</ex> ideas</as>; -- of
plans, theories, proposals, etc.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Insufficiently cooked; -- of food.</def><br/
[<source>PJC</source>]</p>

<p><ent>Halfbeak</ent><br/
<hw>Half"beak`</hw> <pr>(h<aum/f"b<emac/k)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any slender, marine fish of the genus
<gen>Hemirhamphus</gen>, or of the family <fam>Hemiramphidae</fam>,
having an elongated protruding lower jaw; -- called also
<altname>balahoo</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half blood</ent><br/
<hw>Half" blood`</hw> <pr>(h<aum/f"bl<ucr/d`)</pr>. <sn>1.</sn> <def>The
relation between persons born of the same father or of the same mother,
but not of both; <as>as, a brother or sister of the <ex>half
blood</ex></as>. See <er>Blood</er>, <pos>n.</pos>, 2 and 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person so related to another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person whose father and mother are of different
races; a half-breed.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the 2d and 3d senses usually with a
hyphen.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-blooded</ent><br/
<hw>Half"-blood`ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Proceeding from
a male and female of different breeds or races; having only one parent
of good stock; <as>as, a <ex>half-blooded</ex> sheep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Degenerate; mean.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-boot</ent><br/
<hw>Half"-boot`</hw> <pr>(h<aum/f"b<oomac/t`)</pr>, <pos>n.</pos> <def>A
boot with a short top covering only the ankle. See <er>Cocker</er>, and
<cref>Congress boot</cref>, under <er>Congress</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-bound</ent><br/
<hw>Half"-bound`</hw> <pr>(-bound`)</pr>, <pos>n.</pos> <def>Having only
the back and corners in leather, as a book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-bred</ent><br/
<hw>Half"-bred`</hw> <pr>(-br<ecr/d`)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Half-blooded.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Imperfectly acquainted with the rules of
good-breeding; not well trained.</def> <rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-breed</ent><br/
<hw>Half"-breed`</hw> <pr>(-br<emac/d`)</pr>, <pos>a.</pos>
<def>Half-blooded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-breed</ent><br/
<hw>Half"-breed`</hw>, <pos>n.</pos> <def>A person who is half-blooded;
the offspring of parents of different races, especially of the American
Indian and the white race.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-brother</ent><br/
<hw>Half"-broth`er</hw> <pr>(-br<ucr/th`<etil/r)</pr>, <pos>n.</pos>
<def>A brother by one parent, but not by both.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-caste</ent><br/
<hw>Half"-caste`</hw> <pr>(-k<adot/st)</pr>, <pos>n.</pos> <def>One born
of a European parent on the one side, and of a Hindu or Muslim on the
other. Also adjective; <as>as, <ex>half-caste</ex>
parents</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-clammed</ent><br/
<hw>Half"-clammed`</hw> <pr>(-kl<acr/md`)</pr>, <pos>a.</pos>
<def>Half-filled.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lions' <qex>half-clammed</qex> entrails roar for food.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halfcock</ent><br/
<hw>Half"cock`</hw> <pr>(-k<ocr/k`)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos>
<conjf>Halfcocked</conjf><pr>(-k<ocr/kt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Halfcocking</conjf>.]</vmorph> <def>To set the cock of
(a firearm) at the first notch.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To go off half-cocked</b></col>, <col><b>To go off
halfcocked</b></col></mcol>. <sd>(a)</sd> <cd>To be discharged
prematurely, or with the trigger at half cock; -- said of a
firearm.</cd> <sd>(b)</sd> <cd>To do or say something without due
thought or care.</cd> <mark>[Colloq. or Low]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-cracked</ent><br/
<hw>Half"-cracked`</hw> <pr>(-kr<acr/kt`)</pr>, <pos>a.</pos>
<def>Half-demented; half-witted.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-deck</ent><br/
<hw>Half"-deck`</hw> <pr>(-d<ecr/k`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A shell of the genus <gen>Crepidula</gen>; a
boat shell. See <er>Boat shell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <cref>Half deck</cref>, under
<er>Deck</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-decked</ent><br/
<hw>Half"-decked`</hw> <pr>(-d<ecr/kt)</pr>, <pos>a.</pos>
<def>Partially decked.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>half-decked</qex> craft . . . used by the latter
Vikings.</q> <rj><qau>Elton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halfen</ent><br/
<hw>Half"en</hw> <pr>(-'n)</pr>, <pos>a.</pos> <ety>[From
<er>Half</er>.]</ety> <def>Wanting half its due qualities.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halfendeal</ent><br/
<hw>Half"en*deal`</hw> <pr>(-'n*d<emac/l`)</pr>, <pos>adv.</pos>
<ety>[OE. <ets>halfendele</ets>. See <er>Half</er>, and
<er>Deal</er>.]</ety> <def>Half; by the half part.</def>
<mark>[Obs.]</mark> <au>Chaucer.</au> -- <def2><pos>n.</pos> <def>A half
part.</def> <mark>[Obs.]</mark> <au>R. of Brunne.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halfer</ent><br/
<hw>Half"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who possesses or gives half only; one who shares.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A male fallow deer gelded.</def> <rj><au>Pegge
(1814).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-faced</ent><br/
<hw>Half"-faced`</hw> <pr>(-f<amac/st`)</pr>, <pos>a.</pos> <def>Showing
only part of the face; wretched looking; meager.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-fish</ent><br/
<hw>Half"-fish`</hw> <pr>(-f<icr/sh`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A salmon in its fifth year of growth.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-hatched</ent><br/
<hw>Half"-hatched`</hw> <pr>(-h<acr/cht`)</pr>, <pos>a.</pos>
<def>Imperfectly hatched; <as>as, <ex>half-hatched</ex> eggs</as>.</def>
<rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-heard</ent><br/
<hw>Half"-heard`</hw> <pr>(-h<etil/rd`)</pr>, <pos>a.</pos>
<def>Imperfectly or partly heard; not heard to the end.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And leave <qex>half-heard</qex> the melancholy tale.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-hearted</ent><br/
<ent>halfhearted</ent><br/
<mhw><hw>half"heart`ed</hw>, <hw>Half"-heart`ed</hw></mhw>
<pr>(-h<aum/rt`<ecr/d)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Wanting in
heart or spirit; ungenerous; unkind.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lacking zeal or courage; performed with less than a
full effort; lukewarm; unenthusiastic; <as>as, a <ex>half-hearted</ex>
attempt</as>; -- of actions.</def> <wns>[wns=1]</wns> <rj><au>H.
James.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>half-holiday</ent><br/
<hw>half-holiday</hw> <pos>n.</pos> <def>a day on which half of the day
is free from work or duty; a holiday of one half of a day.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Half-hourly</ent><br/
<hw>Half"-hour`ly</hw> <pr>(-our`l<ycr/)</pr>, <pos>a.</pos> <def>Done
or happening at intervals of half an hour.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-learned</ent><br/
<hw>Half"-learned`</hw> <pr>(h<aum/f"l<etil/rnd`)</pr>, <pos>a.</pos>
<def>Imperfectly learned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-length</ent><br/
<hw>Half"-length`</hw> <pr>(-l<ecr/ngth`)</pr>, <pos>a.</pos> <def>Of
half the whole or ordinary length, as a picture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-life</ent><br/
<hw>Half"-life`</hw> <pr>(h<aum/f"l<imac/f`)</pr>, <pos>n.</pos>
<fld>(Physics)</fld> <def>the time it takes for one-half of a substance
decaying in a first-order reaction to be destroyed. For radioactive
substances, it is the time required for one-half of the initial amount
of the radioactive isotope to decay. The <ex>half-life</ex>is a measure
of the rate of the reaction being observed. For processes that are true
first-order processes, such as radioactive decay, the <ex>half-life</ex>
is independent of the quantity of material present, and it is thus a
constant. The time it takes for one-half the remaining quantity of a
radioactive isotope to decay will be the same regardless of how far the
decay process has advanced. Some chemical reactions are also first
order, and may be characterized as having a <ex>half-life.</ex> However,
for chemical reactions the <ex>half-life</ex> will depend upon
temperature and in some cases other environmental conditions, whereas
for radioactive isotopes the rate of decay is largely independent of the
environment.</def><br/
[<source>PJC</source>]</p>

<p><ent>half-light</ent><br/
<hw>half-light</hw> <pos>n.</pos> <def>a grayish light (as at dawn or
dusk or in dim interiors).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Half-mast</ent><br/
<hw>Half"-mast`</hw> <pr>(-m<adot/st`)</pr>, <pos>n.</pos> <def>A point
some distance below the top of a mast or staff; <as>as, a flag a
<ex>half-mast</ex> (a token of mourning, etc.)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-moon</ent><br/
<hw>Half"-moon`</hw> <pr>(-m<oomac/n`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The moon at the quarters, when half its disk appears
illuminated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The shape of a half-moon; a crescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>See how in warlike muster they appear,<br/
In rhombs, and wedges, and <qex>half-moons</qex>, and wings.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Fort.)</fld> <def>An outwork composed of two faces,
forming a salient angle whose gorge resembles a half-moon; -- now called
a <altname>ravelin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A marine, sparoid, food fish of
California (<spn>Caesiosoma Californiense</spn>). The body is ovate,
blackish above, blue or gray below. Called also
<altname>medialuna</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half nelson</ent><br/
<hw>Half nelson</hw>. <fld>(Wrestling)</fld> <def>A hold in which one
arm is thrust under the corresponding arm of the opponent, generally
behind, and the hand placed upon the back of his neck. In the
<col><b>full nelson</b></col> both hands are so placed.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Halfness</ent><br/
<hw>Half"ness</hw> <pr>(h<aum/f"n<ecr/s)</pr>, <pos>n.</pos> <def>The
quality of being half; incompleteness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As soon as there is any departure from simplicity, and attempt at
<qex>halfness</qex>, or good for me that is not good for him, my
neighbor feels the wrong.</q> <rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halfpace</ent><br/
<hw>Half"pace`</hw> <pr>(-p<amac/s`)</pr>, <pos>n.</pos>
<fld>(Arch.)</fld> <def>A platform of a staircase where the stair turns
back in exactly the reverse direction of the lower flight. See
<er>Quarterpace</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term and <contr>quarterpace</contr> are rare or
unknown in the United States, <altname>platform</altname> or
<altname>landing</altname> being used instead.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>halfpence</ent><br/
<hw>half"pence</hw> <pr>(h<amac/"p<ecr/ns)</pr>, <pos>n.</pos> <def>an
English coin worth half a penny; -- no longer minted.</def><br/
<syn><b>Syn. --</b> halfpenny, ha'penny.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>half-penny</ent><br/
<ent>halfpenny</ent><br/
<mhw><hw>half"pen*ny</hw>, <hw>half"-pen*ny</hw></mhw>
<pr>(h<amac/"p<ecr/n*n<ycr/ <or/ h<aum/f"-; 277)</pr>,
<pos>n.</pos>;<plu><it>pl.</it> <plw>Half-pence</plw>
<pr>(-p<eit/ns)</pr> or
<plw>Half-pennies</plw><pr>(-p<ecr/n*n<icr/z)</pr>.</plu> <def>An
English coin of the value of half a penny, no longer minted; also, the
value of half a penny.</def><br/
<syn><b>Syn. --</b> ha'penny.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>halfpennyworth</ent><br/
<hw>halfpennyworth</hw> <pos>n.</pos> <def>the amount that can be bought
for a halfpenny.</def><br/
<syn><b>Syn. --</b> ha'p'orth.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Half-pike</ent><br/
<hw>Half"-pike`</hw> <pr>(h<aum/f"p<imac/k`)</pr>, <pos>n.</pos>
<fld>(Mil.)</fld> <def>A short pike, sometimes carried by officers of
infantry, sometimes used in boarding ships; a spontoon.</def>
<rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-port</ent><br/
<hw>Half"-port`</hw> <pr>(-p<omac/rt`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>One half of a shutter made in two parts for
closing a porthole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-ray</ent><br/
<hw>Half"-ray`</hw> <pr>(-r<amac/`)</pr>, <pos>n.</pos>
<fld>(Geom.)</fld> <def>A straight line considered as drawn from a
center to an indefinite distance in one direction, the complete ray
being the whole line drawn to an indefinite distance in both
directions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-read</ent><br/
<hw>Half"-read`</hw> <pr>(-r<ecr/d`)</pr>, <pos>a.</pos> <def>Informed
by insufficient reading; superficial; shallow.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half seas over</ent><br/
<hw>Half" seas` o"ver</hw> <pr>(s<emac/z` <omac/"v<etil/r)</pr>.
<def>Half drunk.</def> <mark>[Slang: used only predicatively.]</mark>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-sighted</ent><br/
<hw>Half"-sight`ed</hw> <pr>(-s<imac/t`<ecr/d)</pr>, <pos>a.</pos>
<def>Seeing imperfectly; having weak discernment.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-sister</ent><br/
<hw>Half"-sis`ter</hw> <pr>(-s<icr/s`t<etil/r)</pr>, <pos>n.</pos>
<def>A sister by one parent only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-strained</ent><br/
<hw>Half"-strained`</hw> <pr>(h<aum/f"str<amac/nd`)</pr>, <pos>a.</pos>
<def>Half-bred; imperfect.</def> <mark>[R.]</mark> <ldquo/A
<xex>half-strained</xex> villain.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-sword</ent><br/
<hw>Half"-sword`</hw> <pr>(h<aum/f"s<omac/rd`)</pr>, <pos>n.</pos>
<def>Half the length of a sword; close fight.</def> <ldquo/At
<xex>half-sword</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-timbered</ent><br/
<hw>Half"-tim`bered</hw> <pr>(h<aum/f"t<icr/m`b<etil/rd)</pr>,
<pos>a.</pos> <fld>(Arch.)</fld> <def>Constructed of a timber frame,
having the spaces filled in with masonry; -- said of
buildings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>halftime</ent><br/
<hw>half"time`</hw> <pos>n.</pos> <def>an intermission between the first
and second half of a game, especially a football game. Also used
attributively, as the <ex>halftime</ex> entertainment</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Half-tone</ent><br/
<ent>Half tone</ent><br/
<mhw>{ <hw>Half tone</hw>, <it>or</it> <hw>Half"-tone`</hw> }</mhw>,
<pos>n.</pos> <sn>1.</sn> <fld>(Fine Arts)</fld> <def>An intermediate or
middle tone in a painting, engraving, photograph, etc.; a middle tint,
neither very dark nor very light.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Music)</fld> <def>A half step.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>A print obtained by the half-tone photo-engraving
process.</def> <wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>the etched plate used to reproduce a half-tone
illustration.</def> <wns>[wns=4]</wns><br/
<syn><b>Syn. --</b> halftone engraving, photoengraving.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Half-tone</ent><br/
<hw>Half"-tone`</hw> <pr>(h<aum/f"t<omac/n`)</pr>, <pos>a.</pos>
<def>Having, consisting of, or pertaining to, half tones;</def>
<specif>specif.</specif> (<fld>Photo-engraving</fld>), <def>pertaining
to or designating plates, processes, or the pictures made by them, in
which gradation of tone in the photograph is reproduced by a graduated
system of dotted and checkered spots, usually nearly invisible to the
unaided eye, produced by the interposition between the camera and the
object of a screen. The name alludes to the fact that this process was
the first that was practically successful in reproducing the half tones
of the photograph.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Half-tongue</ent><br/
<hw>Half"-tongue`</hw> <pr>(h<aum/f"t<ucr/ng`)</pr>, <pos>n.</pos>
<fld>(O. Law)</fld> <def>A jury, for the trial of a foreigner, composed
equally of citizens and aliens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>half-tracked</ent><br/
<ent>half-track</ent><br/
<mhw><hw>half-track</hw>, <hw>half-tracked</hw></mhw> <pos>adj.</pos>
<def>having caterpillar treads on the rear and wheels in front; <as>as,
<ex>half-track</ex> armored vehicles</as>.</def><br/
<syn><b>Syn. --</b> half-track.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>half-track</ent><br/
<hw>half-track</hw> <pos>n.</pos> <def>a half-tracked vehicle; -- used
mostly of armored military vehicles.</def><br/
[<source>PJC</source>]</p>

<p><ent>half-truth</ent><br/
<hw>half"-truth`</hw> <pr>(h<aum/f"tr<oomac/th)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>half-truths</plw>
<pr>(h<aum/f"tr<oomac/<th/z)`</pr>.</plu> <def>a partially true
statement, especially one intended to deceive or mislead.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Halfway</ent><br/
<hw>Half"way`</hw> <pr>(h<aum/f"w<amac/`)</pr>, <pos>adv.</pos> <def>In
the middle; at half the distance; imperfectly; partially; <as>as, he
<ex>halfway</ex> yielded</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Temples proud to meet their gods <qex>halfway</qex>.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halfway</ent><br/
<hw>Half"way`</hw>, <pos>a.</pos> <def>Equally distant from the
extremes; situated at an intermediate point; midway; <as>as, at the
<ex>halfway</ex> mark</as>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> center(prenominal), middle(prenominal),
midway.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>partial.</def> <wns>[wns=2]</wns><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>including only half or a portion; incomplete;
<as>as, <ex>halfway</ex> measures</as>.</def> <wns>[wns=3]</wns><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><cs><col><b>Halfway covenant</b></col>, <cd>a practice among the
Congregational churches of New England, between 1657 and 1662, of
permitting baptized persons of moral life and orthodox faith to enjoy
all the privileges of church membership, save the partaking of the
Lord's Supper. They were also allowed to present their children for
baptism.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>halfway house</ent><br/
<hw>half"way house`</hw>, <sn>1.</sn> <def>an inn or place of call
midway on a journey.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A residence for former convicts, persons recovering
from mental illness, or from drug or alcohol addiction, serving as an
intermediate environment between total confinement and complete freedom,
and having structured programs designed to ease successful reintegration
into society.</def><br/
[<source>PJC</source>]</p>

<p><ent>Half-wit</ent><br/
<hw>Half"-wit`</hw> <pr>(-w<icr/t`)</pr>, <pos>n.</pos> <def>A foolish
person; a dolt; a blockhead; a dunce.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-witted</ent><br/
<hw>Half"-wit`ted</hw> <pr>(-t<ecr/d)</pr>, <pos>a.</pos> <def>Weak in
intellect; silly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Half-yearly</ent><br/
<hw>Half"-year`ly</hw> <pr>(-y<emac/r`l<ycr/)</pr>, <pos>a.</pos>
<def>Two in a year; semiannual.</def> -- <def2><pos>adv.</pos>
<def>Twice in a year; semiannually.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halibut</ent><br/
<hw>Hal"i*but</hw> <pr>(h<ocr/l"<icr/*b<ucr/t; 277)</pr>, <pos>n.</pos>
<ety>[OE. <ets>hali</ets> holy + <ets>but</ets>, <ets>butte</ets>,
flounder; akin to D. <ets>bot</ets>, G. <ets>butte</ets>; cf. D.
<ets>heilbot</ets>, G. <ets>heilbutt</ets>. So named as being eaten on
holidays. See <er>Holy</er>, <er>Holiday</er>.]</ety> <fld>(Zool.)</fld>
<def>A large, northern, marine flatfish (<spn>Hippoglossus
vulgaris</spn>), of the family <fam>Pleuronectidae</fam>. It often grows
very large, weighing more than three hundred pounds. It is an important
food fish.</def> <altsp>[Written also <asp>holibut</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halichondriae</ent><br/
\'d8<hw>Hal`i*chon"dri*ae</hw>
<pr>(h<acr/l`<icr/*k<ocr/n"dr<icr/*<emac/)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"a`ls</grk>, <grk>"alo`s</grk>, sea +
<grk>cho`ndros</grk> cartilage.]</ety> <fld>(Zool.)</fld> <def>An order
of sponges, having simple siliceous spicules and keratose fibers; --
called also <altname>Keratosilicoidea</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halicore</ent><br/
\'d8<hw>Hal"i*core</hw> <pr>(h<acr/l"<icr/*k<omac/r; L.
h<adot/*l<icr/k"<osl/*r<emac/)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>"a`ls</grk> sea + <grk>ko`rh</grk> maiden.]</ety> <def>Same as
<er>Dugong</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halidom</ent><br/
<hw>Hal"i*dom</hw> <pr>(h<acr/l"<icr/*d<ucr/m)</pr>, <pos>n.</pos>
<ety>[AS. <ets>h<amac/ligd<omac/m</ets> holiness, sacrament, sanctuary,
relics; <ets>h<amac/lig</ets> holy + <ets>-d<omac/m</ets>, E.
<ets>-dom</ets>. See <er>Holy</er>.]</ety> <sn>1.</sn> <def>Holiness;
sanctity; sacred oath; sacred things; sanctuary; -- used chiefly in
oaths.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So God me help and <qex>halidom</qex>.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By my <qex>halidom</qex>, I was fast asleep.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Holy doom; the Last Day.</def> <mark>[R.]</mark>
<rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halieutics</ent><br/
<hw>Hal`i*eu"tics</hw> <pr>(-<umac/"t<icr/ks)</pr>, <pos>n.</pos>
<ety>[L. <ets>halieuticus</ets> pertaining to fishing, Gr.
<grk>"alieytiko`s</grk>.]</ety> <def>A treatise upon fish or the art of
fishing; ichthyology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halimas</ent><br/
<hw>Hal"i*mas</hw> <pr>(-m<acr/s)</pr>, <pos>a.</pos> <ety>[See
<er>Hallowmas</er>.]</ety> <def>The feast of All Saints;
Hallowmas.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halimodendron</ent><br/
<hw>Halimodendron</hw> <pos>n.</pos> <def>A genus of trees consisting of
one species, the salt tree.</def><br/
<syn><b>Syn. --</b> genus <gen>Halimodendron</gen>.</syn><br/
<-- ? salt tree (Athel tree) is <spn>Tamarix aphylla</spn>? -->
[<source>WordNet 1.5</source>]</p>

<p><ent>Haliographer</ent><br/
<hw>Ha`li*og"ra*pher</hw> <pr>(h<amac/`l<icr/*<ocr/g"r<adot/*f<etil/r
<or/ h<acr/l`<icr/-)</pr>, <pos>n.</pos> <def>One who writes about or
describes the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haliography</ent><br/
<hw>Ha`li*og"ra*phy</hw> <pr>(-f<ycr/)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"a`ls</grk> the sea + <ets>-graphy</ets>.]</ety> <def>Description
of the sea; the science that treats of the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haliotidae</ent><br/
<hw>Haliotidae</hw> <pos>prop. n.</pos> <def>A natural family of
mollusks including the <er>abalone</er> (<gen>Haliotis</gen>).</def><br/
<syn><b>Syn. --</b> family <fam>Haliotidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haliotis</ent><br/
\'d8<hw>Ha`li*o"tis</hw> <pr>(h<amac/`l<icr/*<omac/"t<icr/s <or/
h<acr/l`<icr/-)</pr>, <pos>prop. n.</pos> <ety>[NL., fr. Gr.
<grk>"a`ls</grk> sea + <grk>o'y^s</grk>, <grk>'wto`s</grk>, ear.]</ety>
<fld>(Zool.)</fld> <def>A genus of marine shells; the ear-shells. See
<er>Abalone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haliotoid</ent><br/
<hw>Ha"li*o*toid`</hw> <pr>(h<amac/"l<icr/*<osl/*toid` <or/
h<acr/l"<icr/-)</pr>, <pos>a.</pos> <ety>[<ets>Haliotis</ets> +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or pertaining to
the genus <gen>Haliotis</gen>; ear-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halisauria</ent><br/
\'d8<hw>Hal`i*sau"ri*a</hw>
<pr>(h<acr/l`<icr/*s<add/"r<icr/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"a`ls</grk>, <grk>"alo`s</grk>, sea +
<grk>say^ros</grk>.]</ety> <fld>(Paleon.)</fld> <def>The
Enaliosauria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halite</ent><br/
<hw>Ha"lite</hw> <pr>(h<amac/"l<imac/t <or/ h<acr/l"<imac/t)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"a`ls</grk> salt.]</ety> <fld>(Min.)</fld>
<def>Native salt; sodium chloride.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halituous</ent><br/
<hw>Ha*lit"u*ous</hw> <pr>(h<adot/*l<icr/t"<usl/*<ucr/s; 135)</pr>,
<pos>a.</pos> <ety>[L. <ets>halitus</ets> breath, vapor, fr.
<ets>halare</ets> to breathe: cf. F. <ets>halitueux</ets>.]</ety>
<def>Produced by, or like, breath; vaporous.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halk</ent><br/
<hw>Halk</hw> <pr>(h<add/k)</pr>, <pos>n.</pos> <def>A nook; a
corner.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hall</ent><br/
<hw>Hall</hw> <pr>(h<add/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>halle</ets>, <ets>hal</ets>, AS. <ets>heal</ets>, <ets>heall</ets>;
akin to D. <ets>hal</ets>, OS. & OHG. <ets>halla</ets>, G.
<ets>halle</ets>, Icel. <ets>h<oum/ll</ets>, and prob. from a root
meaning, to hide, conceal, cover. See <er>Hell</er>,
<er>Helmet</er>.]</ety> <sn>1.</sn> <def>A building or room of
considerable size and stateliness, used for public purposes; <as>as,
Westminster <ex>Hall</ex>, in London</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <def>The chief room in a castle or manor
house, and in early times the only public room, serving as the place of
gathering for the lord's family with the retainers and servants, also
for cooking and eating. It was often contrasted with the
<contr>bower</contr>, which was the private or sleeping
apartment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full sooty was her bower and eke her <qex>hall</qex>.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p><specif>Hence, as the entrance from outside was directly into the
hall:</specif> <sd>(b)</sd> <def>A vestibule, entrance room, etc., in
the more elaborated buildings of later times.</def> Hence: <sd>(c)</sd>
<def>Any corridor or passage in a building.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A name given to many manor houses because the
magistrate's court was held in the hall of his mansion; a chief mansion
house.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A college in an English university (at Oxford, an
unendowed college).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The apartment in which English university students
dine in common; hence, the dinner itself; <as>as, <ex>hall</ex> is at
six o'clock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Cleared passageway in a crowd; -- formerly an
exclamation.</def> <mark>[Obs.]</mark> <ldquo/A <xex>hall</xex>! a
<xex>hall</xex>!<rdquo/ <rj><au>B. Jonson.</au></rj></p>

<p><syn><b>Syn.</b> -- Entry; court; passage. See
<er>Vestibule</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallage</ent><br/
<hw>Hall"age</hw> <pr>(-<asl/j; 48)</pr>, <pos>n.</pos> <fld>(O. Eng.
Law)</fld> <def>A fee or toll paid for goods sold in a hall.</def></p>

<p><ent>Hallelujah</ent><br/
<ent>Halleluiah</ent><br/
<mhw>{ <hw>Hal`le*lu"iah</hw>, <hw>Hal`le*lu"jah</hw> }</mhw>
<pr>(h<acr/l`l<esl/*l<umac/"y<adot/)</pr>, <pos>n. & interj.</pos>
<ety>[Heb. See <er>Alleluia</er>.]</ety> <def>Praise ye Jehovah; praise
ye the Lord; -- an exclamation used chiefly in songs of praise or
thanksgiving to God, and as an expression of gratitude or
adoration.</def> <rj><au>Rev. xix. 1 (Rev. Ver. )</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So sung they, and the empyrean rung<br/
With <qex>Hallelujahs</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In those days, as St. Jerome tells us,<ldquo/any one as he walked
in the fields, might hear the plowman at his
<qex>hallelujahs</qex>.<rdquo/</q> <rj><qau>Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallelujatic</ent><br/
<hw>Hal`le*lu*jat"ic</hw> <pr>(-l<usl/*y<acr/t"<icr/k)</pr>,
<pos>a.</pos> <def>Pertaining to, or containing, hallelujahs.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halliard</ent><br/
<hw>Hal"liard</hw> <pr>(h<acr/l"y<etil/rd)</pr>, <pos>n.</pos> <def>See
<er>Halyard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallidome</ent><br/
<hw>Hal"li*dome</hw> <pr>(h<acr/l"l<icr/*d<omac/m)</pr>, <pos>n.</pos>
<def>Same as <er>Halidom</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallier</ent><br/
<hw>Hal"li*er</hw> <pr>(h<acr/l"l<icr/*<etil/r <or/
h<add/l"y<etil/r)</pr>, <pos>n.</pos> <ety>[From <er>Hale</er> to
pull.]</ety> <def>A kind of net for catching birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hall-mark</ent><br/
<hw>Hall"-mark`</hw> <pr>(h<add/l"m<aum/rk`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The official stamp of the Goldsmiths' Company and other
assay offices, in the United Kingdom, on gold and silver articles,
attesting their purity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence,</specif> <mark>[figuratively]</mark>:
<def>A distinguishing characteristic or characteristics; <as>as, a word
or phrase lacks the <ex>hall-mark</ex> of the best
writers</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Halloa</ent><br/
<hw>Hal*loa"</hw> <pr>(h<acr/l*l<omac/")</pr>. <def>See
<er>Halloo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halloo</ent><br/
<hw>Hal*loo"</hw> <pr>(h<acr/l*l<oomac/")</pr>, <pos>n.</pos>
<ety>[Perh. fr. <ets>ah</ets> + <ets>lo</ets>; cf. AS.
<ets>eal<amac/</ets>, G. <ets>halloh</ets>, F. <ets>haler</ets> to set
(a dog) on. Cf. <er>Hollo</er>, <ets>interj</ets>.]</ety> <def>A loud
exclamation; a call to invite attention or to incite a person or an
animal; a shout.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>List! List! I hear<br/
Some far off <qex>halloo</qex> break the silent air.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halloo</ent><br/
<hw>Hal*loo"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hallooed</conjf> <pr>(-l<oomac/d")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hallooing</conjf>.]</vmorph> <def>To cry out; to exclaim
with a loud voice; to call to a person, as by the word
<ex>halloo</ex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Country folks <qex>hallooed</qex> and hooted after me.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halloo</ent><br/
<hw>Hal*loo"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To encourage with
shouts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Old John <qex>hallooes</qex> his hounds again.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To chase with shouts or outcries.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If I fly . . . <qex>Halloo</qex> me like a hare.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To call or shout to; to hail.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halloo</ent><br/
<hw>Hal*loo"</hw>, <pos>interj.</pos> <ety>[OE. <ets>halow</ets>. See
<er>Halloo</er>, <pos>n.</pos>]</ety> <def>An exclamation to call
attention or to encourage one. Now mostly replaced by
<er>hello</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallow</ent><br/
<hw>Hal"low</hw> <pr>(h<acr/l"l<osl/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hallowed</conjf><pr>(-l<osl/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hallowing</conjf>.]</vmorph> <ety>[OE. <ets>halowen</ets>,
<ets>halwien</ets>, <ets>halgien</ets>, AS. <ets>h<amac/lgian</ets>, fr.
<ets>h<amac/lig</ets> holy. See <er>Holy</er>.]</ety> <def>To make holy;
to set apart for holy or religious use; to consecrate; to treat or keep
as sacred; to reverence.</def> <ldquo/<xex>Hallowed</xex> be thy
name.<rdquo/ <rj><au>Matt. vi. 9.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hallow</qex> the Sabbath day, to do no work therein.</q>
<rj><qau>Jer. xvii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His secret altar touched with <qex>hallowed</qex> fire.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In a larger sense . . . we can not <qex>hallow</qex> this ground
[Gettysburg].</q> <rj><qau>A. Lincoln.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hallowed</ent><br/
<hw>hallowed</hw> <pos>adj.</pos> <def>belonging to or derived from or
associated with a divine power; made holy. Opposite of
<ant>unholy</ant>.</def> [Narrower terms: <stype>beatified, blessed
</stype>; <stype>blessed </stype>; <stype>consecrated, sacred,
sanctified </stype>] <see>Also See: <er>consecrated</er>,
<er>consecrate</er>, <er>sacred</er>.</see><br/
<syn><b>Syn. --</b> holy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Halloween</ent><br/
<hw>Hal`low*een"</hw> <pr>(h<acr/l`l<osl/*<emac/n")</pr>, <pos>n.</pos>
<def>The evening preceding Allhallows or All Saints' Day (November 1);
also the entire day, October 31. It is often marked by parties or
celebrations, and sometimes by pranks played by young people.</def>
<mark>[Scot.]</mark> <rj><au>Burns.</au></rj><br/
<syn><b>Syn. --</b> Hallowe'en, Allhallows Eve.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Hallowmas</ent><br/
<hw>Hal"low*mas</hw> <pr>(h<acr/l"l<osl/*m<adot/s)</pr>, <pos>n.</pos>
<ety>[See <er>Mass</er> the eucharist.]</ety> <def>The feast of All
Saints, or Allhallows.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To speak puling, like a beggar at <qex>Hallowmas</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halloysite</ent><br/
<hw>Hal*loy"site</hw> <pr>(h<acr/l*loi"s<imac/t)</pr>, <pos>n.</pos>
<ety>[Named after <person>Omalius
d'<etsep>Halloy</etsep></person>.]</ety> <fld>(Min.)</fld> <def>A
claylike mineral, occurring in soft, smooth, amorphous masses, of a
whitish color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallstattian</ent><br/
<ent>Hallstatt</ent><br/
<mhw>{ <hw>Hall"statt</hw> <pr>(h<aum/l"st<aum/t; -sht<aum/t)</pr>,
<hw>Hall*stat"ti*an</hw> <pr>(h<aum/l*st<aum/t"t<icr/*<ait/n)</pr>
}</mhw>, <pos>a.</pos> <def>Of or pertaining to Hallstatt, Austria, or
the Hallstatt civilization.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<cs><p>-- <mcol><col><b>Hallstatt civilization</b></col> <it>or</it>
<col><b>Hallstattian civilization</b></col></mcol>, <cd>a prehistoric
civilization of central Europe, variously dated at from 1000 to 1500
<sc>b. c.</sc> and usually associated with the Celtic or Alpine race. It
was characterized by expert use of bronze, a knowledge of iron,
possession of domestic animals, agriculture, and artistic skill and
sentiment in manufacturing pottery, ornaments, etc.</cd><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The <qex>Hallstattian civilization</qex> flourished chiefly in
Carinthia, southern Germany, Switzerland, Bohemia, Silesia, Bosnia, the
southeast of France, and southern Italy.</q> <rj><qau>J.
Deniker.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p>-- <col><b>Hallstattian epoch</b></col>, <cd>the first iron age,
represented by the <cref>Hallstatt civilization</cref>.</cd><br/
[<source>Webster 1913 Suppl.</source>]</p></cs>

<p><ent>Hallucal</ent><br/
<hw>Hal"lu*cal</hw> <pr>(h<acr/l"l<usl/*k<ait/l)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to the hallux.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallucinate</ent><br/
<hw>Hal*lu"ci*nate</hw> <pr>(h<acr/l*l<umac/"s<icr/*n<amac/t)</pr>,
<pos>v. i.</pos> <ety>[L. <ets>hallucinatus</ets>,
<ets>alucinatus</ets>, p. p. of <ets>hallucinari</ets>,
<ets>alucinari</ets>, to wander in mind, talk idly, dream.]</ety>
<sn>1.</sn> <def>To wander; to go astray; to err; to blunder; -- used of
mental processes.</def> <mark>[R.]</mark> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>To perceive a
non-existent object or phenomenon; to believe that one is experiencing
something which in reality does not exist; to experience a
hallucination{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>hallucinate</ent><br/
<hw>hal*lu"ci*nate</hw> <pr>(h<acr/l*l<umac/"s<icr/*n<amac/t)</pr>,
<pos>v. t.</pos> <def>To experience (something nonexistent) as an
hallucination{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>hallucinating</ent><br/
<hw>hallucinating</hw> <pos>adj.</pos> <def>Experiencing
hallucinations.</def><br/
<syn><b>Syn. --</b> delirious.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Hallucination</ent><br/
<hw>Hal*lu`ci*na"tion</hw> <pr>(-n<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>hallucinatio</ets>: cf. F.
<ets>hallucination</ets>.]</ety> <sn>1.</sn> <def>The act of
hallucinating; a wandering of the mind; error; mistake; a
blunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This must have been the <qex>hallucination</qex> of the
transcriber.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 666 pr=JMD --></p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>The perception of objects which
have no reality, or of sensations which have no corresponding external
cause, arising from disorder of the nervous system, as in delirium
tremens; delusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hallucinations</qex> are always evidence of cerebral
derangement and are common phenomena of insanity.</q> <rj><qau>W. A.
Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallucinator</ent><br/
<hw>Hal*lu"ci*na`tor</hw>
<pr>(h<acr/l*l<umac/"s<icr/*n<amac/`t<etil/r)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <def>One whose judgment and acts are affected by
hallucinations; one who errs on account of his hallucinations.</def>
<rj><au>N. Brit. Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hallucinatory</ent><br/
<hw>Hal*lu"ci*na*to*ry</hw> <pr>(-n<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Partaking of, having the character of, or tending to
produce, hallucinations; <as>as, <ex>hallucinatory</ex>
visions</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hallucinogen</ent><br/
<hw>hal*lu"ci*no*gen</hw> <pos>n.</pos> <def>A substance capable of
producing hallucinations when ingested; a hallucinogenic substance;
<as>as, LSD is a powerful <ex>hallucinogen</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hallucinogenic</ent><br/
<hw>hal*lu"ci*no*gen`ic</hw> <pos>adj.</pos> <sn>1.</sn> <def>capable of
producing hallucinations; <as>as, LSD is a powerful
<ex>hallucinogenic</ex> drug</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hallux</ent><br/
\'d8<hw>Hal"lux</hw> <pr>(h<acr/l"l<ucr/ks)</pr>, <pos>n.</pos>
<ety>[NL., fr. L. <ets>hallex</ets>, <ets>allex</ets>.]</ety>
<fld>(Anat.)</fld> <def>The first, or preaxial, digit of the hind limb,
corresponding to the pollux in the fore limb; the great toe; the hind
toe of birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hallway</ent><br/
<hw>hall"way</hw> <pos>n.</pos> <def>an interior passage or corridor in
a building, onto which rooms open.</def><br/
<syn><b>Syn. --</b> hall.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Halm</ent><br/
<hw>Halm</hw> <pr>(h<add/m)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Same as <er>Haulm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halma</ent><br/
\'d8<hw>Hal"ma</hw> <pr>(h<acr/l"m<adot/)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>"a`lma</grk>, fr. <grk>"a`llesqai</grk> to leap.]</ety>
<fld>(Greek Antiq.)</fld> <def>The long jump, with weights in the hands,
-- the most important of the exercises of the Pentathlon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halma</ent><br/
<hw>Hal"ma</hw> <pr>(h<acr/l"m<adot/)</pr>, <pos>n.</pos> <def>A game
played on a board having 256 squares, by two persons with 19 men each,
or by four with 13 men each, starting from different corners and
striving to place each his own set of men in a corresponding position in
the opposite corner by moving them or by jumping them over those met in
progress.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Halo</ent><br/
<hw>Ha"lo</hw> <pr>(h<amac/"l<osl/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Halos</plw> <pr>(-l<omac/z)</pr>.</plu> <ety>[L.
<ets>halos</ets>, acc. <ets>halo</ets>, Gr. <grk>"a`lws</grk> a
thrashing floor, also (from its round shape) the disk of the sun or
moon, and later a halo round it; cf. Gr. <grk>e'ily`ein</grk> to enfold,
<grk>'ely`ein</grk> to roll round, L. <ets>volvere</ets>, and E.
<ets>voluble</ets>.]</ety> <sn>1.</sn> <def>A luminous circle, usually
prismatically colored, round the sun or moon, and supposed to be caused
by the refraction of light through crystals of ice in the atmosphere.
Connected with halos there are often white bands, crosses, or arches,
resulting from the same atmospheric conditions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A circle of light; especially, the bright ring
represented in painting as surrounding the heads of saints and other
holy persons; a glory; a nimbus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An ideal glory investing, or affecting one's
perception of, an object.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A colored circle around a nipple; an
areola.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halo</ent><br/
<hw>Ha"lo</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Haloed</conjf> <pr>(-l<omac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Haloing</conjf>.]</vmorph> <def>To form, or surround with, a
halo; to encircle with, or as with, a halo.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fire<br/
That <qex>haloed</qex> round his saintly brow.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>halobacterium</ent><br/
<ent>halobacter</ent><br/
<mhw><hw>halobacter</hw>, <hw>halobacterium</hw></mhw> <pos>n.</pos>;
<plu><it>pl.</it> <plw>halobacteria</plw> <pr>(?)</pr>, or
<plw>halobacters</plw> <pr>(#)</pr>.</plu> <def>Any halophilic bacterium
of the archaebacteria group, expecially of the genera
<gen>Halobacterium</gen> and <gen>Halococcus</gen>, which live in saline
environments such as the Dead Sea or salt flats.</def><br/
<syn><b>Syn. --</b> halobacteria, halobacter.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Halocarpus</ent><br/
<hw>Halocarpus</hw> <pos>n.</pos> <def>A genus of dioecious trees or
shrubs of New Zealand; similar in habit to
<gen>Dacrydium</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Halocarpus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haloed</ent><br/
<hw>Ha"loed</hw> <pr>(h<amac/"l<omac/d)</pr>, <pos>a.</pos>
<def>Surrounded with a halo; invested with an ideal glory;
glorified.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>haloed</qex> face bending over me.</q> <rj><qau>C.
Bront<eacute/.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halogen</ent><br/
<hw>Hal"o*gen</hw> <pr>(h<acr/l"<osl/*j<ecr/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"a`ls</grk>, <grk>"alo`s</grk>, salt + <ets>-gen</ets>:
cf. F. <ets>halog<egrave/ne</ets>.]</ety> <fld>(Chem.)</fld> <def>An
electro-negative element or radical, which, by combination with a metal,
forms a haloid salt; especially, chlorine, fluorine, bromine, and
iodine; sometimes, also cyanogen. See <cref>Chlorine family</cref>,
under <er>Chlorine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halogenous</ent><br/
<hw>Ha*log"e*nous</hw> <pr>(h<adot/*l<ocr/j"<esl/*n<ucr/s)</pr>,
<pos>a.</pos> <def>Of the nature of a halogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haloid</ent><br/
<hw>Ha"loid</hw> <pr>(h<amac/"loid <or/ h<acr/l"oid)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>"a`ls</grk>, <grk>"alo`s</grk> salt + <ets>-oid</ets>:
cf. F. <ets>halo<ium/de</ets>.]</ety> <fld>(Chem.)</fld> <def>Resembling
salt; -- said of certain binary compounds consisting of a metal united
to a negative element or radical, and now chiefly applied to the
chlorides, bromides, iodides, and sometimes also to the fluorides and
cyanides.</def> -- <def2><pos>n.</pos> <def>A haloid
substance.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halomancy</ent><br/
<hw>Hal"o*man`cy</hw> <pr>(h<acr/l"<osl/*m<acr/n`s<ycr/)</pr>,
<pos>n.</pos> <def>See <er>Alomancy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halometer</ent><br/
<hw>Ha*lom"e*ter</hw> <pr>(h<adot/*l<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"a`ls</grk>, <grk>"alo`s</grk>, salt +
<ets>-meter</ets>.]</ety> <def>An instrument for measuring the forms and
angles of salts and crystals; a goniometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halones</ent><br/
\'d8<hw>Ha*lo"nes</hw> <pr>(h<adot/*l<omac/"n<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. Gr. <grk>"a`lwn</grk>, <grk>"a`lwnos</grk>, a
halo.]</ety> <fld>(Biol.)</fld> <def>Alternating transparent and opaque
white rings which are seen outside the blastoderm, on the surface of the
developing egg of the hen and other birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halophyte</ent><br/
<hw>Hal"o*phyte</hw> <pr>(h<acr/l"<osl/*f<imac/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"a`ls</grk>, <grk>"alo`s</grk>, salt + <grk>fyto`n</grk>
a plant.]</ety> <fld>(Bot.)</fld> <def>A plant found growing in salt
marshes, or in the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haloscope</ent><br/
<hw>Ha"lo*scope</hw> <pr>(h<amac/"l<osl/*sk<omac/p)</pr>, <pos>n.</pos>
<ety>[<ets>Halo</ets> + <ets>-scope</ets>.]</ety> <def>An instrument for
exhibition or illustration of the phenomena of halos, parhelia, and the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halotrichite</ent><br/
<hw>Hal*o*tri"chite</hw> <pr>(h<acr/l*<osl/*tr<imac/"k<imac/t)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"a`ls</grk> sea + <grk>qri`x</grk>,
<grk>tricho`s</grk>, hair.]</ety> <fld>(Min.)</fld> <def>An iron alum
occurring in silky fibrous aggregates of a yellowish white
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haloxyline</ent><br/
<hw>Ha*lox"y*line</hw>, <pos>n.</pos> <ety>[Gr. <grk>"a`ls</grk>,
<grk>"alo`s</grk>, salt + <grk>xy`lon</grk> wood.]</ety> <def>An
explosive mixture, consisting of sawdust, charcoal, niter, and
ferrocyanide of potassium, used as a substitute for gunpowder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halp</ent><br/
<hw>Halp</hw> <pr>(h<aum/lp)</pr>, <pos>imp.</pos> <mord>of
<er>Help</er></mord>. <def>Helped.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halpace</ent><br/
<hw>Hal"pace</hw> <pr>(h<acr/l"p<amac/s)</pr>, <pos>n.</pos>
<fld>(Arch.)</fld> <def>See <er>Haut pas</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hals</ent><br/
<hw>Hals</hw> <pr>(h<add/ls)</pr>, <pos>n.</pos> <ety>[AS.
<ets>heals</ets>; akin to D., G., & Goth. <ets>hals</ets>. See
<er>Collar</er>.]</ety> <def>The neck or throat.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Do me hangen by the <qex>hals</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halse</ent><br/
<hw>Halse</hw> <pr>(h<add/ls)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>healsian</ets>.]</ety> <sn>1.</sn> <def>To embrace about the neck;
to salute; to greet.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Each other kissed glad<br/
And lovely <qex>halst</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To adjure; to beseech; to entreat.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>O dere child, I <qex>halse</qex> thee,<br/
In virtue of the Holy Trinity.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halse</ent><br/
<hw>Halse</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Halsed</conjf> <pr>(h<add/lst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Halsing</conjf>.]</vmorph> <ety>[Cf. <er>Hawser</er>.]</ety>
<def>To haul; to hoist.</def> <mark>[Obs.]</mark>
<rj><au>Grafton</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halsening</ent><br/
<hw>Hal"sen*ing</hw> <pr>(h<add/l"s<ecr/n*<icr/ng)</pr>, <pos>a.</pos>
<def>Sounding harshly in the throat; inharmonious; rough.</def>
<mark>[Obs.]</mark> <rj><au>Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halser</ent><br/
<hw>Hals"er</hw> <pr>(h<add/s"<etil/r)</pr>, <pos>n.</pos> <def>See
<er>Hawser</er>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw> <pr>(h<add/lt)</pr>, <def><pos>3d pers. sing. pres.</pos>
of <er>Hold</er>, contraction for <xex>holdeth</xex>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw> <pr>(h<add/lt)</pr>, <pos>n.</pos> <ety>[Formerly
<ets>alt</ets>, It. <ets>alto</ets>, G. <ets>halt</ets>, fr.
<ets>halten</ets> to hold. See <er>Hold</er>.]</ety> <def>A stop in
marching or walking, or in any action; arrest of progress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Without any <qex>halt</qex> they marched.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Lovers] soon in passion's war contest,<br/
Yet in their march soon make a <qex>halt</qex>.</q>
<rj><qau>Davenant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Halted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Halting</conjf>.]</vmorph> <sn>1.</sn> <def>To hold one's self
from proceeding; to hold up; to cease progress; to stop for a longer or
shorter period; to come to a stop; to stand still.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To stand in doubt whether to proceed, or what to do;
to hesitate; to be uncertain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How long <qex>halt</qex> ye between two opinions?</q> <rj><qau>1
Kings xviii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw> <pr>(h<add/lt)</pr>, <pos>v. t.</pos> <fld>(Mil.)</fld>
<def>To cause to cease marching; to stop; <as>as, the general
<ex>halted</ex> his troops for refreshment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw>, <pos>a.</pos> <ety>[AS. <ets>healt</ets>; akin to OS.,
Dan., & Sw. <ets>halt</ets>, Icel. <ets>haltr</ets>, <ets>halltr</ets>,
Goth. <ets>halts</ets>, OHG. <ets>halz</ets>.]</ety> <def>Halting or
stopping in walking; lame.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bring in hither the poor, and the maimed, and the <qex>halt</qex>,
and the blind.</q> <rj><qau>Luke xiv. 21. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw>, <pos>n.</pos> <def>The act of limping;
lameness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halt</ent><br/
<hw>Halt</hw>, <pos>v. i.</pos> <ety>[OE. <ets>halten</ets>, AS.
<ets>healtian</ets>. See <er>Halt</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To walk lamely; to limp.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have an irregular rhythm; to be
defective.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The blank verse shall <qex>halt</qex> for it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halter</ent><br/
<hw>Halt"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who halts
or limps; a cripple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halter</ent><br/
<hw>Hal"ter</hw> <pr>(h<add/l"t<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>halter</ets>, <ets>helter</ets>, <ets>helfter</ets>, AS.
<ets>h<ae/lftre</ets>; akin to G. <ets>halfter</ets>, D.
<ets>halfter</ets>, <ets>halster</ets>, and also to E. <ets>helve</ets>.
See <er>Helve</er>.]</ety> <def>A strong strap or cord.</def>
<specif>Especially:</specif> <sd>(a)</sd> <def>A rope or strap, with or
without a headstall, for leading or tying a horse.</def> <sd>(b)</sd>
<def>A rope for hanging malefactors; a noose.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No man e'er felt the <qex>halter</qex> draw<br/
With good opinion of the law.</q> <rj><qau>Trumbull.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halter</ent><br/
<hw>Hal"ter</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Haltered</conjf> <pr>(-t<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Haltering</conjf>.]</vmorph> <def>To tie by the neck
with a rope, strap, or halter; to put a halter on; to subject to a
hangman's halter.</def> <ldquo/A <xex>haltered</xex> neck.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halteres</ent><br/
\'d8<hw>Hal*te"res</hw> <pr>(h<acr/l*t<emac/"r<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. Gr. <grk>"alth^res</grk> weights used in
jumping, fr. <grk>"a`llesqai</grk> to leap.]</ety> <fld>(Zool.)</fld>
<def>Balancers; the rudimentary hind wings of Diptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halter-sack</ent><br/
<hw>Hal"ter-sack`</hw> <pr>(h<add/l"t<etil/r*s<acr/k`)</pr>,
<pos>n.</pos> <def>A term of reproach, implying that one is fit to be
hanged.</def> <mark>[Obs.]</mark> <au>Beau. & Fl.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haltingly</ent><br/
<hw>Halt"ing*ly</hw> <pr>(h<add/lt"<icr/ng*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a halting or limping manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halvans</ent><br/
<hw>Hal"vans</hw> <pr>(h<acr/l"v<ait/nz)</pr>, <pos>n. pl.</pos>
<fld>(Mining)</fld> <def>Impure ore; dirty ore.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halve</ent><br/
<hw>Hal"ve</hw> <pr>(h<aum/l"v<eit/)</pr>, <pos>n.</pos> <def>A
half.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halve</ent><br/
<hw>Halve</hw> <pr>(h<aum/v)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Halved</conjf> <pr>(h<aum/vd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Halving</conjf>.]</vmorph> <ety>[From
<er>Half</er>.]</ety> <sn>1.</sn> <def>To divide into two equal parts;
<as>as, to <ex>halve</ex> an apple</as>; to be or form half
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So far apart their lives are thrown<br/
From the twin soul that <qex>halves</qex> their own.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>To join, as two pieces of timber,
by cutting away each for half its thickness at the joining place, and
fitting together.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of a hole, match, etc., to reach or play in the same
number of strokes as an opponent.</def></p>

<p><ent>Halved</ent><br/
<hw>Halved</hw> <pr>(h<aum/vd)</pr>, <pos>a.</pos> <def>Appearing as if
one side, or one half, were cut away; dimidiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halves</ent><br/
<hw>Halves</hw> <pr>(h<aum/vz)</pr>, <pos>n.</pos>, <def><pos>pl.</pos>
of <er>Half</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>By halves</b></col>, <cd>by one half at once; halfway;
fragmentarily; partially; incompletely.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not believe by <qex>halves</qex>; either I have faith, or I
have it not.</q> <rj><qau>J. H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To go halves</b></col>. <cd>See under
<er>Go</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halwe</ent><br/
<hw>Hal"we</hw> <pr>(h<aum/l"w<eit/)</pr>, <pos>n.</pos> <ety>[OE., fr.
AS. <ets>h<amac/lga</ets>. See <er>Holy</er>.]</ety> <def>A saint.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halyard</ent><br/
<hw>Hal"yard</hw> <pr>(h<acr/l"y<etil/rd)</pr>, <pos>n.</pos>
<ety>[<ets>Hale</ets>, <pos>v. t.</pos> + <ets>yard</ets>.]</ety>
<fld>(Naut.)</fld> <def>A rope or tackle for hoisting or lowering yards,
sails, flags, etc.</def> <altsp>[Written also <asp>halliard</asp>,
<asp>haulyard</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Halysites</ent><br/
\'d8<hw>Hal`y*si"tes</hw> <pr>(h<acr/l`<icr/*s<imac/"t<emac/z)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>"a`lysis</grk> a chain.]</ety>
<fld>(Paleon.)</fld> <def>A genus of Silurian fossil corals; the chain
corals. See <cref>Chain coral</cref>, under <er>Chain</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ham</ent><br/
<hw>Ham</hw> <pr>(h<aum/m)</pr>, <pos>n.</pos> <def>Home.</def>
<mark>[North of Eng.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ham</ent><br/
<hw>Ham</hw> <pr>(h<acr/m)</pr>, <pos>n.</pos> <ety>[AS. <ets>ham</ets>;
akin to D. <ets>ham</ets>, dial. G. <ets>hamme</ets>, OHG.
<ets>hamma</ets>. Perh. named from the bend at the ham, and akin to E.
<ets>chamber</ets>. Cf. <er>Gammon</er> ham.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>The region back of the knee
joint; the popliteal space; the hock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The thigh of any animal; especially, the thigh of a
hog cured by salting and smoking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A plentiful lack of wit, together with most weak
<qex>hams</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ham</ent><br/
<hw>Ham</hw> <pr>(h<acr/m)</pr>, <pos>n.</pos> <sn>1.</sn> <ety>[Short
for <er>hamfatter</er>.]</ety> <def>a person who performs in a showy or
exaggerated style; -- used especially of actors. Also used
attributively, <as>as, a <ex>ham</ex> actor</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The licensed operator of an amateur radio
station.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ham</ent><br/
<hw>Ham</hw> <pr>(h<acr/m)</pr>, <pos>v. i.</pos> <fld>(Theater)</fld>
<def>To act with exaggerated voice and gestures; to overact.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>ham it up</b></col> <cd>to act in a showy fashion or to
act so as to attract attention; to ham.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>PJC</source>]</p>

<p><ent>Hamadryad</ent><br/
<hw>Ham"a*dry`ad</hw> <pr>(h<acr/m"<adot/*dr<imac/`<acr/d)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> E. <plw>Hamadryads</plw>
<pr>(-<acr/dz)</pr>, L. <plw>Hamadryades</plw>
<pr>(-dr<imac/"<adot/*d<emac/z)</pr>.</plu> <ety>[L.
<ets>Hamadryas</ets>, <ets>-adis</ets>, Gr. <grk>"Amadrya`s</grk>;
<grk>"a`ma</grk> together + <grk>dry^s</grk> oak, tree: cf. F.
<ets>hamadryade</ets>. See <er>Same</er>, and <er>Tree</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Class. Myth.)</fld> <def>A tree nymph whose life
ended with that of the particular tree, usually an oak, which had been
her abode.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A large venomous East Indian
snake (<spn>Ophiophagus bungarus</spn>), allied to the cobras.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamadryas</ent><br/
\'d8<hw>Ha*ma"dry*as</hw> <pr>(h<adot/*m<amac/"dr<icr/*<acr/s)</pr>,
<pos>n.</pos> <ety>[L., a hamadryad. See <er>Hamadryad</er>.]</ety>
<fld>(Zool.)</fld> <def>The sacred baboon of Egypt (<spn>Cynocephalus
Hamadryas</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamal</ent><br/
\'d8<hw>Ha*mal"</hw> <pr>(h<adot/*m<aum/l")</pr>, <pos>n.</pos>
<altsp>[Written also <asp>hammal</asp>, <asp>hummaul</asp>,
<asp>hamaul</asp>, <asp>khamal</asp>, etc.]</altsp> <ety>[Turk. & Ar.
<ets>hamm<amac/l</ets>, fr. Ar. <ets>hamala</ets> to carry.]</ety>
<def>In Turkey and other Oriental countries, a porter or burden bearer;
specif., in Western India, a palanquin bearer.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hamamelidaceae</ent><br/
<hw>Hamamelidaceae</hw> <pos>n.</pos> <def>A natural family of plants
comprising the genera <gen>Hamamelis</gen>; <gen>Corylopsis</gen>;
<gen>Fothergilla</gen>; <gen>Liquidambar</gen>; <gen>Parrotia</gen>; and
other small genera.</def><br/
<syn><b>Syn. --</b> family <fam>Hamamelidaceae</fam>, witch-hazel
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hamamelidae</ent><br/
<hw>Hamamelidae</hw> <pos>n.</pos> <def>a group of chiefly woody plants
considered among the most primitive of angiosperms; they have a perianth
poorly developed or lacking, and flowers often unisexual and often in
catkins and often wind pollinated. The group contains 23 families
including the Betulaceae and Fagaceae (includes the Amentiferae);
sometimes it is classified as a superorder.</def><br/
<syn><b>Syn. --</b> subclass <subclass>Hamamelidae</subclass>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hamamelidanthum</ent><br/
<hw>Hamamelidanthum</hw> <pos>n.</pos> <def>A genus of fossil plants of
the Oligocene having flowers resembling those of the witch hazel; found
in Baltic region.</def><br/
<syn><b>Syn. --</b> genus <gen>Hamamelidanthum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hamamelidoxylon</ent><br/
<hw>Hamamelidoxylon</hw> <pos>n.</pos> <def>A genus of fossil plants
having wood identical with or similar to that of the witch
hazel.</def><br/
<syn><b>Syn. --</b> genus <gen>Hamamelidoxylon</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hamamelis</ent><br/
<hw>Ham`a*me"lis</hw> <pr>(h<acr/m`<adot/*m<emac/"l<icr/s)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>"amamhli`s</grk> a kind of medlar
or service tree; <grk>"a`ma</grk> at the same time + <grk>mh^lon</grk>
an apple, any tree fruit.]</ety> <fld>(Bot.)</fld> <def>A genus of
plants which includes the witch-hazel (<spn>Hamamelis Virginica</spn>),
a preparation of which is used medicinally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamate</ent><br/
<hw>Ha"mate</hw> <pr>(h<amac/"m<asl/t)</pr>, <pos>a.</pos> <ety>[L.
<ets>hamatus</ets>, fr. <ets>hamus</ets> hook.]</ety> <def>Hooked; bent
at the end into a hook; hamous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamated</ent><br/
<hw>Ha"ma*ted</hw> <pr>(h<amac/"m<asl/*t<ecr/d)</pr>, <pos>a.</pos>
<def>Hooked, or set with hooks; hamate.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamatum</ent><br/
\'d8<hw>Ha*ma"tum</hw> <pr>(h<adot/*m<amac/"t<ucr/m)</pr>, <pos>n.</pos>
<ety>[NL., fr. L. <ets>hamatus</ets> hooked.]</ety> <fld>(Anat.)</fld>
<def>See <er>Unciform</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamble</ent><br/
<hw>Ham"ble</hw> <pr>(h<acr/m"b'l)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>hamelen</ets> to mutilate, AS. <ets>hamelian</ets>; akin to OHG.
<ets>hamal<omac/n</ets> to mutilate, <ets>hamal</ets> mutilated,
<ets>ham</ets> mutilated, Icel. <ets>hamla</ets> to mutilate. Cf.
<er>Hamper</er> to fetter.]</ety> <def>To hamstring.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamburg</ent><br/
<hw>Ham"burg</hw> <pr>(-b<ucir/rg)</pr>, <pos>n.</pos> <def>A commercial
city of Germany, near the mouth of the Elbe.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Black Hamburg grape</b></col>. <cd>See under
<er>Black</er>.</cd> -- <col><b>Hamburg edging</b></col>, <cd>a kind of
embroidered work done by machinery on cambric or muslin; -- used for
trimming.</cd> -- <col><b>Hamburg lake</b></col>, <cd>a purplish crimson
pigment resembling cochineal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hame</ent><br/
<hw>Hame</hw> <pr>(h<amac/m)</pr>, <pos>n.</pos> <def>Home.</def>
<mark>[Scot. & O. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hame</ent><br/
<hw>Hame</hw>, <pos>n.</pos> <ety>[Scot. <ets>haims</ets>,
<ets>hammys</ets>, <ets>hems</ets>, OE. <ets>ham</ets>; cf. D.
<ets>haam</ets>.]</ety> <def>One of the two curved pieces of wood or
metal, in the harness of a draught horse, to which the traces are
fastened. They are fitted upon the collar, or have pads fitting the
horse's neck attached to them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamel</ent><br/
<hw>Ham"el</hw> <pr>(h<acr/m"<ecr/l)</pr>, <pos>v. t.</pos>
<mark>[Obs.]</mark> <def>Same as <er>Hamble</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamesucken</ent><br/
<ent>Hamesecken</ent><br/
<mhw>{ <hw>Hame"seck`en</hw> <pr>(h<amac/m"s<ecr/k`'n)</pr>,
<hw>Hame"suck`en</hw> <pr>(-s<ucr/k`'n)</pr>, }</mhw> <pos>n.</pos>
<ety>[AS. <ets>h<amac/ms<omac/cn</ets>. See <er>Home</er>, and
<er>Seek</er>.]</ety> <fld>(Scots Law)</fld> <def>The felonious seeking
and invasion of a person in his dwelling house.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamfatter</ent><br/
<hw>Ham"fat`ter</hw> <pr>(h<acr/m"f<acr/t`t<etil/r)</pr>, <pos>n.</pos>
<ety>[From a negro minstrel song called <ldquo/The <ets>ham-fat</ets>
man.<rdquo/]</ety> <def>A low-grade actor or performer; a ham.</def>
<mark>[Theatrical Slang]</mark><br/
<syn><b>Syn. --</b> ham.</syn><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>ham-handed</ent><br/
<ent>ham-fisted</ent><br/
<mhw><hw>ham-fisted</hw> <hw>ham-handed</hw></mhw> <pos>adj.</pos>
<def>not skillful in physical movement especially with the hands;
clumsy; bungling; -- also used metaphorically of actions; <as>as,
<ex>ham-handed</ex> governmental interference</as>.</def><br/
<syn><b>Syn. --</b> bumbling, bungling, butterfingered, handless,
heavy-handed, left-handed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hamiform</ent><br/
<hw>Ha"mi*form</hw> <pr>(h<amac/"m<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[L. <ets>hamus</ets> hook + <ets>-form</ets>.]</ety>
<def>Hook-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamilton period</ent><br/
<hw>Ham"il*ton pe"ri*od</hw> <pr>(h<acr/m"<icr/l*t<ucr/n
p<emac/"r<icr/*<ucr/d)</pr>. <fld>(Geol.)</fld> <def>A subdivision of
the Devonian system of America; -- so named from
<etsep>Hamilton</etsep>, Madison Co., New York. It includes the
Marcellus, Hamilton, and Genesee epochs or groups. See the Chart of
<er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haminoea</ent><br/
<hw>Haminoea</hw> <pos>n.</pos> <def>A common genus of marine bubble
shells of the Pacific coast of North America.</def><br/
<syn><b>Syn. --</b> genus <gen>Haminoea</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haminura</ent><br/
\'d8<hw>Ham`i*nu"ra</hw> <pr>(h<acr/m`<icr/*n<umac/"r<adot/)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>A large edible river fish
(<spn>Erythrinus macrodon</spn>) of Guiana.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamite</ent><br/
<hw>Ha"mite</hw> <pr>(h<amac/"m<imac/t)</pr>, <pos>n.</pos><ety>[L.
<ets>hamus</ets> hook.]</ety> <fld>(Paleon.)</fld> <def>A fossil
cephalopod of the genus <gen>Hamites</gen>, related to the ammonites,
but having the last whorl bent into a hooklike form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamite</ent><br/
<hw>Ham"ite</hw> <pr>(h<acr/m"<imac/t)</pr>, <pos>n.</pos> <def>A
descendant of Ham, Noah's second son. See Gen. x. 6-20.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamitic</ent><br/
<hw>Ham*it"ic</hw> <pr>(h<acr/m*<icr/t"<icr/k)</pr>, <pos>a.</pos>
<def>Pertaining to Ham or his descendants.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hamitic languages</b></col>, <cd>the group of languages
spoken mainly in the Sahara, Egypt, Galla, and Som<acir/li Land, and
supposed to be allied to the Semitic.</cd> <rj><au>Keith
Johnston.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamlet</ent><br/
<hw>Ham"let</hw> <pr>(h<acr/m"l<ecr/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hamelet</ets>, OF. <ets>hamelet</ets>, dim. of <ets>hamel</ets>, F.
<ets>hameau</ets>, LL. <ets>hamellum</ets>, a dim. of German origin; cf.
G. <ets>heim</ets> home. <root/220. See <er>Home</er>.]</ety> <def>A
small village; a little cluster of houses in the country.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The country wasted, and the <qex>hamlets</qex> burned.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- Village; neighborhood. See
<er>Village</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamleted</ent><br/
<hw>Ham"let*ed</hw>, <pos>p. a.</pos> <def>Confined to a hamlet.</def>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer</ent><br/
<hw>Ham"mer</hw> <pr>(h<acr/m"m<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hamer</ets>, AS. <ets>hamer</ets>, <ets>hamor</ets>; akin to D.
<ets>hamer</ets>, G. & Dan. <ets>hammer</ets>, Sw. <ets>hammare</ets>,
Icel. <ets>hamarr</ets>, hammer, crag, and perh. to Gr.
<grk>'a`kmwn</grk> anvil, Skr. <ets>a<cced/man</ets> stone.]</ety>
<sn>1.</sn> <def>An instrument for driving nails, beating metals, and
the like, consisting of a head, usually of steel or iron, fixed
crosswise to a handle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With busy <qex>hammers</qex> closing rivets up.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something which in form or action resembles the
common hammer</def>; as: <sd>(a)</sd> <def>That part of a clock which
strikes upon the bell to indicate the hour.</def> <sd>(b)</sd> <def>The
padded mallet of a piano, which strikes the wires, to produce the
tones.</def> <sd>(c)</sd> <fld>(Anat.)</fld> <def>The malleus.</def> See
under <er>Ear</er>. <sd>(d)</sd> <fld>(Gun.)</fld> <def>That part of a
gunlock which strikes the percussion cap, or firing pin; the cock;
formerly, however, a piece of steel covering the pan of a flintlock
musket and struck by the flint of the cock to ignite the priming.</def>
<sd>(e)</sd> <def>Also, a person or thing that smites or shatters;
<as>as, St. Augustine was the <ex>hammer</ex> of
heresies.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He met the stern legionaries [of Rome] who had been the
<ldquo/massive iron <qex>hammers</qex><rdquo/ of the whole earth.</q>
<rj><qau>J. H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Athletics)</fld> <def>A spherical weight attached
to a flexible handle and hurled from a mark or ring. The weight of head
and handle is usually not less than 16 pounds.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Atmospheric hammer</b></col>, <cd>a dead-stroke hammer in
which the spring is formed by confined air.</cd> -- <mcol><col><b>Drop
hammer</b></col>, <col><b>Face hammer</b></col>, etc.</mcol> <cd>See
under <er>Drop</er>, <er>Face</er>, etc.</cd> -- <col><b>Hammer
fish</b></col>. <cd>See <er>Hammerhead</er>.</cd> -- <col><b>Hammer
hardening</b></col>, <cd>the process of hardening metal by hammering it
when cold.</cd> -- <col><b>Hammer shell</b></col> <fld>(Zool.)</fld>,
<cd>any species of <gen>Malleus</gen>, a genus of marine bivalve shells,
allied to the pearl oysters, having the wings narrow and elongated, so
as to give them a hammer-shaped outline; -- called also <altname>hammer
oyster</altname>.</cd> -- <col><b>To bring to the hammer</b></col>,
<cd>to put up at auction.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer</ent><br/
<hw>Ham"mer</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hammered</conjf> <pr>(-m<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hammering</conjf>.]</vmorph> <sn>1.</sn> <def>To beat
with a hammer; to beat with heavy blows; <as>as, to <ex>hammer</ex>
iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form or forge with a hammer; to shape by
beating.</def> <ldquo/<xex>Hammered</xex> money.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To form in the mind; to shape by hard intellectual
labor; -- usually with <xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who was <qex>hammering</qex> out a penny dialogue.</q>
<rj><qau>Jeffry.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer</ent><br/
<hw>Ham"mer</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be busy forming
anything; to labor hard as if shaping something with a hammer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whereon this month I have been <qex>hammering</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strike repeated blows, literally or
figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blood and revenge are <qex>hammering</qex> in my head.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammerable</ent><br/
<hw>Ham"mer*a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos>
<def>Capable of being/formed or shapeo by a hammer.</def>
<rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer-beam</ent><br/
<hw>Ham"mer-beam`</hw> <pr>(-b<emac/m`)</pr>, <pos>n.</pos> <fld>(Gothic
Arch.)</fld> <def>A member of one description of roof truss, called
<xex>hammer-beam truss</xex>, which is so framed as not to have a
tiebeam at the top of the wall. Each principal has two hammer-beams,
which occupy the situation, and to some extent serve the purpose, of a
tiebeam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer break</ent><br/
<hw>Ham"mer break</hw>. <fld>(Elec.)</fld> <def>An interrupter in which
contact is broken by the movement of an automatically vibrating hammer
between a contact piece and an electromagnet, or of a rapidly moving
piece mechanically driven.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hammercloth</ent><br/
<hw>Ham"mer*cloth`</hw> <pr>(-kl<ocr/th; 115)</pr>, <pos>n.</pos>
<ety>[Prob. fr. D. <ets>hemel</ets> heaven, canopy, tester (akin to G.
<ets>himmel</ets>, and perh. also to E. <ets>heaven</ets>) + E.
<ets>cloth</ets>; or perh. a corruption of <ets>hamper
cloth</ets>.]</ety> <def>The cloth which covers a coach box.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer-dressed</ent><br/
<hw>Ham"mer-dressed`</hw> <pr>(-dr<ecr/st`)</pr>, <pos>a.</pos>
<def>Having the surface roughly shaped or faced with the stonecutter's
hammer; -- said of building stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammerer</ent><br/
<hw>Ham"mer*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
works with a hammer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer-harden</ent><br/
<hw>Ham"mer-hard`en</hw> <pr>(-h<aum/rd`'n)</pr>, <pos>v. t.</pos>
<def>To harden, as a metal, by hammering it in the cold state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammerhead</ent><br/
<hw>Ham"mer*head`</hw> <pr>(-h<ecr/d`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A shark of the genus <gen>Sphyrna</gen> or
<gen>Zygaena</gen>, having the eyes set on projections from the sides of
the head, which gives it a hammer shape. The <spn>Sphyrna zygaena</spn>
is found in the North Atlantic. Called also <altname>hammer
fish</altname>, and <altname>balance fish</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 667 pr=JMD --></p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A fresh-water fish; the
stone-roller.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>An African fruit bat
(<spn>Hypsignathus monstrosus</spn>); -- so called from its large blunt
nozzle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammerkop</ent><br/
<hw>Ham"mer*kop</hw> <pr>(h<acr/m"m<etil/r*k<ocr/p)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A bird of the Heron family; the umber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer-less</ent><br/
<hw>Ham"mer-less</hw>, <pos>a.</pos> <fld>(Firearms)</fld> <def>Without
a visible hammer; -- said of a gun having a cock or striker concealed
from sight, and out of the way of an accidental touch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammer lock</ent><br/
<hw>Hammer lock</hw>. <fld>(Wrestling)</fld> <def>A hold in which an arm
of one contestant is held twisted and bent behind his back by his
opponent.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hammerman</ent><br/
<hw>Ham"mer*man</hw> <pr>(-m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hammermen</plw> <pr>(-m<eit/n)</pr>.</plu> <def>A
hammerer; a forgeman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hamming</ent><br/
<hw>ham"ming</hw> <pos>n.</pos> <def>poor acting by a ham actor; see
<er>ham</er>.</def><br/
<syn><b>Syn. --</b> overacting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hammochrysos</ent><br/
\'d8<hw>Ham`mo*chry"sos</hw> <pr>(h<acr/m`m<osl/*kr<imac/"s<ocr/s)</pr>,
<pos>n.</pos> <ety>[L., fr. Gr. <grk>"ammo`chrysos</grk>;
<grk>"a`mmos</grk>, <grk>'a`mmos</grk>, sand + <grk>chryso`s</grk>
gold.]</ety> <def>A stone with spangles of gold color in it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hammock</ent><br/
<hw>Ham"mock</hw> <pr>(h<acr/m"m<ocr/k)</pr>, <pos>n.</pos> <ety>[A word
of Indian origin: cf. Sp. <ets>hamaca</ets>. Columbus, in the Narrative
of his first voyage, says: <ldquo/A great many Indians in canoes came to
the ship to-day for the purpose of bartering their cotton, and
<ets>hamacas</ets>, or nets, in which they sleep.<rdquo/]</ety>
<sn>1.</sn> <def>A swinging couch or bed, usually made of netting or
canvas about six feet long and three feet wide, suspended by clews or
cords at the ends.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of land thickly wooded, and usually covered
with bushes and vines. Used also adjectively; <as>as, <ex>hammock</ex>
land</as>.</def> <mark>[Southern U. S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hammock nettings</b></col> <fld>(Naut.)</fld>,
<cd>formerly, nets for stowing hammocks; now, more often, wooden boxes
or a trough on the rail, used for that purpose.</cd></cs></p>

<p><ent>Hamous</ent><br/
<ent>Hamose</ent><br/
<mhw>{ <hw>Ha*mose"</hw> <pr>(h<asl/*m<omac/s")</pr>, <hw>Ha"mous</hw>
<pr>(h<amac/"m<ucr/s)</pr>, }</mhw><ety>[L. <ets>hamus</ets>
hook.]</ety> <fld>(Bot.)</fld> <def>Having the end hooked or
curved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamper</ent><br/
<hw>Ham"per</hw> <pr>(h<acr/m"p<etil/r)</pr>, <pos>n.</pos> <ety>[Contr.
fr. <ets>hanaper</ets>.]</ety> <def>A large basket, usually with a
cover, used for the packing and carrying of articles; <as>as, a
<ex>hamper</ex> of wine; a clothes <ex>hamper</ex>; an oyster
<ex>hamper</ex>, which contains two bushels.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamper</ent><br/
<hw>Ham"per</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hampered</conjf> <pr>(-p<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hampering</conjf>.]</vmorph> <def>To put in a
hamper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamper</ent><br/
<hw>Ham"per</hw>, <pos>v. t.</pos> <ety>[OE. <ets>hamperen</ets>,
<ets>hampren</ets>, prob. of the same origin as E.
<ets>hamble</ets>.]</ety> <def>To put a hamper or fetter on; to shackle;
to insnare; to inveigle; to entangle; hence, to impede in motion or
progress; to embarrass; to encumber.</def> <ldquo/<xex>Hampered</xex>
nerves.<rdquo/ <rj><au>Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A lion <qex>hampered</qex> in a net.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>hamper</qex> and entangle our souls.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamper</ent><br/
<hw>Ham"per</hw>, <pos>n.</pos> <ety>[See <er>Hamper</er> to
shackle.]</ety> <sn>1.</sn> <def>A shackle; a fetter; anything which
impedes.</def> <rj><au>W. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>Articles ordinarily
indispensable, but in the way at certain times.</def> <rj><au>Ham. Nav.
Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Top hamper</b></col> <fld>(Naut.)</fld>, <cd>unnecessary
spars and rigging kept aloft.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamshackle</ent><br/
<hw>Ham"shac`kle</hw> <pr>(h<acr/m"sh<acr/k`'l)</pr>, <pos>v. t.</pos>
<ety>[<ets>Ham</ets> + <ets>shackle</ets>.]</ety> <def>To fasten (an
animal) by a rope binding the head to one of the fore legs; <as>as, to
<ex>hamshackle</ex> a horse or cow</as>; hence, to bind or restrain; to
curb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamster</ent><br/
<hw>Ham"ster</hw> <pr>(-st<etil/r)</pr>, <pos>n.</pos> <ety>[G.
<ets>hamster</ets>.]</ety> <fld>(Zool.)</fld> <def>A small European
rodent (<spn>Cricetus frumentarius</spn>). It is remarkable for having a
pouch on each side of the jaw, under the skin, and for its migrations.
Hamsters are commonly kept as a pets.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hamstring</ent><br/
<hw>Ham"string`</hw> <pr>(h<acr/m"str<icr/ng`)</pr>, <pos>n.</pos>
<fld>(Anat.)</fld> <def>One of the great tendons situated in each side
of the ham, or space back of the knee, and connected with the muscles of
the back of the thigh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamstring</ent><br/
<hw>Ham"string`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hamstrung</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hamstringing</conjf>. See <er>String</er>.]</vmorph> <def>To lame
or disable by cutting the tendons of the ham or knee; to hough; hence,
to cripple; to incapacitate; to disable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So have they <qex>hamstrung</qex> the valor of the subject by
seeking to effeminate us all at home.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamular</ent><br/
<hw>Ham"u*lar</hw> <pr>(h<acr/m"<usl/*l<etil/r)</pr>, <pos>a.</pos>
<def>Hooked; hooklike; hamate; <as>as, the <ex>hamular</ex> process of
the sphenoid bone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamulate</ent><br/
<hw>Ham"u*late</hw> <pr>(-l<asl/t)</pr>, <pos>a.</pos> <def>Furnished
with a small hook; hook-shaped.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamule</ent><br/
<hw>Ham"ule</hw> <pr>(-<umac/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>hamulus</ets>.]</ety> <def>A little hook.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamulose</ent><br/
<hw>Ham"u*lose`</hw> <pr>(-<usl/*l<omac/s`)</pr>, <pos>a.</pos> <ety>[L.
<ets>hamulus</ets>, dim. of <ets>hamus</ets> a hook.]</ety> <def>Bearing
a small hook at the end.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hamulus</ent><br/
\'d8<hw>Ham"u*lus</hw> <pr>(-l<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hamuli</plw> <pr>(-l<imac/)</pr>.</plu> <ety>[L.,
a little hook.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>A hook, or
hooklike process.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A hooked barbicel of a
feather.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Han</ent><br/
<hw>Han</hw> <pr>(h<acr/n)</pr>, <ety>contr. <pos>inf. & plural
pres.</pos> of <er>Haven</er>.</ety> <def>To have; have.</def>
<mark>[Obs.]</mark> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Him thanken all, and thus they <qex>han</qex> an end.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanap</ent><br/
<hw>Han"ap</hw> <pr>(-<acr/p)</pr>, <pos>n.</pos> <ety>[F.
<ets>hanap</ets>. See <er>Hanaper</er>.]</ety> <def>A rich goblet, esp.
one used on state occasions.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanaper</ent><br/
<hw>Han"a*per</hw> <pr>(-<adot/*p<etil/r)</pr>, <pos>n.</pos> <ety>[LL.
<ets>hanaperium</ets> a large vase, fr. <ets>hanapus</ets> vase, bowl,
cup (whence F. <ets>hanap</ets>); of German origin; cf. OHG.
<ets>hnapf</ets>, G. <ets>napf</ets>, akin to AS. <ets>hn<ae/p</ets>
cup, bowl. Cf. <er>Hamper</er>, <er>Nappy</er>, <pos>n.</pos>]</ety>
<def>A kind of basket, usually of wickerwork, and adapted for the
packing and carrying of articles; a hamper.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hanaper office</b></col>, <cd>an office of the English
court of chancery in which writs relating to the business of the public,
and the returns to them, were anciently kept in a hanaper or
hamper.</cd> <rj><au>Blackstone.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hance</ent><br/
<hw>Hance</hw> <pr>(h<adot/ns)</pr>, <pos>v. t.</pos> <ety>[See
<er>Enhance</er>.]</ety> <def>To raise; to elevate.</def>
<mark>[Obs.]</mark> <rj><au>Lydgate.</au></rj></p>

<p><ent>Hanch</ent><br/
<ent>Hance</ent><br/
<mhw>{ <hw>Hance</hw> <pr>(h<acr/ns)</pr>, <hw>Hanch</hw>
<pr>(h<acr/nch)</pr>, }</mhw> <pos>n.</pos> <ety>[See
<er>Hanse</er>.]</ety> <sn>1.</sn> <fld>(Arch.)</fld> <def>See
<er>Hanse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A sudden fall or break, as the
fall of the fife rail down to the gangway.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hand</ent><br/
<hw>Hand</hw> <pr>(h<acr/nd)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hand</ets>, <ets>hond</ets>; akin to D., G., & Sw. <ets>hand</ets>,
OHG. <ets>hant</ets>, Dan. <ets>haand</ets>, Icel. <ets>h<oum/nd</ets>,
Goth. <ets>handus</ets>, and perh. to Goth. <ets>hin<thorn/an</ets> to
seize (in comp.). Cf. <er>Hunt</er>.]</ety> <sn>1.</sn> <def>That part
of the fore limb below the forearm or wrist in man and monkeys, and the
corresponding part in many other animals; manus; paw. See
<er>Manus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles, or to some extent performs the
office of, a human hand</def>; as: <sd>(a)</sd> <def>A limb of certain
animals, as the foot of a hawk, or any one of the four extremities of a
monkey.</def> <sd>(b)</sd> <def>An index or pointer on a dial; <as>as,
the hour or minute <ex>hand</ex> of a clock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A measure equal to a hand's breadth, -- four inches;
a palm. Chiefly used in measuring the height of horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Side; part; direction, either right or
left.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On this <qex>hand</qex> and that <qex>hand</qex>, were
hangings.</q> <rj><qau>Ex. xxxviii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Protestants were then on the winning <qex>hand</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Power of performance; means of execution; ability;
skill; dexterity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had a great mind to try his <qex>hand</qex> at a Spectator.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Actual performance; deed; act; workmanship; agency;
hence, manner of performance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To change the <qex>hand</qex> in carrying on the war.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gideon said unto God, If thou wilt save Israel by my
<qex>hand</qex>.</q> <rj><qau>Judges vi. 36.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>An agent; a servant, or laborer; a workman, trained
or competent for special service or duty; a performer more or less
skillful; <as>as, a deck <ex>hand</ex>; a farm <ex>hand</ex>; an old
<ex>hand</ex> at speaking.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A dictionary containing a natural history requires too many
<qex>hands</qex>, as well as too much time, ever to be hoped for.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I was always reckoned a lively <qex>hand</qex> at a simile.</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Handwriting; style of penmanship; <as>as, a good,
bad, or running <ex>hand</ex></as>. Hence, a signature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I say she never did invent this letter;<br/
This is a man's invention and his <qex>hand</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some writs require a judge's <qex>hand</qex>.</q>
<rj><qau>Burril.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Personal possession; ownership; hence, control;
direction; management; -- usually in the plural.</def> <ldquo/Receiving
in <xex>hand</xex> one year's tribute.<rdquo/
<rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Albinus . . . found means to keep in his <qex>hands</qex> the
government of Britain.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Agency in transmission from one person to another;
<as>as, to buy at first <ex>hand</ex>, that is, from the producer, or
when new; at second <ex>hand</ex>, that is, when no longer in the
producer's hand, or when not new</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Rate; price.</def> <mark>[Obs.]</mark>
<ldquo/Business is bought at a dear <xex>hand</xex>, where there is
small dispatch.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>That which is, or may be, held in a hand at
once</def>; as: <sd>(a)</sd> <fld>(Card Playing)</fld> <def>The quota of
cards received from the dealer.</def> <sd>(b)</sd> <fld>(Tobacco
Manuf.)</fld> <def>A bundle of tobacco leaves tied together.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Firearms)</fld> <def>The small part of a gunstock
near the lock, which is grasped by the hand in taking aim.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hand</xex> is used figuratively for a large variety
of acts or things, in the doing, or making, or use of which the hand is
in some way employed or concerned; also, as a symbol to denote various
qualities or conditions, as: <sd>(a)</sd> Activity; operation; work; --
in distinction from the <xex>head</xex>, which implies thought, and the
<xex>heart</xex>, which implies affection. <ldquo/His <xex>hand</xex>
will be against every man.<rdquo/ <au>Gen. xvi. 12.</au><sd>(b)</sd>
Power; might; supremacy; -- often in the Scriptures. <ldquo/With a
mighty <xex>hand</xex> . . . will I rule over you.<rdquo/ <au>Ezek. xx.
33.</au> <sd>(c)</sd> Fraternal feeling; <as>as, to give, or take, the
<ex>hand</ex>; to give the right <ex>hand</ex></as>. <sd>(d)</sd>
Contract; -- commonly of marriage; as, to ask the <xex>hand</xex>; to
pledge the <xex>hand</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hand</xex> is often used adjectively or in
compounds (with or without the hyphen), signifying <xex>performed by the
hand</xex>; as, <xex>hand</xex> blow or <xex>hand</xex>-blow,
<xex>hand</xex> gripe or <xex>hand</xex>-gripe: <xex>used by</xex>, or
<xex>designed for</xex>, <xex>the hand</xex>; as, <xex>hand</xex> ball
or <xex>hand</xex>ball, <xex>hand</xex> bow, <xex>hand</xex> fetter,
<xex>hand</xex> grenade or <xex>hand</xex>-grenade, <xex>hand</xex>gun
or <xex>hand</xex> gun, <xex>hand</xex>loom or <xex>hand</xex> loom,
<xex>hand</xex>mill or <xex>hand</xex> organ or <xex>hand</xex>organ,
<xex>hand</xex>saw or <xex>hand</xex> saw, <xex>hand</xex>-weapon:
<xex>measured</xex> or <xex>regulated by the hand</xex>; as,
<xex>hand</xex>breadth or <xex>hand's</xex> breadth, <xex>hand</xex>
gallop or <xex>hand</xex>-gallop. Most of the words in the following
paragraph are written either as two words or in combination.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hand bag</b></col>, <cd>a satchel; a small bag for
carrying books, papers, parcels, etc.</cd> -- <col><b>Hand
basket</b></col>, <cd>a small or portable basket.</cd> -- <col><b>Hand
bell</b></col>, <cd>a small bell rung by the hand; a table bell.</cd>
<au>Bacon.</au> -- <col><b>Hand bill</b></col>, <cd>a small pruning
hook. See 4th <er>Bill</er>.</cd> -- <col><b>Hand car</b></col>. <cd>See
under <er>Car</er>.</cd> -- <col><b>Hand director</b></col>
<fld>(Mus.)</fld>, <cd>an instrument to aid in forming a good position
of the hands and arms when playing on the piano; a hand guide.</cd> --
<col><b>Hand drop</b></col>. <cd>See <er>Wrist drop</er>.</cd> --
<col><b>Hand gallop</b></col>. <cd>See under <er>Gallop</er>.</cd> --
<col><b>Hand gear</b></col> <fld>(Mach.)</fld>, <cd>apparatus by means
of which a machine, or parts of a machine, usually operated by other
power, may be operated by hand.</cd> -- <col><b>Hand glass</b></col>.
<sd>(a)</sd> <cd>A glass or small glazed frame, for the protection of
plants.</cd> <sd>(b)</sd> <cd>A small mirror with a handle.</cd> --
<col><b>Hand guide</b></col>. <cd>Same as <cref>Hand director</cref>
(above).</cd> -- <col><b>Hand language</b></col>, <cd>the art of
conversing by the hands, esp. as practiced by the deaf and dumb;
dactylology.</cd> -- <col><b>Hand lathe</b></col>. <cd>See under
<er>Lathe</er>.</cd> -- <col><b>Hand money</b></col>, <cd>money paid in
hand to bind a contract; earnest money.</cd> -- <col><b>Hand
organ</b></col> <fld>(Mus.)</fld>, <cd>a barrel organ, operated by a
crank turned by hand.</cd> -- <col><b>Hand plant</b></col>.
<fld>(Bot.)</fld> <cd>Same as <cref>Hand tree</cref> (below). --
<er>Hand rail</er>, a rail, as in staircases, to hold by.</cd>
<au>Gwilt.</au> -- <col><b>Hand sail</b></col>, <cd>a sail managed by
the hand.</cd> <au>Sir W. Temple.</au> -- <col><b>Hand screen</b></col>,
<cd>a small screen to be held in the hand.</cd> -- <col><b>Hand
screw</b></col>, <cd>a small jack for raising heavy timbers or
weights</cd>; <fld>(Carp.)</fld> <cd>a screw clamp.</cd> -- <col><b>Hand
staff</b></col> <plu>(pl. <plw>Hand staves</plw>)</plu>, <cd>a
javelin.</cd> <au>Ezek. xxxix. 9.</au> -- <col><b>Hand stamp</b></col>,
<cd>a small stamp for dating, addressing, or canceling papers,
envelopes, etc.</cd> -- <col><b>Hand tree</b></col> <fld>(Bot.)</fld>,
<cd>a lofty tree found in Mexico (<spn>Cheirostemon platanoides</spn>),
having red flowers whose stamens unite in the form of a hand.</cd> --
<col><b>Hand vise</b></col>, <cd>a small vise held in the hand in doing
small work.</cd> <au>Moxon.</au> -- <mcol><col><b>Hand work</b></col>,
<it>or</it> <col><b>Handwork</b></col></mcol>, <cd>work done with the
hands, as distinguished from work done by a machine; handiwork.</cd> --
<col><b>All hands</b></col>, <cd>everybody; all parties.</cd> --
<mcol><col><b>At all hands</b></col>, <col><b>On all
hands</b></col></mcol>, <cd>on all sides; from every direction;
generally.</cd> -- <mcol><col><b>At any hand</b></col>, <col><b>At no
hand</b></col></mcol>, <cd>in any (or no) way or direction; on any
account; on no account.</cd> <ldquo/And therefore <xex>at no hand</xex>
consisting with the safety and interests of humility.<rdquo/ <au>Jer.
Taylor.</au> -- <mcol><col><b>At first hand</b></col>, <col><b>At second
hand</b></col></mcol>. <cd>See def. 10 (above).</cd> -- <col><b>At
hand</b></col>. <sd>(a)</sd> <cd>Near in time or place; either present
and within reach, or not far distant.</cd> <ldquo/Your husband is
<xex>at hand</xex>; I hear his trumpet.<rdquo/ <au>Shak.</au>
<sd>(b)</sd> <cd>Under the hand or bridle.</cd> <mark>[Obs.]</mark>
<ldquo/Horses hot <xex>at hand</xex>.<rdquo/ <au>Shak.</au> --
<col><b>At the hand of</b></col>, <cd>by the act of; as a gift
from.</cd> <ldquo/Shall we receive good <xex>at the hand of</xex> God
and shall we not receive evil?<rdquo/ <au>Job ii. 10.</au> --
<col><b>Bridle hand</b></col>. <cd>See under <er>Bridle</er>.</cd> --
<col><b>By hand</b></col>, <cd>with the hands, in distinction from
instrumentality of tools, engines, or animals; as, to weed a garden
<xex>by hand</xex>; to lift, draw, or carry <xex>by hand</xex>.</cd> --
<col><b>Clean hands</b></col>, <cd>freedom from guilt, esp. from the
guilt of dishonesty in money matters, or of bribe taking.</cd> <ldquo/He
that hath <xex>clean hands</xex> shall be stronger and stronger.<rdquo/
<au>Job xvii. 9.</au> -- <col><b>From hand to hand</b></col>, <cd>from
one person to another.</cd> -- <col><b>Hand in hand</b></col>.
<sd>(a)</sd> <cd>In union; conjointly; unitedly.</cd> <au>Swift.</au>
<sd>(b)</sd> <cd>Just; fair; equitable.</cd><br/
<br/
<q>As fair and as good, a kind of <qex>hand in hand</qex>
comparison.</q> <rj><qau>Shak.</qau></rj><br/
<br/
-- <mcol><col><b>Hand over hand</b></col>, <col><b>Hand over
fist</b></col></mcol>, <cd>by passing the hands alternately one before
or above another; as, to climb <xex>hand over hand</xex>; also, rapidly;
as, to come up with a chase <xex>hand over hand</xex>.</cd> --
<col><b>Hand over head</b></col>, <cd>negligently; rashly; without
seeing what one does.</cd> <mark>[Obs.]</mark> <au>Bacon.</au> --
<col><b>Hand running</b></col>, <cd>consecutively; <as>as, he won ten
times <ex>hand running</ex></as>.</cd> -- <col><b>Hands off!</b></col>
<cd>keep off! forbear! no interference or meddling!</cd> -- <col><b>Hand
to hand</b></col>, <cd>in close union; in close fight; <as>as, a
<ex>hand to hand</ex> contest</as>.</cd> <au>Dryden.</au> --
<col><b>Heavy hand</b></col>, <cd>severity or oppression.</cd> --
<col><b>In hand</b></col>. <sd>(a)</sd> <cd>Paid down.</cd> <ldquo/A
considerable reward <xex>in hand</xex>, and . . . a far greater reward
hereafter.<rdquo/ <au>Tillotson.</au> <sd>(b)</sd> <cd>In preparation;
taking place.</cd> <au>Chaucer.</au> <ldquo/Revels . . . in
<xex>hand</xex>.<rdquo/ <au>Shak.</au> <sd>(c)</sd> <cd>Under
consideration, or in the course of transaction; <as>as, he has the
business <ex>in hand</ex></as>.</cd> -- <mcol><col><b>In one's
hand</b></col> <it>or</it> <col><b>In one's hands</b></col></mcol>.
<sd>(a)</sd> <cd>In one's possession or keeping.</cd> <sd>(b)</sd>
<cd>At one's risk, or peril; <as>as, I took my life <ex>in my
hand</ex></as>.</cd> -- <col><b>Laying on of hands</b></col>, <cd>a form
used in consecrating to office, in the rite of confirmation, and in
blessing persons.</cd> -- <col><b>Light hand</b></col>, <cd>gentleness;
moderation.</cd> -- <col><b>Note of hand</b></col>, <cd>a promissory
note.</cd> -- <mcol><col><b>Off hand</b></col>, <col><b>Out of
hand</b></col></mcol>, <cd>forthwith; without delay, hesitation, or
difficulty; promptly.</cd> <ldquo/She causeth them to be hanged up
<xex>out of hand</xex>.<rdquo/ <au>Spenser.</au> -- <col><b>Off one's
hands</b></col>, <cd>out of one's possession or care.</cd> -- <col><b>On
hand</b></col>, <cd>in present possession; as, he has a supply of goods
<xex>on hand</xex>.</cd> -- <col><b>On one's hands</b></col>, <cd>in
one's possession care, or management.</cd> -- <col><b>Putting the hand
under the thigh</b></col>, <cd>an ancient Jewish ceremony used in
swearing.</cd> -- <col><b>Right hand</b></col>, <cd>the place of honor,
power, and strength.</cd> -- <col><b>Slack hand</b></col>, <cd>idleness;
carelessness; inefficiency; sloth.</cd> -- <col><b>Strict
hand</b></col>, <cd>severe discipline; rigorous government.</cd> --
<col><b>To bear a hand</b></col> <fld>(Naut.)</fld>, <cd>to give help
quickly; to hasten.</cd> -- <col><b>To bear in hand</b></col>, <cd>to
keep in expectation with false pretenses.</cd> <mark>[Obs.]</mark>
<au>Shak.</au> -- <mcol><col><b>To be hand and glove with</b></col>
<it>or</it> <col><b>To be hand in glove with</b></col></mcol>. <cd>See
under <er>Glove</er>.</cd> -- <col><b>To be on the mending
hand</b></col>, <cd>to be convalescent or improving.</cd> -- <col><b>To
bring up by hand</b></col>, <cd>to feed (an infant) without suckling
it.</cd> -- <col><b>To change hand</b></col>. <cd>See
<er>Change</er>.</cd> -- <col><b>To change hands</b></col>, <cd>to
change sides, or change owners.</cd> <au>Hudibras.</au> -- <col><b>To
clap the hands</b></col>, <cd>to express joy or applause, as by striking
the palms of the hands together.</cd> -- <col><b>To come to
hand</b></col>, <cd>to be received; to be taken into possession; as, the
letter <xex>came to hand</xex> yesterday.</cd> -- <col><b>To get
hand</b></col>, <cd>to gain influence.</cd> <mark>[Obs.]</mark><br/
<br/
<q>Appetites have . . . <qex>got</qex> such a <qex>hand</qex> over
them.</q> <rj><qau>Baxter.</qau></rj><br/
<br/
-- <col><b>To get one's hand in</b></col>, <cd>to make a beginning in a
certain work; to become accustomed to a particular business.</cd> --
<col><b>To have a hand in</b></col>, <cd>to be concerned in; to have a
part or concern in doing; to have an agency or be employed in.</cd> --
<col><b>To have in hand</b></col>. <sd>(a)</sd> <cd>To have in one's
power or control.</cd> <au>Chaucer.</au> <sd>(b)</sd> <cd>To be engaged
upon or occupied with.</cd> -- <col><b>To have one's hands
full</b></col>, <cd>to have in hand all that one can do, or more than
can be done conveniently; to be pressed with labor or engagements; to be
surrounded with difficulties.</cd> -- <mcol><col><b>To have the (higher)
upper hand</b></col>, <it>or</it> <col><b>To get the (higher) upper
hand</b></col></mcol>, <cd>to have, or get, the better of another person
or thing.</cd> -- <mcol><col><b>To his hand</b></col>, <col><b>To my
hand</b></col>, etc.</mcol>, <cd>in readiness; already prepared.</cd>
<ldquo/The work is made <xex>to his hands</xex>.<rdquo/ <au>Locke.</au>
-- <col><b>To hold hand</b></col>, <cd>to compete successfully or on
even conditions.</cd> <mark>[Obs.]</mark> <au>Shak.</au> -- <col><b>To
lay hands on</b></col>, <cd>to seize; to assault.</cd> -- <col><b>To
lend a hand</b></col>, <cd>to give assistance.</cd> -- <mcol><col><b>To
lift the hand against</b></col>, <it>or</it> <col><b>To put forth the
hand against</b></col></mcol>, <cd>to attack; to oppose; to kill.</cd>
-- <col><b>To live from hand to mouth</b></col>, <cd>to obtain food and
other necessaries as want compels, without previous provision.</cd> --
<col><b>To make one's hand</b></col>, <cd>to gain advantage or
profit.</cd> -- <col><b>To put the hand unto</b></col>, <cd>to
steal.</cd> <au>Ex. xxii. 8.</au> -- <mcol><col><b>To put the last hand
to</b></col> <it>or</it> <col><b>To put the finishing hand
to</b></col></mcol>, <cd>to make the last corrections in; to complete;
to perfect.</cd> -- <col><b>To set the hand to</b></col>, <cd>to engage
in; to undertake.</cd><br/
<br/
<q>That the Lord thy God may bless thee in all that thou <qex>settest
thine hand to</qex>.</q> <rj><qau>Deut. xxiii. 20.</qau></rj><br/
<br/
-- <col><b>To stand one in hand</b></col>, <cd>to concern or affect
one.</cd> -- <col><b>To strike hands</b></col>, <cd>to make a contract,
or to become surety for another's debt or good behavior.</cd> --
<col><b>To take in hand</b></col>. <sd>(a)</sd> <cd>To attempt or
undertake</cd>. <sd>(b)</sd> <cd>To seize and deal with; as, he
<xex>took</xex> him <xex>in hand</xex>.</cd> -- <col><b>To wash the
hands of</b></col>, <cd>to disclaim or renounce interest in, or
responsibility for, a person or action; as, <xex>to wash one's hands
of</xex> a business.</cd> <au>Matt. xxvii. 24.</au> -- <col><b>Under the
hand of</b></col>, <cd>authenticated by the handwriting or signature of;
<as>as, the deed is executed <ex>under the hand</ex> and seal
<ex>of</ex> the owner</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hand</ent><br/
<hw>Hand</hw> <pr>(h<acr/nd)</pr>, <pos>n.</pos> <def>A gambling game
played by American Indians, consisting of guessing the whereabouts of
bits of ivory or the like, which are passed rapidly from hand to
hand.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hand</ent><br/
<hw>Hand</hw> <pr>(h<acr/nd)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Handed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Handing</conjf>.]</vmorph> <sn>1.</sn> <def>To give, pass, or
transmit with the hand; <as>as, he <ex>handed</ex> them the
letter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lead, guide, or assist with the hand; to conduct;
<as>as, to <ex>hand</ex> a lady into a carriage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To manage; <as>as, I <ex>hand</ex> my
oar</as>.</def> <mark>[Obs.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To seize; to lay hands on.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To pledge by the hand; to handfast.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>To furl; -- said of a sail.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hand down</b></col>, <cd>to transmit in succession, as
from father to son, or from predecessor to successor; as, fables are
<xex>handed down</xex> from age to age; to forward to the proper officer
(the decision of a higher court); as, the Clerk of the Court of Appeals
<xex>handed down</xex> its decision.</cd> -- <col><b>To hand
over</b></col>, <cd>to yield control of; to surrender; to deliver
up.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hand</ent><br/
<hw>Hand</hw>, <pos>v. i.</pos> <def>To cooperate.</def>
<mark>[Obs.]</mark> <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handbag</ent><br/
<hw>hand"bag`</hw> <pos>n.</pos> <def>a small bag usually made of cloth,
leather or a similar imitation material, and often having a strap to
permit carrying it by slinging it over a shoulder, used by women to
carry money and small personal items or accessories; <as>as, she had to
search under the cosmetics, hankies, and medicines in her
<ex>handbag</ex> to find a comb</as>.</def><br/
<syn><b>Syn. --</b> bag, pocketbook, purse.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handball</ent><br/
<hw>Hand"ball`</hw> <pr>(h<acr/nd"b<add/l`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A small ball, usually made of rubber, thrown or struck
with the hand in various games.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A game played with such a ball, as by players
striking it to and fro between them with the hands, or, when played in a
walled court or against a single wall, striking it in turns against a
wall, until one side or the other fails to return the ball.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Handbarrow</ent><br/
<hw>Hand"bar`row</hw> <pr>(h<acr/nd"b<acr/r`r<osl/)</pr>, <pos>n.</pos>
<def>A frame or barrow, without a wheel, carried by hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handbasin</ent><br/
<hw>handbasin</hw> <pos>n.</pos> <def>A small basin used for washing
thehands; <as>as, `wash-hand basin' is a British term</as>.</def><br/
<syn><b>Syn. --</b> washbasin, washbowl, lavabo, wash-hand
basin.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handbasket</ent><br/
<hw>hand"bask*et</hw> <pos>n.</pos> <def>a container that is usually
woven and has handles.</def><br/
<syn><b>Syn. --</b> basket.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><col><b>go to hell in a handbasket</b></col> <cd>to deteriorate
substantially and quickly; <as>as, after they lost the contract, the
company's profits <ex>went to hell in a handbasket</ex></as>.</cd><br/
[<source>PJC</source>]</p>

<p><ent>handbell</ent><br/
<hw>handbell</hw> <pos>n.</pos> <def>a bell that is held in the
hand.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handbill</ent><br/
<hw>Hand"bill`</hw> <pr>(-b<icr/l`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A loose, printed sheet, to be distributed by hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A pruning hook.</def> <altsp>[Usually written
<asp>hand bill</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handbook</ent><br/
<hw>Hand"book`</hw> <pr>(-b<oocr/k`)</pr>, <pos>n.</pos>
<ety>[<ets>Hand</ets> + <ets>book</ets>; cf. AS.
<ets>handb<omac/c</ets>, or G. <ets>handbuch</ets>.]</ety> <sn>1.</sn>
<def>A book of reference, to be carried in the hand; a manual; a
guidebook.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A book containing reference information for a
specific field; <as>as, the <ex>Handbook</ex> of
Chemistry</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hand-brake</ent><br/
<ent>handbrake</ent><br/
<mhw><hw>hand"brake`</hw>, <hw>hand"-brake`</hw></mhw> <pos>n.</pos>
<def>a brake operated by hand, used to stop a vehicle or keep it
stationary; it usually operates by a mechanical linkage.</def><br/
<syn><b>Syn. --</b> handbrake, emergency, emergency brake, parking
brake.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handbreadth</ent><br/
<hw>Hand"breadth`</hw> <pr>(-br<ecr/dth`)</pr>, <pos>n.</pos> <def>A
space equal to the breadth of the hand; a palm.</def> <rj><au>Ex.
xxxvii. 12.</au></rj><br/
<syn><b>Syn. --</b> handsbreadth.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>handbuild</ent><br/
<hw>handbuild</hw> <pos>v. t.</pos> <def>to make without a wheel; of
pottery.</def><br/
<syn><b>Syn. --</b> coil.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handcar</ent><br/
<hw>handcar</hw> <pos>n.</pos> <def>a small railroad car propelled by
hand or by a small motor.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handcart</ent><br/
<hw>Hand"cart`</hw>, <pos>n.</pos> <def>A cart drawn or pushed by
hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handcloth</ent><br/
<hw>Hand"cloth`</hw> <pr>(-kl<ocr/th`; 115)</pr>, <pos>n.</pos> <def>A
handkerchief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handcolor</ent><br/
<hw>handcolor</hw> <pos>v. t.</pos> <def>to add color to (a
black-and-white image) using an instrument held in the hand; <as>as,
Some old photographs are <ex>handcolored</ex></as>.</def><br/
<syn><b>Syn. --</b> color by hand.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Handcraft</ent><br/
<hw>Hand"craft`</hw> <pr>(-kr<adot/ft`)</pr>, <pos>n.</pos> <def>Same as
<er>Handicraft</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hand-craft</ent><br/
<ent>handcraft</ent><br/
<mhw><hw>hand"craft`</hw>, <hw>hand"-craft`</hw></mhw> <pos>v. t.</pos>
<def>to make (something) by hand.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-crafted</ent><br/
<hw>hand-crafted</hw> <pos>adj.</pos> <def>made by hand or by a hand
process. Contrasted to <ant>machine-made</ant>.</def> [Narrower terms:
<stype>camp-made </stype>; <stype>hand-loomed, handwoven </stype>;
<stype>handsewn, handstitched </stype>; <stype>overhand, oversewn
)</stype>]<br/
<syn><b>Syn. --</b> handmade.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handcraftsman</ent><br/
<hw>Hand"crafts`man</hw> <pr>(-m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-men</plw> <pr>(-m<eit/n)</pr>.</plu> <def>A
handicraftsman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handcuff</ent><br/
<hw>Hand"cuff`</hw> <pr>(-k<ucr/f`)</pr>, <pos>n.</pos> <ety>[AS.
<ets>handcops</ets>; <ets>hand</ets> hand + <ets>cosp</ets>,
<ets>cops</ets>, fetter. The second part was confused with E.
<ets>cuffs</ets>,]</ety> <def>A fastening, consisting of an iron ring
around the wrist, usually connected by a chain with one on the other
wrist; a manacle; -- usually in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 668 pr=JMD --></p>

<p><ent>Handcuff</ent><br/
<hw>Hand"cuff`</hw> <pr>(h<acr/nd"k<ucr/f`)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Handcuffed</conjf>
<pr>(-k<ucr/ft`)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Handcuffing</conjf>.]</vmorph> <def>To apply handcuffs to; to
manacle.</def> <rj><au>Hay (1754).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hand-down</ent><br/
<hw>hand-down</hw> <pos>adj.</pos> <def>same as
<er>hand-me-down</er>.</def><br/
<syn><b>Syn. --</b> hand-me-down, secondhand, used.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handed</ent><br/
<hw>Hand"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>With hands joined; hand
in hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Into their inmost bower,<br/
<qex>Handed</qex> they went.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a peculiar or characteristic hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As poisonous tongued as <qex>handed</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Handed</xex> is used in composition in the sense of
<xex>having</xex> (such or so many) <xex>hands</xex>; as,
bloody-<xex>handed</xex>; free-<xex>handed</xex>;
heavy-<xex>handed</xex>; left-<xex>handed</xex>;
single-<xex>handed</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>hander</ent><br/
<hw>hand"er</hw> <pr>(h<acr/nd"<etil/r)</pr>, <pos>n.</pos> <def>One who
hands over or transmits; a conveyer in succession.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handfast</ent><br/
<hw>hand"fast`</hw> <pr>(h<acr/nd"f<adot/st`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Hold; grasp</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Custody; power of confining or keeping.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A contract; specifically, an espousal.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>handfast</ent><br/
<hw>hand"fast`</hw>, <pos>a.</pos> <def>Fast by contract; betrothed by
joining hands.</def> <mark>[Obs.]</mark> <rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handfast</ent><br/
<hw>hand"fast`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>handfasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>handfasting</conjf>.]</vmorph> <sn>1.</sn> <def>To pledge; to
bind.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To betroth by joining hands, in order to permit
cohabitation, before the formal celebration of marriage; in some parts
of Scotland it was in effect to marry provisionally, permitting
cohabitation for a year, after which the marriage could be formalized or
dissolved.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ Handfasting was a simple contract of agreement under
which cohabitation was permitted for a year, at the end of which time
the contract could be either dissolved or made permanent by a formal
marriage. Such marriages, at first probably not intended to be
temporary, are supposed to have originated in Scotland from a scarcity
of clergy, and to have existed at times in other countries.</note><br/
[<source>Century Dict. 1906.</source>]</p>

<p><ent>handfast</ent><br/
<hw>hand"fast`</hw>, <pos>a.</pos> <ety>[G. <ets>handfest</ets>;
<ets>hand</ets> hand + <ets>fest</ets> strong. See <er>Fast</er>.]</ety>
<def>Strong; steadfast.</def><mark>[R.]</mark>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handfastly</ent><br/
<hw>hand"fast`ly</hw>, <pos>adv.</pos> <def>In a handfast or publicly
pledged manner.</def> <mark>[Obs.]</mark>
<rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handfish</ent><br/
<hw>hand"fish`</hw> <pr>(h<acr/nd"f<icr/sh`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The frogfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handful</ent><br/
<hw>hand"ful</hw> <pr>(h<acr/nd"f<usdot/l)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>handfuls</plw>
<pr>(h<acr/nd"f<usdot/lz)</pr>.</plu> <ety>[AS.
<ets>handfull</ets>.]</ety> <sn>1.</sn> <def>As much as the hand will
grasp or contain.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hand's breadth; four inches.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Knap the tongs together about a <qex>handful</qex> from the
bottom.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A small quantity or number.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>handful</qex> of men were tied to very hard duty.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person, task, or situation, which is the most that
one can manage; <as>as, my two-year-old is a
<ex>handful</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To have one's handful</b></col>, <cd>to have one's hands
full; to have all one can do.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>had their handful</qex> to defend themselves from
firing.</q> <rj><qau>Sir. W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hand-hole</ent><br/
<hw>hand"-hole`</hw> <pr>(h<acr/nd"h<omac/l`)</pr>, <pos>n.</pos>
<fld>(Steam Boilers)</fld> <def>A small hole in a boiler for the
insertion of the hand in cleaning, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hand-hole plate</b></col>, <cd>the cover of a
hand-hole.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>handicap</ent><br/
<hw>hand"i*cap</hw> <pr>(h<acr/n"d<icr/*k<acr/p)</pr>, <pos>n.</pos>
<ety>[From <ets>hand in cap</ets>; -- perh. in reference to an old mode
of settling a bargain by taking pieces of money from a cap.]</ety>
<sn>1.</sn> <def>An allowance of a certain amount of time or distance in
starting, granted in a race to the competitor possessing inferior
advantages; or an additional weight or other hindrance imposed upon the
one possessing superior advantages, in order to equalize, as much as
possible, the chances of success; <as>as, the <ex>handicap</ex> was five
seconds, or ten pounds, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A race, for horses or men, or any contest of
agility, strength, or skill, in which there is an allowance of time,
distance, weight, or other advantage, to equalize the chances of the
competitors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An old game at cards.</def> <mark>[Obs.]</mark>
<rj><au>Pepys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>a physical or mental disability of the body which
makes normal human activities more difficult or impossible; <as>as, his
deformed leg was a major <ex>handicap</ex> in walking</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>any disadvantage that makes an activity more
difficult or impossible; <as>as, insufficient capital was a big
<ex>handicap</ex> in competing against Microsoft</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Handicap</ent><br/
<hw>Hand"i*cap</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Handicapped</conjf> <pr>(-k<acr/pt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Handicapping</conjf>.]</vmorph> <def>To encumber with a
handicap in any contest; hence, in general, to place at disadvantage;
<as>as, the candidate was heavily <ex>handicapped</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handicapper</ent><br/
<hw>Hand"i*cap`per</hw> <pr>(-k<acr/p`p<etil/r)</pr>, <pos>n.</pos>
<def>One who determines the conditions of a handicap.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handicapped</ent><br/
<hw>Hand"i*capped</hw> <pr>(h<acr/nd"<icr/*k<acr/pt)</pr>, <pos>a.</pos>
<def>suffering from a handicap (in senses 4 or 5); disabled; at a
disadvantage.</def><br/
[<source>PJC</source>]</p>

<p><ent>Handicraft</ent><br/
<hw>Hand"i*craft</hw> <pr>(h<acr/nd"<icr/*kr<adot/ft)</pr>,
<pos>n.</pos> <ety>[For <ets>handcraft</ets>, influenced by
<ets>handiwork</ets>; AS. <ets>handcr<ae/ft</ets>.]</ety> <sn>1.</sn>
<def>A trade requiring skill of hand; manual occupation;
handcraft.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man who earns his living by handicraft; a
handicraftsman.</def> <mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handicraftsman</ent><br/
<hw>Hand"i*crafts`man</hw> <pr>(-kr<adot/fts`m<ait/n)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>-men</plw>
<pr>(-m<eit/n)</pr>.</plu> <def>A man skilled or employed in
handcraft.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handily</ent><br/
<hw>Hand"i*ly</hw> <pr>(-<icr/*l<ycr/)</pr>, <pos>adv.</pos> <ety>[See
<er>Handy</er>.]</ety> <def>In a handy manner; skillfully;
conveniently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handiness</ent><br/
<hw>Hand"i*ness</hw>, <pos>n.</pos> <def>The quality or state of being
handy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handiron</ent><br/
<hw>Hand"i`ron</hw> <pr>(-<imac/`<ucr/rn)</pr>, <pos>n.</pos> <def>See
<er>Andiron</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handiwork</ent><br/
<hw>Hand"i*work`</hw> <pr>(-<icr/*w<ucir/rk`)</pr>, <pos>n.</pos>
<ety>[OE. <ets>handiwerc</ets>, AS. <ets>handgeweorc</ets>;
<ets>hand</ets> hand + <ets>geweorc</ets> work; prefix <ets>ge-</ets> +
<ets>weorc</ets>. See <er>Work</er>.]</ety> <def>Work done by the hands;
hence, any work done personally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The firmament showeth his <qex>handiwork</qex>.</q> <rj><qau>Ps.
xix. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handkercher</ent><br/
<hw>Hand"ker*cher</hw> <pr>(h<acr/<nsm/"k<etil/r*ch<etil/r)</pr>,
<pos>n.</pos> <def>A handkerchief.</def> <mark>[Obs. or Colloq.]</mark>
<rj><au>Chapman (1654). Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handkerchief</ent><br/
<hw>Hand"ker*chief</hw> <pr>(h<acr/<nsm/"k<etil/r*ch<icr/f; 277)</pr>,
<pos>n.</pos> <ety>[<ets>Hand</ets> + <ets>kerchief</ets>.]</ety>
<sn>1.</sn> <def>A piece of cloth, usually square and often fine and
elegant, carried for wiping the face or hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of cloth shaped like a handkerchief to be
worn about the neck; a neckerchief; a neckcloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handle</ent><br/
<hw>Han"dle</hw> <pr>(h<acr/n"d'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Handled</conjf>
<pr>(-d'ld)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Handling</conjf>
<pr>(-dl<icr/ng)</pr>.]</vmorph> <ety>[OE. <ets>handlen</ets>, AS.
<ets>handlian</ets>; akin to D. <ets>handelen</ets> to trade, G.
<ets>handeln</ets>. See <er>Hand</er>.]</ety> <sn>1.</sn> <def>To touch;
to feel with the hand; to use or hold with the hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Handle</qex> me, and see; for a spirit hath not flesh.</q>
<rj><qau>Luke xxiv. 39.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>About his altar, <qex>handling</qex> holy things.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To manage in using, as a spade or a musket; to
wield; often, to manage skillfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That fellow <qex>handles</qex> his bow like a crowkeeper.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To accustom to the hand; to work upon, or take care
of, with the hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hardness of the winters forces the breeders to house and
<qex>handle</qex> their colts six months every year.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To receive and transfer; to have pass through one's
hands; hence, to buy and sell; <as>as, a merchant <ex>handles</ex> a
variety of goods, or a large stock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To deal with; to make a business of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They that <qex>handle</qex> the law knew me not.</q> <rj><qau>Jer.
ii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To treat; to use, well or ill.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How wert thou <qex>handled</qex> being prisoner?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To manage; to control; to practice skill
upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You shall see how I will <qex>handle</qex> her.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To use or manage in writing or speaking; to treat,
as a theme, an argument, or an objection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We will <qex>handle</qex> what persons are apt to envy others.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To handle without gloves</b></col>. <cd>See under
<er>Glove</er>.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handle</ent><br/
<hw>Han"dle</hw> <pr>(h<acr/n"d'l)</pr>, <pos>v. i.</pos> <def>To use
the hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They have hands, but they <qex>handle</qex> not.</q> <rj><qau>Ps.
cxv. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handle</ent><br/
<hw>Han"dle</hw>, <pos>n.</pos> <ety>[AS. <ets>handle</ets>. See
<er>Hand</er>.]</ety> <sn>1.</sn> <def>That part of vessels,
instruments, etc., which is held in the hand when used or moved, as the
haft of a sword, the knob of a door, the bail of a kettle,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That of which use is made; the instrument for
effecting a purpose; a tool.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To give a handle</b></col>, <cd>to furnish an occasion or
means.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handleable</ent><br/
<hw>Han"dle*a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos>
<def>Capable of being handled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handlebar</ent><br/
<hw>han"dle*bar`</hw> <pos>n.</pos> <def>The curved bar connected by a
shaft to the front wheel of a bicycle or motorcycle, positioned nearly
horizontally in front of the rider's seat, designed to be gripped by the
rider while riding, and used to steer the vehicle. Usually used in the
plural; <as>as, don't let go of the <ex>handlbars</ex></as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>handled</ent><br/
<hw>handled</hw> <pos>adj.</pos> <def>fitted with or having having a
handle; <as>as, a <ex>handled</ex> magnifying glass is easier to
use</as>. Opposite of <ant>handleless</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>-handled</ent><br/
<hw>-handled</hw> <pos>suff.</pos> <def>having a usually specified type
of handle; <as>as, a pearl-<ex>handled</ex> revolver; a
long-<ex>handled</ex> shovel</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handleless</ent><br/
<hw>handleless</hw> <pos>adj.</pos> <def>having no handle; <as>as, sleek
cabinets with apparently <ex>handleless</ex> doors</as>. Opposite of
<ant>handled</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handler</ent><br/
<hw>handler</hw> <pos>n.</pos> <sn>1.</sn> <def>one who trains or
exhibits animals.</def><br/
<syn><b>Syn. --</b> animal trainer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>someone in charge of training an athlete (especially
a boxer) or a team.</def> <note>The term is used sometimes sarcastically
of political consultants: <ldquo/the president's
handlers<rdquo/.</note><br/
<syn><b>Syn. --</b> coach, manager.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Handless</ent><br/
<hw>Hand"less</hw> <pr>(h<acr/nd"l<ecr/s)</pr>, <pos>a.</pos>
<def>Without a hand.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handline</ent><br/
<hw>handline</hw> <pos>n.</pos> <def>a fishing line managed principally
by hand.</def><br/
<syn><b>Syn. --</b> hand line.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handling</ent><br/
<hw>Han"dling</hw> <pr>(h<acr/n"dl<icr/ng)</pr>, <pos>n.</pos> <ety>[AS.
<ets>handlung</ets>.]</ety> <sn>1.</sn> <def>A touching, controlling,
managing, using, etc., with the hand or hands, or as with the hands. See
<er>Handle</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The heavens and your fair <qex>handling</qex><br/
Have made you master of the field this day.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Drawing, Painting, etc.)</fld> <def>The mode of
using the pencil or brush, etc.; style of touch.</def>
<rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handlock</ent><br/
<hw>handlock</hw> <pos>n.</pos> <def>a metal loop that can be locked
around the wrist, usually used in pairs; a handcuff.</def><br/
<syn><b>Syn. --</b> handcuffs, handcuff, cuffs, cuff, manacle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-loomed</ent><br/
<hw>hand-loomed</hw> <pos>adj.</pos> <def>Woven on a handloom; -- of
fabrics, rugs, or carpets.</def><br/
<syn><b>Syn. --</b> handwoven.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Handmade</ent><br/
<hw>Hand"made`</hw> <pr>(h<acr/nd"m<amac/d`)</pr>, <pos>a.</pos>
<def>Manufactured by hand; <as>as, <ex>handmade</ex> shoes</as>.
Contrasted with <contr>machine-made</contr>.</def></p>

<p><ent>Handmaiden</ent><br/
<ent>Handmaid</ent><br/
<mhw>{ <hw>Hand"maid`</hw> <pr>(h<acr/nd"m<amac/d`)</pr>,
<hw>Hand"maid`en</hw> <pr>(h<acr/nd"m<amac/d`'n)</pr>, }</mhw>
<pos>n.</pos> <def>A maid that waits at hand; a female servant or
attendant.</def> <wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something or someone serving in a subordinate
position; <as>as, theology should be the <ex>handmaiden</ex> of
ethics</as>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> handmaid, servant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-me-down</ent><br/
<hw>hand-me-down</hw> <pos>adj.</pos> <sn>1.</sn> <def>obtained or used
after prior use by another person.</def> <note>the term
<ex>hand-me-down</ex> is often used of clothing previously worn by older
family members. The term may also be used metaphorically of
ideas.</note><br/
<syn><b>Syn. --</b> hand-down, secondhand, used.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-me-down</ent><br/
<hw>hand-me-down</hw> <pos>n.</pos> <def>An outgrown garment given to
one person after use by another; -- usually transferred between members
of a family or close friends; <as>as, because she was the youngest of
four girls, the clothes she wore were always
<ex>hand-me-downs</ex></as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>handoff</ent><br/
<hw>handoff</hw> <pos>n.</pos> <fld>(Football)</fld> <def>A football
play in which one player hands the ball to a teammate.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-operated</ent><br/
<hw>hand-operated</hw> <pos>adj.</pos> <sn>1.</sn> <def>requiring hand
manipulation for operation; not automatic or machine-driven; <as>as, a
<ex>hand-operated</ex> winch</as>. Opposite of <ant>automatic</ant> or
<ant>powered</ant>.</def><br/
<syn><b>Syn. --</b> non-automatic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-out</ent><br/
<ent>handout</ent><br/
<mhw><hw>hand"out</hw>, <hw>hand"-out</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>money or an object given in or as in a charitable
gesture; -- also used of government disbursements to individuals for
welfare; <as>as, government <ex>hand-outs</ex> to welfare
clients</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a printed circular distributed gratis, usually for
political or advertising purposes.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>a printed statement distributed, usually to the news
media.</def><br/
[<source>PJC</source>]</p>

<p><ent>handover</ent><br/
<hw>handover</hw> <pos>n.</pos> <def>The act of relinquishing property
or authority etc. to another; <as>as, the <ex>handover</ex> of occupied
territory to the original posssessors; the <ex>handover</ex> of power
from the military back to the civilian authorities</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hand-picked</ent><br/
<hw>hand-picked</hw> <pos>adj.</pos> <def>carefully selected; <as>as, a
<ex>hand-picked</ex> jury; the company's president groomed his
<ex>hand-picked</ex> successor</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>handrail</ent><br/
<hw>hand"rail`</hw> <pos>n.</pos> <def>a rail{1} at the side of
staircase or balcony to prevent people from falling; -- shaped so as to
be conveniently gripped with the hand; <as>as, please hold onto the
<ex>handrail</ex> when crossing the walkway</as>.</def><br/
<syn><b>Syn. --</b> bannister, banister, balustrade,
balusters.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handrest</ent><br/
<hw>hand"rest`</hw> <pos>n.</pos> <def>a support for the hand.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hands</ent><br/
<hw>hands</hw> <pos>n.</pos> <sn>1.</sn> <def>a person's power or
discretionary action; <as>as, my fate is in your
<ex>hands</ex></as>.</def><br/
<syn><b>Syn. --</b> custody.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The force of workers available; <as>as, all
<ex>hands</ex> on deck</as>.</def><br/
<syn><b>Syn. --</b> work force, manpower, men.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>A dictionary containing a natural history requires too many
<qex>hands</qex>, as well as too much time, ever to be hoped for.</q>
<rj><qau>Locke.</qau></rj></p>

<p><ent>Handsaw</ent><br/
<hw>Hand"saw`</hw> <pr>(h<acr/nd"s<add/`)</pr> <pos>n.</pos> <def>A saw
used with one hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handsbreadth</ent><br/
<hw>handsbreadth</hw> <pos>n.</pos> <def>any unit of length based on the
breadth of the human hand.</def><br/
<syn><b>Syn. --</b> handbreath.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handsel</ent><br/
<hw>Hand"sel</hw> <pr>(h<acr/nd"s<ecr/l)</pr>, <pos>n.</pos>
<altsp>[Written also <asp>hansel</asp>.]</altsp> <ety>[OE.
<ets>handsal</ets>, <ets>hansal</ets>, <ets>hansel</ets>, AS.
<ets>handselen</ets>a giving into hands, or more prob. fr. Icel.
<ets>handsal</ets>; <ets>hand</ets> hand + <ets>sal</ets> sale, bargain;
akin to AS. <ets>sellan</ets> to give, deliver. See <er>Sell</er>,
<er>Sale</er>. ]</ety> <sn>1.</sn> <def>A sale, gift, or delivery into
the hand of another; especially, a sale, gift, delivery, or using which
is the first of a series, and regarded as an omen for the rest; a first
installment; an earnest; as the first money received for the sale of
goods in the morning, the first money taken at a shop newly opened, the
first present sent to a young woman on her wedding day, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their first good <qex>handsel</qex> of breath in this world.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our present tears here, not our present laughter,<br/
Are but the <qex>handsels</qex> of our joys hereafter.</q>
<rj><qau>Herrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Price; payment.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Handsel Monday</b></col>, <cd>the first Monday of the new
year, when <xex>handsels</xex> or presents are given to servants,
children, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handsel</ent><br/
<hw>Hand"sel</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Handseled</conjf> <it>or</it> <conjf>Handselled</conjf>
<pr>(h<acr/nd"s<ecr/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Handseling</conjf> <it>or</it>
<conjf>Handselling</conjf>.]</vmorph> <ety>[Written also
<ets>hansel</ets>.]</ety> <ety>[OE <ets>handsellen</ets>,
<ets>hansellen</ets>; cf. Icel. <ets>hadsala</ets>,
<ets>handselja</ets>. See <er>Handsel</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To give a handsel to.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To use or do for the first time, esp. so as to make
fortunate or unfortunate; to try experimentally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No contrivance of our body, but some good man in Scripture hath
<qex>handseled</qex> it with prayer.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>handset</ent><br/
<hw>handset</hw> <pos>n.</pos> <fld>(Electronics)</fld> <def>The
mouthpiece and earpiece of a communications device mounted on a single
handle; <as>as, when the telephone rings, pick up the
<ex>handset</ex></as>.</def><br/
<syn><b>Syn. --</b> French telephone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handsewn</ent><br/
<hw>handsewn</hw> <pos>adj.</pos> <def>sewn by hand rather than
machine.</def><br/
<syn><b>Syn. --</b> handstitched.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handstand</ent><br/
<hw>handstand</hw> <pos>n.</pos> <def>The gymnastic act of supporting
oneself by one's hands alone in an upside down position; <as>as, to do
<ex>handstands</ex> for exercise</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Handsome</ent><br/
<hw>Hand"some</hw> <pr>(h<acr/n"s<ucr/m; 277)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Handsomer</adjf> <pr>(-<etil/r)</pr>;
<pos>superl.</pos> <adjf>Handsomest</adjf>.]</amorph>
<ety>[<ets>Hand</ets> + <ets>-some</ets>. It at first meant, dexterous;
cf. D. <ets>handzaam</ets> dexterous, ready, limber, manageable, and E.
<ets>handy</ets>.]</ety> <sn>1.</sn> <def>Dexterous; skillful; handy;
ready; convenient; -- applied to things as persons.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That they [engines of war] be both easy to be carried and
<qex>handsome</qex> to be moved and turned about.</q> <rj><qau>Robynson
(Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For a thief it is so <qex>handsome</qex> as it may seem it was
first invented for him.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Agreeable to the eye or to correct taste; having a
pleasing appearance or expression; attractive; having symmetry and
dignity; comely; -- expressing more than <xex>pretty</xex>, and less
than <xex>beautiful</xex>; <as>as, a <ex>handsome</ex> man or woman; a
<ex>handsome</ex> garment, house, tree, horse.</as></def><-- MW10 treats
it as synonymous with beautiful in this sense. --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Suitable or fit in action; marked with propriety and
ease; graceful; becoming; appropriate; <as>as, a <ex>handsome</ex>
style, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Easiness and <qex>handsome</qex> address in writing.</q>
<rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Evincing a becoming generosity or nobleness of
character; liberal; generous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Handsome</qex> is as <qex>handsome</qex> does.</q>
<rj><qau>Old Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Ample; moderately large.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . accumulated a <xex>handsome</xex> sum of money.</q>
<rj><qau>V. Knox.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To do the handsome thing</b></col>, <cd>to act
liberally.</cd> <mark>[Colloq.]</mark></cs></p>

<p><syn><b>Syn.</b> -- <er>Handsome</er>, <er>Pretty</er>.</syn> <usage>
<xex>Pretty</xex> applies to things comparatively small, which please by
their delicacy and grace; as, a <xex>pretty</xex> girl, a
<xex>pretty</xex> flower, a <xex>pretty</xex> cottage.
<xex>Handsome</xex> rises higher, and is applied to objects on a larger
scale. We admire what is <xex>handsome</xex>, we are pleased with what
is <xex>pretty</xex>. The word is connected with <xex>hand</xex>, and
has thus acquired the idea of training, cultivation, symmetry, and
proportion, which enters so largely into our conception of
<xex>handsome</xex>. Thus Drayton makes mention of <xex>handsome</xex>
players, meaning those who are well trained; and hence we speak of a
man's having a <xex>handsome</xex> address, which is the result of
culture; of a <xex>handsome</xex> horse or dog, which implies well
proportioned limbs; of a <xex>handsome</xex> face, to which, among other
qualities, the idea of proportion and a graceful contour are essential;
of a <xex>handsome</xex> tree, and a <xex>handsome</xex> house or villa.
So, from this idea of proportion or suitableness, we have, with a
different application, the expressions, a <xex>handsome</xex> fortune, a
<xex>handsome</xex> offer.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handsome</ent><br/
<hw>Hand"some</hw>, <pos>v. t.</pos> <def>To render handsome.</def>
<mark>[Obs.]</mark> <rj><au>Donne</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handsomely</ent><br/
<hw>Hand"some*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a handsome
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>Carefully; in shipshape
style.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handsomeness</ent><br/
<hw>Hand"some*ness</hw>, <pos>n.</pos> <def>The quality of being
handsome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Handsomeness</qex> is the mere animal excellence, beauty the
mere imaginative.</q> <rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handspike</ent><br/
<hw>Hand"spike`</hw> <pr>(h<acr/nd"sp<imac/k`)</pr>, <pos>n.</pos>
<def>A bar or lever, generally of wood, used in a windlass or capstan,
for heaving anchor, and, in modified forms, for various
purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handspring</ent><br/
<hw>Hand"spring`</hw> <pr>(-spr<icr/ng)</pr>, <pos>n.</pos> <def>A
somersault made with the assistance of the hands placed upon the
ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handstitched</ent><br/
<hw>handstitched</hw> <pos>adj.</pos> <def>same as
<er>handsewn</er>.</def><br/
<syn><b>Syn. --</b> handsewn.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hand-tight</ent><br/
<hw>Hand"-tight`</hw> <pr>(-t<imac/t`)</pr>, <pos>a.</pos> <def>As tight
as can be made by the hand; <as>as, to tighten the nut
<ex>hand-tight</ex></as>.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hand-to-hand</ent><br/
<hw>hand-to-hand</hw> <pos>adj.</pos> <def>close to one's adversary; --
of combat; <as>as, <ex>hand-to-hand</ex> fighting</as>.</def><br/
<syn><b>Syn. --</b> at close quarters(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handwash</ent><br/
<hw>handwash</hw> <pos>v.</pos> <def>to wash by hand, launder by hand;
-- contrasted to <contr>machine-wash</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>handwear</ent><br/
<hw>handwear</hw> <pos>n.</pos> <def>clothing for the hands, especially
gloves.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handwheel</ent><br/
<hw>Hand"wheel`</hw> <pr>(-hw<emac/l)</pr>, <pos>n.</pos>
<fld>(Mach.)</fld> <def>Any wheel worked by hand; esp., one the rim of
which serves as the handle by which a valve, car brake, or other part is
adjusted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hand-winged</ent><br/
<hw>Hand"-winged`</hw> <pr>(h<acr/nd"w<icr/ngd`)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having wings that are like hands in the
structure and arrangement of their bones; -- said of bats. See
<er>Cheiroptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>handwoven</ent><br/
<hw>handwoven</hw> <pos>adj.</pos> <def>same as <er>hand-loomed; <as>as,
a <ex>handwoven</ex> tablecloth</as></er>.</def><br/
<syn><b>Syn. --</b> hand-loomed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handwriting</ent><br/
<hw>Hand"writ`ing</hw> <pr>(-r<imac/t"<icr/ng)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The cast or form of writing peculiar to each hand or
person; chirography.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is written by hand; manuscript.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The handwriting on the wall</b></col>, <cd>a doom
pronounced; an omen of disaster.</cd> <rj><au>Dan. v.
5.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hand-written</ent><br/
<ent>handwritten</ent><br/
<mhw><hw>handwritten</hw>, <hw>hand-written</hw></mhw> <pos>adj.</pos>
<def>written by hand.</def><br/
<syn><b>Syn. --</b> handwritten.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Handy</ent><br/
<hw>Hand"y</hw> <pr>(h<acr/nd"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Handier</adjf>
<pr>(-<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Handiest</adjf>.]</amorph> <ety>[OE. <ets>hendi</ets>, AS.
<ets>hendig</ets> (in comp.), fr. <ets>hand</ets> hand; akin to D.
<ets>handig</ets>, Goth. <ets>handugs</ets> clever, wise.]</ety>
<sn>1.</sn> <def>Performed by the hand.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To draw up and come to <qex>handy</qex> strokes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Skillful in using the hand; dexterous; ready;
adroit.</def> <ldquo/Each is <xex>handy</xex> in his way.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ready to the hand; near; also, suited to the use of
the hand; convenient; valuable for reference or use; <as>as, my tools
are <ex>handy</ex>; a <ex>handy</ex> volume.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>Easily managed; obedient to the
helm; -- said of a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handy-dandy</ent><br/
<hw>Hand"y-dan`dy</hw> <pr>(h<acr/nd"<ycr/*d<acr/n`d<ycr/)</pr>,
<pos>n.</pos> <def>A child's play, one child guessing in which closed
hand the other holds some small object, winning the object if right and
forfeiting an equivalent if wrong; hence, forfeit.</def> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handyfight</ent><br/
<hw>Hand"y*fight`</hw> <pr>(h<acr/nd"<ycr/*f<imac/t`)</pr>,
<pos>n.</pos> <def>A fight with the hands; boxing.</def> <ldquo/Pollux
loves <xex>handyfights</xex>.<rdquo/ <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handygripe</ent><br/
<hw>Hand"y*gripe`</hw> <pr>(h<acr/nd"<ycr/*gr<imac/p`)</pr>,
<pos>n.</pos> <def>Seizure by, or grasp of, the hand; also, close
quarters in fighting.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handystroke</ent><br/
<hw>Hand"y*stroke`</hw> <pr>(h<acr/nd"<ycr/*str<omac/k`)</pr>,
<pos>n.</pos> <def>A blow with the hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Handywork</ent><br/
<hw>Hand"y*work`</hw> <pr>(h<acr/nd"<ycr/*w<ucir/rk`)</pr>,
<pos>n.</pos> <def>See <er>Handiwork</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hang</ent><br/
<hw>Hang</hw> <pr>(h<acr/ng)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hanged</conjf> <pr>(h<acr/ngd)</pr> <or/
<conjf>Hung</conjf> <pr>(h<ucr/ng)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hanging</conjf>. <usage>The use of <xex>hanged</xex> is
preferable to that of <xex>hung</xex>, when reference is had to death or
execution by suspension, and it is also more common.</usage>]</vmorph>
<ety>[OE. <ets>hangen</ets>, <ets>hongien</ets>, v. t. & i., AS.
<ets>hangian</ets>, v. i., fr. <ets>h<omac/n</ets>, v. t. (imp.
<ets>heng</ets>, p. p. <ets>hongen</ets>); akin to OS.
<ets>hang<omac/n</ets>, v. i., D. <ets>hangen</ets>, v. t. & i., G.
<ets>hangen</ets>, v. i, <ets>h<aum/ngen</ets>, v. t., Icel.
<ets>hanga</ets>, v. i., Goth. <ets>h<amac/han</ets>, v. t. (imp.
<ets>ha<iacute/hah</ets>), <ets>h<amac/han</ets>, v. i. (imp.
<ets>hahaida</ets>), and perh. to L. <ets>cunctari</ets> to delay.
<root/37. ]</ety> <sn>1.</sn> <def>To suspend; to fasten to some
elevated point without support from below; -- often used with
<xex>up</xex> or <xex>out</xex>; <as>as, to <ex>hang</ex> a coat on a
hook; to <ex>hang</ex> up a sign; to <ex>hang</ex> out a
banner.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fasten in a manner which will allow of free
motion upon the point or points of suspension; -- said of a pendulum, a
swing, a door, gate, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fit properly, as at a proper angle (a part of an
implement that is swung in using), as a scythe to its snath, or an ax to
its helve.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To put to death by suspending by the neck; -- a form
of capital punishment; <as>as, to <ex>hang</ex> a
murderer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To cover, decorate, or furnish by hanging pictures,
trophies, drapery, and the like, or by covering with paper hangings; --
said of a wall, a room, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hung</qex> be the heavens with black.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>hung</qex> thy holy roofs with savage spoils.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To paste, as paper hangings, on the walls of a
room.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To hold or bear in a suspended or inclined manner or
position instead of erect; to droop; <as>as, he <ex>hung</ex> his head
in shame</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cowslips wan that <qex>hang</qex> the pensive head.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To prevent from reaching a decision, esp. by
refusing to join in a verdict that must be unanimous; <as>as, one
obstinate juror can <ex>hang</ex> a jury</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>To hang down</b></col>, <cd>to let fall below the proper
position; to bend down; to decline; as, to <xex>hang down</xex> the
head, or, elliptically, to <xex>hang</xex> the head.</cd> -- <col><b>To
hang fire</b></col> <fld>(Mil.)</fld>, <cd>to be slow in communicating
fire through the vent to the charge; as, the gun <xex>hangs fire</xex>;
hence, to hesitate, to hold back as if in suspense.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hang</ent><br/
<hw>Hang</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be suspended or
fastened to some elevated point without support from below; to dangle;
to float; to rest; to remain; to stay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be fastened in such a manner as to allow of free
motion on the point or points of suspension.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To die or be put to death by suspension from the
neck.</def> <mark>[R.]</mark> <ldquo/Sir Balaam <xex>hangs</xex>.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To hold for support; to depend; to cling; -- usually
with <xex>on</xex> or <xex>upon</xex>; <as>as, this question
<ex>hangs</ex> on a single point</as>.</def> <ldquo/Two infants
<xex>hanging</xex> on her neck.<rdquo/ <rj><au>Peacham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To be, or be like, a suspended weight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Life <qex>hangs</qex> upon me, and becomes a burden.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To hover; to impend; to appear threateningly; --
usually with <ptcl>over</ptcl>; <as>as, evils <ex>hang</ex> over the
country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To lean or incline; to incline downward.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To decide which way <qex>hung</qex> the victory.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His neck obliquely o'er his shoulder <qex>hung</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To slope down; <as>as, <ex>hanging</ex>
grounds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To be undetermined or uncertain; to be in suspense;
to linger; to be delayed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A noble stroke he lifted high,<br/
Which <qex>hung</qex> not, but so swift with tempest fell<br/
On the proud crest of Satan.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Cricket, Tennis, etc.)</fld> <def>Of a ball: To
rebound unexpectedly or unusually slowly, due to backward spin on the
ball or imperfections of ground.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>11.</sn> <fld>(Baseball)</fld> <def>to fail to curve, break, or
drop as intended; -- said of pitches, such as curve balls or
sliders.</def><br/
[<source>PJC</source>]</p>

<p><sn>12.</sn> <fld>(Computers)</fld> <def>to cease to operate normally
and remain suspended in some state without performing useful work; --
said of computer programs, computers, or individual processes within a
program; <as>as, when using Windows 3.1, my system would <ex>hang</ex>
and need rebooting several times a day</as>.</def> <note>this situation
could be caused by bugs within an operating system or within a program,
or incompatibility between programs or between programs and the
hardware.</note><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To hang around</b></col>, <cd>to loiter idly about.</cd>
-- <col><b>To hang back</b></col>, <cd>to hesitate; to falter; to be
reluctant.</cd> <ldquo/If any one among you <xex>hangs
back</xex>.<rdquo/ <au>Jowett (Thucyd.).</au> -- <col><b>To hang by the
eyelids</b></col>. <sd>(a)</sd> <cd>To hang by a very slight hold or
tenure.</cd> <sd>(b)</sd> <cd>To be in an unfinished condition; to be
left incomplete.</cd> -- <col><b>To hang in doubt</b></col>, <cd>to be
in suspense.</cd> -- <col><b>To hang on</b></col><cd> (with the emphasis
on the preposition), to keep hold; to hold fast; to stick; to be
persistent, as a disease.</cd> -- <mcol><col><b>To hang on the
lips</b></col> <col><b>To hang on the words</b></col>, etc.</mcol>,
<cd>to be charmed by eloquence.</cd> -- <col><b>To hang out</b></col>.
<sd>(a)</sd> <cd>To be hung out so as to be displayed; to project.</cd>
<sd>(b)</sd> <cd>To be unyielding; <as>as, the juryman <ex>hangs
out</ex> against an agreement</as>; to hold out.</cd>
<mark>[Colloq.]</mark> <sd>(c)</sd> <cd>to loiter or lounge around a
particular place; <as>as, teenageers tend to <ex>hang out</ex> at the
mall these days</as>.</cd> -- <col><b>To hang over</b></col>.
<sd>(a)</sd> <cd>To project at the top.</cd> <sd>(b)</sd> <cd>To impend
over.</cd> -- <col><b>To hang to</b></col>, <cd>to cling.</cd> --
<col><b>To hang together</b></col>. <sd>(a)</sd> <cd>To remain united;
to stand by one another.</cd> <ldquo/We are all of a piece; we <xex>hang
together</xex>.<rdquo/ <au>Dryden.</au> <sd>(b)</sd> <cd>To be
self-consistent; <as>as, the story does not <ex>hang
together</ex></as>.</cd> <mark>[Colloq.]</mark> -- <col><b>To hang
upon</b></col>. <sd>(a)</sd> <cd>To regard with passionate
affection.</cd> <sd>(b)</sd> <fld>(Mil.)</fld> <cd>To hover around;
<as>as, <ex>to hang upon</ex> the flanks of a retreating
enemy</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hang</ent><br/
<hw>Hang</hw>, <pos>n.</pos> <sn>1.</sn> <def>The manner in which one
part or thing hangs upon, or is connected with, another; <as>as, the
<ex>hang</ex> of a scythe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Connection; arrangement; plan; <as>as, the
<ex>hang</ex> of a discourse</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 669 pr=JMD --></p>

<p><sn>3.</sn> <def>A sharp or steep declivity or slope.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To get the hang of</b></col>, <cd>to learn the method or
arrangement of; hence, to become accustomed to.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hangar</ent><br/
<hw>hang"ar</hw> <pos>n.</pos> <def>a large building at an airport where
aircraft can be stored and maintained.</def><br/
<syn><b>Syn. --</b> airdock, repair shed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hangbird</ent><br/
<hw>Hang"bird`</hw> <pr>(h<acr/ng"b<etil/rd`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The Baltimore oriole (<spn>Icterus
galbula</spn>); -- so called because its nest is suspended from the limb
of a tree. See <er>Baltimore oriole</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hang-by</ent><br/
<hw>Hang"-by`</hw> <pr>(-b<imac/`)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hang-bies</plw> <pr>(-b<imac/z`)</pr>.</plu>
<def>A dependent; a hanger-on; -- so called in contempt.</def>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hangdog</ent><br/
<hw>Hang"dog`</hw> <pr>(-d<ocr/g`)</pr>, <pos>n.</pos> <def>A base,
degraded person; a sneak; a gallows bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hangdog</ent><br/
<hw>Hang"dog`</hw>, <pos>a.</pos> <def>Low; sneaking; ashamed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The poor colonel went out of the room with a <qex>hangdog</qex>
look.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanger</ent><br/
<hw>Hang"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who hangs, or causes to be hanged; a hangman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That by which a thing is suspended.</def>
Especially: <sd>(a)</sd> <def>A strap hung to the girdle, by which a
dagger or sword is suspended.</def> <sd>(b)</sd> <fld>(Mach.)</fld>
<def>A part that suspends a journal box in which shafting runs. See
<xex>Illust.</xex> of <er>Countershaft</er>.</def> <sd>(c)</sd> <def>A
bridle iron.</def><-- (d) clothes hanger --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which hangs or is suspended, as a sword worn at
the side; especially, in the 18th century, a short, curved
sword.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A steep, wooded declivity.</def> <mark>[Eng.]</mark>
<rj><au>Gilbert White.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanger-on</ent><br/
<hw>Hang"er-on`</hw> <pr>(-<ocr/n`)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hangers-on</plw>
<pr>(-<etil/rz-<ocr/n`)</pr>.</plu> <def>One who hangs on, or sticks to,
a person, place, or service; a dependent; one who adheres to others'
society longer than he is wanted.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanging</ent><br/
<hw>Hang"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Requiring, deserving,
or foreboding death by the halter.</def> <ldquo/What a
<xex>hanging</xex> face!<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suspended from above; pendent; <as>as,
<ex>hanging</ex> shelves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Adapted for sustaining a hanging object; <as>as, the
<ex>hanging</ex> post of a gate, the post which holds the
hinges</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hanging compass</b></col>, <cd>a compass suspended so
that the card may be read from beneath.</cd> -- <col><b>Hanging
garden</b></col>, <cd>a garden sustained at an artificial elevation by
any means, as by the terraces at Babylon.</cd> -- <col><b>Hanging
indentation</b></col>. <cd>See under <er>Indentation</er>.</cd> --
<col><b>Hanging rail</b></col> <fld>(Arch.)</fld>, <cd>that rail of a
door or casement to which hinges are attached.</cd> -- <col><b>Hanging
side</b></col> <fld>(Mining)</fld>, <cd>the overhanging side of an
inclined or hading vein.</cd> -- <col><b>Hanging sleeves</b></col>.
<sd>(a)</sd> <cd>Strips of the same stuff as the gown, hanging down the
back from the shoulders.</cd> <sd>(b)</sd> <cd>Loose, flowing
sleeves.</cd> -- <col><b>Hanging stile</b></col>. <fld>(Arch.)</fld>
<sd>(a)</sd> <cd>That stile of a door to which hinges are secured.</cd>
<sd>(b)</sd> <cd>That upright of a window frame to which casements are
hinged, or in which the pulleys for sash windows are fastened.</cd> --
<col><b>Hanging wall</b></col> <fld>(Mining)</fld>, <cd>the upper wall
of inclined vein, or that which hangs over the miner's head when working
in the vein.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanging</ent><br/
<hw>Hang"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of suspending
anything; the state of being suspended.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Death by suspension; execution by a
halter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is hung as lining or drapery for the
walls of a room, as tapestry, paper, etc., or to cover or drape a door
or window; -- used chiefly in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now purple <qex>hangings</qex> clothe the palace walls.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hangman</ent><br/
<hw>Hang"man</hw> <pr>(h<acr/ng"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hangmen</plw> <pr>(-m<eit/n)</pr>.</plu> <def>One
who hangs another; esp., one who makes a business of hanging; a public
executioner; -- sometimes used as a term of reproach, without reference
to office.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hangmanship</ent><br/
<hw>Hang"man*ship</hw>, <pos>n.</pos> <def>The office or character of a
hangman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hangnail</ent><br/
<hw>Hang"nail`</hw> <pr>(-n<amac/l`)</pr>, <pos>n.</pos> <ety>[A
corruption of <ets>agnail</ets>.]</ety> <def>A small piece or sliver of
skin which hangs loose, near the root of a finger nail.</def>
<rj><au>Holloway.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hangnest</ent><br/
<hw>Hang"nest`</hw> <pr>(-n<ecr/st`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A nest that hangs like a bag or pocket.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bird which builds such a nest; a
hangbird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hangover</ent><br/
<hw>hangover</hw> <pos>n.</pos> <sn>1.</sn> <def>An unpleasant feeling,
such as a headache, occurring as an aftereffect from the use of drugs
(especially alcohol).</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>an official who remains in office after his
term.</def><br/
<syn><b>Syn. --</b> holdover.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hank</ent><br/
<hw>Hank</hw> <pr>(h<acr/<nsm/k)</pr>, <pos>n.</pos> <ety>[Cf. Dan.
<ets>hank</ets> handle, Sw. <ets>hank</ets> a band or tie, Icel.
<ets>hanki</ets> hasp, clasp, <ets>h<oum/nk</ets>, <ets>hangr</ets>,
hank, coil, skein, G. <ets>henkel</ets>, <ets>henk</ets>, handle; all
probably akin to E. <ets>hang</ets>. See <er>Hang</er>.]</ety>
<sn>1.</sn> <def>A parcel consisting of two or more skeins of yarn or
thread tied together.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rope or withe for fastening a gate.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hold; influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the devil hath got such a <qex>hank</qex> over him.</q>
<rj><qau>Bp. Sanderson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>A ring or eye of rope, wood, or
iron, attached to the edge of a sail and running on a stay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Wrestling)</fld> <def>A throw in which a wrestler
turns his left side to his opponent, twines his left leg about his
opponent's right leg from the inside, and throws him backward.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hank</ent><br/
<hw>Hank</hw>, <pos>v. t.</pos> <sn>1.</sn> <ety>[OE.
<ets>hanken</ets>.]</ety> <def>To fasten with a rope, as a gate.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form into hanks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanker</ent><br/
<hw>Han"ker</hw> <pr>(h<acr/<nsm/"k<etil/r)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hankered</conjf>
<pr>(-k<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hankering</conjf>.]</vmorph> <ety>[Prob. fr. <ets>hang</ets>; cf.
D. <ets>hunkeren</ets>, <ets>hengelen</ets>.]</ety> <sn>1.</sn> <def>To
long (for) with a keen appetite and uneasiness; to have a vehement
desire; -- usually with <xex>for</xex> or <xex>after</xex>; <as>as, to
<ex>hanker</ex> after fruit; to <ex>hanker</ex> after the diversions of
the town.</as></def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>hankering</qex> to join his friend.</q> <rj><qau>J. A.
Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To linger in expectation or with desire.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hankeringly</ent><br/
<hw>Han"ker*ing*ly</hw>, <pos>adv.</pos> <def>In a hankering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hankey-pank</ent><br/
<ent>Hankey-pankey</ent><br/
<mhw><hw>Han"key-pan"key</hw>, <hw>Han"key-pank`</hw></mhw>
<pr>(h<acr/<nsm/"k<ycr/*p<acr/<nsm/"k<ycr/)</pr>, <pos>n.</pos>
<ety>[Cf. <er>Hocus-pocus</er>.]</ety> <altsp>[Also spelled
<asp>hanky-panky</asp>.]</altsp> <sn>1.</sn> <def>Professional cant; the
chatter of conjurers to divert attention from their tricks; hence,
jugglery.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Illegal or unethical behavior, usually
surreptitious; <as>as, the boss got suspicious when profits seemed lower
than expected, and hired an investigator to see if any
<ex>hankey-pankey</ex> was going on</as>.</def> <mark>[Informal]</mark>
<br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Extramarital sexual relations, especially
adultery.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>hankie</ent><br/
<hw>hankie</hw> <pos>n.</pos> <def>Same as
<er>handkerchief</er>.</def><br/
<syn><b>Syn. --</b> handkerchief, hanky, hankey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hanky</ent><br/
<hw>hanky</hw> <pos>n.</pos> <def>Same as
<er>handkerchief</er>.</def><br/
<syn><b>Syn. --</b> handkerchief, hankie, hankey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hanover</ent><br/
<hw>Hanover</hw> <pos>n.</pos> <def>the English royal house that reigned
from 1714 to 1901.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hanoverian</ent><br/
<hw>Han`o*ve"ri*an</hw> <pr>(h<acr/n`<osl/*v<emac/"r<icr/*<ait/n)</pr>,
<pos>a.</pos> <def>Of or pertaining to Hanover or its people, or to the
House of Hanover in England.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanoverian</ent><br/
<hw>Han`o*ve"ri*an</hw>, <pos>n.</pos> <def>A native or naturalized
inhabitant of Hanover; one of the House of Hanover.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hansa</ent><br/
<hw>Han"sa</hw> <pr>(h<acr/n"s<adot/)</pr>, <pos>n.</pos> <def>See 2d
<er>Hanse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hansard</ent><br/
<hw>Han"sard</hw> <pr>(-s<etil/rd)</pr>, <pos>n.</pos> <def>An official
report of proceedings in the British Parliament; -- so called from the
name of the publishers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hansard</ent><br/
<hw>Han"sard</hw>, <pos>n.</pos> <def>A merchant of one of the Hanse
towns. See the Note under 2d <er>Hanse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanse</ent><br/
<hw>Hanse</hw> <pr>(h<acr/ns)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>anse</ets> handle, <ets>anse de panier</ets> surbased arch, flat
arch, vault, and E. <ets>haunch</ets> hip.]</ety> <fld>(Arch.)</fld>
<def>That part of an elliptical or many-centered arch which has the
shorter radius and immediately adjoins the impost.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanse</ent><br/
<hw>Hanse</hw>, <pos>n.</pos> <ety>[G. <ets>hanse</ets>, or F.
<ets>hanse</ets> (from German), OHG. & Goth. <ets>hansa</ets>; akin to
AS. <ets>h<omac/s</ets> band, troop.]</ety> <def>An association; a
league or confederacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hanse towns</b></col> <fld>(Hist.)</fld>, <cd>certain
commercial cities in Germany which associated themselves for the
protection and enlarging of their commerce. The confederacy, called also
<altname>Hansa</altname> and <altname>Hanseatic league</altname>, held
its first diet in 1260, and was maintained for nearly four hundred
years. At one time the league comprised eighty-five cities. Its
remnants, L<uum/beck, Hamburg, and Bremen, are <stype>free
cities</stype>, and are still frequently called <ex>Hanse
towns</ex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanseatic</ent><br/
<hw>Han`se*at"ic</hw> <pr>(h<acr/n`s<esl/*<acr/t"<icr/k)</pr>,
<pos>a.</pos> <def>Pertaining to the Hanse towns, or to their
confederacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hanseatic league</b></col>. <cd>See under 2d
<er>Hanse</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hansel</ent><br/
<hw>Han"sel</hw> <pr>(h<acr/n"s<ecr/l)</pr>, <pos>n. & v.</pos> <def>See
<er>Handsel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanselines</ent><br/
<hw>Han"sel*ines</hw> <pr>(h<aum/n"s<eit/l*<imac/nz)</pr>, <pos>n.</pos>
<def>A sort of breeches.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></p>

<p><ent>Hansom cab</ent><br/
<ent>Hansom</ent><br/
<mhw><hw>Han"som</hw> <pr>(h<acr/n"s<ucr/m)</pr>, <pos>n.</pos>,
<hw>Han"som cab`</hw> <pr>(k<acr/b`)</pr></mhw>. <ety>[From the name of
the inventor.]</ety> <def>A light, low, two-wheeled covered carriage
with the driver's seat elevated behind, the reins being passed over the
top.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He hailed a cruising <qex>hansom</qex> . . . <ldquo/ 'Tis the
gondola of London,<rdquo/ said Lothair.</q>
<rj><qau>Beaconsfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Han't</ent><br/
<hw>Han't</hw> <pr>(h<amac/nt; <it>in England</it>, h<aum/nt)</pr>.
<def>A contraction of <sig>have not</sig>, or <sig>has not</sig>, used
in illiterate speech. In the United States the commoner spelling is
<asp>hain't</asp>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hanukkah</ent><br/
<ent>Hanukka</ent><br/
<mhw>{ <hw>Ha"nuk*ka</hw>, <it>or</it> <hw>Ha"nuk*kah</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[Heb. <ets>khanukk<amac/h</ets>.]</ety>
<def>The Jewish Feast of the Dedication, instituted by Judas Maccabaeus,
his brothers, and the whole congregation of Israel, in 165 <sc>b.
c.</sc>, to commemorate the dedication of the new altar set up at the
purification of the temple of Jerusalem to replace the altar which had
been polluted by Antiochus Epiphanes of Syria (<au>1 Maccabees i. 58,
iv. 59</au>). The feast, which is mentioned in John x. 22, is held for
eight days (beginning with the 25th day of Kislev, corresponding to
December), and is celebrated everywhere, chiefly as a festival of
lights, by the Jews.</def> <altsp>[Also spelled
<asp>Chanuka</asp>.]</altsp><br/
<syn><b>Syn. --</b> Chanukah, Festival of Lights, Feast of Dedication,
Feast of the Dedication.</syn><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hanuman</ent><br/
<hw>Han"u*man</hw> <pr>(h<adot/n"<usdot/*m<ait/n)</pr>, <pos>n.</pos>
<def>See <er>Hoonoomaun</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>haoma</ent><br/
<hw>haoma</hw> <pos>n.</pos> <def>A leafless East Indian vine
(<spn>Sarcostemma acidum</spn>); its sour milky juice was formerly used
to make an intoxicating drink.</def><br/
<syn><b>Syn. --</b> soma, <spn>Sarcostemma acidum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hap</ent><br/
<hw>Hap</hw> <pr>(h<acr/p)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>happen</ets>.]</ety> <def>To clothe; to wrap.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The surgeon <qex>happed</qex> her up carefully.</q> <rj><qau>Dr.
J. Brown.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hap</ent><br/
<hw>Hap</hw>, <pos>n.</pos> <ety>[Cf. <er>Hap</er> to clothe.]</ety>
<def>A cloak or plaid.</def> <mark>[O. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hap</ent><br/
<hw>Hap</hw>, <pos>n.</pos> <ety>[Icel. <ets>happ</ets> unexpected good
luck. <root/39.]</ety> <def>That which happens or comes suddenly or
unexpectedly; also, the manner of occurrence or taking place; chance;
fortune; accident; casual event; fate; luck; lot.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whether art it was or heedless <qex>hap</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cursed be good <qex>haps</qex>, and cursed be they that build<br/
Their hopes on <qex>haps</qex>.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Loving goes by <qex>haps</qex>:<br/
Some Cupid kills with arrows, some with traps.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hap</ent><br/
<hw>Hap</hw>, <pos>v. i.</pos> <ety>[OE. <ets>happen</ets>. See
<er>Hap</er> chance, and cf. <er>Happen</er>.]</ety> <def>To happen; to
befall; to chance.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sends word of all that <qex>haps</qex> in Tyre.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ha'penny</ent><br/
<hw>Ha'"pen*ny</hw> <pr>(h<amac/"p<ecr/n*n<ycr/)</pr>, <pos>n.</pos>
<def>A half-penny.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haphazard</ent><br/
<hw>Hap"haz`ard</hw> <pr>(h<acr/p"h<acr/z`<etil/rd <or/
h<acr/p`h<acr/z"<etil/rd)</pr>, <pos>n.</pos> <ety>[<ets>Hap</ets> +
<ets>hazard</ets>.]</ety> <def>Extra hazard; chance; accident;
random.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We take our principles at <qex>haphazard</qex>, upon trust.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>haphazard</ent><br/
<hw>hap"haz`ard</hw> <pr>(h<acr/p"h<acr/z`<etil/rd <or/
h<acr/p`h<acr/z"<etil/rd)</pr>, <pos>a.</pos> <def>Determined by chance,
whimsy, or guesswork; unplanned; aimless; random; -- used mostly of
human actions.</def><br/
[<source>PJC</source>]</p>

<p><ent>Haphtarah</ent><br/
\'d8<hw>Haph*ta"rah</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>-taroth</plw> <pr>(#)</pr></plu>. <ety>[Heb.
<ets>hapht<amac/r<amac/h</ets>, prop., valedictory, fr.
<ets>p<amac/tar</ets> to depart.]</ety> <def>One of the lessons from the
Nebiim (or Prophets) read in the Jewish synagogue on Sabbaths, feast
days, fasts, and the ninth of Ab, at the end of the service, after the
parashoth, or lessons from the Law. Such a practice is evidenced in Luke
iv.17 and Acts xiii.15.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hapless</ent><br/
<hw>Hap"less</hw> <pr>(h<acr/p"l<ecr/s)</pr>, <pos>a.</pos> <def>Without
hap or luck; luckless; unfortunate; unlucky; unhappy; <as>as,
<ex>hapless</ex> youth; <ex>hapless</ex> maid.</as></def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haplessly</ent><br/
<hw>Hap"less*ly</hw>, <pos>adv.</pos> <def>In a hapless, unlucky
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haploid</ent><br/
<hw>Hap"loid</hw> <pr>(h<acr/p"loid)</pr>, <pos>a.</pos> <ety>[NL., fr.
Gr. <grk>"aplo`os</grk> simple.]</ety> <fld>(Biol.)</fld> <def>having
half the number of chromosomes normally present in somatic cells; having
only one chromosome of each type, and therefore having only one complete
set of genes; Contrasted with <contr>diploid</contr> and
<contr>polyploid</contr>. See also <er>diploid</er>.</def> <note>The
germ cells of animals, the ovum and sperm cells, are <ex>haploid</ex>,
whereas the somatic cells are diploid. <ex>Haploid</ex> variants of
somatic cells may also be generated under certain conditions in the
laboratory.</note><br/
[<source>PJC</source>]</p>

<p><ent>Haplomi</ent><br/
\'d8<hw>Ha*plo"mi</hw> <pr>(h<adot/*pl<omac/"m<imac/)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. Gr. <grk>"aplo`os</grk> simple +
<grk>'w^mos</grk> shoulder.]</ety> <fld>(Zool.)</fld> <def>An order of
freshwater fishes, including the true pikes, cyprinodonts, and
blindfishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>haplosporidian</ent><br/
<hw>haplosporidian</hw> <pos>n.</pos> <def>A parasite in invertebrates
and lower vertebrates of no known economic importance.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haplostemonous</ent><br/
<hw>Hap`lo*stem"o*nous</hw>
<pr>(h<acr/p`l<osl/*st<ecr/m"<osl/*n<ucr/s)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>"aplo`os</grk> simple + <grk>sth`mwn</grk> a
thread.]</ety> <fld>(Bot.)</fld> <def>Having but one series of stamens,
and that equal in number to the proper number of petals;
isostemonous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haply</ent><br/
<hw>Hap"ly</hw> <pr>(h<acr/p"l<ycr/)</pr>, <pos>adv.</pos> <def>By hap,
chance, luck, or accident; perhaps; it may be.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest <qex>haply</qex> ye be found even to fight against God.</q>
<rj><qau>Acts v. 39.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Happed</ent><br/
<hw>Happed</hw> <pr>(h<acr/pt)</pr>, <pos>p. a.</pos> <ety>[From 1st
<er>Hap</er>.]</ety> <def>Wrapped; covered; cloaked.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>happed</qex> with flowers in the green wood were.</q>
<rj><qau>Hogg.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Happen</ent><br/
<hw>Hap"pen</hw> <pr>(h<acr/p"p'n)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Happened</conjf>
<pr>(-p'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Happening</conjf>.]</vmorph> <ety>[OE. <ets>happenen</ets>,
<ets>hapnen</ets>. See <er>Hap</er> to happen.]</ety> <sn>1.</sn>
<def>To come by chance; to come without previous expectation; to fall
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There shall no evil <qex>happen</qex> to the just.</q>
<rj><qau>Prov. xii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take place; to occur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All these things which had <qex>happened</qex>.</q> <rj><qau>Luke
xxiv. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To happen on</b></col>, <cd>to meet with; to fall or
light upon.</cd> <ldquo/I have <xex>happened on</xex> some other
accounts.<rdquo/ <au>Graunt.</au> -- <col><b>To happen in</b></col>,
<cd>to make a casual call.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>happening</ent><br/
<hw>happening</hw> <pos>n.</pos> <sn>1.</sn> <def>something that
happens; an occurrence; an event.</def><br/
<syn><b>Syn. --</b> occurrence, natural event.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>An event that is
particularly interesting, noteworthy, or important.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>An artistic or entertainment event that is
unconventional, sometimes discontinuous, designed to evoke strong
emotions, and sometimes involving participation by the
audience.</def><br/
[<source>PJC</source>]</p>

<p><ent>Happily</ent><br/
<hw>Hap"pi*ly</hw> <pr>(h<acr/p"p<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<ety>[From <er>Happy</er>.]</ety> <sn>1.</sn> <def>By chance;
peradventure; haply.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>By good fortune; fortunately; luckily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Preferred by conquest, <qex>happily</qex> o'erthrown.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In a happy manner or state; in happy circumstances;
<as>as, he lived <ex>happily</ex> with his wife</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>With address or dexterity; gracefully; felicitously;
in a manner to insure success; with success.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Formed by thy converse, <qex>happily</qex> to steer<br/
From grave to gay, from lively to severe.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- Fortunately; luckily; successfully; prosperously;
contentedly; dexterously; felicitously.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Happiness</ent><br/
<hw>Hap"pi*ness</hw>, <pos>n.</pos> <ety>[From <er>Happy</er>.]</ety>
<sn>1.</sn> <def>Good luck; good fortune; prosperity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>happiness</qex> bechance to thee in Milan!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An agreeable feeling or condition of the soul
arising from good fortune or propitious happening of any kind; the
possession of those circumstances or that state of being which is
attended with enjoyment; the state of being happy; contentment; joyful
satisfaction; felicity; blessedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fortuitous elegance; unstudied grace; -- used
especially of language.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some beauties yet no precepts can declare,<br/
For there's a <qex>happiness</qex>, as well as care.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Happiness</er>, <er>Felicity</er>,
<er>Blessedness</er>, <er>Bliss</er>.</syn> <usage> <xex>Happiness</xex>
is generic, and is applied to almost every kind of enjoyment except that
of the animal appetites; <xex>felicity</xex> is a more formal word, and
is used more sparingly in the same general sense, but with elevated
associations; <xex>blessedness</xex> is applied to the most refined
enjoyment arising from the purest social, benevolent, and religious
affections; <xex>bliss</xex> denotes still more exalted delight, and is
applied more appropriately to the joy anticipated in heaven.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>O <qex>happiness</qex>! our being's end and aim!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Others in virtue place <qex>felicity</qex>,<br/
But virtue joined with riches and long life;<br/
In corporal pleasures he, and careless ease.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His overthrow heaped <qex>happiness</qex> upon him;<br/
For then, and not till then, he felt himself,<br/
And found the <qex>blessedness</qex> of being little.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Happy</ent><br/
<hw>Hap"py</hw> <pr>(h<acr/p"p<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Happier</adjf>
<pr>(-p<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Happiest</adjf>.]</amorph> <ety>[From <er>Hap</er> chance.]</ety>
<sn>1.</sn> <def>Favored by hap, luck, or fortune; lucky; fortunate;
successful; prosperous; satisfying desire; <as>as, a <ex>happy</ex>
expedient; a <ex>happy</ex> effort; a <ex>happy</ex> venture; a
<ex>happy</ex> omen.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Chymists have been more <qex>happy</qex> in finding experiments
than the causes of them.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Experiencing the effect of favorable fortune; having
the feeling arising from the consciousness of well-being or of
enjoyment; enjoying good of any kind, as peace, tranquillity, comfort;
contented; joyous; <as>as, <ex>happy</ex> hours, <ex>happy</ex>
thoughts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Happy</qex> is that people, whose God is the Lord.</q>
<rj><qau>Ps. cxliv. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The learned is <qex>happy</qex> Nature to explore,<br/
The fool is <qex>happy</qex> that he knows no more.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Dexterous; ready; apt; felicitous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One gentleman is <qex>happy</qex> at a reply, another excels in a
in a rejoinder.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Happy family</b></col>, <cd>a collection of animals of
different and hostile propensities living peaceably together in one
cage. Used ironically of conventional alliances of persons who are in
fact mutually repugnant.</cd> -- <col><b>Happy-go-lucky</b></col>,
<cd>trusting to hap or luck; improvident; easy-going.</cd>
<ldquo/<xex>Happy-go-lucky</xex> carelessness.<rdquo/ <rj><au>W.
Black.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>haptic</ent><br/
<hw>haptic</hw> <pos>adj.</pos> <def>relating to or based on the sense
of touch.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hapuku</ent><br/
\'d8<hw>Ha*pu"ku</hw> <pr>(h<adot/*p<oomac/"k<oomac/)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>A large and valuable food fish
(<spn>Polyprion prognathus</spn>) of New Zealand. It sometimes weighs
one hundred pounds or more.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haquebut</ent><br/
<hw>Haque"but</hw> <pr>(h<acr/k"b<ucr/t)</pr>, <pos>n.</pos> <def>See
<er>Hagbut</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p> <pos>n.</pos> <sn>1.</sn> <def>(Japan) suicide by self-disembowlment
on a sword.</def><br/
<syn><b>Syn. --</b> harikari.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hara-kiri</ent><br/
<ent>harakiri</ent><br/
<mhw><hw>ha"ra*ki`ri</hw>, <hw>ha"ra-ki`ri</hw></mhw>
<pr>(h<add/"r<add/*k<emac/`r<icr/)</pr>, <pos>n.</pos> <ety>[Jap.,
stomach cutting.]</ety> <def>A ritual form of suicide, by slashing the
abdomen, formerly practiced in Japan, and commanded by the government in
the cases of disgraced officials; disembowelment; -- also written, but
incorrectly, <asp>hari-kari</asp>.</def> <rj><au>W. E.
Griffis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hari-kari</ent><br/
<hw>ha"ri-ka`ri</hw> <def>An incorrect but common spelling and
pronunciation of <er>hara-kiri</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Harangue</ent><br/
<hw>Ha*rangue"</hw> <pr>(h<adot/*r<acr/ng")</pr>, <pos>n.</pos> <ety>[F.
<ets>harangue</ets>: cf. Sp. <ets>arenga</ets>, It. <ets>aringa</ets>;
lit., a speech before a multitude or on the hustings, It.
<ets>aringo</ets> arena, hustings, pulpit; all fr. OHG. <ets>hring</ets>
ring, anything round, ring of people, G. <ets>ring</ets>. See
<er>Ring</er>.]</ety> <def>A speech addressed to a large public
assembly; a popular oration; a loud address to a multitude; in a bad
sense, a noisy or pompous speech; declamation; ranting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gray-headed men and grave, with warriors mixed,<br/
Assemble, and <qex>harangues</qex> are heard.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Harangue</er>, <er>Speech</er>,
<er>Oration</er>.</syn> <usage> <xex>Speech</xex> is generic; an
<xex>oration</xex> is an elaborate and rhetorical speech; an
<xex>harangue</xex> is a vehement appeal to the passions, or a noisy,
disputatious address. A general makes an <xex>harangue</xex> to his
troops on the eve of a battle; a demagogue <xex>harangues</xex> the
populace on the subject of their wrongs.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harangue</ent><br/
<hw>Ha*rangue"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harangued</conjf> <pr>(h<adot/*r<acr/ngd")</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Haranguing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>haranguer</ets>, It. <ets>aringare</ets>.]</ety> <def>To make an
harangue; to declaim.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harangue</ent><br/
<hw>Ha*rangue"</hw>, <pos>v. t.</pos> <def>To address by an
harangue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harangueful</ent><br/
<hw>Ha*rangue"ful</hw> <pr>(-f<usdot/l)</pr>, <pos>a.</pos> <def>Full of
harangue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haranguer</ent><br/
<hw>Ha*rang"uer</hw> <pr>(h<adot/*r<acr/ng"<etil/r)</pr>, <pos>n.</pos>
<def>One who harangues, or is fond of haranguing; a declaimer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With them join'd all th' <qex>haranguers</qex> of the throng,<br/
That thought to get preferment by the tongue.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harass</ent><br/
<hw>Har"ass</hw> <pr>(h<acr/r"<ait/s <it>or</it> h<adot/*r<acr/s")</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harassed</conjf> <pr>(h<acr/r"<ait/st <it>or</it>
h<adot/*r<acr/st")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Harassing</conjf>.]</vmorph> <ety>[F. <ets>harasser</ets>; cf.
OF. <ets>harace</ets> a basket made of cords, <ets>harace</ets>,
<ets>harasse</ets>,a very heavy and large shield; or <ets>harer</ets> to
set (a dog) on.]</ety> <def>To fatigue; to tire with repeated and
exhausting efforts; esp., to weary by importunity, teasing, or fretting;
to cause to endure excessive burdens or anxieties; -- sometimes followed
by <xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Troops] <qex>harassed</qex> with a long and wearisome march.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nature oppressed and <qex>harass'd</qex> out with care.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Vext with lawyers and <qex>harass'd</qex> with debt.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><syn><b>Syn.</b> -- To weary; jade; tire; perplex; distress; tease;
worry; disquiet; chafe; gall; annoy; irritate; plague; vex; molest;
trouble; disturb; torment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harass</ent><br/
<hw>Har"ass</hw>, <pos>n.</pos> <sn>1.</sn> <def>Devastation;
waste.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Worry; harassment.</def> <mark>[R.]</mark>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>harassed</ent><br/
<hw>harassed</hw> <pr>(h<acr/r"<ait/st <it>or</it>
h<adot/*r<acr/st")</pr>, <pos>adj.</pos> <def>troubled persistently,
especially with petty annoyances; <as>as, <ex>harassed</ex> working
mothers</as>.</def><br/
<syn><b>Syn. --</b> annoyed, harried, pestered.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harasser</ent><br/
<hw>Har"ass*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
harasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harassment</ent><br/
<hw>Har"ass*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The act
of harassing, or state of being harassed; worry; annoyance;
anxiety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Little <qex>harassments</qex> which I am led to suspect do
occasionally molest the most fortunate.</q> <rj><qau>Ld.
Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harberous</ent><br/
<hw>Har"ber*ous</hw> <pr>(h<add/r"b<etil/r*<ucr/s)</pr>, <pos>a.</pos>
<def>Harborous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A bishop must be faultless, the husband of one wife, honestly
appareled, <qex>harberous</qex>.</q> <rj><qau>Tyndale (1 Tim. iii.
2).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harbinger</ent><br/
<hw>Har"bin*ger</hw> <pr>(h<add/r"b<icr/n*j<etil/r)</pr>, <pos>n.</pos>
<ety>[OE. <ets>herbergeour</ets>, OF. <ets>herbergeor</ets> one who
provides lodging, fr. <ets>herbergier</ets> to provide lodging, F.
<ets>h<eacute/berger</ets>, OF. <ets>herberge</ets> lodging, inn, F.
<ets>auberge</ets>; of German origin. See <er>Harbor</er>.]</ety>
<sn>1.</sn> <def>One who provides lodgings; especially, the officer of
the English royal household who formerly preceded the court when
traveling, to provide and prepare lodgings.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A forerunner; a precursor; a messenger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I knew by these <qex>harbingers</qex> who were coming.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harbinger</ent><br/
<hw>Har"bin*ger</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harbingered</conjf> <pr>(h<add/r"b<icr/n*j<etil/rd)</pr>; <pos>p.
pr. & vb. n.</pos> <conjf>Harbingering</conjf>.]</vmorph> <def>To usher
in; to be a harbinger of.</def> <ldquo/Thus did the star of religious
freedom <xex>harbinger</xex> the day.<rdquo/
<rj><au>Bancroft.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harbor</ent><br/
<hw>Har"bor</hw> <pr>(h<aum/r"b<etil/r)</pr>, <pos>n.</pos>
<altsp>[Written also <asp>harbour</asp>.]</altsp> <ety>[OE.
<ets>herbor</ets>, <ets>herberwe</ets>, <ets>herberge</ets>, Icel.
<ets>herbergi</ets> (cf. OHG. <ets>heriberga</ets>), orig., a shelter
for soldiers; <ets>herr</ets> army + <ets>bjarga</ets> to save, help,
defend; akin to AS. <ets>here</ets> army, G. <ets>heer</ets>, OHG.
<ets>heri</ets>, Goth. <ets>harjis</ets>, and AS. <ets>beorgan</ets> to
save, shelter, defend, G. <ets>bergen</ets>. See <er>Harry</er>, <er>2d
Bury</er>, and cf. <er>Harbinger</er>.]</ety> <sn>1.</sn> <def>A station
for rest and entertainment; a place of security and comfort; a refuge; a
shelter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[A grove] fair <qex>harbour</qex> that them seems.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For <qex>harbor</qex> at a thousand doors they knocked.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specif.: A lodging place; an inn.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astrol.)</fld> <def>The mansion of a heavenly
body.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A portion of a sea, a lake, or other large body of
water, either landlocked or artificially protected so as to be a place
of safety for vessels in stormy weather; a port or haven.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 670 pr=JMD --></p>

<p><sn>5.</sn> <fld>(Glass Works)</fld> <def>A mixing box for
materials.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harbor dues</b></col> <fld>(Naut.)</fld>, <cd>fees paid
for the use of a harbor.</cd> -- <col><b>Harbor seal</b></col>
<fld>(Zool.)</fld>, <cd>the common seal.</cd> -- <col><b>Harbor
watch</b></col>, <cd>a watch set when a vessel is in port; an anchor
watch.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harbor</ent><br/
<hw>Har"bor</hw> <pr>(h<aum/r"b<etil/r)</pr>, <pos>v. t.</pos>
<altsp>[Written also <asp>harbour</asp>.]</altsp> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Harbored</conjf> <pr>(-b<etil/rd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Harboring</conjf>.]</vmorph> <ety>[OE.
<ets>herberen</ets>, <ets>herberwen</ets>, <ets>herbergen</ets>; cf.
Icel. <ets>herbergja</ets>. See <er>Harbor</er>, <pos>n.</pos>]</ety>
<def>To afford lodging to; to entertain as a guest; to shelter; to
receive; to give a refuge to; to indulge or cherish (a thought or
feeling, esp. an ill thought); <as>as, to <ex>harbor</ex> a
grudge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any place that <qex>harbors</qex> men.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bare suspicion made it treason to <qex>harbor</qex> the person
suspected.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let not your gentle breast <qex>harbor</qex> one thought of
outrage.</q> <rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harbor</ent><br/
<hw>Har"bor</hw>, <pos>v. i.</pos> <def>To lodge, or abide for a time;
to take shelter, as in a harbor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For this night let's <qex>harbor</qex> here in York.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harborage</ent><br/
<hw>Har"bor*age</hw> <pr>(-<asl/j)</pr>, <pos>n.</pos> <def>Shelter;
entertainment.</def><mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Where can I get me <qex>harborage</qex> for the night?</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harborer</ent><br/
<hw>Har"bor*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who, or
that which, harbors.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Geneva was . . . a <qex>harborer</qex> of exiles for religion.</q>
<rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harborless</ent><br/
<hw>Har"bor*less</hw>, <pos>a.</pos> <def>Without a harbor;
shelterless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harbor master</ent><br/
<hw>Har"bor mas`ter</hw> <pr>(m<adot/s`t<etil/r)</pr>. <def>An officer
charged with the duty of executing the regulations respecting the use of
a harbor.</def></p>

<p><ent>Harbrough</ent><br/
<ent>Harborough</ent><br/
<mhw>{ <hw>Har"bor*ough</hw> <pr>(-<osl/)</pr>, <hw>Har"brough</hw>
<pr>(-br<osl/)</pr>, }</mhw> <pos>n.</pos> <ety>[See
<er>Harbor</er>.]</ety> <def>A shelter.</def> <mark>[Obs.]</mark>.
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harborous</ent><br/
<hw>Har"bor*ous</hw> <pr>(-b<etil/r*<ucr/s)</pr>, <pos>a.</pos>
<def>Hospitable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard</ent><br/
<hw>Hard</hw> <pr>(h<aum/rd)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Harder</adjf> <pr>(-<etil/r)</pr>;
<pos>superl.</pos> <adjf>Hardest</adjf>.]</amorph> <ety>[OE.
<ets>hard</ets>, <ets>heard</ets>, AS. <ets>heard</ets>; akin to OS. &
D. <ets>hard</ets>, G. <ets>hart</ets>, OHG. <ets>herti</ets>,
<ets>harti</ets>, Icel. <ets>har<edh/r</ets>, Dan. <ets>haard</ets>, Sw.
<ets>h<aring/rd</ets>, Goth. <ets>hardus</ets>, Gr. <grk>kraty`s</grk>
strong, <grk>ka`rtos</grk>, <grk>kra`tos</grk>, strength, and also to E.
<ets>-ard</ets>, as in <ets>coward</ets>, <ets>drunkard</ets>,
<ets>-crat</ets>, <ets>-cracy</ets> in auto<ets>crat</ets>,
demo<ets>cracy</ets>; cf. Skr. <ets>kratu</ets> strength,
<ets>k<rsdot/</ets> to do, make. Cf. <er>Hardy</er>.]</ety> <sn>1.</sn>
<def>Not easily penetrated, cut, or separated into parts; not yielding
to pressure; firm; solid; compact; -- applied to material bodies, and
opposed to <ant>soft</ant>; <as>as, <ex>hard</ex> wood; <ex>hard</ex>
flesh; a <ex>hard</ex> apple.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Difficult, mentally or judicially; not easily
apprehended, decided, or resolved; <as>as a <ex>hard</ex>
problem</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hard</qex> causes they brought unto Moses.</q>
<rj><qau>Ex. xviii. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In which are some things <qex>hard</qex> to be understood.</q>
<rj><qau>2 Peter iii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Difficult to accomplish; full of obstacles;
laborious; fatiguing; arduous; <as>as, a <ex>hard</ex> task; a disease
<ex>hard</ex> to cure.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Difficult to resist or control; powerful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The stag was too <qex>hard</qex> for the horse.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> A power which will be always too <qex>hard</qex> for them.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Difficult to bear or endure; not easy to put up with
or consent to; hence, severe; rigorous; oppressive; distressing; unjust;
grasping; <as>as, a <ex>hard</ex> lot; <ex>hard</ex> times;
<ex>hard</ex> fare; a <ex>hard</ex> winter; <ex>hard</ex> conditions or
terms.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I never could drive a <qex>hard</qex> bargain.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Difficult to please or influence; stern; unyielding;
obdurate; unsympathetic; unfeeling; cruel; <as>as, a <ex>hard</ex>
master; a <ex>hard</ex> heart; <ex>hard</ex> words; a <ex>hard</ex>
character.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Not easy or agreeable to the taste; harsh; stiff;
rigid; ungraceful; repelling; <as>as, a <ex>hard</ex>
style</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Figures <qex>harder</qex> than even the marble itself.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Rough; acid; sour, as liquors; <as>as, <ex>hard</ex>
cider</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Pron.)</fld> <def>Abrupt or explosive in utterance;
not aspirated, sibilated, or pronounced with a gradual change of the
organs from one position to another; -- said of certain consonants, as
<xex>c</xex> in <xex>came</xex>, and <xex>g</xex> in <xex>go</xex>, as
distinguished from the same letters in <xex>center</xex>,
<xex>general</xex>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Wanting softness or smoothness of utterance; harsh;
<as>as, a <ex>hard</ex> tone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Painting)</fld> <sd>(a)</sd> <def>Rigid in the
drawing or distribution of the figures; formal; lacking grace of
composition.</def> <sd>(b)</sd> <def>Having disagreeable and abrupt
contrasts in the coloring or light and shade.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hard cancer</b></col>, <col><b>Hard case</b></col>,
etc.</mcol> <cd>See under <er>Cancer</er>, <er>Case</er>, etc.</cd> --
<mcol><col><b>Hard clam</b></col>, <it>or</it> <col><b>Hard-shelled
clam</b></col></mcol> <fld>(Zool.)</fld>, <cd>the quahog.</cd> --
<col><b>Hard coal</b></col>, <cd>anthracite, as distinguished from
<contr>bituminous coal</contr> (<contr>soft coal</contr>).</cd> --
<col><b>Hard and fast</b></col>. <fld>(Naut.)</fld> <cd>See under
<er>Fast</er>.</cd> -- <col><b>Hard finish</b></col> <fld>(Arch.)</fld>,
<cd>a smooth finishing coat of hard fine plaster applied to the surface
of rough plastering.</cd> -- <col><b>Hard lines</b></col>, <cd>hardship;
difficult conditions.</cd> -- <col><b>Hard money</b></col>, <cd>coin or
specie, as distinguished from paper money.</cd> -- <col><b>Hard
oyster</b></col> <fld>(Zool.)</fld>, <cd>the northern native
oyster.</cd> <mark>[Local, U. S.]</mark> -- <col><b>Hard pan</b></col>,
<cd>the hard stratum of earth lying beneath the soil; hence,
figuratively, the firm, substantial, fundamental part or quality of
anything; as, the <xex>hard pan</xex> of character, of a matter in
dispute, etc. See <er>Pan</er>.</cd> -- <col><b>Hard rubber</b></col>.
<cd>See under <er>Rubber</er>.</cd> -- <col><b>Hard solder</b></col>.
<cd>See under <er>Solder</er>.</cd> -- <col><b>Hard water</b></col>,
<cd>water, which contains lime or some mineral substance rendering it
unfit for washing. See <er>Hardness</er>, 3.</cd> -- <col><b>Hard
wood</b></col>, <cd>wood of a solid or hard texture; as walnut, oak,
ash, box, and the like, in distinction from pine, poplar, hemlock,
etc.</cd> -- <col><b>In hard condition</b></col>, <cd>in excellent
condition for racing; having firm muscles; -- said of race
horses.</cd></cs></p>

<p><syn><b>Syn.</b> -- Solid; arduous; powerful; trying; unyielding;
stubborn; stern; flinty; unfeeling; harsh; difficult; severe; obdurate;
rigid. See <er>Solid</er>, and <er>Arduous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard</ent><br/
<hw>Hard</hw>, <pos>adv.</pos> <ety>[OE. <ets>harde</ets>, AS.
<ets>hearde</ets>.]</ety> <sn>1.</sn> <def>With pressure; with urgency;
hence, diligently; earnestly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And prayed so <qex>hard</qex> for mercy from the prince.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My father<br/
Is <qex>hard</qex> at study; pray now, rest yourself.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With difficulty; <as>as, the vehicle moves
<ex>hard</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Uneasily; vexatiously; slowly.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>So as to raise difficulties.</def> <ldquo/The
question is <xex>hard</xex> set.<rdquo/ <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>With tension or strain of the powers; violently;
with force; tempestuously; vehemently; vigorously; energetically;
<as>as, to press, to blow, to rain <ex>hard</ex></as>; hence, rapidly;
nimbly; <as>as, to run <ex>hard</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Close or near.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose house joined <qex>hard</qex> to the synagogue.</q>
<rj><qau>Acts xviii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hard by</b></col>, <col><b>near
by</b></col></mcol><cd>; close at hand; not far off.</cd>
<ldquo/<xex>Hard by</xex> a cottage chimney smokes.<rdquo/
<au>Milton.</au> -- <mcol><col><b>Hard pushed</b></col>, <col><b>Hard
run</b></col></mcol>, <cd>greatly pressed; <as>as, he was <ex>hard
pushed</ex> or <ex>hard run</ex> for time, money, etc.</as></cd>
<mark>[Colloq.]</mark> -- <col><b>Hard up</b></col>, <cd>closely pressed
by want or necessity; without money or resources; <as>as, <ex>hard
up</ex> for amusements</as>.</cd> <mark>[Slang]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hard</xex> in nautical language is often joined to
words of command to the helmsman, denoting that the order should be
carried out with the utmost energy, or that the helm should be put, in
the direction indicated, to the extreme limit, as, <xex>Hard
aport!</xex> <xex>Hard astarboard!</xex> <xex>Hard alee!</xex> <xex>Hard
aweather!</xex> <xex>Hard up!</xex><br/
<xex>Hard</xex> is also often used in composition with a participle; as,
<xex>hard</xex>-baked; <xex>hard</xex>-earned; <ex>hard</ex>-featured;
<xex>hard</xex>-working; <xex>hard</xex>-won.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard</ent><br/
<hw>Hard</hw> <pr>(h<aum/rd)</pr>, <pos>v. t.</pos> <def>To harden; to
make hard.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard</ent><br/
<hw>Hard</hw>, <pos>n.</pos> <def>A ford or passage across a river or
swamp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-and-fast</ent><br/
<hw>hard-and-fast</hw> <pos>adj.</pos> <def>invariable; firmly
established; <as>as, <ex>hard-and-fast</ex> regulations</as>.</def><br/
<syn><b>Syn. --</b> strict.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hardass</ent><br/
<hw>hard"ass</hw> <pos>n.</pos> <def>A person who strictly enforces
rules and regulations.</def> <mark>[vulgar slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>hard-bound</ent><br/
<ent>hardcover</ent><br/
<ent>hardbacked</ent><br/
<ent>hardback</ent><br/
<mhw><hw>hard"back`</hw>, <hw>hard"backed`</hw>, <hw>hard"cov*er</hw>
<hw>hard"-bound`</hw></mhw> <pos>adj.</pos> <def>Having rigid front and
back covers, usually boards covered with paper, cloth, or leather; -- of
books. Contrasted with <contr>softcover</contr> and
<contr>paperback</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hardback</ent><br/
<hw>hard"back`</hw> <pos>n.</pos> <def>A book with cardboard or cloth or
leather covers; a hardcover book. Compare
<contr>paperback</contr>.</def><br/
<syn><b>Syn. --</b> hardcover.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardbake</ent><br/
<hw>Hard"bake`</hw> <pr>(-b<amac/k`)</pr>, <pos>n.</pos> <def>A
sweetmeat of boiled brown sugar or molasses made with almonds, and
flavored with orange or lemon juice, etc.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-baked</ent><br/
<hw>hard-baked</hw> <pos>adj.</pos> <def>baked until hard.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardbeam</ent><br/
<hw>Hard"beam`</hw> <pr>(-b<emac/m`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A tree of the genus <gen>Carpinus</gen>, of
compact, horny texture; hornbeam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-boiled</ent><br/
<ent>hard-bitten</ent><br/
<mhw><hw>hard-bitten</hw> <hw>hard-boiled</hw></mhw> <pos>adj.</pos>
<def>not given to sentimentality or gentleness; -- of people; <as>as, a
<ex>hard-bitten</ex> character</as>.</def><br/
<syn><b>Syn. --</b> pugnacious, tough.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>hardboard</ent><br/
<hw>hard"board`</hw> <pos>n.</pos> <def>a cheap hard material made from
wood chips that are pressed together and bound with synthetic resin to
form sheets, used in construction and various other purposes; -- called
also <altname>particle board</altname> and
<altname>chipboard</altname>.</def><br/
<syn><b>Syn. --</b> chipboard.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hard-boiled</ent><br/
<hw>hard-boiled</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>hard-bitten</er>.</def><br/
<syn><b>Syn. --</b> hard-bitten, pugnacious.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>emotionally hardened; -- used of persons.</def><br/
<syn><b>Syn. --</b> callous, case-hardened, hardened.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>cooked until the yolk is solid; -- used of eggs;
<as>as, a breakfast of pancakes and <ex>hard-boiled</ex>
eggs</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hardbound</ent><br/
<hw>hardbound</hw> <pos>adj.</pos> <def>same as <er>hardback</er>; --
used of books.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hardcover</ent><br/
<hw>hard"cov*er</hw> <pos>n. & a.</pos> <def>Same as <er>hardback</er>
<pos>n.</pos> and <pos>a.</pos></def><br/
<syn><b>Syn. --</b> hardback.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harden</ent><br/
<hw>Hard"en</hw> <pr>(h<aum/rd"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hardened</conjf>
<pr>(-'nd)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Hardening</conjf>
<pr>(-'n*<icr/ng)</pr>.]</vmorph> <ety>[OE. <ets>hardnen</ets>,
<ets>hardenen</ets>.]</ety> <sn>1.</sn> <def>To make hard or harder; to
make firm or compact; to indurate; <as>as, to <ex>harden</ex> clay or
iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To accustom by labor or suffering to endure with
constancy; to strengthen; to stiffen; to inure; also, to confirm in
wickedness or shame; to make unimpressionable.</def>
<ldquo/<xex>Harden</xex> not your heart.<rdquo/ <rj><au>Ps. xcv.
8.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I would <qex>harden</qex> myself in sorrow.</q> <rj><qau>Job vi.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harden</ent><br/
<hw>Hard"en</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become hard or
harder; to acquire solidity, or more compactness; <as>as, mortar
<ex>hardens</ex> by drying</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The deliberate judgment of those who knew him [A. Lincoln] has
<qex>hardened</qex> into tradition.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become confirmed or strengthened, in either a
good or a bad sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They, <qex>hardened</qex> more by what might most reclaim.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardenbergia</ent><br/
<hw>Hardenbergia</hw> <pos>prop. n.</pos> <def>A small genus of
Australian woody vines with small violet flowers; closely related to
genus Kennedia.</def><br/
<syn><b>Syn. --</b> genus <gen>Hardenbergia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardened</ent><br/
<hw>Hard"ened</hw> <pr>(-'nd)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Made
hard, or harder, or compact; made unfeeling or callous; made obstinate
or obdurate; confirmed in error or vice.</def></p>

<p><sn>2.</sn> <def>Rendered resistant to the effects of nearby
explosions; <as>as, a <ex>hardened</ex> missile silo; <ex>hardened</ex>
warhead electronics</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Experienced and inured to hardship; <as>as,
<ex>hardened</ex> combat troops</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Strongly habituated to a certain type of behavior,
and unlikely to change; <as>as, a <ex>hardened</ex> criminal</as>.
Usually used only of behavior perceived negatively.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Impenetrable; hard; obdurate; callous; unfeeling;
unsusceptible; insensible. See <er>Obdurate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardener</ent><br/
<hw>Hard"en*er</hw> <pr>(-'n*<etil/r)</pr>, <pos>n.</pos> <def>One who,
or that which, hardens; specif., one who tempers tools.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardening</ent><br/
<hw>Hard"en*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>Making hard or
harder.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which hardens, as a material used for
converting the surface of iron into steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harder</ent><br/
<hw>Har"der</hw> <pr>(h<aum/r"d<etil/r)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A South African mullet, salted for
food.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harderian</ent><br/
<hw>Har*de"ri*an</hw> <pr>(h<aum/r*d<emac/"r<icr/*<ait/n)</pr>,
<pos>a.</pos> <fld>(Anat.)</fld> <def>A term applied to a lachrymal
gland on the inner side of the orbit of many animals which have a third
eyelid, or nictitating membrane. See <cref>Nictitating membrane</cref>,
under <er>Nictitate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-favored</ent><br/
<hw>Hard"-fa`vored</hw> <pr>(h<aum/rd"f<amac/`v<etil/rd)</pr>,
<pos>a.</pos> <def>Hard-featured; ill-looking; <as>as, Vulcan was
<ex>hard-favored</ex></as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-favoredness</ent><br/
<hw>Hard"-fa`vored*ness</hw>, <pos>n.</pos> <def>Coarseness of
features.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-featured</ent><br/
<hw>Hard"-fea`tured</hw> <pr>(-f<emac/`t<usl/rd; 135)</pr>,
<pos>a.</pos> <def>Having coarse, unattractive or stern features.</def>
<rj><au>Smollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardfern</ent><br/
<hw>Hard"fern`</hw> <pr>(-f<etil/rn`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A species of fern (<spn>Lomaria borealis</spn>),
growing in Europe and Northwestern America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-fisted</ent><br/
<hw>Hard"-fist`ed</hw> <pr>(-f<icr/st`<ecr/d)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Having hard or strong hands; <as>as, a
<ex>hard-fisted</ex> laborer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Close-fisted; covetous; niggardly.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-fought</ent><br/
<hw>hard"-fought`</hw> <pr>(-f<add/t`)</pr>, <pos>a.</pos>
<def>Vigorously contested by both opponents; -- of contests; <as>as, a
<ex>hard-fought</ex> battle; a <ex>hard-fought</ex> primary
election</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hard grass</ent><br/
<hw>Hard" grass`</hw> <pr>(gr<adot/s`)</pr>. <fld>(Bot.)</fld> <def>A
name given to several different grasses, especially to the
<spn>Roltb<oum/llia incurvata</spn>, and to the species of
<gen>Aegilops</gen>, from one of which it is contended that wheat has
been derived.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardhack</ent><br/
<hw>Hard"hack`</hw> <pr>(-h<acr/k`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A very astringent shrub (<spn>Spiraea
tomentosa</spn>), common in pastures. The <spn>Potentilla
fruticosa</spn> is also called by this name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-handed</ent><br/
<hw>Hard"-hand`ed</hw> <pr>(-h<acr/nd`<ecr/d)</pr>, <pos>a.</pos>
<def>Having hard hands, as a manual laborer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hard-handed</qex> men that work in Athens here.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardhead</ent><br/
<hw>Hard"head`</hw> <pr>(-h<ecr/d`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Clash or collision of heads in contest.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The menhaden. See
<er>Menhaden</er>.</def> <mark>[Local, U. S.]</mark> <sd>(b)</sd>
<def>Block's gurnard (<spn>Trigla gurnardus</spn>) of Europe.</def>
<sd>(c)</sd> <def>A California salmon; the steelhead.</def> <sd>(d)</sd>
<def>The gray whale.</def> See <cref>Gray whale</cref>, under
<er>Gray</er>. <sd>(e)</sd> <def>A coarse American commercial sponge
(<spn>Spongia dura</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-headed</ent><br/
<ent>hardheaded</ent><br/
<mhw><hw>hard"head`ed</hw>, <hw>hard"-head`ed</hw></mhw>, <pos>a.</pos>
<def>Having sound judgment; sagacious; shrewd; practical and
pragmatic.</def> -- <wordforms><wf>Hard"-head`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-hearted</ent><br/
<hw>Hard"-heart`ed</hw> <pr>(-h<aum/rt`<ecr/d)</pr>, <pos>a.</pos>
<def>Unsympathetic; inexorable; cruel; pitiless.</def> --
<wordforms><wf>Hard"-heart`ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-hitting</ent><br/
<hw>hard-hitting</hw> <pos>adj.</pos> <sn>1.</sn> <def>characterized by
or full of force and vigor; forceful; <as>as, a <ex>hard-hitting</ex>
expose</as>.</def><br/
<syn><b>Syn. --</b> trenchant, vigorous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>aggressive; <as>as, a <ex>hard-hitting</ex>
advertising campaign</as>. Opposite of
<ant>unaggressive</ant>.</def><br/
<syn><b>Syn. --</b> high-pressure.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardihead</ent><br/
<hw>Har"di*head</hw> <pr>(h<aum/r"d<icr/*h<ecr/d)</pr>, <pos>n.</pos>
<def>Hardihood.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardihood</ent><br/
<hw>Har"di*hood</hw> <pr>(h<aum/r"d<icr/*h<oocr/d)</pr>, <pos>n.</pos>
<ety>[<ets>Hardy</ets> + <ets>-hood</ets>.]</ety> <def>Boldness, united
with firmness and constancy of mind; bravery; intrepidity; also,
audaciousness; impudence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A bound of graceful <qex>hardihood</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the society of numbers which gives <qex>hardihood</qex> to
iniquity.</q> <rj><qau>Buckminster.</qau></rj></p>

<p><syn><b>Syn.</b> -- Intrepidity; courage; pluck; resolution;
stoutness; audacity; effrontery; impudence.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardily</ent><br/
<hw>Har"di*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>Same as
<er>Hardly</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Boldly; stoutly; resolutely.</def>
<rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardiment</ent><br/
<hw>Har"di*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <ety>[OF.
<ets>hardement</ets>. See <er>Hardy</er>.]</ety> <def>Hardihood;
boldness; courage; energetic action.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Changing <qex>hardiment</qex> with great Glendower.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardiness</ent><br/
<hw>Har"di*ness</hw> <pr>(-d<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Capability of endurance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hardihood; boldness; firmness; assurance.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Plenty and peace breeds cowards; Hardness ever<br/
Of <qex>hardiness</qex> is mother.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They who were not yet grown to the <qex>hardiness</qex> of avowing
the contempt of the king.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hardship; fatigue.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardish</ent><br/
<hw>Hard"ish</hw> <pr>(h<aum/rd"<icr/sh)</pr>, <pos>a.</pos>
<def>Somewhat hard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-labored</ent><br/
<hw>Hard"-la`bored</hw> <pr>(h<aum/rd"l<amac/`b<etil/rd)</pr>,
<pos>a.</pos> <def>Wrought with severe labor; elaborate; studied.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardly</ent><br/
<hw>Hard"ly</hw> <pr>(h<aum/rd"l<ycr/)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>heardlice</ets>. See <er>Hard</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>In a hard or difficult manner; with
difficulty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Recovering <qex>hardly</qex> what he lost before.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unwillingly; grudgingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The House of Peers gave so <qex>hardly</qex> their consent.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Scarcely; barely; not quite; not wholly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hardly</qex> shall you find any one so bad, but he desires
the credit of being thought good.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Severely; harshly; roughly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has in many things been <qex>hardly</qex> used.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Confidently; hardily.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Certainly; surely; indeed.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hardly ever</ent><br/
<hw>hard"ly ev"er</hw> <pr>(h<aum/rd"l<ycr/ <ecr/v"<etil/r)</pr>,
<pos>adv.</pos> <def>Seldom; rarely; almost never.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hard-mouthed</ent><br/
<hw>Hard"-mouthed`</hw> <pr>(-mou<th/d`)</pr>, <pos>a.</pos> <def>Not
sensible to the bit; not easily governed; <as>as, a
<ex>hard-mouthed</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardness</ent><br/
<hw>Hard"ness</hw>, <pos>n.</pos> <ety>[AS. <ets>heardness</ets>.]</ety>
<sn>1.</sn> <def>The quality or state of being hard, literally or
figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The habit of authority also had given his manners some peremptory
<qex>hardness</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>The cohesion of the particles on
the surface of a body, determined by its capacity to scratch another, or
be itself scratched; -- measured among minerals on a scale of which
diamond and talc form the extremes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>The peculiar quality exhibited by
water which has mineral salts dissolved in it. Such water forms an
insoluble compound with soap, and is hence unfit for washing
purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This quality is caused by the presence of calcium
carbonate, causing <xex>temporary hardness</xex> which can be removed by
boiling, or by calcium sulphate, causing <xex>permanent hardness</xex>
which can not be so removed, but may be improved by the addition of
sodium carbonate.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>hardnose</ent><br/
<hw>hard"nose</hw> <pos>n.</pos> <def>A hard-nosed person; one who is
realistic and pragmatic and is impatient with those who are not.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>hard-nosed</ent><br/
<hw>hard-nosed</hw> <pos>adj.</pos> <def>facing reality squarely; guided
by practical experience and observation rather than theory; tough and
pragmatic; <as>as, a <ex>hard-nosed</ex> businessman</as>.</def><br/
<syn><b>Syn. --</b> down-to-earth, hardheaded, practical,
pragmatic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardock</ent><br/
<hw>Har"dock</hw> <pr>(h<aum/r"d<ocr/k)</pr>, <pos>n.</pos>
<mark>[Obs.]</mark> <def>See <er>Hordock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-of-hearing</ent><br/
<hw>hard-of-hearing</hw> <pos>adj.</pos> <def>having a reduced ability
to hear, but not fully deaf; partly deaf.</def><br/
<syn><b>Syn. --</b> hearing-impaired.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hard-on</ent><br/
<hw>hard-on</hw> <pos>n.</pos> <def>An erect penis; a penile
erection.</def> <mark>[slang or vulgar]</mark><br/
<syn><b>Syn. --</b> erection.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardpan</ent><br/
<hw>Hard"pan`</hw> <pr>(h<aum/rd"p<acr/n)</pr>, <pos>n.</pos> <def>The
hard substratum. Same as <cref>Hard pan</cref>, under <er>Hard</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-pressed</ent><br/
<hw>hard-pressed</hw> <pos>adj.</pos> <def>facing or experiencing
trouble or difficulty; <as>as, financially <ex>hard-pressed</ex> Mexican
hotels are lowering their prices; they were <ex>hard-pressed</ex> to
find a substitute on short notice</as>; -- see
<er>distressed</er>{1}.</def><br/
<syn><b>Syn. --</b> distressed, hard put, in a bad way(predicate), in
trouble(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hards</ent><br/
<hw>Hards</hw> <pr>(h<aum/rdz)</pr>, <pos>n. pl.</pos> <ety>[OE.
<ets>herdes</ets>, AS. <ets>heordan</ets>; akin to G.
<ets>hede</ets>.]</ety> <def>The refuse or coarse part of flax;
tow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard-shell</ent><br/
<hw>Hard"-shell`</hw> <pr>(h<aum/rd"sh<ecr/l`)</pr>, <pos>a.</pos>
<def>Unyielding; insensible to argument; uncompromising; strict.</def>
<mark>[Colloq., U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardship</ent><br/
<hw>Hard"ship</hw> <pr>(h<aum/rd"sh<icr/p)</pr>, <pos>n.</pos> <def>That
which is hard to bear, as toil, privation, injury, injustice, etc.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardspun</ent><br/
<hw>Hard"spun`</hw>, <pos>a.</pos> <def>Firmly twisted in
spinning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hard steel</ent><br/
<hw>Hard steel</hw>. <def>Steel hardened by the addition of other
elements, as manganese, phosphorus, or (usually) carbon.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>hard-surfaced</ent><br/
<hw>hard-surfaced</hw> <pos>adj.</pos> <def>paved; -- of roads. Opposite
of <ant>unpaved</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hard-tack</ent><br/
<ent>Hardtack</ent><br/
<mhw><hw>Hard"tack`</hw> or <hw>Hard"-tack`</hw></mhw>
<pr>(h<aum/rd"t<acr/k`)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A name
given by soldiers and sailors to a kind of unleavened hard biscuit or
sea bread. Called also <altname>pilot biscuit</altname>, <altname>pilot
bread</altname>, <altname>ship biscuit</altname> and <altname>ship
bread</altname></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any of several mahogany trees, esp. the
<spn>Cercocarpus betuloides</spn>.</def> <au>MW10</au><br/
[<source>PJC</source>]</p>

<p><ent>Hardtail</ent><br/
<hw>Hard"tail`</hw> <pr>(h<aum/rd"t<amac/l`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>See <er>Jurel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard-to-please</ent><br/
<hw>hard-to-please</hw> <pos>adj.</pos> <def>Requiring great patience
and effort and skill; demanding; -- of persons. Opposite of
<ant>undemanding</ant>.</def><br/
<syn><b>Syn. --</b> harsh, demanding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hard-visaged</ent><br/
<hw>Hard"-vis`aged</hw> <pr>(h<aum/rd"v<icr/z`<asl/jd; 48)</pr>,
<pos>a.</pos> <def>Of a harsh or stern countenance; hard-featured.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardware</ent><br/
<hw>Hard"ware`</hw> <pr>(h<aum/rd"w<acir/r`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Ware made of metal, as cutlery, kitchen utensils, and
the like; ironmongery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any of the physical objects used in carrying out an
activity, in contrast to the knowledge, skill, or theory required to
perform the activity; mostly used collectively.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <fld>(Computers)</fld>
<def>The sum of all the physical objects, such as the electrical,
mechanical, and electronic devices which comprise a computer system;
<as>as, the typical PC <ex>hardware</ex> suite consists of a mainboard
and a number of peripherals such as hard drives and speakers, connected
by adapter cards, but the input and output from users occurs mostly
through the keyboard and monitor</as>; contrasted with
<contr>software</contr>, the programs executed by the
computer.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Specifically:</specif> <fld>(Military)</fld>
<def>The weapons, transport, and other physical objects used in
conducting a war.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <mark>(Slang)</mark> <def>Weapons, especially handguns,
carried on the person; <as>as, check your <ex>hardware</ex> at the door
before entering</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hardwareman</ent><br/
<hw>hard"ware`man</hw> <pr>(h<aum/rd"w<acir/r`m<acr/n)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Hardwaremen</plw>
<pr>(h<aum/rd"w<acir/r`m<ecr/n)</pr>.</plu> <def>One who makes, or deals
in, hardware.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hard wired</ent><br/
<ent>hard-wired</ent><br/
<mhw><hw>hard"-wired"</hw>, <hw>hard" wired"</hw></mhw>
<pr>(h<aum/rd"w<imac/rd")</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Computers)</fld> <def>Contained within the circuitry of a computer
or computer peripheral device, and not changeable by programming; -- of
functions; <as>as, error correction is <ex>hard-wired</ex> into the
circuit of the disk drive, so it proceeds very rapidly</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Connected by a continuous electrical wire, rather
than through a switch; <as>as, the air-conditioner was
<ex>hard-wired</ex> into the wall circuit, so moving it would require an
electrician</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <mark>(Metaph.)</mark> <def>Performed by an inborn
pattern of neural circuits; instinctive; not learned; <as>as, many bird
songs are <ex>hard-wired</ex>, but some are learned</as>.</def><br/
[<source>PJC</source>]</p>

<p><q>People, as the cybernetic metaphor now has it, are <ldquo/hard
wired<rdquo/ to do good in order to enhance their own happiness.</q>
<au>Andrew Delbanco (New York Times Magazine, May 7, 2000; p.
46).</au><br/
[<source>PJC</source>]</p>

<p><ent>hardwood</ent><br/
<hw>hard"wood`</hw> <pos>n.</pos> <def>The wood of broad-leaved
dicotyledonous trees (as distinguished from the wood of conifers); also
items made from such wood; <as>as, decorative
<ex>hardwood</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hardwood</ent><br/
<hw>hard"wood`</hw> <pos>adj.</pos> <def>Made of the hard-to-cut wood of
a broad-leaved tree, as e.g. oak; consisting of a hardwood; <as>as,
<ex>hardwood</ex> floors</as>; -- of wood and wooden objects.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hard-won</ent><br/
<hw>hard"-won`</hw> <pos>a.</pos> <def>Acquired with difficulty; <as>as,
to squander one's <ex>hard-won</ex> fortune</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hardworking</ent><br/
<hw>hard"work`ing</hw> <pos>adj.</pos> <sn>1.</sn> <def>habitually
working diligently and for long hours.</def><br/
<syn><b>Syn. --</b> industrious, tireless, untiring.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hardy</ent><br/
<hw>Har"dy</hw> <pr>(h<aum/r"d<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Hardier</adjf>
<pr>(-d<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Hardiest</adjf>.]</amorph> <ety>[F. <ets>hardi</ets>, p. p. fr.
OF. <ets>hardir</ets> to make bold; of German origin, cf. OHG.
<ets>hertan</ets> to harden, G. <ets>h<aum/rten</ets>. See
<er>Hard</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>Bold; brave; stout;
daring; resolute; intrepid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hap helpeth <qex>hardy</qex> man alway.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confident; full of assurance; in a bad sense,
morally hardened; shameless.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Strong; firm; compact.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[A] blast may shake in pieces his <qex>hardy</qex> fabric.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Inured to fatigue or hardships; strong; capable of
endurance; <as>as, a <ex>hardy</ex> veteran; a <ex>hardy</ex>
mariner.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Able to withstand the cold of winter.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Plants which are <xex>hardy</xex> in Virginia may perish
in New England. <xex>Half-hardy</xex> plants are those which are able to
withstand mild winters or moderate frosts.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hardy</ent><br/
<hw>Har"dy</hw>, <pos>n.</pos> <def>A blacksmith's fuller or chisel,
having a square shank for insertion into a square hole in an anvil,
called the <ecol><b>hardy hole</b></ecol>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hare</ent><br/
<hw>Hare</hw> <pr>(h<acir/r)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Harry</er>, <er>Harass</er>.]</ety> <def>To excite; to tease,
harass, or worry; to harry.</def> <mark>[Obs.]</mark>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hare</ent><br/
<hw>Hare</hw>, <pos>n.</pos> <ety>[AS. <ets>hara</ets>; akin to D.
<ets>haas</ets>, G. <ets>hase</ets>, OHG. <ets>haso</ets>, Dan. & Sw.
<ets>hare</ets>, Icel. <ets>h<emac/ri</ets>, Skr.
<ets><cced/a<cced/a</ets>. <root/226.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Zool.)</fld> <def>A rodent of the genus
<gen>Lepus</gen>, having long hind legs, a short tail, and a divided
upper lip. It is a timid animal, moves swiftly by leaps, and is
remarkable for its fecundity.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The species of hares are numerous. The common European
hare is <spn>Lepus timidus</spn>. The northern or varying hare of
America (<spn>Lepus Americanus</spn>), and the prairie hare (<spn>Lepus
campestris</spn>), turn white in winter. In America, the various species
of hares are commonly called <altname>rabbits</altname>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>A small constellation situated
south of and under the foot of Orion; Lepus.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hare and hounds</b></col>, <cd>a game played by men and
boys, two, called <xex>hares</xex>, having a few minutes' start, and
scattering bits of paper to indicate their course, being chased by the
others, called the <xex>hounds</xex>, through a wide circuit.</cd> --
<col><b>Hare kangaroo</b></col> <fld>(Zool.)</fld>, <cd>a small
Australian kangaroo (<spn>Lagorchestes Leporoides</spn>), resembling the
hare in size and color,</cd> -- <col><b>Hare's lettuce</b></col>
<fld>(Bot.)</fld>, <cd>a plant of the genus <gen>Sonchus</gen>, or sow
thistle; -- so called because hares are said to eat it when fainting
with heat.</cd> <au>Dr. Prior.</au> -- <col><b>Jumping hare</b></col>.
<fld>(Zool.)</fld> <cd>See under <er>Jumping</er>.</cd> --
<mcol><col><b>Little chief hare</b></col>, <it>or</it> <col><b>Crying
hare</b></col></mcol>. <fld>(Zool.)</fld> <cd>See <er>Chief
hare</er>.</cd> -- <col><b>Sea hare</b></col>. <fld>(Zool.)</fld>
<cd>See <er>Aplysia</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harebell</ent><br/
<hw>Hare"bell`</hw> <pr>(h<acir/r"b<ecr/l`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A small, slender, branching plant (<spn>Campanula
rotundifolia</spn>), having blue bell-shaped flowers; also, <spn>Scilla
nutans</spn>, which has similar flowers; -- called also
<altname>bluebell</altname>.</def> <altsp>[Written also
<asp>hairbell</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>E'en the light <qex>harebell</qex> raised its head.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 671 pr=JMD --></p>

<p><ent>Harebrained</ent><br/
<hw>Hare"brained`</hw> <pr>(h<acir/r"br<amac/nd`)</pr>, <pos>a.</pos>
<def>Wild; giddy; volatile; heedless.</def> <ldquo/A mad
<xex>hare-brained</xex> fellow.<rdquo/ <au>North (Plutarch).</au>
<altsp>[Written also <asp>hairbrained</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harefoot</ent><br/
<hw>Hare"foot`</hw> <pr>(-f<oocr/t`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A long, narrow foot, carried (that is, produced
or extending) forward; -- said of dogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A tree (<spn>Ochroma
Lagopus</spn>) of the West Indies, having the stamens united somewhat in
the form of a hare's foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harefoot clover</b></col> <fld>(Bot.)</fld>, <cd>a
species of clover (<spn>Trifolium arvense</spn>) with soft and silky
heads.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hare-hearted</ent><br/
<hw>Hare"-heart`ed</hw> <pr>(-h<aum/rt`<ecr/d)</pr>, <pos>a.</pos>
<def>Timorous; timid; easily frightened.</def>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harehound</ent><br/
<hw>Hare"hound`</hw> <pr>(-hound`)</pr>, <pos>n.</pos> <def>See
<er>Harrier</er>.</def> <rj><au>A. Chalmers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hareld</ent><br/
<hw>Har"eld</hw> <pr>(h<acr/r"<ecr/ld)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The long-tailed duck. See <er>Old
Squaw</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harelip</ent><br/
<hw>Hare"lip`</hw> <pr>(h<acir/r"l<icr/p`)</pr>, <pos>n.</pos> <def>A
lip, commonly the upper one, having a fissure of perpendicular division
like that of a hare.</def> -- <wordforms><wf>Hare"lipped`</wf>
<pr>(-l<icr/pt`)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harem</ent><br/
<hw>Ha"rem</hw> <pr>(h<amac/"r<ecr/m; 277)</pr>, <pos>n.</pos><ety>[Ar.
<ets>haram</ets>, orig., anything forbidden or sacred, fr.
<ets>harama</ets> to forbid, prohibit.]</ety> <ety>[Written also
<ets>haram</ets> and <ets>hareem</ets>.]</ety> <sn>1.</sn> <def>The
apartments or portion of the house allotted to females in Muslim
families.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The family of wives and concubines belonging to one
man, in Muslim countries; a seraglio.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harengiform</ent><br/
<hw>Ha*ren"gi*form</hw> <pr>(h<adot/*r<ecr/n"j<icr/*f<ocir/rm)</pr>,
<pos>a.</pos> <ety>[F. <ets>hareng</ets> herring (LL.
<ets>harengus</ets>) + <ets>-form</ets>.]</ety>
<def>Herring-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hare's-ear</ent><br/
<hw>Hare's"-ear`</hw> <pr>(h<acir/rz"<emac/r`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>An umbelliferous plant (<spn>Bupleurum
rotundifolium</spn>); -- so named from the shape of its leaves.</def>
<rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hare's-foot fern</ent><br/
<hw>Hare's"-foot` fern`</hw> <pr>(-f<oocr/t` f<etil/rn`)</pr>.
<fld>(Bot.)</fld> <def>A species of fern (<spn>Davallia
Canariensis</spn>) with a soft, gray, hairy rootstock; -- whence the
name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hare's-tail</ent><br/
<hw>Hare's"-tail`</hw> <pr>(-t<amac/l`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A kind of grass (<spn>Eriophorum
vaginatum</spn>). See <cref>Cotton grass</cref>, under
<er>Cotton</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hare's-tail grass</b></col> <fld>(Bot.)</fld>, <cd>a
species of grass (<spn>Lagurus ovatus</spn>) whose head resembles a
hare's tail.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harfang</ent><br/
<hw>Har"fang</hw> <pr>(h<aum/r"f<acr/ng)</pr>, <pos>n.</pos> <ety>[See
<er>Hare</er>, <pos>n.</pos>, and <er>Fang</er>.]</ety>
<fld>(Zool.)</fld> <def>The snowy owl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hariali grass</ent><br/
<hw>Ha`ri*a"li grass`</hw> <pr>(h<aum/`r<icr/*<aum/"l<icr/
gr<adot/s`)</pr>. <fld>(Bot.)</fld> <def>The East Indian name of the
<spn>Cynodon Dactylon</spn>; dog's-grass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haricot</ent><br/
<hw>Har"i*cot</hw> <pr>(h<acr/r"<esl/*k<osl/; F.
<adot/`r<esl/`k<osl/")</pr>, <pos>n.</pos> <ety>[F.]</ety> <sn>1.</sn>
<def>A ragout or stew of meat with beans and other vegetables.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The ripe seeds, or the unripe pod, of the common
string bean (<spn>Phaseolus vulgaris</spn>), used as a vegetable. Other
species of the same genus furnish different kinds of haricots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harier</ent><br/
<hw>Har"i*er</hw> <pr>(h<acr/r"<icr/*<etil/r)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>See <er>Harrier</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harikari</ent><br/
<hw>Ha"ri*ka`ri</hw> <pr>(h<aum/"r<icr/*k<aum/`r<icr/)</pr>,
<pos>n.</pos> <def>See <er>Hara-kiri</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hariolation</ent><br/
<hw>Har`i*o*la"tion</hw>
<pr>(h<acr/r`<icr/*<osl/*l<amac/"sh<ucr/n)</pr>, <pos>n.</pos> <ety>[See
<er>Ariolation</er>.]</ety> <def>Prognostication; soothsaying.</def>
<mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harish</ent><br/
<hw>Har"ish</hw> <pr>(h<acir/r"<icr/sh)</pr>, <pos>a.</pos> <def>Like a
hare.</def> <mark>[R.]</mark> <rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hark</ent><br/
<hw>Hark</hw> <pr>(h<aum/rk)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>herken</ets>. See <er>Hearken</er>.]</ety> <def>To listen; to
hearken.</def> <mark>[Now rare, except in the imperative form used as an
interjection, Hark! listen.]</mark> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Hark away!</b></col> <col><b>Hark back!</b></col>
<col><b>Hark forward!</b></col></mcol> <fld>(Sporting)</fld>, <cd>cries
used to incite and guide hounds in hunting.</cd> -- <col><b>To hark
back</b></col>, <cd>to go back for a fresh start, as when one has
wandered from his direct course, or made a digression.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>He must have overshot the mark, and must <qex>hark back</qex>.</q>
<rj><qau>Haggard.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>harked back</qex> to the subject.</q> <rj><qau>W. E.
Norris.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Harken</ent><br/
<hw>Hark"en</hw> <pr>(h<aum/rk"'n)</pr>, <pos>v. t. & i.</pos> <def>To
hearken.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harl</ent><br/
<hw>Harl</hw> <pr>(h<aum/rl)</pr>, <pos>n.</pos> <ety>[Cf. OHG.
<ets>harluf</ets> noose, rope; E. <ets>hards</ets> refuse of
flax.]</ety> <sn>1.</sn> <def>A filamentous substance; especially, the
filaments of flax or hemp.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A barb, or barbs, of a fine large feather, as of a
peacock or ostrich, -- used in dressing artificial flies.</def>
<altsp>[Written also <asp>herl</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harle</ent><br/
<hw>Harle</hw> <pr>(h<aum/rl)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The red-breasted merganser.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlech group</ent><br/
<hw>Har"lech group`</hw> <pr>(h<aum/r"l<ecr/k gr<oomac/p`)</pr>.
<ety>[So called from <etsep>Harlech</etsep> in Wales.]</ety>
<fld>(Geol.)</fld> <def>A minor subdivision at the base of the Cambrian
system in Wales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlequin</ent><br/
<hw>Har"le*quin</hw> <pr>(h<aum/r"l<esl/*k<icr/n <i>or</i>
h<aum/r"l<esl/*kw<icr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>arlequin</ets>, formerly written also <ets>harlequin</ets> (cf. It,
<ets>arlecchino</ets>), prob. fr. OF. <ets>hierlekin</ets>,
<ets>hellequin</ets>, goblin, elf, which is prob. of German or Dutch
origin; cf. D. <ets>hel</ets> hell. Cf. <er>Hell</er>,
<er>Kin</er>.]</ety> <def>A buffoon, dressed in parti-colored clothes,
who plays tricks, often without speaking, to divert the bystanders or an
audience; a merry-andrew; originally, a droll rogue of Italian
comedy.</def> <rj><au>Percy Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As dumb <qex>harlequin</qex> is exhibited in our theaters.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harlequin bat</b></col> <fld>(Zool.)</fld>, <cd>an Indian
bat (<spn>Scotophilus ornatus</spn>), curiously variegated with white
spots.</cd> -- <col><b>Harlequin beetle</b></col> <fld>(Zool.)</fld>,
<cd>a very large South American beetle (<spn>Acrocinus longimanus</spn>)
having very long legs and antennae. The elytra are curiously marked with
red, black, and gray.</cd> -- <col><b>Harlequin cabbage bug</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Calicoback</er>.</cd> --
<col><b>Harlequin caterpillar</b></col>. <fld>(Zool.)</fld>, <cd>the
larva of an American bombycid moth (<spn>Euchaetes egle</spn>) which is
covered with black, white, yellow, and orange tufts of hair.</cd> --
<col><b>Harlequin duck</b></col> <fld>(Zool.)</fld>, <cd>a North
American duck (<spn>Histrionicus histrionicus</spn>). The male is dark
ash, curiously streaked with white.</cd> -- <col><b>Harlequin
moth</b></col>. <fld>(Zool.)</fld> <cd>See <er>Magpie Moth</er>.</cd> --
<col><b>Harlequin opal</b></col>. <cd>See <er>Opal</er>.</cd> --
<col><b>Harlequin snake</b></col> <fld>(Zool.)</fld>, <cd>See
<er>harlequin snake</er> in the vocabulary.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlequin</ent><br/
<hw>Har"le*quin</hw> <pr>(h<aum/r"l<esl/*k<icr/n <or/ -kw<icr/n)</pr>,
<pos>v. i.</pos> <def>To play the droll; to make sport by playing
ludicrous tricks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlequin</ent><br/
<hw>Har"le*quin</hw>, <pos>v. t.</pos> <def>To remove or conjure away,
as by a harlequin's trick.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And kitten, if the humor hit<br/
Has <qex>harlequined</qex> away the fit.</q> <rj><qau>M.
Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlequinade</ent><br/
<hw>Har"le*quin*ade`</hw> <pr>(-<amac/d`)</pr>, <pos>n.</pos> <ety>[F.
<ets>arleguinade</ets>.]</ety> <def>A play or part of a play in which
the harlequin is conspicuous; the part of a harlequin.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>harlequin snake</ent><br/
<hw>har"le*quin snake`</hw> <pos>n.</pos> <def>any of several venomous
New World snakes brilliantly banded in red and black and either yellow
or white, especially the <stype>eastern coral snake</stype>, a small
poisonous snake (<spn>Micrurus fulvius</spn> or <spn>Elaps
fulvius</spn>), ringed with red and black, found in the Southeastern
United States. They are widely distributed in Southern and Central
America;</def><br/
<syn><b>Syn. --</b> coral snake, New World coral snake.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harlock</ent><br/
<hw>Har"lock</hw> <pr>(h<aum/r"l<ocr/k)</pr>, <pos>n.</pos>
<def>Probably a corruption either of <altname>charlock</altname> or
<altname>hardock</altname>.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlot</ent><br/
<hw>Har"lot</hw> <pr>(-l<ocr/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harlot</ets>, <ets>herlot</ets>, a vagabond, OF. <ets>harlot</ets>,
<ets>herlot</ets>, <ets>arlot</ets>; cf. Pr. <ets>arlot</ets>, Sp.
<ets>arlote</ets>, It. <ets>arlotto</ets>; of uncertain origin.]</ety>
<sn>1.</sn> <def>A churl; a common man; a person, male or female, of low
birth.</def> <rj><au><mark>[Obs.]</mark></au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was a gentle <qex>harlot</qex> and a kind.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person given to low conduct; a rogue; a cheat; a
rascal.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A woman who prostitutes her body for hire; a
prostitute; a common woman; a strumpet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlot</ent><br/
<hw>Har"lot</hw>, <pos>a.</pos> <def>Wanton; lewd; low; base.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlot</ent><br/
<hw>Har"lot</hw>, <pos>v. i.</pos> <def>To play the harlot; to practice
lewdness.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlotize</ent><br/
<hw>Har"lot*ize</hw> <pr>(-<imac/z)</pr>, <pos>v. i.</pos> <def>To
harlot.</def> <mark>[Obs.]</mark> <rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harlotry</ent><br/
<hw>Har"lot*ry</hw> <pr>(-r<ycr/)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Ribaldry; buffoonery; a ribald story.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au> <au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The trade or practice of prostitution; habitual or
customary lewdness.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything meretricious; <as>as, <ex>harlotry</ex> in
art</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A harlot; a strumpet; a baggage.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He sups to-night with a <qex>harlotry</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harm</ent><br/
<hw>Harm</hw> <pr>(h<aum/rm)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harm</ets>, <ets>hearm</ets>, AS. <ets>hearm</ets>; akin to OS.
<ets>harm</ets>, G. <ets>harm</ets> grief, Icel. <ets>harmr</ets>, Dan.
<ets>harme</ets>, Sw. <ets>harm</ets>; cf. OSlav. & Russ.
<ets>sram'</ets> shame, Skr. <ets><cced/rama</ets> toil, fatigue.]</ety>
<sn>1.</sn> <def>Injury; hurt; damage; detriment; misfortune.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which causes injury, damage, or loss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We, ignorant of ourselves,<br/
Beg often our own <qex>harms</qex>.</q> <rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Mischief; evil; loss; injury. See
<er>Mischief</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harm</ent><br/
<hw>Harm</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harmed</conjf> <pr>(h<aum/rmd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Harming</conjf>.]</vmorph> <ety>[OE. <ets>harmen</ets>, AS.
<ets>hearmian</ets>. See <er>Harm</er>, <pos>n.</pos>]</ety> <def>To
hurt; to injure; to damage; to wrong.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though yet he never <qex>harmed</qex> me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No ground of enmity between us known<br/
Why he should mean me ill or seek to <qex>harm</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmaline</ent><br/
<hw>Har"ma*line</hw> <pr>(h<aum/r"m<adot/*l<icr/n <or/ -l<emac/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>harmaline</ets> See
<er>Harmel</er>.]</ety> <fld>(Chem.)</fld> <def>An alkaloid found in the
plant <xex>Peganum harmala</xex>. It forms bitter, yellow
salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmattan</ent><br/
<hw>Har*mat"tan</hw> <pr>(h<aum/r*m<acr/t"t<ait/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>harmattan</ets>, prob. of Arabic origin.]</ety> <def>A
dry, hot wind, prevailing on the Atlantic coast of Africa, in December,
January, and February, blowing from the interior or Sahara. It is
usually accompanied by a haze which obscures the sun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmel</ent><br/
<hw>Har"mel</hw> <pr>(h<aum/r"m<ecr/l)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>harmal</ets>.]</ety> <fld>(Bot.)</fld> <def>A kind of rue
(<spn>Ruta sylvestris</spn>) growing in India. At Lahore the seeds are
used medicinally and for fumigation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmful</ent><br/
<hw>Harm"ful</hw> <pr>(h<aum/rm"f<usdot/l)</pr>, <pos>a.</pos> <def>Full
of harm; injurious; hurtful; mischievous.</def> <ldquo/ Most
<xex>harmful</xex> hazards.<rdquo/ <rj><au>Strype.</au></rj></p>

<p>--<wordforms><wf>Harm"ful*ly</wf>, <pos>adv.</pos> --
<wf>Harm"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmine</ent><br/
<hw>Har"mine</hw> <pr>(h<aum/r"m<icr/n <or/ -m<emac/n)</pr>,
<pos>n.</pos><ety>[See <er>Harmaline</er>.]</ety> <fld>(Chem.)</fld>
<def>An alkaloid accompanying harmaline (in the <spn>Peganum
harmala</spn>), and obtained from it by oxidation. It is a white
crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmless</ent><br/
<hw>Harm"less</hw> <pr>(h<aum/rm"l<ecr/s)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Free from harm; unhurt; <as>as, to give bond to save
another <ex>harmless</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free from power or disposition to harm; innocent;
inoffensive.</def> <ldquo/ The <xex>harmless</xex> deer.<rdquo/
<rj><au>Drayton</au></rj></p>

<p><syn><b>Syn.</b> -- Innocent; innoxious; innocuous; inoffensive;
unoffending; unhurt; uninjured; unharmed.</syn></p>

<p>--<wordforms><wf>Harm"less*ly</wf>, <pos>adv.</pos>-
<wf>Harm"less*ness</wf>, <pos>n.</pos></wordforms></p>

<p><ent>Harmonical</ent><br/
<ent>Harmonic</ent><br/
<mhw><hw>Har*mon"ic</hw> <pr>(h<aum/r*m<ocr/n"<icr/k)</pr>,
<hw>Har*mon"ic*al</hw> <pr>(-<icr/*k<ait/l)</pr></mhw>, <pos>a.</pos>
<ety>[L. <ets>harmonicus</ets>, Gr. <grk>"armoniko`s</grk>; cf. F.
<ets>harmonique</ets>. See <er>Harmony</er>.]</ety> <sn>1.</sn>
<def>Concordant; musical; consonant; <as>as, <ex>harmonic</ex>
sounds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Harmonic</qex> twang! of leather, horn, and brass.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Relating to harmony, -- as
<xex>melodic</xex> relates to melody; harmonious; esp., relating to the
accessory sounds or overtones which accompany the predominant and
apparent single tone of any string or sonorous body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>Having relations or properties
bearing some resemblance to those of musical consonances; -- said of
certain numbers, ratios, proportions, points, lines, motions, and the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harmonic interval</b></col> <fld>(Mus.)</fld>, <cd>the
distance between two notes of a chord, or two consonant notes.</cd> --
<col><b>Harmonical mean</b></col> <fld>(Arith. & Alg.)</fld>,
<cd>certain relations of numbers and quantities, which bear an analogy
to musical consonances.</cd> -- <col><b>Harmonic motion</b></col>, <--
reference to diagram of a circle with radius having point P on the
circle, and a diameter with point A in the diameter. The motion of point
A, plotted over time, will describe a sine wave! --> <cd>the motion of
the point A, of the foot of the perpendicular PA, when P moves uniformly
in the circumference of a circle, and PA is drawn perpendicularly upon a
fixed diameter of the circle. This is <xex>simple harmonic motion</xex>.
The combinations, in any way, of two or more simple harmonic motions,
make other kinds of harmonic motion. The motion of the pendulum bob of a
clock is approximately <xex>simple harmonic motion</xex>.</cd> --
<col><b>Harmonic proportion</b></col>. <cd>See under
<er>Proportion</er>.</cd> -- <mcol><col><b>Harmonic series</b></col>
<it>or</it> <col><b>Harmonic progression</b></col></mcol>. <cd>See under
<er>Progression</er>.</cd> -- <col><b>Spherical harmonic
analysis</b></col>, <cd>a mathematical method, sometimes referred to as
that of <altname>Laplace's Coefficients</altname>, which has for its
object the expression of an arbitrary, periodic function of two
independent variables, in the proper form for a large class of physical
problems, involving arbitrary data, over a spherical surface, and the
deduction of solutions for every point of space. The functions employed
in this method are called <xex>spherical harmonic functions</xex>.</cd>
<au>Thomson & Tait.</au> -- <col><b>Harmonic suture</b></col>
<fld>(Anat.)</fld>, <cd>an articulation by simple apposition of
comparatively smooth surfaces or edges, as between the two superior
maxillary bones in man; -- called also <altname>harmonia</altname>, and
<altname>harmony</altname>.</cd> -- <col><b>Harmonic triad</b></col>
<fld>(Mus.)</fld>, <cd>the chord of a note with its third and fifth; the
common chord.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonic</ent><br/
<hw>Har*mon"ic</hw> <pr>(h<aum/r*m<ocr/n"<icr/k)</pr>, <pos>n.</pos>
<fld>(Mus.)</fld> <def>A musical note produced by a number of vibrations
which is a multiple of the number producing some other; an overtone. See
<er>Harmonics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonica</ent><br/
<hw>Har*mon"i*ca</hw> <pr>(-<icr/*k<adot/)</pr>, <pos>n.</pos>
<ety>[Fem. fr. L. <ets>harmonicus</ets> harmonic. See <er>Harmonic</er>,
<pos>n.</pos> ]</ety> <sn>1.</sn> <def>A musical instrument, consisting
of a series of hemispherical glasses which, by touching the edges with
the dampened finger, give forth the tones; it is now called the
<altname>glass harmonica</altname>, to distinguish it from the common
harmonica, formerly called the harmonicon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A toy instrument of strips of glass or metal hung on
two tapes, and struck with hammers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A small wind musical instrument shaped like a flat
bar with holes along the thin edges, held in the hand and producing
notes from multiple vibrating reeds arranged inside along its length; it
was formerly called the <altname>harmonicon</altname>. See
<er>harmonicon</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Harmonically</ent><br/
<hw>Har*mon"ic*al*ly</hw> <pr>(-<icr/*k<ait/l*l<ycr/)</pr>,
<pos>adv.</pos> <sn>1.</sn> <def>In an harmonical manner;
harmoniously.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In respect to harmony, as distinguished from
<xex>melody</xex>; <as>as, a passage <ex>harmonically</ex>
correct</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>In harmonical
progression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonicon</ent><br/
<hw>Har*mon"i*con</hw> <pr>(-<icr/*k<ocr/n)</pr>, <pos>n.</pos> <def>A
small, flat, wind instrument of music, in which the notes are produced
by the vibration of free metallic reeds; it is now called the
<altname>harmonica</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Harmonics</ent><br/
<hw>Har*mon"ics</hw> <pr>(-<icr/ks)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The doctrine or science of musical sounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Mus.)</fld> <def>Secondary and
less distinct tones which accompany any principal, and apparently
simple, tone, as the octave, the twelfth, the fifteenth, and the
seventeenth. The name is also applied to the artificial tones produced
by a string or column of air, when the impulse given to it suffices only
to make a part of the string or column vibrate; overtones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonious</ent><br/
<hw>Har*mo"ni*ous</hw> <pr>(h<aum/r*m<omac/"n<icr/*<ucr/s)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>harmonieux</ets>. See
<er>Harmony</er>.]</ety> <sn>1.</sn> <def>Adapted to each other; having
parts proportioned to each other; symmetrical.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God hath made the intellectual world <qex>harmonious</qex> and
beautiful without us.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Acting together to a common end; agreeing in action
or feeling; living in peace and friendship; <as>as, an
<ex>harmonious</ex> family</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Vocally or musically concordant; agreeably
consonant; symphonious.</def></p>

<p>-- <wordforms><wf>Har*mo"ni*ous*ly</wf>, <pos>adv.</pos> --
<wf>Har*mo"ni*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmoniphon</ent><br/
<hw>Har*mon"i*phon</hw> <pr>(h<aum/r*m<ocr/n"<icr/*f<ocr/n)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"armoni`a</grk> harmony + <grk>fwnh`</grk>
sound.]</ety> <fld>(Mus.)</fld> <def>An obsolete wind instrument with a
keyboard, in which the sound, which resembled the oboe, was produced by
the vibration of thin metallic plates, acted upon by blowing through a
tube.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonist</ent><br/
<hw>Har"mo*nist</hw> <pr>(h<aum/r"m<osl/*n<icr/st)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>harmoniste</ets>.]</ety> <sn>1.</sn> <def>One who
shows the agreement or harmony of corresponding passages of different
authors, as of the four evangelists.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>One who understands the principles
of harmony or is skillful in applying them in composition; a musical
composer.</def></p>

<p><ent>Harmonite</ent><br/
<ent>Harmonist</ent><br/
<mhw>{ <hw>Har"mo*nist</hw>, <hw>Har"mo*nite</hw> <pr>(-n<imac/t)</pr>,
}</mhw> <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One of a religious
sect, founded in W<uum/rtemburg in the last century, composed of
followers of <person>George Rapp</person>, a weaver. They had all their
property in common. In 1803, a portion of this sect settled in
Pennsylvania and called the village thus established, Harmony.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonium</ent><br/
<hw>Har*mo"ni*um</hw> <pr>(h<aum/r*m<omac/"n<icr/*<ucr/m)</pr>,
<pos>n.</pos> <ety>[NL. See <er>Harmony</er>. ]</ety> <def>A musical
instrument, resembling a small organ and especially designed for church
music, in which the tones are produced by forcing air by means of a
bellows so as to cause the vibration of free metallic reeds. It is now
made with one or two keyboards, and has pedals and stops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>harmonizable</ent><br/
<hw>harmonizable</hw> <pos>adj.</pos> <def>capable of being made
harmonious or consistent.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harmonization</ent><br/
<hw>Har`mo*ni*za"tion</hw>
<pr>(h<aum/r`m<osl/*n<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The act of harmonizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonize</ent><br/
<hw>Har"mo*nize</hw> <pr>(h<aum/r"m<osl/*n<imac/z)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Harmonized</conjf>
<pr>(-n<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Harmonizing</conjf> <pr>(-n<imac/"z<icr/ng)</pr>.]</vmorph>
<ety>[Cf. F. <ets>harmoniser</ets>. ]</ety> <sn>1.</sn> <def>To agree in
action, adaptation, or effect on the mind; to agree in sense or purport;
<as>as, the parts of a mechanism <ex>harmonize</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be in peace and friendship, as individuals,
families, or public organizations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To agree in vocal or musical effect; to form a
concord; <as>as, the tones <ex>harmonize</ex> perfectly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonize</ent><br/
<hw>Har"mo*nize</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To adjust in fit
proportions; to cause to agree; to show the agreement of; to reconcile
the apparent contradiction of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>To accompany with harmony; to
provide with parts, as an air, or melody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonizer</ent><br/
<hw>Har"mo*ni`zer</hw> <pr>(-n<imac/`z<etil/r)</pr>, <pos>n.</pos>
<def>One who harmonizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmonometer</ent><br/
<hw>Har`mo*nom"e*ter</hw> <pr>(-n<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"armoni`a</grk> harmony + <ets>meter</ets>:
cf. F. <ets>harmonometre</ets>.]</ety> <def>An instrument for measuring
the harmonic relations of sounds. It is often a monochord furnished with
movable bridges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmony</ent><br/
<hw>Har"mo*ny</hw> <pr>(h<aum/r"m<osl/*n<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Harmonies</plw> <pr>(-n<icr/z)</pr>.</plu>
<ety>[F. <ets>harmonie</ets>, L. <ets>harmonia</ets>, Gr.
<grk>"armoni`a</grk> joint, proportion, concord, fr. <grk>"armo`s</grk>
a fitting or joining. See <er>Article</er>.]</ety> <sn>1.</sn> <def>The
just adaptation of parts to each other, in any system or combination of
things, or in things intended to form a connected whole; such an
agreement between the different parts of a design or composition as to
produce unity of effect; <as>as, the <ex>harmony</ex> of the
universe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Concord or agreement in facts, opinions, manners,
interests, etc.; good correspondence; peace and friendship; <as>as, good
citizens live in <ex>harmony</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A literary work which brings together or arranges
systematically parallel passages of historians respecting the same
events, and shows their agreement or consistency; <as>as, a
<ex>harmony</ex> of the Gospels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>A succession of
chords according to the rules of progression and modulation.</def>
<sd>(b)</sd> <def>The science which treats of their construction and
progression.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ten thousand harps, that tuned<br/
Angelic <qex>harmonies</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anat.)</fld> <def>See <cref>Harmonic suture</cref>,
under <er>Harmonic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Close harmony</b></col>, <col><b>Dispersed
harmony</b></col></mcol>, <cd>etc. See under <er>Close</er>,
<er>Dispersed</er>, etc.</cd> -- <col><b>Harmony of the
spheres</b></col>. <cd>See <cref>Music of the spheres</cref>, under
<er>Music</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- <er>Harmony</er>, <er>Melody</er>.</syn> <usage>
<xex>Harmony</xex> results from the concord of two or more strains or
sounds which differ in pitch and quality. <xex>Melody</xex> denotes the
pleasing alternation and variety of musical and measured sounds, as they
succeed each other in a single verse or strain.</usage><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 672 pr=JMD --></p>

<p><ent>Harmost</ent><br/
<hw>Har"most</hw> <pr>(h<aum/r"m<ocr/st)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"armosth`s</grk>, fr. <grk>"armo`zein</grk> to join, arrange,
command: cf. F. <ets>harmoste</ets>. See <er>Harmony</er>.]</ety>
<fld>(Gr. Antiq.)</fld> <def>A city governor or prefect appointed by the
Spartans in the cities subjugated by them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harmotome</ent><br/
<hw>Har"mo*tome</hw> <pr>(-m<osl/*t<omac/m)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"armo`s</grk> a joint + <grk>te`mnein</grk> to cut: cf.
F. <ets>harmotome</ets>.]</ety> <fld>(Min.)</fld> <def>A hydrous
silicate of alumina and baryta, occurring usually in white cruciform
crystals; cross-stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A related mineral, called <xex>lime harmotome</xex>, and
<xex>Phillipsite</xex>, contains lime in place of baryta.</note>
<rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harness</ent><br/
<hw>Har"ness</hw> <pr>(-n<ecr/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harneis</ets>, <ets>harnes</ets>, OF. <ets>harneis</ets>, F.
<ets>harnais</ets>, <ets>harnois</ets>; of Celtic origin; cf. Armor.
<ets>harnez</ets> old iron, armor, W. <ets>haiarn</ets> iron, Armor.
<ets>houarn</ets>, Ir. <ets>iarann</ets>, Gael. <ets>iarunn</ets>. Cf.
<er>Iron</er>.]</ety> <sn>1.</sn> <def>Originally, the complete dress,
especially in a military sense, of a man or a horse; hence, in general,
armor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At least we'll die with <qex>harness</qex> on our back.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The equipment of a draught or carriage horse, for
drawing a wagon, coach, chaise, etc.; gear; tackling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The part of a loom comprising the heddles, with
their means of support and motion, by which the threads of the warp are
alternately raised and depressed for the passage of the
shuttle.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To die in harness</b></col>, <cd>to die with armor on;
hence, colloquially, to die while actively engaged in work or
duty.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harness</ent><br/
<hw>Har"ness</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harnessed</conjf> <pr>(-n<ecr/st)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Harnessing</conjf>.]</vmorph> <ety>[OE.
<ets>harneisen</ets>; cf. F. <ets>harnacher</ets>, OF.
<ets>harneschier</ets>.]</ety> <sn>1.</sn> <def>To dress in armor; to
equip with armor for war, as a horseman; to array.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Harnessed</qex> in rugged steel.</q>
<rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A gay dagger,<br/
<qex>Harnessed</qex> well and sharp as point of spear.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To equip or furnish for defense.</def> <au>Dr.
H. More.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make ready for draught; to equip with harness, as
a horse. Also used figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Harnessed</qex> to some regular profession.</q> <rj><qau>J.
C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harnessed antelope</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Guib</er>.</cd> -- <col><b>Harnessed moth</b></col>
<fld>(Zool.)</fld>, <cd>an American bombycid moth (<spn>Arctia
phalerata</spn> of Harris), having, on the fore wings, stripes and bands
of buff on a black ground.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harness cask</ent><br/
<hw>Har"ness cask`</hw> <pr>(k<adot/sk`)</pr>. <fld>(Naut.)</fld> <def>A
tub lashed to a vessel's deck and containing salted provisions for daily
use; -- called also <altname>harness tub</altname>.</def> <rj><au>W. C.
Russell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harnesser</ent><br/
<hw>Har"ness*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
harnesses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harns</ent><br/
<hw>Harns</hw> <pr>(h<aum/rnz)</pr>, <pos>n. pl.</pos> <ety>[Akin to
Icel. <ets>hjarni</ets>, Dan. <ets>hierne</ets>.]</ety> <def>The
brains.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harp</ent><br/
<hw>Harp</hw> <pr>(h<aum/rp)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harpe</ets>, AS. <ets>hearpe</ets>; akin to D. <ets>harp</ets>, G.
<ets>harfe</ets>, OHG. <ets>harpha</ets>, Dan. <ets>harpe</ets>, Icel. &
Sw. <ets>harpa</ets>.]</ety> <sn>1.</sn> <def>A musical instrument
consisting of a triangular frame furnished with strings and sometimes
with pedals, held upright, and played with the fingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>A constellation;
<xex>Lyra</xex>, or the Lyre.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A grain sieve.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Aeolian harp</b></col>. <cd>See under
<er>Aeolian</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harp seal</b></col> <fld>(Zool.)</fld>, <cd>an arctic
seal (<spn>Phoca Gr<oe/nlandica</spn>). The adult males have a
light-colored body, with a harp-shaped mark of black on each side, and
the face and throat black. Called also <altname>saddler</altname>, and
<altname>saddleback</altname>. The immature ones are called
<altname>bluesides</altname>; their fur is white, and they are killed
and skinned to harvest the fur.</cd> -- <col><b>Harp shell</b></col>
<fld>(Zool.)</fld>, <cd>a beautiful marine gastropod shell of the genus
<gen>Harpa</gen>, of several species, found in tropical seas. See
<er>Harpa</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harp</ent><br/
<hw>Harp</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harped</conjf> <pr>(h<aum/rpt)</pr> <pos>p. pr. & vb. n.</pos>
<conjf>Harping</conjf>.]</vmorph> <ety>[AS. <ets>hearpian</ets>. See
<er>Harp</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To play on the
harp.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I heard the voice of harpers, <qex>harping</qex> with their
harps.</q> <rj><qau>Rev. xiv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dwell on or recur to a subject tediously or
monotonously in speaking or in writing; to refer to something repeatedly
or continually; -- usually with <xex>on</xex> or <xex>upon</xex>.</def>
<ldquo/<xex>Harpings</xex> upon old themes.<rdquo/ <rj><au>W.
Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Harping</qex> on what I am,<br/
Not what he knew I was.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To harp on one string</b></col>, <cd>to dwell upon one
subject with disagreeable or wearisome persistence.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harp</ent><br/
<hw>Harp</hw>, <pos>v. t.</pos> <def>To play on, as a harp; to play (a
tune) on the harp; to develop or give expression to by skill and art; to
sound forth as from a harp; to hit upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou 'st <qex>harped</qex> my fear aright.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpa</ent><br/
\'d8<hw>Har"pa</hw> <pr>(h<aum/r"p<adot/)</pr>, <pos>n.</pos> <ety>[L.,
harp.]</ety> <fld>(Zool.)</fld> <def>A genus of marine univalve shells;
the harp shells; -- so called from the form of the shells, and their
ornamental ribs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpagon</ent><br/
<hw>Har"pa*gon</hw> <pr>(-g<ocr/n)</pr>, <pos>n.</pos> <ety>[L.
<ets>harpago</ets>, Gr. <grk>"arpa`gh</grk> hook, rake.]</ety> <def>A
grappling iron.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harper</ent><br/
<hw>Harp"er</hw> <pr>(h<aum/rp"<etil/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hearpere</ets>.]</ety> <sn>1.</sn> <def>A player on the harp; a
minstrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The murmuring pines and the hemlocks . . . <br/
Stand like <qex>harpers</qex> hoar, with beards that rest on their
bosoms.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A brass coin bearing the emblem of a harp, --
formerly current in Ireland.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harping</ent><br/
<hw>Harp"ing</hw> <pr>(h<aum/rp"<icr/ng)</pr>, <pos>a.</pos>
<def>Pertaining to the harp; <as>as, <ex>harping</ex>
symphonies</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harping iron</ent><br/
<hw>Harp"ing i`ron</hw> <pr>(<imac/`<ucr/rn)</pr>. <ety>[F.
<ets>harper</ets> to grasp strongly. See <er>Harpoon</er>.]</ety> <def>A
harpoon.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpings</ent><br/
<hw>Harp"ings</hw> <pr>(-<icr/ngz)</pr>, <pos>n. pl.</pos>
<fld>(Naut.)</fld> <def>The fore parts of the wales, which encompass the
bow of a vessel, and are fastened to the stem.</def> <altsp>[Written
also <asp>harpins</asp>.]</altsp> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpist</ent><br/
<hw>Harp"ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>harpiste</ets>.]</ety> <def>A player on the harp; a harper.</def>
<rj><au>W. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpoon</ent><br/
<hw>Har*poon"</hw> <pr>(h<aum/r*p<oomac/n")</pr>, <pos>n.</pos> <ety>[F.
<ets>harpon</ets>, LL. <ets>harpo</ets>, perh. of Ger. origin, fr. the
<ets>harp</ets>; cf. F. <ets>harper</ets> to take and grasp strongly,
<ets>harpe</ets> a dog's claw, <ets>harpin</ets> boathook (the sense of
<ets>hook</ets> coming from the shape of the harp); but cf. also Gr.
<grk>"a`rph</grk> the kite, sickle, and E. <ets>harpy</ets>. Cf.
<er>Harp</er>.]</ety> <def>A spear or javelin used to strike and kill
large fish, as whales; a harping iron. It consists of a long shank, with
a broad, flat, triangular head, sharpened at both edges, and is thrown
by hand, or discharged from a gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harpoon fork</b></col>, <cd>a kind of hayfork, consisting
of a bar with hinged barbs at one end and a loop for a rope at the other
end, used for lifting hay from the load by horse power.</cd> --
<col><b>Harpoon gun</b></col>, <cd>a gun used in the whale fishery for
shooting the harpoon into a whale.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpoon</ent><br/
<hw>Har*poon"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harpooned</conjf> <pr>(-p<oomac/nd")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Harpooning</conjf>.]</vmorph> <def>To strike, catch, or
kill with a harpoon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpooneer</ent><br/
<hw>Har`poon*eer"</hw> <pr>(h<aum/r`p<oomac/n*<emac/r")</pr>,
<pos>n.</pos> <def>An harpooner.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpooner</ent><br/
<hw>Har*poon"er</hw> <pr>(h<aum/r*p<oomac/n"<etil/r)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>harponneur</ets>.]</ety> <def>One who throws the
harpoon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpress</ent><br/
<hw>Harp"ress</hw> <pr>(h<aum/rp"r<ecr/s)</pr>, <pos>n.</pos> <def>A
female harper.</def> <mark>[R.]</mark> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpsichon</ent><br/
<hw>Harp"si*chon</hw> <pr>(h<aum/rp"s<icr/*k<ocr/n)</pr>, <pos>n.</pos>
<def>A harpsichord.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harpsichord</ent><br/
<hw>Harp"si*chord</hw> <pr>(-k<ocir/rd)</pr>, <pos>n.</pos> <ety>[OF.
<ets>harpechorde</ets>, in which the <ets>harpe</ets> is of German
origin. See <er>Harp</er>, and <er>Chord</er>.]</ety> <fld>(Mus.)</fld>
<def>A harp-shaped instrument of music set horizontally on legs, like
the grand piano, with strings of wire, played by the fingers, by means
of keys provided with quills, instead of hammers, for striking the
strings. It is now superseded by the piano.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>harpsichordist</ent><br/
<hw>harpsichordist</hw> <pos>n.</pos> <def>someone who plays the
harpsichord.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>harpulla</ent><br/
<hw>harpulla</hw> <pos>n.</pos> <def>A fast-growing tree of India and
East Indies (<spn>Harpullia cupanioides</spn>) yielding a wood used
especially for building.</def><br/
<syn><b>Syn. --</b> <spn>Harpullia cupanioides</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>harpullia</ent><br/
<hw>harpullia</hw> <pos>n.</pos> <def>any of various tree of the genus
<gen>Harpullia</gen>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harpy</ent><br/
<hw>Har"py</hw> <pr>(h<aum/r"p<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Harpies</plw> <pr>(-p<icr/z)</pr>.</plu> <ety>[F.
<ets>harpie</ets>, L. <ets>harpyia</ets>, Gr. <grk>"a`rpyia</grk>, from
the root of <grk>"arpa`zein</grk> to snatch, to seize. Cf.
<er>Rapacious</er>.]</ety> <sn>1.</sn> <fld>(Gr. Myth.)</fld> <def>A
fabulous winged monster, ravenous and filthy, having the face of a woman
and the body of a vulture, with long claws, and the face pale with
hunger. Some writers mention two, others three.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both table and provisions vanished quite.<br/
With sound of <qex>harpies'</qex> wings and talons heard.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is rapacious or ravenous; an
extortioner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>harpies</qex> about all pocket the pool.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The European moor
buzzard or marsh harrier (<spn>Circus aeruginosus</spn>).</def>
<sd>(b)</sd> <def>A large and powerful, double-crested, short-winged
American eagle (<spn>Thrasa<eum/tus harpyia</spn>). It ranges from Texas
to Brazil.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harpy bat</b></col> <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>An East Indian fruit bat of the genus <gen>Harpyia</gen> (esp.
<spn>Harpyia cephalotes</spn>), having prominent, tubular nostrils.</cd>
<sd>(b)</sd> <cd>A small, insectivorous Indian bat (<spn>Harpiocephalus
harpia</spn>).</cd> -- <col><b>Harpy fly</b></col> <fld>(Zool.)</fld>,
<cd>the house fly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harquebuse</ent><br/
<ent>Harquebus</ent><br/
<mhw>{ <hw>Har"que*bus</hw> <hw>Har"que*buse</hw> }</mhw>
<pr>(h<aum/r"kw<esl/*b<ucr/s)</pr>, <pos>n.</pos> <ety>[See
<er>Arquebus</er>.]</ety> <def>A firearm with match holder, trigger, and
tumbler, made in the second half of the 15th century. The barrel was
about forty inches long. A form of the harquebus was subsequently called
<stype>arquebus with matchlock</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrage</ent><br/
<hw>Har"rage</hw> <pr>(h<acr/r"r<asl/j; 48)</pr> <pos>v. t.</pos>
<ety>[See <er>Harry</er>.]</ety> <def>To harass; to plunder from.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harre</ent><br/
<hw>Har"re</hw> <pr>(h<aum/r"r<eit/)</pr>, <pos>n.</pos> <ety>[OE., fr.
AS. <ets>heorr</ets>, <ets>h<iacute/or</ets>.]</ety> <def>A hinge.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harridan</ent><br/
<hw>Har"ri*dan</hw> <pr>(h<acr/r"r<icr/*d<ait/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>haridelle</ets> a worn-out horse, jade.]</ety> <def>A
worn-out strumpet; a vixenish woman; a hag.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a weak, watery, wicked old <qex>harridan</qex>, substituted
for the pretty creature I had been used to see.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>harried</ent><br/
<hw>harried</hw> <pos>adj.</pos> <def>same as
<er>harassed</er>.</def><br/
<syn><b>Syn. --</b> annoyed, harassed, pestered.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harrier</ent><br/
<hw>Har"ri*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <ety>[From
<er>Hare</er>, <pos>n.</pos>]</ety> <fld>(Zool.)</fld> <def>One of a
small breed of hounds, used for hunting hares.</def> <altsp>[Written
also <asp>harier</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrier</ent><br/
<hw>Har"ri*er</hw>, <pos>n.</pos> <ety>[From <er>Harry</er>.]</ety>
<sn>1.</sn> <def>One who harries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of several species of hawks
or buzzards of the genus <gen>Circus</gen> which fly low and
<xex>harry</xex> small animals or birds, -- as the European marsh
harrier (<spn>Circus aeruginosus</spn>), and the hen harrier
(<spn>Circus cyaneus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harrier hawk</b></col> <fld>(Zool.)</fld>, <cd>one of
several species of American hawks of the genus
<gen>Micrastur</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrisia</ent><br/
<hw>Harrisia</hw> <pos>prop. n.</pos> <fld>(Bot.)</fld> <def>A genus of
slender often treelike spiny cacti with solitary showy nocturnal white
or pink flowers; Florida and Caribbean to South America.</def><br/
<syn><b>Syn. --</b> genus <gen>Harrisia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harrow</ent><br/
<hw>Har"row</hw> <pr>(h<acr/r"r<osl/)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harowe</ets>, <ets>harwe</ets>, AS. <ets>hearge</ets>; cf. D.
<ets>hark</ets> rake, G. <ets>harke</ets>, Icel. <ets>herfi</ets>
harrow, Dan. <ets>harve</ets>, Sw. <ets>harf</ets>. <root/16.]</ety>
<sn>1.</sn> <def>An implement of agriculture, usually formed of pieces
of timber or metal crossing each other, and set with iron or wooden
teeth. It is drawn over plowed land to level it and break the clods, to
stir the soil and make it fine, or to cover seed when sown.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>An obstacle formed by turning an
ordinary harrow upside down, the frame being buried.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bush harrow</b></col>, <cd>a kind of light harrow made of
bushes, for harrowing grass lands and covering seeds, or to finish the
work of a toothed harrow.</cd> -- <col><b>Drill harrow</b></col>.
<cd>See under 6th <er>Drill</er>.</cd> -- <col><b>Under the
harrow</b></col>, <cd>subjected to actual torture with a toothed
instrument, or to great affliction or oppression.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrow</ent><br/
<hw>Har"row</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harrowed</conjf> <pr>(h<acr/r"r<osl/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Harrowing</conjf>.]</vmorph> <ety>[OE.
<ets>harowen</ets>, <ets>harwen</ets>; cf. Dan. <ets>harve</ets>. See
<er>Harrow</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To draw a harrow
over, as for the purpose of breaking clods and leveling the surface, or
for covering seed; <as>as, to <ex>harrow</ex> land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Will he <qex>harrow</qex> the valleys after thee?</q> <rj><qau>Job
xxxix. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break or tear, as with a harrow; to wound; to
lacerate; to torment or distress; to vex.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My aged muscles <qex>harrowed</qex> up with whips.</q>
<rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I could a tale unfold, whose lightest word<br/
Would <qex>harrow</qex> up thy soul.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrow</ent><br/
<hw>Har"row</hw>, <pos>interj.</pos> <ety>[OF. <ets>harau</ets>,
<ets>haro</ets>; fr. OHG. <ets>hara</ets>, <ets>hera</ets>,
<ets>herot</ets>, or fr. OS. <ets>herod</ets> hither, akin to E.
<ets>here</ets>.]</ety> <def>Help! Halloo! An exclamation of distress; a
call for succor; -- the ancient Norman hue and cry.</def>
<ldquo/<xex>Harrow</xex> and well away!<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Harrow</qex>! alas! here lies my fellow slain.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrow</ent><br/
<hw>Har"row</hw>, <pos>v. t.</pos> <ety>[See <er>Harry</er>.]</ety>
<def>To pillage; to harry; to oppress.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Meaning thereby to <qex>harrow</qex> his people.</q>
<rj><qau>Bacon</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrower</ent><br/
<hw>Har"row*er</hw> <pr>(h<acr/r"r<osl/*<etil/r)</pr>, <pos>n.</pos>
<def>One who harrows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harrower</ent><br/
<hw>Har"row*er</hw>, <pos>n.</pos> <def>One who harries.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harry</ent><br/
<hw>Har"ry</hw> <pr>(-r<ycr/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Harried</conjf> <pr>(-r<icr/d)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Harrying</conjf>.]</vmorph> <ety>[OE.
<ets>harwen</ets>, <ets>herien</ets>, <ets>her<yogh/ien</ets>, AS.
<ets>hergian</ets> to act as an army, to ravage, plunder, fr.
<ets>here</ets> army; akin to G. <ets>heer</ets>, Icel. <ets>herr</ets>,
Goth. <ets>harjis</ets>, and Lith. <ets>karas</ets> war. Cf.
<er>Harbor</er>, <er>Herald</er>, <er>Heriot</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To strip; to pillage; to lay waste; <as>as, the
Northmen came several times and <ex>harried</ex> the
land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>harry</qex> this beautiful region.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A red squirrel had <qex>harried</qex> the nest of a wood
thrush.</q> <rj><qau>J. Burroughs.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To agitate; to worry; to harrow; to harass.</def>
<rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- To ravage; plunder; pillage; lay waste; vex;
tease; worry; annoy; harass.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harry</ent><br/
<hw>Har"ry</hw>, <pos>v. i.</pos> <def>To make a predatory incursion; to
plunder or lay waste.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harry</ent><br/
<hw>Har"ry</hw> <pr>(h<acr/r"r<ycr/)</pr>, <pos>prop. n.</pos>
<def>Harold or Henry; a nickname.</def><br/
[<source>PJC</source>]</p>

<p><ent>Harsh</ent><br/
<hw>Harsh</hw> <pr>(h<aum/rsh)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Harsher</adjf>
<pr>(h<aum/rsh"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Harshest</adjf>.]</amorph> <ety>[OE. <ets>harsk</ets>; akin to G.
<ets>harsch</ets>, Dan. <ets>harsk</ets> rancid, Sw.
<ets>h<aum/rsk</ets>; from the same source as E. <ets>hard</ets>. See
<er>Hard</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>Rough;
disagreeable; grating</def>; <specif>esp.:</specif> <sd>(a)</sd>
<def>disagreeable to the touch.</def> <ldquo/<xex>Harsh</xex>
sand.<rdquo/ <au>Boyle.</au> <sd>(b)</sd> <def>disagreeable to the
taste.</def> <ldquo/Berries <xex>harsh</xex> and crude.<rdquo/
<au>Milton.</au> <sd>(c)</sd> <def>disagreeable to the ear.</def>
<ldquo/<xex>Harsh</xex> din.<rdquo/ <au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unpleasant and repulsive to the sensibilities;
austere; crabbed; morose; abusive; abusive; severe; rough.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Clarence is so <qex>harsh</qex>, so blunt.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Though <qex>harsh</qex> the precept, yet the preacher charmed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Painting, Drawing, etc.)</fld> <def>Having violent
contrasts of color, or of light and shade; lacking in harmony.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harshly</ent><br/
<hw>Harsh"ly</hw>, <pos>adv.</pos> <def>In a harsh manner; gratingly;
roughly; rudely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T will sound <qex>harshly</qex> in her ears.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harshness</ent><br/
<hw>Harsh"ness</hw>, <pos>n.</pos> <def>The quality or state of being
harsh.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, she is<br/
Ten times more gentle than her father's crabbed,<br/
And he's composed of <qex>harshness</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'Tis not enough no <qex>harshness</qex> gives offense,<br/
The sound must seem an echo to the sense.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- Acrimony; roughness; sternness; asperity;
tartness. See <er>Acrimony</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harslet</ent><br/
<hw>Hars"let</hw> <pr>(h<aum/rs"l<ecr/t)</pr>, <pos>n.</pos> <def>See
<er>Haslet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hart</ent><br/
<hw>Hart</hw> <pr>(h<aum/rt)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hart</ets>, <ets>hert</ets>, <ets>heort</ets>, AS.
<ets>heort</ets>, <ets>heorot</ets>; akin to D. <ets>hert</ets>, OHG.
<ets>hiruz</ets>, <ets>hirz</ets>, G. <ets>hirsch</ets>, Icel.
<ets>hj<oum/rtr</ets>, Dan. & Sw. <ets>hjort</ets>, L.
<ets>cervus</ets>, and prob. to Gr. <grk>kerao`s</grk> horned,
<grk>ke`ras</grk> horn. <root/230. See <er>Horn</er>.]</ety>
<fld>(Zool.)</fld> <def>A stag; the male of the red deer. See the Note
under <er>Buck</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Goodliest of all the forest, <qex>hart</qex> and hind.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hartebeest</ent><br/
<hw>hartebeest</hw> <pos>n.</pos> <sn>1.</sn> <def>large African
antelope with lyre-shaped horns that curve backward.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hartebeest</ent><br/
<ent>Hartbeest</ent><br/
<mhw><hw>Hart"beest`</hw>, <hw>Har"te*beest`</hw></mhw>
<pr>(-b<emac/st`)</pr>, <pos>n.</pos> <ety>[D. <ets>hertebeest</ets>.
See <er>Hart</er>, and <er>Beast</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A large South African antelope (<spn>Alcelaphus
caama</spn>), formerly much more abundant than it is now. The face and
legs are marked with black, the rump with white.</def> <altsp>[Written
also <asp>hartebeest</asp>, and <asp>hartebest</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any anteleope of the genus <gen>Alcelaphus</gen> and
certain species of <gen>Darnaliscus</gen>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Harten</ent><br/
<hw>Hart"en</hw> <pr>(-'n)</pr>, <pos>v. t.</pos> <def>To hearten; to
encourage; to incite.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hartford</ent><br/
<hw>Hart"ford</hw> <pr>(h<aum/rt"f<etil/rd)</pr>, <pos>n.</pos> <def>The
Hartford grape, a variety of grape first raised at <xex>Hartford</xex>,
Connecticut, from the Northern fox grape. Its large dark-colored berries
ripen earlier than those of most other kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hart's clover</ent><br/
<hw>Hart's" clo`ver</hw> <pr>(h<aum/rts" kl<omac/`v<etil/r)</pr>.
<fld>(Bot.)</fld> <def>Melilot or sweet clover. See
<er>Melilot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hart's-ear</ent><br/
<hw>Hart's"-ear`</hw> <pr>(-<emac/r`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>An Asiatic species of <gen>Cacalia</gen>
(<spn>Cacalia Kleinia</spn>), used medicinally in India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hartshorn</ent><br/
<hw>Harts"horn`</hw> <pr>(-h<ocir/rn`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The horn or antler of the hart, or male red deer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Spirits of hartshorn (see below); volatile
salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hartshorn plantain</b></col> <fld>(Bot.)</fld>, <cd>an
annual species of plantain (<spn>Plantago Coronopus</spn>); -- called
also <altname>buck's-horn</altname>.</cd> <au>Booth.</au> --
<col><b>Hartshorn shavings</b></col>, <cd>originally taken from the
horns of harts, are now obtained chiefly by planing down the bones of
calves. They afford a kind of jelly.</cd> <au>Hebert.</au> --
<col><b>Salt of hartshorn</b></col> <fld>(Chem.)</fld>, <cd>an impure
solid carbonate of ammonia, obtained by the destructive distillation of
hartshorn, or any kind of bone; volatile salts.</cd> <au>Brande &
C.</au>-- <col><b>Spirits of hartshorn</b></col> <fld>(Chem.)</fld>,
<cd>a solution of ammonia in water; -- so called because formerly
obtained from hartshorn shavings by destructive distillation. Similar
ammoniacal solutions from other sources have received the same
name.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 673 pr=JMD --></p>

<p><ent>Hart's-tongue</ent><br/
<hw>Hart's"-tongue`</hw> <pr>(h<aum/rts"t<ucr/ng`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>A common British fern
(<spn>Scolopendrium vulgare</spn>), rare in America.</def> <sd>(b)</sd>
<def>A West Indian fern, the <spn>Polypodium Phyllitidis</spn> of
Linnaeus. It is also found in Florida.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hartwort</ent><br/
<hw>Hart"wort`</hw> <pr>(h<aum/rt"w<ucir/rt`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A coarse umbelliferous plant of Europe
(<spn>Tordylium maximum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is often vaguely given to other plants of the
same order, as species of <gen>Seseli</gen> and
<gen>Bupleurum</gen>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harum-scarum</ent><br/
<hw>Har"um-scar"um</hw> <pr>(h<acir/r"<ucr/m*sk<acir/r"<ucr/m)</pr>,
<pos>a.</pos> <ety>[Cf. <ets>hare</ets>,<pos>v. t.</pos>, and
<ets>scare</ets>, <pos>v. t.</pos>]</ety> <def>Wild; giddy; flighty;
rash; thoughtless.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They had a quarrel with Sir Thomas Newcome's own son, a
<qex>harum-scarum</qex> lad.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haruspication</ent><br/
<hw>Ha*rus`pi*ca"tion</hw>
<pr>(h<adot/*r<ucr/s`p<icr/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>See <er>Haruspicy</er>.</def> <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haruspice</ent><br/
<hw>Ha*rus"pice</hw> <pr>(h<adot/*r<ucr/s"p<icr/s)</pr>, <pos>n.</pos>
<ety>[F., fr. L. <ets>haruspex</ets>.]</ety> <def>A diviner of ancient
Rome. Same as <er>Aruspice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haruspicy</ent><br/
<hw>Ha*rus"pi*cy</hw> <pr>(-p<icr/*s<ycr/)</pr>, <pos>n.</pos> <def>The
art or practices of haruspices. See <er>Aruspicy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvest</ent><br/
<hw>Har"vest</hw> <pr>(h<aum/r"v<ecr/st)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harvest</ets>, <ets>hervest</ets>, AS. <ets>h<ae/rfest</ets>
autumn; akin to LG. <ets>harfst</ets>, D. <ets>herfst</ets>, OHG.
<ets>herbist</ets>, G. <ets>herbst</ets>, and prob. to L.
<ets>carpere</ets> to pluck, Gr. <grk>karpo`s</grk> fruit. Cf.
<er>Carpet</er>.]</ety> <sn>1.</sn> <def>The gathering of a crop of any
kind; the ingathering of the crops; also, the season of gathering grain
and fruits, late summer or early autumn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seedtime and <qex>harvest</qex> . . . shall not cease.</q>
<rj><qau>Gen. viii. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At <qex>harvest</qex>, when corn is ripe.</q>
<rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is reaped or ready to be reaped or
gathered; a crop, as of grain (wheat, maize, etc.), or fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Put ye in the sickle, for the <qex>harvest</qex> is ripe.</q>
<rj><qau>Joel iii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To glean the broken ears after the man<br/
That the main <qex>harvest</qex> reaps.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The product or result of any exertion or labor;
gain; reward.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pope's principal <qex>harvest</qex> was in the jubilee.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>harvest</qex> of a quiet eye.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harvest fish</b></col> <fld>(Zool.)</fld>, <cd>a marine
fish of the Southern United States (<spn>Stromateus alepidotus</spn>);
-- called <altname>whiting</altname> in Virginia. Also applied to the
dollar fish.</cd> -- <col><b>Harvest fly</b></col> <fld>(Zool.)</fld>,
<cd>an hemipterous insect of the genus <gen>Cicada</gen>, often called
<altname>locust</altname>. See <er>Cicada</er>.</cd> -- <col><b>Harvest
lord</b></col>, <cd>the head reaper at a harvest.</cd>
<mark>[Obs.]</mark> <au>Tusser.</au> -- <col><b>Harvest mite</b></col>
<fld>(Zool.)</fld>, <cd>a minute European mite (<spn>Leptus
autumnalis</spn>), of a bright crimson color, which is troublesome by
penetrating the skin of man and domestic animals; -- called also
<altname>harvest louse</altname>, and <altname>harvest
bug</altname>.</cd> -- <col><b>Harvest moon</b></col>, <cd>the moon near
the full at the time of harvest in England, or about the autumnal
equinox, when, by reason of the small angle that is made by the moon's
orbit with the horizon, it rises nearly at the same hour for several
days.</cd> -- <col><b>Harvest mouse</b></col> <fld>(Zool.)</fld>, <cd>a
very small European field mouse (<spn>Mus minutus</spn>). It builds a
globular nest on the stems of wheat and other plants.</cd> --
<col><b>Harvest queen</b></col>, <cd>an image representing Ceres,
formerly carried about on the last day of harvest.</cd> <au>Milton.</au>
-- <col><b>Harvest spider</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Daddy longlegs</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvest</ent><br/
<hw>Har"vest</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Harvested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Harvesting</conjf>.]</vmorph> <def>To reap or gather, as any
crop.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvester</ent><br/
<hw>Har"vest*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who harvests; a machine for cutting and gathering grain; a
reaper.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A harvesting ant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvest-home</ent><br/
<hw>Har"vest-home"</hw> <pr>(-h<omac/m)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The gathering and bringing home of the harvest; the time of
harvest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Showed like a stubble land at <qex>harvest-home</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The song sung by reapers at the feast made at the
close of the harvest; the feast itself.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A service of thanksgiving, at harvest time, in the
Church of England and in the Protestant Episcopal Church in the United
States.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The opportunity of gathering treasure.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvesting</ent><br/
<hw>Har"vest*ing</hw>, <def><pos>a. & n.</pos>, from <er>Harvest</er>,
<pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Harvesting ant</b></col> <fld>(Zool.)</fld>, <cd>any
species of ant which gathers and stores up seeds for food. Many species
are known.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The species found in Southern Europe and Palestine are
<spn>Aphenogaster structor</spn> and <spn>Aphenogaster barbara</spn>;
that of Texas, called <stype>agricultural ant</stype>, is
<spn>Pogonomyrmex barbatus</spn> or <spn>Myrmica molifaciens</spn>; that
of Florida is <spn>Pogonomyrmex crudelis</spn>. See <cref>Agricultural
ant</cref>, under <er>Agricultural</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvestless</ent><br/
<hw>Har"vest*less</hw>, <pos>a.</pos> <def>Without harvest; lacking in
crops; barren.</def> <ldquo/<xex>Harvestless</xex> autumns.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>harvest-lice</ent><br/
<hw>harvest-lice</hw> <pos>n.</pos> <def>An erect perennial Old World
herb (<spn>Agrimonia eupatoria</spn>) of dry grassy habitats.</def><br/
<syn><b>Syn. --</b> <spn>Agrimonia eupatoria</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Harvestman</ent><br/
<hw>Har"vest*man</hw> <pr>(-m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Harvestmen</plw> <pr>(-m<eit/n)</pr>.</plu>
<sn>1.</sn> <def>A man engaged in harvesting.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>See <er>Daddy longlegs</er>,
1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvestry</ent><br/
<hw>Har"vest*ry</hw> <pr>(-r<ycr/)</pr>, <pos>n.</pos> <def>The act of
harvesting; also, that which is harvested.</def>
<rj><au>Swinburne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Harvey process</ent><br/
<hw>Har"vey proc"ess</hw> <pr>(?)</pr>. <fld>(Metal.)</fld> <def>A
process of hardening the face of steel, as armor plates, invented by
<person>Hayward A. <etsep>Harvey</etsep></person> of New Jersey,
consisting in the additional carburizing of the face of a piece of low
carbon steel by subjecting it to the action of carbon under
long-continued pressure at a very high heat, and then to a violent
chilling, as by a spray of cold water. This process gives an armor plate
a thick surface of extreme hardness supported by material gradually
decreasing in hardness to the unaltered soft steel at the
back.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hary</ent><br/
<hw>Har"y</hw> <pr>(h<acr/r"<ycr/)</pr>, <pos>v. t.</pos> <ety>[Cf. OF.
<ets>harier</ets> to harass, or E. <ets>harry</ets>, <pos>v.
t.</pos>]</ety> <def>To draw; to drag; to carry off by violence.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Has</ent><br/
<hw>Has</hw> <pr>(h<acr/z)</pr>, <def><pos>3d pers. sing. pres.</pos> of
<er>Have</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasard</ent><br/
<hw>Has"ard</hw> <pr>(-<etil/rd)</pr>, <pos>n.</pos> <def>Hazard.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hase</ent><br/
<hw>Hase</hw> <pr>(h<amac/z)</pr>, <pos>v. t.</pos> <mark>[Obs.]</mark>
<def>See <er>Haze</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hash</ent><br/
<hw>Hash</hw> <pr>(h<acr/sh)</pr>, <pos>n.</pos> <ety>[Formerly
<ets>hachey</ets>, <ets>hachee</ets>, F. <ets>hachis</ets>, fr.
<ets>hacher</ets> to hash; of German origin; cf. G. <ets>hippe</ets>
sickle, OHG. <ets>hippa</ets>, for <ets>happia</ets>. Cf.
<er>Hatchet</er>.]</ety> <sn>1.</sn> <def>That which is hashed or
chopped up; meat and vegetables, especially such as have been already
cooked, chopped into small pieces and mixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A new mixture of old matter; a second preparation or
exhibition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not bear elections, and still less the <qex>hash</qex> of
them over again in a first session.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hashish.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hash</ent><br/
<hw>Hash</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hashed</conjf> <pr>(h<acr/sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hashing</conjf>.]</vmorph> <ety>[From <er>Hash</er>,
<pos>n.</pos>: cf. F. <ets>hacher</ets> to hash.]</ety> <def>To chop
into small pieces; to mince and mix; <as>as, to <ex>hash</ex>
meat</as>.</def> <rj><au>Hudibras.</au></rj></p>

<p><ent>Hashish</ent><br/
<ent>Hasheesh</ent><br/
<mhw>{ <hw>Hash"eesh</hw> <hw>Hash"ish</hw> }</mhw>
<pr>(h<acr/sh"<emac/sh)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>hash<imac/sh</ets>.]</ety> <def>A slightly acrid gum resin produced
by the common hemp (<spn>Cannabis sativa</spn>), of the variety
<varn>Indica</varn>, when cultivated in a warm climate; also, the tops
of the plant, from which the resinous product is obtained. It is
narcotic, and has long been used in the East for its intoxicating
effect. The active psychoactive principle has been identified as
<part>tetrahydrocannabinol</part>. See <er>Bhang</er>, and
<er>Ganja</er>.</def><br/
<syn><b>Syn. --</b> hash.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hashmark</ent><br/
<hw>hash"mark`</hw> <pos>n.</pos> <fld>(Mil.)</fld> <def>an insignia
worn on the uniform to indicate years of service.</def><br/
<syn><b>Syn. --</b> service stripe, hash mark.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hask</ent><br/
<hw>Hask</hw> <pr>(h<acr/sk)</pr>, <pos>n.</pos> <ety>[See
<er>Hassock</er>.]</ety> <def>A basket made of rushes or flags, as for
carrying fish.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haslet</ent><br/
<hw>Has"let</hw> <pr>(h<acr/s"l<ecr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<acir/telettes</ets> broil, for <ets>hastelettes</ets>, fr. F.
<ets>haste</ets> spit; cf. L. <ets>hasta</ets> spear, and also OHG.
<ets>harst</ets> gridiron.]</ety> <def>The edible viscera, as the heart,
liver, etc., of a beast, esp. of a hog.</def> <altsp>[Written also
<asp>harslet</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasp</ent><br/
<hw>Hasp</hw> <pr>(h<adot/sp)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hasp</ets>, <ets>hesp</ets>, AS. <ets>h<ae/pse</ets>; akin to G.
<ets>haspe</ets>, <ets>h<aum/spe</ets>, Sw. & Dan. <ets>haspe</ets>,
Icel. <ets>hespa</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A clasp, especially a metal strap permanently fast
at one end to a staple or pin, while the other passes over a staple, and
is fastened by a padlock or a pin; also, a metallic hook for fastening a
door.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A spindle to wind yarn, thread, or silk
on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An instrument for cutting the surface of grass land;
a scarifier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasp</ent><br/
<hw>Hasp</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hasped</conjf> <pr>(h<adot/spt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hasping</conjf>.]</vmorph> <ety>[AS.
<ets>h<ae/psian</ets>.]</ety> <def>To shut or fasten with a
hasp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hassle</ent><br/
<hw>hassle</hw> <pos>n.</pos> <sn>1.</sn> <def>An inconvenience caused
by difficulties encountered trying to accomplish a task; <as>as, finding
a parking place in midtown is always a <ex>hassle</ex></as>.</def><br/
<syn><b>Syn. --</b> fuss, trouble, bother.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>disorderly fighting; an angry dispute or
disturbance.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> hassle, scuffle, tussle, rough-and-tumble.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hassle</ent><br/
<hw>hassle</hw> <pos>v. i.</pos> <sn>1.</sn> <def>to dispute or quarrel,
often over petty disagreements.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To expend excessive time and energy trying to
accomplish a task.</def><br/
[<source>PJC</source>]</p>

<p><ent>hassle</ent><br/
<hw>hassle</hw> <pos>v. t.</pos> <def>to repeatedly annoy; <as>as, He is
known to <ex>hassle</ex> his staff when he is overworked</as>.</def><br/
<syn><b>Syn. --</b> harass, harry, chivy, chivvy, chevy, chevvy, beset,
plague, molest, provoke.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hassock</ent><br/
<hw>Has"sock</hw> <pr>(h<acr/s"s<ucr/k)</pr>, <pos>n.</pos> <ety>[Scot.
<ets>hassock</ets>, <ets>hassik</ets>, a besom, anything bushy, a large,
round turf used as a seat, OE. <ets>hassok</ets> sedgy ground, W.
<ets>hesgog</ets> sedgy, <ets>hesg</ets> sedge, rushes; cf. Ir.
<ets>seisg</ets>, and E. <ets>sedge</ets>.]</ety> <sn>1.</sn> <def>A
rank tuft of bog grass; a tussock.</def> <rj><au>Forby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small stuffed cushion or footstool, for kneeling
on in church, or for home use.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And knees and <qex>hassocks</qex> are well nigh divorced.</q>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hast</ent><br/
<hw>Hast</hw> <pr>(h<acr/st)</pr>, <def><pos>2d pers. sing. pres.</pos>
of <er>Have</er>, contr. of <altname>havest</altname>.</def>
<mark>[Archaic]</mark></p>

<p><ent>Hastated</ent><br/
<ent>Hastate</ent><br/
<mhw>{ <hw>Has"tate</hw> <pr>(h<acr/s"t<asl/t)</pr>, <hw>Has"ta*ted</hw>
<pr>(h<amac/s"t<asl/*t<ecr/d)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>hastatus</ets>, fr. <ets>hasta</ets> spear. Cf. <er>Gad</er>,
<pos>n.</pos>]</ety> <def>Shaped like the head of a halberd; triangular,
with the basal angles or lobes spreading; <as>as, a <ex>hastate</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haste</ent><br/
<hw>Haste</hw> <pr>(h<amac/st)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hast</ets>; akin to D. <ets>haast</ets>, G., Dan., Sw., & OFries.
<ets>hast</ets>, cf. OF. <ets>haste</ets>, F. <ets>h<acir/te</ets> (of
German origin); all perh. fr. the root of E. <ets>hate</ets> in a
earlier sense of, to pursue. See <er>Hate</er>.]</ety> <sn>1.</sn>
<def>Celerity of motion; speed; swiftness; dispatch; expedition; --
applied only to voluntary beings, as men and other animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king's business required <qex>haste</qex>.</q> <rj><qau>1 Sam.
xxi. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being urged or pressed by business;
hurry; urgency; sudden excitement of feeling or passion; precipitance;
vehemence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I said in my <qex>haste</qex>, All men are liars.</q> <rj><qau>Ps.
cxvi. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To make haste</b></col>, <cd>to hasten.</cd></cs></p>

<p><syn><b>Syn.</b> -- Speed; quickness; nimbleness; swiftness;
expedition; dispatch; hurry; precipitance; vehemence;
precipitation.</syn> <usage> -- <er>Haste</er>, <er>Hurry</er>,
<er>Speed</er>, <er>Dispatch</er>. <xex>Haste</xex> denotes quickness of
action and a strong desire for getting on; <xex>hurry</xex> includes a
confusion and want of collected thought not implied in <xex>haste</xex>;
<xex>speed</xex> denotes the actual progress which is made;
<xex>dispatch</xex>, the promptitude and rapidity with which things are
done. A man may properly be in <xex>haste</xex>, but never in a
<xex>hurry</xex>. <xex>Speed</xex> usually secures
<xex>dispatch</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haste</ent><br/
<hw>Haste</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hasting</conjf>.]</vmorph> <ety>[OE. <ets>hasten</ets>; akin to
G. <ets>hasten</ets>, D. <ets>haasten</ets>, Dan. <ets>haste</ets>, Sw.
<ets>hasta</ets>, OF. <ets>haster</ets>, F. <ets>h<acir/ter</ets>. See
<er>Haste</er>, <pos>n.</pos>]</ety> <def>To hasten; to hurry.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll <qex>haste</qex> the writer.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They were troubled and <qex>hasted</qex> away.</q> <rj><qau>Ps.
xlviii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasten</ent><br/
<hw>Has"ten</hw> <pr>(h<amac/s"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hastened</conjf>
<pr>(h<amac/s"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hastening</conjf> <pr>(h<amac/s"'n*<icr/ng)</pr>.]</vmorph>
<def>To press; to drive or urge forward; to push on; to precipitate; to
accelerate the movement of; to expedite; to hurry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would <qex>hasten</qex> my escape from the windy storm.</q>
<rj><qau>Ps. lv. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasten</ent><br/
<hw>Has"ten</hw>, <pos>v. i.</pos> <def>To move with celerity; to be
rapid in motion; to act speedily or quickly; to go quickly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>hastened</qex> to the spot whence the noise came.</q>
<rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastener</ent><br/
<hw>Has"ten*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who hastens.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which hastens; especially, a stand or reflector
used for confining the heat of the fire to meat while roasting before
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastif</ent><br/
<hw>Has"tif</hw> <pr>(h<amac/s"t<icr/f)</pr>, <pos>a.</pos> <ety>[OF.
See <er>Hastive</er>.]</ety> <def>Hasty.</def> <mark>[Obs.]</mark>
<au>Chaucer.</au> -- <wordforms><wf>Has"tif*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastile</ent><br/
<hw>Has"tile</hw> <pr>(h<acr/s"t<imac/l <or/ -t<icr/l)</pr>,
<pos>a.</pos> <ety>[L. <ets>hasta</ets> a spear.]</ety>
<fld>(Bot.)</fld> <def>Same as <er>Hastate</er>.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastily</ent><br/
<hw>Has"ti*ly</hw> <pr>(h<amac/s"t<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<ety>[From <er>Hasty</er>.]</ety> <sn>1.</sn> <def>In haste; with speed
or quickness; speedily; nimbly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without due reflection; precipitately;
rashly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>hastily</qex> engaged in the war.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Passionately; impatiently.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastiness</ent><br/
<hw>Has"ti*ness</hw>, <pos>n.</pos> <def>The quality or state of being
hasty; haste; precipitation; rashness; quickness of temper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastings</ent><br/
<hw>Has"tings</hw> <pr>(-t<icr/ngz)</pr>, <pos>n. pl.</pos> <ety>[From
<er>Haste</er>, <pos>v.</pos>]</ety> <def>Early fruit or vegetables;
especially, early pease.</def> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastings sands</ent><br/
<hw>Has"tings sands`</hw> <pr>(s<acr/ndz`)</pr>. <fld>(Geol.)</fld>
<def>The lower group of the Wealden formation; -- so called from its
development around <etsep>Hastings</etsep>, in Sussex,
England.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hastive</ent><br/
<hw>Has"tive</hw> <pr>(-t<icr/v)</pr>, <pos>a.</pos> <ety>[OF.
<ets>hastif</ets>. See <er>Haste</er>, <pos>n.</pos>, and cf.
<er>Hastif</er>.]</ety> <def>Forward; early; -- said of fruits.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasty</ent><br/
<hw>Has"ty</hw> <pr>(h<amac/s"t<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Hastier</adjf>
<pr>(-t<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Hastiest</adjf>.]</amorph> <ety>[Akin to D. <ets>haastig</ets>,
G., Sw., & Dan. <ets>hastig</ets>. See <er>Haste</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Involving haste; done, made, etc.,
in haste; <as>as, a <ex>hasty</ex> retreat; a <ex>hasty</ex>
sketch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Demanding haste or immediate action.</def>
<mark>[R.]</mark> <au>Chaucer.</au> <ldquo/<xex>Hasty</xex>
employment.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Moving or acting with haste or in a hurry; hurrying;
hence, acting without deliberation; precipitate; rash; easily excited;
eager.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seest thou a man that is <qex>hasty</qex> in his words? There is
more hope of a fool than of him.</q> <rj><qau>Prov. xxix.
20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hasty</qex> multitude<br/
Admiring entered.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not <qex>hasty</qex> to go out of his sight.</q> <rj><qau>Eccl.
viii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Made or reached without deliberation or due caution;
<as>as, a <ex>hasty</ex> conjecture, inference, conclusion, etc., a
<ex>hasty</ex> resolution.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Proceeding from, or indicating, a quick
temper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Take no unkindness of his <qex>hasty</qex> words.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Forward; early; first ripe.</def>
<mark>[Obs.]</mark> <ldquo/As the <xex>hasty</xex> fruit before the
summer.<rdquo/ <rj><au>Is. xxviii. 4.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hasty pudding</ent><br/
<hw>Has"ty pud"ding</hw> <pr>(h<amac/s"t<ycr/ p<usdot/d"d<icr/ng)</pr>.
<sn>1.</sn> <def>A thick batter pudding made of Indian meal stirred into
boiling water; mush.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A batter or pudding made of flour or oatmeal,
stirred into boiling water or milk.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hat</ent><br/
<hw>Hat</hw> <pr>(h<aum/t)</pr>, <pos>a.</pos> <def>Hot.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hat</ent><br/
<hw>Hat</hw>, <def><pos>sing. pres.</pos> of <er>Hote</er> to be called.
Cf.</def> <er>Hatte</er>. <mark>[Obs.]</mark> <ldquo/That one
<xex>hat</xex> abstinence.<rdquo/ <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hat</ent><br/
<hw>Hat</hw> <pr>(h<acr/t)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<ae/t</ets>, <ets>h<ae/tt</ets>; akin to Dan. <ets>hat</ets>, Sw.
<ets>hatt</ets>, Icel. <ets>hattr</ets> a hat, <ets>h<oum/ttr</ets>
hood, D. <ets>hoed</ets> hat, G. <ets>hut</ets>, OHG. <ets>huot</ets>,
and prob. to L. <ets>cassis</ets> helmet. <root/13. Cf.
<er>Hood</er>.]</ety> <def>A covering for the head; esp., one with a
crown and brim, made of various materials, and worn by men or women for
protecting the head from the sun or weather, or for ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hat block</b></col>, <cd>a block on which hats are formed
or dressed.</cd> -- <col><b>To pass around the hat</b></col>, <cd>to
take up a collection of voluntary contributions, which are often
received in a hat.</cd> <mark>[Colloq.]</mark>
<rj><au>Lowell.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatable</ent><br/
<hw>Hat"a*ble</hw> <pr>(h<amac/t"<adot/*b'l)</pr>, <pos>a.</pos>
<ety>[From <er>Hate</er>.]</ety> <def>Capable of being, or deserving to
be, hated; odious; detestable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatband</ent><br/
<hw>Hat"band`</hw> <pr>(h<acr/t"b<acr/nd`)</pr>, <pos>n.</pos> <def>A
band round the crown of a hat; sometimes, a band of black cloth, crape,
etc., worn as a badge of mourning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatbox</ent><br/
<hw>Hat"box`</hw> <pr>(-b<ocr/ks`)</pr>, <pos>n.</pos> <def>A box for a
hat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch</ent><br/
<hw>Hatch</hw> <pr>(h<acr/ch)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Hatched</conjf> <pr>(h<acr/cht)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Hatching</conjf>.]</vmorph> <ety>[F.
<ets>hacher</ets> to chop, hack. See <er>Hash</er>.]</ety> <sn>1.</sn>
<def>To cross with lines in a peculiar manner in drawing and engraving.
See <er>Hatching</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall win this sword, silvered and <qex>hatched</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those <qex>hatching</qex> strokes of the pencil.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cross; to spot; to stain; to steep.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His weapon <qex>hatched</qex> in blood.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch</ent><br/
<hw>Hatch</hw>, <pos>v. t.</pos> <ety>[OE. <ets>hacchen</ets>,
<ets>hetchen</ets>; akin to G. <ets>hecken</ets>, Dan. <ets>hekke</ets>;
cf. MHG. <ets>hagen</ets> bull; perh. akin to E. <ets>hatch</ets> a half
door, and originally meaning, to produce under a hatch. <root/12.]</ety>
<sn>1.</sn> <def>To produce, as young, from an egg or eggs by
incubation, or by artificial heat; to produce young from (eggs); <as>as,
the young when <ex>hatched</ex></as>.</def> <rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As the partridge sitteth on eggs, and <qex>hatcheth</qex> them
not.</q> <rj><qau>Jer. xvii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For the hens do not sit upon the eggs; but by keeping them in a
certain equal heat they [the husbandmen] bring life into them and
<qex>hatch</qex> them.</q> <rj><qau>Robynson (More's
Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To contrive or plot; to form by meditation, and
bring into being; to originate and produce; to concoct; <as>as, to
<ex>hatch</ex> mischief; to <ex>hatch</ex> heresy.</as></def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fancies <qex>hatched</qex><br/
In silken-folded idleness.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch</ent><br/
<hw>Hatch</hw>, <pos>v. i.</pos> <def>To produce young; -- said of eggs;
to come forth from the egg; -- said of the young of birds, fishes,
insects, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch</ent><br/
<hw>Hatch</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
hatching.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Development; disclosure; discovery.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The chickens produced at once or by one incubation;
a brood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch</ent><br/
<hw>Hatch</hw>, <pos>n.</pos> <ety>[OE. <ets>hacche</ets>, AS.
<ets>h<ae/c</ets>, cf. <ets>haca</ets> the bar of a door, D.
<ets>hek</ets> gate, Sw. <ets>h<aum/ck</ets> coop, rack, Dan.
<ets>hekke</ets> manger, rack. Prob. akin to E. <ets>hook</ets>, and
first used of something made of pieces fastened together. Cf.
<er>Heck</er>, <er>Hack</er> a frame.]</ety> <sn>1.</sn> <def>A door
with an opening over it; a half door, sometimes set with spikes on the
upper edge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In at the window, or else o'er the <qex>hatch</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A frame or weir in a river, for catching
fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A flood gate; a sluice gate.</def>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A bedstead.</def> <mark>[Scot.]</mark> <rj><au>Sir
W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An opening in the deck of a vessel or floor of a
warehouse which serves as a passageway or hoistway; a hatchway; also; a
cover or door, or one of the covers used in closing such an
opening.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mining)</fld> <def>An opening into, or in search
of, a mine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Booby hatch</b></col>, <col><b>Buttery
hatch</b></col>, <col><b>Companion hatch</b></col>, etc.</mcol> <cd>See
under <er>Booby</er>, <er>Buttery</er>, etc.</cd> -- <col><b>To batten
down the hatches</b></col> <fld>(Naut.)</fld>, <cd>to lay tarpaulins
over them, and secure them with battens.</cd> -- <col><b>To be under
hatches</b></col>, <cd>to be confined below in a vessel; to be under
arrest, or in slavery, distress, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch</ent><br/
<hw>Hatch</hw>, <pos>v. t.</pos> <def>To close with a hatch or
hatches.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T were not amiss to keep our door <qex>hatched</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatch-boat</ent><br/
<hw>Hatch"-boat`</hw> <pr>(h<acr/ch"b<omac/t`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>A vessel whose deck consists almost wholly of
movable hatches; -- used mostly in the fisheries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hatched</ent><br/
<hw>hatched</hw> <pos>adj.</pos> <ety>[<pos>p. p.</pos> from
<er>hatch</er>, <pos>v. i.</pos>]</ety> <def>produced from an
egg.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hatchel</ent><br/
<hw>Hatch"el</hw> <pr>(-<ecr/l; 277)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hechele</ets>, <ets>hekele</ets>; akin to D. <ets>hekel</ets>, G.
<ets>hechel</ets>, Dan. <ets>hegle</ets>, Sw. <ets>h<aum/kla</ets>, and
prob. to E. <ets>hook</ets>. See <er>Hook</er>, and cf. <er>Hackle</er>,
<er>Heckle</er>.]</ety> <def>An instrument with long iron teeth set in a
board, for cleansing flax or hemp from the tow, hards, or coarse part; a
kind of large comb; -- called also <altname>hackle</altname> and
<altname>heckle</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatchel</ent><br/
<hw>Hatch"el</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hatcheled</conjf> or <conjf>Hatchelled</conjf>
<pr>(-<ecr/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hatcheling</conjf> or <conjf>Hatchelling</conjf>.]</vmorph>
<ety>[OE. <ets>hechelen</ets>, <ets>hekelen</ets>; akin to D.
<ets>hekelen</ets>, G. <ets>hecheln</ets>, Dan. <ets>hegle</ets>, Sw.
<ets>h<aum/kla</ets>. See <er>Hatchel</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To draw through the teeth of a hatchel, as flax or
hemp, so as to separate the coarse and refuse parts from the fine,
fibrous parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tease; to worry; to torment.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatcheler</ent><br/
<hw>Hatch"el*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
uses a hatchel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatcher</ent><br/
<hw>Hatch"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who hatches, or that which hatches; a hatching apparatus; an
incubator.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who contrives or originates; a
plotter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A great <qex>hatcher</qex> and breeder of business.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatchery</ent><br/
<hw>Hatch"er*y</hw> <pr>(-<ycr/)</pr>, <pos>n.</pos> <def>A house for
hatching fish, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatchet</ent><br/
<hw>Hatch"et</hw> <pr>(-<ecr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>hachette</ets>, dim. of <ets>hache</ets> ax. See 1st
<er>Hatch</er>, <er>Hash</er>.]</ety> <sn>1.</sn> <def>A small ax with a
short handle, to be used with one hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, a tomahawk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Buried was the bloody <qex>hatchet</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 674 pr=JMD --></p>

<p><cs><col><b>hatchet face</b></col>, <cd>a thin, sharp face, like the
edge of a hatchet</cd>; hence: <col><b>hatchet-faced</b></col>,
<cd>sharp-visaged.</cd> <au>Dryden.</au> -- <col><b>To bury the
hatchet</b></col>, <cd>to make peace or become reconciled.</cd> --
<col><b>To take up the hatchet</b></col>, <cd>to make or declare war.
The last two phrases are derived from the practice of the American
Indians.</cd></cs></p>

<p><ent>hatchet man</ent><br/
<hw>hatchet man</hw> <pos>n.</pos> <sn>1.</sn> <def>A person hired to
murder or physically attack another; a hit man.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A person who deliberately tries to ruin the
reputation of another, often unscrupulously, by slander or other
malicious communication, often with a political motive, and sometimes
for pay.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hatchettite</ent><br/
<ent>Hatchettine</ent><br/
<mhw>{ <hw>Hatch"et*tine</hw> <pr>(h<acr/ch"<ecr/t*t<icr/n)</pr>,
<hw>Hatch"et*tite</hw> <pr>(-t<icr/t)</pr>, }</mhw> <pos>n.</pos>
<ety>[Named after the discoverer, <person>Charles
<etsep>Hatchett</etsep></person>.]</ety> <fld>(Min.)</fld> <def>Mineral
tallow; a waxy or spermaceti-like substance, commonly of a greenish
yellow color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatching</ent><br/
<hw>Hatch"ing</hw>, <pos>n.</pos> <ety>[See 1st <er>Hatch</er>.]</ety>
<def>A mode of execution in engraving, drawing, and miniature painting,
in which shading is produced by lines crossing each other at angles more
or less acute; -- called also
<altname>crosshatching</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatchment</ent><br/
<hw>Hatch"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <ety>[Corrupt.
fr. <ets>achievement</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Her.)</fld> <def>A sort of panel, upon which the
arms of a deceased person are temporarily displayed, -- usually on the
walls of his dwelling. It is lozenge-shaped or square, but is hung
cornerwise. It is used in England as a means of giving public
notification of the death of the deceased, his or her rank, whether
married, widower, widow, etc. Called also
<altname>achievement</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His obscure funeral;<br/
No trophy, sword, or <qex>hatchment</qex> o'er his bones.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sword or other mark of the profession of arms; in
general, a mark of dignity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let there be deducted, out of our main potation,<br/
Five marks in <qex>hatchments</qex> to adorn this thigh.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatchure</ent><br/
<hw>Hatch"ure</hw> <pr>(-<usl/r; 135)</pr>, <pos>n.</pos> <def>Same as
<er>Hachure</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatchway</ent><br/
<hw>Hatch"way`</hw> <pr>(-w<amac/`)</pr>, <pos>n.</pos> <def>A square or
oblong opening in a deck or floor, affording passage from one deck or
story to another; the entrance to a cellar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hate</ent><br/
<hw>Hate</hw> <pr>(h<amac/t)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hating</conjf>.]</vmorph> <ety>[OE. <ets>haten</ets>,
<ets>hatien</ets>, AS. <ets>hatian</ets>; akin to OS. <ets>hatan</ets>,
<ets>hat<omac/n</ets> to be hostile to, D. <ets>haten</ets> to hate,
OHG. <ets>hazz<emac/n</ets>, <ets>hazz<omac/n</ets>, G.
<ets>hassen</ets>, Icel. & Sw. <ets>hata</ets>, Dan. <ets>hade</ets>,
Goth. <ets>hatan</ets>, <ets>hatjan</ets>. <root/36. Cf. <er>Hate</er>,
<pos>n.</pos>, <er>Heinous</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To have a great aversion to, with a strong desire
that evil should befall the person toward whom the feeling is directed;
to dislike intensely; to detest; <as>as, to <ex>hate</ex> one's enemies;
to <ex>hate</ex> hypocrisy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whosoever <qex>hateth</qex> his brother is a murderer.</q>
<rj><qau>1 John iii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be very unwilling; followed by an infinitive, or
a substantive clause with <xex>that</xex>; <as>as, to <ex>hate</ex> to
get into debt; to <ex>hate</ex> that anything should be
wasted.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>hate</qex> that he should linger here.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Script.)</fld> <def>To love less, relatively.</def>
<rj><au>Luke xiv. 26.</au></rj></p>

<p><syn><b>Syn.</b> -- To <er>Hate</er>, <er>Abhor</er>,
<er>Detest</er>, <er>Abominate</er>, <er>Loathe</er>.</syn> <usage>
<xex>Hate</xex> is the generic word, and implies that one is inflamed
with extreme dislike. We <xex>abhor</xex> what is deeply repugnant to
our sensibilities or feelings. We <xex>detest</xex> what contradicts so
utterly our principles and moral sentiments that we feel bound to lift
up our voice against it. What we <xex>abominate</xex> does equal
violence to our moral and religious sentiments. What we
<xex>loathe</xex> is offensive to our own nature, and excites unmingled
disgust. Our Savior is said to have <xex>hated</xex> the deeds of the
Nicolaitanes; his language shows that he <xex>loathed</xex> the
lukewarmness of the Laodiceans; he <xex>detested</xex> the hypocrisy of
the scribes and Pharisees; he <xex>abhorred</xex> the suggestions of the
tempter in the wilderness.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hate</ent><br/
<hw>Hate</hw>, <pos>n.</pos> <ety>[OE. <ets>hate</ets>, <ets>hete</ets>,
AS. <ets>hete</ets>; akin to D. <ets>haat</ets>, G. <ets>hass</ets>,
Icel. <ets>hatr</ets>, SW. <ets>hat</ets>, Dan. <ets>had</ets>, Goth.
<ets>hatis</ets>. Cf. <er>Hate</er>, <pos>v.</pos>]</ety> <def>Strong
aversion coupled with desire that evil should befall the person toward
whom the feeling is directed; as exercised toward things, intense
dislike; hatred; detestation; -- opposed to <xex>love</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For in a wink the false love turns to <qex>hate</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hateful</ent><br/
<hw>Hate"ful</hw> <pr>(-f<usdot/l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Manifesting hate or hatred; malignant; malevolent.</def>
<mark>[Archaic or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And worse than death, to view with <qex>hateful</qex> eyes<br/
His rival's conquest.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exciting or deserving great dislike, aversion, or
disgust; odious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unhappy, wretched, <qex>hateful</qex> day!</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Odious; detestable; abominable; execrable;
loathsome; abhorrent; repugnant; malevolent.</syn></p>

<p>-- <wordforms><wf>Hate"ful*ly</wf>, <pos>adv.</pos> --
<wf>Hate"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatel</ent><br/
<hw>Hat"el</hw> <pr>(h<amac/t"<ecr/l)</pr>, <pos>a.</pos> <def>Hateful;
detestable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hatemonger</ent><br/
<hw>hatemonger</hw> <pos>n.</pos> <def>one who arouses hatred for others
by speech or writing.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hater</ent><br/
<hw>Hat"er</hw> <pr>(h<amac/t"<etil/r)</pr>, <pos>n.</pos> <def>One who
hates.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An enemy to God, and a <qex>hater</qex> of all good.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hath</ent><br/
<hw>Hath</hw> <pr>(h<acr/th)</pr>, <pos>v., 3d pers. sing. pres.</pos>
<mord>of <er>Have</er>, contracted from <xex>haveth</xex></mord>.
<def>Has.</def> <mark>[Archaic.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>hath</qex> God wrought?</q> <rj><qau>Samuel F. B. Morse
[The first message sent by telegraph, from Mr. Morse, at the chamber of
the Supreme Court (then in the United States Capitol) to his assistant
Albert Vail at the Mount Clair Depot in Baltimore in 1844. Mr. Morse
allowed Annie Ellsworth, the daughter of a friend, to choose the words,
which she took from Numbers xxiii. 23.]</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>Hatiora</ent><br/
<hw>Hatiora</hw> <pos>n.</pos> <def>A small genus of South American
epiphytic or lithophytic cacti.</def><br/
<syn><b>Syn. --</b> genus <gen>Hatiora</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hatless</ent><br/
<hw>Hat"less</hw> <pr>(h<acr/t"l<ecr/s)</pr>, <pos>a.</pos> <def>Having
no hat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hatpin</ent><br/
<hw>hatpin</hw> <pos>n.</pos> <def>a long sturdy pin used by women to
secure a hat to their hair.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hatrack</ent><br/
<hw>Hat"rack`</hw> <pr>(h<acr/t"r<acr/k`)</pr>, <pos>n.</pos> <def>A
hatstand; hattree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatred</ent><br/
<hw>Ha"tred</hw> <pr>(h<amac/"tr<ecr/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hatred</ets>, <ets>hatreden</ets>. See <er>Hate</er>, and cf.
<er>Kindred</er>.]</ety> <def>Strong aversion; intense dislike; hate; an
affection of the mind awakened by something regarded as evil.</def></p>

<p><syn><b>Syn.</b> -- Odium; ill will; enmity; hate; animosity;
malevolence; rancor; malignity; detestation; loathing; abhorrence;
repugnance; antipathy. See <er>Odium</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatstand</ent><br/
<hw>Hat"stand`</hw> <pr>(h<acr/t"st<acr/nd`)</pr>, <pos>n.</pos> <def>A
stand of wood or iron, with hooks or pegs upon which to hang hats,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatte</ent><br/
<hw>Hat"te</hw> <pr>(h<aum/t"t<eit/)</pr>, <def><pos>pres. & imp. sing.
& pl.</pos> of <er>Hote</er>, to be called. See <er>Hote</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A full perilous place, purgatory it <qex>hatte</qex>.</q>
<rj><qau>Piers Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatted</ent><br/
<hw>Hat"ted</hw> <pr>(h<acr/t"t<ecr/d)</pr>, <pos>a.</pos> <def>Covered
with a hat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatter</ent><br/
<hw>Hat"ter</hw> <pr>(-t<etil/r)</pr>, <pos>v. t.</pos> <ety>[Prov. E.,
to entangle; cf. LG. ver<ets>haddern</ets>, ver<ets>heddern</ets>,
ver<ets>hiddern</ets>.]</ety> <def>To tire or worry; -- with
<xex>out</xex>.</def> <mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatter</ent><br/
<hw>Hat"ter</hw>, <pos>n.</pos> <def>One who makes or sells
hats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatteria</ent><br/
\'d8<hw>Hat*te"ri*a</hw> <pr>(h<acr/t*t<emac/"r<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A New Zealand
lizard, which, in anatomical character, differs widely from all other
existing lizards. It is the only living representative of the order
<ord>Rhynchocephala</ord>, of which many Mesozoic fossil species are
known; -- called also <altname>Sphenodon</altname>,
<altname>tuatara</altname>, and <altname>Tuatera</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatting</ent><br/
<hw>Hat"ting</hw> <pr>(h<acr/t"t<icr/ng)</pr>, <pos>n.</pos> <def>The
business of making hats; also, stuff for hats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hatti-sherif</ent><br/
\'d8<hw>Hat"ti-sher`if</hw> <pr>(h<acr/t"t<icr/*sh<ecr/r`<icr/f <or/
h<aum/t"t<emac/*sh<asl/*r<emac/f")</pr>, <pos>n.</pos> <ety>[Turk., fr.
Ar. <ets>khatt</ets> a writing + <ets>sher<imac/f</ets> noble.]</ety>
<def>A irrevocable Turkish decree countersigned by the sultan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hattree</ent><br/
<hw>Hat"tree`</hw> <pr>(h<acr/t"tr<emac/`)</pr>, <pos>n.</pos> <def>A
hatstand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haubergeon</ent><br/
<hw>Hau*ber"ge*on</hw> <pr>(h<add/*b<etil/r"j<esl/*<ocr/n)</pr>,
<pos>n.</pos> <def>See <er>Habergeon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hauberk</ent><br/
<hw>Hau"berk</hw> <pr>(h<add/"b<etil/rk)</pr>, <pos>n.</pos> <ety>[OF.
<ets>hauberc</ets>, <ets>halberc</ets>, F. <ets>haubert</ets>, OHG.
<ets>halsberc</ets>; <ets>hals</ets> neck + <ets>bergan</ets> to
protect, G. <ets>bergen</ets>; akin to AS. <ets>healsbeorg</ets>, Icel.
<ets>h<amac/lsbj<oum/rg</ets>. See <er>Collar</er>, and <er>Bury</er>,
<pos>v. t.</pos>]</ety> <def>A coat of mail; especially, the long coat
of mail of the European Middle Ages, as contrasted with the habergeon,
which is shorter and sometimes sleeveless. By old writers it is often
used synonymously with <xex>habergeon</xex>. See
<er>Habergeon</er>.</def> <altsp>[Written variously <asp>hauberg</asp>,
<asp>hauberque</asp>, <asp>hawberk</asp>, etc.]</altsp>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Helm, nor <qex>hawberk's</qex> twisted mail.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hauerite</ent><br/
<hw>Hau"er*ite</hw> <pr>(h<add/"<etil/r*<imac/t)</pr>, <pos>n.</pos>
<ety>[Named after <person>Von <ets>Hauer</ets></person>, of
Vienna.]</ety> <fld>(Min.)</fld> <def>Native sulphide of manganese, a
reddish brown or brownish black mineral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haugh</ent><br/
<hw>Haugh</hw> <pr>(h<add/)</pr>, <pos>n.</pos> <ety>[See <er>Haw</er> a
hedge.]</ety> <def>A low-lying meadow by the side of a river.</def>
<mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>On a <qex>haugh</qex> or level plain, near to a royal borough.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haught</ent><br/
<hw>Haught</hw> <pr>(h<add/t)</pr>, <pos>a.</pos> <ety>[See
<er>Haughty</er>.]</ety> <def>High; elevated; hence, haughty;
proud.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haughtily</ent><br/
<hw>Haugh"ti*ly</hw> <pr>(h<add/"t<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<ety>[From <er>Haughty</er>.]</ety> <def>In a haughty manner;
arrogantly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haughtiness</ent><br/
<hw>Haugh"ti*ness</hw>, <pos>n.</pos> <ety>[For <ets>hauteinness</ets>.
See <er>Haughty</er>.]</ety> <def>The quality of being haughty; disdain;
arrogance.</def></p>

<p><syn><b>Syn.</b> -- Arrogance; disdain; contemptuousness;
superciliousness; loftiness.</syn> <usage> -- <er>Haughtiness</er>,
<er>Arrogance</er>, <er>Disdain</er>. <xex>Haughtiness</xex> denotes the
expression of conscious and proud superiority; <xex>arrogance</xex> is a
disposition to claim for one's self more than is justly due, and enforce
it to the utmost; <xex>disdain</xex> in the exact reverse of
condescension toward inferiors, since it expresses and desires others to
feel how far below ourselves we consider them. A person is
<xex>haughty</xex> in disposition and demeanor; <xex>arrogant</xex> in
his claims of homage and deference; <xex>disdainful</xex> even in
accepting the deference which his <xex>haughtiness</xex> leads him
<xex>arrogantly</xex> to exact.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haughty</ent><br/
<hw>Haugh"ty</hw> <pr>(h<add/"t<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Haughtier</adjf>
<pr>(h<add/"t<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Haughtiest</adjf>.]</amorph> <ety>[OE. <ets>hautein</ets>, F.
<ets>hautain</ets>, fr. <ets>haut</ets> high, OF. also <ets>halt</ets>,
fr. L. <ets>altus</ets>. See <er>Altitude</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>High; lofty; bold.</def> <mark>[Obs. or
Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To measure the most <qex>haughty</qex> mountain's height.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Equal unto this <qex>haughty</qex> enterprise.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disdainfully or contemptuously proud; arrogant;
overbearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A woman of a <qex>haughty</qex> and imperious nature.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Indicating haughtiness; <as>as, a <ex>haughty</ex>
carriage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Satan, with vast and <qex>haughty</qex> strides advanced,<br/
Came towering.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haul</ent><br/
<hw>Haul</hw> <pr>(h<add/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hauled</conjf> <pr>(h<add/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hauling</conjf>.]</vmorph> <ety>[OE. <ets>halen</ets>,
<ets>halien</ets>, F. <ets>haler</ets>, of German or Scand. origin; akin
to AS. <ets>geholian</ets> to acquire, get, D. <ets>halen</ets> to
fetch, pull, draw, OHG. <ets>hol<omac/n</ets>, <ets>hal<omac/n</ets>, G.
<ets>holen</ets>, Dan. <ets>hale</ets> to haul, Sw. <ets>hala</ets>, and
to L. <ets>calare</ets> to call, summon, Gr. <grk>kalei^n</grk> to call.
Cf. <er>Hale</er>, <pos>v. t.</pos>, <er>Claim</er>. <er>Class</er>,
<er>Council</er>, <er>Ecclesiastic</er>.]</ety> <sn>1.</sn> <def>To pull
or draw with force; to drag.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some dance, some <qex>haul</qex> the rope.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thither they bent, and <qex>hauled</qex> their ships to land.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Romp-loving miss<br/
Is <qex>hauled</qex> about in gallantry robust.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To transport by drawing, as with horses or oxen;
<as>as, to <ex>haul</ex> logs to a sawmill</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When I was seven or eight years of age, I began <qex>hauling</qex>
all the wood used in the house and shops.</q> <rj><qau>U. S.
Grant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To haul over the coals</b></col>. <cd>See under
<er>Coal</er>.</cd> -- <col><b>To haul the wind</b></col>
<fld>(Naut.)</fld>, <cd>to turn the head of the ship nearer to the point
from which the wind blows.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haul</ent><br/
<hw>Haul</hw>, <pos>v. i.</pos> <sn>1.</sn> <fld>(Naut.)</fld> <def>To
change the direction of a ship by hauling the wind. See under
<er>Haul</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . <qex>hauled</qex> up for it, and found it to be an
island.</q> <rj><qau>Cook.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pull apart, as oxen sometimes do when
yoked.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To haul around</b></col> <fld>(Naut.)</fld>, <cd>to shift
to any point of the compass; -- said of the wind.</cd> -- <col><b>To
haul off</b></col> <fld>(Naut.)</fld>, <cd>to sail closer to the wind,
in order to get farther away from anything; hence, to withdraw; to draw
back.</cd></cs><-- haul off (b), to get ready (usu. for violent action)
-- used with "and" -- "hauled off and punched him on the nose" --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haul</ent><br/
<hw>Haul</hw>, <pos>n.</pos> <sn>1.</sn> <def>A pulling with force; a
violent pull.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A single draught of a net; <as>as, to catch a
hundred fish at a <ex>haul</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is caught, taken, or gained at once, as
by hauling a net.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Transportation by hauling; the distance through
which anything is hauled, as freight in a railroad car; <as>as, a long
<ex>haul</ex> or short <ex>haul</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Rope Making)</fld> <def>A bundle of about four
hundred threads, to be tarred.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haulabout</ent><br/
<hw>Haul"a*bout`</hw> <pr>(h<add/l"<adot/*bout`)</pr>, <pos>n.</pos>
<def>A bargelike vessel with steel hull, large hatchways, and coal
transporters, for coaling war vessels from its own hold or from other
colliers.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Haulage</ent><br/
<hw>Haul"age</hw> <pr>(-<asl/j)</pr>, <pos>n.</pos> <def>Act of hauling;
<as>as, the <ex>haulage</ex> of cars by an engine</as>; charge for
hauling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hauler</ent><br/
<hw>Haul"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who hauls.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trucking company; a freight transporter using
trucks.</def><br/
[<source>PJC</source>]</p>

<p><ent>haulier</ent><br/
<hw>haulier</hw> <pos>n.</pos> <def>a haulage contractor.</def><br/
<syn><b>Syn. --</b> hauler.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Haulm</ent><br/
<hw>Haulm</hw> <pr>(h<add/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>halm</ets>, AS. <ets>healm</ets>; akin to D., G., Dan., & Sw.
<ets>halm</ets>, Icel. <ets>h<amac/lmr</ets>, L. <ets>calamus</ets>
reed, cane, stalk, Gr. <grk>kalamo`s</grk>. Cf. <er>Excel</er>,
<er>Culminate</er>, <er>Culm</er>, <er>Shawm</er>,
<er>Calamus</er>.]</ety> <def>The denuded stems or stalks of such crops
as buckwheat and the cereal grains, beans, etc.; straw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haulm</ent><br/
<hw>Haulm</hw>, <pos>n.</pos> <def>A part of a harness; a
hame.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hauls</ent><br/
<hw>Hauls</hw> <pr>(h<add/ls)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Hals</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haulse</ent><br/
<hw>Haulse</hw> <pr>(h<add/ls)</pr>, <pos>v.</pos> <mark>[Obs.]</mark>
<def>See <er>Halse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hault</ent><br/
<hw>Hault</hw> <pr>(h<add/lt)</pr>, <pos>a.</pos> <ety>[OF.
<ets>hault</ets>, F. <ets>haut</ets>. See <er>Haughty</er>.]</ety>
<def>Lofty; haughty.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Through support of countenance proud and <qex>hault</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haum</ent><br/
<hw>Haum</hw> <pr>(h<add/m)</pr>, <pos>n.</pos> <def>See <er>Haulm</er>,
stalk.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunce</ent><br/
<hw>Haunce</hw> <pr>(h<adot/ns)</pr>, <pos>v. t.</pos> <def>To
enhance.</def> <mark>[Obs.]</mark> <rj><au>Lydgate.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunch</ent><br/
<hw>Haunch</hw> <pr>(h<aum/nch; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>hanche</ets>, of German origin; cf. OD. <ets>hancke</ets>,
<ets>hencke</ets>, and also OHG. <ets>ancha</ets>; prob. not akin to E.
<ets>ankle</ets>.]</ety> <sn>1.</sn> <def>The hip; the projecting region
of the lateral parts of the pelvis and the hip joint; the hind
part.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of meats: The leg and loin taken together; <as>as, a
<ex>haunch</ex> of venison</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Haunch bone</b></col>. <cd>See <cref>Innominate
bone</cref>, under <er>Innominate</er>.</cd> -- <col><b>Haunches of an
arch</b></col> <fld>(Arch.)</fld>, <cd>the parts on each side of the
crown of an arch. (See <er>Crown</er>, <pos>n.</pos>, 11.) Each
<xex>haunch</xex> may be considered as from one half to two thirds of
the half arch.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunched</ent><br/
<hw>Haunched</hw> <pr>(h<aum/ncht)</pr>, <pos>a.</pos> <def>Having
haunches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunt</ent><br/
<hw>Haunt</hw> <pr>(h<aum/nt; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Haunted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Haunting</conjf>.]</vmorph> <ety>[F.
<ets>hanter</ets>; of uncertain origin, perh. from an assumed LL.
<ets>ambitare</ets> to go about, fr. L. <ets>ambire</ets> (see
<er>Ambition</er>); or cf. Icel. <ets>heimta</ets> to demand, regain,
akin to <ets>heim</ets> home (see <er>Home</er>). <root/36.]</ety>
<sn>1.</sn> <def>To frequent; to resort to frequently; to visit
pertinaciously or intrusively; to intrude upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You wrong me, sir, thus still to <qex>haunt</qex> my house.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those cares that <qex>haunt</qex> the court and town.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inhabit or frequent as a specter; to visit as a
ghost or apparition; -- said of spirits or ghosts, especially of dead
people; <as>as, the murdered man <ex>haunts</ex> the house where he
died</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Foul spirits <qex>haunt</qex> my resting place.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To practice; to devote one's self to.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That other merchandise that men <qex>haunt</qex> with fraud . . .
is cursed.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Leave honest pleasure, and <qex>haunt</qex> no good pastime.</q>
<rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To accustom; to habituate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Haunt</qex> thyself to pity.</q>
<rj><qau>Wyclif.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunt</ent><br/
<hw>Haunt</hw>, <pos>v. i.</pos> <def>To persist in staying or
visiting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I've charged thee not to <qex>haunt</qex> about my doors.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunt</ent><br/
<hw>Haunt</hw>, <pos>n.</pos> <sn>1.</sn> <def>A place to which one
frequently resorts; <as>as, drinking saloons are the <ex>haunts</ex> of
tipplers; a den is the <ex>haunt</ex> of wild beasts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In Old English the place occupied by any one as a
dwelling or in his business was called a <xex>haunt</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<note>
<p>Often used figuratively.</p>

<p><q>The household nook,<br/
The <qex>haunt</qex> of all affections pure.</q>
<rj><qau>Keble.</qau></rj></p>

<p><q>The feeble soul, a <qex>haunt</qex> of fears.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>
</note>

<p><sn>2.</sn> <def>The habit of resorting to a place.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>haunt</qex> you have got about the courts.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Practice; skill.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of clothmaking she hadde such an <qex>haunt</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunted</ent><br/
<hw>Haunt"ed</hw>, <pos>a.</pos> <def>Inhabited by, or subject to the
visits of, apparitions; frequented by a ghost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All houses wherein men have lived and died<br/
Are <qex>haunted</qex> houses.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haunter</ent><br/
<hw>Haunt"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who, or
that which, haunts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haurient</ent><br/
<hw>Hau"ri*ent</hw> <pr>(h<add/"r<icr/*<eit/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>hauriens</ets>, p. pr. of <ets>haurire</ets> to
breathe.]</ety> <fld>(Her.)</fld> <def>In pale, with the head in chief;
-- said of the figure of a fish, as if rising for air.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hausen</ent><br/
<hw>Hau"sen</hw> <pr>(h<add/"s<ecr/n)</pr>, <pos>n.</pos>
<ety>[G.]</ety> <fld>(Zool.)</fld> <def>A large sturgeon (<spn>Acipenser
huso</spn> syn. <spn>Huso huso</spn>) from the region of the Black Sea;
also called <altname>Beluga</altname>. It is sometimes twelve feet long,
and provides the highest quality <prod>caviar</prod>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hausse</ent><br/
<hw>Hausse</hw> <pr>(h<add/s)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Gun.)</fld> <def>A kind of graduated breech sight for a small arm,
or a cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haustellata</ent><br/
\'d8<hw>Haus`tel*la"ta</hw> <pr>(h<add/s`t<ecr/l*l<amac/"t<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. <ets>haustellum</ets>, fr. L.
<ets>haurire</ets>, <ets>haustum</ets>, to draw water, to swallow. See
<er>Exhaust</er>.]</ety> <fld>(Zool.)</fld> <def>An artificial division
of insects, including all those with a sucking proboscis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haustellate</ent><br/
<hw>Haus"tel*late</hw> <pr>(h<add/s"t<ecr/l*l<asl/t <or/
h<add/s*t<ecr/l"l<asl/t)</pr>, <pos>a.</pos> <ety>[See
<er>Haustellata</er>.]</ety> <fld>(Zool.)</fld> <def>Provided with a
haustellum, or sucking proboscis.</def> -- <def2><pos>n.</pos> <def>One
of the Haustellata.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haustellum</ent><br/
\'d8<hw>Haus*tel"lum</hw> <pr>(h<add/s*t<ecr/l"l<ucr/m)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Haustella</plw>
<pr>(-l<adot/)</pr>.</plu> <ety>[NL.]</ety> <fld>(Zool.)</fld> <def>The
sucking proboscis of various insects. See <er>Lepidoptera</er>, and
<er>Diptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haustorium</ent><br/
\'d8<hw>Haus*to"ri*um</hw> <pr>(h<add/s*t<omac/"r<icr/*<ucr/m)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Haustoria</plw>
<pr>(h<add/s*t<omac/"r<icr/*<adot/)</pr>.</plu> <ety>[LL., a well, fr.
L. <ets>haurire</ets>, <ets>haustum</ets>, to drink.]</ety>
<fld>(Bot.)</fld> <def>One of the suckerlike rootlets of such plants as
the dodder and ivy.</def> <rj><au>R. Brown.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haut</ent><br/
<hw>Haut</hw> <pr>(h<add/t)</pr>, <pos>a.</pos> <ety>[F. See
<er>Haughty</er>.]</ety> <def>Haughty.</def> <mark>[Obs.]</mark>
<ldquo/Nations proud and <xex>haut</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hautboy</ent><br/
<hw>Haut"boy</hw> <pr>(h<omac/"boi)</pr>, <pos>n.</pos> <ety>[F.
<ets>hautbois</ets>, lit., high wood; <ets>haut</ets> high +
<ets>bois</ets> wood. So called on account of its high tone. See
<er>Haughty</er>, <er>Bush</er>; and cf. <er>Oboe</er>.]</ety>
<sn>1.</sn> <fld>(Mus.)</fld> <def>A wind instrument, sounded through a
reed, and similar in shape to the clarinet, but with a thinner tone. Now
more commonly called <altname>oboe</altname>. See <xex>Illust.</xex> of
<er>Oboe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A sort of strawberry
(<spn>Fragaria elatior</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hautboyist</ent><br/
<hw>Haut"boy*ist</hw> <pr>(h<omac/"boi*<icr/st)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>hautbo<ium/ste</ets>.]</ety> <def>A player on the
hautboy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hautein</ent><br/
<hw>Hau"tein</hw> <pr>(h<omac/"t<asl/n)</pr>, <pos>a.</pos> <ety>[See
<er>Haughty</er>.]</ety> <sn>1.</sn> <def>Haughty; proud.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>High; -- said of the voice or flight of birds.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hauteur</ent><br/
\'d8<hw>Hau`teur"</hw> <pr>(h<omac/`t<etil/r")</pr>, <pos>n.</pos>
<ety>[F., fr. <ets>haut</ets> high. See <er>Haughty</er>.]</ety>
<def>Haughty manner or spirit; haughtiness; pride; arrogance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hautgout</ent><br/
\'d8<hw>Haut`go<ucir/t"</hw> <pr>(h<omac/`g<oomac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>High relish or flavor; high seasoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hautpas</ent><br/
\'d8<hw>Haut`pas"</hw> <pr>(h<omac/`p<aum/")</pr>, <pos>n.</pos>
<ety>[F. <ets>haut</ets> high + <ets>pas</ets> step.]</ety> <def>A
raised part of the floor of a large room; a platform for a raised table
or throne. See <er>Dais</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 675 pr=JMD --></p>

<p><ent>Hauynite</ent><br/
<hw>Ha"<uum/y*nite</hw> <pr>(<aum/"w<esl/*n<imac/t)</pr>, <pos>n.</pos>
<ety>[From the French mineralogist <etsep>Ha<uum/y</etsep>.]</ety>
<fld>(Min.)</fld> <def>A blue isometric mineral, characteristic of some
volcanic rocks. It is a silicate of alumina, lime, and soda, with
sulphate of lime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havana</ent><br/
<hw>Ha*van"a</hw> <pr>(h<adot/*v<acr/n"<adot/)</pr>, <pos>prop. a.</pos>
<def>Of or pertaining to Havana, the capital of the island of Cuba;
<as>as, an <ex>Havana</ex> cigar</as></def>; -- <altsp>formerly
sometimes written <asp>Havannah</asp>.</altsp> -- <def2><pos>n.</pos>
<def>An Havana cigar.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>Young Frank Clavering stole his father's <qex>Havannahs</qex>, and
. . . smoked them in the stable.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havanese</ent><br/
<hw>Hav`an*ese"</hw> <pr>(h<acr/v`<acr/n*<emac/z" <or/ -<emac/s")</pr>,
<pos>a.</pos> <def>Of or pertaining to Havana, in Cuba.</def> --
<def2><pos>n. sing. & pl.</pos> <def>A native or inhabitant, or the
people, of Havana.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Have</ent><br/
<hw>Have</hw> <pr>(h<acr/v)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Had</conjf> <pr>(h<acr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Having</conjf>. <pos>Indic. present</pos>, I
<conjf>have</conjf>, thou <conjf>hast</conjf>, he <conjf>has</conjf>;
we, ye, they <conjf>have</conjf>.]</vmorph> <ety>[OE. <ets>haven</ets>,
<ets>habben</ets>, AS. <ets>habben</ets> (imperf. <ets>h<ae/fde</ets>,
p. p. <ets>geh<ae/fd</ets>); akin to OS. <ets>hebbian</ets>, D.
<ets>hebben</ets>, OFries. <ets>hebba</ets>, OHG. <ets>hab<emac/n</ets>,
G. <ets>haben</ets>, Icel. <ets>hafa</ets>, Sw. <ets>hafva</ets>, Dan.
<ets>have</ets>, Goth. <ets>haban</ets>, and prob. to L.
<ets>habere</ets>, whence F. <ets>avoir</ets>. Cf. <er>Able</er>,
<er>Avoirdupois</er>, <er>Binnacle</er>, <er>Habit</er>.]</ety>
<sn>1.</sn> <def>To hold in possession or control; to own; <as>as, he
<ex>has</ex> a farm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To possess, as something which appertains to, is
connected with, or affects, one.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The earth <qex>hath</qex> bubbles, as the water
<qex>has</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>had</qex> a fever late.</q> <rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To accept possession of; to take or
accept.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Break thy mind to me in broken English; wilt thou <qex>have</qex>
me?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To get possession of; to obtain; to get.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To cause or procure to be; to effect; to exact; to
desire; to require.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>had</qex> the church accurately described to me.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wouldst thou <qex>have</qex> me turn traitor also?</q>
<rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To bear, as young; <as>as, she has just <ex>had</ex>
a child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To hold, regard, or esteem.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of them shall I be <qex>had</qex> in honor.</q> <rj><qau>2 Sam.
vi. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To cause or force to go; to take.</def> <ldquo/The
stars <xex>have</xex> us to bed.<rdquo/ <au>Herbert.</au>
<ldquo/<xex>Have</xex> out all men from me.<rdquo/ <au>2 Sam. xiii.
9.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To take or hold (one's self); to proceed promptly;
-- used reflexively, often with ellipsis of the pronoun; <as>as, to
<ex>have</ex> after one; to <ex>have</ex> at one or at a thing, <it>i.
e.</it>, to aim at one or at a thing; to attack; to <ex>have</ex> with a
companion.</as></def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To be under necessity or obligation; to be
compelled; followed by an infinitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Science <qex>has</qex>, and will long <qex>have</qex>, to be a
divider and a separatist.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The laws of philology <qex>have</qex> to be established by
external comparison and induction.</q> <rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To understand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>have</qex> me, have you not?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To put in an awkward position; to have the
advantage of; <as>as, that is where he <ex>had</ex> him</as>.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Have</xex>, as an auxiliary verb, is used with the
past participle to form preterit tenses; as, I <xex>have</xex> loved; I
shall <xex>have</xex> eaten. Originally it was used only with the
participle of transitive verbs, and denoted the possession of the object
in the state indicated by the participle; as, <xex>I have conquered
him</xex>, I have or hold him in a conquered state; but it has long
since lost this independent significance, and is used with the
participles both of transitive and intransitive verbs as a device for
expressing past time. <xex>Had</xex> is used, especially in poetry, for
<xex>would have</xex> or <xex>should have</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Myself for such a face <qex>had</qex> boldly died.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To have a care</b></col>, <cd>to take care; to be on
one's guard.</cd> -- <col><b>To have <plain>(a man)</plain>
out</b></col>, <cd>to engage (one) in a duel.</cd> -- <col><b>To have
done</b></col> (with). <cd>See under <er>Do</er>, <pos>v. i.</pos></cd>
-- <col><b>To have it out</b></col>, <cd>to speak freely; to bring an
affair to a conclusion.</cd> -- <col><b>To have on</b></col>, <cd>to
wear.</cd> -- <col><b>To have to do with</b></col>. <cd>See under Do,
<pos>v. t.</pos></cd></cs></p>

<p><syn><b>Syn.</b> -- To possess; to own. See
<er>Possess</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haveless</ent><br/
<hw>Have"less</hw>, <pos>a.</pos> <def>Having little or nothing.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havelock</ent><br/
<hw>Hav"e*lock</hw> <pr>(h<acr/v"<esl/*l<ocr/k)</pr>, <pos>n.</pos>
<ety>[From <ets>Havelock</ets>, an English general distinguished in
India in the rebellion of 1857.]</ety> <def>A light cloth covering for
the head and neck, used by soldiers as a protection from
sunstroke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haven</ent><br/
<hw>Ha"ven</hw> <pr>(h<amac/"v'n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<ae/fene</ets>; akin to D. & LG. <ets>haven</ets>, G.
<ets>hafen</ets>, MHG. <ets>habe</ets>, Dan. <ets>havn</ets>, Icel.
<ets>h<oum/fn</ets>, Sw. <ets>hamn</ets>; akin to E. <ets>have</ets>,
and hence orig., a holder; or to <ets>heave</ets> (see <er>Heave</er>);
or akin to AS. <ets>h<ae/f</ets> sea, Icel. & Sw. <ets>haf</ets>, Dan.
<ets>hav</ets>, which is perh. akin to E. <ets>heave</ets>.]</ety>
<sn>1.</sn> <def>A bay, recess, or inlet of the sea, or the mouth of a
river, which affords anchorage and shelter for shipping; a harbor; a
port.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What shipping and what lading 's in our <qex>haven</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their <qex>haven</qex> under the hill.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place of safety; a shelter; an asylum.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>haven</qex>, or the rock of love.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haven</ent><br/
<hw>Ha"ven</hw>, <pos>v. t.</pos> <def>To shelter, as in a haven.</def>
<rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havenage</ent><br/
<hw>Ha"ven*age</hw> <pr>(-<asl/j)</pr>, <pos>n.</pos> <def>Harbor dues;
port dues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havened</ent><br/
<hw>Ha"vened</hw> <pr>(h<amac/"v'nd)</pr>, <pos>p. a.</pos>
<def>Sheltered in a haven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blissful <qex>havened</qex> both from joy and pain.</q>
<rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havener</ent><br/
<hw>Ha"ven*er</hw> <pr>(h<amac/"v'n*<etil/r)</pr>, <pos>n.</pos> <def>A
harbor master.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haver</ent><br/
<hw>Ha"ver</hw> <pr>(h<acr/v"<etil/r)</pr>, <pos>n.</pos> <def>A
possessor; a holder.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haver</ent><br/
<hw>Hav"er</hw>, <pos>n.</pos> <ety>[D. <ets>haver</ets>; akin to G.
<ets>haber</ets>.]</ety> <def>The oat; oats.</def> <mark>[Prov. Eng. &
Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Haver bread</b></col>, <cd>oaten bread.</cd> --
<col><b>Haver cake</b></col>, <cd>oaten cake.</cd> <au>Piers
Plowman.</au> -- <col><b>Haver grass</b></col>, <cd>the wild oat.</cd>
-- <col><b>Haver meal</b></col>, <cd>oatmeal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haver</ent><br/
<hw>Ha"ver</hw> <pr>(h<amac/"v<etil/r)</pr>, <pos>v. i.</pos>
<ety>[Etymol. uncertain.]</ety> <def>To maunder; to talk foolishly; to
chatter.</def> <mark>[Scot.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haversack</ent><br/
<hw>Hav"er*sack</hw> <pr>(h<acr/v"<etil/r*s<acr/k)</pr>, <pos>n.</pos>
<ety>[F. <ets>havresac</ets>, G. <ets>habersack</ets>, sack for oats.
See 2d <er>Haver</er>, and <er>Sack</er> a bag.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A bag for oats or oatmeal.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bag or case, usually of stout cloth, in which a
soldier carries his rations when on a march; -- distinguished from
<xex>knapsack</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A gunner's case or bag used to carry cartridges from
the ammunition chest to the piece in loading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haversian</ent><br/
<hw>Ha*ver"sian</hw> <pr>(h<adot/*v<etil/r"sh<ait/n)</pr>, <pos>a.</pos>
<def>Pertaining to, or discovered by, Clopton <xex>Havers</xex>, an
English physician of the seventeenth century.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Haversian canals</b></col> <fld>(Anat.)</fld>, <cd>the
small canals through which the blood vessels ramify in
bone.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havier</ent><br/
<hw>Hav"ier</hw> <pr>(h<amac/"y<etil/r)</pr>, <pos>n.</pos>
<ety>[Formerly <ets>haver</ets>, prob. fr. <er>Half</er>; cf. L.
<ets>semimas</ets> emasculated, prop., half male.]</ety> <def>A
castrated deer.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q><qex>Haviers</qex>, or stags which have been gelded when young,
have no horns.</q> <rj><qau>Encyc. of Sport.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Havildar</ent><br/
\'d8<hw>Hav`il*dar"</hw> <pr>(h<acr/v`<icr/l*d<aum/r")</pr>,
<pos>n.</pos> <def>In the British Indian armies, a noncommissioned
officer of native soldiers, corresponding to a sergeant.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Havildar major</b></col>, <cd>a native sergeant major in
the East Indian army.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Having</ent><br/
<hw>Hav"ing</hw> <pr>(h<acr/v"<icr/ng)</pr>, <pos>n.</pos>
<def>Possession; goods; estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll lend you something; my <qex>having</qex> is not much.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havior</ent><br/
<hw>Hav"ior</hw> <pr>(h<amac/v"y<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>havour</ets>, a corruption of OF. <ets>aveir</ets>,
<ets>avoir</ets>, a having, of same origin as E. <ets>aver</ets> a work
horse. The <ets>h</ets> is due to confusion with E.
<ets>have</ets>.]</ety> <def>Behavior; demeanor.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havoc</ent><br/
<hw>Hav"oc</hw> <pr>(h<acr/v"<ocr/k)</pr>, <pos>n.</pos> <ety>[W.
<ets>hafog</ets> devastation, havoc; or, if this be itself fr. E.
<ets>havoc</ets>, cf. OE. <ets>havot</ets>, or AS. <ets>hafoc</ets>
hawk, which is a cruel or rapacious bird, or F. <ets>hai, voux!</ets> a
cry to hounds.]</ety> <def>Wide and general destruction; devastation;
waste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As for Saul, he made <qex>havoc</qex> of the church.</q>
<rj><qau>Acts viii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye gods, what <qex>havoc</qex> does ambition make<br/
Among your works!</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havoc</ent><br/
<hw>Hav"oc</hw>, <pos>v. t.</pos> <def>To devastate; to destroy; to lay
waste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To waste and <qex>havoc</qex> yonder world.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Havoc</ent><br/
<hw>Hav"oc</hw>, <pos>interj.</pos> <ety>[See <er>Havoc</er>,
<pos>n.</pos>]</ety> <def>A cry in war as the signal for indiscriminate
slaughter.</def> <rj><au>Toone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Do not cry <qex>havoc</qex>, where you should but hunt<br/
With modest warrant.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cry '<qex>havoc</qex>,' and let slip the dogs of war!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haw</ent><br/
<hw>Haw</hw> <pr>(h<add/)</pr>, <pos>n.</pos> <ety>[OE. <ets>hawe</ets>,
AS. <ets>haga</ets>; akin to D. <ets>haag</ets> headge, G.
<ets>hag</ets>, <ets>hecke</ets>, Icel. <ets>hagi</ets> pasture, Sw.
<ets>hage</ets>, Dan. <ets>have</ets> garden. <root/12. Cf.
<er>Haggard</er>, <er>Ha-ha</er>, <er>Haugh</er>,
<er>Hedge</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A hedge; an inclosed garden or yard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And eke there was a polecat in his <qex>haw</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fruit of the hawthorn.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haw</ent><br/
<hw>Haw</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety>
<fld>(Anat.)</fld> <def>The third eyelid, or nictitating membrane. See
<cref>Nictitating membrane</cref>, under <er>Nictitate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haw</ent><br/
<hw>Haw</hw>, <pos>n.</pos> <ety>[Cf. <ets>ha</ets> an interjection of
wonder, surprise, or hesitation.]</ety> <def>An intermission or
hesitation of speech, with a sound somewhat like <xex>haw!</xex> also,
the sound so made.</def> <ldquo/Hums or <xex>haws</xex>.<rdquo/
<rj><au>Congreve.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haw</ent><br/
<hw>Haw</hw>, <pos>v. i.</pos> <def>To stop, in speaking, with a sound
like <xex>haw</xex>; to speak with interruption and
hesitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cut it short; don't prose -- don't hum and <qex>haw</qex>.</q>
<rj><qau>Chesterfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>hemming and hawing</b></col> <cd>speaking hesitantly and
inarticulately, with numerous pauses and interjections.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Haw</ent><br/
<hw>Haw</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hawed</conjf> <pr>(h<add/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hawing</conjf>.]</vmorph> <ety>[Written also
<ets>hoi</ets>.]</ety> <ety>[Perhaps connected with <ets>here</ets>,
<ets>hither</ets>; cf., however, F. <ets>huhau</ets>, <ets>hurhau</ets>,
<ets>hue</ets>, interj. used in turning a horse to the right, G.
<ets>hott</ets>, <ets>h<uum/</ets>, interj. used in calling to a
horse.]</ety> <def>To turn to the near side, or toward the driver; --
said of cattle or a team: a word used by teamsters in guiding their
teams, and most frequently in the imperative. See
<er>Gee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To haw and gee</b></col>, <it>or</it> <col><b>To
haw and gee about</b></col></mcol>, <cd>to go from one thing to another
without good reason; to have no settled purpose; to be irresolute or
unstable.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haw</ent><br/
<hw>Haw</hw>, <pos>v. t.</pos> <def>To cause to turn, as a team, to the
near side, or toward the driver; <as>as, to <ex>haw</ex> a team of
oxen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To haw and gee</b></col>, <it>or</it> <col><b>To
haw and gee about</b></col></mcol>, <cd>to lead this way and that at
will; to lead by the nose; to master or control.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawaiian</ent><br/
<hw>Ha*wai"ian</hw> <pr>(h<adot/*w<imac/"y<ait/n)</pr>, <pos>prop.
a.</pos> <def>Belonging to Hawaii or the Sandwich Islands, or to the
people of Hawaii.</def> -- <def2><pos>n.</pos> <def>A native of
Hawaii.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawebake</ent><br/
<hw>Hawe"bake`</hw> <pr>(h<add/"b<amac/k`)</pr>, <pos>n.</pos>
<def>Probably, the baked berry of the hawthorn tree, that is, coarse
fare. See 1st <er>Haw</er>, 2.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawfinch</ent><br/
<hw>Haw"finch`</hw> <pr>(h<add/"f<icr/nch`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The common European grosbeak
(<spn>Coccothraustes vulgaris</spn>); -- called also <altname>cherry
finch</altname>, and <altname>coble</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haw-haw</ent><br/
<hw>Haw-haw"</hw> <pr>(h<add/*h<add/)</pr>, <pos>n.</pos>
<ety>[Duplication of <ets>haw</ets> a hedge.]</ety> <sn>1.</sn> <def>See
<er>Ha-ha</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a loud laugh that sounds like a horse
neighing.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> hee-haw, horselaugh, ha-ha.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a sunken fence (so as not to interfere with the
view).</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> haha.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hawhaw</ent><br/
<hw>Haw*haw"</hw>, <pos>v. i.</pos> <ety>[Of imitative origin.]</ety>
<def>To laugh boisterously.</def> <mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>haw-haw'd</qex>, I tell you, for more than half an
hour.</q> <rj><qau>Major Jack Downing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw> <pr>(h<add/k)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hauk</ets> (prob. fr. Icel.), <ets>havek</ets>, AS.
<ets>hafoc</ets>, <ets>heafoc</ets>; akin to D. <ets>havik</ets>, OHG.
<ets>habuh</ets>, G. <ets>habicht</ets>, Icel. <ets>haukr</ets>, Sw.
<ets>h<oum/k</ets>, Dan. <ets>h<oum/g</ets>, prob. from the root of E.
<ets>heave</ets>.]</ety> <fld>(Zool.)</fld> <def>One of numerous species
and genera of rapacious birds of the family <fam>Falconidae</fam>. They
differ from the true falcons in lacking the prominent tooth and notch of
the bill, and in having shorter and less pointed wings. Many are of
large size and grade into the eagles. Some, as the goshawk, were
formerly trained like falcons. In a more general sense the word is not
infrequently applied, also, to true falcons, as the sparrow
<xex>hawk</xex>, pigeon <xex>hawk</xex>, duck <xex>hawk</xex>, and
prairie <xex>hawk</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Among the common American species are the red-tailed
hawk (<spn>Buteo borealis</spn>); the red-shouldered (<spn>Buteo
lineatus</spn>); the broad-winged (<spn>Buteo Pennsylvanicus</spn>); the
rough-legged (<spn>Archibuteo lagopus</spn>); the sharp-shinned
(<spn>Accipiter fuscus</spn>). See <er>Fishhawk</er>, <er>Goshawk</er>,
<cref>Marsh hawk</cref>, under <er>Marsh</er>, <cref>Night hawk</cref>,
under <er>Night</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bee hawk</b></col> <fld>(Zool.)</fld>, <cd>the honey
buzzard.</cd> -- <col><b>Eagle hawk</b></col>. <cd>See under
<er>Eagle</er>.</cd> -- <col><b>Hawk eagle</b></col> <fld>(Zool.)</fld>,
<cd>an Asiatic bird of the genus <gen>Spizaetus</gen>, or
<gen>Limnaetus</gen>, intermediate between the hawks and eagles. There
are several species.</cd> -- <col><b>Hawk fly</b></col>
<fld>(Zool.)</fld>, <cd>a voracious fly of the family
<fam>Asilidae</fam>. See <cref>Hornet fly</cref>, under
<er>Hornet</er>.</cd> -- <col><b>Hawk moth</b></col>. <fld>(Zool.)</fld>
<cd>See <er>Hawk moth</er>, in the Vocabulary.</cd> -- <col><b>Hawk
owl</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A northern owl
(<spn>Surnia ulula</spn>) of Europe and America. It flies by day, and in
some respects resembles the hawks.</cd> <sd>(b)</sd> <cd>An owl of India
(<spn>Ninox scutellatus</spn>).</cd> -- <col><b>Hawk's bill</b></col>
<fld>(Horology)</fld>, <cd>the pawl for the rack, in the striking
mechanism of a clock.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw> <pr>(h<add/k)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hawked</conjf> <pr>(h<add/kt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hawking</conjf>.]</vmorph> <sn>1.</sn> <def>To catch, or
attempt to catch, birds by means of hawks trained for the purpose, and
let loose on the prey; to practice falconry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A falconer Henry is, when Emma <qex>hawks</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make an attack while on the wing; to soar and
strike like a hawk; -- generally with <xex>at</xex>; <as>as, to
<ex>hawk</ex> at flies</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A falcon, towering in her pride of place,<br/
Was by a mousing owl <qex>hawked</qex> at and killed.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw>, <pos>v. i.</pos> <ety>[W. <ets>hochi</ets>.]</ety>
<def>To clear the throat with an audible sound by forcing an expiratory
current of air through the narrow passage between the depressed soft
palate and the root of the tongue, thus aiding in the removal of foreign
substances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw>, <pos>v. t.</pos> <def>To raise by hawking, as
phlegm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw>, <pos>n.</pos> <ety>[W. <ets>hoch</ets>.]</ety> <def>An
effort to force up phlegm from the throat, accompanied with
noise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw>, <pos>v. t.</pos> <ety>[Akin to D. <ets>hauker</ets> a
hawker, G. <ets>h<oum/ken</ets>, <ets>h<oum/cken</ets>, to higgle, to
retail, <ets>h<oum/ke</ets>, <ets>h<oum/ker</ets>, a higgler, huckster.
See <er>Huckster</er>.]</ety> <def>To offer for sale by outcry in the
street; to carry (merchandise) about from place to place for sale; to
peddle; <as>as, to <ex>hawk</ex> goods or pamphlets</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His works were <qex>hawked</qex> in every street.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk</ent><br/
<hw>Hawk</hw>, <pos>n.</pos> <fld>(Masonry)</fld> <def>A small board,
with a handle on the under side, to hold mortar.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hawk boy</b></col>, <cd>an attendant on a plasterer to
supply him with mortar.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hawksbill</ent><br/
<ent>hawkbill</ent><br/
<mhw><hw>hawk"bill`</hw>, <hw>hawks"bill`</hw></mhw>
<pr>(-b<icr/l`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A sea turtle
(<spn>Eretmochelys imbricata</spn>), which yields the best quality of
tortoise shell; -- called also <altname>caret</altname>.</def><br/
<syn><b>Syn. --</b> hawksbill turtle, hawkbill, tortoiseshell turtle,
Eretmochelys imbricata.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawkbit</ent><br/
<hw>Hawk"bit`</hw> <pr>(-b<icr/t`)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The fall dandelion (<spn>Leontodon autumnale</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawked</ent><br/
<hw>Hawked</hw> <pr>(h<add/kt)</pr>, <pos>a.</pos> <def>Curved like a
hawk's bill; crooked.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawker</ent><br/
<hw>Hawk"er</hw> <pr>(h<add/k"<etil/r)</pr>, <pos>n.</pos> <def>One who
sells wares by crying them in the street; hence, a peddler or a
packman.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawker</ent><br/
<hw>Hawk"er</hw>, <pos>v. i.</pos> <def>To sell goods by outcry in the
street.</def> <mark>[Obs.]</mark> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawker</ent><br/
<hw>Hawk"er</hw>, <pos>n.</pos> <ety>[Cf. AS. <ets>hafecere</ets>. See
1st <er>Hawk</er>.]</ety> <def>A falconer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawkey</ent><br/
<hw>Hawk"ey</hw> <pr>(-<ycr/)</pr>, <pos>n.</pos> <def>See
<er>Hockey</er>.</def> <rj><au>Holloway.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawk-eyed</ent><br/
<hw>Hawk"-eyed`</hw> <pr>(-<imac/d`)</pr>, <pos>a.</pos> <def>Having
very keen vision; sharp-sighted; discerning.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> keen-sighted, lynx-eyed, quick-sighted, sharp-eyed,
sharp-sighted.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>alert to possible danger.</def>
<wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> argus-eyed, open-eyed, unsleeping, vigilant, wary,
watchful.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hawkeye State</ent><br/
<hw>Hawk"eye` State</hw>. <def>Iowa; -- a nickname of obscure
origin.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hawk moth</ent><br/
<hw>Hawk" moth`</hw> <pr>(m<ocr/th`; 115)</pr>. <fld>(Zool.)</fld>
<def>Any moth of the family <fam>Sphingidae</fam>, of which there are
numerous genera and species. They are large, handsome moths with long
narrow forewings capable of powerful flight and hovering over flowers to
feed. They fly mostly at twilight and hover about flowers like a humming
bird, sucking the honey by means of a long, slender proboscis. The
larvae are large, hairless caterpillars ornamented with green and other
bright colors, and often with a caudal spine. See <er>Sphinx</er>, also
<cref>Tobacco worm</cref>, and <cref>Tomato worm</cref>.</def><br/
<syn><b>Syn. --</b> hawk moth, sphingid, sphinx moth, hummingbird
moth.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><caption>Tobacco Hawk Moth (<spn>Macrosila Carolina</spn>), and its
Larva, the Tobacco Worm.</caption><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The larvae of several species of hawk moths feed on
grapevines. The elm-tree hawk moth is <styp><spn>Ceratomia
Amyntor</spn></styp>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>hawk's-beard</ent><br/
<hw>hawk's-beard</hw> <pos>n.</pos> <def>Any of various plants of the
genus <gen>Crepis</gen> having loose heads of yellow flowers on top of a
long branched leafy stem; found in the Northern hemisphere.</def><br/
<syn><b>Syn. --</b> hawk's-beards.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hawksbill</ent><br/
<hw>hawks"bill</hw> <pos>n.</pos> <def>See <er>hawkbill</er>.</def><br/
<syn><b>Syn. --</b> hawksbill turtle, hawkbill, tortoiseshell turtle,
<spn>Eretmochelys imbricata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hawkweed</ent><br/
<hw>Hawk"weed`</hw> <pr>(-w<emac/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>A plant of the genus
<gen>Hieracium</gen>; -- so called from the ancient belief that birds of
prey used its juice to strengthen their vision.</def> <sd>(b)</sd>
<def>A plant of the genus <gen>Senecio</gen> (<spn>Senecio
hieracifolius</spn>).</def> <rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawm</ent><br/
<hw>Hawm</hw> <pr>(h<add/m)</pr>, <pos>n.</pos> <def>See <er>Haulm</er>,
straw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawm</ent><br/
<hw>Hawm</hw>, <pos>v. i.</pos> <ety>[Etymol. uncertain.]</ety> <def>To
lounge; to loiter.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawse</ent><br/
<hw>Hawse</hw> <pr>(h<add/z <or/ h<add/s; 277)</pr>, <pos>n.</pos>
<ety>[Orig. a <ets>hawse hole</ets>, or hole in the bow of the ship; cf.
Icel. <ets>hals</ets>, <ets>h<amac/ls</ets>, neck, part of the bows of a
ship, AS. <ets>heals</ets> neck. See <er>Collar</er>, and cf.
<er>Halse</er> to embrace.]</ety> <sn>1.</sn> <def>A hawse hole.</def>
<rj><au>Harris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The situation of the
cables when a vessel is moored with two anchors, one on the starboard,
the other on the port bow.</def> <sd>(b)</sd> <def>The distance ahead to
which the cables usually extend; <as>as, the ship has a clear or open
<ex>hawse</ex>, or a foul <ex>hawse</ex>; to anchor in our
<ex>hawse</ex>, or athwart <ex>hawse</ex>.</as></def> <sd>(c)</sd>
<def>That part of a vessel's bow in which are the hawse holes for the
cables.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Athwart hawse</b></col>. <cd>See under
<er>Athwart</er>.</cd> -- <col><b>Foul hawse</b></col>, <cd>a hawse in
which the cables cross each other, or are twisted together.</cd> --
<col><b>Hawse block</b></col>, <cd>a block used to stop up a hawse hole
at sea; -- called also <altname>hawse plug</altname>.</cd> --
<col><b>Hawse piece</b></col>, <cd>one of the foremost timbers of a
ship, through which the hawse hole is cut.</cd> -- <col><b>Hawse
plug</b></col>. <cd>Same as <cref>Hawse block</cref> (above).</cd> --
<col><b>To come in at the hawse holes</b></col>, <cd>to enter the naval
service at the lowest grade.</cd> <mark>[Cant]</mark> -- <col><b>To
freshen the hawse</b></col>, <cd>to veer out a little more cable and
bring the chafe and strain on another part.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hawsepipe</ent><br/
<ent>hawsehole</ent><br/
<mhw><hw>hawse"hole`</hw>, <hw>hawse"pipe`</hw></mhw> <pos>n.</pos>
<def>a hole in the bow of a ship, through which the anchor rope or cable
passes.</def><br/
<syn><b>Syn. --</b> hawse, hawsepipe.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><-- p. 676 pr=JMD --></p>

<p><ent>Hawser</ent><br/
<hw>Haws"er</hw> <pr>(h<add/z"<etil/r <it>or</it> h<add/s"<etil/r)</pr>,
<pos>n.</pos> <ety>[From F. <ets>hausser</ets> to lift, raise (cf. OF.
<ets>hausser<eacute/e</ets> towpath, towing, F.
<ets>haussi<egrave/re</ets> hawser), LL. <ets>altiare</ets>, fr. L.
<ets>altus</ets> high. See <er>Haughty</er>.]</ety> <def>A large rope
made of three strands each containing many yarns.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Three hawsers twisted together make a cable; but it
nautical usage the distinction between cable and hawser is often one of
size rather than of manufacture.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hawser iron</b></col>, <cd>a calking iron.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawser-laid</ent><br/
<hw>Haws"er-laid`</hw> <pr>(-l<amac/d`)</pr>, <pos>a.</pos> <def>Made in
the manner of a hawser. Cf. <er>Cable-laid</er>, and see
<xex>Illust.</xex> of <er>Cordage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hawthorn</ent><br/
<hw>Haw"thorn`</hw> <pr>(h<add/"th<ocir/rn`)</pr>, <pos>n.</pos>
<ety>[AS. <ets>haga<thorn/orn</ets>, <ets>h<ae/g<thorn/orn</ets>. See
<er>Haw</er> a hedge, and <er>Thorn</er>.]</ety> <fld>(Bot.)</fld>
<def>A thorny shrub or tree (the <spn>Crataegus oxyacantha</spn>),
having deeply lobed, shining leaves, small, roselike, fragrant flowers,
and a fruit called <prod>haw</prod>. It is much used in Europe for
hedges, and for standards in gardens. The American hawthorn is
<spn>Crataegus cordata</spn>, which has the leaves but little
lobed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gives not the <qex>hawthorn</qex> bush a sweeter shade<br/
To shepherds?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hay</ent><br/
<hw>Hay</hw> <pr>(h<amac/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hege</ets>: cf. F. <ets>haie</ets>, of German origin. See
<er>Haw</er> a hedge, <er>Hedge</er>.]</ety> <sn>1.</sn> <def>A
hedge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A net set around the haunt of an animal, especially
of a rabbit.</def> <rj><au>Rowe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dance the hay</b></col>, <cd>to dance in a ring.</cd>
<rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hay</ent><br/
<hw>Hay</hw>, <pos>v. i.</pos> <def>To lay snares for rabbits.</def>
<rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hay</ent><br/
<hw>Hay</hw>, <pos>n.</pos> <ety>[OE. <ets>hei</ets>, AS.
<ets>h<emac/g</ets>; akin to D. <ets>hooi</ets>, OHG. <ets>hewi</ets>,
<ets>houwi</ets>, G. <ets>heu</ets>, Dan. & Sw. <ets>h<oum/</ets>, Icel.
<ets>hey</ets>, <ets>ha</ets>, Goth. <ets>hawi</ets> grass, fr. the root
of E. <ets>hew</ets>. See <er>Hew</er> to cut.]</ety> <def>Grass cut and
cured for fodder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Make <qex>hay</qex> while the sun shines.</q>
<rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hay</qex> may be dried too much as well as too little.</q>
<rj><qau>C. L. Flint.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hay cap</b></col>, <cd>a canvas covering for a
haycock.</cd> -- <col><b>Hay fever</b></col> <fld>(Med.)</fld>,
<cd>nasal catarrh accompanied with fever, and sometimes with paroxysms
of dyspn<oe/a, to which some persons are subject in the spring and
summer seasons. It has been attributed to the effluvium from hay, and to
the pollen of certain plants. It is also called <altname>hay
asthma</altname>, <altname>hay cold</altname>, <altname>rose
cold</altname>, and <altname>rose fever</altname>.</cd> -- <col><b>Hay
knife</b></col>, <cd>a sharp instrument used in cutting hay out of a
stack or mow.</cd> -- <col><b>Hay press</b></col>, <cd>a press for
baling loose hay.</cd> -- <col><b>Hay tea</b></col>, <cd>the juice of
hay extracted by boiling, used as food for cattle, etc.</cd> --
<col><b>Hay tedder</b></col>, <cd>a machine for spreading and turning
new-mown hay. See <er>Tedder</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hay</ent><br/
<hw>Hay</hw>, <pos>v. i.</pos> <def>To cut and cure grass for
hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haybird</ent><br/
<hw>Hay"bird`</hw> <pr>(h<amac/"b<etil/rd`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The European spotted
flycatcher.</def> <sd>(b)</sd> <def>The European blackcap.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haybote</ent><br/
<hw>Hay"bote`</hw> <pr>(h<amac/"b<omac/t`)</pr>, <pos>n.</pos> <ety>[See
<er>Hay</er> hedge, and <er>Bote</er>, and cf.
<er>Hedgebote</er>.]</ety> <fld>(Eng. Law.)</fld> <def>An allowance of
wood to a tenant for repairing his hedges or fences; hedgebote. See
<er>Bote</er>.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haycock</ent><br/
<hw>Hay"cock`</hw> <pr>(h<amac/"k<ocr/k`)</pr>, <pos>n.</pos> <def>A
conical pile or heap of hay in the field.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The tanned <qex>haycock</qex> in the mead.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hay-cutter</ent><br/
<hw>Hay"-cut`ter</hw> <pr>(h<amac/"k<ucr/t`t<etil/r)</pr>, <pos>n.</pos>
<def>A machine in which hay is chopped short, as fodder for
cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayfield</ent><br/
<hw>Hay"field`</hw> <pr>(h<amac/"f<emac/ld`)</pr>, <pos>n.</pos> <def>A
field where grass for hay has been cut; a meadow.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayfork</ent><br/
<hw>Hay"fork`</hw> <pr>(h<amac/"f<ocir/rk`)</pr>, <pos>n.</pos> <def>A
fork for pitching and tedding hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horse hayfork</b></col>, <cd>a contrivance for unloading
hay from the cart and depositing it in the loft, or on a mow, by horse
power.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayloft</ent><br/
<hw>Hay"loft`</hw> <pr>(h<amac/"l<ocr/ft`; 115)</pr>, <pos>n.</pos>
<def>A loft or scaffold for hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haymaker</ent><br/
<hw>Hay"mak`er</hw> <pr>(h<amac/"m<amac/k`<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who cuts and cures hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A machine for curing hay in rainy weather.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A forceful punch that results in someone being
knocked down or knocked out; <as>as, he delivered a <ex>haymaker</ex> to
his opponent's jaw</as>.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Haymaking</ent><br/
<hw>Hay"mak`ing</hw>, <pos>n.</pos> <def>The operation or work of
cutting grass and curing it for hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haymow</ent><br/
<hw>Hay"mow`</hw> <pr>(h<amac/"mou`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A mow or mass of hay laid up in a barn for preservation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place in a barn where hay is
deposited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayrack</ent><br/
<hw>Hay"rack`</hw> <pr>(h<amac/"r<acr/k`)</pr>, <pos>n.</pos> <def>A
frame mounted on the running gear of a wagon, and used in hauling hay,
straw, sheaves, etc.; -- called also <altname>hay rigging</altname> and
<altname>hay rig</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayrake</ent><br/
<hw>Hay"rake`</hw> <pr>(h<amac/"r<amac/k`)</pr>, <pos>n.</pos> <def>A
rake for collecting hay; especially, a large rake drawn by a horse or
horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayrick</ent><br/
<hw>Hay"rick`</hw> <pr>(-r<icr/k`)</pr>, <pos>n.</pos> <def>A heap or
pile of hay, usually covered with thatch for preservation in the open
air.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hayrig</ent><br/
<hw>hay"rig</hw> <pos>n.</pos> <def>a frame attached to a wagon to
increase the amount of hay it can carry.</def><br/
<syn><b>Syn. --</b> hayrack, hay rigging.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hayseed</ent><br/
<hw>hay"seed</hw> <pos>n.</pos> <sn>1.</sn> <def>a rural,
unsophisticated person; also used in an extended sense for one who is
not very intelligent or uninterested in culture.</def><br/
<syn><b>Syn. --</b> yokel, rube, hick, yahoo, bumpkin,
chawbacon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Seed from grass, especially that which falls out of
hay.</def><br/
[<source>PJC</source>]</p>

<p><ent>Haystack</ent><br/
<hw>Hay"stack`</hw> <pr>(h<amac/"st<acr/k`)</pr>, <pos>n.</pos> <def>A
stack or conical pile of hay in the open air.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haystalk</ent><br/
<hw>Hay"stalk`</hw> <pr>(h<amac/"st<add/k`)</pr>, <pos>n.</pos> <def>A
stalk of hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haythorn</ent><br/
<hw>Hay"thorn`</hw> <pr>(h<amac/"th<ocir/rn`)</pr>, <pos>n.</pos>
<def>Hawthorn.</def> <rj><au>R. Scot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haytian</ent><br/
<hw>Hay"ti*an</hw> <pr>(h<amac/"t<icr/*<ait/n)</pr>, <pos>a.</pos>
<def>Of or pertaining to Haiti; now usually written
<altname>Haitian</altname>.</def> -- <def2><pos>n.</pos> <def>A native
of Haiti.</def></def2> <altsp>[Written also
<asp>Haitian</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hayward</ent><br/
<hw>Hay"ward</hw> <pr>(h<amac/"w<etil/rd)</pr>, <pos>n.</pos>
<ety>[<ets>Hay</ets> a hedge + <ets>ward</ets>.]</ety> <def>An officer
who is appointed to guard hedges, and to keep cattle from breaking or
cropping them, and whose further duty it is to impound animals found
running at large.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazard</ent><br/
<hw>Haz"ard</hw> <pr>(h<acr/z"<etil/rd)</pr>, <pos>n.</pos> <ety>[F.
<ets>hasard</ets>, Sp. <ets>azar</ets> an unforeseen disaster or
accident, an unfortunate card or throw at dice, prob. fr. Ar.
<ets>zahr</ets>, <ets>z<amac/r</ets>, a die, which, with the article
<ets>al</ets> the, would give <ets>azzahr</ets>,
<ets>azz<amac/r</ets>.]</ety> <sn>1.</sn> <def>A game of chance played
with dice.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The uncertain result of throwing a die; hence, a
fortuitous event; chance; accident; casualty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will stand the <qex>hazard</qex> of the die.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Risk; danger; peril; <as>as, he encountered the
enemy at the <ex>hazard</ex> of his reputation and life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men are led on from one stage of life to another in a condition of
the utmost <qex>hazard</qex>.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Billiards)</fld> <def>Holing a ball, whether the
object ball (winning <xex>hazard</xex>) or the player's ball (losing
<xex>hazard</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Anything that is hazarded or risked, as the stakes
in gaming.</def> <ldquo/Your latter <xex>hazard</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Golf)</fld> <def>Any place into which the ball may
not be safely played, such as bunkers, furze, water, sand, or other kind
of bad ground.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Hazard table</b></col>, <cd>a table on which hazard is
played, or any game of chance for stakes.</cd> -- <col><b>To run the
hazard</b></col>, <cd>to take the chance or risk.</cd> -- <col><b>to
hazard</b></col>, <cd>at risk; liable to suffer damage or
loss.</cd></cs></p>

<p><syn><b>Syn.</b> -- Danger; risk; chance. See
<er>Danger</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazard</ent><br/
<hw>Haz"ard</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hazarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hazarding</conjf>.]</vmorph> <ety>[Cf. F. <ets>hasarder</ets>.
See <er>Hazard</er>, <pos>n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To expose to the operation of chance; to put in
danger of loss or injury; to venture; to risk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men <qex>hazard</qex> nothing by a course of evangelical
obedience.</q> <rj><qau>John Clarke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>hazards</qex> his neck to the halter.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To venture to incur, or bring on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>hazarded</qex> the loss of whom I loved.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>hazard</qex> to cut their feet.</q>
<rj><qau>Landor.</qau></rj></p>

<p><syn><b>Syn.</b> -- To venture; risk; jeopard; peril;
endanger.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazard</ent><br/
<hw>Haz"ard</hw> <pr>(h<acr/z"<etil/rd)</pr>, <pos>v. i.</pos> <def>To
try the chance; to encounter risk or danger.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazardable</ent><br/
<hw>Haz"ard*a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Liable to hazard or chance; uncertain; risky.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Such as can be hazarded or risked.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazarder</ent><br/
<hw>Haz"ard*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A player at the game of hazard; a gamester.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who hazards or ventures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazardize</ent><br/
<hw>Haz"ard*ize</hw> <pr>(-<imac/z)</pr>, <pos>n.</pos> <def>A hazardous
attempt or situation; hazard.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Herself had run into that <qex>hazardize</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazardous</ent><br/
<hw>Haz"ard*ous</hw> <pr>(-<ucr/s)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hasardeux</ets>.]</ety> <def>Exposed to hazard; dangerous;
risky.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To enterprise so <qex>hazardous</qex> and high!</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Perilous; dangerous; bold; daring; adventurous;
venturesome; precarious; uncertain.</syn></p>

<p>-- <wordforms><wf>Haz"ard*ous*ly</wf>, <pos>adv.</pos> --
<wf>Haz"ard*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>hazardousness</ent><br/
<hw>haz"ard*ous*ness</hw> <pos>n.</pos> <def>the state of being
dangerous.</def><br/
<syn><b>Syn. --</b> perilousness, precariousness, danger.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hazardry</ent><br/
<hw>Haz"ard*ry</hw> <pr>(-r<ycr/)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Playing at hazard; gaming; gambling.</def> <mark>[R.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rashness; temerity.</def> <mark>[R.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haze</ent><br/
<hw>Haze</hw> <pr>(h<amac/z)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>h<oum/ss</ets> gray; akin to AS. <ets>hasu</ets>, <ets>heasu</ets>,
gray; or Armor. <ets>a<eacute/zen</ets>, <ets><eacute/zen</ets>, warm
vapor, exhalation, zephyr.]</ety> <sn>1.</sn> <def>Light vapor or smoke
in the air which more or less impedes vision, with little or no
dampness; a lack of transparency in the air; hence, figuratively,
obscurity; dimness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O'er the sky<br/
The silvery <qex>haze</qex> of summer drawn.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Above the world's uncertain <qex>haze</qex>.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of confusion, uncertainty, or vagueness of
thought or perception; <as>as, after the explosion, people were
wandering around in a <ex>haze</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Haze</ent><br/
<hw>Haze</hw>, <pos>v. i.</pos> <def>To be hazy, or thick with
haze.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haze</ent><br/
<hw>Haze</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hazed</conjf> <pr>(h<amac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hazing</conjf>.]</vmorph> <altsp>[Also <asp>hase</asp>.]</altsp>
<ety>[Cf. Sw. <ets>haza</ets> to hamstring, fr. <ets>has</ets> hough,
OD. <ets>h<ae/ssen</ets> ham.]</ety> <sn>1.</sn> <def>To harass by
exacting unnecessary, disagreeable, or difficult work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To harass or annoy by playing abusive or shameful
tricks upon; to humiliate by practical jokes; -- used esp. of college
students, as an initiation rite into a fraternity or other group;
<as>as, the sophomores <ex>hazed</ex> a freshman</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazel</ent><br/
<hw>Ha"zel</hw> <pr>(h<amac/"z'l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hasel</ets>, AS. <ets>h<ae/sel</ets>; akin to D.
<ets>hazelaar</ets>, G. <ets>hazel</ets>, OHG. <ets>hasal</ets>,
<ets>hasala</ets>, Icel. <ets>hasl</ets>, Dan & Sw. <ets>hassel</ets>,
L. <ets>corylus</ets>, for <ets>cosylus</ets>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A shrub or small tree of the genus
<gen>Corylus</gen>, as the <spn>Corylus avellana</spn>, bearing a nut
containing a kernel of a mild, farinaceous taste; the filbert. The
American species are <spn>Corylus Americana</spn>, which produces the
common hazelnut, and <spn>Corylus rostrata</spn>. See
<er>Filbert</er>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A miner's name for freestone.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hazel earth</b></col>, <cd>soil suitable for the hazel; a
fertile loam.</cd> -- <col><b>Hazel grouse</b></col> <fld>(Zool.)</fld>,
<cd>a European grouse (<spn>Bonasa betulina</spn>), allied to the
American ruffed grouse.</cd> -- <col><b>Hazel hoe</b></col>, <cd>a kind
of grub hoe.</cd> -- <col><b>Witch hazel</b></col>. <cd>See
<er>Witch-hazel</er>, and <er>Hamamelis</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazel</ent><br/
<hw>Ha"zel</hw>, <pos>a.</pos> <sn>1.</sn> <def>Consisting of hazels, or
of the wood of the hazel; pertaining to, or derived from, the hazel;
<as>as, a <ex>hazel</ex> wand</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I sit me down beside the <qex>hazel</qex> grove.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of a light brown color, like the hazelnut.</def>
<ldquo/Thou hast <xex>hazel</xex> eyes.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazeless</ent><br/
<hw>Haze"less</hw> <pr>(h<amac/z"l<ecr/s)</pr>, <pos>a.</pos>
<def>Destitute of haze.</def> <rj><au>Tyndall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazelly</ent><br/
<hw>Ha"zel*ly</hw> <pr>(h<amac/"z'l*l<ycr/)</pr>, <pos>a.</pos> <def>Of
the color of the hazelnut; of a light brown.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazelnut</ent><br/
<hw>Ha"zel*nut`</hw> <pr>(h<amac/"z'l*n<ucr/t`)</pr>, <pos>n.</pos>
<ety>[AS. <ets>h<ae/selhnutu</ets>.]</ety> <def>The nut of the
hazel.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hazelwood</ent><br/
<hw>hazelwood</hw> <pos>n.</pos> <def>A reddish-brown wood and lumber
from the heartwood of the sweet gum tree.</def><br/
<syn><b>Syn. --</b> sweet gum, satin walnut, red gum.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hazelwort</ent><br/
<hw>Ha"zel*wort`</hw> <pr>(-w<ucr/rt)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The asarabacca.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazily</ent><br/
<hw>Ha"zi*ly</hw> <pr>(h<amac/"z<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a hazy manner; mistily; obscurely; confusedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Haziness</ent><br/
<hw>Ha"zi*ness</hw>, <pos>n.</pos> <def>The quality or state of being
hazy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazle</ent><br/
<hw>Ha"zle</hw> <pr>(h<amac/"z'l)</pr>, <pos>v. t.</pos> <def>To make
dry; to dry.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hazy</ent><br/
<hw>Ha"zy</hw> <pr>(h<amac/"z<ycr/)</pr>, <pos>a.</pos> <ety>[From
<er>Haze</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Thick with haze;
somewhat obscured with haze; not clear or transparent.</def> <ldquo/A
tender, <xex>hazy</xex> brightness.<rdquo/
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Obscure; confused; not clear; <as>as, a
<ex>hazy</ex> argument; a <ex>hazy</ex> intellect.</as></def>
<rj><au>Mrs. Gore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>H-bomb</ent><br/
<hw>H"-bomb`</hw> <pr>(<amac/ch"b<ocr/mb`)</pr> <pos>n.</pos> <def>The
<altname>hydrogen bomb</altname>, a thermonuclear weapon that releases
atomic energy by union of hydrogen nuclei at high temperatures to form
helium. The force of its explosion may range from one to hundreds of
megatons of TNT equivalent.</def><br/
<syn><b>Syn. --</b> hydrogen bomb, fusion bomb, thermonuclear
bomb.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>HDL</ent><br/
<hw>HDL</hw> <pr>(<amac/ch`d<emac/*<ecr/l")</pr>, <pos>n.</pos>
<def>High density lipoprotein, a lipoprotein that transports cholesterol
in the blood; high levels are thought to be associated with decreased
risk of coronary heart disease and atherosclerosis; sometimes called
<altname>good cholesterol</altname>. Contrasted with
<contr>LDL</contr>.</def><br/
<syn><b>Syn. --</b> high-density lipoprotein.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>He</ent><br/
<hw>He</hw> <pr>(h<emac/)</pr>, <pos>pron.</pos>
<nmorph>[<pos>nom.</pos> <decf>He</decf>; <pos>poss.</pos>
<decf>His</decf> <pr>(h<icr/z)</pr>; <pos>obj.</pos> <decf>Him</decf>
<pr>(h<icr/m)</pr>; <pos>pl. nom.</pos> <decf>They</decf>
<pr>(<th/<amac/)</pr>; <pos>poss.</pos> <decf>Their</decf> or
<decf>Theirs</decf> <pr>(<th/<acir/rz <it>or</it> <th/<amac/rz)</pr>;
<pos>obj.</pos> <decf>Them</decf> <pr>(<th/<ecr/m)</pr>.]</nmorph>
<ety>[AS. <ets>h<emac/</ets>, masc., <ets>he<oacute/</ets>, fem.,
<ets>hit</ets>, neut.; pl. <ets>h<imac/</ets>, or <ets>hie</ets>,
<ets>hig</ets>; akin to OFries. <ets>hi</ets>, D. <ets>hij</ets>, OS.
<ets>he</ets>, <ets>hi</ets>, G. <ets>heute</ets> to-day, Goth.
<ets>himma</ets>, dat. masc., this, <ets>hina</ets>, accus. masc., and
<ets>hita</ets>, accus. neut., and prob. to L. <ets>his</ets> this.
<root/183. Cf. <er>It</er>.]</ety> <sn>1.</sn> <def>The man or male
being (or object personified to which the masculine gender is assigned),
previously designated; a pronoun of the masculine gender, usually
referring to a specified subject already indicated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy desire shall be to thy husband, and <qex>he</qex> shall rule
over thee.</q> <rj><qau>Gen. iii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt fear the Lord thy God; <qex>him</qex> shalt thou
serve.</q> <rj><qau>Deut. x. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any one; the man or person; -- used indefinitely,
and usually followed by a relative pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>He</qex> that walketh with wise men shall be wise.</q>
<rj><qau>Prov. xiii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Man; a male; any male person; -- in this sense used
substantively.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I stand to answer thee,<br/
Or any <qex>he</qex>, the proudest of thy sort.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When a collective noun or a class is referred to,
<xex>he</xex> is of common gender. In early English, <ex>he</ex>
referred to a feminine or neuter noun, or to one in the plural, as well
as to noun in the masculine singular. In composition, <ex>he</ex>
denotes a male animal; as, a <ex>he</ex>-goat.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>He</ent><br/
<hw>He</hw> <pr>(?)</pr>, <fld>(Chem.)</fld> <def>The chemical symbol
for <er>helium</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>-head</ent><br/
<hw>-head</hw> <pr>(-h<ecr/d)</pr>, <pos>suffix.</pos> <def>A variant of
<er>-hood</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Head</ent><br/
<hw>Head</hw> <pr>(h<ecr/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hed</ets>, <ets>heved</ets>, <ets>heaved</ets>, AS.
<ets>he<aacute/fod</ets>; akin to D. <ets>hoofd</ets>, OHG.
<ets>houbit</ets>, G. <ets>haupt</ets>, Icel. <ets>h<oum/fu<edh/</ets>,
Sw. <ets>hufvud</ets>, Dan. <ets>hoved</ets>, Goth.
<ets>haubi<thorn/</ets>. The word does not correspond regularly to L.
<ets>caput</ets> head (cf. E. <er>Chief</er>, <er>Cadet</er>,
<er>Capital</er>), and its origin is unknown.]</ety> <sn>1.</sn>
<def>The anterior or superior part of an animal, containing the brain,
or chief ganglia of the nervous system, the mouth, and in the higher
animals, the chief sensory organs; poll; cephalon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The uppermost, foremost, or most important part of
an inanimate object; such a part as may be considered to resemble the
head of an animal; often, also, the larger, thicker, or heavier part or
extremity, in distinction from the smaller or thinner part, or from the
point or edge; <as>as, the <ex>head</ex> of a cane, a nail, a spear, an
ax, a mast, a sail, a ship</as>; that which covers and closes the top or
the end of a hollow vessel; <as>as, the <ex>head</ex> of a cask or a
steam boiler</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The place where the head should go; <as>as, the
<ex>head</ex> of a bed, of a grave, etc.; the <ex>head</ex> of a
carriage, that is, the hood which covers the head</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The most prominent or important member of any
organized body; the chief; the leader; <as>as, the <ex>head</ex> of a
college, a school, a church, a state, and the like</as>.</def>
<ldquo/Their princes and <xex>heads</xex>.<rdquo/ <rj><au>Robynson
(More's Utopia).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heads</qex> of the chief sects of philosophy.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>head</qex> I him appoint.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The place or honor, or of command; the most
important or foremost position; the front; <as>as, the <ex>head</ex> of
the table; the <ex>head</ex> of a column of soldiers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>An army of fourscore thousand troops, with the duke of Marlborough
at the <qex>head</qex> of them.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Each one among many; an individual; -- often used in
a plural sense; <as>as, a thousand <ex>head</ex> of
cattle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It there be six millions of people, there are about four acres for
every <qex>head</qex>.</q> <rj><qau>Graunt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The seat of the intellect; the brain; the
understanding; the mental faculties; <as>as, a good <ex>head</ex>, that
is, a good mind; it never entered his <ex>head</ex>, it did not occur to
him; of his own <ex>head</ex>, of his own thought or
will.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men who had lost both <qex>head</qex> and heart.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The source, fountain, spring, or beginning, as of a
stream or river; <as>as, the <ex>head</ex> of the Nile</as>; hence, the
altitude of the source, or the height of the surface, as of water, above
a given place, as above an orifice at which it issues, and the pressure
resulting from the height or from motion; sometimes also, the quantity
in reserve; <as>as, a mill or reservoir has a good <ex>head</ex> of
water, or ten feet <ex>head</ex></as>; also, that part of a gulf or bay
most remote from the outlet or the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A headland; a promontory; <as>as, Gay
<ex>Head</ex></as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A separate part, or topic, of a discourse; a theme
to be expanded; a subdivision; <as>as, the <ex>heads</ex> of a
sermon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Culminating point or crisis; hence, strength;
force; height.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere foul sin, gathering <qex>head</qex>, shall break into
corruption.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The indisposition which has long hung upon me, is at last grown to
such a <qex>head</qex>, that it must quickly make an end of me or of
itself.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Power; armed force.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My lord, my lord, the French have gathered <qex>head</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>A headdress; a covering of the head; <as>as, a
laced <ex>head</ex>; a <ex>head</ex> of hair.</as></def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>An ear of wheat, barley, or of one of the other
small cereals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>A dense cluster of
flowers, as in clover, daisies, thistles; a capitulum.</def>
<sd>(b)</sd> <def>A dense, compact mass of leaves, as in a cabbage or a
lettuce plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>The antlers of a deer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>A rounded mass of foam which rises on a pot of beer
or other effervescing liquor.</def> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <pluf>pl.</pluf> <def>Tiles laid at the eaves of a
house.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Head</xex> is often used adjectively or in
self-explaining combinations; as, <xex>head</xex> gear or
<xex>head</xex>gear, <xex>head</xex> rest. Cf. <er>Head</er>,
<pos>a.</pos></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A buck of the first head</b></col>, <cd>a male fallow
deer in its fifth year, when it attains its complete set of
antlers.</cd> <au>Shak.</au> -- <col><b>By the head</b></col>.
<fld>(Naut.)</fld> <cd>See under <er>By</er>.</cd> --
<mcol><col><b>Elevator head</b></col>, <col><b>Feed head</b></col>,
etc.</mcol> <cd>See under <er>Elevator</er>, <er>Feed</er>, etc.</cd> --
<col><b>From head to foot</b></col>, <cd>through the whole length of a
man; completely; throughout.</cd> <ldquo/Arm me, audacity, from
<xex>head to foot</xex>.<rdquo/ <au>Shak.</au> -- <col><b>Head and
ears</b></col>, <cd>with the whole person; deeply; completely; as, he
was <xex>head and ears</xex> in debt or in trouble.</cd>
<mark>[Colloq.]</mark> -- <col><b>Head fast</b></col>.
<fld>(Naut.)</fld> <cd>See 5th <er>Fast</er>.</cd> -- <col><b>Head
kidney</b></col> <fld>(Anat.)</fld>, <cd>the most anterior of the three
pairs of embryonic renal organs developed in most vertebrates; the
pronephros.</cd> -- <col><b>Head money</b></col>, <cd>a capitation tax;
a poll tax.</cd> <au>Milton.</au> -- <col><b>Head pence</b></col>, <cd>a
poll tax.</cd> <mark>[Obs.]</mark> -- <col><b>Head sea</b></col>, <cd>a
sea that meets the head of a vessel or rolls against her course.</cd> --
<col><b>Head and shoulders</b></col>. <sd>(a)</sd> <cd>By force;
violently; as, to drag one, <xex>head and shoulders</xex>.</cd>
<ldquo/They bring in every figure of speech, <xex>head and
shoulders</xex>.<rdquo/ <au>Felton.</au> <sd>(b)</sd> <cd>By the height
of the head and shoulders; hence, by a great degree or space; by far;
much; as, he is <xex>head and shoulders</xex> above them.</cd> --
<mcol><col><b>Heads or tails</b></col> <it>or</it> <col><b>Head or
tail</b></col></mcol>, <cd>this side or that side; this thing or that;
-- a phrase used in throwing a coin to decide a choice, question, or
stake, <xex>head</xex> being the side of the coin bearing the effigy or
principal figure (or, in case there is no head or face on either side,
that side which has the date on it), and <xex>tail</xex> the other
side.</cd> -- <col><b>Neither head nor tail</b></col>, <cd>neither
beginning nor end; neither this thing nor that; nothing distinct or
definite; -- a phrase used in speaking of what is indefinite or
confused; as, they made <xex>neither head nor tail</xex> of the
matter.</cd> <mark>[Colloq.]</mark> -- <col><b>Head wind</b></col>,
<cd>a wind that blows in a direction opposite the vessel's course.</cd>
-- <col><b>off the top of my head</b></col>, <cd>from quick
recollection, or as an approximation; without research or calculation;
-- a phrase used when giving quick and approximate answers to questions,
to indicate that a response is not necessarily accurate.</cd> --
<col><b>Out of one's own head</b></col>, <cd>according to one's own
idea; without advice or co<oum/peration of another.</cd> -- <col><b>Over
the head of</b></col>, <cd>beyond the comprehension of.</cd> <au>M.
Arnold.</au> -- <col><b>to go over the head of (a person)</b></col>,
<cd>to appeal to a person superior to (a person) in line of
command.</cd> -- <col><b>To be out of one's head</b></col>, <cd>to be
temporarily insane.</cd> -- <col><b>To come or draw to a head</b></col>.
<cd>See under <er>Come</er>, <er>Draw</er>.</cd> -- <mcol><col><b>To
give <plain>(one)</plain> the head</b></col>, <it>or</it> <col><b>To
give head</b></col></mcol>, <cd>to let go, or to give up, control; to
free from restraint; to give license.</cd> <ldquo/He <xex>gave</xex> his
able horse <xex>the head</xex>.<rdquo/ <au>Shak.</au> <ldquo/He has so
long <xex>given</xex> his unruly passions their <xex>head</xex>.<rdquo/
<au>South.</au> -- <col><b>To his head</b></col>, <cd>before his
face.</cd> <ldquo/An uncivil answer from a son to a father, from an
obliged person to a benefactor, is a greater indecency than if an enemy
should storm his house or revile him <xex>to his head</xex>.<rdquo/
<au>Jer. Taylor.</au> -- <col><b>To lay heads together</b></col>, <cd>to
consult; to conspire.</cd> -- <col><b>To lose one's head</b></col>,
<cd>to lose presence of mind.</cd> -- <mcol><col><b>To make
head</b></col>, <it>or</it> <col><b>To make head
against</b></col></mcol>, <cd>to resist with success; to advance.</cd>
-- <col><b>To show one's head</b></col>, <cd>to appear.</cd>
<au>Shak.</au> -- <col><b>To turn head</b></col>, <cd>to turn the face
or front.</cd> <ldquo/The ravishers <xex>turn head</xex>, the fight
renews.<rdquo/ <au>Dryden.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 677 pr=JMD --></p>

<p><ent>Head</ent><br/
<hw>Head</hw> <pr>(h<ecr/d)</pr>, <pos>a.</pos> <def>Principal; chief;
leading; first; <as>as, the <ex>head</ex> master of a school; the
<ex>head</ex> man of a tribe; a <ex>head</ex> chorister; a <ex>head</ex>
cook.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Head</ent><br/
<hw>Head</hw> <pr>(h<ecr/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Headed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Heading</conjf>.]</vmorph> <sn>1.</sn> <def>To be at the head of;
to put one's self at the head of; to lead; to direct; to act as leader
to; <as>as, to <ex>head</ex> an army, an expedition, or a
riot</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form a head to; to fit or furnish with a head;
<as>as, to <ex>head</ex> a nail</as>.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To behead; to decapitate.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cut off the top of; to lop off; <as>as, to
<ex>head</ex> trees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To go in front of; to get in the front of, so as to
hinder or stop; to oppose; hence, to check or restrain; <as>as, to
<ex>head</ex> a drove of cattle; to <ex>head</ex> a person; the wind
<ex>heads</ex> a ship.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To set on the head; <as>as, to <ex>head</ex> a
cask</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To head off</b></col>, <cd>to intercept; to get before;
<as>as, an officer <ex>heads off</ex> a thief who is escaping</as>.</cd>
<ldquo/We'll <ex>head</ex> them <ex>off</ex> at the pass.<rdquo/ --
<col><b>To head up</b></col>, <sd>(a)</sd> <cd>to close, as a cask or
barrel, by fitting a head to.</cd> <sd>(b)</sd> <cd>To serve as the
leader of; <as>as, to <ex>head up</ex> a team of
investigators</as>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Head</ent><br/
<hw>Head</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To originate; to
spring; to have its source, as a river.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A broad river, that <qex>heads</qex> in the great Blue Ridge.</q>
<rj><qau>Adair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go or point in a certain direction; to tend;
<as>as, how does the ship <ex>head</ex>?</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To form a head; <as>as, this kind of cabbage
<ex>heads</ex> early</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headache</ent><br/
<hw>Head"ache`</hw> <pr>(h<ecr/d"<amac/k`)</pr>, <pos>n.</pos> <def>Pain
in the head; cephalalgia.</def> <ldquo/<xex>Headaches</xex> and
shivering fits.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headachy</ent><br/
<hw>Head"ach`y</hw>, <pos>a.</pos> <def>Afflicted with headache.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headband</ent><br/
<hw>Head"band`</hw> <pr>(h<ecr/d"b<acr/nd`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A fillet; a band for the head.</def> <ldquo/The
<xex>headbands</xex> and the tablets.<rdquo/ <rj><au>Is. iii.
20.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The band at each end of the back of a
book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headboard</ent><br/
<hw>Head"board`</hw> <pr>(h<ecr/d"b<omac/rd`)</pr>, <pos>n.</pos> <def>A
board or boarding which marks or forms the head of anything; <as>as, the
<ex>headboard</ex> of a bed; the <ex>headboard</ex> of a
grave.</as></def></p>

<p><ent>Headborrow</ent><br/
<ent>Headborough</ent><br/
<mhw>{ <hw>Head"bor*ough</hw> <hw>Head"bor*row</hw> }</mhw>
<pr>(h<ecr/d"b<ucr/r*<osl/)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
chief of a frankpledge, tithing, or decennary, consisting of ten
families; -- called also <altname>borsholder</altname>,
<altname>boroughhead</altname>, <altname>boroughholder</altname>, and
sometimes <altname>tithingman</altname>. See <er>Borsholder</er>.</def>
<mark>[Eng.]</mark> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Modern Law)</fld> <def>A petty constable.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Head-cheese</ent><br/
<hw>Head"-cheese`</hw> <pr>(h<ecr/d"ch<emac/z`)</pr>, <pos>n.</pos>
<def>A dish made of portions of the head, or head and feet, of swine,
cut up fine, seasoned, and pressed into a cheeselike mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headdress</ent><br/
<hw>Head"dress`</hw> <pr>(h<ecr/d"dr<ecr/s`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A covering or ornament for the head; a headtire;
<as>as, chiefs among the plains Indians had elaborate long
<ex>headdresses</ex> with many feathers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Among birds the males very often appear in a most beautiful
<qex>headdress</qex>, whether it be a crest, a comb, a tuft of feathers,
or a natural little plume.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A manner of dressing the hair or of adorning it,
whether with or without a veil, ribbons, combs, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headed</ent><br/
<hw>Head"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Furnished with a head
(commonly as denoting intellectual faculties); -- used in composition;
<as>as, clear-<ex>headed</ex>, long-<ex>headed</ex>,
thick-<ex>headed</ex>; a many-<ex>headed</ex> monster.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formed into a head; <as>as, a <ex>headed</ex>
cabbage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Header</ent><br/
<hw>Head"er</hw> <pr>(h<ecr/d"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, heads nails, rivets, etc., esp. a machine
for heading.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who heads a movement, a party, or a mob; head;
chief; leader.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>A brick or stone
laid with its shorter face or head in the surface of the wall.</def>
<sd>(b)</sd> <def>In framing, the piece of timber fitted between two
trimmers, and supported by them, and carrying the ends of the
tailpieces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A reaper for wheat, that cuts off the heads
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A fall or plunge head first, as while riding a
bicycle, or a skateboard, or in bathing; -- sometimes, implying the
striking of the head on the ground; <as>as, to take a
<ex>header</ex></as>.</def> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Headforemost</ent><br/
<ent>Headfirst</ent><br/
<mhw>{ <hw>Head`first"</hw> <pr>(h<ecr/d"f<etil/rst`)</pr>,
<hw>Head`fore"most`</hw> <pr>(h<ecr/d`f<omac/r"m<omac/st`)</pr>, }</mhw>
<pos>adv.</pos> <def>With the head foremost; -- of motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headfish</ent><br/
<hw>Head"fish`</hw> <pr>(h<ecr/d"f<icr/sh`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The sunfish (<gen>Mola</gen>).</def></p>

<p><ent>Headgear</ent><br/
<ent>Head gear</ent><br/
<mhw><hw>Head" gear`</hw>, <or/ <hw>Head"gear`</hw>
<pr>(h<ecr/d"g<emac/r`)</pr></mhw>, <pos>n.</pos> <sn>1.</sn>
<def>Headdress.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Apparatus above ground at the mouth of a mine or
deep well.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Head-hunter</ent><br/
<hw>Head"-hunt`er</hw> <pr>(h<ecr/d"h<ucr/nt`<etil/r)</pr>,
<pos>n.</pos> <def>A member of any tribe or race of savages who have the
custom of decapitating human beings and preserving their heads as
trophies. The Dyaks of Borneo are the most noted head-hunters.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person whose profession is to find executives to
fill open positions in corporations; an executive personnel recruiter;
also, a company that performs a similar service.</def><br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>Head"-hunt`ing</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headily</ent><br/
<hw>Head"i*ly</hw> <pr>(h<ecr/d"<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a heady or rash manner; hastily; rashly; obstinately.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headiness</ent><br/
<hw>Head"i*ness</hw>, <pos>n.</pos> <def>The quality of being
heady.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heading</ent><br/
<hw>Head"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or state of
one who, or that which, heads; formation of a head.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which stands at the head; title; <as>as, the
<ex>heading</ex> of a paper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Material for the heads of casks, barrels,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining, tunneling)</fld> <sd>(a)</sd> <def>A
gallery, drift, or adit in a mine; the vein above a drift.</def>
<sd>(b)</sd> <def>The end of a drift or gallery; also, the working face
at the end of a tunnel, gallery, drift, or adit from which the work is
advanced.</def><br/
[<source>1913 Webster</source> <source>+RH</source>]</p>

<p><sn>5.</sn> <fld>(Sewing)</fld> <def>The extension of a line ruffling
above the line of stitch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Masonry)</fld> <def>That end of a stone or brick
which is presented outward.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heading course</b></col> <fld>(Arch.)</fld>, <cd>a course
consisting only of headers. See <er>Header</er>, <pos>n.</pos> 3
<sd>(a)</sd>.</cd> -- <col><b>Heading joint</b></col>. <sd>(a)</sd>
<fld>(Carp.)</fld> <cd>A joint, as of two or more boards, etc., at right
angles to the grain of the wood.</cd> <sd>(b)</sd> <fld>(Masonry)</fld>
<cd>A joint between two roussoirs in the same course.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>head-in-the-clouds</ent><br/
<hw>head-in-the-clouds</hw> <pos>adj.</pos> <def>unable to concentrate
on matters at hand; flighty[2].</def><br/
<syn><b>Syn. --</b> flighty, scatterbrained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>headlamp</ent><br/
<hw>head"lamp`</hw> <pr>(h<ecr/d"l<acr/mp`)</pr>, <pos>n.</pos> <def>A
powerful light with a reflector, attached to the front of an automobile,
locomotive, or other vehicle; called also
<altname>headlight</altname>.</def><br/
<syn><b>Syn. --</b> headlight.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Headland</ent><br/
<hw>Head"land</hw> <pr>(h<ecr/d"l<acr/nd)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A cape; a promontory; a point of land projecting into
the sea or other expanse of water.</def> <ldquo/Sow the
<xex>headland</xex> with wheat.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ridge or strip of unplowed at the ends of furrows,
or near a fence.</def> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headless</ent><br/
<hw>Head"less</hw>, <pos>a.</pos> <ety>[AS.
<ets>he<aacute/fodle<aacute/s</ets>.]</ety> <sn>1.</sn> <def>Having no
head; beheaded; <as>as, a <ex>headless</ex> body, neck, or
carcass</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of a chief or leader.</def> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Destitute of understanding or prudence; foolish;
rash; obstinate; mindless.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Witless headiness in judging or <qex>headless</qex> hardiness in
condemning.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headlight</ent><br/
<hw>Head"light`</hw> <pr>(h<ecr/d"l<imac/t`)</pr>, <pos>n.</pos>
<fld>(Engin.)</fld> <def>A light, with a powerful reflector, placed at
the front of a vehicle such as an automobile, truck, locomotive etc., to
throw light on the road or track ahead of the vehicle at night, or in
going through a dark tunnel; a <altname>headlamp</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Headline</ent><br/
<hw>Head"line`</hw> <pr>(-l<imac/n`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Print.)</fld> <def>The line at the head or top of a
page.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>See <er>Headrope</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Journalism)</fld> <def>A title for an article in a
newspaper, sometimes one line, sometimes more, set in larger and bolder
type than the body of the article and indicating the subject matter or
content of the article.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A similar title at the top of the newspaper
indicating the most important story of the day; also, a title for an
illustration or picture.</def><br/
[<source>PJC</source>]</p>

<p><ent>headline</ent><br/
<hw>head"line`</hw> <pr>(-l<imac/n`)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To mention in a headline.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To furnish with a headline (senses 1, 3, or
4).</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To publicise prominently in an
advertisement.</def><br/
[<source>PJC</source>]</p>

<p><ent>headlinese</ent><br/
<hw>headlinese</hw> <pos>n.</pos> <def>The abbreviated writing style of
headline writers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>headlock</ent><br/
<hw>head"lock`</hw> <fld>(Sport)</fld>, <pos>n.</pos> <def>A wrestling
hold in which the opponent's head is locked between the crook of your
elbow and the side of your body.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Headlong</ent><br/
<hw>Head"long`</hw> <pr>(-l<ocr/ng`; 115)</pr>, <pos>adv.</pos>
<ety>[OE. <ets>hedling</ets>, <ets>hevedlynge</ets>; prob. confused with
E. <ets>long</ets>, <pos>a. & adv.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>With the head foremost; headforemost; head first;
<as>as, to fall <ex>headlong</ex></as>.</def> <rj><au>Acts i.
18.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rashly; precipitately; without
deliberation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hastily; without delay or respite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headlong</ent><br/
<hw>Head"long</hw>, <pos>a.</pos> <sn>1.</sn> <def>Rash; precipitate;
<as>as, <ex>headlong</ex> folly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Steep; precipitous.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a tower upon a <qex>headlong</qex> rock.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Head-lugged</ent><br/
<hw>Head"-lugged`</hw> <pr>(-l<ucr/gd`)</pr>, <pos>a.</pos> <def>Lugged
or dragged by the head.</def> <mark>[R.]</mark> <ldquo/The
<xex>head-lugged</xex> bear.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headman</ent><br/
<hw>Head"man`</hw> <pr>(h<ecr/d"m<acr/n`)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Headmen</plw> <pr>(-m<ecr/n`)</pr>.</plu>
<ety>[AS. <ets>he<aacute/fodman</ets>.]</ety> <def>A head or leading
man, especially of a village community.</def></p>

<p><ent>Headmould shot</ent><br/
<ent>Headmold shot</ent><br/
<mhw>{ <hw>Head"mold` shot"</hw>, <hw>Head"mould` shot"</hw> }</mhw>
<pr>(-m<omac/ld` sh<ocr/t`)</pr>. <fld>(Med.)</fld> <def>An old name for
the condition of the skull, in which the bones ride, or are
<xex>shot</xex>, over each other at the sutures.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headmost</ent><br/
<hw>Head"most`</hw> <pr>(-m<omac/st`)</pr>, <pos>a.</pos> <def>Most
advanced; most forward; <as>as, the <ex>headmost</ex> ship in a
fleet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headnote</ent><br/
<hw>Head"note`</hw> <pr>(-n<omac/t`)</pr>, <pos>n.</pos> <def>A note at
the head of a page or chapter; in law reports, an abstract of a case,
showing the principles involved and the opinion of the court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>head-on</ent><br/
<hw>head-on</hw> <pos>adj.</pos> <sn>1.</sn> <def>characterized by
direct opposition; <as>as, a <ex>head-on</ex>
confrontation</as>.</def><br/
<syn><b>Syn. --</b> head-to-head.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Without evasion or compromise; <as>as, his usual
<ex>head-on</ex> fashion; to meet a problem
<ex>head-on</ex></as>.</def><br/
<syn><b>Syn. --</b> downright, flat-footed, forthright, foursquare,
straightforward.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>Meeting front to front; used mostly of collisions
between vehicles; <as>as, a <ex>head-on</ex> automobile
collision</as>.</def><br/
<syn><b>Syn. --</b> frontal.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Headpan</ent><br/
<hw>Head"pan`</hw> <pr>(-p<acr/n`)</pr>, <pos>n.</pos> <ety>[AS.
<ets>he<aacute/fodpanne</ets>.]</ety> <def>The brainpan.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headpiece</ent><br/
<hw>Head"piece`</hw> <pr>(-p<emac/s`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Head.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In his <qex>headpiece</qex> he felt a sore pain.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cap of defense; especially, an open one, as
distinguished from the closed helmet of the Middle Ages.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Understanding; mental faculty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eumenes had the best <qex>headpiece</qex> of all Alexander's
captains.</q> <rj><qau>Prideaux.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An engraved ornament at the head of a chapter, or of
a page.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>headpin</ent><br/
<hw>head"pin`</hw> <fld>(Bowling)</fld> <pos>n.</pos> <def>The front pin
in the triangular arrangement of ten pins.</def><br/
<syn><b>Syn. --</b> kingpin.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Headquarters</ent><br/
<hw>Head"quar`ters</hw> <pr>(-kw<add/r`t<etil/rz)</pr>, <pos>n.
pl.</pos> <ety>[but sometimes used as a <pos>n. sing.</pos>]</ety>
<sn>1.</sn> <def>The quarters or place of residence of any chief
officer, as the general in command of an army, or the head of a police
force; the place from which orders or instructions are issued; hence,
the center of authority or order.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The brain, which is the <qex>headquarters</qex>, or office, of
intelligence.</q> <rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The main office from which an organization such as a
commercial enterprise is managed; -- usually where the chief executive
officer works.</def><br/
[<source>PJC</source>]</p>

<p><ent>Headrace</ent><br/
<hw>Head"race`</hw> <pr>(-r<amac/s`)</pr>, <pos>n.</pos> <def>See
<er>Race</er>, a water course.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headroom</ent><br/
<hw>Head"room`</hw> <pr>(-r<oomac/m`)</pr>, <pos>n.</pos>
<fld>(Arch.)</fld> <def>See <er>Headway</er>, 2.</def> <mark>[Mostly
Brit.]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Headrope</ent><br/
<hw>Head"rope`</hw> <pr>(-r<omac/p`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>That part of a boltrope which is sewed to the
upper edge or head of a sail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headsail</ent><br/
<hw>Head"sail`</hw> <pr>(-s<amac/l`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>Any sail set forward of the foremast.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headshake</ent><br/
<hw>Head`shake`</hw> <pr>(-sh<amac/k`)</pr>, <pos>n.</pos> <def>A
significant shake of the head, commonly as a signal of denial.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headship</ent><br/
<hw>Head"ship</hw>, <pos>n.</pos> <def>Authority or dignity; chief
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headsman</ent><br/
<hw>Heads"man</hw> <pr>(h<ecr/dz"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Headsmen</plw> <pr>(-m<eit/n)</pr>.</plu> <def>An
executioner who cuts off heads.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headspring</ent><br/
<hw>Head"spring`</hw> <pr>(h<ecr/d"spr<icr/ng`)</pr>, <pos>n.</pos>
<def>Fountain; source.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>headspring</qex> of our belief.</q>
<rj><qau>Stapleton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headstall</ent><br/
<hw>Head"stall`</hw> <pr>(-st<add/l`)</pr>, <pos>n.</pos> <def>That part
of a bridle or halter which encompasses the head.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headstock</ent><br/
<hw>Head"stock`</hw> <pr>(-st<ocr/k`)</pr>, <pos>n.</pos>
<fld>(Mach.)</fld> <def>A part (usually separate from the bed or frame)
for supporting some of the principal working parts of a machine</def>;
as: <sd>(a)</sd> <def>The part of a lathe that holds the revolving
spindle and its attachments; -- also called <altname>poppet
head</altname>, the opposite corresponding part being called a
<xex>tailstock</xex>.</def> <sd>(b)</sd> <def>The part of a planing
machine that supports the cutter, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headstone</ent><br/
<hw>Head"stone`</hw> <pr>(-st<omac/n`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The principal stone in a foundation; the chief or corner
stone.</def> <rj><au>Ps. cxviii. 22.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The stone at the head of a grave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headstrong</ent><br/
<hw>Head"strong`</hw> <pr>(-str<ocr/ng`; 115)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Not easily restrained; ungovernable; obstinate;
stubborn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now let the <qex>headstrong</qex> boy my will control.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Directed by ungovernable will, or proceeding from
obstinacy; <as>as, a <ex>headstrong</ex> course</as>.</def>
<rj><au>Dryden.</au></rj></p>

<p><syn><b>Syn.</b> -- Violent; obstinate; ungovernable; untractable;
stubborn; unruly; venturesome; heady.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headstrongness</ent><br/
<hw>Head"strong`ness</hw>, <pos>n.</pos> <def>Obstinacy.</def>
<mark>[R.]</mark> <rj><au>Gayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heads-up</ent><br/
<hw>heads-up</hw> <pos>adj.</pos> <def>maintaining presence of mind;
alert and attentive; able to recognize and take quick advantage of
opportunities; resourceful; <as>as, he played good <ex>heads-up</ex>
baseball</as>.</def><br/
<syn><b>Syn. --</b> wide-awake.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>heads-up</ent><br/
<hw>heads-up</hw> <pos>n.</pos> <ety>[From its use as an interjection to
warn of impending danger.]</ety> <def>a warning to be prepared for an
imminent event.</def><br/
[<source>PJC</source>]</p>

<p><ent>Headtire</ent><br/
<hw>Head"tire`</hw> <pr>(-t<imac/r`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A headdress.</def> <ldquo/A <xex>headtire</xex> of fine
linen.<rdquo/ <rj><au>1 Esdras iii. 6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manner of dressing the head, as at a particular
time and place.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Headwater</ent><br/
<hw>Head"wa`ter</hw> <pr>(-w<amac/`)</pr>, <pos>n.</pos> <def>The source
and upper part of a stream; -- commonly used in the plural; <as>as, the
<ex>headwaters</ex> of the Missouri</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Headway</ent><br/
<hw>Head"way`</hw> <pr>(-w<ucir/rk`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The progress made by a ship in motion; hence, progress or success
of any kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>Clear space under an arch,
girder, and the like, sufficient to allow of easy passing underneath;
clearance; headroom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>headword</ent><br/
<hw>headword</hw> <pos>n.</pos> <sn>1.</sn> <def>a word that is
qualified by a modifier.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a word placed at the beginning of a line, paragraph,
or short article (as in a dictionary or encyclopedia entry); the word
which forms the title of an entry in a dictionary.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Headwork</ent><br/
<hw>Head"work`</hw> <pr>(h<ecr/d"w<ucir/rk`)</pr>, <pos>n.</pos>
<def>Mental labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heady</ent><br/
<hw>Head"y</hw> <pr>(h<ecr/d"<ycr/)</pr>, <pos>a.</pos> <ety>[From
<er>Head</er>.]</ety> <sn>1.</sn> <def>Willful; rash; precipitate;
hurried on by will or passion; ungovernable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the talent required is to be hot, to be <qex>heady</qex>, --
to be violent on one side or the other.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Apt to affect the head; intoxicating;
strong.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The liquor is too <qex>heady</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Violent; impetuous.</def> <ldquo/A <xex>heady</xex>
currance.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heal</ent><br/
<hw>Heal</hw> <pr>(h<emac/l)</pr>, <pos>v. t.</pos> <ety>[See
<er>Hele</er>.]</ety> <def>To cover, as a roof, with tiles, slate, lead,
or the like.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heal</ent><br/
<hw>Heal</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Healed</conjf> <pr>(h<emac/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Healing</conjf>.]</vmorph> <ety>[OE. <ets>helen</ets>,
<ets>h<ae/len</ets>, AS. <ets>h<aemac/lan</ets>, fr. <ets>h<amac/l</ets>
hale, sound, whole; akin to OS. <ets>h<emac/lian</ets>, D.
<ets>heelen</ets>, G. <ets>heilen</ets>, Goth. <ets>hailjan</ets>. See
<er>Whole</er>.]</ety> <sn>1.</sn> <def>To make hale, sound, or whole;
to cure of a disease, wound, or other derangement; to restore to
soundness or health.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Speak the word only, and my servant shall be
<qex>healed</qex>.</q> <rj><qau>Matt. viii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To remove or subdue; to cause to pass away; to cure;
-- said of a disease or a wound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>heal</qex> their backsliding.</q> <rj><qau>Hos. xiv.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To restore to original purity or
integrity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus saith the Lord, I have <qex>healed</qex> these waters.</q>
<rj><qau>2 Kings ii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To reconcile, as a breach or difference; to make
whole; to free from guilt; as, to <qex>heal</qex> dissensions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heal</ent><br/
<hw>Heal</hw> <pr>(h<emac/l)</pr>, <pos>v. i.</pos> <def>To grow sound;
to return to a sound state; <as>as, the limb <ex>heals</ex>, or the
wound <ex>heals</ex></as>; -- sometimes with <xex>up</xex> or
<xex>over</xex>; <as>as, it will <ex>heal</ex> up, or
over</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those wounds <qex>heal</qex> ill that men do give themselves.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heal</ent><br/
<hw>Heal</hw>, <pos>n.</pos> <ety>[AS. <ets>h<aemac/lu</ets>,
<ets>h<aemac/l</ets>. See <er>Heal</er>, <pos>v. t.</pos>]</ety>
<def>Health.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healable</ent><br/
<hw>Heal"a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <def>Capable
of being healed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healall</ent><br/
<hw>Heal"all`</hw> <pr>(-<add/l`)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A common herb of the Mint family (<spn>Brunella vulgaris</spn>),
destitute of active properties, but anciently thought to be a
panacea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heald</ent><br/
<hw>Heald</hw> <pr>(h<emac/ld)</pr>, <pos>n.</pos> <ety>[CF.
<er>Heddle</er>.]</ety> <def>A heddle.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healer</ent><br/
<hw>Heal"er</hw> <pr>(h<emac/l"<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, heals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healful</ent><br/
<hw>Heal"ful</hw> <pr>(h<emac/l"f<usdot/l)</pr>, <pos>a.</pos>
<def>Tending or serving to heal; healing.</def> <mark>[Obs.]</mark>
<rj><au>Ecclus. xv. 3.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healing</ent><br/
<hw>Heal"ing</hw>, <pos>a.</pos> <def>Tending to cure; soothing;
mollifying; <as>as, the <ex>healing</ex> art; a <ex>healing</ex> salve;
<ex>healing</ex> words.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here <qex>healing</qex> dews and balms abound.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healingly</ent><br/
<hw>Heal"ing*ly</hw>, <pos>adv.</pos> <def>So as to heal or
cure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Health</ent><br/
<hw>Health</hw> <pr>(h<ecr/lth)</pr>, <pos>n.</pos> <ety>[OE.
<ets>helthe</ets>, AS. <ets>h<aemac/l<thorn/</ets>, fr.
<ets>h<amac/l</ets> hale, sound, whole. See <er>Whole</er>.]</ety>
<sn>1.</sn> <def>The state of being hale, sound, or whole, in body,
mind, or soul; especially, the state of being free from physical disease
or pain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no <qex>health</qex> in us.</q> <rj><qau>Book of Common
Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Though <qex>health</qex> may be enjoyed without gratitude, it can
not be sported with without loss, or regained by courage.</q>
<rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A wish of health and happiness, as in pledging a
person in a toast.</def> <ldquo/Come, love and <xex>health</xex> to
all.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bill of health</b></col>. <cd>See under
<er>Bill</er>.</cd> -- <col><b>Health lift</b></col>, <cd>a machine for
exercise, so arranged that a person lifts an increasing weight, or moves
a spring of increasing tension, in such a manner that most of the
muscles of the body are brought into gradual action; -- also called
<altname>lifting machine</altname>.</cd> -- <col><b>Health
officer</b></col>, <cd>one charged with the enforcement of the sanitary
laws of a port or other place.</cd> -- <col><b>To drink a
health</b></col>. <cd>See under <er>Drink</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthful</ent><br/
<hw>Health"ful</hw> <pr>(-f<usdot/l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Full of health; free from illness or disease; well; whole; sound;
healthy; <as>as, a <ex>healthful</ex> body or mind; a <ex>healthful</ex>
plant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Serving to promote health of body or mind;
wholesome; salubrious; salutary; <as>as, a <ex>healthful</ex> air,
diet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>healthful</qex> Spirit of thy grace.</q> <rj><qau>Book of
Common Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Indicating, characterized by, or resulting from,
health or soundness; <as>as, a <ex>healthful</ex>
condition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A mind . . . <qex>healthful</qex> and so well-proportioned.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Well-disposed; favorable.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Gave <qex>healthful</qex> welcome to their shipwrecked guests.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthfully</ent><br/
<hw>Health"ful*ly</hw>, <pos>adv.</pos> <def>In health;
wholesomely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthfulness</ent><br/
<hw>Health"ful*ness</hw>, <pos>n.</pos> <def>The state of being
healthful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthily</ent><br/
<hw>Health"i*ly</hw> <pr>(-<icr/*l<ycr/)</pr>, <pos>adv.</pos> <def>In a
healthy manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthiness</ent><br/
<hw>Health"i*ness</hw>, <pos>n.</pos> <def>The state of being healthy or
healthful; freedom from disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthless</ent><br/
<hw>Health"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Without health,
whether of body or mind; infirm.</def> <ldquo/A <xex>healthless</xex> or
old age.<rdquo/ <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not conducive to health; unwholesome.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthlessness</ent><br/
<hw>Health"less*ness</hw>, <pos>n.</pos> <def>The state of being
healthless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthsome</ent><br/
<hw>Health"some</hw> <pr>(-s<ucr/m)</pr>, <pos>a.</pos> <def>Wholesome;
salubrious.</def> <mark>[R.]</mark> <ldquo/<xex>Healthsome</xex>
air.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthward</ent><br/
<hw>Health"ward</hw> <pr>(-w<etil/rd)</pr>, <pos>a. & adv.</pos> <def>In
the direction of health; <as>as, a <ex>healthward</ex>
tendency</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Healthy</ent><br/
<hw>Health"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Healthier</adjf>
<pr>(-<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Healthiest</adjf>.]</amorph> <sn>1.</sn> <def>Being in a state of
health; enjoying health; hale; sound; free from disease; <as>as, a
<ex>healthy</ex> child; a <ex>healthy</ex> plant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>His mind was now in a firm and <qex>healthy</qex> state.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Evincing health; <as>as, a <ex>healthy</ex> pulse; a
<ex>healthy</ex> complexion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Conducive to health; wholesome; salubrious;
salutary; <as>as, a <ex>healthy</ex> exercise; a <ex>healthy</ex>
climate.</as></def></p>

<p><syn><b>Syn.</b> -- Vigorous; sound; hale; salubrious; healthful;
wholesome; salutary.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heam</ent><br/
<hw>Heam</hw> <pr>(h<emac/m)</pr>, <pos>n.</pos> <ety>[Cf. AS.
cild<ets>hamma</ets> womb, OD. <ets>hamme</ets> afterbirth, LG.
<ets>hamen</ets>.]</ety> <def>The afterbirth or secundines of a
beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heap</ent><br/
<hw>Heap</hw> <pr>(h<emac/p)</pr>, <pos>n.</pos> <ety>[OE.
<ets>heep</ets>, <ets>heap</ets>, heap, multitude, AS.
<ets>he<aacute/p</ets>; akin to OS. <ets>h<omac/p</ets>, D.
<ets>hoop</ets>, OHG. <ets>houf</ets>, <ets>h<umac/fo</ets>, G.
<ets>haufe</ets>, <ets>haufen</ets>, Sw. <ets>hop</ets>, Dan.
<ets>hob</ets>, Icel. <ets>h<omac/pr</ets> troop, flock, Russ.
<ets>kupa</ets> heap, crowd, Lith. <ets>kaupas</ets>. Cf. <er>Hope</er>,
in <ets>Forlorn hope</ets>.]</ety> <sn>1.</sn> <def>A crowd; a throng; a
multitude or great number of persons.</def> <mark>[Now Low or
Humorous]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The wisdom of a <qex>heap</qex> of learned men.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>heap</qex> of vassals and slaves.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He had <qex>heaps</qex> of friends.</q> <rj><qau>W.
Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A great number or large quantity of things not
placed in a pile; <as>as, a <ex>heap</ex> of trouble</as>.</def>
<mark>[Now Low or Humorous]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A vast <qex>heap</qex>, both of places of scripture and
quotations.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have noticed a <qex>heap</qex> of things in my life.</q>
<rj><qau>R. L. Stevenson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pile or mass; a collection of things laid in a
body, or thrown together so as to form an elevation; <as>as, a
<ex>heap</ex> of earth or stones</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Huge <qex>heaps</qex> of slain around the body rise.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><-- (Computer programming) The main segment of memory available for
dynamic assignment --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heap</ent><br/
<hw>Heap</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Heaped</conjf> <pr>(h<emac/pt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Heaping</conjf>.]</vmorph> <ety>[AS.
<ets>he<aacute/pian</ets>.]</ety> <sn>1.</sn> <def>To collect in great
quantity; to amass; to lay up; to accumulate; -- usually with
<xex>up</xex>; <as>as, to <ex>heap</ex> up treasures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though he <qex>heap</qex> up silver as the dust.</q> <rj><qau>Job.
xxvii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw or lay in a heap; to make a heap of; to
pile; <as>as, to <ex>heap</ex> stones</as>; -- often with
<ptcl>up</ptcl>; <as>as, to <ex>heap</ex> up earth</as>; or with
<ptcl>on</ptcl>; <as>as, to <ex>heap</ex> on wood or
coal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 678 pr=JMD --></p>

<p><sn>3.</sn> <def>To form or round into a heap, as in measuring; to
fill (a measure) more than even full.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heaper</ent><br/
<hw>Heap"er</hw> <pr>(h<emac/p"<etil/r)</pr>, <pos>n.</pos> <def>One who
heaps, piles, or amasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heaps</ent><br/
<hw>heaps</hw> <pos>n.</pos> <def>a large quantity. See <er>heap</er>,
senses 2 and 3; <as>as, he made <ex>heaps</ex> of money in the stock
market</as>.</def><br/
<syn><b>Syn. --</b> tons, dozens, lots, piles, scores, stacks, loads,
rafts, slews, wads, oodles, gobs, scads, lashings.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heapy</ent><br/
<hw>Heap"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <def>Lying in
heaps.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hear</ent><br/
<hw>Hear</hw> <pr>(h<emac/r)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Heard</conjf> <pr>(h<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hearing</conjf>.]</vmorph> <ety>[OE. <ets>heren</ets>,
AS,. <ets>hi<eacute/ran</ets>, <ets>h<ymac/ran</ets>,
<ets>h<emac/ran</ets>; akin to OS. <ets>h<omac/rian</ets>, OFries.
<ets>hera</ets>, <ets>hora</ets>, D. <ets>hooren</ets>, OHG.
<ets>h<omac/ren</ets>, G. <ets>h<oum/ren</ets>, Icel. <ets>heyra</ets>,
Sw. <ets>h<oum/ra</ets>, Dan. <ets>hore</ets>, Goth. <ets>hausjan</ets>,
and perh. to Gr. <grk>'akoy`ein</grk>, E. <ets>acoustic</ets>. Cf.
<er>Hark</er>, <er>Hearken</er>.]</ety> <sn>1.</sn> <def>To perceive by
the ear; to apprehend or take cognizance of by the ear; <as>as, to
<ex>hear</ex> sounds; to <ex>hear</ex> a voice; to <ex>hear</ex> one
call.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lay thine ear close to the ground, and list if thou canst
<qex>hear</qex> the tread of travelers.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He had been <qex>heard</qex> to utter an ominous growl.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give audience or attention to; to listen to; to
heed; to accept the doctrines or advice of; to obey; to examine; to try
in a judicial court; <as>as, to <ex>hear</ex> a recitation; to
<ex>hear</ex> a class; the case will be <ex>heard</ex>
to-morrow.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To attend, or be present at, as hearer or worshiper;
<as>as, to <ex>hear</ex> a concert; to <ex>hear</ex>
Mass.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give attention to as a teacher or
judge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy matters are good and right, but there is no man deputed of the
king to <qex>hear</qex> thee.</q> <rj><qau>2 Sam. xv. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I beseech your honor to <qex>hear</qex> me one single word.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To accede to the demand or wishes of; to listen to
and answer favorably; to favor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I love the Lord, because he hath <qex>heard</qex> my voice.</q>
<rj><qau>Ps. cxvi. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They think that they shall be <qex>heard</qex> for their much
speaking.</q> <rj><qau>Matt. vi. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hear him</b></col>. <cd>See Remark, under <er>Hear</er>,
<pos>v. i.</pos></cd> -- <col><b>To hear a bird sing</b></col>, <cd>to
receive private communication.</cd> <mark>[Colloq.]</mark>
<au>Shak.</au> -- <col><b>To hear say</b></col>, <cd>to hear one say; to
learn by common report; to receive by rumor.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hear</ent><br/
<hw>Hear</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To have the sense or
faculty of perceiving sound.</def> <ldquo/The <xex>hearing</xex>
ear.<rdquo/ <rj><au>Prov. xx. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To use the power of perceiving sound; to perceive or
apprehend by the ear; to attend; to listen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So spake our mother Eve, and Adam <qex>heard</qex>,<br/
Well pleased, but answered not.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be informed by oral communication; to be told; to
receive information by report or by letter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>heard</qex>, sir, of such a man.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I must <qex>hear</qex> from thee every day in the hour.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hear ill</b></col>, <cd>to be blamed.</cd>
<mark>[Obs.]</mark><br/
<br/
<q>Not only within his own camp, but also now at Rome, he <qex>heard
ill</qex> for his temporizing and slow proceedings.</q>
<rj><qau>Holland.</qau></rj><br/
<br/
-- <col><b>To hear well</b></col>, <cd>to be praised.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hear</xex>, or <xex>Hear him</xex>, is often used
in the imperative, especially in the course of a speech in English
assemblies, to call attention to the words of the speaker.</note><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hear him</qex>, . . . a cry indicative, according to the
tone, of admiration, acquiescence, indignation, or derision.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hearable</ent><br/
<hw>hearable</hw> <pos>adj.</pos> <def>perceptible by the ear. Opposite
of <ant>inaudible</ant>.</def> <see>Also See: loud,
perceptible.</see><br/
<syn><b>Syn. --</b> audible.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Heard</ent><br/
<hw>Heard</hw> <pr>(h<etil/rd)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Hear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearer</ent><br/
<hw>Hear"er</hw> <pr>(h<emac/r"<etil/r)</pr>, <pos>n.</pos> <def>One who
hears; an auditor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearing</ent><br/
<hw>Hear"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or power of
perceiving sound; perception of sound; the faculty or sense by which
sound is perceived; <as>as, my <ex>hearing</ex> is good</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have heard of thee by the <qex>hearing</qex> of the ear.</q>
<rj><qau>Job xlii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Hearing in a special sensation, produced by stimulation
of the auditory nerve; the stimulus (waves of sound) acting not directly
on the nerve, but through the medium of the endolymph on the delicate
epithelium cells, constituting the peripheral terminations of the nerve.
See <er>Ear</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Attention to what is delivered; opportunity to be
heard; audience; <as>as, I could not obtain a
<ex>hearing</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A listening to facts and evidence, for the sake of
adjudication; a session of a court for considering proofs and
determining issues.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His last offenses to us<br/
Shall have judicious <qex>hearing</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Another <qex>hearing</qex> before some other court.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hearing</xex>, as applied to equity cases, means
the same thing that the word <xex>trial</xex> does at law.</note>
<rj><au>Abbot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Extent within which sound may be heard; sound;
earshot.</def> <ldquo/She's not within <xex>hearing</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They laid him by the pleasant shore,<br/
And in the <qex>hearing</qex> of the wave.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hearing-impaired</ent><br/
<hw>hearing-impaired</hw> <pos>adj.</pos> <def>having a hearing
impairment making hearing difficult; having a defective but functioning
sense of hearing.</def><br/
<syn><b>Syn. --</b> hard-of-hearing.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Hearken</ent><br/
<hw>Heark"en</hw> <pr>(h<aum/rk"'n)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hearkened</conjf>
<pr>(-'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hearkening</conjf>.]</vmorph> <ety>[OE. <ets>hercnen</ets>,
<ets>hercnien</ets>, AS. <ets>hercnian</ets>, <ets>heorcnian</ets>, fr.
<ets>hi<eacute/ran</ets>, <ets>h<ymac/ran</ets>, to hear; akin to OD.
<ets>harcken</ets>, <ets>horcken</ets>, LG. <ets>harken</ets>,
<ets>horken</ets>, G. <ets>horchen</ets>. See <er>Hear</er>, and cf.
<er>Hark</er>.]</ety> <sn>1.</sn> <def>To listen; to lend the ear; to
attend to what is uttered; to give heed; to hear, in order to obey or
comply.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Furies <qex>hearken</qex>, and their snakes uncurl.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hearken</qex>, O Israel, unto the statutes and unto the
judgments, which I teach you.</q> <rj><qau>Deut. iv. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inquire; to seek information.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Hearken</xex> after their
offense.<rdquo/ <rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- To attend; listen; hear; heed. See
<er>Attend</er>, <pos>v. i.</pos></syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearken</ent><br/
<hw>Heark"en</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To hear by
listening.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[She] <qex>hearkened</qex> now and then<br/
Some little whispering and soft groaning sound.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give heed to; to hear attentively.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The King of Naples . . . <qex>hearkens</qex> my brother's
suit.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hearken out</b></col>, <cd>to search out.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>If you find none, you must <qex>hearken out</qex> a vein and
buy.</q> <rj><qau>B. Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearkener</ent><br/
<hw>Heark"en*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
hearkens; a listener.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearsal</ent><br/
<hw>Hear"sal</hw> <pr>(h<etil/r"s<ait/l)</pr>, <pos>n.</pos>
<def>Rehearsal.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearsay</ent><br/
<hw>Hear"say`</hw> <pr>(h<emac/r"s<amac/`)</pr>, <pos>n.</pos>
<def>Report; rumor; fame; common talk; something heard from
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Much of the obloquy that has so long rested on the memory of our
great national poet originated in frivolous <qex>hearsays</qex> of his
life and conversation.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hearsay evidence</b></col> <fld>(Law)</fld>, <cd>that
species of testimony which consists in a narration by one person of
matters told him by another. It is, with a few exceptions, inadmissible
as testimony.</cd> <rj><au>Abbott.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearse</ent><br/
<hw>Hearse</hw> <pr>(h<etil/rs)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A hind in the second year of its age.</def>
<mark>[Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearse</ent><br/
<hw>Hearse</hw> <pr>(h<etil/rs)</pr>, <pos>n.</pos> <ety>[See
<er>Herse</er>.]</ety> <sn>1.</sn> <def>A framework of wood or metal
placed over the coffin or tomb of a deceased person, and covered with a
pall; also, a temporary canopy bearing wax lights and set up in a
church, under which the coffin was placed during the funeral
ceremonies.</def> <mark>[Obs.]</mark> <rj><au>Oxf. Gloss.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grave, coffin, tomb, or sepulchral monument.</def>
<mark>[Archaic]</mark> <ldquo/Underneath this marble
<xex>hearse</xex>.<rdquo/ <rj><au>B. Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Beside the <qex>hearse</qex> a fruitful palm tree grows.</q>
<rj><qau>Fairfax</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who lies beneath this sculptured <qex>hearse</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A bier or handbarrow for conveying the dead to the
grave.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Set down, set down your honorable load,<br/
It honor may be shrouded in a <qex>hearse</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A carriage or motor vehicle specially adapted or
used for conveying the dead to the grave in a coffin.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hearse</ent><br/
<hw>Hearse</hw>, <pos>v. t.</pos> <def>To inclose in a hearse; to
entomb.</def> <mark>[Obs.]</mark> <ldquo/Would she were
<xex>hearsed</xex> at my foot.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearsecloth</ent><br/
<hw>Hearse"cloth`</hw> <pr>(-kl<ocr/th`; 115)</pr>, <pos>n.</pos> <def>A
cloth for covering a coffin when on a bier; a pall.</def> <rj><au>Bp.
Sanderson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearselike</ent><br/
<hw>Hearse"like`</hw> <pr>(-l<imac/k`)</pr>, <pos>a.</pos> <def>Suitable
to a funeral.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If you listen to David's harp, you shall hear as many
<qex>hearselike</qex> airs as carols.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart</ent><br/
<hw>Heart</hw> <pr>(h<aum/rt)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harte</ets>, <ets>herte</ets>, <ets>heorte</ets>, AS.
<ets>heorte</ets>; akin to OS. <ets>herta</ets>, OFies.
<ets>hirte</ets>, D. <ets>hart</ets>, OHG. <ets>herza</ets>, G.
<ets>herz</ets>, Icel. <ets>hjarta</ets>, Sw. <ets>hjerta</ets>, Goth.
<ets>ha<iacute/rt<omac/</ets>, Lith. <ets>szirdis</ets>, Russ.
<ets>serdtse</ets>, Ir. <ets>cridhe</ets>, L. <ets>cor</ets>, Gr.
<grk>kardi`a</grk>, <grk>kh^r</grk>. <root/277. Cf. <er>Accord</er>,
<er>Discord</er>, <er>Cordial</er>, 4th <er>Core</er>,
<er>Courage</er>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>A hollow,
muscular organ, which, by contracting rhythmically, keeps up the
circulation of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why does my blood thus muster to my <qex>heart</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In adult mammals and birds, the heart is four-chambered,
the right auricle and ventricle being completely separated from the left
auricle and ventricle; and the blood flows from the systemic veins to
the right auricle, thence to the right ventricle, from which it is
forced to the lungs, then returned to the left auricle, thence passes to
the left ventricle, from which it is driven into the systemic arteries.
See <xex>Illust.</xex> under <er>Aorta</er>. In fishes there are but one
auricle and one ventricle, the blood being pumped from the ventricle
through the gills to the system, and thence returned to the auricle. In
most amphibians and reptiles, the separation of the auricles is partial
or complete, and in reptiles the ventricles also are separated more or
less completely. The so-called <xex>lymph hearts</xex>, found in many
amphibians, reptiles, and birds, are contractile sacs, which pump the
lymph into the veins.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The seat of the affections or sensibilities,
collectively or separately, as love, hate, joy, grief, courage, and the
like; rarely, the seat of the understanding or will; -- usually in a
good sense, when no epithet is expressed; the better or lovelier part of
our nature; the spring of all our actions and purposes; the seat of
moral life and character; the moral affections and character itself; the
individual disposition and character; <as>as, a good, tender, loving,
bad, hard, or selfish <ex>heart</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hearts</qex> are dust, <qex>hearts'</qex> loves remain.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The nearest the middle or center; the part most
hidden and within; the inmost or most essential part of any body or
system; the source of life and motion in any organization; the chief or
vital portion; the center of activity, or of energetic or efficient
action; <as>as, the <ex>heart</ex> of a country, of a tree,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Exploits done in the <qex>heart</qex> of France.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Peace subsisting at the <qex>heart</qex><br/
Of endless agitation.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Courage; courageous purpose; spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eve, recovering <qex>heart</qex>, replied.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The expelled nations take <qex>heart</qex>, and when they fly from
one country invade another.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Vigorous and efficient activity; power of fertile
production; condition of the soil, whether good or bad.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That the spent earth may gather <qex>heart</qex> again.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which resembles a heart in shape; especially, a
roundish or oval figure or object having an obtuse point at one end, and
at the other a corresponding indentation, -- used as a symbol or
representative of the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>One of the suits of playing cards, distinguished by
the figure or figures of a heart; <as>as, <ex>hearts</ex> are
trumps</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Vital part; secret meaning; real
intention.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And then show you the <qex>heart</qex> of my message.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A term of affectionate or kindly and familiar
address.</def> <ldquo/I speak to thee, my <xex>heart</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Heart</ex> is used in many compounds, the most of
which need no special explanation; as, <ex>heart</ex>-appalling,
<ex>heart</ex>-breaking, <ex>heart</ex>-cheering,
<ex>heart</ex>-chilled, <ex>heart</ex>-expanding, <ex>heart</ex>-free,
<ex>heart</ex>-hardened, <ex>heart</ex>-heavy, <ex>heart</ex>-purifying,
<ex>heart</ex>-searching, <ex>heart</ex>-sickening,
<ex>heart</ex>-sinking, <ex>heart</ex>-sore, <ex>heart</ex>-stirring,
<ex>heart</ex>-touching, <ex>heart</ex>-wearing, <ex>heart</ex>-whole,
<ex>heart</ex>-wounding, <ex>heart</ex>-wringing, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>After one's own heart</b></col>, <cd>conforming with
one's inmost approval and desire; <as>as, a friend <ex>after my own
heart</ex></as>.</cd><br/
<br/
<q>The Lord hath sought him a man <qex>after his own heart</qex>.</q>
<rj><qau>1 Sam. xiii. 14.</qau></rj><br/
<br/
-- <col><b>At heart</b></col>, <cd>in the inmost character or
disposition; at bottom; really; <as>as, he is <ex>at heart</ex> a good
man</as>.</cd> -- <col><b>By heart</b></col>, <cd>in the closest or most
thorough manner; <as>as, to know or learn <ex>by heart</ex></as>.
<ldquo/Composing songs, for fools to get <xex>by heart</xex><rdquo/
(that is, to commit to memory, or to learn thoroughly).</cd>
<au>Pope.</au> -- <col><b>to learn by heart</b></col>, <cd>to
memorize.</cd> -- <col><b>For my heart</b></col>, <cd>for my life; if my
life were at stake.</cd> <mark>[Obs.]</mark> <ldquo/I could not get him
<xex>for my heart</xex> to do it.<rdquo/ <au>Shak.</au> -- <col><b>Heart
bond</b></col> <fld>(Masonry)</fld>, <cd>a bond in which no header stone
stretches across the wall, but two headers meet in the middle, and their
joint is covered by another stone laid header fashion.</cd>
<au>Knight.</au> -- <col><b>Heart and hand</b></col>, <cd>with
enthusiastic co<oum/peration.</cd> -- <col><b>Heart hardness</b></col>,
<cd>hardness of heart; callousness of feeling; moral insensibility.</cd>
<au>Shak.</au> -- <col><b>Heart heaviness</b></col>, <cd>depression of
spirits.</cd> <au>Shak.</au> -- <col><b>Heart point</b></col>
<fld>(Her.)</fld>, <cd>the fess point. See <er>Escutcheon</er>.</cd> --
<col><b>Heart rising</b></col>, <cd>a rising of the heart, as in
opposition.</cd> -- <col><b>Heart shell</b></col> <fld>(Zool.)</fld>,
<cd>any marine, bivalve shell of the genus <gen>Cardium</gen> and allied
genera, having a heart-shaped shell; esp., the European <gen>Isocardia
cor</gen>; -- called also <altname>heart cockle</altname>.</cd> --
<col><b>Heart sickness</b></col>, <cd>extreme depression of
spirits.</cd> -- <col><b>Heart and soul</b></col>, <cd>with the utmost
earnestness.</cd> -- <col><b>Heart urchin</b></col> <fld>(Zool.)</fld>,
<cd>any heartshaped, spatangoid sea urchin. See
<er>Spatangoid</er>.</cd> -- <col><b>Heart wheel</b></col>, <cd>a form
of cam, shaped like a heart. See <er>Cam</er>.</cd> -- <col><b>In good
heart</b></col>, <cd>in good courage; in good hope.</cd> -- <col><b>Out
of heart</b></col>, <cd>discouraged.</cd> -- <col><b>Poor
heart</b></col>, <cd>an exclamation of pity.</cd> -- <col><b>To break
the heart of</b></col>. <sd>(a)</sd> <cd>To bring to despair or hopeless
grief; to cause to be utterly cast down by sorrow.</cd> <sd>(b)</sd>
<cd>To bring almost to completion; to finish very nearly; -- said of
anything undertaken; <as>as, he has <ex>broken the heart</ex> of the
task</as>.</cd> -- <col><b>To find in the heart</b></col>, <cd>to be
willing or disposed.</cd> <ldquo/I could <xex>find in my heart</xex> to
ask your pardon.<rdquo/ <au>Sir P. Sidney.</au> -- <col><b>To have at
heart</b></col>, <cd>to desire (anything) earnestly.</cd> -- <col><b>To
have in the heart</b></col>, <cd>to purpose; to design or intend to
do.</cd> -- <col><b>To have the heart in the mouth</b></col>, <cd>to be
much frightened.</cd> -- <col><b>To lose heart</b></col>, <cd>to become
discouraged.</cd> -- <col><b>To lose one's heart</b></col>, <cd>to fall
in love.</cd> -- <col><b>To set the heart at rest</b></col>, <cd>to put
one's self at ease.</cd> -- <col><b>To set the heart upon</b></col>,
<cd>to fix the desires on; to long for earnestly; to be very fond
of.</cd> -- <col><b>To take heart of grace</b></col>, <cd>to take
courage.</cd> -- <col><b>To take to heart</b></col>, <cd>to grieve
over.</cd> -- <col><b>To wear one's heart upon one's sleeve</b></col>,
<cd>to expose one's feelings or intentions; to be frank or
impulsive.</cd> -- <mcol><col><b>With all one's heart</b></col>,
<col><b>With one's whole heart</b></col></mcol>, <cd>very earnestly;
fully; completely; devotedly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart</ent><br/
<hw>Heart</hw> <pr>(h<aum/rt)</pr>, <pos>v. t.</pos> <def>To give heart
to; to hearten; to encourage; to inspirit.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My cause is <qex>hearted</qex>; thine hath no less reason.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart</ent><br/
<hw>Heart</hw>, <pos>v. i.</pos> <def>To form a compact center or heart;
<as>as, a <ex>hearting</ex> cabbage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartache</ent><br/
<hw>Heart"ache`</hw> <pr>(-<amac/k`)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>heortece</ets>.]</ety> <def>Sorrow; anguish of mind; mental
pang.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heartbeat</ent><br/
<hw>heartbeat</hw> <pos>n.</pos> <def>the audible and palpable rhythmic
contraction and expansion of the arteries with each beat of the heart;
<as>as, he listened to her <ex>heartbeat</ex> with a
stethoscope</as>.</def><br/
<syn><b>Syn. --</b> pulse, pulsation, beat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>in a heartbeat</b></col> <cd>immediately.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Heartbreak</ent><br/
<hw>Heart"break`</hw> <pr>(-br<amac/k`)</pr>, <pos>n.</pos>
<def>Crushing sorrow or grief; a yielding to such grief.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartbreaking</ent><br/
<hw>Heart"break`ing</hw>, <pos>a.</pos> <def>Causing overpowering
sorrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartbroken</ent><br/
<hw>Heart"bro`ken</hw> <pr>(-br<omac/`k'n)</pr>, <pos>a.</pos>
<def>Overcome by crushing sorrow; deeply grieved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartburn</ent><br/
<hw>Heart"burn`</hw> <pr>(-b<ucir/rn`)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>An uneasy, burning sensation in the stomach,
often attended with an inclination to vomit. It is sometimes idiopathic,
but is often a symptom of other complaints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartburned</ent><br/
<hw>Heart"burned`</hw> <pr>(-b<ucir/rnd`)</pr>, <pos>a.</pos>
<def>Having heartburn.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartburning</ent><br/
<hw>Heart"burn`ing</hw> <pr>(-b<ucir/rn`<icr/ng)</pr>, <pos>a.</pos>
<def>Causing discontent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartburning</ent><br/
<hw>Heart"burn`ing</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Med.)</fld>
<def>Same as <er>Heartburn</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Discontent; secret enmity.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The transaction did not fail to leave
<qex>heartburnings</qex>.</q> <rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartdear</ent><br/
<hw>Heart"dear`</hw> <pr>(-d<emac/r`)</pr>, <pos>a.</pos> <def>Sincerely
beloved.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartdeep</ent><br/
<hw>Heart"deep`</hw> <pr>(-d<emac/p`)</pr>, <pos>a.</pos> <def>Rooted in
the heart.</def> <rj><au>Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart-eating</ent><br/
<hw>Heart"-eat`ing</hw> <pr>(-<emac/t`<icr/ng)</pr>, <pos>a.</pos>
<def>Preying on the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearted</ent><br/
<hw>Heart"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having a heart; having
(such) a heart (regarded as the seat of the affections, disposition, or
character).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Shaped like a heart; cordate.</def>
<mark>[R.]</mark> <rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Seated or laid up in the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I hate the Moor: my cause is <qex>hearted</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is chiefly used in composition; as,
hard-<xex>hearted</xex>, faint-<xex>hearted</xex>,
kind-<xex>hearted</xex>, lion-<xex>hearted</xex>,
stout-<xex>hearted</xex>, etc. Hence the nouns
hard-<xex>hearted</xex>ness, faint-<xex>hearted</xex>ness,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartedness</ent><br/
<hw>Heart"ed*ness</hw>, <pos>n.</pos> <def>Earnestness; sincerity;
heartiness.</def> <mark>[R.]</mark> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ See also the Note under <er>Hearted</er>. The analysis
of the compounds gives <xex>hard-hearted</xex> + -<xex>ness</xex>,
rather than <xex>hard</xex> + <xex>heartedness</xex>, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearten</ent><br/
<hw>Heart"en</hw> <pr>(h<aum/rt"'n)</pr>, <pos>v. t.</pos> <ety>[From
<er>Heart</er>.]</ety> <sn>1.</sn> <def>To encourage; to animate; to
incite or stimulate the courage of; to embolden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hearten</qex> those that fight in your defense.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restore fertility or strength to, as to
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartener</ent><br/
<hw>Heart"en*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who, or
that which, heartens, animates, or stirs up.</def> <rj><au>W.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartfelt</ent><br/
<hw>Heart"felt`</hw> <pr>(-f<ecr/lt`)</pr>, <pos>a.</pos> <def>Hearty;
sincere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartgrief</ent><br/
<hw>Heart"grief`</hw> <pr>(-gr<emac/f`)</pr>, <pos>n.</pos>
<def>Heartache; sorrow.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearth</ent><br/
<hw>Hearth</hw> <pr>(h<aum/rth)</pr>, <pos>n.</pos> <ety>[OE.
<ets>harthe</ets>, <ets>herth</ets>, <ets>herthe</ets>, AS.
<ets>heor<edh/</ets>; akin to D. <ets>haard</ets>, <ets>heerd</ets>, Sw.
<ets>h<aum/rd</ets>, G. <ets>herd</ets>; cf. Goth.
<ets>ha<uacute/ri</ets> a coal, Icel. <ets>hyrr</ets> embers, and L.
<ets>cremare</ets> to burn.]</ety> <sn>1.</sn> <def>The pavement or
floor of brick, stone, or metal in a chimney, on which a fire is made;
the floor of a fireplace; also, a corresponding part of a
stove.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was a fire on the <qex>hearth</qex> burning before him.</q>
<rj><qau>Jer. xxxvi. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where fires thou find'st unraked and <qex>hearths</qex>
unswept.<br/
There pinch the maids as blue as bilberry.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The house itself, as the abode of comfort to its
inmates and of hospitality to strangers; fireside.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Household talk and phrases of the <qex>hearth</qex>.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><sn>3.</sn> <fld>(Metal. & Manuf.)</fld> <def>The floor of a furnace,
on which the material to be heated lies, or the lowest part of a melting
furnace, into which the melted material settles; <as>as, an
open-<ex>hearth</ex> smelting furnace</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Hearth ends</b></col> <fld>(Metal.)</fld>, <cd>fragments
of lead ore ejected from the furnace by the blast.</cd> --
<mcol><col><b>Hearth money</b></col>, <col><b>Hearth
penny</b></col></mcol> <ety>[AS. <ets>heor<edh/pening</ets>]</ety>, a
<cd>tax formerly laid in England on hearths, each hearth (in all houses
paying the church and poor rates) being taxed at two shillings; --
called also <altname>chimney money</altname>, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>He had been importuned by the common people to relieve them from
the . . . burden of the <qex>hearth money</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hearthrug</ent><br/
<hw>hearthrug</hw> <pos>n.</pos> <def>a rug spread out in front of a
fireplace.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hearthstone</ent><br/
<hw>Hearth"stone`</hw> <pr>(-st<omac/n`)</pr>, <pos>n.</pos> <def>Stone
forming the hearth; hence, the fireside; home.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Chords of memory, stretching from every battlefield and patriot
grave to every living heart and <qex>hearthstone</qex>.</q> <rj><qau>A.
Lincoln.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartily</ent><br/
<hw>Heart"i*ly</hw> <pr>(h<aum/rt"<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<ety>[From <er>Hearty</er>.]</ety> <sn>1.</sn> <def>From the heart; with
all the heart; with sincerity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>heartily</qex> forgive them.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With zeal; actively; vigorously; willingly;
cordially; <as>as, he <ex>heartily</ex> assisted the
prince</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To eat heartily</b></col>, <cd>to eat freely and with
relish.</cd> <rj><au>Addison.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- Sincerely; cordially; zealously; vigorously;
actively; warmly; eagerly; ardently; earnestly.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 679 pr=JMD --></p>

<p><ent>Heartiness</ent><br/
<hw>Heart"i*ness</hw> <pr>(h<aum/rt"<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The quality of being hearty; <as>as, the <ex>heartiness</ex> of a
greeting</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heartleaf</ent><br/
<hw>heartleaf</hw> <pos>n.</pos> <fld>(Bot.)</fld> <sn>1.</sn> <def>wild
ginger (<spn>Asarum shuttleworthii</spn>) having persistent heart-shaped
pungent leaves, growing from Western Virginia to Alabama.</def><br/
<syn><b>Syn. --</b> <spn>Asarum shuttleworthii</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>An evergreen low-growing perennial
(<spn>Asarum virginicum</spn>) having mottled green and silvery-gray
heart-shaped pungent leaves, growing from Virginia to South
Carolina.</def><br/
<syn><b>Syn. --</b> <spn>Asarum virginicum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heartless</ent><br/
<hw>Heart"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Without a
heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You have left me <qex>heartless</qex>; mine is in your bosom.</q>
<rj><qau>J. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of courage; spiritless;
despondent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Heartless</qex> they fought, and quitted soon their
ground.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Heartless</qex> and melancholy.</q> <rj><qau>W.
Irwing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Destitute of feeling or affection; unsympathetic;
cruel.</def> <ldquo/The <xex>heartless</xex> parasites.<rdquo/
<rj><au>Byron.</au></rj></p>

<p>-- <wordforms><wf>Heart"less*ly</wf>, <pos>adv.</pos> --
<wf>Heart"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartlet</ent><br/
<hw>Heart"let</hw> <pr>(-l<ecr/t)</pr>, <pos>n.</pos> <def>A little
heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartlings</ent><br/
<hw>Heart"lings</hw> <pr>(-l<icr/ngz)</pr>, <pos>interj.</pos> <def>An
exclamation used in addressing a familiar acquaintance.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartpea</ent><br/
<hw>Heart"pea`</hw> <pr>(-p<emac/`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>Same as <er>Heartseed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartquake</ent><br/
<hw>Heart"quake`</hw> <pr>(-kw<amac/k`)</pr>, <pos>n.</pos>
<def>Trembling of the heart; trepidation; fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In many an hour of danger and <qex>heartquake</qex>.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartrending</ent><br/
<hw>Heart"rend`ing</hw> <pr>(-r<ecr/nd`<icr/ng)</pr>, <pos>a.</pos>
<def>Causing intense grief; overpowering with anguish; very
distressing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart-robbing</ent><br/
<hw>Heart"-rob`bing</hw> <pr>(-r<ocr/b`b<icr/ng)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Depriving of thought; ecstatic.</def>
<ldquo/<xex>Heart-robbing</xex> gladness.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Stealing the heart or affections; winning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart's-ease</ent><br/
<hw>Heart's"-ease`</hw> <pr>(h<aum/rts"<emac/z`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Ease of heart; peace or tranquillity of mind or
feeling.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A species of violet (<spn>Viola
tricolor</spn>), a common and long cultivated European herb from which
most common garden pansies are derived; -- called also
<altname>pansy</altname>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> wild pansy, Johnny-jump-up, heartsease,
love-in-idleness, pink of my John, Viola tricolor.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A violet of the Pacific coast of
North America (<spn>Viola ocellata</spn>) having white petals tinged
with yellow and deep violet.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> two-eyed violet, heartsease, <spn>Viola
ocellata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>A common Old World viola
(<spn>Viola arvensis</spn>) with creamy often violet-tinged
flowers.</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> field pansy, heartsease, <spn>Viola
arvensis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heartseed</ent><br/
<hw>Heart"seed`</hw> <pr>(h<aum/rt"s<emac/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A climbing plant of the genus
<gen>Cardiospermum</gen>, having round seeds which are marked with a
spot like a heart.</def> <rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heart-shaped</ent><br/
<ent>heartshaped</ent><br/
<mhw><hw>heart"shaped`</hw>, <hw>heart"-shaped`</hw></mhw>
<pr>(h<aum/rt"sh<amac/pt`)</pr>, <pos>a.</pos> <def>Having the shape of
a heart; cordate; -- of a leaf shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartsick</ent><br/
<hw>Heart"sick`</hw> <pr>(h<aum/rt"s<icr/k`)</pr>, <pos>a.</pos>
<ety>[AS. <ets>heortise<oacute/c</ets>.]</ety> <def>Sick at heart;
extremely depressed in spirits; very despondent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartsome</ent><br/
<hw>Heart"some</hw> <pr>(h<aum/rt"s<ucr/m)</pr>, <pos>a.</pos>
<def>Merry; cheerful; lively.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart-spoon</ent><br/
<hw>Heart"-spoon`</hw> <pr>(h<aum/rt"sp<oomac/n`)</pr>, <pos>n.</pos>
<def>A part of the breastbone.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He feeleth through the <qex>herte-spon</qex> the pricke.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartstricken</ent><br/
<hw>Heart"strick`en</hw> <pr>(h<aum/rt"str<icr/k`'n)</pr>, <pos>a.</pos>
<def>Shocked; dismayed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartstrike</ent><br/
<hw>Heart"strike`</hw> <pr>(h<aum/rt"str<imac/k`)</pr>, <pos>v. t.</pos>
<def>To affect at heart; to shock.</def> <mark>[R.]</mark> <ldquo/They
seek to <xex>heartstrike</xex> us.<rdquo/ <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartstring</ent><br/
<hw>Heart"string`</hw> <pr>(h<aum/rt"str<icr/ng`)</pr>, <pos>n.</pos>
<def>A nerve or tendon, supposed to brace and sustain the heart.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sobbing, as if a <qex>heartstring</qex> broke.</q>
<rj><qau>Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartstruck</ent><br/
<hw>Heart"struck`</hw> <pr>(h<aum/rt"str<ucr/k`)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Driven to the heart; infixed in the mind.</def>
<ldquo/His <xex>heartstruck</xex> injuries.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Shocked with pain, fear, or remorse; dismayed;
heartstricken.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartswelling</ent><br/
<hw>Heart"swell`ing</hw> <pr>(h<aum/rt"sw<ecr/l`<icr/ng)</pr>,
<pos>a.</pos> <def>Rankling in, or swelling, the heart.</def>
<ldquo/<xex>Heartswelling</xex> hate.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heart-warming</ent><br/
<ent>heartwarming</ent><br/
<mhw><hw>heart"warm`ing</hw>, <hw>heart"-warm`ing</hw></mhw>
<pos>adj.</pos> <def>causing gladness and pleasure; -- used mostly of
the actions of people, and sometimes of animals; <as>as, Is there a
sight more <ex>heart-warming</ex> than a family reunion?</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heart-whole</ent><br/
<hw>Heart"-whole`</hw> <pr>(h<aum/rt"h<omac/l`)</pr>, <pos>a.</pos>
<ety>[See <er>Whole</er>.]</ety> <sn>1.</sn> <def>Having the heart or
affections free; not in love.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With unbroken courage; undismayed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of a single and sincere heart; with unconditional
commitment or unstinting devotion; <as>as, <ex>heart-whole</ex>
friendship</as>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> wholehearted.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>If he keeps <qex>heart-whole</qex> towards his Master.</q>
<rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartwood</ent><br/
<hw>Heart"wood`</hw> <pr>(h<aum/rt"w<oocr/d`)</pr>, <pos>n.</pos>
<def>The hard, central part of the trunk of a tree, consisting of the
old and matured wood, and usually differing in color from the outer
layers. It is technically known as <altname>duramen</altname>, and
distinguished from the softer <contr>sapwood</contr> or
<contr>alburnum</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heart-wounded</ent><br/
<hw>Heart"-wound`ed</hw> <pr>(h<aum/rt"w<oomac/nd`<ecr/d <or/
-wound`<ecr/d)</pr>, <pos>a.</pos> <def>Wounded to the heart with love
or grief.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearty</ent><br/
<hw>Heart"y</hw> <pr>(h<aum/rt"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Heartier</adjf>
<pr>(h<aum/rt"<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Heartiest</adjf>.]</amorph> <sn>1.</sn> <def>Pertaining to, or
proceeding from, the heart; warm; cordial; bold; zealous; sincere;
willing; also, energetic; active; eager; <as>as, a <ex>hearty</ex>
welcome; <ex>hearty</ex> in supporting the government.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full of <qex>hearty</qex> tears<br/
For our good father's loss.</q> <rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exhibiting strength; sound; healthy; firm; not weak;
<as>as, a <ex>hearty</ex> man; <ex>hearty</ex> timber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Promoting strength; nourishing; rich; abundant;
<as>as, <ex>hearty</ex> food; a <ex>hearty</ex> meal.</as></def></p>

<p><syn><b>Syn.</b> -- Sincere; real; unfeigned; undissembled; cordial;
earnest; warm; zealous; ardent; eager; active; vigorous.</syn> <usage>
-- <er>Hearty</er>, <er>Cordial</er>, <er>Sincere</er>.
<xex>Hearty</xex> implies honesty and simplicity of feelings and
manners; <xex>cordial</xex> refers to the warmth and liveliness with
which the feelings are expressed; <xex>sincere</xex> implies that this
expression corresponds to the real sentiments of the heart. A man should
be <xex>hearty</xex> in his attachment to his friends,
<xex>cordial</xex> in his reception of them to his house, and
<xex>sincere</xex> in his offers to assist them.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hearty</ent><br/
<hw>Heart"y</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Hearties</plw>
<pr>(h<aum/rt"<icr/z)</pr>.</plu> <def>Comrade; boon companion; good
fellow; -- a term of familiar address and fellowship among
sailors.</def> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heartyhale</ent><br/
<hw>Heart"y*hale`</hw> <pr>(h<aum/rt"h<amac/l`)</pr>, <pos>a.</pos>
<def>Good for the heart.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heat</ent><br/
<hw>Heat</hw> <pr>(h<emac/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hete</ets>, <ets>h<ae/te</ets>, AS. <ets>h<aemac/tu</ets>,
<ets>h<aemac/to</ets>, fr. <ets>h<amac/t</ets> hot; akin to OHG.
<ets>heizi</ets> heat, Dan. <ets>hede</ets>, Sw. <ets>hetta</ets>. See
<er>Hot</er>.]</ety> <sn>1.</sn> <def>A force in nature which is
recognized in various effects, but especially in the phenomena of fusion
and evaporation, and which, as manifested in fire, the sun's rays,
mechanical action, chemical combination, etc., becomes directly known to
us through the sense of feeling. In its nature heat is a mode of motion,
being in general a form of molecular disturbance or vibration. It was
formerly supposed to be a subtile, imponderable fluid, to which was
given the name <altname>caloric</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ As affecting the human body, heat produces different
sensations, which are called by different names, as heat or sensible
heat, warmth, cold, etc., according to its degree or amount relatively
to the normal temperature of the body.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sensation caused by the force or influence of
heat when excessive, or above that which is normal to the human body;
the bodily feeling experienced on exposure to fire, the sun's rays,
etc.; the reverse of <ant>cold</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>High temperature, as distinguished from low
temperature, or cold; <as>as, the <ex>heat</ex> of summer and the cold
of winter; <ex>heat</ex> of the skin or body in fever,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Else how had the world . . . <br/
Avoided pinching cold and scorching <qex>heat</qex>!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Indication of high temperature; appearance,
condition, or color of a body, as indicating its temperature; redness;
high color; flush; degree of temperature to which something is heated,
as indicated by appearance, condition, or otherwise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It has raised . . . <qex>heats</qex> in their faces.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heats</qex> smiths take of their iron are a blood-red
<qex>heat</qex>, a white-flame <qex>heat</qex>, and a sparkling or
welding <qex>heat</qex>.</q> <rj><qau>Moxon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A single complete operation of heating, as at a
forge or in a furnace; <as>as, to make a horseshoe in a certain number
of <ex>heats</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A violent action unintermitted; a single effort; a
single course in a race that consists of two or more courses; <as>as, he
won two <ex>heats</ex> out of three</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many causes . . . for refreshment betwixt the
<qex>heats</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] struck off at one <qex>heat</qex> the matchless tale of
<ldquo/Tam o' Shanter.<rdquo/</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Utmost violence; rage; vehemence; <as>as, the
<ex>heat</ex> of battle or party</as>.</def> <ldquo/The <xex>heat</xex>
of their division.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Agitation of mind; inflammation or excitement;
exasperation.</def> <ldquo/The <xex>heat</xex> and hurry of his
rage.<rdquo/ <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Animation, as in discourse; ardor; fervency; <as>as,
in the <ex>heat</ex> of argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With all the strength and <qex>heat</qex> of eloquence.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Zool.)</fld> <def>Sexual excitement in animals;
readiness for sexual activity; estrus or rut.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>11.</sn> <def>Fermentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Strong psychological pressure, as in a police
investigation; <as>as, when they turned up the <ex>heat,</ex> he took it
on the lam</as>.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Animal heat</b></col>, <col><b>Blood
heat</b></col>, <col><b>Capacity for heat</b></col></mcol>, <cd>etc. See
under <er>Animal</er>, <er>Blood</er>, etc.</cd> -- <col><b>Atomic
heat</b></col> <fld>(Chem.)</fld>, <cd>the product obtained by
multiplying the atomic weight of any element by its specific heat. The
atomic heat of all solid elements is nearly a constant, the mean value
being 6.4.</cd> -- <col><b>Dynamical theory of heat</b></col>, <cd>that
theory of heat which assumes it to be, not a peculiar kind of matter,
but a peculiar motion of the ultimate particles of matter.</cd>
<col><b>Heat engine</b></col>, <cd>any apparatus by which a heated
substance, as a heated fluid, is made to perform work by giving motion
to mechanism, as a hot-air engine, or a steam engine.</cd> --
<col><b>Heat producers</b></col>. <fld>(Physiol.)</fld> <cd>See under
<er>Food</er>.</cd> -- <col><b>Heat rays</b></col>, <cd>a term formerly
applied to the rays near the red end of the spectrum, whether within or
beyond the visible spectrum.</cd> -- <col><b>Heat weight</b></col>
<fld>(Mech.)</fld>, <cd>the product of any quantity of heat by the
mechanical equivalent of heat divided by the absolute temperature; --
called also <altname>thermodynamic function</altname>, and
<altname>entropy</altname>.</cd> -- <col><b>Mechanical equivalent of
heat</b></col>. <cd>See under <er>Equivalent</er>.</cd> --
<col><b>Specific heat of a substance</b> <plain>(at any
temperature)</plain></col>, <cd>the number of units of heat required to
raise the temperature of a unit mass of the substance at that
temperature one degree.</cd> -- <col><b>Unit of heat</b></col>, <cd>the
quantity of heat required to raise, by one degree, the temperature of a
unit mass of water, initially at a certain standard temperature. The
temperature usually employed is that of 0<deg/ Centigrade, or 32<deg/
Fahrenheit.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heat</ent><br/
<hw>Heat</hw> <pr>(h<emac/t)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Heated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Heating</conjf>.]</vmorph> <ety>[OE. <ets>heten</ets>, AS.
<ets>h<aemac/tan</ets>, fr. <ets>h<amac/t</ets> hot. See
<er>Hot</er>.]</ety> <sn>1.</sn> <def>To make hot; to communicate heat
to, or cause to grow warm; <as>as, to <ex>heat</ex> an oven or furnace,
an iron, or the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Heat</qex> me these irons hot.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To excite or make hot by action or emotion; to make
feverish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pray, walk softly; do not <qex>heat</qex> your blood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To excite ardor in; to rouse to action; to excite to
excess; to inflame, as the passions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A noble emulation <qex>heats</qex> your breast.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heat</ent><br/
<hw>Heat</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To grow warm or hot by
the action of fire or friction, etc., or the communication of heat;
<as>as, the iron or the water <ex>heats</ex> slowly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grow warm or hot by fermentation, or the
development of heat by chemical action; <as>as, green hay <ex>heats</ex>
in a mow, and manure in the dunghill</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heat</ent><br/
<hw>Heat</hw> <pr>(h<ecr/t)</pr>, <ety><pos>imp. & p. p.</pos> of
<er>Heat</er>.</ety> <def>Heated; <as>as, the iron though <ex>heat</ex>
red-hot</as>.</def> <mark>[Obs. or Archaic]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heated</ent><br/
<hw>heated</hw> <pos>adj.</pos> <sn>1.</sn> <def>characterized by great
warmth and intensity of feeling; <as>as, a <ex>heated</ex>
argument</as>. Opposite of <ant>dispassionate, passionless</ant>.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> ardent, fervent, fervid, fiery, hot, impassioned,
perfervid, torrid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>supplied with a mechanism for heating; -- of
structures or devices; <as>as, a <ex>heated</ex> fishing cabin</as>.
Opposite of <ant>unheated</ant>.</def> <wns>[wns=2]</wns><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Heater</ent><br/
<hw>Heat"er</hw> <pr>(h<emac/t"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, heats.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any contrivance or implement, as a furnace, stove,
or other heated body or vessel, etc., used to impart heat to something,
or to contain something to be heated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pistol or other carryable firearm; <as>as, gunmen
with their <ex>heaters</ex> bulging in their pockets</as>.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Feed heater</b></col>. <cd>See under
<er>Feed</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heath</ent><br/
<hw>Heath</hw> <pr>(h<emac/th)</pr>, <pos>n.</pos> <ety>[OE.
<ets>heth</ets> waste land, the plant heath, AS.
<ets>h<aemac/<edh/</ets>; akin to D. & G. <ets>heide</ets>, Icel.
<ets>hei<edh/r</ets> waste land, Dan. <ets>hede</ets>, Sw.
<ets>hed</ets>, Goth. <ets>hai<thorn/i</ets> field, L.
<ets>bucetum</ets> a cow pasture; cf. W. <ets>coed</ets> a wood, Skr.
<ets>ksh<emac/tra</ets> field. <root/20.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>A low shrub (<spn>Erica
vulgaris</spn> <it>or</it> <spn>Calluna vulgaris</spn>), with minute
evergreen leaves, and handsome clusters of pink flowers. It is used in
Great Britain for brooms, thatch, beds for the poor, and for heating
ovens. It is also called <altname>heather</altname>, and
<altname>ling</altname>.</def> <sd>(b)</sd> <def>Also, any species of
the genus <gen>Erica</gen>, of which several are European, and many more
are South African, some of great beauty. See <xex>Illust.</xex> of
<er>Heather</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place overgrown with heath; any cheerless tract of
country overgrown with shrubs or coarse herbage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their stately growth, though bare,<br/
Stands on the blasted <qex>heath</qex>.</q>
<rj><qau>Milton</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heath cock</b></col> <fld>(Zool.)</fld>, <cd>the
blackcock. See <cref>Heath grouse</cref> (below).</cd> -- <col><b>Heath
grass</b></col> <fld>(Bot.)</fld>, <cd>a kind of perennial grass, of the
genus <gen>Triodia</gen> (<spn>Triodia decumbens</spn>), growing on dry
heaths.</cd> -- <mcol><col><b>Heath grouse</b></col>, <it>or</it>
<col><b>Heath game</b></col></mcol> <fld>(Zool.)</fld>, <cd>a European
grouse (<spn>Tetrao tetrix</spn>), which inhabits heaths; -- called also
<altname>black game</altname>, <altname>black grouse</altname>,
<altname>heath poult</altname>, <altname>heath fowl</altname>,
<altname>moor fowl</altname>. The male is called <altname>heath
cock</altname>, and <altname>blackcock</altname>; the female,
<altname>heath hen</altname>, and <altname>gray hen</altname>.</cd> --
<col><b>Heath hen</b></col>. <fld>(Zool.)</fld> <cd>See <cref>Heath
grouse</cref> (above).</cd> -- <col><b>Heath pea</b></col>
<fld>(Bot.)</fld>, <cd>a species of bitter vetch (<spn>Lathyrus
macrorhizus</spn>), the tubers of which are eaten, and in Scotland are
used to flavor whisky.</cd> -- <col><b>Heath throstle</b></col>
<fld>(Zool.)</fld>, <cd>a European thrush which frequents heaths; the
ring ouzel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathclad</ent><br/
<hw>Heath"clad`</hw> <pr>(-kl<acr/d`)</pr>, <pos>a.</pos> <def>Clad or
crowned with heath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathen</ent><br/
<hw>Hea"then</hw> <pr>(h<emac/"<th/'n; 277)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Heathens</plw> <pr>(-<th/'nz)</pr> or
<xex>collectively</xex> <plw>Heathen</plw>.</plu> <ety>[OE.
<ets>hethen</ets>, AS. <ets>h<aemac/<edh/en</ets>, prop. an adj. fr.
<ets>h<aemac/<edh/</ets> heath, and orig., therefore, one who lives in
the country or on the heaths and in the woods (cf. <ets>pagan</ets>, fr.
<ets>pagus</ets> village); akin to OS. <ets>h<emac/<edh/in</ets>, adj.,
D. <ets>heiden</ets> a heathen, G. <ets>heide</ets>, OHG.
<ets>heidan</ets>, Icel. <ets>hei<edh/inn</ets>, adj., Sw.
<ets>heden</ets>, Goth. <ets>hai<thorn/n<omac/</ets>, <pos>n.</pos> fem.
See <er>Heath</er>, and cf. <er>Hoiden</er>.]</ety> <sn>1.</sn> <def>An
individual of the pagan or unbelieving nations, or those which worship
idols and do not acknowledge the true God; a pagan; an
idolater.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An irreligious person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If it is no more than a moral discourse, he may preach it and they
may hear it, and yet both continue unconverted <qex>heathens</qex>.</q>
<rj><qau>V. Knox.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The heathen</b></col>, <cd>as the term is used in the
Scriptures, all people except the Jews; now used of all people except
Christians, Jews, and Muslims.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Ask of me, and I shall give thee the <qex>heathen</qex> for thine
inheritance.</q> <rj><qau>Ps. ii. 8.</qau></rj></p>

<p><syn><b>Syn.</b> -- Pagan; gentile. See <er>Pagan</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathen</ent><br/
<hw>Hea"then</hw> <pr>(h<emac/"<th/'n)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Gentile; pagan; <as>as, a <ex>heathen</ex> author</as>.</def>
<ldquo/The <xex>heathen</xex> philosopher.<rdquo/ <ldquo/All in gold,
like <xex>heathen</xex> gods.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Barbarous; unenlightened; heathenish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Irreligious; scoffing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathendom</ent><br/
<hw>Hea"then*dom</hw> <pr>(-d<ucr/m)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<aemac/<edh/end<omac/m</ets>.]</ety> <sn>1.</sn> <def>That part of
the world where heathenism prevails; the heathen nations, considered
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Heathenism.</def> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenesse</ent><br/
<hw>Hea"then*esse</hw> <pr>(-<ecr/s)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<aemac/<edh/ennes</ets>, i. e., heathenness.]</ety>
<def>Heathendom.</def> <mark>[Obs.]</mark> <rj><au>Chaucer. Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenish</ent><br/
<hw>Hea"then*ish</hw>, <pos>a.</pos> <ety>[AS.
<ets>h<aemac/<edh/enisc</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining
to the heathen; resembling or characteristic of heathens.</def>
<ldquo/Worse than <xex>heathenish</xex> crimes.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rude; uncivilized; savage; cruel.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Irreligious; <as>as, a <ex>heathenish</ex> way of
living</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenishly</ent><br/
<hw>Hea"then*ish*ly</hw>, <pos>adv.</pos> <def>In a heathenish
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenishness</ent><br/
<hw>Hea"then*ish*ness</hw>, <pos>n.</pos> <def>The state or quality of
being heathenish.</def> <ldquo/The . . . <xex>heathenishness</xex> and
profaneness of most playbooks.<rdquo/ <rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenism</ent><br/
<hw>Hea"then*ism</hw> <pr>(-<icr/z'm)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The religious system or rites of a heathen nation; idolatry;
paganism.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manners or morals usually prevalent in a heathen
country; ignorance; rudeness; barbarism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenize</ent><br/
<hw>Hea"then*ize</hw> <pr>(-<imac/z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Heathenized</conjf>
<pr>(-<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Heathenizing</conjf> <pr>(-<imac/`z<icr/ng)</pr>.]</vmorph>
<def>To render heathen or heathenish.</def>
<rj><au>Firmin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenness</ent><br/
<hw>Hea"then*ness</hw>, <pos>n.</pos> <ety>[Cf.
<er>Heathenesse</er>.]</ety> <def>State of being heathen or like the
heathen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathenry</ent><br/
<hw>Hea"then*ry</hw> <pr>(-r<ycr/)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The state, quality, or character of the heathen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>heathenry</qex> and your laziness.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Heathendom; heathen nations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heather</ent><br/
<hw>Heath"er</hw> <pr>(h<ecr/<th/"<etil/r; 277. This is the only
pronunciation in Scotland)</pr>, <pos>n.</pos> <ety>[See
<er>Heath</er>.]</ety> <def>Heath.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Gorse and grass<br/
And <qex>heather</qex>, where his footsteps pass,<br/
The brighter seem.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heather bell</b></col> <fld>(Bot.)</fld>, <cd>one of the
pretty subglobose flowers of two European kinds of heather (<spn>Erica
Tetralix</spn>, and <spn>Erica cinerea</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heathery</ent><br/
<hw>Heath"er*y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <def>Heathy;
abounding in heather; of the nature of heath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heath fowl</ent><br/
<ent>heathfowl</ent><br/
<mhw><hw>heathfowl</hw>, <hw>heath fowl</hw></mhw> <pos>n.</pos> <def>A
large Northern European black grouse (<spn>Lyrurus tetrix</spn> formerly
<spn>Tetrao tetrix</spn>) with a lyre-shaped tail; it is also called
<altname>heath grouse</altname>, <altname>black game</altname>,
<altname>black grouse</altname>, <altname>heath poult</altname>,
<altname>heath fowl</altname>, and <altname>moor fowl</altname>. See
<cref>heath grouse</cref> under <er>heath</er>, above.</def><br/
<syn><b>Syn. --</b> European black grouse, <spn>Lyrurus
tetrix</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heathy</ent><br/
<hw>Heath"y</hw> <pr>(h<emac/th"<ycr/)</pr>, <pos>a.</pos> <def>Full of
heath; abounding with heath; <as>as, <ex>heathy</ex> land;
<ex>heathy</ex> hills.</as></def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heating</ent><br/
<hw>Heat"ing</hw> <pr>(h<emac/t"<icr/ng)</pr>, <pos>a.</pos> <def>That
heats or imparts heat; promoting warmth or heat; exciting action;
stimulating; <as>as, <ex>heating</ex> medicines or
applications</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heating surface</b></col> <fld>(Steam Boilers)</fld>,
<cd>the aggregate surface exposed to fire or to the heated products of
combustion, esp. of all the plates or sheets that are exposed to water
on their opposite surfaces; -- called also <altname>fire
surface</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heatingly</ent><br/
<hw>Heat"ing*ly</hw>, <pos>adv.</pos> <def>In a heating manner; so as to
make or become hot or heated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heatless</ent><br/
<hw>Heat"less</hw>, <pos>a.</pos> <def>Destitute of heat; cold.</def>
<au>Beau. & Fl.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>heatstroke</ent><br/
<hw>heatstroke</hw> <pos>n.</pos> <def>A physiological disturbance
caused by exposure to excessive heat, resulting in rapid pulse, hot dry
skin, and fever, leading to loss of consciousness.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>heaume</ent><br/
<hw>heaume</hw> <pos>n.</pos> <sn>1.</sn> <def>a large medieval helmet
supported on the shoulders; called also
<altname>helm</altname>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Heave</ent><br/
<hw>Heave</hw> <pr>(h<emac/v)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Heaved</conjf> <pr>(h<emac/vd)</pr>, or
<conjf>Hove</conjf> <pr>(h<omac/v)</pr>; <pos>p. p.</pos>
<conjf>Heaved</conjf>, <conjf>Hove</conjf>, formerly
<conjf>Hoven</conjf> <pr>(h<omac/"v'n)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Heaving</conjf>.]</vmorph> <ety>[OE. <ets>heven</ets>,
<ets>hebben</ets>, AS. <ets>hebban</ets>; akin to OS.
<ets>hebbian</ets>, D. <ets>heffen</ets>, OHG. <ets>heffan</ets>,
<ets>hevan</ets>, G. <ets>heben</ets>, Icel. <ets>hefja</ets>, Sw.
<ets>h<aum/fva</ets>, Dan. <ets>h<ae/ve</ets>, Goth. <ets>hafjan</ets>,
L. <ets>capere</ets> to take, seize; cf. Gr. <grk>kw`ph</grk> handle.
Cf. <er>Accept</er>, <er>Behoof</er>, <er>Capacious</er>,
<er>Forceps</er>, <er>Haft</er>, <er>Receipt</er>.]</ety> <sn>1.</sn>
<def>To cause to move upward or onward by a lifting effort; to lift; to
raise; to hoist; -- often with <xex>up</xex>; <as>as, the wave
<ex>heaved</ex> the boat on land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One <qex>heaved</qex> ahigh, to be hurled down below.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Heave</xex>, as now used, implies that the thing
raised is heavy or hard to move; but formerly it was used in a less
restricted sense.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Here a little child I stand,<br/
<qex>Heaving</qex> up my either hand.</q>
<rj><qau>Herrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw; to cast; -- obsolete, provincial, or
colloquial, except in certain nautical phrases; <as>as, to
<ex>heave</ex> the lead; to <ex>heave</ex> the log.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To force from, or into, any position; to cause to
move; also, to throw off; -- mostly used in certain nautical phrases;
<as>as, to <ex>heave</ex> the ship ahead</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To raise or force from the breast; to utter with
effort; <as>as, to <ex>heave</ex> a sigh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The wretched animal <qex>heaved</qex> forth such groans.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To cause to swell or rise, as the breast or
bosom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The glittering, finny swarms<br/
That <qex>heave</qex> our friths, and crowd upon our shores.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To heave a cable short</b></col> <fld>(Naut.)</fld>,
<cd>to haul in cable till the ship is almost perpendicularly above the
anchor.</cd> -- <col><b>To heave a ship ahead</b></col>
<fld>(Naut.)</fld>, <cd>to warp her ahead when not under sail, as by
means of cables.</cd> -- <col><b>To heave a ship down</b></col>
<fld>(Naut.)</fld>, <cd>to throw or lay her down on one side; to careen
her.</cd> -- <col><b>To heave a ship to</b></col> <fld>(Naut.)</fld>,
<cd>to bring the ship's head to the wind, and stop her motion.</cd> --
<col><b>To heave about</b></col> <fld>(Naut.)</fld>, <cd>to put about
suddenly.</cd> -- <col><b>To heave in</b></col> <fld>(Naut.)</fld>,
<cd>to shorten (cable).</cd> -- <col><b>To heave in stays</b></col>
<fld>(Naut.)</fld>, <cd>to put a vessel on the other tack.</cd> --
<col><b>To heave out a sail</b></col> <fld>(Naut.)</fld>, <cd>to unfurl
it.</cd> -- <col><b>To heave taut</b></col> <fld>(Naut.)</fld>, <cd>to
turn a capstan, etc., till the rope becomes strained. See <er>Taut</er>,
and <er>Tight</er>.</cd> -- <col><b>To heave the lead</b></col>
<fld>(Naut.)</fld>, <cd>to take soundings with lead and line.</cd> --
<col><b>To heave the log</b></col>. <fld>(Naut.)</fld> <cd>See
<er>Log</er>.</cd> -- <col><b>To heave up anchor</b></col>
<fld>(Naut.)</fld>, <cd>to raise it from the bottom of the sea or
elsewhere.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 680 --></p>

<p><ent>Heave</ent><br/
<hw>Heave</hw> <pr>(h<emac/v)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
be thrown up or raised; to rise upward, as a tower or mound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the huge columns <qex>heave</qex> into the sky.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where <qex>heaves</qex> the turf in many a moldering heap.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heaving</qex> sods of Bunker Hill.</q> <rj><qau>E.
Everett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rise and fall with alternate motions, as the
lungs in heavy breathing, as waves in a heavy sea, as ships on the
billows, as the earth when broken up by frost, etc.; to swell; to
dilate; to expand; to distend; hence, to labor; to struggle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Frequent for breath his panting bosom <qex>heaves</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heaving</qex> plain of ocean.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make an effort to raise, throw, or move anything;
to strain to do something difficult.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Church of England had struggled and <qex>heaved</qex> at a
reformation ever since Wyclif's days.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make an effort to vomit; to retch; to
vomit.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To heave at</b></col>. <sd>(a)</sd> <cd>To make an effort
at.</cd> <sd>(b)</sd> <cd>To attack, to oppose.</cd> <mark>[Obs.]</mark>
<au>Fuller.</au> -- <col><b>To heave in sight</b></col> <cd>(as a ship
at sea), to come in sight; to appear.</cd> -- <col><b>To heave
up</b></col>, <cd>to vomit.</cd> <mark>[Low]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heave</ent><br/
<hw>Heave</hw>, <pos>n.</pos> <sn>1.</sn> <def>An effort to raise
something, as a weight, or one's self, or to move something
heavy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After many strains and <qex>heaves</qex><br/
He got up to his saddle eaves.</q> <rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An upward motion; a rising; a swell or distention,
as of the breast in difficult breathing, of the waves, of the earth in
an earthquake, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There's matter in these sighs, these profound
<qex>heaves</qex>,<br/
You must translate.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>None could guess whether the next <qex>heave</qex> of the
earthquake would settle . . . or swallow them.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>A horizontal dislocation in a
metallic lode, taking place at an intersection with another
lode.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heaven</ent><br/
<hw>Heav"en</hw> <pr>(h<ecr/v"'n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>heven</ets>, <ets>hefen</ets>, <ets>heofen</ets>, AS.
<ets>heofon</ets>; akin to OS. <ets>hevan</ets>, LG. <ets>heben</ets>,
<ets>heven</ets>, Icel. <ets>hifinn</ets>; of uncertain origin, cf. D.
<ets>hemel</ets>, G. <ets>himmel</ets>, Icel. <ets>himmin</ets>, Goth.
<ets>himins</ets>; perh. akin to, or influenced by, the root of E.
<ets>heave</ets>, or from a root signifying <ets>to cover</ets>, cf.
Goth. <ets>gaham<omac/n</ets> to put on, clothe one's self, G.
<ets>hemd</ets> shirt, and perh. E. <ets>chemise</ets>.]</ety>
<sn>1.</sn> <def>The expanse of space surrounding the earth; esp., that
which seems to be over the earth like a great arch or dome; the
firmament; the sky; the place where the sun, moon, and stars appear; --
often used in the plural in this sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I never saw the <qex>heavens</qex> so dim by day.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When my eyes shall be turned to behold for the last time the sun
in <qex>heaven</qex>.</q> <rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The dwelling place of the Deity; the abode of bliss;
the place or state of the blessed after death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unto the God of love, high <qex>heaven's</qex> King.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a knell<br/
That summons thee to <qex>heaven</qex> or to hell.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>New thoughts of God, new hopes of <qex>Heaven</qex>.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this general sense <xex>heaven</xex> and its
corresponding words in other languages have as various definite
interpretations as there are phases of religious belief.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The sovereign of heaven; God; also, the assembly of
the blessed, collectively; -- used variously in this sense, as in No.
2.; <as>as, <ex>heaven</ex> helps those who help
themselves</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Her prayers, whom <qex>Heaven</qex> delights to hear.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The will<br/
And high permission of all-ruling <qex>Heaven</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any place of supreme happiness or great comfort;
perfect felicity; bliss; a sublime or exalted condition; <as>as, a
<ex>heaven</ex> of delight</as>.</def> <ldquo/A <xex>heaven</xex> of
beauty.<rdquo/ <au>Shak.</au> <ldquo/The brightest <xex>heaven</xex> of
invention.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O bed! bed! delicious bed!<br/
That <qex>heaven</qex> upon earth to the weary head!</q>
<rj><qau>Hood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Heaven</xex> is very often used, esp. with
participles, in forming compound words, most of which need no special
explanation; as, <xex>heaven</xex>-appeasing,
<xex>heaven</xex>-aspiring, <xex>heaven</xex>-begot,
<xex>heaven</xex>-born, <xex>heaven</xex>-bred,
<xex>heaven</xex>-conducted, <xex>heaven</xex>-descended,
<xex>heaven</xex>-directed, <xex>heaven</xex>-exalted,
<xex>heaven</xex>-given, <xex>heaven</xex>-guided,
<xex>heaven</xex>-inflicted, <xex>heaven</xex>-inspired,
<xex>heaven</xex>-instructed, <xex>heaven</xex>-kissing,
<xex>heaven</xex>-loved, <xex>heaven</xex>-moving,
<xex>heaven</xex>-protected, <xex>heaven</xex>-taught,
<xex>heaven</xex>-warring, and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heaven</ent><br/
<hw>Heav"en</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Heavened</conjf> <pr>(h<ecr/v"'nd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Heavening</conjf>.]</vmorph> <def>To place in happiness
or bliss, as if in heaven; to beatify.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We are happy as the bird whose nest<br/
Is <qex>heavened</qex> in the hush of purple hills.</q> <rj><qau>G.
Massey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavenize</ent><br/
<hw>Heav"en*ize</hw> <pr>(h<ecr/v"'n*<imac/z)</pr>, <pos>v. t.</pos>
<def>To render like heaven or fit for heaven.</def> <mark>[R.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heavenliness</ent><br/
<hw>heav"en*li*ness</hw> <pr>(h<ecr/v"'n*l<icr/*n<ecr/s)</pr>,
<pos>n.</pos> <ety>[From <er>Heavenly</er>.]</ety> <def>The state or
quality of being heavenly.</def> <rj><au>Sir J. Davies.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavenly</ent><br/
<hw>Heav"en*ly</hw> <pr>(h<ecr/v"'n*l<ycr/)</pr>, <pos>a.</pos>
<ety>[AS. <ets>heofonic</ets>.]</ety> <sn>1.</sn> <def>Pertaining to,
resembling, or inhabiting heaven; celestial; not earthly; <as>as,
<ex>heavenly</ex> regions; <ex>heavenly</ex> music.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>As is the <qex>heavenly</qex>, such are they also that are
<qex>heavenly</qex>.</q> <rj><qau>1 Cor. xv. 48.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Appropriate to heaven in character or happiness;
perfect; pure; supremely blessed; <as>as, a <ex>heavenly</ex> race; the
<ex>heavenly</ex>, throng.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The love of heaven makes one <qex>heavenly</qex>.</q> <rj><qau>Sir
P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavenly</ent><br/
<hw>Heav"en*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a manner
resembling that of heaven.</def> <ldquo/She was <xex>heavenly</xex>
true.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>By the influence or agency of heaven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Out <qex>heavenly</qex> guided soul shall climb.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavenly-minded</ent><br/
<hw>Heav"en*ly-mind`ed</hw>
<pr>(h<ecr/v"'n*l<icr/*m<imac/nd`<ecr/d)</pr>, <pos>a.</pos> <def>Having
the thoughts and affections placed on, or suitable for, heaven and
heavenly objects; devout; godly; pious.</def> <au>Milner.</au> --
<wordforms><wf>Heav"en*ly-mind`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavenward</ent><br/
<hw>Heav"en*ward</hw> <pr>(h<ecr/v"'n*w<etil/rd)</pr>, <pos>a. &
adv.</pos> <def>Toward heaven.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heave offering</ent><br/
<hw>Heave" of`fer*ing</hw> <pr>(?)</pr>. <fld>(Jewish Antiq.)</fld>
<def>An offering or oblation heaved up or elevated before the altar, as
the shoulder of the peace offering. See <er>Wave offering</er>.</def>
<-- sic!? --> <rj><au>Ex. xxix. 27.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heaver</ent><br/
<hw>Heav"er</hw> <pr>(h<emac/v"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, heaves or lifts; a laborer employed on
docks in handling freight; <as>as, a coal
<ex>heaver</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A bar used as a lever.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heaves</ent><br/
<hw>Heaves</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A disease of horses,
characterized by difficult breathing, with heaving of the flank,
wheezing, flatulency, and a peculiar cough; broken wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavily</ent><br/
<hw>Heav"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From 2d
<er>Heavy</er>.]</ety> <sn>1.</sn> <def>In a heavy manner; with great
weight; <as>as, to bear <ex>heavily</ex> on a thing; to be
<ex>heavily</ex> loaded.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Heavily</qex> interested in those schemes of emigration.</q>
<rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>As if burdened with a great weight; slowly and
laboriously; with difficulty; hence, in a slow, difficult, or suffering
manner; sorrowfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And took off their chariot wheels, that they drave them
<qex>heavily</qex>.</q> <rj><qau>Ex. xiv. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why looks your grace so <qex>heavily</qex> to-day?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Greatly; intensely; <as>as, <ex>heavily</ex>
involved in a plot; <ex>heavily</ex> invested in real
estate</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>In large quantity; <as>as, it rained
<ex>heavily</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Heaviness</ent><br/
<hw>Heav"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
heavy in its various senses; weight; sadness; sluggishness; oppression;
thickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heaving</ent><br/
<hw>Heav"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lifting or rising;
a swell; a panting or deep sighing.</def> <rj><au>Addison.</au>
<au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavisome</ent><br/
<hw>Heav"i*some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Heavy; dull.</def>
<mark>[Prov.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavy</ent><br/
<hw>Heav"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
heaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavy</ent><br/
<hw>Heav"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Heavier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Heaviest</adjf>.]</amorph> <ety>[OE. <ets>hevi</ets>, AS.
<ets>hefig</ets>, fr. <ets>hebban</ets> to lift, heave; akin to OHG.
<ets>hebig</ets>, <ets>hevig</ets>, Icel. <ets>h<oum/figr</ets>,
<ets>h<oum/fugr</ets>. See <er>Heave</er>.]</ety> <sn>1.</sn>
<def>Heaved or lifted with labor; not light; weighty; ponderous; <as>as,
a <ex>heavy</ex> stone</as>; hence, sometimes, large in extent,
quantity, or effects; <as>as, a <ex>heavy</ex> fall of rain or snow; a
<ex>heavy</ex> failure; <ex>heavy</ex> business transactions, etc.</as>;
often implying strength; <as>as, a <ex>heavy</ex> barrier</as>; also,
difficult to move; <as>as, a <ex>heavy</ex> draught</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not easy to bear; burdensome; oppressive; hard to
endure or accomplish; hence, grievous, afflictive; <as>as,
<ex>heavy</ex> yokes, expenses, undertakings, trials, news,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hand of the Lord was <qex>heavy</qex> upon them of Ashdod.</q>
<rj><qau>1 Sam. v. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The king himself hath a <qex>heavy</qex> reckoning to make.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sent hither to impart the <qex>heavy</qex> news.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Trust him not in matter of <qex>heavy</qex> consequence.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Laden with that which is weighty; encumbered;
burdened; bowed down, either with an actual burden, or with care, grief,
pain, disappointment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heavy</qex> [sorrowing] nobles all in council were.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A light wife doth make a <qex>heavy</qex> husband.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Slow; sluggish; inactive; or lifeless, dull,
inanimate, stupid; <as>as, a <ex>heavy</ex> gait, looks, manners, style,
and the like; a <ex>heavy</ex> writer or book.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whilst the <qex>heavy</qex> plowman snores.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of a <qex>heavy</qex>, dull, degenerate mind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither [is] his ear <qex>heavy</qex>, that it can not hear.</q>
<rj><qau>Is. lix. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Strong; violent; forcible; <as>as, a <ex>heavy</ex>
sea, storm, cannonade, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Loud; deep; -- said of sound; <as>as, <ex>heavy</ex>
thunder</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But, hark! that <qex>heavy</qex> sound breaks in once more.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Dark with clouds, or ready to rain; gloomy; -- said
of the sky.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Impeding motion; cloggy; clayey; -- said of earth;
<as>as, a <ex>heavy</ex> road, soil, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Not raised or made light; <as>as, <ex>heavy</ex>
bread</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Not agreeable to, or suitable for, the stomach; not
easily digested; -- said of food.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Having much body or strength; -- said of wines, or
other liquors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>With child; pregnant.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heavy artillery</b></col>. <fld>(Mil.)</fld> <sd>(a)</sd>
<cd>Guns of great weight or large caliber, esp. siege, garrison, and
seacoast guns.</cd> <sd>(b)</sd> <cd>Troops which serve heavy guns.</cd>
-- <col><b>Heavy cavalry</b></col>. <cd>See under <er>Cavalry</er>.</cd>
-- <col><b>Heavy fire</b></col> <fld>(Mil.)</fld>, <cd>a continuous or
destructive cannonading, or discharge of small arms.</cd> --
<col><b>Heavy metal</b></col> <fld>(Mil.)</fld>, <cd>large guns carrying
balls of a large size; also, large balls for such guns.</cd><-- a type
of rock music (1970's), with a hard beat, amplified electronically -->
-- <col><b>Heavy metals</b></col>. <fld>(Chem.)</fld> <cd>See under
<er>Metal</er>.</cd> -- <col><b>Heavy weight</b></col>, <cd>in
wrestling, boxing, etc., a term applied to the heaviest of the classes
into which contestants are divided. Cf. <cref>Feather weight</cref>
<sd>(c)</sd>, under <er>Feather</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Heavy</xex> is used in composition to form many
words which need no special explanation; as, <xex>heavy</xex>-built,
<xex>heavy</xex>-browed, <xex>heavy</xex>-gaited, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavy</ent><br/
<hw>Heav"y</hw>, <pos>adv.</pos> <def>Heavily; -- sometimes used in
composition; <as>as, <ex>heavy</ex>-laden</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavy</ent><br/
<hw>Heav"y</hw>, <pos>v. t.</pos> <def>To make heavy.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavy-armed</ent><br/
<hw>Heav"y-armed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Mil.)</fld>
<def>Wearing heavy or complete armor; carrying heavy arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heavy-haded</ent><br/
<hw>Heav"y-had"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Clumsy;
awkward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heavy-handed</ent><br/
<hw>heavy-handed</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>ham-fisted</er>.</def><br/
<syn><b>Syn. --</b> bumbling, bungling, butterfingered, ham-fisted,
ham-handed, handless, left-handed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>unjustly harsh or domineering; <as>as, incensed at
the government's <ex>heavy-handed</ex> economic policies</as>.</def><br/
<syn><b>Syn. --</b> harsh, roughshod.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heavy-headed</ent><br/
<hw>Heav"y-head"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dull;
stupid.</def> <ldquo/Gross <xex>heavy-headed</xex> fellows.<rdquo/
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heavy-hearted</ent><br/
<ent>heavyhearted</ent><br/
<mhw><hw>heavyhearted</hw>, <hw>heavy-hearted</hw></mhw> <pos>adj.</pos>
<def>feeling or affected by sorrow or unhappiness.</def><br/
<syn><b>Syn. --</b> blue, sad.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>heavy-laden</ent><br/
<hw>heavy-laden</hw> <pos>adj.</pos> <sn>1.</sn> <def>burdened by
cares.</def><br/
<syn><b>Syn. --</b> care-laden.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>bearing a heavy load; <as>as, the
<ex>heavy-laden</ex> trucks wore deep ruts in the unpaved
road</as>.</def><br/
<syn><b>Syn. --</b> burdened, laden, weighed down.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>heavyset</ent><br/
<hw>heavyset</hw> <pos>adj.</pos> <sn>1.</sn> <def>obese.</def>
<note>usually men are portly and women are stout</note><br/
<syn><b>Syn. --</b> portly, stout.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>heavy and compact in form or build or
stature.</def><br/
<syn><b>Syn. --</b> compact, stocky, thick, thickset.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heavy spar</ent><br/
<hw>Heav"y spar`</hw> <pr>(?)</pr>. <fld>(Min.)</fld> <def>Native barium
sulphate or barite, -- so called because of its high specific gravity as
compared with other non-metallic minerals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heavyweight</ent><br/
<hw>heavyweight</hw> <pos>adj.</pos> <def>heaviest in a category;
<as>as, a <ex>heavyweight</ex> boxer</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>heavyweight</ent><br/
<hw>heavyweight</hw> <pos>n.</pos> <sn>1.</sn> <def>a wrestler who
weighs more than 214 pounds.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a boxer who weighs more than 195 pounds.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a very large person.</def><br/
<syn><b>Syn. --</b> giant, hulk.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>a person of exceptional importance and
reputation.</def><br/
<syn><b>Syn. --</b> colossus, behemoth, giant, titan.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hebdomad</ent><br/
<hw>Heb"do*mad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hebdomas</ets>, <ets>-adis</ets>, Gr. <grk>"ebdoma`s</grk> the
number seven days, fr. <?/ seventh, <?/ seven. See
<er>Seven</er>.]</ety> <def>A week; a period of seven days.</def>
<mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj></p>

<p><ent>Hebdomadary</ent><br/
<ent>Hebdomadal</ent><br/
<mhw>{ <hw>Heb*dom"a*dal</hw> <pr>(?)</pr>, <hw>Heb*dom"a*da*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hebdomadalis</ets>,
LL. <ets>hebdomadarius</ets>: cf. F. <ets>hebdomadaire</ets>.]</ety>
<def>Consisting of seven days, or occurring at intervals of seven days;
weekly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebdomadally</ent><br/
<hw>Heb*dom"a*dal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In periods
of seven days; weekly.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebdomadary</ent><br/
<hw>Heb*dom"a*da*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>hebdomadarius</ets>: cf. F. <ets>hebdomadier</ets>.]</ety> <fld>(R.
C. Ch.)</fld> <def>A member of a chapter or convent, whose week it is to
officiate in the choir, and perform other services, which, on
extraordinary occasions, are performed by the superiors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebdomatical</ent><br/
<hw>Heb`do*mat"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hebdomaticus</ets>, Gr. <?/.]</ety> <def>Weekly; hebdomadal.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebe</ent><br/
<hw>He"be</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>"h`bh</grk> youth, <grk>"H`bh</grk> Hebe.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Class. Myth.)</fld> <def>The goddess of youth,
daughter of Jupiter and Juno. She was believed to have the power of
restoring youth and beauty to those who had lost them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>An African ape; the
hamadryas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heben</ent><br/
<hw>Heb"en</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ebony.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebenon</ent><br/
<hw>Heb"e*non</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Henbane</er>.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebetate</ent><br/
<hw>Heb"e*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hebetated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hebetating</conjf>.]</vmorph> <ety>[L.
<ets>hebetatus</ets>, p. p. of <ets>hebetare</ets> to dull. See
<er>Hebete</er>.]</ety> <def>To render obtuse; to dull; to blunt; to
stupefy; <as>as, to <ex>hebetate</ex> the intellectual
faculties</as>.</def> <rj><au>Southey</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebetate</ent><br/
<hw>Heb"e*tate</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Obtuse;
dull.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having a dull or blunt and soft
point.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebetation</ent><br/
<hw>Heb`e*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hebetatio</ets>: cf. F. <ets>h<eacute/b<eacute/tation</ets>.]</ety>
<sn>1.</sn> <def>The act of making blunt, dull, or stupid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being blunted or dulled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebete</ent><br/
<hw>He*bete"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>hebes</ets>,
<ets>hebetis</ets>, dull, stupid, fr. <ets>hebere</ets> to be
dull.]</ety> <def>Dull; stupid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebetude</ent><br/
<hw>Heb"e*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hebetudo</ets>.]</ety> <def>Dullness; stupidity.</def>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraic</ent><br/
<hw>He"bra"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Hebraicus</ets>, Gr. <?/: cf. F. <ets>hebra<ium/que</ets>. See
<er>Hebrew</er>.]</ety> <def>Of or pertaining to the Hebrews, or to the
language of the Hebrews.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraically</ent><br/
<hw>He*bra"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>After the
manner of the Hebrews or of the Hebrew language.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraism</ent><br/
<hw>He"bra*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>h<eacute/bra<ium/sme</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A Hebrew idiom or custom; a peculiar expression or
manner of speaking in the Hebrew language.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The type of character of the Hebrews.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The governing idea of <qex>Hebraism</qex> is strictness of
conscience.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraist</ent><br/
<hw>He"bra*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>h<eacute/bra<ium/ste</ets>.]</ety> <def>One versed in the Hebrew
language and learning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraistic</ent><br/
<hw>He`bra*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or resembling, the Hebrew language or idiom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraistically</ent><br/
<hw>He`bra*is"tic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
Hebraistic sense or form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which is <qex>Hebraistically</qex> used in the New Testament.</q>
<rj><qau>Kitto.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraize</ent><br/
<hw>He"bra*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Gr. <?/ to
speak Hebrew: cf. F. <ets>h<eacute/bra<ium/ser</ets>.]</ety> <def>To
convert into the Hebrew idiom; to make Hebrew or Hebraistic.</def>
<rj><au>J. R. Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebraize</ent><br/
<hw>He"bra*ize</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hebraized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hebraizing</conjf>.]</vmorph> <def>To speak Hebrew, or to conform
to the Hebrew idiom, or to Hebrew customs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebrew</ent><br/
<hw>He"brew</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>H<eacute/breu</ets>, L. <ets>Hebraeus</ets>, Gr. <?/, fr. Heb.
<ets>'ibhr<imac/</ets>.]</ety> <sn>1.</sn> <def>An appellative of
Abraham or of one of his descendants, esp. in the line of Jacob; an
Israelite; a Jew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There came one that had escaped and told Abram the
<qex>Hebrew</qex>.</q> <rj><qau>Gen. xiv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language of the Hebrews; -- one of the Semitic
family of languages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebrew</ent><br/
<hw>He"brew</hw>, <pos>a.</pos> <def>Of or pertaining to the Hebrews;
<as>as, the <ex>Hebrew</ex> language or rites</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebrew calendar</ent><br/
<hw>Hebrew calendar</hw>. <def>same as <er>Jewish
calendar</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hebrewess</ent><br/
<hw>He"brew*ess</hw>, <pos>n.</pos> <def>An Israelitish woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hebrician</ent><br/
<hw>He*bri"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Hebraist.</def>
<mark>[R.]</mark></p>

<p><ent>Hebridian</ent><br/
<ent>Hebridean</ent><br/
<mhw>{ <hw>He*brid"e*an</hw> <pr>(?)</pr>, <hw>He*brid"i*an</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to the islands
called Hebrides, west of Scotland.</def> -- <def2><pos>n.</pos> <def>A
native or inhabitant of the Hebrides.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hecatomb</ent><br/
<hw>Hec"a*tomb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hecatombe</ets>, Gr. <?/; <?/ hundred + <?/ ox: cf. F.
<ets>h<eacute/catombe</ets>.]</ety> <fld>(Antiq.)</fld> <def>A sacrifice
of a hundred oxen or cattle at the same time; hence, the sacrifice or
slaughter of any large number of victims.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Slaughtered <qex>hecatombs</qex> around them bleed.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>More than a human <qex>hecatomb</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hecatompedon</ent><br/
<hw>Hec`a*tom"pe*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
hundred feet long, <?/ <?/ the Parthenon; <?/ hundred + <?/ foot.]</ety>
<fld>(Arch.)</fld> <def>A name given to the old Parthenon at Athens,
because measuring 100 Greek feet, probably in the width across the
stylobate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hecdecane</ent><br/
<hw>Hec"de*cane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ six + <?/
ten.]</ety> <fld>(Chem.)</fld> <def>A white, semisolid, spermaceti-like
hydrocarbon, <chform>C16H34</chform>, of the paraffin series, found
dissolved as an important ingredient of kerosene, and so called because
each molecule has sixteen atoms of carbon; -- called also
<altname>hexadecane</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heck</ent><br/
<hw>Heck</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Hatch</er> a
half door.]</ety> <altsp>[Written also <asp>hack</asp>.]</altsp>
<sn>1.</sn> <def>The bolt or latch of a door.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rack for cattle to feed at.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A door, especially one partly of latticework; --
called also <altname>heck door</altname>.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A latticework contrivance for catching
fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Weaving)</fld> <def>An apparatus for separating the
threads of warps into sets, as they are wound upon the reel from the
bobbins, in a warping machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A bend or winding of a stream.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Half heck</b></col>, <cd>the lower half of a door.</cd>
-- <col><b>Heck board</b></col>, <cd>the loose board at the bottom or
back of a cart.</cd> -- <mcol><col><b>Heck box</b></col> <it>or</it>
<col><b>Heck frame</b></col></mcol>, <cd>that which carries the heck in
warping.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heck</ent><br/
<hw>Heck</hw> <pr>(?)</pr>, <pos>n.</pos> <def>hell; -- a euphemism.
Used commonly in the phrase <ldquo/What the
<xex>heck</xex><rdquo/.</def> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Heckerism</ent><br/
<hw>Heck"er*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(R. C. Ch.)</fld>
<sd>(a)</sd> <def>The teaching of <person>Isaac Thomas
<etsep>Hecker</etsep></person> (1819-88), which interprets Catholicism
as promoting human aspirations after liberty and truth, and as the
religion best suited to the character and institutions of the American
people.</def> <sd>(b)</sd> <def>Improperly, certain views or principles
erroneously ascribed to <person>Father Hecker</person> in a French
translation of Elliott's Life of <persfn>Hecker</persfn>. They were
condemned as <ldquo/Americanism<rdquo/ by the Pope, in a letter to
<person>Cardinal Gibbons</person>, January 22, 1899.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heckimal</ent><br/
<hw>Heck"i*mal</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European blue titmouse (<spn>Parus c<oe/ruleus</spn>).</def>
<altsp>[Written also <asp>heckimel</asp>, <asp>hackeymal</asp>,
<asp>hackmall</asp>, <asp>hagmall</asp>, and
<asp>hickmall</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heckle</ent><br/
<hw>Hec"kle</hw> <pr>(?)</pr>, <pos>n. & v. t.</pos> <def>Same as
<er>Hackle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heckle</ent><br/
<hw>Hec"kle</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To interrogate, or
ply with questions, esp. with severity or antagonism, as a candidate for
the ministry.</def></p>

<p><q>Robert bore <qex>heckling</qex>, however, with great patience and
adroitness.</q> <rj><qau>Mrs. Humphry Ward.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To shout questions or jibes at (a public speaker),
so as to disconcert him or render his talk ineffective.</def><br/
[<source>PJC</source>]</p>

<p><ent>heckling</ent><br/
<hw>heckling</hw> <pos>n.</pos> <ety>[<pos>vb. n.</pos> from
<er>heckle</er>{2}.]</ety> <def>Shouting in order to interrupt a speech
with which the shouter disagrees.</def><br/
<syn><b>Syn. --</b> barracking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hectare</ent><br/
<hw>Hec"tare`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Gr. <?/
hundred + F. <ets>are</ets> an are.]</ety> <def>A measure of area, or
superficies, containing a hundred ares, or 10,000 square meters, and
equivalent to 2.471 acres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectic</ent><br/
<hw>Hec"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>hectique</ets>, Gr. <?/ habitual, consumptive, fr. <?/ habit, a
habit of body or mind, fr. <?/ to have; akin to Skr. <ets>sah</ets> to
overpower, endure; cf. AS. <ets>sige</ets>, <ets>sigor</ets>, victory,
G. <ets>sieg</ets>, Goth. <ets>sigis</ets>. Cf. <er>Scheme</er>.]</ety>
<sn>1.</sn> <def>Habitual; constitutional; pertaining especially to slow
waste of animal tissue, as in consumption; <as>as, a <ex>hectic</ex>
type in disease; a <ex>hectic</ex> flush.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a hectic condition; having hectic fever;
consumptive; <as>as, a <ex>hectic</ex> patient</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hectic fever</b></col> <fld>(Med.)</fld>, <cd>a fever of
irritation and debility, occurring usually at a advanced stage of
exhausting disease, as a in pulmonary consumption.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectic</ent><br/
<hw>Hec"tic</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Med.)</fld>
<def>Hectic fever.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hectic flush.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is no living hue, but a strange <qex>hectic</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 681 --></p>

<p><ent>Hectocotylized</ent><br/
<hw>Hec`to*cot"y*lized</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Changed into a hectocotylus; having a
hectocotylis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectocotylus</ent><br/
\'d8<hw>Hec`to*cot"y*lus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hectocotyli</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
fr. Gr. <?/ a hundred + <?/ a hollow vessel.]</ety> <fld>(Zool.)</fld>
<def>One of the arms of the male of most kinds of cephalopods, which is
specially modified in various ways to effect the fertilization of the
eggs. In a special sense, the greatly modified arm of Argonauta and
allied genera, which, after receiving the spermatophores, becomes
detached from the male, and attaches itself to the female for
reproductive purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hectogram</ent><br/
<hw>hec"to*gram</hw> <pr>(h<ecr/k"t<osl/*gr<acr/m)</pr>, <pos>n.</pos>
<ety>[F. <ets>hectogramme</ets>, fr. Gr. <grk>'ekato`n</grk> hundred +
F. <ets>gramme</ets> a gram.]</ety> <def>A measure of mass or weight,
containing a hundred grams, or about 3.527 ounces avoirdupois. See 3rd
<er>gram</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectogramme</ent><br/
<hw>Hec"to*gramme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>The same as <er>Hectogram</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectograph</ent><br/
<hw>Hec"to*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ hundred
+ <ets>-graph</ets>.]</ety> <def>A contrivance for multiple copying, by
means of a surface of gelatin softened with glycerin.</def>
<altsp>[Written also <asp>hectograph</asp>.]</altsp></p>

<p><ent>Hectolitre</ent><br/
<ent>Hectoliter</ent><br/
<mhw>{ <hw>Hec"to*li`ter</hw>, <hw>Hec"to*li`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>hectolitre</ets>, fr. Gr. <?/
hundred + F. <ets>litre</ets> a liter.]</ety> <def>A measure of liquids,
containing a hundred liters; equal to a tenth of a cubic meter, nearly
26<frac12/ gallons of wine measure, or 22.0097 imperial gallons. As a
dry measure, it contains ten decaliters, or about 2<frac56/ Winchester
bushels.</def></p>

<p><ent>Hectometre</ent><br/
<ent>Hectometer</ent><br/
<mhw>{ <hw>Hec"to*me`ter</hw>, <hw>Hec"to*me`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <?/ <ets>hectom<egrave/tre</ets>,
fr. Gr. <?/ hundred + F. <ets>m<egrave/tre</ets> a meter.]</ety> <def>A
measure of length, equal to a hundred meters. It is equivalent to 328.09
feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hector</ent><br/
<hw>Hec"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the Trojan
warrior <ets>Hector</ets>, the son of Priam.]</ety> <def>A bully; a
blustering, turbulent, insolent, fellow; one who vexes or
provokes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hector</ent><br/
<hw>Hec"tor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hectored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hectoring</conjf>.]</vmorph> <def>To treat with insolence; to
threaten; to bully; hence, to torment by words; to tease; to taunt; to
worry or irritate by bullying.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hector</ent><br/
<hw>Hec"tor</hw>, <pos>v. i.</pos> <def>To play the bully; to bluster;
to be turbulent or insolent.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectorism</ent><br/
<hw>Hec"to*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The disposition or
the practice of a hector; a bullying.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectorly</ent><br/
<hw>Hec"tor*ly</hw>, <pos>a.</pos> <def>Resembling a hector; blustering;
insolent; taunting.</def> <ldquo/<xex>Hectorly</xex>, ruffianlike
swaggering or huffing.<rdquo/ <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hectostere</ent><br/
<hw>Hec"to*stere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hectost<egrave/re</ets>; Gr. <?/ hundred + F.
<ets>st<egrave/re</ets>.]</ety> <def>A measure of solidity, containing
one hundred cubic meters, and equivalent to 3531.66 English or 3531.05
United States cubic feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heddle</ent><br/
<hw>Hed"dle</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Heddles</plw> <pr>(#)</pr>.</plu> <ety>[Cf. <er>Heald</er>.]</ety>
<fld>(Weaving)</fld> <def>One of the sets of parallel doubled threads
which, with mounting, compose the harness employed to guide the warp
threads to the lathe or batten in a loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heddle</ent><br/
<hw>Hed"dle</hw>, <pos>v. t.</pos> <def>To draw (the warp thread)
through the heddle-eyes, in weaving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heddle-eye</ent><br/
<hw>Hed"dle-eye`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Weaving)</fld>
<def>The eye or loop formed in each heddle to receive a warp
thread.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heddling</ent><br/
<hw>Hed"dling</hw> <pr>(?)</pr>, <pos>vb. n.</pos> <def>The act of
drawing the warp threads through the heddle-eyes of a weaver's harness;
the harness itself.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hederaceous</ent><br/
<hw>Hed`er*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hederaceus</ets>, fr. <ets>hedera</ets> ivy.]</ety> <def>Of,
pertaining to, or resembling, ivy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hederal</ent><br/
<hw>Hed"er*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
ivy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hederic</ent><br/
<hw>He*der"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
derived from, the ivy (<gen>Hedera</gen>); <as>as, <ex>hederic</ex>
acid, an acid of the acetylene series</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hederiferous</ent><br/
<hw>Hed`er*if"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hedera</ets> ivy + <ets>-ferous</ets>.]</ety> <def>Producing ivy;
ivy-bearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hederose</ent><br/
<hw>Hed"er*ose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hederosus</ets>, fr. <ets>hedera</ets> ivy.]</ety> <def>Pertaining
to, or of, ivy; full of ivy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedge</ent><br/
<hw>Hedge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hegge</ets>,
AS. <ets>hecg</ets>; akin to <ets>haga</ets> an inclosure, E.
<ets>haw</ets>, AS. <ets>hege</ets> hedge, E. <ets>hay</ets>bote, D.
<ets>hegge</ets>, OHG. <ets>hegga</ets>, G. <ets>hecke</ets>. <root/12.
See <er>Haw</er> a hedge.]</ety> <def>A thicket of bushes, usually thorn
bushes; especially, such a thicket planted as a fence between any two
portions of land; and also any sort of shrubbery, as evergreens, planted
in a line or as a fence; particularly, such a thicket planted round a
field to fence it, or in rows to separate the parts of a
garden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The roughest berry on the rudest <qex>hedge</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Through the verdant maze<br/
Of sweetbrier <qex>hedges</qex> I pursue my walk.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hedge</xex>, when used adjectively or in
composition, often means <xex>rustic</xex>, <xex>outlandish</xex>,
<xex>illiterate</xex>, <xex>poor</xex>, or <xex>mean</xex>; as,
<xex>hedge</xex> priest; <xex>hedge</xex>born, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hedge bells</b></col>, <col><b>Hedge
bindweed</b></col></mcol> <fld>(Bot.)</fld>, <cd>a climbing plant
related to the morning-glory (<spn>Convolvulus sepium</spn>).</cd> --
<col><b>Hedge bill</b></col>, <cd>a long-handled billhook.</cd> --
<col><b>Hedge garlic</b></col> <fld>(Bot.)</fld>, <cd>a plant of the
genus <gen>Alliaria</gen>. See <cref>Garlic mustard</cref>, under
<er>Garlic</er>.</cd> -- <col><b>Hedge hyssop</b></col>
<fld>(Bot.)</fld>, <cd>a bitter herb of the genus <gen>Gratiola</gen>,
the leaves of which are emetic and purgative.</cd> -- <col><b>Hedge
marriage</b></col>, <cd>a secret or clandestine marriage, especially one
performed by a hedge priest.</cd> <mark>[Eng.]</mark> -- <col><b>Hedge
mustard</b></col> <fld>(Bot.)</fld>, <cd>a plant of the genus
<gen>Sisymbrium</gen>, belonging to the Mustard family.</cd> --
<col><b>Hedge nettle</b></col> <fld>(Bot.)</fld>, <cd>an herb, or under
shrub, of the genus <gen>Stachys</gen>, belonging to the Mint family. It
has a nettlelike appearance, though quite harmless.</cd> --
<col><b>Hedge note</b></col>. <sd>(a)</sd> <cd>The note of a hedge
bird.</cd> <sd>(b)</sd> <cd>Low, contemptible writing.</cd>
<mark>[Obs.]</mark> <au>Dryden.</au> -- <col><b>Hedge priest</b></col>,
<cd>a poor, illiterate priest.</cd> <au>Shak.</au> -- <col><b>Hedge
school</b></col>, <cd>an open-air school in the shelter of a hedge, in
Ireland; a school for rustics.</cd> -- <col><b>Hedge sparrow</b></col>
<fld>(Zool.)</fld>, <cd>a European warbler (<spn>Accentor
modularis</spn>) which frequents hedges. Its color is reddish brown, and
ash; the wing coverts are tipped with white. Called also
<altname>chanter</altname>, <altname>hedge warbler</altname>,
<altname>dunnock</altname>, and <altname>doney</altname>.</cd> --
<col><b>Hedge writer</b></col>, <cd>an insignificant writer, or a writer
of low, scurrilous stuff.</cd> <mark>[Obs.]</mark> <au>Swift.</au> --
<col><b>To breast up a hedge</b></col>. <cd>See under
<er>Breast</er>.</cd> -- <col><b>To hang in the hedge</b></col>, <cd>to
be at a standstill.</cd> <ldquo/While the business of money <xex>hangs
in the hedge</xex>.<rdquo/ <rj><au>Pepys.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedge</ent><br/
<hw>Hedge</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hedged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hedging</conjf>.]</vmorph> <sn>1.</sn> <def>To inclose or
separate with a hedge; to fence with a thickly set line or thicket of
shrubs or small trees; <as>as, to <ex>hedge</ex> a field or
garden</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To obstruct, as a road, with a barrier; to hinder
from progress or success; -- sometimes with <xex>up</xex> and
<xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>hedge</qex> up thy way with thorns.</q> <rj><qau>Hos.
ii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lollius Urbius . . . drew another wall . . . to <qex>hedge</qex>
out incursions from the north.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To surround for defense; to guard; to protect; to
hem (in).</def> <ldquo/England, <xex>hedged</xex> in with the
main.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To surround so as to prevent escape.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That is a law to <qex>hedge</qex> in the cuckoo.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To protect oneself against excessive loss in an
activity by taking a countervailing action; <as>as, to <ex>hedge</ex> an
investment denominated in a foreign currency by buying or selling
futures in that currency; to <ex>hedge</ex> a donation to one political
party by also donating to the opposed political party</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To hedge a bet</b></col>, <cd>to bet upon both sides;
that is, after having bet on one side, to bet also on the other, thus
guarding against loss. See hedge{5}.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedge</ent><br/
<hw>Hedge</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To shelter one's self
from danger, risk, duty, responsibility, etc., as if by hiding in or
behind a hedge; to skulk; to slink; to shirk obligations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I myself sometimes, leaving the fear of God on the left hand and
hiding mine honor in my necessity, am fain to shuffle, to
<qex>hedge</qex> and to lurch.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Betting)</fld> <def>To reduce the risk of a wager
by making a bet against the side or chance one has bet on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To use reservations and qualifications in one's
speech so as to avoid committing one's self to anything
definite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Heroic Stanzas read much more like an elaborate attempt to
<qex>hedge</qex> between the parties than . . . to gain favor from the
Roundheads.</q> <rj><qau>Saintsbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedgeborn</ent><br/
<hw>Hedge"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Born under a
hedge; of low birth.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedgebote</ent><br/
<hw>Hedge"bote`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eng. Law)</fld>
<def>Same as <er>Haybote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hedged</ent><br/
<hw>hedged</hw> <pos>adj.</pos> <ety>[<pos>p. p.</pos> from
<er>hedge</er>, <pos>v. i.</pos> {3}.]</ety> <def>qualified; limited or
restricted; <as>as, a <ex>hedged</ex> promise</as>.</def><br/
<syn><b>Syn. --</b> weasel-worded.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hedge fund</ent><br/
<hw>Hedge" fund`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Finance)</fld>
<def>a mutual fund or partnership of investors who pool large sums of
money to speculate in securities, increasing the risk of such activity
by using borrowed money to leverage the investments, or by selling
short.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hedgehog</ent><br/
<hw>Hedge"hog`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A small European insectivore (<spn>Erinaceus
Europaeus</spn>), and other allied species of Asia and Africa, having
the hair on the upper part of its body mixed with prickles or spines. It
is able to roll itself into a ball so as to present the spines outwardly
in every direction. It is nocturnal in its habits, feeding chiefly upon
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The Canadian
porcupine.</def><mark>[U.S]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A species of <gen>Medicago</gen>
(<spn>Medicago intertexta</spn>), the pods of which are armed with short
spines; -- popularly so called.</def> <rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A form of dredging machine.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Elec.)</fld> <def>A variety of transformer with
open magnetic circuit, the ends of the iron wire core being turned
outward and presenting a bristling appearance, whence the
name.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>6.</sn> <fld>(Mil.)</fld> <def>a defensive obstacle having
pointed barbs extending outward, such as one composed of crossed logs
with barbed wire wound around them, or a tangle of steel beams embedded
in concrete used to impede or damage landing craft on a beach; also, a
position well-fortified with such defensive obstacles.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Hedgehog caterpillar</b></col> <fld>(Zool.)</fld>,
<cd>the hairy larvae of several species of bombycid moths, as of the
Isabella moth. It curls up like a hedgehog when disturbed. See
<er>Woolly bear</er>, and <er>Isabella moth</er>.</cd> --
<col><b>Hedgehog fish</b></col> <fld>(Zool.)</fld>, <cd>any spinose
plectognath fish, esp. of the genus <gen>Diodon</gen>; the porcupine
fish.</cd> -- <col><b>Hedgehog grass</b></col> <fld>(Bot.)</fld>, <cd>a
grass with spiny involucres, growing on sandy shores; burgrass
(<spn>Cenchrus tribuloides</spn>).</cd> -- <col><b>Hedgehog
rat</b></col> <fld>(Zool.)</fld>, <cd>one of several West Indian
rodents, allied to the porcupines, but with ratlike tails, and few
quills, or only stiff bristles. The hedgehog rats belong to
<gen>Capromys</gen>, <gen>Plagiodon</gen>, and allied genera.</cd> --
<col><b>Hedgehog shell</b></col> <fld>(Zool.)</fld>, <cd>any spinose,
marine, univalve shell of the genus <gen>Murex</gen>.</cd> --
<col><b>Hedgehog thistle</b></col> <fld>(Bot.)</fld>, <cd>a plant of the
Cactus family, globular in form, and covered with spines
(<gen>Echinocactus</gen>).</cd> -- <col><b>Sea hedgehog</b></col>.
<cd>See <er>Diodon</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedgeless</ent><br/
<hw>Hedge"less</hw>, <pos>a.</pos> <def>Having no hedge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedgepig</ent><br/
<hw>Hedge"pig`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A young
hedgehog.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedger</ent><br/
<hw>Hedg"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes or mends
hedges; also, one who hedges, <as>as, in betting</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedgerow</ent><br/
<hw>Hedge"row`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A row of shrubs, or
trees, planted for inclosure or separation of fields.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>hedgerow</qex> elms and hillocks green.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedging bill</ent><br/
<hw>Hedg"ing bill`</hw> <pr>(?)</pr>. <def>A hedge bill. See under
<er>Hedge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hediondilla</ent><br/
<hw>hediondilla</hw> <pos>n.</pos> <def>A desert shrub (<spn>Larrea
tridentata</spn>) of the Southwestern U.S. and Northern Mexico having
persistent resinous aromatic foliage and small yellow flowers.</def><br/
<syn><b>Syn. --</b> creosote bush, coville, <spn>Larrea
tridentata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hedonic</ent><br/
<hw>He*don"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, fr. <?/
pleasure, <?/ sweet, pleasant.]</ety> <sn>1.</sn> <def>Pertaining to
pleasure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or relating to Hedonism or the Hedonic
sect.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hedonic sect</b></col> <cd>a sect that placed the highest
good in the gratification of the senses, -- called also
<altname>Cyrenaic sect</altname>, (which see), and <altname>School of
Aristippus</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedonics</ent><br/
<hw>He*don"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Philos.)</fld>
<def>That branch of moral philosophy which treats of the relation of
duty to pleasure; the science of practical, positive enjoyment or
pleasure.</def> <rj><au>J. Grote.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedonism</ent><br/
<hw>Hed"on*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
doctrine of the Hedonic sect; the pursuit of pleasure as a matter of
ethical principle.</def> <wns>[wns=1]</wns><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The ethical theory which finds the explanation and
authority of duty in its tendency to give pleasure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedonist</ent><br/
<hw>Hed"on*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who believes in
hedonism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedonistic</ent><br/
<hw>Hed`o*nis"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Hedonic</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hedysarum</ent><br/
<hw>Hedysarum</hw> <pos>n.</pos> <def>A genus of herbs of Northern
temperate regions.</def><br/
<syn><b>Syn. --</b> genus <gen>Hedysarum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heed</ent><br/
<hw>Heed</hw> <pr>(h<emac/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Heeded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Heeding</conjf>.]</vmorph> <ety>[OE. <ets>heden</ets>, AS.
<ets>h<emac/dan</ets>; akin to OS. <ets>h<omac/dian</ets>, D.
<ets>hoeden</ets>, Fries. <ets>hoda</ets>, OHG. <ets>huoten</ets>, G.
<ets>h<uum/ten</ets>, Dan. <ets>hytte</ets>. <root/13. Cf.
<er>Hood</er>.]</ety> <def>To mind; to regard with care; to take notice
of; to attend to; to observe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With pleasure Argus the musician <qex>heeds</qex>.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To notice; regard; mind. See <er>Attend</er>,
<pos>v. t.</pos></syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heed</ent><br/
<hw>Heed</hw>, <pos>v. i.</pos> <def>To mind; to consider.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heed</ent><br/
<hw>Heed</hw>, <pos>n.</pos> <sn>1.</sn> <def>Attention; notice;
observation; regard; -- often with <xex>give</xex> or
<xex>take</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With wanton <qex>heed</qex> and giddy cunning.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Amasa took no <qex>heed</qex> to the sword that was in Joab's
hand.</q> <rj><qau>2 Sam. xx. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Birds give more <qex>heed</qex> and mark words more than
beasts.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Careful consideration; obedient regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore we ought to give the more earnest <qex>heed</qex> to the
things which we have heard.</q> <rj><qau>Heb. ii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A look or expression of heading.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He did it with a serious mind; a <qex>heed</qex><br/
Was in his countenance.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heedful</ent><br/
<hw>Heed"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of heed;
regarding with care; cautious; circumspect; attentive; vigilant.</def>
<rj><au>Shak.</au></rj></p>

<p>-- <wordforms><wf>Heed"ful*ly</wf>, <pos>adv.</pos> --
<wf>Heed"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heedless</ent><br/
<hw>Heed"less</hw>, <pos>a.</pos> <def>Without heed or care;
inattentive; careless; thoughtless; unobservant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, negligent and <qex>heedless</qex> discipline!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heedless</qex> lover does not know<br/
Whose eyes they are that wound him so.</q>
<rj><qau>Waller.</qau></rj></p>

<p>-- <wordforms><wf>Heed"less*ly</wf>, <pos>adv.</pos> --
<wf>Heed"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heedy</ent><br/
<hw>Heed"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Heedful.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Heedy</xex> shepherds.<rdquo/
<au>Spenser.</au> -- <wordforms><wf>Heed"i*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos> <mark>[Obs.]</mark> -- <wf>Heed"i*ness</wf>,
<pos>n.</pos> <mark>[Obs.]</mark> <au>Spenser.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>hee-haw</ent><br/
<hw>hee-haw</hw> <pos>v. i.</pos> <def>to bray in the manner of a
donkey.</def><br/
<syn><b>Syn. --</b> bray.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hee-haw</ent><br/
<hw>hee-haw</hw> <pos>n.</pos> <def>a loud laugh that sounds like a
horse neighing.</def><br/
<syn><b>Syn. --</b> horselaugh, ha-ha, haw-haw.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heel</ent><br/
<hw>Heel</hw> <pr>(h<emac/l)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>helden</ets> to lean, incline, AS. <ets>heldan</ets>,
<ets>hyldan</ets>; akin to Icel. <ets>halla</ets>, Dan.
<ets>helde</ets>, Sw. <ets>h<aum/lla</ets> to tilt, pour, and perh. to
E. <ets>hill</ets>.]</ety> <fld>(Naut.)</fld> <def>To lean or tip to one
side, as a ship; <as>as, the ship <ex>heels</ex> aport; the boat
<ex>heeled</ex> over when the squall struck it.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heeling error</b></col> <fld>(Naut.)</fld>, <cd>a
deviation of the compass caused by the heeling of an iron vessel to one
side or the other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heel</ent><br/
<hw>Heel</hw>, <pos>n.</pos> <ety>[OE. <ets>hele</ets>,
<ets>heele</ets>, AS. <ets>h<emac/la</ets>, perh. for
<ets>h<omac/hila</ets>, fr. AS. <ets>h<omac/h</ets> heel (cf.
<er>Hough</er>); but cf. D. <ets>hiel</ets>, OFries. <ets>heila</ets>,
<ets>h<emac/la</ets>, Icel. <ets>h<ae/ll</ets>, Dan. <ets>h<ae/l</ets>,
Sw. <ets>h<aum/l</ets>, and L. <ets>calx</ets>. <root/12. Cf.
<er>Inculcate</er>.]</ety> <sn>1.</sn> <def>The hinder part of the foot;
sometimes, the whole foot; -- in man or quadrupeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [the stag] calls to mind his strength and then his speed,<br/
His winged <qex>heels</qex> and then his armed head.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The hinder part of any covering for the foot, as of
a shoe, sock, etc.; specif., a solid part projecting downward from the
hinder part of the sole of a boot or shoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The latter or remaining part of anything; the
closing or concluding part.</def> <ldquo/The <xex>heel</xex> of a
hunt.<rdquo/ <au>A. Trollope.</au> <ldquo/The <xex>heel</xex> of the
white loaf.<rdquo/ <au>Sir W. Scott.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Anything regarded as like a human heel in shape; a
protuberance; a knob.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The part of a thing corresponding in position to the
human heel; the lower part, or part on which a thing rests</def>;
especially: <sd>(a)</sd> <fld>(Naut.)</fld> <def>The after end of a
ship's keel.</def> <sd>(b)</sd> <fld>(Naut.)</fld> <def>The lower end of
a mast, a boom, the bowsprit, the sternpost, etc.</def> <sd>(c)</sd>
<fld>(Mil.)</fld> <def>In a small arm, the corner of the but which is
upwards in the firing position.</def> <sd>(d)</sd> <fld>(Mil.)</fld>
<def>The uppermost part of the blade of a sword, next to the hilt.</def>
<sd>(e)</sd> <def>The part of any tool next the tang or handle; <as>as,
the <ex>heel</ex> of a scythe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Man.)</fld> <def>Management by the heel, especially
the spurred heel; <as>as, the horse understands the <ex>heel</ex>
well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>The lower end of a
timber in a frame, as a post or rafter. In the United States, specif.,
the obtuse angle of the lower end of a rafter set sloping.</def>
<sd>(b)</sd> <def>A cyma reversa; -- so called by workmen.</def>
<rj><au>Gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Golf)</fld> <def>The part of the face of the club
head nearest the shaft.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>9.</sn> <def>In a carding machine, the part of a flat nearest the
cylinder.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Heel chain</b></col> <fld>(Naut.)</fld>, <cd>a chain
passing from the bowsprit cap around the heel of the jib boom.</cd> --
<col><b>Heel plate</b></col>, <cd>the butt plate of a gun.</cd> --
<col><b>Heel of a rafter</b></col>. <fld>(Arch.)</fld> <cd>See
<er>Heel</er>, <pos>n.</pos>, 7.</cd> -- <col><b>Heel ring</b></col>,
<cd>a ring for fastening a scythe blade to the snath.</cd> --
<col><b>Neck and heels</b></col>, <cd>the whole body.</cd>
<mark>(Colloq.)</mark> -- <col><b>To be at the heels of</b></col>,
<cd>to pursue closely; to follow hard; <as>as, hungry want <ex>is
at</ex> my <ex>heels</ex></as>.</cd> <au>Otway.</au> -- <col><b>To be
down at the heel</b></col>, <cd>to be slovenly or in a poor plight.</cd>
-- <col><b>To be out at the heels</b></col>, <cd>to have on stockings
that are worn out; hence, to be shabby, or in a poor plight.</cd>
<au>Shak.</au> -- <col><b>To cool the heels</b></col>. <cd>See under
<er>Cool</er>.</cd> -- <col><b>To go heels over head</b></col>, <cd>to
turn over so as to bring the heels uppermost; hence, to move in a
inconsiderate, or rash, manner.</cd> -- <col><b>To have the heels
of</b></col>, <cd>to outrun.</cd> -- <col><b>To lay by the
heels</b></col>, <cd>to fetter; to shackle; to imprison.</cd>
<au>Shak.</au> <au>Addison.</au> -- <col><b>To show the heels</b></col>,
<cd>to flee; to run from.</cd> -- <col><b>To take to the
heels</b></col>, <cd>to flee; to betake to flight.</cd> -- <col><b>To
throw up another's heels</b></col>, <cd>to trip him.</cd>
<au>Bunyan.</au> -- <col><b>To tread upon one's heels</b></col>, <cd>to
follow closely.</cd> <au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heel</ent><br/
<hw>Heel</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Heeled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Heeling</conjf>.]</vmorph> <sn>1.</sn> <def>To perform by the use
of the heels, as in dancing, running, and the like.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I cannot sing,<br/
Nor <qex>heel</qex> the high lavolt.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To add a heel to; <as>as, to <ex>heel</ex> a
shoe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To arm with a gaff, as a cock for
fighting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Golf)</fld> <def>To hit (the ball) with the heel of
the club.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>5.</sn> <fld>(Football)</fld> <def>To make (a fair catch)
standing with one foot advanced, the heel on the ground and the toe
up.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heelball</ent><br/
<hw>Heel"ball`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A composition of
wax and lampblack, used by shoemakers for polishing, and by antiquaries
in copying inscriptions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heeler</ent><br/
<hw>Heel"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A cock
that strikes well with his heels or spurs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dependent and subservient hanger-on of a political
patron.</def> <mark>[Political Cant, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The army of hungry <qex>heelers</qex> who do their bidding.</q>
<rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heelless</ent><br/
<hw>Heel"less</hw>, <pos>a.</pos> <def>Without a heel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heelpath</ent><br/
<hw>Heel"path`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called with a
play upon the words <ets>tow</ets> and <ets>toe</ets>.]</ety> <def>The
bank of a canal opposite, and corresponding to, that of the towpath;
berm.</def> <mark>[U. S.]</mark></p>

<p><q>The Cowles found convenient spiles sunk in the
<qex>heelpath</qex>.</q> <rj><qau>The Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heelpiece</ent><br/
<hw>Heel"piece`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
piece of armor to protect the heels.</def>
<rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of leather fixed on the heel of a
shoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The end.</def> <ldquo/The <xex>heelpiece</xex> of
his book.<rdquo/ <rj><au>Lloyd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heelpost</ent><br/
<hw>Heel"post`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>The post supporting the outer end of a propeller
shaft.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Carp.)</fld> <def>The post to which a gate or door
is hinged.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Engineering)</fld> <def>The quoin post of a lock
gate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heelspur</ent><br/
<hw>Heel"spur`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A slender bony or cartilaginous process developed from the heel
bone of bats. It helps to support the wing membranes. See
<xex>Illust.</xex> of <er>Cheiropter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heeltap</ent><br/
<hw>Heel"tap`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One of
the segments of leather in the heel of a shoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small portion of liquor left in a glass after
drinking.</def> <ldquo/Bumpers around and no <xex>heeltaps</xex>.<rdquo/
<rj><au>Sheridan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heeltap</ent><br/
<hw>Heel"tap`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Heeltapped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Heeltapping</conjf>.]</vmorph> <def>To add a piece of leather to
the heel of (a shoe, boot, etc.)</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heeltool</ent><br/
<hw>Heel"tool`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tool used by
turners in metal, having a bend forming a heel near the cutting
end.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heemraad</ent><br/
<hw>Heem"raad`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>-raaden</plw> <pr>(#)</pr></plu>. <altsp>[Sometimes, incorrectly,
<asp>Heemraat</asp> or even <asp>Heemrad</asp>.]</altsp> <ety>[D.
<ets>heem</ets> village + <ets>raad</ets> council, councilor.]</ety>
<def>In Holland, and, until the 19th century, also in Cape Colony, a
council to assist a local magistrate in the government of rural
districts; hence, also, a member of such a council.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heep</ent><br/
<hw>Heep</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The hip of the
dog-rose.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heer</ent><br/
<hw>Heer</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[Etymol. uncertain.]</ety>
<def>A yarn measure of six hundred yards or <frac1x24/ of a spindle. See
<er>Spindle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heer</ent><br/
<hw>Heer</hw>, <pos>n.</pos> <ety>[See <er>Hair</er>.]</ety>
<def>Hair.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 682 --></p>

<p><ent>Heft</ent><br/
<hw>Heft</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Haft</er>,
<pos>n.</pos></def> <mark>[Obs.]</mark> <rj><au>Waller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heft</ent><br/
<hw>Heft</hw>, <pos>n.</pos> <ety>[From <er>Heave</er>: cf.
<ets>hefe</ets> weight. Cf. <er>Haft</er>.]</ety> <sn>1.</sn> <def>The
act or effort of heaving; violent strain or exertion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He craks his gorge, his sides,<br/
With violent <qex>hefts</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Weight; ponderousness.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of his age and <qex>heft</qex>.</q> <rj><qau>T.
Hughes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The greater part or bulk of anything; <as>as, the
<ex>heft</ex> of the crop was spoiled</as>.</def> <mark>[Colloq. U.
S.]</mark> <rj><au>J. Pickering.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heft</ent><br/
\'d8<hw>Heft</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>G. pl.</it>
<plw>Hefte</plw> <pr>(#)</pr></plu>. <ety>[G.]</ety> <def>A number of
sheets of paper fastened together, as for a notebook; also, a part of a
serial publication.</def></p>

<p><q>The size of <ldquo/<qex>hefts</qex><rdquo/ will depend on the
material requiring attention, and the annual volume is to cost about 15
marks.</q> <rj><qau>The Nation.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heft</ent><br/
<hw>Heft</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hefted</conjf> (<conjf>Heft</conjf>, <mark>obs</mark>.); <pos>p.
pr. & vb. n.</pos> <conjf>Hefting</conjf>.]</vmorph> <sn>1.</sn> <def>To
heave up; to raise aloft.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Inflamed with wrath, his raging blade he <qex>heft</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To prove or try the weight of by raising.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hefty</ent><br/
<hw>Heft"y</hw>, <pos>a.</pos> <sn>1.</sn> <def>Moderately heavy.</def>
<mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Strong; muscular; -- of people.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Substantial; large; <as>as, a <ex>hefty</ex>
increase in annual profits</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hegari</ent><br/
<hw>hegari</hw> <pos>n.</pos> <def>Sudanese sorghums having white seeds;
one variety is grown in Southwestern U.S.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hegel</ent><br/
<hw>Hegel</hw> <pos>prop. n.</pos> <def><person>Georg Wilhelm Friedrich
Hegel</person>, a German writer (1770-1831).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hegelian</ent><br/
<hw>He*ge"li*an</hw> <pr>(?; 106)</pr>, <pos>prop. a.</pos>
<def>Pertaining to Hegelianism.</def> -- <def2><pos>n.</pos> <def>A
follower of <persfn>Hegel</persfn>.</def></def2></p>

<p><ent>Hegelism</ent><br/
<ent>Hegelianism</ent><br/
<mhw>{ <hw>He*ge"li*an*ism</hw> <pr>(?)</pr>, <hw>He"gel*ism</hw>
<pr>(?)</pr>, }</mhw> <pos>prop. n.</pos> <def>The system of logic and
philosophy set forth by <etsep>Hegel</etsep>, a German writer
(1770-1831).</def></p>

<p><ent>Hegemonical</ent><br/
<ent>Hegemonic</ent><br/
<mhw>{ <hw>Heg`e*mon"ic</hw> <pr>(?)</pr>, <hw>Heg`e*mon"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/. See
<er>Hegemony</er>.]</ety> <def>Leading; controlling; ruling;
predominant.</def> <ldquo/Princelike and <xex>hegemonical</xex>.<rdquo/
<rj><au>Fotherby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hegemony</ent><br/
<hw>He*gem`o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr. <?/
guide, leader, fr. <?/ to go before.]</ety> <def>Leadership;
preponderant influence or authority; -- usually applied to the relation
of a government or state to its neighbors or confederates.</def>
<rj><au>Lieber.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hegge</ent><br/
<hw>Heg"ge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hedge.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hegira</ent><br/
<hw>He*gi"ra</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>hejira</asp>.]</altsp> <ety>[Ar. <ets>hijrah</ets> flight.]</ety>
<def>The flight of Mohammed from Mecca, September 13, <sc>a. d.</sc> 622
(subsequently established as the first year of the Moslem era); hence,
any flight or exodus regarded as like that of Mohammed.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The starting point of the Era was made to begin, not
from the date of the flight, but from the first day of the Arabic year,
which corresponds to July 16, <sc>a. d.</sc> 622.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>he-huckleberry</ent><br/
<hw>he-huckleberry</hw> <pos>n.</pos> <def>A deciduous much-branched
shrub (<spn>Lyonia ligustrina</spn>) with dense downy panicles of small
bell-shaped white flowers.</def><br/
<syn><b>Syn. --</b> maleberry, male berry, privet andromeda, <spn>Lyonia
ligustrina</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heifer</ent><br/
<hw>Heif"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hayfare</ets>, AS. <ets>he<aacute/hfore</ets>,
<ets>he<aacute/fore</ets>; the second part of this word seems akin to
AS. <ets>fearr</ets> bull, ox; akin to OHG. <ets>farro</ets>, G.
<ets>farre</ets>, D. <ets>vaars</ets>, heifer, G. <ets>f<aum/rse</ets>,
and perh. to Gr. <?/, <?/, calf, heifer.]</ety> <fld>(Zool.)</fld>
<def>A young cow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heigh-ho</ent><br/
<hw>Heigh"-ho</hw> <pr>(h<imac/"-h<omac/)</pr>, <pos>interj.</pos>
<def>An exclamation of surprise, joy, dejection, uneasiness, weariness,
etc.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Height</ent><br/
<hw>Height</hw> <pr>(h<imac/t)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>hight</asp>.]</altsp> <ety>[OE. <ets>heighte</ets>,
<ets>heght</ets>, <ets>heighthe</ets>, AS. <ets>he<aacute/h<edh/u</ets>,
<ets>h<emac/h<edh/u</ets> fr. <ets>heah</ets> high; akin to D.
<ets>hoogte</ets>, Sw. <ets>h<oum/jd</ets>, Dan. <ets>h<oum/ide</ets>,
Icel. <ets>h<ae/<edh/</ets>, Goth. <ets>hauhi<thorn/a</ets>. See
<er>High</er>.]</ety> <sn>1.</sn> <def>The condition of being high;
elevated position.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold the <qex>height</qex> of the stars, how high they are!</q>
<rj><qau>Job xxii. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The distance to which anything rises above its foot,
above that on which in stands, above the earth, or above the level of
the sea; altitude; the measure upward from a surface, as the floor or
the ground, of an animal, especially of a man; stature.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Goliath's] <qex>height</qex> was six cubits and a span.</q>
<rj><qau>1 Sam. xvii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Degree of latitude either north or south.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Guinea lieth to the north sea, in the same <qex>height</qex> as
Peru to the south.</q> <rj><qau>Abp. Abbot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is elevated; an eminence; a hill or
mountain; <as>as, Alpine <ex>heights</ex></as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Elevation in excellence of any kind, as in power,
learning, arts; also, an advanced degree of social rank; pre<eum/minence
or distinction in society; prominence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Measure your mind's <qex>height</qex> by the shade it casts.</q>
<rj><qau>R. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All would in his power hold, all make his subjects.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Progress toward eminence; grade; degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Social duties are carried to greater <qex>heights</qex>, and
enforced with stronger motives by the principles of our religion.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Utmost degree in extent; extreme limit of energy or
condition; <as>as, the <ex>height</ex> of a fever, of passion, of
madness, of folly; the <ex>height</ex> of a tempest.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>My grief was at the <qex>height</qex> before thou camest.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>On height</b></col>, <cd>aloud.</cd>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] spake these same words, all <qex>on hight</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Heighten</ent><br/
<hw>Height"en</hw> <pr>(h<imac/t"'n)</pr>, <pos>v. t.</pos>
<altsp>[Written also <asp>highten</asp>.]</altsp> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Heightened</conjf> <pr>(#)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Heightening</conjf>.]</vmorph> <sn>1.</sn> <def>To make
high; to raise higher; to elevate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To carry forward; to advance; to increase; to
augment; to aggravate; to intensify; to render more conspicuous; -- used
of things, good or bad; <as>as, to <ex>heighten</ex> beauty; to
<ex>heighten</ex> a flavor or a tint.</as></def> <ldquo/To
<xex>heighten</xex> our confusion.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An aspect of mystery which was easily <qex>heightened</qex> to the
miraculous.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heightener</ent><br/
<hw>Height"en*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>hightener</ets>.]</ety> <def>One who, or that which,
heightens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heights</ent><br/
<hw>heights</hw> <pos>n.</pos> <def>a high place; the high part of a
district; <as>as, he doesn't like <ex>heights</ex></as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Heimdal</ent><br/
<hw>Heimdal</hw> <pos>n.</pos> <def>god of dawn and light; guardian of
Asgard.</def><br/
<syn><b>Syn. --</b> Heimdall, Heimdallr.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heimdall</ent><br/
<hw>Heimdall</hw> <pos>n.</pos> <def>Same as <er>Heimdal</er>.</def><br/
<syn><b>Syn. --</b> Heimdal, Heimdallr.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heimdallr</ent><br/
<hw>Heimdallr</hw> <pos>n.</pos> <def>Same as
<er>Heimdal</er>.</def><br/
<syn><b>Syn. --</b> Heimdall, Heimdal.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>heinie</ent><br/
<hw>hei"nie</hw> <pr>(h<imac/"n<emac/)</pr>, <pos>n.</pos> <def>The
buttocks; -- a word used with children.</def> <mark>[slang]</mark><br/
<syn><b>Syn. --</b> ass, butt, buttocks, rear end, derriere, rump,
behind.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Heinous</ent><br/
<hw>Hei"nous</hw> <pr>(h<amac/"n<ucr/s)</pr>, <pos>a.</pos> <ety>[OF.
<ets>ha<ium/nos</ets> hateful, F. <ets>haineux</ets>, fr. OF.
<ets>ha<ium/ne</ets> hate, F. <ets>haine</ets>, fr. <ets>ha<ium/r</ets>
to hate; of German origin. See <er>Hate</er>.]</ety> <def>Hateful;
hatefully bad; flagrant; odious; atrocious; giving great offense; --
applied to deeds or to character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It were most <qex>heinous</qex> and accursed sacrilege.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>heinous</qex> had the fact been, how deserving<br/
Contempt!</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Monstrous; flagrant; flagitious;
atrocious.</syn></p>

<p>-- <wordforms><wf>Hei"nous*ly</wf>, <pos>adv.</pos> --
<wf>Hei"nous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>heinousness</ent><br/
<hw>heinousness</hw> <pos>n.</pos> <def>the quality of being shockingly
cruel and inhumane.</def><br/
<syn><b>Syn. --</b> atrocity, atrociousness, barbarity,
barbarousness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heir</ent><br/
<hw>Heir</hw> <pr>(<acir/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>heir</ets>, <ets>eir</ets>, <ets>hair</ets>, OF. <ets>heir</ets>,
<ets>eir</ets>, F. <ets>hoir</ets>, L. <ets>heres</ets>; of uncertain
origin. Cf. <er>Hereditary</er>, <er>Heritage</er>.]</ety> <sn>1.</sn>
<def>One who inherits, or is entitled to succeed to the possession of,
any property after the death of its owner; one on whom the law bestows
the title or property of another at the death of the latter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am my father's <qex>heir</qex> and only son.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who receives any endowment from an ancestor or
relation; <as>as, the <ex>heir</ex> of one's reputation or
virtues</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And I his <qex>heir</qex> in misery alone.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heir apparent</b></col>. <fld>(Law.)</fld> <cd>See under
<er>Apparent</er>.</cd> -- <col><b>Heir at law</b></col>, <cd>one who,
after his ancector's death, has a right to inherit all his intestate
estate.</cd> <au>Wharton (Law Dict.).</au> -- <col><b>Heir
presumptive</b></col>, <cd>one who, if the ancestor should die
immediately, would be his heir, but whose right to the inheritance may
be defeated by the birth of a nearer relative, or by some other
contingency.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heir</ent><br/
<hw>Heir</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To inherit; to succeed
to.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One only daughter <qex>heired</qex> the royal state.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heirdom</ent><br/
<hw>Heir"dom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of an heir;
succession by inheritance.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heiress</ent><br/
<hw>Heir"ess</hw>, <pos>n.</pos> <def>A female heir.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heirless</ent><br/
<hw>Heir"less</hw> <pos>a.</pos> <def>Destitute of an heir.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heirloom</ent><br/
<hw>Heir"loom`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Heir</ets> +
<ets>loom</ets>, in its earlier sense of <it>implement</it>,
<it>tool.</it> See <er>Loom</er> the frame.]</ety> <def>Any furniture,
movable, or personal chattel, which by law or special custom descends to
the heir along with the inheritance; any piece of personal property that
has been in a family for several generations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Woe to him whose daring hand profanes<br/
The honored <qex>heirlooms</qex> of his ancestors.</q>
<rj><qau>Moir.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heirship</ent><br/
<hw>Heir"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state,
character, or privileges of an heir; right of inheriting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heirship movables</b></col>, <cd>certain kinds of
movables which the heir is entitled to take, besides the heritable
estate.</cd> <mark>[Scot.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hejira</ent><br/
<hw>He*ji"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hegira</er>.</def></p>

<p><ent>Hektometer</ent><br/
<ent>Hektoliter</ent><br/
<ent>Hektogram</ent><br/
<ent>Hektare</ent><br/
<mhw><hw>Hek"tare`</hw>, <hw>Hek"to*gram</hw>, <hw>Hek"to*li`ter</hw>,
<and/ <hw>Hek"to*me`ter</hw></mhw>, <pos>n.</pos> <def>Same as
<er>Hectare</er>, <er>Hectogram</er>, <er>Hectoliter</er>, and
<er>Hectometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hektograph</ent><br/
<hw>Hek"to*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hectograph</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helamys</ent><br/
\'d8<hw>Hel*a*mys</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ fawn + <?/ mouse.]</ety> <fld>(Zool.)</fld> <def>See <cref>Jumping
hare</cref>, under <er>Hare</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helcoplasty</ent><br/
<hw>Hel"co*plas`ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
wound + <ets>-plasty</ets>.]</ety> <fld>(Med.)</fld> <def>The act or
process of repairing lesions made by ulcers, especially by a plastic
operation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Held</ent><br/
<hw>Held</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Hold</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hele</ent><br/
<hw>Hele</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Heal</er>,
<pos>n.</pos>]</ety> <def>Health; welfare.</def> <mark>[Obs.]</mark>
<ldquo/In joy and perfyt <xex>hele</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hele</ent><br/
<hw>Hele</hw>, <pos>v. t.</pos> <ety>[AS. <ets>helan</ets>, akin to D.
<ets>helen</ets>, OHG. <ets>helan</ets>, G. <ets>hehlen</ets>, L.
<ets>celare</ets>. <root/17. See <er>Hell</er>, and cf.
<er>Conceal</er>.]</ety> <def>To hide; to cover; to roof.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Hide and <qex>hele</qex> things.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helena</ent><br/
<hw>Hel"e*na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. Sp.
<ets>helena</ets>.]</ety> <def>See <cref>St. Elmo's fire</cref>, under
<er>Saint</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helenin</ent><br/
<hw>Hel"e*nin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
neutral organic substance found in the root of the elecampane
(<spn>Inula helenium</spn>), and extracted as a white crystalline or
oily material, with a slightly bitter taste.</def> <-- used to induce
interferon production -- contains RNA --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heleodytes</ent><br/
<hw>Heleodytes</hw> <pos>prop. n.</pos> <def>A genus comprising the
cactus wrens; one of several alternative classifications.</def><br/
<syn><b>Syn. --</b> Campylorhynchus, genus <gen>Campylorhynchus</gen>,
genus <gen>Heleodytes</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heliac</ent><br/
<hw>He"li*ac</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Heliacal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliacal</ent><br/
<hw>He*li"a*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ belonging
to the sun, fr. <?/ the sun: cf. F. <ets>h<eacute/liaque</ets>.]</ety>
<fld>(Astron.)</fld> <def>Emerging from the light of the sun, or passing
into it; rising or setting at the same, or nearly the same, time as the
sun.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>heliacal</xex> rising of a star is when, after
being in conjunction with the sun, and invisible, it emerges from the
light so as to be visible in the morning before sunrising. On the
contrary, the <xex>heliacal</xex> setting of a star is when the sun
approaches conjunction so near as to render the star
invisible.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliacally</ent><br/
<hw>He*li"a*cal*ly</hw>, <pos>adv.</pos> <def>In a heliacal
manner.</def> <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helianthin</ent><br/
<hw>He`li*an"thin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr. L.
<ets>helianthes</ets>, or NL. <ets>helianthus</ets>, sunflower, in
allusion to its color.]</ety> <fld>(Chem.)</fld> <def>An artificial,
orange dyestuff, analogous to tropaolin, and like it used as an
indicator in alkalimetry; -- called also <altname>methyl
orange</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helianthoid</ent><br/
<hw>He`li*an"thoid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Helianthoidea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helianthoidea</ent><br/
\'d8<hw>He`li*an"thoi"de*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. L. <ets>helianthes</ets> sunflower +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>An order of Anthozoa;
the Actinaria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>helianthus</ent><br/
<hw>helianthus</hw> <pos>n.</pos> <def>any plant of the genus
<gen>Helianthus</gen> having large flower heads with dark disk florets
and showy yellow rays.</def><br/
<syn><b>Syn. --</b> sunflower.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Helical</ent><br/
<hw>Hel"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Helix</er>.]</ety> <def>Of or pertaining to, or in the form of, a
helix; spiral; <as>as, a <ex>helical</ex> staircase; a <ex>helical</ex>
spring.</as></def> -- <wordforms><wf>Hel"i*cal*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helichrysum</ent><br/
\'d8<hw>Hel`i*chry"sum</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[L., the
marigold, fr. Gr. <?/ a kind of plant.]</ety> <fld>(Bot.)</fld> <def>A
genus of composite plants, with shining, commonly white or yellow, or
sometimes reddish, radiated involucres, which are often called
<ldquo/everlasting flowers.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliciform</ent><br/
<hw>He*lic"i*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Helix</ets> + <ets>-form</ets>.]</ety> <def>Having the form
of a helix; spiral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicin</ent><br/
<hw>Hel"i*cin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
glucoside obtained as a white crystalline substance by partial oxidation
of salicin, from a willow (<spn>Salix Helix</spn> of
Linnaeus.)</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicine</ent><br/
<hw>Hel"i*cine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Curled; spiral; helicoid; -- applied esp. to certain arteries of
the penis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicograph</ent><br/
<hw>Hel"i*co*graph`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helix</ets> + <ets>-graph</ets>.]</ety> <def>An instrument
for drawing spiral lines on a plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicoid</ent><br/
<hw>Hel"i*coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/; <?/, <?/,
spiral + <?/ shape: cf. F. <ets>h<eacute/lico<ium/de</ets>. See
<er>Helix</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Spiral; curved, like the spire of a univalve
shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Shaped like a snail shell;
pertaining to the <fam>Helicidae</fam>, or Snail family.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Helicoid parabola</b></col> <fld>(Math.)</fld>, <cd>the
parabolic spiral.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicoid</ent><br/
<hw>Hel"i*coid</hw>, <pos>n.</pos> <fld>(Geom.)</fld> <def>A warped
surface which may be generated by a straight line moving in such a
manner that every point of the line shall have a uniform motion in the
direction of another fixed straight line, and at the same time a uniform
angular motion about it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicoidal</ent><br/
<hw>Hel`i*coid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Helicoid</er>.</def> -- <wordforms><wf>Hel`i*coid"al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicon</ent><br/
<hw>Hel"i*con</hw> <pr>(h<ecr/l"<icr/*k<ocr/n)</pr>, <pos>prop. n.</pos>
<ety>[L., fr. Gr. <grk>"Elikw`n</grk>.]</ety> <def>A mountain in
B<oe/otia, in <country>Greece</country>, supposed by the Greeks to be
the residence of <persfn>Apollo</persfn> and the Muses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From <qex>Helicon's</qex> harmonious springs<br/
A thousand rills their mazy progress take.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliconia</ent><br/
\'d8<hw>Hel`i*co"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Helicon</er>.]</ety> <fld>(Zool.)</fld> <def>One of numerous species
of <gen>Heliconius</gen>, a genus of tropical American butterflies. The
wings are usually black, marked with green, crimson, and
white.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliconian</ent><br/
<hw>Hel`i*co"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Heliconius</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to
Helicon.</def> <ldquo/<xex>Heliconian</xex> honey.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Like or pertaining to the
butterflies of the genus <gen>Heliconius</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helicopter</ent><br/
<hw>Hel"i*cop`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>"e`lix</grk>, <grk>"e`likos</grk>, a spiral + <grk>ptero`n</grk> a
wing.]</ety> <def>a heavier-than-air aircraft whose lift is provided by
the aerodynamic forces on rotating blades rather than on fixed wings.
Contrasted with <contr>fixed-wing aircraft</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Helicopter</ent><br/
<hw>Hel"i*cop`ter</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>to travel in
a helicopter.</def><br/
[<source>PJC</source>]</p>

<p><ent>Helicopter</ent><br/
<hw>Hel"i*cop`ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>to transport
in a helicopter.</def><br/
[<source>PJC</source>]</p>

<p><ent>Helicotrema</ent><br/
\'d8<hw>Hel`i*co"tre"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"e`lix</grk>, <grk>"e`likos</grk>, a helix + <?/ a hole.]</ety>
<fld>(Anat.)</fld> <def>The opening by which the two scalae communicate
at the top of the cochlea of the ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helio-</ent><br/
<hw>He"li*o-</hw> <pr>(h<emac/"l<icr/*<osl/-)</pr>. <def>A combining
form from Gr. <grk>"h`lios</grk> <sig>the sun</sig>.</def></p>

<p><ent>Heliocentrical</ent><br/
<ent>Heliocentric</ent><br/
<mhw>{ <hw>He`li*o*cen"tric</hw>
<pr>(h<emac/`l<icr/*<osl/*s<ecr/n"tr<icr/k)</pr>,
<hw>He`li*o*cen"tric"al</hw>
<pr>(h<emac/`l<icr/*<osl/*s<ecr/n"tr<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[<ets>Helio-</ets> + <ets>centric</ets>,
<ets>centrical</ets>: cf. F. <ets>h<eacute/liocentrique</ets>.]</ety>
<fld>(Astron.)</fld> <def>pertaining to the sun's center, or appearing
to be seen from it; having, or relating to, the sun as a center; --
opposed to <contr>geocentrical</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heliocentric parallax</b></col>. <cd>See under
<er>Parallax</er>.</cd> -- <mcol><col><b>Heliocentric place</b></col>,
<col><b>latitude</b></col>, <col><b>longitude</b></col></mcol>, <cd>etc.
(of a heavenly body), the direction, latitude, longitude, etc., of the
body as viewed from the sun.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliochrome</ent><br/
<hw>He"li*o*chrome</hw> <pr>(h<emac/"l<icr/*<osl/*kr<omac/m)</pr>,
<pos>n.</pos> <ety>[<ets>Helio-</ets> + Gr. <grk>chrw^ma</grk>
color.]</ety> <def>A photograph in colors.</def><-- now, just color
photograph --> <rj><au>R. Hunt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliochromic</ent><br/
<hw>He`li*o*chro"mic</hw> <pr>(h<emac/`l<icr/*<osl/*kr<omac/"m<icr/k
<it>or</it> h<emac/`l<icr/*<osl/*kr<ocr/m"<icr/k)</pr>, <pos>a.</pos>
<def>Pertaining to, or produced by, heliochromy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliochromy</ent><br/
<hw>He"li*o*chro`my</hw> <pr>(h<emac/"l<icr/*<osl/*kr<omac/`m<ycr/
<it>or</it> h<emac/`l<icr/*<ocr/k"r<osl/`m<ycr/)</pr>, <pos>n.</pos>
<def>The art of producing photographs in color.</def><-- color
photography? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliogram</ent><br/
<hw>He"li*o*gram</hw> <pr>(h<emac/"l<icr/*<osl/*gr<adot/m)</pr>,
<pos>n.</pos> <ety>[<ets>Helio-</ets> + <ets>-gram</ets>.]</ety> <def>A
message transmitted by a heliograph.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heliograph</ent><br/
<hw>He"li*o*graph</hw> <pr>(h<emac/"l<icr/*<osl/*gr<adot/f)</pr>,
<pos>n.</pos> <ety>[<ets>Helio-</ets> + <ets>-graph</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A picture taken by heliography; a
photograph.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instrument for taking photographs of the
sun.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An apparatus for telegraphing by means of the sun's
rays. See <er>Heliotrope</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliograph</ent><br/
<hw>He"li*o*graph</hw> <pr>(h<emac/"l<icr/*<osl/*gr<adot/f)</pr>,
<pos>v. t.</pos> <sn>1.</sn> <def>To telegraph, or signal, with a
heliograph.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To photograph by sunlight.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heliographic</ent><br/
<hw>He`li*o*graph"ic</hw>
<pr>(h<emac/`l<icr/*<osl/*gr<acr/f"<icr/k)</pr>, <pos>a.</pos>
<fld>(Astron.)</fld> <sn>1.</sn> <def>Of or pertaining to a description
of the sun.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ <xex>Heliographic</xex> longitudes and latitudes of
spots on the sun's surface are analogous to geographic longitudes and
latitudes of places on the earth.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to heliography or a heliograph;
made by heliography.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heliographic chart</b></col>. <cd>See under
<er>Chart</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliography</ent><br/
<hw>He`li*og"ra*phy</hw>, <pos>n.</pos> <sn>1.</sn>
<ety>[<ets>Helio-</ets> + <ets>-graphy</ets>.]</ety> <def>The
description of the sun.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>The system, art, or practice of telegraphing, or
signaling, with the heliograph.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>An early photographic process invented by
Nic<eacute/phore Niepce, and still used in photo-engraving. It consists
essentially in exposing under a design or in a camera a polished metal
plate coated with a preparation of asphalt, and subsequently treating
the plate with a suitable solvent. The light renders insoluble those
parts of the film which is strikes, and so a permanent image is formed,
which can be etched upon the plate by the use of acid.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>Photography.</def> <mark>[Archaic.]</mark>
<rj><au>R. Hunt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliogravure</ent><br/
<hw>He`li*o*grav"ure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<eacute/liogravure</ets>.]</ety> <sn>1.</sn> <def>The process of
photographic engraving.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plate or picture made by the process of
heliogravure.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heliolater</ent><br/
<hw>He`li*ol"a*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + Gr. <?/ servant, worshiper.]</ety> <def>A
worshiper of the sun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliolatry</ent><br/
<hw>He`li*ol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + Gr. <?/ service, worship.]</ety> <def>Sun
worship. See <er>Sabianism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliolite</ent><br/
<hw>He"li*o*lite</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + <ets>-lite</ets>.]</ety> <fld>(Paleon.)</fld>
<def>A fossil coral of the genus <gen>Heliolites</gen>, having
twelve-rayed cells. It is found in the Silurian rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliometer</ent><br/
<hw>He`li*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + <ets>-meter</ets>: cf. F.
<ets>h<eacute/liom<egrave/tre</ets>.]</ety> <fld>(Astron.)</fld> <def>An
instrument devised originally for measuring the diameter of the sun; now
employed for delicate measurements of the distance and relative
direction of two stars too far apart to be easily measured in the field
of view of an ordinary telescope.</def></p>

<p><ent>Heliometrical</ent><br/
<ent>Heliometric</ent><br/
<mhw>{ <hw>He`li*o*met"ric</hw> <pr>(?)</pr>,
<hw>He`li*o*met"ric*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of
or pertaining to the heliometer, or to heliometry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliometry</ent><br/
<hw>He`li*om"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The apart or
practice of measuring the diameters of heavenly bodies, their relative
distances, etc. See <er>Heliometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliopora</ent><br/
\'d8<hw>He`li*op"o*ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ the sun + <?/ a passage, pore.]</ety> <fld>(Zool.)</fld> <def>An
East Indian stony coral now known to belong to the Alcyonaria; -- called
also <altname>blue coral</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helioscope</ent><br/
<hw>He"li*o*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + <ets>-scope</ets>: cf. F.
<ets>h<eacute/lioscope</ets>.]</ety> <fld>(Astron.)</fld> <def>A
telescope or instrument for viewing the sun without injury to the eyes,
as through colored glasses, or with mirrors which reflect but a small
portion of light.</def> -- <wordforms><wf>He`li*o*scop`ic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliostat</ent><br/
<hw>He"li*o*stat</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + Gr. <?/ placed, standing, fr. <?/ to place,
stand: cf. F. <ets>h<eacute/liostate</ets>.]</ety> <def>An instrument
consisting of a mirror moved by clockwork, by which a sunbeam is made
apparently stationary, by being steadily directed to one spot during the
whole of its diurnal period; also, a geodetic heliotrope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotrope</ent><br/
<hw>He"li*o*trope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<eacute/liotrope</ets>, L. <ets>heliotropium</ets>, Gr. <?/; <?/
the sun + <?/ to turn, <?/ turn. See <er>Heliacal</er>,
<er>Trope</er>.]</ety> <sn>1.</sn> <fld>(Anc. Astron.)</fld> <def>An
instrument or machine for showing when the sun arrived at the tropics
and equinoctial line.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Heliotropium</gen>; -- called also <altname>turnsole</altname> and
<altname>girasole</altname>. <spn>Heliotropium Peruvianum</spn> is the
commonly cultivated species with fragrant flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geodesy & Signal Service)</fld> <def>An instrument
for making signals to an observer at a distance, by means of the sun's
rays thrown from a mirror.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Min.)</fld> <def>See <er>Bloodstone</er>
<sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heliotrope purple</b></col>, <cd>a grayish purple
color.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotroper</ent><br/
<hw>He"li*o*tro`per</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The person at
a geodetic station who has charge of the heliotrope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotropic</ent><br/
<hw>He`li*o*trop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Manifesting heliotropism; turning toward the sun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotropism</ent><br/
<hw>He`li*ot"ro*pism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + Gr. <?/ to turn.]</ety> <fld>(Bot.)</fld>
<def>The phenomenon of turning toward the light, seen in many leaves and
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotype</ent><br/
<hw>He"li*o*type</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Helio-</ets> + <ets>-type</ets>.]</ety> <def>A picture
obtained by the process of heliotypy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotypic</ent><br/
<hw>He`li*o*typ"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to, or
obtained by, heliotypy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliotypy</ent><br/
<hw>He"li*o*ty`py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A method of
transferring pictures from photographic negatives to hardened gelatin
plates from which impressions are produced on paper as by
lithography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heliozoa</ent><br/
\'d8<hw>He`li*o*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ the sun + <grk>zw^,on</grk> an animal.]</ety> <fld>(Zool.)</fld>
<def>An order of fresh-water rhizopods having a more or less globular
form, with slender radiating pseudopodia; the sun animalcule.</def></p>

<p><ent>heliport</ent><br/
<hw>heliport</hw> <pos>n.</pos> <def>an airport for
helicopters.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Helipterum</ent><br/
<hw>Helipterum</hw> <pos>n.</pos> <def>genus of South African and
Australian herbs or shrubs grown as everlastings; the various
<gen>Helipterum</gen> species are currently in process of being assigned
to other genera, especially <gen>Pteropogon</gen> and
<gen>Hyalosperma</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Helipterum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Helispherical</ent><br/
<ent>Helispheric</ent><br/
<mhw><hw>Hel`i*spher"ic</hw> <pr>(?)</pr>, <hw>Hel`i*spher"ic*al</hw>
<pr>(<?/)</pr></mhw>, <pos>a.</pos> <ety>[<ets>Helix</ets> +
<ets>spheric</ets>, <ets>spherical</ets>.]</ety> <def>Spiral.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Helispherical line</b></col> <fld>(Math.)</fld>. <cd>the
rhomb line in navigation.</cd> <mark>[R.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helium</ent><br/
<hw>He"li*um</hw> <pr>(h<emac/"l<icr/*<ucr/m)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>"h`lios</grk> the sun.]</ety> <fld>(Chem.)</fld>
<def>An inert, monoatomic, gaseous element occurring in the atmosphere
of the sun and stars, and in small quantities in the earth's atmosphere,
in several minerals and in certain mineral waters. It is obtained from
natural gas in industrial quantities. Symbol, <it>He</it>; atomic number
2; at. wt., 4.0026 (C=12.011). Helium was first detected
spectroscopically in the sun by <person>Lockyer</person> in 1868; it was
first prepared by <person>Ramsay</person> in 1895. Helium has a density
of 1.98 compared with hydrogen, and is more difficult to liquefy than
the latter. Chemically, it is an inert <isa>noble gas</isa>, belonging
to the argon group, and cannot be made to form compounds. The helium
nucleus is the charged particle which constitutes alpha rays, and helium
is therefore formed as a decomposition product of certain radioactive
substances such as radium. The normal helium nucleus has two protons and
two neutrons, but an isotope with only one neutron is also observed in
atmospheric helium at an abundance of 0.013 %. Liquid helium has a
boiling point of -268.9<deg/ C at atmospheric pressure, and is used for
maintaining very low temperatures, both in laboratory experimentation
and in commercial applications to maintain superconductivity in
low-temperature superconducting devices. Gaseous helium at normal
temperatures is used for buoyancy in blimps, dirigibles, and
high-altitude balloons, and also for amusement in party
balloons.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><-- p. 683 --></p>

<p><ent>Helix</ent><br/
<hw>He"lix</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Helices</plw> <pr>(#)</pr>, E. <plw>Helixes</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>helix</ets>, Gr. <?/, <?/, fr. <?/ to
turn round; cf. L. <ets>volvere</ets>, and E. <ets>volute</ets>,
<ets>voluble</ets>.]</ety> <sn>1.</sn> <fld>(Geom.)</fld> <def>A
nonplane curve whose tangents are all equally inclined to a given plane.
The common helix is the curve formed by the thread of the ordinary
screw. It is distinguished from the <xex>spiral</xex>, all the
convolutions of which are in the plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>A caulicule or little volute
under the abacus of the Corinthian capital.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>The incurved margin or rim of the
external ear. See <xex>Illust.</xex> of <er>Ear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A genus of land snails, including
a large number of species.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The genus originally included nearly all shells, but is
now greatly restricted. See <er>Snail</er>,
<er>Pulmonifera</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hell</ent><br/
<hw>Hell</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>hell</ets>;
akin to D. <ets>hel</ets>, OHG. <ets>hella</ets>, G.
<ets>h<oum/lle</ets>, Icel. <ets>hal</ets>, Sw. <ets>helfvete</ets>,
Dan. <ets>helvede</ets>, Goth. <ets>halja</ets>, and to AS.
<ets>helan</ets> to conceal. <?/<?/<?/. Cf. <er>Hele</er>, <pos>v.
t.</pos>, <er>Conceal</er>, <er>Cell</er>, <er>Helmet</er>,
<er>Hole</er>, <er>Occult</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The place of the dead, or of souls after death; the
grave; -- called in Hebrew <xex>sheol</xex>, and by the Greeks
<xex>hades</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He descended into <qex>hell</qex>.</q> <rj><qau>Book of Common
Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou wilt not leave my soul in <qex>hell</qex>.</q> <rj><qau>Ps.
xvi. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place or state of punishment for the wicked
after death; the abode of evil spirits. Hence, any mental torment;
anguish.</def> <ldquo/Within him <xex>hell</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a knell<br/
That summons thee to heaven or to <qex>hell</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place where outcast persons or things are
gathered</def>; as: <sd>(a)</sd> <def>A dungeon or prison; also, in
certain running games, a place to which those who are caught are carried
for detention.</def> <sd>(b)</sd> <def>A gambling house.</def> <ldquo/A
convenient little gambling <xex>hell</xex> for those who had grown
reckless.<rdquo/ <au>W. Black.</au> <sd>(c)</sd> <def>A place into which
a tailor throws his shreds, or a printer his broken type.</def>
<au>Hudibras.</au><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Gates of hell</b></col>. <fld>(Script.)</fld> <cd>See
<er>Gate</er>, <pos>n.</pos>, 4.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hell</ent><br/
<hw>Hell</hw>, <pos>v. t.</pos> <def>To overwhelm.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellanodic</ent><br/
<hw>Hel`la*nod"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/,
<?/, a Greek + <?/ right, judgment.]</ety> <fld>(Gr. Antiq.)</fld>
<def>A judge or umpire in games or combats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellbender</ent><br/
<hw>Hell"bend`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A large North American aquatic salamander (<spn>Protonopsis
horrida</spn> or <spn>Menopoma Alleghaniensis</spn>). It is very
voracious and very tenacious of life. Also called
<altname>alligator</altname>, and <altname>water
dog</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hell-bent</ent><br/
<hw>hell-bent</hw> <pos>adj.</pos> <def>recklessly determined; <as>as,
<ex>hell-bent</ex> on winning</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hellborn</ent><br/
<hw>Hell"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Born in or of
hell.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellbred</ent><br/
<hw>Hell"bred`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Produced in
hell.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellbrewed</ent><br/
<hw>Hell"brewed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Prepared in
hell.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellbroth</ent><br/
<hw>Hell"broth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A composition for
infernal purposes; a magical preparation.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hell-cat </ent><br/
<hw>Hell"-cat `</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A witch; a
hag.</def> <rj><au>Middleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hell-diver</ent><br/
<hw>Hell"-div`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The dabchick.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helldoomed</ent><br/
<hw>Hell"doomed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Doomed to
hell.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellebore</ent><br/
<hw>Hel"le*bore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>helleborus</ets>, <ets>elleborus</ets>, Gr. <?/, <?/; cf. F.
<ets>hell<eacute/bore</ets>, <ets>ell<eacute/bore</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>A genus of perennial herbs
(<gen>Helleborus</gen>) of the Crowfoot family, mostly having powerfully
cathartic and even poisonous qualities. <spn>Helleborus niger</spn> is
the European black hellebore, or Christmas rose, blossoming in winter or
earliest spring. <spn>Helleborus officinalis</spn> was the officinal
hellebore of the ancients.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Any plant of several species of
the poisonous liliaceous genus <gen>Veratrum</gen>, especially
<spn>Veratrum album</spn> and <spn>Veratrum viride</spn>, both called
<altname>white hellebore</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helleborein</ent><br/
<hw>Hel`le*bo"re*in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A poisonous glucoside accompanying helleborin in several species of
hellebore, and extracted as a white crystalline substance with a
bittersweet taste. It has a strong action on the heart, resembling
digitalin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helleborin</ent><br/
<hw>Hel*leb"o*rin</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A poisonous glucoside found in several species
of hellebore, and extracted as a white crystalline substance with a
sharp tingling taste. It possesses the essential virtues of the plant;
-- called also <altname>elleborin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helleborism</ent><br/
<hw>Hel"le*bo*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The practice or
theory of using hellebore as a medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellene</ent><br/
<hw>Hel"lene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/.]</ety>
<def>A native of either ancient or modern Greece; a Greek.</def>
<rj><au>Brewer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenian</ent><br/
<hw>Hel*le"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to the Hellenes, or Greeks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenic</ent><br/
<hw>Hel*len"ic</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[Gr. <?/, <?/,
fr. <?/ the Greeks.]</ety> <def>Of or pertaining to the Hellenes, or
inhabitants of Greece; Greek; Grecian.</def> <ldquo/The
<xex>Hellenic</xex> forces.<rdquo/ <rj><au>Jowett (Thucyd.
).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenic</ent><br/
<hw>Hel*len"ic</hw>, <pos>n.</pos> <def>The dialect, formed with slight
variations from the Attic, which prevailed among Greek writers after the
time of Alexander.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenism</ent><br/
<hw>Hel"len*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf. F.
<ets>Hell<eacute/nisme</ets>.]</ety> <sn>1.</sn> <def>A phrase or form
of speech in accordance with genius and construction or idioms of the
Greek language; a Grecism.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The type of character of the ancient Greeks, who
aimed at culture, grace, and amenity, as the chief elements in human
well-being and perfection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenist</ent><br/
<hw>Hel"len*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf. F.
<ets>Hell<eacute/niste</ets>.]</ety> <sn>1.</sn> <def>One who affiliates
with Greeks, or imitates Greek manners; esp., a person of Jewish
extraction who used the Greek language as his mother tongue, as did the
Jews of Asia Minor, Greece, Syria, and Egypt; distinguished from the
Hebraists, or native Jews (<au>Acts vi. 1</au>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One skilled in the Greek language and literature;
<as>as, the critical <ex>Hellenist</ex></as>.</def></p>

<p><ent>Hellenistical</ent><br/
<ent>Hellenistic</ent><br/
<mhw>{ <hw>Hel`le*nis"tic</hw> <pr>(?)</pr>, <hw>Hel`le*nis"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>Hell<eacute/nistique</ets>.]</ety> <def>Pertaining to the
Hellenists.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hellenistic language</b></col>, <col><b>Hellenistic
dialect</b></col>, <it>or</it> <col><b>Hellenistic
idiom</b></col></mcol>, <cd>the Greek spoken or used by the Jews who
lived in countries where the Greek language prevailed; the Jewish-Greek
dialect or idiom of the Septuagint.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenistically</ent><br/
<hw>Hel`le*nis"tic*al*ly</hw>, <pos>adv.</pos> <def>According to the
Hellenistic manner or dialect.</def> <rj><au>J. Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenize</ent><br/
<hw>Hel"len*ize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Gr.
<?/.]</ety> <def>To use the Greek language; to play the Greek; to
Grecize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenize</ent><br/
<hw>Hel"len*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Gr.
<?/.]</ety> <def>To give a Greek form or character to; to Grecize;
<as>as, to <ex>Hellenize</ex> a word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellenotype</ent><br/
<hw>Hel*len"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ivorytype</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellespont</ent><br/
<hw>Hel"les*pont</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Hellespontus</ets>, Gr. <?/; <?/ the mythological Helle, daughter
of Athamas + <?/ sea.]</ety> <def>A narrow strait between Europe and
Asia, now called the <altname>Daradanelles</altname>. It connects the
Aegean Sea and the sea of Marmora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellespontine</ent><br/
<hw>Hel`les*pon"tine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the Hellespont.</def> <rj><au>Mitford.</au></rj></p>

<p><ent>Hellgramite</ent><br/
<ent>Hellgamite</ent><br/
<mhw>{ <hw>Hell"ga*mite</hw> <pr>(?)</pr>, <hw>Hell"gra*mite</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>The aquatic
larva of a large American winged insect (<spn>Corydalus cornutus</spn>),
much used a fish bait by anglers; the dobson. It belongs to the
Neuroptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellhag</ent><br/
<hw>Hell"hag`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hag of or fit for
hell.</def> <rj><au>Bp. Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hell-haunted</ent><br/
<hw>Hell"-haunt`ed</hw> <pr>(<?/)</pr>, <pos>a.</pos> <def>Haunted by
devils; hellish.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellhound</ent><br/
<hw>Hell"hound`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hellehund</ets>.]</ety> <def>A dog of hell; an agent of
hell.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>hellhound</qex>, that doth hunt us all to death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellier</ent><br/
<hw>Hel"li*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Hele</er>,
<pos>v. t.</pos>]</ety> <def>One who heles or covers; hence, a tiler,
slater, or thatcher.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>heler</asp>.]</altsp> <rj><au>Usher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellish</ent><br/
<hw>Hell"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
hell; like hell; infernal; malignant; wicked; detestable;
diabolical.</def> <ldquo/<xex>Hellish</xex> hate.<rdquo/
<au>Milton.</au> -- <wordforms><wf>Hell"ish*ly</wf>, <pos>adv.</pos> --
<wf>Hell"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hellkite</ent><br/
<hw>Hell"kite`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kite of infernal
breed.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hello</ent><br/
<hw>Hel*lo"</hw> <pr>(?)</pr>, <pos>interj. & n.</pos> <def>An
exclamation used as a greeting, to call attention, as an exclamation of
surprise, or to encourage one. This variant of <er>Halloo</er> and
<er>Holloo</er> has become the dominant form. In the United States, it
is the most common greeting used in answering a telephone.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hellward</ent><br/
<hw>Hell"ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Toward hell.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helly</ent><br/
<hw>Hell"y</hw>, <pos>a.</pos> <ety>[AS. <ets>hell<imac/c</ets>.]</ety>
<def>Hellish.</def> <rj><au>Anderson (1573).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helm</ent><br/
<hw>Helm</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Haulm</er>,
straw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helm</ent><br/
<hw>Helm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>helme</ets>,
AS. <ets>helma</ets> rudder; akin to D. & G. <ets>helm</ets>, Icel.
<ets>hj<amac/lm</ets>, and perh. to E. <ets>helve</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Naut.)</fld> <def>The apparatus by which a ship is
steered, comprising rudder, tiller, wheel, etc.; -- commonly used of the
tiller or wheel alone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place or office of direction or
administration.</def> <ldquo/The <xex>helm</xex> of the
Commonwealth.<rdquo/ <rj><au>Melmoth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One at the place of direction or control; a
steersman; hence, a guide; a director.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>helms</qex> o' the State, who care for you like
fathers.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[Cf. <er>Helve</er>.]</ety> <def>A helve.</def>
<mark>[Obs. or Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Helm amidships</b></col>, <cd>when the tiller, rudder,
and keel are in the same plane.</cd> -- <col><b>Helm aport</b></col>,
<cd>when the tiller is borne over to the port side of the ship.</cd> --
<col><b>Helm astarboard</b></col>, <cd>when the tiller is borne to the
starboard side.</cd> -- <mcol><col><b>Helm alee</b></col>, <col><b>Helm
aweather</b></col></mcol>, <cd>when the tiller is borne over to the lee
or to the weather side.</cd> -- <mcol><col><b>Helm hard alee</b></col>,
<col><b>Helm hard aport</b></col>, <col><b>Helm hard
astarboard</b></col>, etc.,</mcol> <cd>when the tiller is borne over to
the extreme limit.</cd> -- <col><b>Helm port</b></col>, <cd>the round
hole in a vessel's counter through which the rudderstock passes.</cd> --
<col><b>Helm down</b></col>, <cd>helm alee.</cd> -- <col><b>Helm
up</b></col>, <cd>helm aweather.</cd> -- <col><b>To ease the
helm</b></col>, <cd>to let the tiller come more amidships, so as to
lessen the strain on the rudder.</cd> -- <col><b>To feel the
helm</b></col>, <cd>to obey it.</cd> -- <col><b>To right the
helm</b></col>, <cd>to put it amidships.</cd> -- <col><b>To shift the
helm</b></col>, <cd>to bear the tiller over to the corresponding
position on the opposite side of the vessel.</cd> <rj><au>Ham. Nav.
Encyc.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helm</ent><br/
<hw>Helm</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Helmed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Helming</conjf>.]</vmorph> <def>To steer; to guide; to
direct.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The business he hath <qex>helmed</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A wild wave . . . overbears the bark,<br/
And him that <qex>helms</qex> it.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helm</ent><br/
<hw>Helm</hw>, <pos>n.</pos> <ety>[AS. See <er>Helmet</er>.]</ety>
<sn>1.</sn> <def>A helmet.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A heavy cloud lying on the brow of a mountain.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helm</ent><br/
<hw>Helm</hw>, <pos>v. t.</pos> <def>To cover or furnish with a helm or
helmet.</def> <mark>[Perh. used only as a <pos>past part.</pos> or
<pos>part. adj.</pos>]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She that <qex>helmed</qex> was in starke stours.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmage</ent><br/
<hw>Helm"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Guidance;
direction.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmed</ent><br/
<hw>Helm"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered with a
helmet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>helmed</qex> cherubim<br/
Are seen in glittering ranks.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmet</ent><br/
<hw>Hel"met</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>helmet</ets>, a dim of <ets>helme</ets>, F. <ets>heaume</ets>; of
Teutonic origin; cf. G. <ets>helm</ets>, akin to AS. & OS.
<ets>helm</ets>, D. <ets>helm</ets>, <ets>helmet</ets>, Icel.
<ets>hj<amac/lmr</ets>, Sw. <ets>hjelm</ets>, Dan. <ets>hielm</ets>,
Goth. <ets>hilms</ets>; and prob. from the root of AS. <ets>helan</ets>
to hide, to hele; cf. also Lith. <ets>szalmas</ets>, Russ.
<ets>shleme</ets>, Skr. <ets><cced/arman</ets> protection. <root/17. Cf.
<er>Hele</er>, <er>Hell</er>, <er>Helm</er> a helmet.]</ety> <sn>1.</sn>
<fld>(Armor)</fld> <def>A defensive covering for the head. See
<er>Casque</er>, <er>Headpiece</er>, <er>Morion</er>, <er>Sallet</er>,
and <xex>Illust.</xex> of <er>Beaver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>The representation of a helmet
over shields or coats of arms, denoting gradations of rank by
modifications of form.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A helmet-shaped hat, made of cork, felt, metal, or
other suitable material, worn as part of the uniform of soldiers,
firemen, etc., also worn in hot countries as a protection from the heat
of the sun.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which resembles a helmet in form, position,
etc.</def>; as: <sd>(a)</sd> <fld>(Chem.)</fld> <def>The upper part of a
retort.</def> <au>Boyle.</au> <sd>(b)</sd> <fld>(Bot.)</fld> <def>The
hood-formed upper sepal or petal of some flowers, as of the monkshood or
the snapdragon.</def> <sd>(c)</sd> <fld>(Zool.)</fld> <def>A naked
shield or protuberance on the top or fore part of the head of a
bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Helmet beetle</b></col> <fld>(Zool.)</fld>, <cd>a
leaf-eating beetle of the family <fam>Chrysomelidae</fam>, having a
short, broad, and flattened body. Many species are known.</cd> --
<col><b>Helmet shell</b></col> <fld>(Zool.)</fld>, <cd>one of many
species of tropical marine univalve shells belonging to
<gen>Cassis</gen> and allied genera. Many of them are large and
handsome; several are used for cutting as cameos, and hence are called
<altname>cameo shells</altname>. See <er>King conch</er>.</cd> --
<col><b>Helmet shrike</b></col> <fld>(Zool.)</fld>, <cd>an African wood
shrike of the genus <gen>Prionodon</gen>, having a large
crest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmeted</ent><br/
<hw>Hel`met*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wearing a helmet;
furnished with or having a helmet or helmet-shaped part;
galeate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmet-shaped</ent><br/
<hw>Hel"met-shaped`</hw> <pr>(<?/)</pr>, <pos>a.</pos> <def>Shaped like
a helmet; galeate. See <xex>Illust.</xex> of <er>Galeate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminth</ent><br/
<hw>Hel"minth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/, a
worm.]</ety> <fld>(Zool.)</fld> <def>An intestinal worm, or wormlike
intestinal parasite; one of the Helminthes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthagogue</ent><br/
<hw>Hel*min"tha*gogue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
worm + <?/ to drive.]</ety> <fld>(Med.)</fld> <def>A
vermifuge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthes</ent><br/
\'d8<hw>Hel*min"thes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/, <?/, a worm.]</ety> <fld>(Zool.)</fld> <def>One of the grand
divisions or branches of the animal kingdom. It is a large group
including a vast number of species, most of which are parasitic. Called
also <altname>Enthelminthes</altname>,
<altname>Enthelmintha</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The following classes are included, with others of less
importance: Cestoidea (tapeworms), Trematodea (flukes, etc.),
Turbellaria (planarians), Acanthocephala (thornheads), Nematoidea
(roundworms, trichina, gordius), Nemertina (nemerteans). See
<er>Plathelminthes</er>, and <er>Nemathelminthes</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthiasis</ent><br/
\'d8<hw>Hel`min*thi"a*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <?/ to suffer from worms, fr. <?/, <?/, a worm.]</ety>
<fld>(Med.)</fld> <def>A disease in which worms are present in some part
of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthic</ent><br/
<hw>Hel*min"thic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>helminthique</ets>.]</ety> <def>Of or relating to worms, or
Helminthes; expelling worms.</def> -- <def2><pos>n.</pos> <def>A
vermifuge; an anthelmintic.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthite</ent><br/
<hw>Hel*min"thite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/, a
worm.]</ety> <fld>(Geol.)</fld> <def>One of the sinuous tracks on the
surfaces of many stones, and popularly considered as worm
trails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthoid</ent><br/
<hw>Hel*min"thoid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, <?/, a
worm + <ets>-oid</ets>.]</ety> <def>Wormlike; vermiform.</def></p>

<p><ent>Helminthological</ent><br/
<ent>Helminthologic</ent><br/
<mhw>{ <hw>Hel*min`tho*log"ic</hw> <pr>(?)</pr>,
<hw>Hel*min`tho*log"ic*al</hw>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>helminthologique</ets>.]</ety> <def>Of or pertaining to
helminthology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthologist</ent><br/
<hw>Hel`min*thol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>helminthologiste</ets>.]</ety> <def>One versed in
helminthology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helminthology</ent><br/
<hw>Hel`min*thol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/,
<?/, a worm + <ets>-logy</ets>: cf. F. <ets>helminthologie</ets>.]</ety>
<def>The natural history, or study, of worms, esp. parasitic
worms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmless</ent><br/
<hw>Helm"less</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Destitute of a helmet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without a helm or rudder.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmsman</ent><br/
<hw>Helms"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Helmsmen</plw> <pr>(<?/)</pr>.</plu> <def>The man at the helm; a
steersman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helmwind</ent><br/
<hw>Helm"wind`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wind attending or
presaged by the cloud called <xex>helm</xex>.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helodermatidae</ent><br/
<hw>Helodermatidae</hw> <pos>prop. n.</pos> <def>A natural family of
lizards, including the only known venomous lizards.</def><br/
<syn><b>Syn. --</b> family <fam>Helodermatidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Helot</ent><br/
<hw>He"lot</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>Helotes</ets>, <ets>Hilotae</ets>, pl., fr. Gr. <grk>E'e`lws</grk>
and <grk>E'elw`ths</grk> a bondman or serf of the Spartans; so named
from <grk>'Elos</grk>, a town of Laconia, whose inhabitants were
enslaved; or perh. akin to <grk>e`lei^n</grk> to take, conquer, used as
2d aor. of <?/.]</ety> <def>A slave in ancient Sparta; a Spartan serf;
hence, a slave or serf.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those unfortunates, the <qex>Helots</qex> of mankind, more or less
numerous in every community.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helotism</ent><br/
<hw>He"lot*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
the Helots or slaves in Sparta; slavery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helotium</ent><br/
<hw>Helotium</hw> <pos>n.</pos> <def>The type genus of the
<fam>Helotiaceae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Helotium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Helotry</ent><br/
<hw>He"lot*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The Helots,
collectively; slaves; bondsmen.</def> <ldquo/The <xex>Helotry</xex> of
Mammon.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Help</ent><br/
<hw>Help</hw> <pr>(h<ecr/lp)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Helped</conjf> <pr>(h<ecr/lpt)</pr>
(<mark>Obs</mark>. <pos>imp.</pos> <conjf>Holp</conjf>
<pr>(h<omac/lp)</pr>, <pos>p. p.</pos> <conjf>Holpen</conjf>
<pr>(h<omac/l"p'n)</pr>); <pos>p. pr. & vb. n.</pos>
<conjf>Helping</conjf>.]</vmorph> <ety>[AS. <ets>helpan</ets>; akin to
OS. <ets>helpan</ets>, D. <ets>helpen</ets>, G. <ets>helfen</ets>, OHG.
<ets>helfan</ets>, Icel. <ets>hj<amac/lpa</ets>, Sw. <ets>hjelpa</ets>,
Dan. <ets>hielpe</ets>, Goth. <ets>hilpan</ets>; cf. Lith.
<ets>szelpti</ets>, and Skr. <ets>klp</ets> to be fitting.]</ety>
<sn>1.</sn> <def>To furnish with strength or means for the successful
performance of any action or the attainment of any object; to aid; to
assist; <as>as, to <ex>help</ex> a man in his work; to <ex>help</ex> one
to remember</as>; -- the following infinitive is commonly used without
<it>to</it>; <as>as, <ldquo/<ex>Help</ex> me scale yon
balcony.<rdquo/</as></def> <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with the means of deliverance from
trouble; <as>as, to <ex>help</ex> one in distress; to <ex>help</ex> one
out of prison.</as></def> <ldquo/God <xex>help</xex>, poor souls, how
idly do they talk!<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To furnish with relief, as in pain or disease; to be
of avail against; -- sometimes with <xex>of</xex> before a word
designating the pain or disease, and sometimes having such a word for
the direct object.</def> <ldquo/To <xex>help</xex> him of his
blindness.<rdquo/ <-- now, <it>in</it> is used for that function; -- "to
help him in his misery" --> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The true calamus <qex>helps</qex> coughs.</q>
<rj><qau>Gerarde.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 684 --></p>

<p><sn>4.</sn> <def>To change for the better; to remedy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cease to lament for what thou canst not <qex>help</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To prevent; to hinder; as, the evil approaches, and
who can <xex>help</xex> it?</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To forbear; to avoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not <qex>help</qex> remarking the resemblance betwixt him
and our author.</q> <rj><qau>Pope.</qau></rj></p>

<p><-- often used with "but" --><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To wait upon, as the guests at table, by carving and
passing food.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To help forward</b></col>, <cd>to assist in
advancing.</cd> -- <col><b>To help off</b></col>, <cd>to help to go or
pass away, as time; to assist in removing.</cd> <au>Locke.</au> --
<col><b>To help on</b></col>, <cd>to forward; to promote by aid.</cd> --
<col><b>To help out</b></col>, <cd>to aid, as in delivering from a
difficulty, or to aid in completing a design or task.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The god of learning and of light<br/
Would want a god himself <qex>to help</qex> him <qex>out</qex>.</q>
<rj><qau>Swift.</qau></rj></p>

<p>-- <col><b>To help over</b></col>, <cd>to enable to surmount; <as>as,
<ex>to help</ex> one <ex>over</ex> an obstacle</as>.</cd> -- <col><b>To
help to</b></col>, <cd>to supply with; to furnish with; as, <xex>to
help</xex> one <xex>to</xex> soup.</cd> -- <col><b>To help up</b></col>,
<cd>to help (one) to get up; to assist in rising, as after a fall, and
the like.</cd> <ldquo/A man is well <xex>holp up</xex> that trusts to
you.<rdquo/ <au>Shak.</au></p></cs>

<p><syn><b>Syn.</b> -- To aid; assist; succor; relieve; serve; support;
sustain; befriend.</syn> <usage> -- To <er>Help</er>, <er>Aid</er>,
<er>Assist</er>. These words all agree in the idea of affording relief
or support to a person under difficulties. <xex>Help</xex> turns
attention especially to the source of relief. If I fall into a pit, I
call for <xex>help</xex>; and he who <xex>helps</xex> me out does it by
an act of his own. <xex>Aid</xex> turns attention to the other side, and
supposes co<oum/peration on the part of him who is relieved; as, he
<xex>aided</xex> me in getting out of the pit; I got out by the
<xex>aid</xex> of a ladder which he brought. <xex>Assist</xex> has a
primary reference to relief afforded by a person who <ldquo/stands
by<rdquo/ in order to relieve. It denotes both <xex>help</xex> and
<xex>aid</xex>. Thus, we say of a person who is weak, I
<xex>assisted</xex> him upstairs, or, he mounted the stairs by my
<xex>assistance</xex>. When <xex>help</xex> is used as a noun, it points
less distinctively and exclusively to the source of relief, or, in other
words, agrees more closely with <xex>aid</xex>. Thus we say, I got out
of a pit by the <xex>help</xex> of my friend.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Help</ent><br/
<hw>Help</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To lend aid or
assistance; to contribute strength or means; to avail or be of use; to
assist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A generous present <xex>helps</xex> to persuade, as well as an
agreeable person.</q> <rj><qau>Garth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To help out</b></col>, <cd>to lend aid; to bring a
supply.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Help</ent><br/
<hw>Help</hw>, <pos>n.</pos> <ety>[AS. <ets>help</ets>; akin to D.
<ets>hulp</ets>, G. <ets>h<uum/lfe</ets>, <ets>hilfe</ets>, Icel.
<ets>hj<amac/lp</ets>, Sw. <ets>hjelp</ets>, Dan. <ets>hielp</ets>. See
<er>Help</er>, <pos>v. t.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Strength or means furnished toward promoting an
object, or deliverance from difficulty or distress; aid; ^; also, the
person or thing furnishing the aid; <as>as, he gave me a <ex>help</ex>
of fifty dollars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give us <qex>help</qex> from trouble, for vain is the
<qex>help</qex> of man.</q> <rj><qau>Ps. lx. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God is . . . a very present <qex>help</qex> in trouble.</q>
<rj><qau>Ps. xlvi. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Virtue is a friend and a <qex>help</qex> to nature.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Remedy; relief; <as>as, there is no <ex>help</ex>
for it</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A helper; one hired to help another; also, thew hole
force of hired helpers in any business.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Specifically, a domestic servant, man or
woman.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helper</ent><br/
<hw>Help"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, helps, aids, assists, or relieves; <as>as, a lay <ex>helper</ex>
in a parish</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou art the <qex>helper</qex> of the fatherless.</q> <rj><qau>Ps.
x. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Compassion . . . oftentimes a <qex>helper</qex> of evils.</q>
<rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helpful</ent><br/
<hw>Help"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnishing help;
giving aid; assistant; useful; salutary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heavens make our presence and our practices<br/
Pleasant and <qex>helpful</qex> to him!</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <wordforms><wf>Help"ful*ly</wf>, <pos>adv.</pos> --
<wf>Help"ful*ness</wf>, <pos>n.</pos></wordforms>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>helping</ent><br/
<hw>helping</hw> <pos>n.</pos> <sn>1.</sn> <def>a quantity of food
served as part of a meal.</def><br/
<syn><b>Syn. --</b> portion, serving.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the activity of contributing to the fulfillment of a
need or furtherance of an effort or purpose.</def><br/
<syn><b>Syn. --</b> aid, assistance, help.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Helpless</ent><br/
<hw>Help"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Destitute of help or
strength; unable to help or defend one's self; needing help; feeble;
weak; <as>as, a helpless infant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How shall I then your <qex>helpless</qex> fame defend?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Beyond help; irremediable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>helpless</qex> disagreement or dislike, either of mind
or body.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Bringing no help; unaiding.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet since the gods have been<br/
<qex>Helpless</qex> foreseers of my plagues.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Unsupplied; destitute; -- with <xex>of</xex>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Helpless</qex> of all that human wants require.</q>
<rj><qau>Dryden.</qau></rj></p>

<p>-- <wordforms><wf>Help"less*ly</wf>, <pos>adv.</pos> --
<wf>Help"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helpmate</ent><br/
<hw>Help"mate`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A corruption of
the <ldquo/<ets>help meet</ets> for him<rdquo/ of <au>Genesis ii.
18.</au><au>Fitzedward Hall.</au>]</ety> <def>A helper; a companion;
specifically, a wife.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In Minorca the ass and the hog are common <qex>helpmates</qex>,
and are yoked together in order to turn up the land.</q>
<rj><qau>Pennant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A waiting woman was generally considered as the most suitable
<qex>helpmate</qex> for a parson.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helpmeet</ent><br/
<hw>Help"meet`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Helpmate</er>.]</ety> <def>A wife; a helpmate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord God created Adam, . . . and afterwards, on his finding
the want of a <qex>helpmeet</qex>, caused him to sleep, and took one of
his ribs and thence made woman.</q> <rj><qau>J. H.
Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helter-skelter</ent><br/
<hw>Hel"ter-skel"ter</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[An
onomat<?/poetic word. Cf. G. <ets>holter-polter</ets>, D. <ets>holder de
bolder</ets>.]</ety> <def>In hurry and confusion; without definite
purpose; irregularly.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Helter-skelter</qex> have I rode to thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A wistaria vine running <qex>helter-skelter</qex> across the
roof.</q> <rj><qau>J. C. Harris.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helve</ent><br/
<hw>Helve</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>helve</ets>,
<ets>helfe</ets>, AS. <ets>hielf</ets>, <ets>helf</ets>,
<ets>hylf</ets>, cf. OHG. <ets>halb</ets>; and also E.
<ets>halter</ets>, <ets>helm</ets> of a rudder.]</ety> <sn>1.</sn>
<def>The handle of an ax, hatchet, or adze.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Iron Working)</fld> <sd>(a)</sd> <def>The lever at
the end of which is the hammer head, in a forge hammer.</def>
<sd>(b)</sd> <def>A forge hammer which is lifted by a cam acting on the
helve between the fulcrum and the head.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helve</ent><br/
<hw>Helve</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Helved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Helving</conjf>.]</vmorph> <def>To furnish with a helve, as an
ax.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helvetian</ent><br/
<hw>Hel*ve"tian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Helvetic</er>.</def> -- <def2><pos>n.</pos> <def>A Swiss; a
Switzer.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helvetic</ent><br/
<hw>Hel*ve"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Helveticus</ets>, fr. <ets>Helvetii</ets> the Helvetii.]</ety>
<def>Of or pertaining to the Helvetii, the ancient inhabitant of the
Alps, now Switzerland, or to the modern states and inhabitant of the
Alpine regions; <as>as, the <ex>Helvetic</ex> confederacy;
<ex>Helvetic</ex> states.</as></def></p>

<p><ent>Helvite</ent><br/
<ent>Helvine</ent><br/
<mhw>{ <hw>Hel"vine</hw> <pr>(?)</pr>, <hw>Hel"vite</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[L. <ets>helvus</ets> of a light bay
color.]</ety> <fld>(Min.)</fld> <def>A mineral of a yellowish color,
consisting chiefly of silica, glucina, manganese, and iron, with a
little sulphur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Helxine</ent><br/
<hw>Helxine</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A genus of plants
consisting of one species; a dwarf creeping mat-forming evergreen
herb.</def><br/
<syn><b>Syn. --</b> genus <gen>Helxine</gen>, Soleirolia, genus
<gen>Soleirolia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hem</ent><br/
<hw>Hem</hw> <pr>(h<ecr/m)</pr>, <pos>pron.</pos> <ety>[OE., fr. AS.
<ets>him</ets>, <ets>heom</ets>, dative pl. of. <ets>h<emac/</ets> he.
See <er>He</er>, <er>They</er>.]</ety> <def>Them</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hem</ent><br/
<hw>Hem</hw>, <pos>interj.</pos> <def>An onomatopoetic word used as an
expression of hesitation, doubt, etc. It is often a sort of voluntary
half cough, loud or subdued, and would perhaps be better expressed by
<xex>hm</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cough or cry <qex>hem</qex>, if anybody come.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hem</ent><br/
<hw>Hem</hw>, <pos>n.</pos> <def>An utterance or sound of the voice,
<xex>hem</xex> or <xex>hm</xex>, often indicative of hesitation or
doubt, sometimes used to call attention.</def> <ldquo/His morning
<xex>hems</xex>.<rdquo/ <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hem</ent><br/
<hw>Hem</hw>, <pos>v. i.</pos> <ety>[<root/15. See <er>Hem</er>,
<pos>interj.</pos>]</ety> <def>To make the sound expressed by the word
<xex>hem</xex>; hence, to hesitate in speaking.</def>
<ldquo/<xex>Hem</xex>, and stroke thy beard.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hem</ent><br/
<hw>Hem</hw>, <pos>n.</pos> <ety>[AS. <ets>hem</ets>, border, margin;
cf. Fries. <ets>h<aum/mel</ets>, Prov. G. <ets>hammel</ets> hem of mire
or dirt.]</ety> <sn>1.</sn> <def>The edge or border of a garment or
cloth, doubled over and sewed, to strengthen it and prevent
raveling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Border; edge; margin.</def> <ldquo/<xex>Hem</xex> of
the sea.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A border made on sheet-metal ware by doubling over
the edge of the sheet, to stiffen it and remove the sharp
edge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hem</ent><br/
<hw>Hem</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hemmed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hemming</conjf>.]</vmorph> <sn>1.</sn> <def>To form a hem or
border to; to fold and sew down the edge of.</def>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To border; to edge</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the skirt about<br/
Was <qex>hemmed</qex> with golden fringe.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To hem about</b></col>, <col><b>To hem
around</b></col>, <it>or</it> <col><b>To hem in</b></col></mcol>, <cd>to
inclose and confine; to surround; to environ.</cd> <ldquo/With valiant
squadrons round <xex>about to hem</xex>.<rdquo/ <au>Fairfax.</au>
<ldquo/<xex>Hemmed in</xex> to be a spoil to tyranny.<rdquo/
<au>Daniel.</au> -- <col><b>To hem out</b></col>, <cd>to shut out.</cd>
<ldquo/You can not <xex>hem</xex> me <xex>out</xex> of London.<rdquo/
<au>J. Webster.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hema-</ent><br/
<hw>Hem"a-</hw> <pr>(?)</pr>. <def>Same as <er>Haema-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemachate</ent><br/
<hw>Hem"a*chate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>haemachates</ets>; Gr. <grk>a"i^ma</grk> blood +
<grk>'acha`ths</grk> agate.]</ety> <fld>(Min.)</fld> <def>A species of
agate, sprinkled with spots of red jasper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemachrome</ent><br/
<hw>Hem"a*chrome</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Haemachrome</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemacite</ent><br/
<hw>Hem"a*cite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>a"i^ma</grk> blood.]</ety> <def>A composition made from blood,
mixed with mineral or vegetable substances, used for making buttons,
door knobs, etc.</def></p>

<p><ent>Hemadromometer</ent><br/
<ent>Hemadrometer</ent><br/
<mhw>{ <hw>Hem`a*drom"e*ter</hw> <pr>(?)</pr>,
<hw>Hem`a*dro*mom"e*ter</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[<ets>Hema-</ets> + Gr. <?/ course + <ets>-meter</ets>.]</ety>
<fld>(Physiol.)</fld> <def>An instrument for measuring the velocity with
which the blood moves in the arteries.</def><-- now hemodromometer
--></p>

<p><ent>Hemadromometry</ent><br/
<ent>Hemadrometry</ent><br/
<mhw>{ <hw>Hem`a*drom`e*try</hw> <pr>(?)</pr>,
<hw>Hem`a*dro*mom"e*try</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<fld>(Physiol.)</fld> <def>The act of measuring the velocity with which
the blood circulates in the arteries; haemotachometry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemadynamics</ent><br/
<hw>He`ma*dy*nam"ics</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hema-</ets> + <ets>dynamics</ets>.]</ety>
<fld>(Physiol.)</fld> <def>The principles of dynamics in their
application to the blood; that part of science which treats of the
motion of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemadynamometer</ent><br/
<hw>He`ma*dy"na*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hema-</ets> + <ets>dynamometr</ets>.]</ety>
<fld>(Physiol.)</fld> <def>An instrument by which the pressure of the
blood in the arteries, or veins, is measured by the height to which it
will raise a column of mercury; -- called also a
<altname>haemomanometer</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemal</ent><br/
<hw>He"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>a"i^ma</grk>
blood.]</ety> <def>Relating to the blood or blood vessels; pertaining
to, situated in the region of, or on the side with, the heart and great
blood vessels; -- opposed to <xex>neural</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ As applied to vertebrates, <xex>hemal</xex> is the same
as <xex>ventral</xex>, the heart and great blood vessels being on the
ventral, and the central nervous system on the dorsal, side of the
vertebral column.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hemal arch</b></col> <fld>(Anat.)</fld>, <cd>the ventral
arch in a segment of the spinal skeleton, formed by vertebral processes
or ribs.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemaphaein</ent><br/
<hw>Hem`a*phae"in</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Haemaphaein</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemapophysis</ent><br/
\'d8<hw>Hem`a*poph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hemapophyses</plw> .</plu> <ety>[NL. See
<er>Haema-</er>, and <er>Apophysis</er>.]</ety> <fld>(Anat.)</fld>
<def>The second element in each half of a hemal arch, corresponding to
the sternal part of a rib.</def> <au>Owen.</au> --
<wordforms><wf>Hem`a*po*phys"i*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms></p>

<p><ent>Hemastatical</ent><br/
<ent>Hemastatic</ent><br/
<mhw>{ <hw>Hem`a*stat"ic</hw> <pr>(?)</pr>, <hw>Hem`a*stat"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a. & n.</pos> <def>Same as
<er>Hemostatic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemastatics</ent><br/
<hw>Hem`a*stat"ics</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>Laws relating to the equilibrium of the blood
in the blood vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematachometer</ent><br/
<hw>Hem`a*ta*chom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Haematachometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematein</ent><br/
<hw>Hem`a*te"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/,
blood.]</ety> <fld>(Chem.)</fld> <def>A reddish brown or violet
crystalline substance, <chform>C16H12O6</chform>, got from hematoxylin
by partial oxidation, and regarded as analogous to the
phthaleins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematemesis</ent><br/
\'d8<hw>Hem`a*tem"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood + <?/ a vomiting, fr.
<?/ to vomit.]</ety> <fld>(Med.)</fld> <def>A vomiting of
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematherm</ent><br/
<hw>Hem"a*therm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>a"i^ma</grk> blood + <?/ warm.]</ety> <fld>(Zool.)</fld> <def>A
warm-blooded animal.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemathermal</ent><br/
<hw>Hem`a*ther"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Warm-blooded; hematothermal.</def> <mark>[R]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematic</ent><br/
<hw>He*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Haematic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematic</ent><br/
<hw>He*mat"ic</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A medicine
designed to improve the condition of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematin</ent><br/
<hw>Hem"a*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood.]</ety> <sn>1.</sn>
<def>Hematoxylin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol. Chem.)</fld> <def>A bluish black,
amorphous substance containing iron and obtained from blood. It exists
the red blood corpuscles united with globulin, and the form of
hemoglobin or oxyhemoglobin gives to the blood its red color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematinic</ent><br/
<hw>He`ma*tin"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Hematin</er>.]</ety> <fld>(Med.)</fld> <def>Any substance, such as
an iron salt or organic compound containing iron, which when ingested
tends to increase the hemoglobin contents of the blood.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hematinometer</ent><br/
<hw>Hem`a*ti*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hematin</ets> + <ets>-meter</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A form of hemoglobinometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematinometric</ent><br/
<hw>Hem`a*tin`o*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Relating to the measurement of the amount of
hematin or hemoglobin contained in blood, or other fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematinon</ent><br/
<hw>He*mat"i*non</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood.]</ety> <def>A red
consisting of silica, borax, and soda, fused with oxide of copper and
iron, and used in enamels, mosaics, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematite</ent><br/
<hw>Hem"a*tite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>haematites</ets>, Gr. <?/ bloodlike, fr. <grk>a"i^ma</grk>,
<grk>a"i`matos</grk>, blood.]</ety> <fld>(Min.)</fld> <def>An important
ore of iron, the sesquioxide, so called because of the red color of the
powder. It occurs in splendent rhombohedral crystals, and in massive and
earthy forms; -- the last called red ocher. Called also
<altname>specular iron</altname>, <altname>oligist iron</altname>,
<altname>rhombohedral iron ore</altname>, and
<altname>bloodstone</altname>. See <cref>Brown hematite</cref>, under
<er>Brown</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematitic</ent><br/
<hw>Hem`a*tit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to hematite, or resembling it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemato</ent><br/
<hw>Hem"a*to</hw> <pr>(?)</pr>. <def>See <er>Haema-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematocele</ent><br/
<hw>He*mat"o*cele</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemato-</ets> + Gr. <?/ tumor: cf. F.
<ets>h<eacute/matoc<egrave/le</ets>.]</ety> <fld>(Med.)</fld> <def>A
tumor filled with blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematocrya</ent><br/
\'d8<hw>Hem`a*toc"ry*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood +
<grk>kry`os</grk> cold.]</ety> <fld>(Zool.)</fld> <def>The cold-blooded
vertebrates, that is, all but the mammals and birds; -- the antithesis
to <contr>Hematotherma</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematocrystallin</ent><br/
<hw>Hem`a*to*crys"tal*lin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemato</ets> + <ets>crystalline</ets>.]</ety>
<fld>(Physiol.)</fld> <def>See <er>Hemoglobin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematoid</ent><br/
<hw>Hem"a*toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hemato-</ets>
+ <ets>-oid</ets>.]</ety> <fld>(Physiol.)</fld> <def>Resembling
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematoidin</ent><br/
<hw>Hem`a*toid"in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.
Chem.)</fld> <def>A crystalline or amorphous pigment, free from iron,
formed from hematin in old blood stains, and in old hemorrhages in the
body. It resembles bilirubin. When present in the corpora lutea it is
called <altname>haemolutein</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematology</ent><br/
<hw>Hem`a*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemato-</ets> + <ets>-logy</ets>.]</ety> <def>The science
which treats of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hematolysis</ent><br/
<hw>hematolysis</hw> <pos>n.</pos> <def>The lysis of erythrocytes in the
blood with the release of hemoglobin.</def><br/
<syn><b>Syn. --</b> hemolysis, haemolysis, haematolysis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hematoma</ent><br/
\'d8<hw>Hem`a*to"ma</hw> <pr>(h<emac/`m<adot/*t<omac/"m<adot/
<it>or</it> h<ecr/m`<adot/*t<omac/"m<adot/)</pr>, <pos>n.</pos>
<ety>[NL. See <er>Hema-</er>, and <er>-oma</er>.]</ety>
<fld>(Med.)</fld> <def>A localised leakage of blood from the blood
vessels into nearby tissues, usually confined within a tissue or organ;
especially, a local swelling produced by an effusion of blood beneath
the skin, which may clot and discolor the affected area.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematophilia</ent><br/
\'d8<hw>Hem`a*to*phil"i*a</hw>
<pr>(h<emac/`m<adot/*t<osl/*f<icr/l"<icr/*<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood +
<grk>filei^n</grk> to love.]</ety> <fld>(Med.)</fld> <def>Same as
<er>hemophilia</er>; -- an obsolete term.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hematosin</ent><br/
<hw>Hem`a*to"sin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.
Chem.)</fld> <def>The hematin of blood.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematosis</ent><br/
\'d8<hw>Hem`a*to"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>a"ima`twsis</grk>.]</ety> <fld>(Physiol.)</fld> <sd>(a)</sd>
<def>Sanguification; the conversion of chyle into blood.</def>
<sd>(b)</sd> <def>The arterialization of the blood in the lungs; the
formation of blood in general; haematogenesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematotherma</ent><br/
\'d8<hw>Hem`a*to*ther"ma</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <grk>a"i^ma</grk>, <grk>a"i`matos</grk>, blood +
<grk>thermo`s</grk> warm.]</ety> <fld>(Zool.)</fld> <def>The
warm-blooded vertebrates, comprising the mammals and birds; -- the
antithesis to <contr>hematocrya</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematothermal</ent><br/
<hw>Hem"a*to*ther"mal</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Warm-blooded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematoxylin</ent><br/
<hw>Hem`a*tox"y*lin</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Haematoxylin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hematuria</ent><br/
\'d8<hw>Hem`a*tu"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hema-</er>, and <er>Urine</er>.]</ety> <fld>(Med.)</fld>
<def>Passage of urine mingled with blood; blood in the urine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemautography</ent><br/
<hw>Hem`au*tog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>The obtaining of a curve similar to a pulse
curve or sphygmogram by allowing the blood from a divided artery to
strike against a piece of paper.</def></p>

<p><ent>Hemelytrum</ent><br/
<ent>Hemelytron</ent><br/
<mhw>{ \'d8<hw>Hem*el"y*tron</hw> <pr>(? <or/ ?)</pr>,
\'d8<hw>Hem*el"y*trum</hw> <pr>(-tr<ucr/m cf. <er>Elytron</er>,
277)</pr>, }</mhw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hemelytra</plw> <pr>(<?/)</pr>.</plu> <ety>[NL. See <er>Hemi</er>,
and <er>Elytron</er>.]</ety> <fld>(Zool.)</fld> <def>One of the
partially thickened anterior wings of certain insects, as of many
Hemiptera, the earwigs, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemeralopia</ent><br/
\'d8<hw>Hem`e*ra*lo"pi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/, the opposite of <?/; <?/ day + <?/ of <?/. See
<er>Nyctalopia</er>.]</ety> <fld>(Med.)</fld> <def>A disease of the
eyes, in consequence of which a person can see clearly or without pain
only by daylight or a strong artificial light; day sight.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some writers (as Quain) use the word in the opposite
sense, <it>i. e.</it>, day blindness. See
<er>Nyctalopia</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemerobian</ent><br/
<hw>Hem`er*o"bi*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ day +
<?/ life.]</ety> <fld>(Zool.)</fld> <def>A neuropterous insect of the
genus <gen>Hemerobius</gen>, and allied genera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemerobid</ent><br/
<hw>He*mer"o*bid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of relating to the hemerobians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemerobiidae</ent><br/
<hw>Hemerobiidae</hw> <pos>prop. n.</pos> <def>A natural family of
insects including the brown lacewings.</def><br/
<syn><b>Syn. --</b> family <fam>Hemerobiidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hemerocallidaceae</ent><br/
<hw>Hemerocallidaceae</hw> <pos>n.</pos> <def>one of many subfamilies
into which some classification systems subdivide the Lily family
<fam>Liliaceae</fam>, but not widely accepted; it includes the genus
<gen>Hemerocallis</gen>.</def><br/
<syn><b>Syn. --</b> family <fam>Hemerocallidaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hemerocallis</ent><br/
\'d8<hw>Hem`e*ro*cal"lis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/; <?/ day + <grk>ka`llos</grk> beauty.]</ety> <fld>(Bot.)</fld>
<def>A genus of plants, some species of which are cultivated for their
beautiful flowers; day lily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemi-</ent><br/
<hw>Hem"i-</hw> <pr>(?)</pr>. <ety>[Gr. <grk>"hmi-</grk>. See
<er>Semi-</er>.]</ety> <def>A prefix signifying
<xex>half</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemialbumin</ent><br/
<hw>Hem`i*al*bu"min</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>albumin</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>Same as <er>Hemialbumose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemialbumose</ent><br/
<hw>Hem`i*al"bu"mose`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>albumose</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>An albuminous substance formed in gastric digestion,
and by the action of boiling dilute acids on albumin. It is readily
convertible into hemipeptone. Called also
<altname>hemialbumin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemianaesthesia</ent><br/
\'d8<hw>Hem`i*an`aes*the"si*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>anaesthesia</ets>.]</ety>
<fld>(Med.)</fld> <def>Anaesthesia upon one side of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemibranchi</ent><br/
\'d8<hw>Hem`i*bran"chi</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Hemi-</er>, and <er>Branchia</er>.]</ety> <fld>(Zool.)</fld>
<def>An order of fishes having an incomplete or reduced branchial
apparatus. It includes the sticklebacks, the flutemouths, and
Fistularia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicardia</ent><br/
\'d8<hw>Hem`i*car"di*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hemi-</er>, and <er>Cardia</er>.]</ety> <fld>(Anat.)</fld> <def>A
lateral half of the heart, either the right or left.</def> <rj><au>B. G.
Wilder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicarp</ent><br/
<hw>Hem`i*carp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hemi-</ets> +
Gr. <?/ fruit.]</ety> <fld>(Bot.)</fld> <def>One portion of a fruit that
spontaneously divides into halves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicerebrum</ent><br/
\'d8<hw>Hem`i*cer"e*brum</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>cerebrum</ets>.]</ety> <fld>(Anat.)</fld>
<def>A lateral half of the cerebrum.</def> <rj><au>Wilder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicollin</ent><br/
<hw>Hem`i*col"lin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>collin</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>See <er>Semiglutin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicrania</ent><br/
\'d8<hw>Hem`i*cra"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>h<eacute/micr<acir/nie</ets>. See <er>Cranium</er>, and
<er>Megrim</er>.]</ety> <fld>(Med.)</fld> <def>A pain that affects only
one side of the head.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicrany</ent><br/
<hw>Hem"i*cra`ny</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Hemicranis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemicycle</ent><br/
<hw>Hem"i*cy`cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hemicyclus</ets>, Gr. <?/; <?/ + <grk>ky`klos</grk>.]</ety>
<sn>1.</sn> <def>A half circle; a semicircle.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 685 --></p>

<p><sn>2.</sn> <def>A semicircular place, as a semicircular arena, or
room, or part of a room.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The collections will be displayed in the <qex>hemicycle</qex> of
the central pavilion.</q> <rj><qau>London Academy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemidactyl</ent><br/
<hw>Hem`i*dac"tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hemi-</er>, and <er>Dactyl</er>.]</ety> <fld>(Zool.)</fld> <def>Any
species of Old World geckoes of the genus <gen>Hemidactylus</gen>. The
hemidactyls have dilated toes, with two rows of plates
beneath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemi-demi-semiquaver</ent><br/
<hw>Hem`i-dem`i-sem"i*quaver</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>demi-semiquaver</ets>.]</ety>
<fld>(Mus.)</fld> <def>A short note, equal to one fourth of a
semiquaver, or the sixty-fourth part of a whole note.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiditone</ent><br/
<hw>Hem`i*di"tone</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>ditone</ets>.]</ety> <fld>(Gr. Mus.)</fld>
<def>The lesser third.</def> <rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemigamous</ent><br/
<hw>He*mig"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemi-</ets> + Gr. <?/ marriage.]</ety> <fld>(Bot.)</fld>
<def>Having one of the two florets in the same spikelet neuter, and the
other unisexual, whether male or female; -- said of grasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiglyph</ent><br/
<hw>Hem"i*glyph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hemi-</ets>
+ Gr. <?/ a carving.]</ety> <fld>(Arch.)</fld> <def>The half channel or
groove in the edge of the triglyph in the Doric order.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemihedral</ent><br/
<hw>Hem`i*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemi-</ets> + Gr. <?/ seat, base, fr. <?/ to sit.]</ety>
<fld>(Crystallog.)</fld> <def>Having half of the similar parts of a
crystals, instead of all; consisting of half the planes which full
symmetry would require, as when a cube has planes only on
<xex>half</xex> of its eight solid angles, or one plane out of a pair on
each of its edges; or as in the case of a tetrahedron, which is
<xex>hemihedral</xex> to an octahedron, it being contained under four of
the planes of an octahedron.</def> --
<wordforms><wf>Hem`i*he"dral*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemihedrism</ent><br/
<hw>Hem`i*he"drism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Crystallog.)</fld> <def>The property of crystallizing
hemihedrally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemihedron</ent><br/
<hw>Hem`i*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Crystallog.)</fld> <def>A solid hemihedrally derived. The
tetrahedron is a <xex>hemihedron</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiholohedral</ent><br/
<hw>Hem`i*hol`o*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemi-</ets> + <ets>holohedral</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Presenting hemihedral forms, in which half
the sectants have the full number of planes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemimellitic</ent><br/
<hw>Hem`i*mel*lit"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemi-</ets> + <ets>mellitic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Having <xex>half</xex> as many (<xex>three</xex>) carboxyl radicals
as <xex>mellitic</xex> acid; -- said of an organic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemimetabola</ent><br/
\'d8<hw>Hem`i*me*tab"o*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Hemi-</er>, and <er>Metabola</er>.]</ety> <fld>(Zool.)</fld>
<def>Those insects which have an incomplete metamorphosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemimetabolic</ent><br/
<hw>Hem`i*met`a*bol"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having an incomplete metamorphosis, the larvae
differing from the adults chiefly in laking wings, as in the
grasshoppers and cockroaches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemimorphic</ent><br/
<hw>Hem`i*mor"phic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemi-</ets> + Gr. <grk>morfh`</grk> form.]</ety>
<fld>(Crystallog.)</fld> <def>Having the two ends modified with unlike
planes; -- said of a crystal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemin</ent><br/
<hw>He"min</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>a"i^ma</grk>
blood.]</ety> <fld>(Physiol. Chem.)</fld> <def>A substance, in the form
of reddish brown, microscopic, prismatic crystals, formed from dried
blood by the action of strong acetic acid and common salt; -- called
also <xex>Teichmann's</xex> crystals. Chemically, it is a hydrochloride
of hematin.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The obtaining of these small crystals, from old blood
clots or suspected blood stains, constitutes one of the best evidences
of the presence of blood.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemina</ent><br/
\'d8<hw>He*mi"na</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Heminae</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. Gr. <?/.]</ety>
<sn>1.</sn> <fld>(Rom. Antiq.)</fld> <def>A measure of half a
sextary.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A measure equal to about ten fluid
ounces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemionus</ent><br/
\'d8<hw>He*mi"o*nus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ a half ass, a mule.]</ety> <fld>(Zool.)</fld> <def>A wild ass found
in Tibet; the kiang.</def> <rj><au>Darwin.</au></rj></p>

<p><ent>Hemiopsia</ent><br/
<ent>Hemiopia</ent><br/
<mhw>{ \'d8<hw>Hem`i*o"pi*a</hw> <pr>(?)</pr>, <hw>Hem`i*op"si*a</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL., fr. Gr. <?/ half + Gr.
<?/ sight.]</ety> <fld>(Med.)</fld> <def>A defect of vision in
consequence of which a person sees but half of an object looked
at.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiorthotype</ent><br/
<hw>Hem`i*or"tho*type</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemi-</ets> + Gr. <?/ straight + <ets>-type</ets>.]</ety>
<def>Same as <er>Monoclinic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemipeptone</ent><br/
<hw>Hem`i*pep"tone</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>peptone</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A product of the gastric and pancreatic digestion of
albuminous matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Unlike antipeptone it is convertible into leucin and
tyrosin, by the continued action of pancreatic juice. See
<er>Peptone</er>. It is also formed from hemialbumose and albumin by the
action of boiling dilute sulphuric acid.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiplegia</ent><br/
\'d8<hw>Hem`i*ple"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[NL., fr.
Gr. <?/; <?/ half + <?/ a stroke; cf. F.
<ets>h<eacute/miplagie</ets>.]</ety> <fld>(Med.)</fld> <def>A palsy that
affects one side only of the body.</def> --
<wordforms><wf>Hem`i"pleg"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiplegy</ent><br/
<hw>Hem"i*ple`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Hemiplegia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemipode</ent><br/
<hw>Hem"i*pode</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hemi-</ets> +
Gr. <?/, <?/, foot.]</ety> <fld>(Zool.)</fld> <def>Any bird of the genus
<gen>Turnix</gen>. Various species inhabit Asia, Africa, and
Australia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiprotein</ent><br/
<hw>Hem`i*pro"te*in</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>protein</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>An insoluble, proteid substance, described by
Sch<uum/tzenberger, formed when albumin is heated for some time with
dilute sulphuric acid. It is apparently identical with antialbumid and
dyspeptone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemipter</ent><br/
<hw>He*mip"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>h<eacute/mipt<egrave/res</ets>, pl.]</ety> <fld>(Zool.)</fld>
<def>One of the Hemiptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiptera</ent><br/
\'d8<hw>He*mip"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ half + <?/ wing, fr. <?/ to fly.]</ety> <fld>(Zool.)</fld>
<def>An order of hexapod insects having a jointed proboscis, including
four sharp stylets (mandibles and maxillae), for piercing. In many of
the species (Heteroptera) the front wings are partially coriaceous, and
different from the others.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They are divided into the <xex>Heteroptera</xex>,
including the squash bug, soldier bug, bedbug, etc.; the
<xex>Homoptera</xex>, including the cicadas, cuckoo spits, plant lice,
scale insects, etc.; the <xex>Thysanoptera</xex>, including the thrips,
and, according to most recent writers, the <xex>Pediculina</xex> or true
lice.</note></p>

<p><ent>Hemipterous</ent><br/
<ent>Hemipteral</ent><br/
<mhw>{ <hw>He*mip"ter*al</hw> <pr>(?)</pr>, <hw>He*mip"ter*ous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Of or
pertaining to the Hemiptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemipteran</ent><br/
<hw>He*mip"ter*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Hemiptera; an hemipter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemiramphidae</ent><br/
<hw>Hemiramphidae</hw> <pos>prop. n.</pos> <def>A natural family of fish
including the halfbeaks, marine and freshwater fishes closely related to
the flying fishes but not able to glide.</def><br/
<syn><b>Syn. --</b> family <fam>Hemiramphidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hemisect</ent><br/
<hw>Hem`i*sect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hemisected</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hemisecting</conjf>.]</vmorph> <ety>[<ets>Hemi-</ets> + L.
<ets>secare</ets> to cut.]</ety> <fld>(Anat.)</fld> <def>To divide along
the mesial plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemisection</ent><br/
<hw>Hem`i*sec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>A division along the mesial plane; also, one of the parts so
divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemisphere</ent><br/
<hw>Hem"i*sphere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hemisphaerium</ets>, Gr. <?/; <?/ half = <?/ sphere: cf. F.
<ets>h<eacute/misph<egrave/re</ets>. See <er>Hemi-</er>, and
<er>Sphere</er>.]</ety> <sn>1.</sn> <def>A half sphere; one half of a
sphere or globe, when divided by a plane passing through its
center.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Half of the terrestrial globe, or a projection of
the same in a map or picture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The people who inhabit a hemisphere.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He died . . . mourned by a <qex>hemisphere</qex>.</q> <rj><qau>J.
P. Peters.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cerebral hemispheres</b></col>. <fld>(Anat.)</fld>
<cd>See <er>Brain</er>.</cd> -- <col><b>Magdeburg hemispheres</b></col>
<fld>(Physics)</fld>, <cd>two hemispherical cups forming, when placed
together, a cavity from which the air can be withdrawn by an air pump;
-- used to illustrate the pressure of the air. So called because
invented by Otto von Guericke at <etsep>Magdeburg</etsep>.</cd></cs></p>

<p><ent>Hemispherical</ent><br/
<ent>Hemispheric</ent><br/
<mhw>{ <hw>Hem`i*spher"ic</hw> <pr>(?)</pr>, <hw>Hem`i*spher"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>h<eacute/misph<eacute/rique</ets>.]</ety> <def>Containing, or
pertaining to, a hemisphere; <as>as, a <ex>hemispheric</ex> figure or
form; a <ex>hemispherical</ex> body.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemispheroid</ent><br/
<hw>Hem`i*sphe"roid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemi-</ets> + <ets>spheroid</ets>.]</ety> <def>A half of a
spheroid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemispheroidal</ent><br/
<hw>Hem`i*sphe*roid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling,
or approximating to, a hemisphere in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemispherule</ent><br/
<hw>Hem`i*spher"ule</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A half
spherule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemistich</ent><br/
<hw>Hem"i*stich</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>hemistichium</ets>, Gr. <grk>"hmisti`chion</grk>; <grk>"hmi-</grk>
half + <grk>sti`chos</grk> row, line, verse: cf. F.
<ets>h<eacute/mistiche</ets>.]</ety> <def>Half a poetic verse or line,
or a verse or line not completed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemistichal</ent><br/
<hw>He*mis"ti*chal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or written in, hemistichs; also, by, or according to, hemistichs;
<as>as, a <ex>hemistichal</ex> division of a verse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemisystole</ent><br/
<hw>Hem`i*sys"to*le</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>Contraction of only one ventricle of the
heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hemisystole</xex> is noticed in rare cases of
insufficiency of the mitral valve, in which both ventricles at times
contract simultaneously, as in a normal heart, this condition
alternating with contraction of the right ventricle alone; hence,
<xex>intermittent hemisystole</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemitone</ent><br/
<hw>Hem"i*tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hemitonium</ets>, Gr. <?/.]</ety> <def>See
<er>Semitone</er>.</def></p>

<p><ent>Hemitropous</ent><br/
<ent>Hemitropal</ent><br/
<mhw>{ <hw>He*mit"ro*pal</hw> <pr>(?)</pr>, <hw>He*mit"ro*pous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Hemitrope</er>.]</ety>
<sn>1.</sn> <def>Turned half round; half inverted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having the raphe terminating about
half way between the chalaza and the orifice; amphitropous; -- said of
an ovule.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemitrope</ent><br/
<hw>Hem"i*trope</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hemi-</ets>
+ Gr. <?/ to turn: cf. F. <ets>h<eacute/mitrope</ets>.]</ety> <def>Half
turned round; half inverted; <fld>(Crystallog.)</fld> having a twinned
structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemitrope</ent><br/
<hw>Hem"i*trope</hw>, <pos>n.</pos> <def>That which is hemitropal in
construction; <fld>(Crystallog.)</fld> a twin crystal having a
hemitropal structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemitropy</ent><br/
<hw>He*mit"ro*py</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Crystallog.)</fld> <def>Twin composition in crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemlock</ent><br/
<hw>Hem"lock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hemeluc</ets>, <ets>humloc</ets>, AS. <ets>hemlic</ets>,
<ets>hymlic</ets>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>The name of
several poisonous umbelliferous herbs having finely cut leaves and small
white flowers, as the <spn>Cicuta maculata</spn>, <spn>Cicuta
bulbifera</spn>, and <spn>Cicuta virosa</spn>, and the <spn>Conium
maculatum</spn>. See <er>Conium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The potion of <xex>hemlock</xex> administered to
Socrates is by some thought to have been a decoction of <spn>Cicuta
virosa</spn>, or <xex>water hemlock</xex>, by others, of <spn>Conium
maculatum</spn>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>An evergreen tree common in North
America (<spn>Abies Canadensis</spn> <it>or</it> <spn>Tsuga
Canadensis</spn>); hemlock spruce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The murmuring pines and the <qex>hemlocks</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The wood or timber of the hemlock tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Ground hemlock</b></col>, <it>or</it> <col><b>Dwarf
hemlock</b></col></mcol>. <cd>See under <er>Ground</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemmel</ent><br/
<hw>Hem"mel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot.
<ets>hemmel</ets>, <ets>hammel</ets>, Prov. E. <ets>hemble</ets> hovel,
stable, shed, perh. allied to D. <ets>hemel</ets> heaven, canopy, G.
<ets>himmel</ets>; cf. E. <ets>heaven</ets>. <root/14.]</ety> <def>A
shed or hovel for cattle.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemmer</ent><br/
<hw>Hem"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, hems with a needle.</def> <specif>Specifically:</specif>
<sd>(a)</sd> <def>An attachment to a sewing machine, for turning under
the edge of a piece of fabric, preparatory to stitching it down.</def>
<sd>(b)</sd> <def>A tool for turning over the edge of sheet metal to
make a hem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hemming-stitch</ent><br/
<hw>hemming-stitch</hw> <pos>n.</pos> <def>a stitch used in sewing hems
on skirts and dresses.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hemo-</ent><br/
<hw>Hem"o-</hw> <pr>(?)</pr>. <def>Same as <er>Haema-</er>,
<er>Haemo-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemoglobin</ent><br/
<hw>Hem"o*glo"bin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hemo-</ets> + <ets>globe</ets>.]</ety> <fld>(Physiol.)</fld>
<def>The normal coloring matter of the red blood corpuscles of
vertebrate animals. It is composed of hematin and globulin, and is also
called <altname>haematoglobulin</altname>. In arterial blood, it is
always combined with oxygen, and is then called
<stype>oxyhemoglobin</stype>. It crystallizes under different forms from
different animals, and when crystallized, is called
<stype>haematocrystallin</stype>. See <cref>Blood crystal</cref>, under
<er>Blood</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemoglobinometer</ent><br/
<hw>Hem`o*glo"bin*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol. Chem.)</fld> <def>Same as
<er>Haemochromometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hemolysis</ent><br/
<hw>hemolysis</hw> <pos>n.</pos> <def>The lysis of erythrocytes with the
release of hemoglobin; the breaking apart of red blood cells in the
blood.</def><br/
<syn><b>Syn. --</b> haemolysis, hematolysis, haematolysis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hemolytic</ent><br/
<hw>hemolytic</hw> <pos>adj.</pos> <def>of or pertaining to hemolysis;
causing hemolysis.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hemophilia</ent><br/
\'d8<hw>Hem`o*phil"i*a</hw> <pr>(h<emac/`m<adot/*f<icr/l"<icr/*<adot/
<it>or</it> h<ecr/m`<adot/*f<icr/l"<icr/*<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>a"i^ma</grk>, blood + <grk>filei^n</grk> to
love.]</ety> <fld>(Med.)</fld> <def>A condition characterized by a
tendency to profuse and uncontrollable hemorrhage from the slightest
wounds; it is caused by an absence or abnormality of a clotting factor
in the blood, and is a recessive genetic disease linked to the
X-chromosome, and therefore usually occurs only in males; there are
several specific forms. It may be treated by administering purified
clotting factor. It was formerly termed
<altname>Hematophilia</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hemophiliac</ent><br/
<hw>hem`o*phil"i*ac</hw>
<pr>(h<emac/`m<adot/*f<icr/l"<icr/*<acr/k)</pr>, <pos>n.</pos> <def>A
person afflicted with hemophilia; called also
<altname>hemophile</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hemophiliac</ent><br/
<hw>hem`o*phil"i*ac</hw>
<pr>(h<emac/`m<adot/*f<icr/l"<icr/*<acr/k)</pr>, <pos>a.</pos> <def>of,
pertaining to, characteristic of, or afflicted with hemophilia;
hemophilic.</def><br/
[<source>PJC</source>]</p>

<p><ent>hemophilic</ent><br/
<hw>hem`o*phil"ic</hw> <pos>adj.</pos> <sn>1.</sn> <def>of, pertaining
to, characteristic of, or afflicted with hemophilia;
hemophiliac.</def><br/
<syn><b>Syn. --</b> haemophilic, hemophiliac.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Microbiology)</fld> <def>Growing best in a medium
containing blood, or in blood; -- of bacteria.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hemoptysis</ent><br/
<hw>He*mop"ty*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>a"i^ma</grk> blood + <?/ to spit: cf. F.
<ets>h<eacute/moptysie</ets>.]</ety> <fld>(Med.)</fld> <def>The
expectoration of blood, due usually to hemorrhage from the mucous
membrane of the lungs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemorrhage</ent><br/
<hw>Hem"or*rhage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>haemorrhagia</ets>, Gr. <grk>a"imorragi`a</grk>; <grk>a"i^ma</grk>
blood + <grk>"rhgny`nai</grk> to break, burst: cf. F.
<ets>h<eacute/morragie</ets>, <ets>h<eacute/morrhagie</ets>.]</ety>
<fld>(Med.)</fld> <def>Any discharge of blood from the blood
vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The blood circulates in a system of closed tubes, the
rupture of which gives rise to hemorrhage.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemorrhagic</ent><br/
<hw>Hem`or*rhag"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>a"imorragiko`s</grk>: cf. F.
<ets>h<eacute/morrhagique</ets>.]</ety> <def>Pertaining or tending to a
flux of blood; consisting in, or accompanied by, hemorrhage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemorrhoidal</ent><br/
<hw>Hem`or*rhoid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>h<eacute/morro<ium/dal</ets>,
<ets>h<eacute/morrho<ium/dal</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to, or of the nature of, hemorrhoids.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Of or pertaining to the rectum;
rectal; <as>as, the <ex>hemorrhoidal</ex> arteries, veins, and
nerves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemorrhoids</ent><br/
<hw>Hem"or*rhoids</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>haemorrhoidae</ets>, pl., Gr. <?/, sing., <?/ (sc. <?/), pl., veins
liable to discharge blood, hemorrhoids, fr. <?/ flowing with blood;
<grk>a"i^ma</grk> blood + <?/ to flow: cf. F.
<ets>h<eacute/morro<ium/des</ets>, <ets>h<eacute/morrho<ium/des</ets>.
See <er>Rheum</er>.]</ety> <fld>(Med.)</fld> <def>Livid and painful
swellings formed by the dilation of the blood vessels around the margin
of, or within, the anus, from which blood or mucus is occasionally
discharged; piles; emerods.</def> <usage>[The sing.
<singw>hemorrhoid</singw> is rarely used.]</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>hemosiderin</ent><br/
<hw>hemosiderin</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>a granular
yellowish-brown substance composed of protein and ferric oxide,
resulting from the breakdown of hemoglobin; it has a higher iron content
than ferritin, and its presence in body tissues or phagocytes can be a
symptom of disturbed iron metabolism.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>hemosiderosis</ent><br/
<hw>hemosiderosis</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>The
accumulation of abnormal amounts of hemosiderin in the tisssues. Several
causes have been recognized.</def> <au>Stedman.</au><br/
[<source>PJC</source>]</p>

<p><ent>hemostat</ent><br/
<hw>hemostat</hw> <pos>n.</pos> <def>a surgical instrument that stops
bleeding by clamping the blood vessel.</def><br/
<syn><b>Syn. --</b> haemostat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hemostatic</ent><br/
<hw>Hem`o*stat"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hemo-</ets> + Gr. <grk>statiko`s</grk> causing to stand, fr.
<?/ to stand.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>Of or relating
to stagnation of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Serving to arrest hemorrhage; styptic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemostatic</ent><br/
<hw>Hem`o*stat"ic</hw>, <pos>n.</pos> <def>A medicine or application to
arrest hemorrhage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemothorax</ent><br/
<hw>Hem`o*tho"rax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hemo-</er>, and <er>Thorax</er>.]</ety> <fld>(Med.)</fld> <def>An
effusion of blood into the cavity of the pleura.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemp</ent><br/
<hw>Hemp</hw> <pr>(h<ecr/mp)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hemp</ets>, AS. <ets>henep</ets>, <ets>h<ae/nep</ets>; akin to D.
<ets>hennep</ets>, OHG. <ets>hanaf</ets>, G. <ets>hanf</ets>, Icel.
<ets>hampr</ets>, Dan. <ets>hamp</ets>, Sw. <ets>hampa</ets>, L.
<ets>cannabis</ets>, <ets>cannabum</ets>, Gr. <grk>ka`nnabis</grk>,
<grk>ka`nnabos</grk>; cf. Russ. <ets>konoplia</ets>, Skr.
<ets><cced/a<nsdot/a</ets>; all prob. borrowed from some other language
at an early time. Cf. <er>Cannabine</er>, <er>Canvas</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Cannabis</gen> (<spn>Cannabis sativa</spn>), the fibrous skin or
bark of which is used for making cloth and cordage. The name is also
applied to various other plants yielding fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fiber of the skin or rind of the plant, prepared
for spinning. The name has also been extended to various fibers
resembling the true hemp.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>African hemp</b></col>, <col><b>Bowstring
hemp</b></col></mcol>. <cd>See under <er>African</er>, and
<er>Bowstring</er>.</cd> -- <col><b>Bastard hemp</b></col>, <cd>the
Asiatic herb <spn>Datisca cannabina</spn>.</cd> -- <col><b>Canada
hemp</b></col>, <cd>a species of dogbane (<spn>Apocynum
cannabinum</spn>), the fiber of which was used by the Indians.</cd> --
<col><b>Hemp agrimony</b></col>, <cd>a coarse, composite herb of Europe
(<spn>Eupatorium cannabinum</spn>), much like the American boneset.</cd>
-- <col><b>Hemp nettle</b></col>, <cd>a plant of the genus
<gen>Galeopsis</gen> (<spn>Galeopsis Tetrahit</spn>), belonging to the
Mint family.</cd> -- <col><b>Indian hemp</b></col>. <cd>See under
<er>Indian</er>, <pos>a.</pos></cd> -- <col><b>Manila hemp</b></col>,
<cd>the fiber of <spn>Musa textilis</spn>.</cd> -- <col><b>Sisal
hemp</b></col>, <cd>the fiber of <spn>Agave sisalana</spn>, of Mexico
and Yucatan.</cd> -- <col><b>Sunn hemp</b></col>, <cd>a fiber obtained
from a leguminous plant (<spn>Crotalaria juncea</spn>).</cd> --
<col><b>Water hemp</b></col>, <cd>an annual American weed (<spn>Acnida
cannabina</spn>), related to the amaranth.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hempen</ent><br/
<hw>Hemp"en</hw> <pr>(-'n)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Made of
hemp; <as>as, a <ex>hempen</ex> cord</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like hemp.</def> <ldquo/Beat into a
<xex>hempen</xex> state.<rdquo/ <rj><au>Cook.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hempy</ent><br/
<hw>Hemp"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like hemp.</def>
<mark>[R.]</mark> <rj><au>Howell.</au></rj></p>

<p><ent>Hemselven</ent><br/
<ent>Hemselve</ent><br/
<ent>Hemself</ent><br/
<mhw><hw>Hem*self"</hw> <pr>(?)</pr>, <hw>Hem*selve"</hw>
<pr>(<?/)</pr></mhw>, <hw>Hem*selv"en</hw> <pr>(<?/)</pr>, <pos>pron.
pl.</pos> <ety>[See <er>Hem</er>, <pos>pron.</pos>]</ety>
<def>Themselves; -- used reflexively.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemstitch</ent><br/
<hw>Hem"stitch</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hemstitched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hemstitching</conjf>.]</vmorph> <ety>[<ets>Hem</ets> +
<ets>stitch</ets>.]</ety> <def>To ornament at the head of a broad hem by
drawing out a few parallel threads, and fastening the cross threads in
successive small clusters; <as>as, to <ex>hemstitch</ex> a
handkerchief</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemstitched</ent><br/
<hw>Hem"stitched</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a broad
hem separated from the body of the article by a line of open work;
<as>as, a <ex>hemistitched</ex> handkerchief</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hemuse</ent><br/
<hw>He"muse</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
roebuck in its third year.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hen</ent><br/
<hw>Hen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>henn</ets>,
<ets>hen</ets>, <ets>h<ae/n</ets>; akin to D. <ets>hen</ets>, OHG.
<ets>henna</ets>, G. <ets>henne</ets>, Icel. <ets>h<?/na</ets>, Dan.
<ets>h<oum/na</ets>; the fem. corresponding to AS. <ets>hana</ets> cock,
D. <ets>haan</ets>, OHG. <ets>hano</ets>, G. <ets>hahn</ets>, Icel.
<ets>hani</ets>, Dan. & Sw. <ets>hane</ets>. Prob. akin to L.
<ets>canere</ets> to sing, and orig. meaning, a singer. Cf.
<er>Chanticleer</er>.]</ety> <fld>(Zool.)</fld> <def>The female of the
domestic fowl; also, the female of grouse, pheasants, or any kind of
birds; <as>as, the heath <ex>hen</ex>; the gray
<ex>hen</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Used adjectively or in combination to indicate the
female; as, <xex>hen</xex> canary, <xex>hen</xex> eagle, <xex>hen</xex>
turkey, pea<xex>hen</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hen clam</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A
clam of the <gen>Mactra</gen>, and allied genera; the sea clam or surf
clam. See <er>Surf clam</er>.</cd> <sd>(b)</sd> <cd>A California clam of
the genus <gen>Pachydesma</gen>.</cd> -- <col><b>Hen driver</b></col>.
<cd>See <cref>Hen harrier</cref> (below).</cd> -- <col><b>Hen
harrier</b></col> <fld>(Zool.)</fld>, <cd>a hawk (<spn>Circus
cyaneus</spn>), found in Europe and America; -- called also
<altname>dove hawk</altname>, <altname>henharm</altname>,
<altname>henharrow</altname>, <altname>hen driver</altname>, and
usually, in America, <altname>marsh hawk</altname>. See <er>Marsh
hawk</er>.</cd> -- <col><b>Hen hawk</b></col> <fld>(Zool.)</fld>,
<cd>one of several species of large hawks which capture hens; esp., the
American red-tailed hawk (<spn>Buteo borealis</spn>), the red-shouldered
hawk (<spn>Buteo lineatus</spn>), and the goshawk.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henbane</ent><br/
<hw>Hen"bane`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hen</ets> +
<ets>bane</ets>.]</ety> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Hyoscyamus</gen> (<spn>Hyoscyamus niger</spn>). All parts of the
plant are poisonous, and the leaves are used for the same purposes as
belladonna. It is poisonous to domestic fowls; whence the name. Called
also, <altname>stinking nightshade</altname>, from the fetid odor of the
plant. See <er>Hyoscyamus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henbit</ent><br/
<hw>Hen"bit`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
weed of the genus <gen>Lamium</gen> (<spn>Lamium amplexicaule</spn>)
with deeply crenate leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hence</ent><br/
<hw>Hence</hw> <pr>(h<ecr/ns)</pr>, <pos>adv.</pos> <ety>[OE.
<ets>hennes</ets>, <ets>hens</ets> (the <it>s</it> is prop. a genitive
ending; cf. <er>-wards</er>), also <ets>hen</ets>, <ets>henne</ets>,
<ets>hennen</ets>, <ets>heonnen</ets>, <ets>heonene</ets>, AS.
<ets>heonan</ets>, <ets>heonon</ets>, <ets>heona</ets>, <ets>hine</ets>;
akin to OHG. <ets>hinn<amac/n</ets>, G. <ets>hinnen</ets>, OHG.
<ets>hina</ets>, G. <ets>hin</ets>; all from the root of E.
<ets>he</ets>. See <er>He</er>.]</ety> <sn>1.</sn> <def>From this place;
away.</def> <ldquo/Or that we <xex>hence</xex> wend.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Arise, let us go <qex>hence</qex>.</q> <rj><qau>John xiv.
31.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will send thee far <qex>hence</qex> unto the Gentiles.</q>
<rj><qau>Acts xxii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>From this time; in the future; <as>as, a week
<ex>hence</ex></as>.</def> <ldquo/Half an hour <xex>hence</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 686 --></p>

<p><sn>3.</sn> <def>From this reason; therefore; -- as an inference or
deduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hence</qex>, perhaps, it is, that Solomon calls the fear of
the Lord the beginning of wisdom.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>From this source or origin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All other faces borrowed <qex>hence</qex><br/
Their light and grace.</q> <rj><qau>Suckling.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whence come wars and fightings among you? Come they not
<qex>hence</qex>, even of your lusts?</q> <rj><qau>James. iv.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hence</xex> is used, elliptically and imperatively,
for <xex>go hence</xex>; <xex>depart hence</xex>; <xex>away</xex>;
<xex>be gone</xex>. <ldquo/<xex>Hence</xex> with your little
ones.<rdquo/ <au>Shak.</au> -- <xex>From hence</xex>, though a pleonasm,
is fully authorized by the usage of good writers.</note><-- raus!
--><br/
[<source>1913 Webster</source>]</p>

<p><q>An ancient author prophesied <qex>from hence</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Expelled <qex>from hence</qex> into a world<br/
Of woe and sorrow.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hence</ent><br/
<hw>Hence</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To send away.</def>
<mark>[Obs.]</mark> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henceforth</ent><br/
<hw>Hence`forth"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>From this time
forward; henceforward.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I never from thy side <qex>henceforth</qex> to stray.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henceforward</ent><br/
<hw>Hence`for"ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>From this
time forward; from now into the indefinite future; henceforth.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Henchboy</ent><br/
<hw>Hench"boy`</hw> <pr>(h<ecr/nch"boi`)</pr>, <pos>n.</pos> <def>A
page; a servant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henchman</ent><br/
<hw>Hench"man</hw> <pr>(h<ecr/nch"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-men</plw> <pr>(-m<eit/n)</pr>.</plu> <ety>[OE.
<ets>hencheman</ets>, <ets>henxman</ets>; prob. fr. OE. & AS.
<ets>hengest</ets> horse + E. <ets>man</ets>, and meaning, a groom. AS.
<ets>hengest</ets> is akin to D. & G. <ets>hengst</ets> stallion, OHG.
<ets>hengist</ets> horse, gelding.]</ety> <def>An attendant; a servant;
a follower. Now chiefly used as a political cant term.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hencoop</ent><br/
<hw>Hen"coop`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coop or cage for
hens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hende</ent><br/
<hw>Hende</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE., near, handy, kind,
fr. AS. <ets>gehende</ets> near, fr. <ets>hand</ets> hand. See
<er>Handy</er>.]</ety> <sn>1.</sn> <def>Skillful; dexterous;
clever.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Friendly; civil; gentle; kind.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendecagon</ent><br/
<hw>Hen*dec"a*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ eleven
+ <?/ angle: cf. F. <ets>hend<eacute/cagone</ets>.]</ety>
<fld>(Geom.)</fld> <def>A plane figure of eleven sides and eleven
angles.</def> <altsp>[Written also <asp>endecagon</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendecane</ent><br/
<hw>Hen"de*cane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"e`ndeka</grk> eleven.]</ety> <fld>(Chem.)</fld> <def>A
hydrocarbon, <chform>C11H24</chform>, of the paraffin series; -- so
called because it has eleven atoms of carbon in each molecule. Called
also <altname>endecane</altname>, <altname>undecane</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendecasyllabic</ent><br/
<hw>Hen*dec`a*syl*lab"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Pertaining to a line of eleven syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendecasyllable</ent><br/
<hw>Hen*dec"a*syl`la*ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hendecasyllabus</ets>, Gr. <?/ eleven-syllabled; <?/ eleven + <?/
syllable: cf. F. <ets>hend<eacute/casyllabe</ets>.]</ety> <def>A
metrical line of eleven syllables.</def> <rj><au>J.
Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendecatoic</ent><br/
<hw>Hen*dec`a*to"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Hendecane</er>.]</ety> <fld>(Chem.)</fld> <def>Undecylic; pertaining
to, or derived from, hendecane; <as>as, <ex>hendecatoic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendiadys</ent><br/
<hw>Hen*di"a*dys</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
<?/ <?/ one by two.]</ety> <fld>(Gram.)</fld> <def>A figure in which the
idea is expressed by two nouns connected by <xex>and</xex>, instead of
by a noun and limiting adjective; <as>as, we drink from <ex>cups and
gold</ex>, for <ex>golden cups</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hendy</ent><br/
<hw>Hen"dy</hw> <pr>(?)</pr>, <pos>a.</pos> <mark>[Obs.]</mark> <def>See
<er>Hende</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henen</ent><br/
<hw>Hen"en</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Hence.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henfish</ent><br/
<hw>Hen"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A marine fish; the sea bream.</def> <sd>(b)</sd>
<def>A young bib. See <er>Bib</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heng</ent><br/
<hw>Heng</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>imp.</pos> <mord>of
<er>Hang</er></mord>. <def>Hung.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hen-hearted</ent><br/
<hw>Hen"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cowardly; timid;
chicken-hearted.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henhouse</ent><br/
<hw>Hen"house`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Henhouses</plw>.</plu> <def>A house or shelter for fowls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henhussy</ent><br/
<hw>Hen"hus`sy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cotquean; a man
who intermeddles with women's concerns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heniquen</ent><br/
<hw>He*ni"quen</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Jeniquen</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henna</ent><br/
<hw>Hen"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>hinn<amac/</ets> alcanna (<spn>Lawsonia inermis</spn> syn.
<spn>Lawsonia alba</spn>). Cf. <er>Alcanna</er>, <er>Alkanet</er>,
<er>Orchanet</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>A thorny tree or shrub of the
genus <gen>Lawsonia</gen> (<spn>Lawsonia alba</spn>). The fragrant white
blossoms are used by the Buddhists in religious ceremonies. The powdered
leaves furnish a red coloring matter used in the East to stain the nails
and fingers, the manes of horses, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>The leaves of the henna plant, or
a preparation or dyestuff made from them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hennery</ent><br/
<hw>Hen"ner*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An inclosed place
for keeping hens.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hennes</ent><br/
<hw>Hen"nes</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Hence.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hennotannic</ent><br/
<hw>Hen`no*tan"nic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Henna</ets> + <ets>tannic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a brown resinous substance
resembling tannin, and extracted from the henna plant; <as>as,
<ex>hennotannic</ex> acid</as>.</def></p>

<p><ent>Henogenesis</ent><br/
<ent>Henoge ny</ent><br/
<mhw>{ <hw>He*nog"e* ny</hw> <pr>(?)</pr>, <hw>Hen`o*gen"e*sis</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <grk>e"i^s</grk>, masc.,
<grk>"e`n</grk>, neut., one + root of <grk>gi`gnesqai</grk> to be
born.]</ety> <fld>(Biol.)</fld> <def>Same as
<er>Ontogeny</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henotheism</ent><br/
<hw>Hen"o*the*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>e"i`s
"eno`s qeou^</grk>, of one god]</ety> <def>The worship of a single,
overarching god without denying the existence of other
deities.</def><br/
[<source>Merriam-Webster</source>]</p>

<p><ent>Henotic</ent><br/
<hw>He*not"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"enwtiko`s</grk>, fr. <grk>"enou^n</grk> to unite, fr.
<grk>e"i^s</grk> one.]</ety> <def>Harmonizing; irenic.</def>
<rj><au>Gladstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hen-peck</ent><br/
<ent>henpeck</ent><br/
<mhw><hw>hen"peck`</hw>, <hw>hen"-peck`</hw></mhw>
<pr>(h<ecr/n"p<ecr/k`)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Henpecked</conjf> <pr>(h<ecr/n"p<ecr/kt`)</pr>; <pos>p.
pr. & vb. n.</pos> <conjf>Henpecking</conjf>.]</vmorph> <def>To bother
persistently with trivial complaints; to subject to petty authority; --
said of a woman who thus treats her male companion, especially of wives
who thus dominate their husbands. Commonly used in the past participle
(often adjectively); <as>as, <ex>henpecked</ex> for years, he finally
left her</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hen-of-the-woods</ent><br/
<hw>hen-of-the-woods</hw> <pos>n.</pos> <def>A large grayish-brown
edible fungus (<spn>Polyporus frondosus</spn>) forming a mass of
overlapping caps at the base of trees that somewhat resembles a
hen.</def><br/
<syn><b>Syn. --</b> hen of the woods, <spn>Polyporus
frondosus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Henrietta cloth</ent><br/
<hw>Hen`ri*et"ta cloth`</hw> <pr>(?)</pr>. <def>A fine wide wooled
fabric much used for women's dresses.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Henroost</ent><br/
<hw>Hen"roost`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place where hens
roost.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henry</ent><br/
<hw>Hen"ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Henrys</plw>.</plu> <ety>[From Joseph <etsep>Henry</etsep>, an
American physicist.]</ety> <def>The unit of electric induction; the
induction in a circuit when the electro-motive force induced in this
circuit is one volt, while the inducing current varies at the rate of
one amp<egrave/re a second.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hen's-foot</ent><br/
<hw>Hen's-foot`</hw> <pr>(<?/)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An umbelliferous plant (<spn>Caucalis daucoides</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hent</ent><br/
<hw>Hent</hw> <pr>(h<ecr/nt)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Hente</conjf>; <pos>p. p.</pos>
<conjf>Hent</conjf>.]</vmorph> <ety>[OE. <ets>hente</ets>,
<ets>henten</ets>, fr. AS. <ets>hentan</ets>, <ets>gehentan</ets>, to
pursue, take, seize; cf. Icel. <ets>henda</ets>, Goth. <ets>hinpan</ets>
(in compos.), and E. <ets>hunt</ets>.]</ety> <def>To seize; to lay hold
on; to catch; to get.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au> <au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This cursed Jew him <qex>hente</qex> and held him fast.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But all that he might of his friendes <qex>hente</qex><br/
On bookes and on learning he it spente.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henware</ent><br/
<hw>Hen"ware`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
coarse, blackish seaweed. See <er>Badderlocks</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Henxman</ent><br/
<hw>Henx"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Henchman.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>henyard</ent><br/
<hw>henyard</hw> <pos>n.</pos> <def>an enclosed yard for keeping
poultry.</def><br/
<syn><b>Syn. --</b> chicken yard, chicken run, fowl run.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hep</ent><br/
<hw>hep</hw> <pr>(h<ecr/p)</pr>, <pos>n.</pos> <def>See <er>Hip</er>,
the fruit of the dog-rose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hep</ent><br/
<hw>hep</hw> <pr>(h<ecr/p)</pr>, <pos>a.</pos> <def>Same as
<er>Hip</er>, <pos>a.</pos>, but older and now less frequently
used.</def><br/
[<source>PJC</source>]</p>

<p><ent>hep</ent><br/
<hw>hep</hw> <pr>(h<ecr/p)</pr>, <pos>interj.</pos> <def>A call used by
drill instructors to count cadence during marching; used identically to
<altname>hut</altname> and <altname>hup</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hepcat</ent><br/
<hw>hep"cat`</hw> <pr>(h<ecr/p"k<acr/t`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who performs jazz music.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A person who is hep or hip; same as
<er>hipster</er>; -- an older term becoming dated and less used.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hepar</ent><br/
\'d8<hw>He"par</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hepar</ets>, <ets>hepatis</ets>, the liver, Gr. <?/.]</ety>
<sn>1.</sn> <fld>(Old Chem.)</fld> <def>Liver of sulphur; a substance of
a liver-brown color, sometimes used in medicine. It is formed by fusing
sulphur with carbonates of the alkalies (esp. potassium), and consists
essentially of alkaline sulphides. Called also <altname>hepar
sulphuris</altname> <pr>(<?/)</pr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any substance resembling hepar proper, in
appearance; specifically, in homeopathy, calcium sulphide, called also
<altname>hepar sulphuris calcareum</altname> (<?/).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hepar antimonii</b></col> <pr>(<?/)</pr> <fld>(Old
Chem.)</fld>, <cd>a substance, of a liver-brown color, obtained by
fusing together antimony sulphide with alkaline sulphides, and
consisting of sulphantimonites of the alkalies; -- called also
<altname>liver of antimony</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatic</ent><br/
<hw>He*pat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hepaticus</ets>, Gr. <?/, fr. <?/ the liver; akin to L.
<ets>jecur</ets>, Skr. <ets>yak<?/t</ets>: cf. F.
<ets>h<eacute/patique</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to
the liver; <as>as, <ex>hepatic</ex> artery; <ex>hepatic</ex>
diseases.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling the liver in color or in form; <as>as,
<ex>hepatic</ex> cinnabar</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Pertaining to, or resembling, the
plants called <class>Hepaticae</class>, or scale mosses and
liverworts.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hepatic duct</b></col> <fld>(Anat.)</fld>, <cd>any
biliary duct; esp., the duct, or one of the ducts, which carries the
bile from the liver to the cystic and common bile ducts. See
<xex>Illust.</xex>, under <er>Digestive</er>.</cd> -- <col><b>Hepatic
gas</b></col> <fld>(Old Chem.)</fld>, <cd>sulphureted hydrogen gas.</cd>
-- <mcol><col><b>Hepatic mercurial ore</b></col>, <it>or</it>
<col><b>Hepatic cinnabar</b></col></mcol>. <cd>See under
<er>Cinnabar</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatica</ent><br/
\'d8<hw>He*pat"i*ca</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hepaticae</plw> <pr>(#)</pr>.</plu> <ety>[NL. See <er>Hepatic</er>.
So called in allusion to the shape of the lobed leaves or
fronds.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>A genus of pretty spring flowers
closely related to Anemone; squirrel cup.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(bot.)</fld> <def>Any plant, usually procumbent and
mosslike, of the cryptogamous class <class>Hepaticae</class>; -- called
also <altname>scale moss</altname> and <altname>liverwort</altname>. See
<er>Hepaticae</er>, in the Supplement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatical</ent><br/
<hw>He*pat"ic*al</hw>, <pos>a.</pos> <def>Hepatic.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatite</ent><br/
<hw>Hep"a*tite</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>hepatitis</ets> an unknown precious stone, Gr. <?/, fr. <?/, <?/,
the liver: cf. F. <ets>h<eacute/patite</ets>.]</ety> <fld>(Min.)</fld>
<def>A variety of barite emitting a fetid odor when rubbed or
heated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatitis</ent><br/
\'d8<hw>Hep`a*ti"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, <?/, liver + <ets>-itis</ets>.]</ety> <fld>(Med.)</fld>
<def>Inflammation of the liver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatization</ent><br/
<hw>Hep`a*ti*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Chem.)</fld> <def>Impregnating with sulphureted hydrogen
gas.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. F. <ets>h<eacute/patisation</ets>.]</ety>
<fld>(Med.)</fld> <def>Conversion into a substance resembling the liver;
a state of the lungs when gorged with effused matter, so that they are
no longer pervious to the air.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatize</ent><br/
<hw>Hep"a*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hepatized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hepatizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Gr. <?/
to be like the liver, to be liver-colored, fr. <?/, <?/, the liver: cf.
E. <ets>hepatite</ets>, and (for sense 2) F.
<ets>h<eacute/patiser</ets>.]</ety> <sn>1.</sn> <def>To impregnate with
sulphureted hydrogen gas, formerly called <xex>hepatic</xex>
gas.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the right . . . were two wells of <qex>hepatized</qex>
water.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To gorge with effused matter, as the
lungs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatocele</ent><br/
<hw>He*pat"o*cele</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/,
the liver + <?/ tumor.]</ety> <fld>(Med.)</fld> <def>Hernia of the
liver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatocystic</ent><br/
<hw>Hep`a*to*cys"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepatic</ets> + <ets>cystic</ets>.]</ety> <fld>(Anat.)</fld>
<def>Of or pertaining to the liver and gall bladder; <as>as, the
<ex>hepatocystic</ex> ducts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatogastric</ent><br/
<hw>Hep`a*to*gas"tric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepatic</ets> + <ets>gastric</ets>.]</ety> <fld>(Anat.)</fld>
<def>See <er>Gastrohepatic</er>.</def></p>

<p><ent>Hepatogenous</ent><br/
<ent>Hepatogenic</ent><br/
<mhw>{ <hw>Hep`a*to*gen"ic</hw> <pr>(?)</pr>, <hw>Hep`a*tog"e*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <grk>"h^par</grk>,
<grk>"h`patos</grk>, the liver + root of <grk>gi`gnesqai</grk> to be
born]</ety> <fld>(Med.)</fld> <def>Arising from the liver; due to a
condition of the liver; <as>as, <ex>hepatogenic</ex>
jaundice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatology</ent><br/
<hw>Hep`a*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"h^par</grk>, <grk>"h`patos</grk>, the liver +
<ets>-logy</ets>.]</ety> <def>The science which treats of the liver; a
treatise on the liver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepato-pancreas</ent><br/
<hw>Hep"a*to-pan"cre*as</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"h^par</grk>, <grk>"h`patos</grk>, the liver + E.
<ets>pancreas</ets>.]</ety> <fld>(Zool.)</fld> <def>A digestive gland in
Crustacea, Mollusca, etc., usually called the liver, but different from
the liver of vertebrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatorenal</ent><br/
<hw>Hep`a*to*re"nal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepat</ets>ic + <ets>renal</ets>.]</ety> <fld>(Anat.)</fld>
<def>Of or pertaining to the liver and kidneys; <as>as, the
<ex>hepatorenal</ex> ligament</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepatoscopy</ent><br/
<hw>Hep`a*tos"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; fr.
<grk>"h^par</grk>, <grk>"h`patos</grk>, the liver + <?/ to view: cf. F.
<ets>h<eacute/patoscopie</ets>.]</ety> <def>Divination by inspecting the
liver of animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heppen</ent><br/
<hw>Hep"pen</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. AS.
<ets>geh<ae/p</ets> fit, Icel. <ets>heppinn</ets> lucky, E.
<ets>happy</ets>.]</ety> <def>Neat; fit; comfortable.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hepper</ent><br/
<hw>Hep"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Zool.)</fld> <def>A young salmon; a
parr.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heppelwhite</ent><br/
<hw>Hep"pel*white</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Furniture)</fld> <def>Designating a light and elegant style
developed in England under George III., chiefly by <org>Messrs. A.
Heppelwhite & Co.</org></def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hepta</ent><br/
<hw>Hep"ta</hw> <pr>(?)</pr>. <ety>[See <er>Seven</er>.]</ety> <def>A
combining form from Gr. <grk>"epta`</grk>, seven.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptachord</ent><br/
<hw>Hep"ta*chord</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"epta`chordos</grk> seven-stringed; <grk>"epta`</grk> seven +
<grk>chordh`</grk> chord: cf. F. <ets>heptacorde</ets>. See
<er>Seven</er>, and <er>Chord</er>.]</ety> <sn>1.</sn> <fld>(Anc.
Mus.)</fld> <sd>(a)</sd> <def>A system of seven sounds.</def>
<sd>(b)</sd> <def>A lyre with seven chords.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anc. Poet.)</fld> <def>A composition sung to the
sound of seven chords or tones.</def> <rj><au>Moore (Encyc. of
Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptad</ent><br/
<hw>Hep"tad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>heptas</ets>
the number seven. Gr. <?/, <?/, fr. <grk>"epta`</grk> seven.]</ety>
<fld>(Chem.)</fld> <def>An atom which has a valence of seven, and which
can be theoretically combined with, substituted for, or replaced by,
<xex>seven</xex> monad atoms or radicals; <as>as, iodine is a
<ex>heptad</ex> in iodic acid</as>. Also used as an adjective.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptade</ent><br/
<hw>Hep"tade</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>heptade</ets>. See <er>Heptad</er>.]</ety> <def>The sum or number
of seven.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptaglot</ent><br/
<hw>Hep"ta*glot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>"epta`</grk> seven + 3, <?/, tongue, language.]</ety> <def>A book
in seven languages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptagon</ent><br/
<hw>Hep"ta*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
sevencornered; <grk>"epta`</grk> seven + <?/ angle: cf. F.
<ets>heptagone</ets>.]</ety> <fld>(Geom.)</fld> <def>A plane figure
consisting of seven sides and having seven angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptagonal</ent><br/
<hw>Hep*tag"o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>heptagonal</ets>.]</ety> <def>Having seven angles or
sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heptagonal numbers</b></col> <fld>(Arith.)</fld>, <cd>the
numbers of the series 1, 7, 18, 34, 55, etc., being figurate numbers
formed by adding successively the terms of the arithmetical series 1, 6,
11, 16, 21, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptagynia</ent><br/
\'d8<hw>Hep`ta*gyn"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"epta`</grk> seven + <?/ woman, female: cf. F.
<ets>heptagunie</ets>.]</ety> <fld>(Bot.)</fld> <def>A Linnaean order of
plants having seven pistils.</def></p>

<p><ent>Heptagynous</ent><br/
<ent>Heptagynian</ent><br/
<mhw>{ <hw>Hep`ta*gyn"i*an</hw> <pr>(?)</pr>, <hw>Hep*tag"y*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>heptagyne</ets>.]</ety> <fld>(Bot.)</fld> <def>Having seven
pistils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptahedron</ent><br/
<hw>Hep`ta*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hepta-</ets> + Gr. <?/ seat, base, fr. <?/ to sit: cf. F.
<ets>hepta<egrave/dre</ets>.]</ety> <fld>(Geom.)</fld> <def>A solid
figure with seven sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptamerous</ent><br/
<hw>Hep*tam"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepta-</ets> + Gr. <?/ part.]</ety> <fld>(Bot.)</fld>
<def>Consisting of seven parts, or having the parts in sets of
sevens.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptandria</ent><br/
\'d8<hw>Hep*tan"dri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"epta`</grk> seven + <?/, <?/, man, male: cf. F.
<ets>heptandrie</ets>.]</ety> <fld>(Bot.)</fld> <def>A Linnaean class of
plants having seven stamens.</def></p>

<p><ent>Heptandrous</ent><br/
<ent>Heptandrian</ent><br/
<mhw>{ <hw>Hep*tan"dri*an</hw> <pr>(?)</pr>, <hw>Hep*tan"drous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>heptandre</ets>.]</ety> <fld>(Bot.)</fld> <def>Having seven
stamens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptane</ent><br/
<hw>Hep"tane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"epta`</grk> seven.]</ety> <fld>(Chem.)</fld> <def>Any one of
several isometric hydrocarbons, <chform>C7H16</chform>, of the paraffin
series (nine are possible, four are known); -- so called because the
molecule has <xex>seven</xex> carbon atoms. Specifically, a colorless
liquid, found as a constituent of petroleum, in the tar oil of cannel
coal, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptangular</ent><br/
<hw>Hep*tan"gu*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepta-</ets> + <ets>angular</ets>: cf. F.
<ets>heptangulaire</ets>. Cf. <er>Septangular</er>.]</ety> <def>Having
seven angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptaphyllous</ent><br/
<hw>Hep*taph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepta-</ets> + Gr. <?/ leaf: cf. F.
<ets>heptaphylle</ets>.]</ety> <fld>(Bot.)</fld> <def>Having seven
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptarch</ent><br/
<hw>Hep"tarch</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Heptarchist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptarchic</ent><br/
<hw>Hep*tar"chic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>heptarchique</ets>.]</ety> <def>Of or pertaining to a heptarchy;
constituting or consisting of a heptarchy.</def> <rj><au>T.
Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptarchist</ent><br/
<hw>Hep"tarch*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ruler of one
division of a heptarchy.</def> <altsp>[Written also
<asp>heptarch</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptarchy</ent><br/
<hw>Hep"tarch*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hepta-</ets>
+ <ets>-archy</ets>: cf. F. <ets>heptarchie</ets>.]</ety> <def>A
government by seven persons; also, a country under seven
rulers.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is most commonly applied to England, when it
was divided into seven kingdoms; as, the Saxon <xex>heptachy</xex>,
which consisted of Kent, the South Saxons (Sussex), West Saxons
(Wessex), East Saxons (Essex), the East Angles, Mercia, and
Northumberland.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptaspermous</ent><br/
<hw>Hep`ta*sper"mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepta-</ets> + Gr. <?/ a seed.]</ety> <fld>(Bot.)</fld>
<def>Having seven seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptastich</ent><br/
<hw>Hep"ta*stich</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hepta-</ets> + Gr. <grk>sti`chos</grk> line, verse.]</ety>
<fld>(Pros.)</fld> <def>A composition consisting of seven lines or
verses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptateuch</ent><br/
<hw>Hep"ta*teuch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>heptateuchos</ets>, Gr. <grk>"epta`</grk> seven + <?/ tool, book;
<?/ to prepare, make, work: cf. F. <ets>heptateuque</ets>.]</ety>
<def>The first seven books of the Testament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptavalent</ent><br/
<hw>Hep*tav"a*lent</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hepta-</ets> + L. <ets>valens</ets>, p. pr. See
<er>Valence</er>.]</ety> <fld>(Chem.)</fld> <def>Having seven units of
attractive force or affinity; -- said of <xex>heptad</xex> elements or
radicals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptene</ent><br/
<hw>Hep"tene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"epta`</grk> seven.]</ety> <fld>(Chem.)</fld> <def>Same as
<er>Heptylene</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptine</ent><br/
<hw>Hep"tine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hept</ets>ane +
<ets>-ine</ets>.]</ety> <fld>(Chem.)</fld> <def>Any one of a series of
unsaturated metameric hydrocarbons, <chform>C7H12</chform>, of the
acetylene series.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptoic</ent><br/
<hw>Hep*to"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, heptane; <as>as, <ex>heptoic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptone</ent><br/
<hw>Hep"tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"epta`</grk> seven.]</ety> <fld>(Chem.)</fld> <def>A liquid
hydrocarbon, <chform>C7H10</chform>, of the valylene series.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hep tree</ent><br/
<hw>Hep" tree`</hw> <pr>(?)</pr>. <ety>[See <er>Hep</er>.]</ety>
<def>The wild dog-rose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptyl</ent><br/
<hw>Hep"tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hepta-</ets> +
<ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A compound radical,
<chform>C7H15</chform>, regarded as the essential radical of heptane and
a related series of compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptylene</ent><br/
<hw>Hep"tyl*ene</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A colorless liquid hydrocarbon, <chform>C7H14</chform>, of the
ethylene series; also, any one of its isomers. Called also
<altname>heptene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heptylic</ent><br/
<hw>Hep*tyl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, heptyl or heptane; <as>as,
<ex>heptylic</ex> alcohol</as>. Cf. <er><OE/nanthylic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Her</ent><br/
<hw>Her</hw> <pr>(?)</pr>, <pos>pron. & a.</pos> <ety>[OE.
<ets>hire</ets>, <ets>here</ets>, <ets>hir</ets>, <ets>hure</ets>, gen.
and dat. sing., AS. <ets>hire</ets>, gen. and dat. sing. of
<ets>h<eacute/o</ets> she. from the same root as E. <ets>he</ets>. See
<er>He</er>.]</ety> <def>The form of the objective and the possessive
case of the personal pronoun <xex>she</xex>; <as>as, I saw <ex>her</ex>
with <ex>her</ex> purse out</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The possessive <xex>her</xex> takes the form
<xex>hers</xex> when the noun with which in agrees is not given, but
implied. <ldquo/And what his fortune wanted, <xex>hers</xex> could
mend.<rdquo/</note> <rj><au>Dryden.</au></rj></p>

<p><ent>Here</ent><br/
<ent>Her</ent><br/
<mhw><hw>Her</hw>, <hw>Here</hw> <pr>(<?/)</pr></mhw>, <pos>pron.
pl.</pos> <ety>[OE. <ets>here</ets>, <ets>hire</ets>, AS.
<ets>heora</ets>, <ets>hyra</ets>, gen. pl. of <ets>h<emac/</ets>. See
<er>He</er>.]</ety> <def>Of them; their.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On <qex>here</qex> bare knees adown they fall.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heracleonite</ent><br/
<hw>He*rac"le*on*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>A follower of Heracleon of Alexandria, a Judaizing
Gnostic, in the early history of the Christian church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herakline</ent><br/
<hw>He*rak"line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
Hercules.]</ety> <def>A picrate compound, used as an explosive in
blasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herald</ent><br/
<hw>Her"ald</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>herald</ets>, <ets>heraud</ets>, OF. <ets>heralt</ets>,
<ets>heraut</ets>, <ets>herault</ets>, F. <ets>h<eacute/raut</ets>, LL.
<ets>heraldus</ets>, <ets>haraldus</ets>, fr. (assumed) OHG.
<ets>heriwalto</ets>, <ets>hariwaldo</ets>, a (civil) officer who serves
the army; <ets>hari</ets>, <ets>heri</ets>, army + <ets>waltan</ets> to
manage, govern, G. <ets>walten</ets>; akin to E. <ets>wield</ets>. See
<er>Harry</er>, <er>Wield</er>.]</ety> <sn>1.</sn> <fld>(Antiq.)</fld>
<def>An officer whose business was to denounce or proclaim war, to
challenge to battle, to proclaim peace, and to bear messages from the
commander of an army. He was invested with a sacred and inviolable
character.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 687 --></p>

<p><sn>2.</sn> <def>In the Middle Ages, the officer charged with the
above duties, and also with the care of genealogies, of the rights and
privileges of noble families, and especially of armorial bearings. In
modern times, some vestiges of this office remain, especially in
England. See <cref>Heralds' College</cref> (below), and
<er>King-at-Arms</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A proclaimer; one who, or that which, publishes or
announces; <as>as, the <ex>herald</ex> of another's fame</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A forerunner; a a precursor; a harbinger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was the lark, the <qex>herald</qex> of the morn.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Any messenger.</def> <ldquo/My <xex>herald</xex> is
returned.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heralds' College</b></col>, <cd>in England, an ancient
corporation, dependent upon the crown, instituted or perhaps recognized
by Richard III. in 1483, consisting of the three Kings-at-Arms and the
Chester, Lancaster, Richmond, Somerset, Windsor, and York Heralds,
together with the Earl Marshal. This retains from the Middle Ages the
charge of the armorial bearings of persons privileged to bear them, as
well as of genealogies and kindred subjects; -- called also
<altname>College of Arms</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herald</ent><br/
<hw>Her"ald</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Heralded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Heralding</conjf>.]</vmorph> <ety>[Cf. OF. <ets>herauder</ets>,
<ets>heraulder</ets>.]</ety> <def>To introduce, or give tidings of, as
by a herald; to proclaim; to announce; to foretell; to usher in.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>heralded</ent><br/
<hw>heralded</hw> <pos>adj.</pos> <def>widely publicized; <as>as, the
royal couple's much <ex>heralded</ex> world tour</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heraldic</ent><br/
<hw>He*ral"dic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>h<eacute/raldique</ets>.]</ety> <def>Of or pertaining to heralds or
heraldry; <as>as, <ex>heraldic</ex> blazoning; <ex>heraldic</ex>
language.</as></def> <rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heraldically</ent><br/
<hw>He*ral"dic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In an
heraldic manner; according to the rules of heraldry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heraldist</ent><br/
<hw>heraldist</hw> <pos>adj.</pos> <def>of or pertaining to
heraldry.</def><br/
<syn><b>Syn. --</b> heraldic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heraldry</ent><br/
<hw>Her"ald*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The art
or office of a herald; the art, practice, or science of recording
genealogies, and blazoning arms or ensigns armorial; also, of marshaling
cavalcades, processions, and public ceremonies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coat of arms or some other heraldic device or
collection of heraldic symbols.</def><br/
[<source>PJC</source>]</p>

<p><ent>Heraldship</ent><br/
<hw>Her"ald*ship</hw>, <pos>n.</pos> <def>The office of a herald.</def>
<rj><au>Selden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herapathite</ent><br/
<hw>Her"a*path*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after
Dr. <ets>Herapath</ets>, the discoverer.]</ety> <fld>(Chem.)</fld>
<def>The sulphate of iodoquinine, a substance crystallizing in thin
plates remarkable for their effects in polarizing light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heraud</ent><br/
<hw>Her"aud</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A herald.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herb</ent><br/
<hw>Herb</hw> <pr>(<etil/rb <it>or</it> h<etil/rb; 277)</pr>,
<pos>n.</pos> <ety>[OE. <ets>herbe</ets>, <ets>erbe</ets>, OF.
<ets>herbe</ets>, <ets>erbe</ets>, F. <ets>herbe</ets>, L.
<ets>herba</ets>; perh. akin to Gr. <grk>forbh`</grk> food, pasture,
<grk>fe`rbein</grk> to feed.]</ety> <sn>1.</sn> <def>A plant whose stem
does not become woody and permanent, but dies, at least down to the
ground, after flowering.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Annual herbs live but one season; biennial herbs flower
the second season, and then die; perennial herbs produce new stems year
after year.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Grass; herbage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And flocks<br/
Grazing the tender <qex>herb</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Herb bennet</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Bennet</er>.</cd> -- <col><b>Herb Christopher</b></col>
<fld>(Bot.)</fld>, <cd>an herb (<spn>Actaea spicata</spn>), whose root
is used in nervous diseases; the baneberry. The name is occasionally
given to other plants, as the royal fern, the wood betony, etc.</cd> --
<col><b>Herb Gerard</b></col> <fld>(Bot.)</fld>, <cd>the goutweed; -- so
called in honor of St. <etsep>Gerard</etsep>, who used to be invoked
against the gout.</cd> <au>Dr. Prior.</au> -- <mcol><col><b>Herb
grace</b></col>, <it>or</it> <col><b>Herb of grace</b></col></mcol>.
<fld>(Bot.)</fld> <cd>See <er>Rue</er>.</cd> -- <col><b>Herb
Margaret</b></col> <fld>(Bot.)</fld>, <cd>the daisy. See
<er>Marguerite</er>.</cd> -- <col><b>Herb Paris</b></col>
<fld>(Bot.)</fld>, <cd>an Old World plant related to the trillium
(<spn>Paris quadrifolia</spn>), commonly reputed poisonous.</cd> --
<col><b>Herb Robert</b></col> <fld>(Bot.)</fld>, <cd>a species of
<gen>Geranium</gen> (<spn>Geranium Robertianum</spn>.)</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbaceous</ent><br/
<hw>Her*ba"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>herbaceus</ets> grassy. See <er>Herb</er>.]</ety> <def>Of or
pertaining to herbs; having the nature, texture, or characteristics, of
an herb; <as>as, <ex>herbaceous</ex> plants; an <ex>herbaceous</ex>
stem.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbage</ent><br/
<hw>Herb"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[F. See
<er>Herb</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Herbs collectively; green food beasts; grass;
pasture.</def> <ldquo/Thin <xex>herbage</xex> in the plaims.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law.)</fld> <def>The liberty or right of pasture in
the forest or in the grounds of another man.</def>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbaged</ent><br/
<hw>Herb"aged</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered with
grass.</def> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbal</ent><br/
<hw>Herb"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
herbs.</def> <rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbal</ent><br/
<hw>Herb"al</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A book
containing the names and descriptions of plants.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A collection of specimens of plants, dried and
preserved; a hortus siccus; an herbarium.</def>
<rj><au>Steele.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbalism</ent><br/
<hw>Herb"al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The knowledge of
herbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbalist</ent><br/
<hw>Herb"al*ist</hw>, <pos>n.</pos> <def>One skilled in the knowledge of
plants; a collector of, or dealer in, herbs, especially medicinal
herbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbar</ent><br/
<hw>Herb"ar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An herb.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbarian</ent><br/
<hw>Her*ba"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
herbalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbarist</ent><br/
<hw>Herb"a*rist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A herbalist.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbarium</ent><br/
<hw>Her*ba"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Herbariums</plw> <pr>(#)</pr>, L. <plw>Herbaria</plw>
<pr>(#)</pr>.</plu> <ety>[LL., fr. L. <ets>herba</ets>. See
<er>Herb</er>, and cf. <er>Arbor</er>, <er>Herbary</er>.]</ety>
<sn>1.</sn> <def>A collection of dried specimens of plants,
systematically arranged.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A book or case for preserving dried
plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbarize</ent><br/
<hw>Herb"a*rize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Herborize</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbary</ent><br/
<hw>Herb"a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Herbarium</er>.]</ety> <def>A garden of herbs; a cottage
garden.</def> <rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herber</ent><br/
<hw>Herb"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>herbier</ets>, LL. <ets>herbarium</ets>. See
<er>Herbarium</er>.]</ety> <def>A garden; a pleasure garden.</def>
<mark>[Obs.]</mark> <ldquo/Into an <xex>herber</xex> green.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbergage</ent><br/
<hw>Her"berg*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Harborage</er>.]</ety> <def>Harborage; lodging; shelter;
harbor.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbergeour</ent><br/
<hw>Her"ber*geour</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Harbinger</er>.]</ety> <def>A harbinger.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></p>

<p><ent>Herberwe</ent><br/
<ent>Herbergh</ent><br/
<mhw><hw>Her"bergh</hw> <pr>(?)</pr>, <hw>Her"ber*we</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[See <er>Harbor</er>.]</ety>
<def>A harbor.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbescent</ent><br/
<hw>Her*bes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>herbescens</ets>, <ets>p. pr.</ets> of
<ets>herbescere</ets>.]</ety> <def>Growing into herbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbid</ent><br/
<hw>Herb"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>herbidus</ets>.]</ety> <def>Covered with herbs.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbiferous</ent><br/
<hw>Her*bif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Herb</ets> + <ets>-ferous</ets>: cf. F.
<ets>herbif<eacute/re</ets>.]</ety> <def>Bearing herbs or
vegetation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbist</ent><br/
<hw>Herb"ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
herbalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbivora</ent><br/
\'d8<hw>Her*biv"o*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
L. <ets>herba</ets> herb + <ets>vorare</ets> to devour.]</ety>
<fld>(Zool.)</fld> <def>An extensive division of Mammalia. It formerly
included the Proboscidea, Hyracoidea, Perissodactyla, and Artiodactyla,
but by later writers it is generally restricted to the two latter groups
(Ungulata). They feed almost exclusively upon vegetation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbivore</ent><br/
<hw>Her"bi*vore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>herbivore</ets>.]</ety> <fld>(Zool.)</fld> <def>One of the
Herbivora.</def> <rj><au>P. H. Gosse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbivorous</ent><br/
<hw>Her*biv"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Eating plants; of or pertaining to the Herbivora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herbless</ent><br/
<hw>Herb"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of herbs
or of vegetation.</def> <rj><au>J. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herblet</ent><br/
<hw>Herb"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small herb.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herborist</ent><br/
<hw>Her"bo*rist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>herboriste</ets>.]</ety> <def>A herbalist.</def>
<rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herborization</ent><br/
<hw>Her`bo*ri*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>herborisation</ets>.]</ety> <sn>1.</sn> <def>The act of
herborizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The figure of plants in minerals or
fossils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herborize</ent><br/
<hw>Her"bo*rize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Herborized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Herborizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>herboriser</ets>, for <ets>herbariser</ets>, fr. L.
<ets>herbarium</ets>. See <er>Hebrarium</er>.]</ety> <def>To search for
plants, or new species of plants, with a view to classifying
them.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>herborized</qex> as he traveled.</q> <rj><qau>W.
Tooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herborize</ent><br/
<hw>Her"bo*rize</hw>, <pos>v. t.</pos> <def>To form the figures of
plants in; -- said in reference to minerals. See
<er>Arborized</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Herborized</qex> stones contain fine mosses.</q>
<rj><qau>Fourcroy (Trans.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herborough</ent><br/
<hw>Her"bor*ough</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Harborough</er>, and <er>Harbor</er>.]</ety> <def>A harbor.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj></p>

<p><ent>Herbous</ent><br/
<ent>Herbose</ent><br/
<mhw>{ <hw>Her*bose"</hw> <pr>(?)</pr>, <hw>Herb"ous</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>herbosus</ets>: cf. F.
<ets>herbeux</ets>.]</ety> <def>Abounding with herbs.</def>
<ldquo/Fields poetically called <xex>herbose</xex>.<rdquo/
<rj><au>Byrom.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herb-woman</ent><br/
<hw>Herb"-wom`an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Herb-women</plw> <pr>(<?/)</pr>.</plu> <def>A woman that sells
herbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herby</ent><br/
<hw>Herb"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the nature of,
pertaining to, or covered with, herbs or herbage.</def>
<ldquo/<xex>Herby</xex> valleys.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hercogamous</ent><br/
<hw>Her*cog"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ a
fence + <?/ marriage.]</ety> <fld>(Bot.)</fld> <def>Not capable of
self-fertilization; -- said of hermaphrodite flowers in which some
structural obstacle forbids autogamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herculean</ent><br/
<hw>Her*cu"le*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>herculeus</ets>, fr. <ets>Hercules</ets>: cf. F.
<ets>hercul<eacute/en</ets>. See <er>Hercules</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Requiring the strength of Hercules; hence, very
great, difficult, or dangerous; <as>as, an <ex>Herculean</ex>
task</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having extraordinary strength or size; <as>as,
<ex>Herculean</ex> limbs</as>.</def> <ldquo/<xex>Herculean</xex>
Samson.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hercules</ent><br/
<hw>Her"cu*les</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <fld>(Gr.
Myth.)</fld> <def>A hero, fabled to have been the son of Jupiter and
Alcmena, and celebrated for great strength, esp. for the accomplishment
of his twelve great tasks or <ldquo/labors.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>A constellation in the northern
hemisphere, near Lyra.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hercules' beetle</b></col> <fld>(Zool.)</fld>, <cd>any
species of <gen>Dynastes</gen>, an American genus of very large
lamellicorn beetles, esp. <spn>Dynastes hercules</spn> of South America,
which grows to a length of six inches.</cd> -- <col><b>Hercules
powder</b></col>, <cd>an explosive containing nitroglycerin; -- used for
blasting.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hercules-club</ent><br/
<ent>Hercules'-club</ent><br/
<ent>Hercules'-club</ent><br/
<mhw><hw>Hercules'-club</hw>, <hw>Hercules'-club</hw>,
<hw>Hercules-club</hw></mhw> <pos>prop. n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A densely spiny ornamental tree (<spn>Zanthoxylum
clava-herculis</spn>) of the rue family, growing in southeast U. S. and
West Indies.</def> <wns>[wns=1]</wns> <note>It belongs to the same genus
as one of the trees (<spn>Zanthoxylum Americanum</spn>) called
<er>prickly ash</er>.</note><br/
<syn><b>Syn. --</b> Hercules'-clubs, Hercules-club, <spn>Zanthoxylum
clava-herculis</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A small, prickly, deciduous clump-forming tree or
shrub (<spn>Aralia spinosa</spn>) of eastern U.S.; also called
<altname>Angelica tree</altname> and <altname>prickly
ash</altname>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> American angelica tree, devil's walking stick,
<spn>Aralia spinosa</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>A variety of the common gourd (<spn>Lagenaria
vulgaris</spn>). Its fruit sometimes exceeds five feet in
length.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hercynian</ent><br/
<hw>Her*cyn"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Hercynia</ets> silva, <ets>Hercynius</ets> saltus, the Hercynian
forest; cf. Gr. <?/ <?/.]</ety> <def>Of or pertaining to an extensive
forest in Germany, of which there are still portions in Swabia and the
Hartz mountains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herd</ent><br/
<hw>Herd</hw> <pr>(h<etil/rd)</pr>, <pos>a.</pos> <def>Haired.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herd</ent><br/
<hw>Herd</hw> <pr>(h<etil/rd)</pr>, <pos>n.</pos> <ety>[OE.
<ets>herd</ets>, <ets>heord</ets>, AS. <ets>heord</ets>; akin to OHG.
<ets>herta</ets>, G. <ets>herde</ets>, Icel. <ets>hj<oum/r<edh/</ets>,
Sw. <ets>hjord</ets>, Dan. <ets>hiord</ets>, Goth.
<ets>ha<iacute/rda</ets>; cf. Skr. <ets><cced/ardha</ets> troop,
host.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A number of beasts assembled together; <as>as, a
<ex>herd</ex> of horses, oxen, cattle, camels, elephants, deer, or
swine</as>; a particular stock or family of cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lowing <qex>herd</qex> wind slowly o'er the lea.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Herd</xex> is distinguished from <xex>flock</xex>,
as being chiefly applied to the larger animals. A number of cattle, when
driven to market, is called a <xex>drove</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A crowd of low people; a rabble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But far more numerous was the <qex>herd</qex> of such<br/
Who think too little and who talk too much.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You can never interest the common <qex>herd</qex> in the abstract
question.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Herd's grass</b></col> <fld>(Bot.)</fld>, <cd>one of
several species of grass, highly esteemed for hay. See under
<er>Grass</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herd</ent><br/
<hw>Herd</hw>, <pos>n.</pos> <ety>[OE. <ets>hirde</ets>,
<ets>herde</ets>, <ets>heorde</ets>, AS. <ets>hirde</ets>,
<ets>hyrde</ets>, <ets>heorde</ets>; akin to G. <ets>hirt</ets>,
<ets>hirte</ets>, OHG. <ets>hirti</ets>, Icel.
<ets>hir</ets><?/<ets>ir</ets>, Sw. <ets>herde</ets>, Dan.
<ets>hyrde</ets>, Goth. <ets>ha<iacute/rdeis</ets>. See 2d
<er>Herd</er>.]</ety> <def>One who herds or assembles domestic animals;
a herdsman; -- much used in composition; <as>as, a shep<ex>herd</ex>; a
goat<ex>herd</ex>, and the like.</as></def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herd</ent><br/
<hw>Herd</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Herded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Herding</conjf>.]</vmorph> <ety>[See 2d <er>Herd</er>.]</ety>
<sn>1.</sn> <def>To unite or associate in a herd; to feed or run
together, or in company; <as>as, sheep <ex>herd</ex> on many
hills</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To associate; to ally one's self with, or place
one's self among, a group or company.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll <qex>herd</qex> among his friends, and seem<br/
One of the number.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To act as a herdsman or a shepherd.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herd</ent><br/
<hw>Herd</hw>, <pos>v. t.</pos> <def>To form or put into a
herd.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herdbook</ent><br/
<hw>Herd"book`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A book containing
the list and pedigrees of one or more herds of choice breeds of cattle;
-- also called <altname>herd record</altname>, or <altname>herd
register</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herder</ent><br/
<hw>Herd"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A herdsman.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herderite</ent><br/
<hw>Her"der*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after Baron
von <ets>Herder</ets>, who discovered it.]</ety> <fld>(Min.)</fld>
<def>A rare fluophosphate of glucina, in small white crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herdess</ent><br/
<hw>Herd"ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A shepherdess; a
female herder.</def> <rj><au>Sir P. Sidney.</au>
<au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herdgroom</ent><br/
<hw>Herd"groom`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A herdsman.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herdic</ent><br/
<hw>Her"dic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named from Peter
<ets>Herdic</ets>, the inventor.]</ety> <def>A kind of low-hung
cab.</def></p>

<p><ent>Herdsman</ent><br/
<ent>Herdman</ent><br/
<mhw>{ <hw>Herd"man</hw> <pr>(?)</pr>, <hw>Herds"man</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos>; <plu><it>pl.</it> <plw>-men</plw>
<pr>(<?/)</pr>.</plu> <def>The owner or keeper of a herd or of herds;
one employed in tending a herd of cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herdswoman</ent><br/
<hw>Herds"wom`an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
-<plw>women</plw> <pr>(<?/)</pr>.</plu> <def>A woman who tends a
herd.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Here</ent><br/
<hw>Here</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hair.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Here</ent><br/
<hw>Here</hw> <pr>(h<etil/r)</pr>, <pos>pron.</pos> <sn>1.</sn> <def>See
<er>Her</er>, their.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Her; hers. See <er>Her</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Here</ent><br/
<hw>Here</hw> <pr>(h<emac/r)</pr>, <pos>adv.</pos> <ety>[OE.
<ets>her</ets>, AS. <ets>h<emac/r</ets>; akin to OS.
<ets>h<emac/r</ets>, D. <ets>hier</ets>, OHG. <ets>hiar</ets>, G.
<ets>hier</ets>, Icel. & Goth. <ets>h<emac/r</ets>, Dan. <ets>her</ets>,
Sw. <ets>h<aum/r</ets>; fr. root of E. <ets>he</ets>. See
<er>He</er>.]</ety> <sn>1.</sn> <def>In this place; in the place where
the speaker is; -- opposed to <ant>there</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is not <qex>here</qex>, for he is risen.</q> <rj><qau>Matt.
xxviii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In the present life or state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Happy <qex>here</qex>, and more happy hereafter.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To or into this place; hither.
<mark>[Colloq.]</mark> See <er>Thither</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Here</qex> comes Virgil.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou led'st me <qex>here</qex>.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>At this point of time, or of an argument;
now.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The prisoner <qex>here</qex> made violent efforts to rise.</q>
<rj><qau>Warren.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Here</xex>, in the last sense, is sometimes used
before a verb without subject; as, <xex>Here goes</xex>, for Now
(something or somebody) goes; -- especially occurring thus in drinking
healths. <ldquo/<xex>Here's</xex> [a health] to thee,
Dick.<rdquo/</note> <rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Here and there</b></col>, <cd>in one place and another;
in a dispersed manner; irregularly.</cd> <ldquo/Footsteps <xex>here and
there</xex>.<rdquo/ <au>Longfellow.</au> -- <col><b>It is neither, here
nor there</b></col>, <cd>it is neither in this place nor in that,
neither in one place nor in another; hence, it is to no purpose,
irrelevant, nonsense.</cd><-- mostly used to mean "irrelevant" -->
<au>Shak.</au></cs></p>

<p><ent>Hereabouts</ent><br/
<ent>Herea-bout</ent><br/
<mhw>{ <hw>Here"a-bout`</hw> <pr>(?)</pr>, <hw>Here"a*bouts`</hw>
<pr>(?)</pr>, }</mhw> <pos>adv.</pos> <sn>1.</sn> <def>About this place;
in this vicinity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Concerning this.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereafter</ent><br/
<hw>Here*aft"er</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>h<emac/r<ae/fter</ets>.]</ety> <def>In time to come; in some future
time or state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hereafter</qex> he from war shall come.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereafter</ent><br/
<hw>Here*aft"er</hw>, <pos>n.</pos> <def>A future existence or
state.</def> <-- Syn. afterlife, the life to come, future life, eternal
bliss, eternal reward, --><br/
[<source>1913 Webster</source>]</p>

<p><q>'Tis Heaven itself that points out an <qex>hereafter</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereafterward</ent><br/
<hw>Here*aft"er*ward</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Hereafter.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt <qex>hereafterward</qex> . . . come.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Here-at</ent><br/
<hw>Here-at"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>At, or by reason
of, this; <as>as, he was offended <ex>hereat</ex></as>.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereby</ent><br/
<hw>Here*by"</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>By
means of this.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>hereby</qex> we do know that we know him.</q> <rj><qau>1
John ii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Close by; very near.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereditability</ent><br/
<hw>He*red`i*ta*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of
being hereditable.</def> <rj><au>Brydges.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereditable</ent><br/
<hw>He*red"i*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>hereditabilis</ets>, fr. <ets>hereditare</ets> to inherit, fr. L.
<ets>hereditas</ets> heirship inheritance, <ets>heres</ets> heir: cf.
OF. <ets>hereditable</ets>. See <er>Heir</er>, and cf.
<er>Heritable</er>.]</ety> <sn>1.</sn> <def>Capable of being inherited.
See <er>Inheritable</er>.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Qualified to inherit; capable of
inheriting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereditably</ent><br/
<hw>He*red"i*ta*bly</hw>, <pos>adv.</pos> <def>By inheritance.</def>
<rj><au>W. Tooke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereditament</ent><br/
<hw>Her`e*dit"a*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>hereditamentum</ets>. See <er>Hereditable</er>.]</ety>
<fld>(Law)</fld> <def>Any species of property that may be inherited;
lands, tenements, anything corporeal or incorporeal, real, personal, or
mixed, that may descend to an heir.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>corporeal hereditament</xex> is visible and
tangible; an <xex>incorporeal hereditament</xex> is not in itself
visible or tangible, being an hereditary right, interest, or obligation,
as duty to pay rent, or a right of way.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereditarily</ent><br/
<hw>He*red"i*ta*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By
inheritance; in an hereditary manner.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereditary</ent><br/
<hw>He*red"i*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hereditarius</ets>, fr. <ets>hereditas</ets> heirship, inheritance,
fr. <ets>heres</ets> heir: cf. F. <ets>h<eacute/r<eacute/ditaire</ets>.
See <er>Heir</er>.]</ety> <sn>1.</sn> <def>Descended, or capable of
descending, from an ancestor to an heir at law; received or passing by
inheritance, or that must pass by inheritance; <as>as, an
<ex>hereditary</ex> estate or crown</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Transmitted, or capable of being transmitted, as a
constitutional quality or condition from a parent to a child; <as>as,
<ex>hereditary</ex> pride, bravery, disease</as>.</def></p>

<p><syn><b>Syn.</b> -- Ancestral; patrimonial; inheritable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heredity</ent><br/
<hw>He*red"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hereditas</ets> heirship.]</ety> <fld>(Biol.)</fld> <def>Hereditary
transmission of the physical and psychical qualities of parents to their
offspring; the biological law by which living beings tend to repeat
their characteristics in their descendants. See
<er>Pangenesis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereford</ent><br/
<hw>Her"e*ford</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of a breed of
cattle originating in Herefordshire, England. The Herefords are good
working animals, and their beef-producing quality is
excellent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herehence</ent><br/
<hw>Here"hence`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>From
hence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herein</ent><br/
<hw>Here*in"</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>h<?/rinne</ets>.]</ety> <def>In this.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Herein</qex> is my Father glorified, that ye bear much
fruit.</q> <rj><qau>John xv. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereinafter</ent><br/
<hw>Here`in*aft"er</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the
following part of this (writing, document, speech, and the
like).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereinbefore</ent><br/
<hw>Here`in*be*fore"</hw>, <pos>adv.</pos> <def>In the preceding part of
this (writing, document, book, etc.).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereinto</ent><br/
<hw>Here`in*to"</hw> <pr>(?; 277)</pr>, <pos>adv.</pos> <def>Into
this.</def> <rj><au>Hooker.</au></rj></p>

<p><ent>Heremite</ent><br/
<ent>Heremit</ent><br/
<mhw>{ <hw>Her"e*mit</hw> <pr>(?)</pr>, <hw>Her"e*mite</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[See <er>Hermit</er>.]</ety>
<def>A hermit.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heremitical</ent><br/
<hw>Her`e*mit"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to a hermit; solitary; secluded from society.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heren</ent><br/
<hw>Her"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of hair.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereof</ent><br/
<hw>Here*of"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Of this; concerning
this; from this; hence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hereof</qex> comes it that Prince Harry is valiant.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereon</ent><br/
<hw>Here*on"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>On or upon this;
hereupon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereout</ent><br/
<hw>Here*out"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Out of this.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heresiarch</ent><br/
<hw>Her"e*si*arch</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>haeresiarcha</ets>, Gr. <?/; <?/ heresy + <?/ leader, <?/ to lead:
cf. F. <ets>h<eacute/r<eacute/siarque</ets>.]</ety> <def>A leader in
heresy; the chief of a sect of heretics.</def> <rj><au>Bp.
Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heresiarchy</ent><br/
<hw>Her"e*si*arch`y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chief or
great heresy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The book itself [the Alcoran] consists of <qex>heresiarchies</qex>
against our blessed Savior.</q> <rj><qau>Sir T. Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heresiographer</ent><br/
<hw>Her`e*si*og"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Heresiography</er>.]</ety> <def>One who writes on
heresies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heresiography</ent><br/
<hw>Her`e*si*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
heresy + <ets>-graphy</ets>: cf. F.
<ets>h<eacute/r<eacute/siographie</ets>.]</ety> <def>A treatise on
heresy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heresy</ent><br/
<hw>Her"e*sy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Heresies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>heresie</ets>,
<ets>eresie</ets>, OF. <ets>heresie</ets>, <ets>iresie</ets>, F.
<ets>h<eacute/r<eacute/sie</ets>, L. <ets>haeresis</ets>, Gr. <?/ a
taking, a taking for one's self, choosing, a choice, a sect, a heresy,
fr. <?/ to take, choose.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 688 --></p>

<p><sn>1.</sn> <def>An opinion held in opposition to the established or
commonly received doctrine, and tending to promote a division or party,
as in politics, literature, philosophy, etc.; -- usually, but not
necessarily, said in reproach.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>New opinions<br/
Divers and dangerous, which are <qex>heresies</qex>,<br/
And, not reformed, may prove pernicious.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After the study of philosophy began in Greece, and the
philosophers, disagreeing amongst themselves, had started many questions
. . . because every man took what opinion he pleased, each several
opinion was called a <qex>heresy</qex>; which signified no more than a
private opinion, without reference to truth or falsehood.</q>
<rj><qau>Hobbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>Religious opinion opposed to the
authorized doctrinal standards of any particular church, especially when
tending to promote schism or separation; lack of orthodox or sound
belief; rejection of, or erroneous belief in regard to, some fundamental
religious doctrine or truth; heterodoxy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Doubts 'mongst divines, and difference of texts,<br/
From whence arise diversity of sects,<br/
And hateful <qex>heresies</qex> by God abhor'd.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Deluded people! that do not consider that the greatest
<qex>heresy</qex> in the world is a wicked life.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>An offense against Christianity,
consisting in a denial of some essential doctrine, which denial is
publicly avowed, and obstinately maintained.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A second offense is that of <qex>heresy</qex>, which consists not
in a total denial of Christianity, but of some its essential doctrines,
publicly and obstinately avowed.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/When I call dueling, and similar aberrations of
honor, a moral <xex>heresy</xex>, I refer to the force of the Greek <?/,
as signifying a principle or opinion taken up by the will for the will's
sake, as a proof or pledge to itself of its own power of
self-determination, independent of all other motives.<rdquo/</note>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heretic</ent><br/
<hw>Her"e*tic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>haereticus</ets>, Gr. <?/ able to choose, heretical, fr. <?/ to
take, choose: cf. F. <ets>h<eacute/r<eacute/tique</ets>. See
<er>Heresy</er>.]</ety> <sn>1.</sn> <def>One who holds to a heresy; one
who believes some doctrine contrary to the established faith or
prevailing religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man that is an <qex>heretic</qex>, after the first and second
admonition, reject.</q> <rj><qau>Titus iii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(R. C. Ch.)</fld> <def>One who having made a
profession of Christian belief, deliberately and pertinaciously refuses
to believe one or more of the articles of faith <ldquo/determined by the
authority of the universal church.<rdquo/</def> <rj><au>Addis &
Arnold.</au></rj></p>

<p><syn><b>Syn.</b> -- <er>Heretic</er>, <er>Schismatic</er>,
<er>Sectarian</er>.</syn> <usage>A <xex>heretic</xex> is one whose
errors are doctrinal, and usually of a malignant character, tending to
subvert the true faith. A <xex>schismatic</xex> is one who creates a
<xex>schism</xex>, or division in the church, on points of faith,
discipline, practice, etc., usually for the sake of personal
aggrandizement. A <xex>sectarian</xex> is one who originates or is an
ardent adherent and advocate of a <xex>sect</xex>, or distinct
organization, which separates from the main body of
believers.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heretical</ent><br/
<hw>He*ret"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
heresy; of the nature of, or characterized by, heresy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heretically</ent><br/
<hw>He*ret"i*cal*ly</hw>, <pos>adv.</pos> <def>In an heretical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereticate</ent><br/
<hw>He*ret"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>haereticatus</ets>, p. p. of <ets>haereticare</ets>.]</ety> <def>To
decide to be heresy or a heretic; to denounce as a heretic or
heretical.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And let no one be minded, on the score of my neoterism, to
<qex>hereticate</qex> me.</q> <rj><qau>Fitzed. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heretification</ent><br/
<hw>He*ret`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
hereticating or pronouncing heretical.</def> <rj><au>London
Times.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereto</ent><br/
<hw>Here*to"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>To this;
hereunto.</def> <rj><au>Hooker.</au></rj></p>

<p><ent>Heretog</ent><br/
<ent>Heretoch</ent><br/
<mhw>{ <hw>Her"e*toch</hw> <pr>(?)</pr>, <hw>Her"e*tog</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[AS. <ets>heretoga</ets>,
<ets>heretoha</ets>; <ets>here</ets> army + <ets>te<oacute/n</ets> to
draw, lead; akin to OS. <ets>heritogo</ets>, OHG. <ets>herizogo</ets>,
G. <ets>herzog</ets> duke.]</ety> <fld>(AS. Antiq.)</fld> <def>The
leader or commander of an army; also, a marshal.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heretofore</ent><br/
<hw>Here`to*fore"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Up to this
time; hitherto; before; in time past.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereunto</ent><br/
<hw>Here`un*to"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Unto this; up to
this time; hereto.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hereupon</ent><br/
<hw>Here`up*on"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>On this;
hereon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herewith</ent><br/
<hw>Here*with"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With
this.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herie</ent><br/
<hw>Her"ie</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Hery</er>.]</ety> <def>To praise; to worship.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heriot</ent><br/
<hw>Her"i*ot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>heregeatu</ets> military equipment, heriot; <ets>here</ets> army +
<ets>geatwe</ets>, pl., arms, equipments.]</ety> <fld>(Eng. Law)</fld>
<def>Formerly, a payment or tribute of arms or military accouterments,
or the best beast, or chattel, due to the lord on the death of a tenant;
in modern use, a customary tribute of goods or chattels to the lord of
the fee, paid on the decease of a tenant.</def> <rj><au>Blackstone.
Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heriot custom</b></col>, <cd>a heriot depending on
usage.</cd> -- <col><b>Heriot service</b></col> <fld>(Law)</fld>, <cd>a
heriot due by reservation in a grant or lease of lands.</cd>
<rj><au>Spelman. Blackstone.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heriotable</ent><br/
<hw>Her"i*ot*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Subject to the
payment of a heriot.</def> <rj><au>Burn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herisson</ent><br/
<hw>Her"is*son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<eacute/risson</ets>, prop., hedgehog.]</ety> <fld>(fort.)</fld>
<def>A beam or bar armed with iron spikes, and turning on a pivot; --
used to block up a passage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heritability</ent><br/
<hw>Her`it*a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being heritable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heritable</ent><br/
<hw>Her"it*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>h<eacute/ritable</ets>. See <er>Heritage</er>,
<er>Hereditable</er>.]</ety> <sn>1.</sn> <def>Capable of being inherited
or of passing by inheritance; inheritable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of inheriting or receiving by
inheritance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This son shall be legitimate and <qex>heritable</qex>.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heritable rights</b></col> <fld>(Scots Law)</fld>,
<cd>rights of the heir; rights to land or whatever may be intimately
connected with land; realty.</cd> <rj><au>Jacob (Law
Dict.).</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heritage</ent><br/
<hw>Her"it*age</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>heritage</ets>, <ets>eritage</ets>, OF. <ets>heritage</ets>,
<ets>eritage</ets>, F. <ets>h<eacute/ritage</ets>, fr.
<ets>h<eacute/riter</ets> to inherit, LL. <ets>heriditare</ets>. See
<er>Hereditable</er>.]</ety> <sn>1.</sn> <def>That which is inherited,
or passes from heir to heir; inheritance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Part of my <qex>heritage</qex>,<br/
Which my dead father did bequeath to me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Script.)</fld> <def>A possession; the Israelites,
as God's chosen people; also, a flock under pastoral charge.</def>
<rj><au>Joel iii. 2.</au> <au>1 Peter v. 3.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heritance</ent><br/
<hw>Her"it*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>heritance</ets>.]</ety> <def>Heritage; inheritance.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Robbing their children of the <qex>heritance</qex><br/
Their fathers handed down</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heritor</ent><br/
<hw>Her"it*or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. LL.
<ets>her<?/ator</ets>, fr. L. <ets>heres</ets> an heir.]</ety> <def>A
proprietor or landholder in a parish.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herl</ent><br/
<hw>Herl</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same
as <er>Harl</er>, 2.</def></p>

<p><ent>Hirling</ent><br/
<ent>Herling</ent><br/
<mhw><hw>Her"ling</hw>, <hw>Hir"ling</hw> <pr>(<?/)</pr></mhw>,
<pos>n.</pos> <ety>[Etymol. uncertain.]</ety> <fld>(Zool.)</fld>
<def>The young of the sea trout.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herma</ent><br/
\'d8<hw>Her"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hermae</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>See
<er>Hermes</er>, <sn>2.</sn></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermaphrodeity</ent><br/
<hw>Her*maph`ro*de"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Hermaphrodism.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermaphrodism</ent><br/
<hw>Her*maph"ro*dism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hermaphrodisme</ets>.]</ety> <fld>(Biol.)</fld> <def>See
<er>Hermaphroditism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermaphrodite</ent><br/
<hw>Her*maph"ro*dite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hermaphroditus</ets>, Gr. <?/, so called from the mythical story
that <ets>Hermaphroditus</ets>, son of Hermes and Aphrodite, when
bathing, became joined in one body with Salmacis, the nymph of a
fountain in Caria: cf. F. <ets>hermaphrodite</ets>.]</ety>
<fld>(Biol.)</fld> <def>An individual which has the attributes of both
male and female, or which unites in itself the two sexes; an animal or
plant having the parts of generation of both sexes, as when a flower
contains both the stamens and pistil within the same calyx, or on the
same receptacle. In some cases reproduction may take place without the
union of the distinct individuals. In the animal kingdom true
hermaphrodites are found only among the invertebrates. See
<xex>Illust.</xex> in Appendix, under <xex>Helminths</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermaphrodite</ent><br/
<hw>Her*maph"ro*dite</hw>, <pos>a.</pos> <def>Including, or being of,
both sexes; <as>as, an <ex>hermaphrodite</ex> animal or
flower</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hermaphrodite brig</b></col>. <fld>(Naut.)</fld> <cd>See
under <er>Brig</er>.</cd> <rj><au>Totten.</au></rj></cs></p>

<p><ent>Hermaphroditical</ent><br/
<ent>Hermaphroditic</ent><br/
<mhw>{ <hw>Her*maph`ro*dit"ic</hw> <pr>(?)</pr>,
<hw>Her*maph`ro*dit"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<sn>1.</sn> <fld>(Biol.)</fld> <def>Partaking of the characteristics of
both sexes; having male and female reproductive organs in the same plant
or animal; characterized by hermaphroditism. Opposite of
<contr>dioecious</contr>.</def> <wns>[wns=1]</wns>--
<wordforms><wf>Her*maph`ro*dit"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
<syn><b>Syn. --</b> monoecious, monecious, hermaphrodite.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <fld>(Botany)</fld>
<def>having pistils and stamens in the same flower. Opposite of
<ant>diclinous</ant>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> monoclinous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hermaphroditism</ent><br/
<hw>Her*maph"ro*dit*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Biol.)</fld> <def>The union of the two sexes in the same
individual, or the combination of some of their characteristics or
organs in one individual.</def></p>

<p><ent>Hermeneutical</ent><br/
<ent>Hermeneutic</ent><br/
<mhw>{ <hw>Her`me*neu"tic</hw> <pr>(?)</pr>, <hw>Her`me*neu"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/, fr. <?/ to interpret:
cf. F. <ets>herm<eacute/neutique</ets>.]</ety> <def>Unfolding the
signification; of or pertaining to interpretation; exegetical;
explanatory; <as>as, <ex>hermeneutic</ex> theology, or the art of
expounding the Scriptures; a <ex>hermeneutic</ex> phrase.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermeneutically</ent><br/
<hw>Her`me*neu"tic*al*ly</hw>, <pos>adv.</pos> <def>According to the
principles of interpretation; <as>as, a verse of Scripture was examined
<ex>hermeneutically</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermeneutics</ent><br/
<hw>Her`me*neu"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ (sc.
<?/).]</ety> <def>The science of interpretation and explanation;
exegesis; esp., that branch of theology which defines the laws whereby
the meaning of the Scriptures is to be ascertained.</def>
<rj><au>Schaff-Herzog Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermes</ent><br/
<hw>Her"mes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <sn>1.</sn> <fld>(Myth.)</fld> <def>See
<er>Mercury</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hermes Trismegistus</xex> <ety>[Gr. <grk>'Ermh^s
trisme`gistos</grk>, lit., Hermes thrice greatest]</ety> was a late name
of Hermes, especially as identified with the Egyptian god Thoth. He was
the fabled inventor of astrology and alchemy.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Archaeology)</fld> <def>Originally, a boundary
stone dedicated to Hermes as the god of boundaries, and therefore
bearing in some cases a head, or head and shoulders, placed upon a
quadrangular pillar whose height is that of the body belonging to the
head, sometimes having feet or other parts of the body sculptured upon
it. These figures, though often representing Hermes, were used for other
divinities, and even, in later times, for portraits of human beings.
Called also <altname>herma</altname>. See <cref>Terminal statue</cref>,
under <er>Terminal</er>.</def></p>

<p><ent>Hermetical</ent><br/
<ent>Hermetic</ent><br/
<mhw>{ <hw>Her*met"ic</hw> <pr>(?)</pr>, <hw>Her*met"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[F.
<ets>herm<eacute/tique</ets>. See Note under <er>Hermes</er>, 1.]</ety>
<sn>1.</sn> <def>Of, pertaining to, or taught by, Hermes Trismegistus;
<as>as, <ex>hermetic</ex> philosophy</as>. Hence: Alchemical;
chemic.</def> <ldquo/Delusions of the <xex>hermetic</xex> art.<rdquo/
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The alchemists, as the people were called who tried to make gold,
considered themselves followers of Hermes, and often called themselves
<qex>Hermetic</qex> philosophers.</q> <rj><qau>A. B.
Buckley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the system which explains the
causes of diseases and the operations of medicine on the principles of
the hermetic philosophy, and which made much use, as a remedy, of an
alkali and an acid; <as>as, <ex>hermetic</ex> medicine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Made perfectly close or air-tight by fusion, so that
no gas or spirit can enter or escape; <as>as, an <ex>hermetic</ex>
seal</as>. See Note under <er>Hermetically</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hermetic art</b></col>, <cd>alchemy.</cd> --
<col><b>Hermetic books</b></col>. <sd>(a)</sd> <cd>Books of the
Egyptians, which treat of astrology.</cd> <sd>(b)</sd> <cd>Books which
treat of universal principles, of the nature and orders of celestial
beings, of medicine, and other topics.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermetically</ent><br/
<hw>Her*met"ic*al*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In an
hermetical manner; chemically.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>By fusion, so as to form an air-tight
closure.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A vessel or tube is <xex>hermetically</xex> sealed when
it is closed completely against the passage of air or other fluid by
fusing the extremity; -- sometimes less properly applied to any
air-tight closure.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermit</ent><br/
<hw>Her"mit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ermite</ets>, <ets>eremite</ets>, <ets>heremit</ets>,
<ets>heremite</ets>, F. <ets>hermite</ets>, <ets>ermite</ets>, L.
<ets>eremita</ets>, Gr. <?/, fr. <?/ lonely, solitary. Cf.
<er>Eremite</er>.]</ety> <sn>1.</sn> <def>A person who retires from
society and lives in solitude; a recluse; an anchoret; especially, one
who so lives from religious motives.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had been Duke of Savoy, and after a very glorious reign, took
on him the habit of a <qex>hermit</qex>, and retired into this solitary
spot.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A beadsman; one bound to pray for another.</def>
<mark>[Obs.]</mark> <ldquo/We rest your <xex>hermits</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Cookery)</fld> <def>A spiced molasses cookie, often
containing chopped raisins and nuts.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Hermit crab</b></col> <fld>(Zool.)</fld>, <cd>a marine
decapod crustacean of the family <fam>Paguridae</fam>. The species are
numerous, and belong to many genera. Called also <altname>soldier
crab</altname>. The hermit crabs usually occupy the dead shells of
various univalve mollusks. See <xex>Illust.</xex> of
<er>Commensal</er>.</cd> -- <col><b>Hermit thrush</b></col>
<fld>(Zool.)</fld>, <cd>an American thrush (<spn>Turdus Pallasii</spn>),
with retiring habits, but having a sweet song.</cd> -- <col><b>Hermit
warbler</b></col> <fld>(Zool.)</fld>, <cd>a California wood warbler
(<spn>Dendroica occidentalis</spn>), having the head yellow, the throat
black, and the back gray, with black streaks.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermitage</ent><br/
<hw>Her"mit*age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hermitage</ets>, <ets>ermitage</ets>, F. <ets>hermitage</ets>,
<ets>ermitage</ets>. See <er>Hermit</er>.]</ety> <sn>1.</sn> <def>The
habitation of a hermit; a secluded residence.</def> <-- (Capitalized)
The name given by Catherine II to a part of the Czars' Winter Palace in
St. Petersburg, now an art museum with a very large collection of old
master paintings --><br/
[<source>1913 Webster</source>]</p>

<p><q>Some forlorn and naked <qex>hermitage</qex>,<br/
Remote from all the pleasures of the world.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F. <ets>Vin de l'Hermitage</ets>.]</ety> <def>A
celebrated French wine, both white and red, of the Department of
Dr<ocir/me.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermitary</ent><br/
<hw>Her"mit*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. LL.
<ets>hermitorium</ets>, <ets>eremitorium</ets>.]</ety> <def>A cell
annexed to an abbey, for the use of a hermit.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermitess</ent><br/
<hw>Her"mit*ess</hw>, <pos>n.</pos> <def>A female hermit.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermitical</ent><br/
<hw>Her*mit"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or suited for, a hermit.</def> <rj><au>Coventry.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermodactyl</ent><br/
<hw>Her`mo*dac"tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>hermodactylus</ets>, lit., Hermes' finger; fr. Gr. <?/ Hermes + <?/
finger.]</ety> <fld>(med.)</fld> <def>A heart-shaped bulbous root, about
the size of a finger, brought from Turkey, formerly used as a
cathartic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hermogenian</ent><br/
<hw>Her`mo*ge"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>A disciple of <etsep>Hermogenes</etsep>, an heretical
teacher who lived in Africa near the close of the second century. He
held matter to be the fountain of all evil, and that souls and spirits
are formed of corrupt matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hern</ent><br/
<hw>Hern</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
heron; esp., the common European heron.</def> <ldquo/A stately
<xex>hern</xex>.<rdquo/ <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hernani</ent><br/
<hw>Her*na"ni</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A thin silk or
woolen goods, for women's dresses, woven in various styles and
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herne</ent><br/
<hw>Herne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hyrne</ets>.]</ety> <def>A corner.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lurking in <qex>hernes</qex> and in lanes blind.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hernia</ent><br/
<hw>Her"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Hernias</plw> <pr>(#)</pr>, L. <plw>Herniae</plw>
<pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Med.)</fld> <def>A protrusion,
consisting of an organ or part which has escaped from its natural
cavity, and projects through some natural or accidental opening in the
walls of the latter; <as>as, <ex>hernia</ex> of the brain, of the lung,
or of the bowels</as>. Hernia of the abdominal viscera in most common.
Called also <altname>rupture</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Strangulated hernia</b></col>, <cd>a hernia so tightly
compressed in some part of the channel through which it has been
protruded as to arrest its circulation, and produce swelling of the
protruded part. It may occur in recent or chronic hernia, but is more
common in the latter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hernial</ent><br/
<hw>Her"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, or connected
with, hernia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herniotomy</ent><br/
<hw>Her`ni*ot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hernia</ets> + Gr. <?/ to cut.]</ety> <fld>(Med.)</fld>
<def>A surgical procedure for the cure or relief of hernia;
celotomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hernshaw</ent><br/
<hw>Hern"shaw</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Heronshaw.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hero</ent><br/
<hw>He"ro</hw> <pr>(h<emac/"r<osl/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Heroes</plw> <pr>(h<emac/"r<omac/z)</pr>.</plu>
<ety>[F. <ets>h<eacute/ros</ets>, L. <ets>heros</ets>, Gr.
<grk>"h`rws</grk>.]</ety> <sn>1.</sn> <fld>(Myth.)</fld> <def>An
illustrious man, supposed to be exalted, after death, to a place among
the gods; a demigod, as Hercules.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man of distinguished valor or enterprise in
danger, or fortitude in suffering; a prominent or central personage in
any remarkable action or event; hence, a great or illustrious
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Each man is a <qex>hero</qex> and oracle to somebody.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The principal personage in a poem, story, and the
like, or the person who has the principal share in the transactions
related; as Achilles in the Iliad, Ulysses in the Odyssey, and Aeneas in
the Aeneid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The shining quality of an epic <qex>hero</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hero worship</b></col>, <cd>extravagant admiration for
great men, likened to the ancient worship of heroes.</cd></cs><br/
[<source>1913 Webster</source>]</p>
1 <p><q><qex>Hero worship</qex> exists, has existed, and will forever
exist, universally among mankind.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herodian</ent><br/
<hw>He*ro"di*an</hw> <pr>(h<esl/*r<omac/"d<icr/*<ait/n)</pr>, <pos>prop.
n.</pos> <fld>(Jewish Hist.)</fld> <def>One of a party among the Jews,
composed of partisans of Herod of Galilee. They joined with the
Pharisees against Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herodiones</ent><br/
\'d8<hw>He*ro`di*o"nes</hw>
<pr>(h<esl/*r<omac/`d<icr/*<omac/"n<emac/z)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>'erwdio`s</grk> a heron.]</ety>
<fld>(Zool.)</fld> <def>A division of wading birds, including the
herons, storks, and allied forms. Called also
<altname>Herodii</altname>.</def> -- <wordforms><wf>He*ro`di*o"nine</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroess</ent><br/
<hw>He"ro*ess</hw> <pr>(h<emac/"r<ocr/*<ecr/s)</pr>, <pos>n.</pos>
<def>A heroine.</def> <mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroic</ent><br/
<hw>He*ro"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>h<eacute/ro<ium/que</ets>, L. <ets>hero<ium/cus</ets>, Gr.
<grk>"hrwi:ko`s</grk>.]</ety> <sn>1.</sn> <def>Of or pertaining to, or
like, a hero; of the nature of heroes; distinguished by the existence of
heroes; <as>as, the <ex>heroic</ex> age; an <ex>heroic</ex> people;
<ex>heroic</ex> valor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Worthy of a hero; bold; daring; brave; illustrious;
<as>as, <ex>heroic</ex> action; <ex>heroic</ex>
enterprises.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Sculpture & Painting)</fld> <def>Larger than life
size, but smaller than colossal; -- said of the representation of a
human figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heroic Age</b></col>, <cd>the age when the heroes, or
those called the children of the gods, are supposed to have lived.</cd>
-- <col><b>Heroic poetry</b></col>, <cd>that which celebrates the deeds
of a hero; epic poetry.</cd> -- <mcol><col><b>Heroic treatment</b></col>
<it>or</it> <col><b>Heroic remedies</b></col></mcol> <fld>(Med.)</fld>,
<cd>treatment or remedies of a severe character, suited to a desperate
case.</cd> -- <col><b>Heroic verse</b></col> <fld>(Pros.)</fld>, <cd>the
verse of heroic or epic poetry, being in English, German, and Italian
the iambic of ten syllables; in French the iambic of twelve syllables;
and in classic poetry the hexameter.</cd></cs></p>

<p><syn><b>Syn.</b> -- Brave; intrepid; courageous; daring; valiant;
bold; gallant; fearless; enterprising; noble; magnanimous;
illustrious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroical</ent><br/
<hw>He*ro"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Heroic.</def>
<mark>[R.]</mark> <au>Spectator.</au> --
<wordforms><wf>He*ro"ic*al*ly</wf>, <pos>adv.</pos> --
<wf>He*ro"ic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 689 --></p>

<p><ent>Heroicness</ent><br/
<hw>He*ro"ic*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Heroism.</def>
<mark>[R.]</mark> <rj><au>W. Montagu.</au></rj></p>

<p><ent>Heroicomical</ent><br/
<ent>Heroicomic</ent><br/
<mhw>{ <hw>He`ro*i*com"ic</hw> <pr>(?)</pr>, <hw>He`ro*i*com"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>h<eacute/ro<ium/comigue</ets>. See <er>Heroic</er>, and
<er>Comic</er>.]</ety> <def>Combining the heroic and the ludicrous;
denoting high burlesque; <as>as, a <ex>heroicomic</ex>
poem</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>heroin</ent><br/
<hw>her"o*in</hw> <pr>(h<etil/r"<osl/*<icr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>a morphine derivative, <altname>diacetyl
morphine</altname>, used to relieve severe pain and as a sedative. It is
highly addictive, and its use is strictly controlled in the U.S. by
federal law. It is a popular strong narcotic drug of abuse, in part
because it is more soluble than morphine. It is sometimes included as
one of the components of <partof>Brompton's mixture</partof>, used to
control pain in terminallly ill patients.</def><br/
<syn><b>Syn. --</b> diacetyl morphine, H, horse, junk, scag, shit,
smack.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Heroine</ent><br/
<hw>Her"o*ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<eacute/ro<ium/ne</ets>, L. <ets>heroina</ets>, Gr. <?/, fem. of
<?/. See <er>Hero</er>.]</ety> <sn>1.</sn> <def>A woman of an heroic
spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heroine</qex> assumed the woman's place.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The principal female person who figures in a
remarkable action, or as the subject of a poem or story.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroism</ent><br/
<hw>Her"o*ism</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<eacute/ro<ium/sme</ets>.]</ety> <def>The qualities characteristic
of a hero, as courage, bravery, fortitude, unselfishness, etc.; the
display of such qualities.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Heroism</qex> is the self-devotion of genius manifesting
itself in action.</q> <rj><qau>Hare.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Heroism</er>, <er>Courage</er>,
<er>Fortitude</er>, <er>Bravery</er>, <er>Valor</er>,
<er>Intrepidity</er>, <er>Gallantry</er>.</syn> <usage>
<xex>Courage</xex> is generic, denoting fearlessness or defiance of
danger; <xex>fortitude</xex> is <xex>passive</xex> courage, the habit of
<xex>bearing up</xex> nobly under trials, danger, and sufferings;
<xex>bravery</xex> is courage displayed in daring acts; <xex>valor</xex>
is courage in battle or other conflicts with living opponents;
<xex>intrepidity</xex> is <xex>firm</xex> courage, which shrinks not
amid the most appalling dangers; <xex>gallantry</xex> is
<xex>adventurous</xex> courage, dashing into the thickest of the fight.
<xex>Heroism</xex> may call into exercise all these modifications of
courage. It is a contempt of danger, not from ignorance or inconsiderate
levity, but from a noble devotion to some great cause, and a just
confidence of being able to meet danger in the spirit of such a cause.
Cf. <er>Courage</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heron</ent><br/
<hw>Her"on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>heiroun</ets>, <ets>heroun</ets>, <ets>heron</ets>,
<ets>hern</ets>, OF. <ets>hairon</ets>, F. <ets>h<eacute/ron</ets>, OHG.
<ets>heigir</ets>; cf. Icel. <ets>hegri</ets>, Dan. <ets>heire</ets>,
Sw. <ets>h<aum/ger</ets>, and also G. <ets>h<aum/her</ets> jay, jackdaw,
OHG. <ets>hehara</ets>, <ets>higere</ets>, woodpecker, magpie, D.
<ets>reiger</ets> heron, G. <ets>reiher</ets>, AS.
<ets>hr<amac/gra</ets>. Cf. <er>Aigret</er>, <er>Egret</er>.]</ety>
<fld>(Zool.)</fld> <def>Any wading bird of the genus <gen>Ardea</gen>
and allied genera, of the family <fam>Ardeidae</fam>. The herons have a
long, sharp bill, and long legs and toes, with the claw of the middle
toe toothed. The common European heron (<spn>Ardea cinerea</spn>) is
remarkable for its directly ascending flight, and was formerly hunted
with the larger falcons.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are several common American species; as, the great
blue heron (<spn>Ardea herodias</spn>); the little blue (<spn>Ardea
c<oe/rulea</spn>); the green (<spn>Ardea virescens</spn>); the snowy
(<spn>Ardea candidissima</spn>); the night heron or qua-bird
(<spn>Nycticorax nycticorax</spn>). The plumed herons are called
<stype>egrets</stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heron's bill</b></col> <fld>(Bot.)</fld>, <cd>a plant of
the genus <gen>Erodium</gen>; -- so called from the fancied resemblance
of the fruit to the head and beak of the heron.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroner</ent><br/
<hw>Her"on*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hawk used in
hunting the heron.</def> <ldquo/<xex>Heroner</xex> and falcon.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heronry</ent><br/
<hw>Her"on*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place where herons
breed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heronsew</ent><br/
<hw>Her"on*sew</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A heronshaw.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heronshaw</ent><br/
<hw>Her"on*shaw</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>heroncel</ets>, dim. of <ets>h<eacute/ron</ets>. See
<er>Heron</er>.]</ety> <fld>(Zool.)</fld> <def>A heron.</def>
<altsp>[Written variously <asp>hernshaw</asp>, <asp>harnsey</asp>,
etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroologist</ent><br/
<hw>He`ro*<oum/l"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ +
<?/ discourse.]</ety> <def>One who treats of heroes.</def>
<mark>[R.]</mark> <rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heroship</ent><br/
<hw>He"ro*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The character or
personality of a hero.</def> <ldquo/Three years of
<xex>heroship</xex>.<rdquo/ <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herpes</ent><br/
<hw>Her"pes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>"e`rphs</grk>, fr. <grk>"e`rpein</grk> to creep.]</ety>
<fld>(Med.)</fld> <def>An eruption of the skin, taking various names,
according to its form, or the part affected, caused by a herpesvirus
infection; especially, an eruption of vesicles in small distinct
clusters, accompanied with itching or tingling, including shingles,
ringworm, and the like; -- so called from its tendency to creep or
spread from one part of the skin to another.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Herpes simplex</ent><br/
<hw>Her"pes simp`lex</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>either of two forms of herpesvirus infection, distinguished as
being caused by herpes simplex virus type 1 (HSV-1), which causes mostly
sores and eruptions around the mouth (cold sores and fever blisters) and
at other points above the waist, and herpes simplex virus type 2
(HSV-2), causing genital herpes. HSV-1 is also known in some cases to
cause genital herpes infections.</def><br/
[<source>PJC</source>]</p>

<p><ent>Herpestes</ent><br/
<hw>Herpestes</hw> <pos>n.</pos> <def>A genus of carnivores including
the mongooses.</def><br/
<syn><b>Syn. --</b> genus <gen>Herpestes</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Herpesvirus</ent><br/
<hw>Her"pes*vir`us</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>any of several dozen DNA-containing virus of the family
<fam>Herpetoviridae</fam>, including among them such
human-disease-causing agents as <stype>Herpes simplex virus</stype>
causing oral and genital <er>herpes</er>, <stype>varicella-zoster
virus</stype> (<stype>Herpes zoster virus</stype>) causing shingles and
chickenpox (varicella), <stype>Epstein-Barr virus</stype> (EB virus)
causing infectious mononucleosis, and
<stype>Cytomegalovirus</stype>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Herpes zoster</ent><br/
<hw>Her"pes zos`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>same as <er>shingles</er>; -- a form of <er>herpes</er> caused by
the <causedby>varicella-zoster virus</causedby>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Herpes zoster virus</ent><br/
<hw>Her"pes zos`ter vir*us</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>same as <er>varicella-zoster
virus</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Herpetic</ent><br/
<hw>Her*pet"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>herp<eacute/tique</ets>.]</ety> <def>Pertaining to, or resembling,
the herpes; partaking of the nature of herpes; <as>as, <ex>herpetic</ex>
eruptions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herpetism</ent><br/
<hw>Her"pe*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Herpes</er>.]</ety> <fld>(Med.)</fld> <def>See <cref>Dartrous
diathesis</cref>, under <er>Dartrous</er>.</def></p>

<p><ent>Herpetological</ent><br/
<ent>Herpetologic</ent><br/
<mhw>{ <hw>Her*pet`o*log"ic</hw> <pr>(?)</pr>,
<hw>Her*pet`o*log"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Pertaining to herpetology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herpetologist</ent><br/
<hw>Her`pe*tol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed
in herpetology, or the natural history of reptiles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herpetology</ent><br/
<hw>Her`pe*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also,
but less properly, <ets>erpetology</ets>.]</ety> <ety>[Gr. <?/ a
creeping thing, reptile (fr. <?/ to creep) + <ets>-logy</ets>: cf. F.
<ets>herp<eacute/tologie</ets>.]</ety> <def>The natural history of
reptiles; that branch of Zoology which relates to reptiles, including
their structure, classification, and habits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herpetotomist</ent><br/
<hw>Her`pe*tot"o*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dissects, or studies the anatomy of, reptiles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herpetotomy</ent><br/
<hw>Her`pe*tot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
reptile + <?/ to cut.]</ety> <def>The anatomy or dissection of
reptiles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herr</ent><br/
\'d8<hw>Herr</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A title of respect
given to gentlemen in Germany, equivalent to the English
<sig>Mister</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herrenvolk</ent><br/
<hw>Her"ren*volk</hw> <pr>(h<ecr/r"r<eit/n*f<omac/lk`)</pr>,
<pos>n.</pos> <ety>[German.]</ety> <def>a race that considers itself
superior to all others and fitted to rule the others; -- referred to
especially in NAZI racial theories.</def><br/
<syn><b>Syn. --</b> master race.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Herrenhaus</ent><br/
\'d8<hw>Her"ren*haus`</hw> <pr>(h<ecr/r"r<eit/n*hous`)</pr>,
<pos>n.</pos> <ety>[G., House of Lords.]</ety> <def>See
<er>Legislature</er>, <xex>Austria</xex>, <xex>Prussia</xex>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Herring</ent><br/
<hw>Her"ring</hw> <pr>(h<ecr/r"r<icr/ng)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hering</ets>, AS. <ets>h<ae/ring</ets>; akin to D.
<ets>haring</ets>, G. <ets>h<aum/ring</ets>, <ets>hering</ets>, OHG.
<ets>haring</ets>, <ets>hering</ets>, and prob. to AS. <ets>here</ets>
army, and so called because they commonly move in large numbers. Cf.
<er>Harry</er>.]</ety> <fld>(Zool.)</fld> <def>One of various species of
fishes of the genus <gen>Clupea</gen>, and allied genera, esp. the
common round or English herring (<spn>Clupea harengus</spn>) of the
North Atlantic. Herrings move in vast schools, coming in spring to the
shores of Europe and America, where they are salted and smoked in great
quantities.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Herring gull</b></col> <fld>(Zool.)</fld>, <cd>a large
gull which feeds in part upon herrings; esp., <spn>Larus
argentatus</spn> in America, and <spn>Larus cachinnans</spn> in England.
See <er>Gull</er>.</cd> -- <col><b>Herring hog</b></col>
<fld>(Zool.)</fld>, <cd>the common porpoise.</cd> -- <col><b>King of the
herrings</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The chimaera
(<spn>Chimaera monstrosa</spn>) which follows the schools of herring.
Called also <altname>rabbit fish</altname> in the <country>U.
K.</country> See <er>Chimaera</er>.</cd> <sd>(b)</sd> <cd>The
opah.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herringbone</ent><br/
<hw>Her"ring*bone`</hw> <pr>(h<ecr/r"r<icr/ng*b<omac/n`)</pr>,
<pos>a.</pos> <def>Pertaining to, or like, the spine of a herring;
especially, characterized by an arrangement of work in rows of parallel
lines, which in the alternate rows slope in different
directions.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Herringbone stitch</b></col>, <cd>a kind of cross-stitch
in needlework, chiefly used in flannel.</cd>
<rj><au>Simmonds.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herrnhuter</ent><br/
<hw>Herrn"hut*er</hw> <pr>(h<etil/rn"h<ucr/*<etil/r; G.
h<ecr/rn"h<oomac/*<etil/r)</pr>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld>
<def>One of the Moravians; -- so called from the settlement of
<etsep>Herrnhut</etsep> (the Lord's watch) made, about 1722, by the
Moravians at the invitation of Nicholas Lewis, count of Zinzendorf, upon
his estate in the circle of Bautzen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hers</ent><br/
<hw>Hers</hw> <pr>(h<etil/rz)</pr>, <pos>pron.</pos> <def>See the Note
under <er>Her</er>, <pos>pron.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hersal</ent><br/
<hw>Her"sal</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Rehearsal.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herschel</ent><br/
<hw>Her"schel</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Astron.)</fld>
<def>See <er>Uranus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herschelian</ent><br/
<hw>Her*sche"li*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or relating
to Sir William Herschel; <as>as, the <ex>Herschelian</ex>
telescope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herse</ent><br/
<hw>Herse</hw> <pr>(h<etil/rs)</pr>, <pos>n.</pos> <ety>[F.
<ets>herse</ets> harrow, portcullis, OF. <ets>herce</ets>, LL.
<ets>hercia</ets>, L. <ets>hirpex</ets>, gen. <ets>hirpicis</ets>, and
<ets>irpex</ets>, gen. <ets>irpicis</ets>, harrow. The LL.
<ets>hercia</ets> signifies also a kind of candlestick in the form of a
harrow, having branches filled with lights, and placed at the head of
graves or cenotaphs; whence <ets>herse</ets> came to be used for the
grave, coffin, or chest containing the dead. Cf. <er>Hearse</er>.]</ety>
<sn>1.</sn> <fld>(Fort.)</fld> <def>A kind of gate or portcullis, having
iron bars, like a harrow, studded with iron spikes. It is hung above
gateways so that it may be quickly lowered, to impede the advance of an
enemy.</def> <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <er>Hearse</er>, a carriage for the
dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A funeral ceremonial.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herse</ent><br/
<hw>Herse</hw>, <pos>v. t.</pos> <def>Same as <er>Hearse</er>, <pos>v.
t.</pos></def> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herself</ent><br/
<hw>Her*self"</hw> <pr>(?)</pr>, <pos>pron.</pos> <sn>1.</sn> <def>An
emphasized form of the third person feminine pronoun; -- used as a
subject with <xex>she</xex>; <as>as, she <ex>herself</ex> will bear the
blame</as>; also used alone in the predicate, either in the nominative
or objective case; <as>as, it is <ex>herself</ex>; she blames
<ex>herself</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Her own proper, true, or real character; hence, her
right, or sane, mind; <as>as, the woman was deranged, but she is now
<ex>herself</ex> again; she has come to <ex>herself</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>By herself</b></col>, <cd>alone; apart;
unaccompanied.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hersillon</ent><br/
<hw>Her"sil*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>herse</ets> a harrow. See <er>Herse</er>, <pos>n.</pos>]</ety>
<fld>(Fort.)</fld> <def>A beam with projecting spikes, used to make a
breach impassable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hert</ent><br/
<hw>Hert</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hart.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Herte</ent><br/
<hw>Her"te</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A heart.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hertely</ent><br/
<hw>Her"te*ly</hw>, <pos>a. & adv.</pos> <def>Hearty; heartily.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hery</ent><br/
<hw>Her"y</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>herian</ets>.]</ety> <def>To worship; to glorify; to praise.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer. Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hertz</ent><br/
<hw>Hertz</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[from the German
physicist <person>Heinrich <etsep>Hertz</etsep></person>.]</ety> <def>a
unit of frequency equal to one cycle per second; it is abbreviated
<abbr>Hz</abbr>. It is commonly used to specify the frequency of radio
waves, and also the clock frequencies in digital computers. For these
applications, kilohertz and megahertz are the most commonly used units,
derived from <ex>hertz</ex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hertzian</ent><br/
<hw>Hertz"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pert. to the
German physicist <person>Heinrich
<etsep>Hertz</etsep></person>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Hertzian telegraphy</b></col>, <cd>telegraphy by means of
the Hertzian waves; wireless telegraphy.</cd> -- <col><b>H.
waves</b></col>, <cd>electric waves; -- so called because Hertz was the
first to investigate them systematically. His apparatus consisted
essentially in an <xex>oscillator</xex> for producing the waves, and a
<xex>resonator</xex> for detecting them. The waves were found to have
the same velocity as light, and to undergo reflection, refraction, and
polarization.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Herzog</ent><br/
\'d8<hw>Her"zog</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., akin to AS.
<ets>heretoga</ets>, lit., army leader. See <er>Harry</er>, and
<er>Duke</er>.]</ety> <def>A member of the highest rank of nobility in
Germany and Austria, corresponding to the British duke.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hesitancy</ent><br/
<hw>Hes"i*tan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>haesitantia</ets> a stammering.]</ety> <sn>1.</sn> <def>The act of
hesitating, or pausing to consider; slowness in deciding; vacillation;
also, the manner of one who hesitates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stammering; a faltering in speech.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitant</ent><br/
<hw>Hes"i*tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>haesitans</ets>, <ets>p. pr.</ets> of <ets>haesitare</ets>: cf. F.
<ets>h<eacute/sitant</ets>. See <er>Hesitate</er>.]</ety> <sn>1.</sn>
<def>Not prompt in deciding or acting; hesitating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unready in speech.</def>
<rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitantly</ent><br/
<hw>Hes"i*tant*ly</hw>, <pos>adv.</pos> <def>With hesitancy or
doubt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitate</ent><br/
<hw>Hes"i*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hesitated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hesitating</conjf>.]</vmorph> <ety>[L.
<ets>haesitatus</ets>, p. p. of <ets>haesitare</ets>, intens. fr.
<ets>haerere</ets> to hesitate, stick fast; to hang or hold fast. Cf.
<er>Aghast</er>, <er>Gaze</er>, <er>Adhere</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To stop or pause respecting decision or action; to
be in suspense or uncertainty as to a determination; <as>as, he
<ex>hesitated</ex> whether to accept the offer or not; men often
<ex>hesitate</ex> in forming a judgment.</as></def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To stammer; to falter in speaking.</def></p>

<p><syn><b>Syn.</b> -- To doubt; waver; scruple; deliberate; demur;
falter; stammer.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitate</ent><br/
<hw>Hes"i*tate</hw>, <pos>v. t.</pos> <def>To utter with hesitation or
to intimate by a reluctant manner.</def> <mark>[Poetic & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Just hint a fault, and <qex>hesitate</qex> dislike.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hesitater</ent><br/
<hw>hesitater</hw> <pos>n.</pos> <def>one who hesitates.</def><br/
<syn><b>Syn. --</b> waverer, vacillator, hesitator.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hesitating</ent><br/
<hw>hesitating</hw> <pos>adj.</pos> <def>holding back because of doubt
or lack of confidence.</def><br/
<syn><b>Syn. --</b> hesitant, indecisive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hesitatingly</ent><br/
<hw>Hes"i*ta`ting*ly</hw>, <pos>adv.</pos> <def>With hesitation or
doubt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitation</ent><br/
<hw>Hes`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>haesitatio</ets>: cf. F. <ets>h<eacute/sitation</ets>.]</ety>
<sn>1.</sn> <def>The act of hesitating; suspension of opinion or action;
doubt; vacillation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A faltering in speech; stammering.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitative</ent><br/
<hw>Hes"i*ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Showing, or
characterized by, hesitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He said] in his mild, <qex>hesitative</qex> way.</q> <rj><qau>R.
D. Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesitatory</ent><br/
<hw>Hes"i*ta*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hesitating.</def> <rj><au>R. North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesp</ent><br/
<hw>Hesp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>hespa</ets> a hasp, a wisp or skein. See <er>Hasp</er>.]</ety>
<def>A measure of two hanks of linen thread.</def> <mark>[Scot.]</mark>
<altsp>[Written also <asp>hasp</asp>.]</altsp>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesper</ent><br/
<hw>Hes"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hesperian</er>.]</ety> <def>The evening; Hesperus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperetin</ent><br/
<hw>Hes*per"e*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A white, crystalline substance having a sweetish taste, obtained by
the decomposition of hesperidin, and regarded as a complex derivative of
caffeic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperian</ent><br/
<hw>Hes*pe"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hesperius</ets>, fr. <ets>hesperus</ets> the evening star, Gr. <?/
evening, <?/ <?/ the evening star. Cf. <er>Vesper</er>.]</ety>
<def>Western; being in the west; occidental.</def> <mark>[Poetic]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperian</ent><br/
<hw>Hes*pe"ri*an</hw>, <pos>n.</pos> <def>A native or an inhabitant of a
western country.</def> <mark>[Poetic]</mark> <rj><au>J.
Barlow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperian</ent><br/
<hw>Hes*pe"ri*an</hw>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Of or
pertaining to a family of butterflies called <fam>Hesperidae</fam>, or
skippers.</def> -- <def2><pos>n.</pos> <def>Any one of the numerous
species of <fam>Hesperidae</fam>; a skipper.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperid</ent><br/
<hw>Hes"per*id</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <fld>(Zool.)</fld>
<def>Same as 3d <er>Hesperian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperidene</ent><br/
<hw>Hes*per"i*dene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hesperidium</er>.]</ety> <fld>(Chem.)</fld> <def>An isomeric variety
of terpene from orange oil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperides</ent><br/
\'d8<hw>Hes*per"i*des</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., fr.
Gr. <?/.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Class. Myth.)</fld> <def>The daughters of Hesperus,
or Night (brother of Atlas), and fabled possessors of a garden producing
golden apples, in Africa, at the western extremity of the known world.
To slay the guarding dragon and get some of these apples was one of the
labors of Hercules. Called also <altname>Atlantides</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The garden producing the golden apples.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It not love a Hercules,<br/
Still climbing trees in the <qex>Hesperides</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperidin</ent><br/
<hw>Hes*per"i*din</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hesperidium</er>.]</ety> <fld>(Chem.)</fld> <def>A glucoside found
in ripe and unripe fruit (as the orange), and extracted as a white
crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperidium</ent><br/
\'d8<hw>Hes`pe*rid"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So
called in allusion to the golden apples of the Hesperides. See
<er>Hesperides</er>.]</ety> <fld>(Bot.)</fld> <def>A large berry with a
thick rind, as a lemon or an orange.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperornis</ent><br/
\'d8<hw>Hes`pe*ror"nis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ western + <?/, <?/, a bird.]</ety> <fld>(Paleon.)</fld> <def>A
genus of large, extinct, wingless birds from the Cretaceous deposits of
Kansas, belonging to the Odontornithes. They had teeth, and were
essentially carnivorous swimming ostriches. Several species are known.
See <xex>Illust.</xex> in Append.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesperus</ent><br/
\'d8<hw>Hes"pe*rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Hesper</er>.]</ety> <sn>1.</sn> <def>Venus when she is the evening
star; Hesper.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Evening.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Sun was sunk, and after him the Star<br/
Of <qex>Hesperus</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hessian</ent><br/
<hw>Hes"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or relating to
Hesse, in Germany, or to the Hessians.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hessian boots</b></col>, <it>or</it>
<col><b>Hessians</b></col></mcol>, <cd>boot of a kind worn in England,
in the early part of the nineteenth century, tasseled in front.</cd>
<au>Thackeray.</au> -- <mcol><col><b>Hessian cloth</b></col>,
<it>or</it> <col><b>Hessians</b></col></mcol>, <cd>a coarse hempen cloth
for sacking.</cd> -- <col><b>Hessian crucible</b></col>. <cd>See under
<er>Crucible</er>.</cd> -- <col><b>Hessian fly</b></col>
<fld>(Zool.)</fld>, <cd>a small dipterous fly or midge (<spn>Cecidomyia
destructor</spn>). Its larvae live between the base of the lower leaves
and the stalk of wheat, and are very destructive to young wheat; -- so
called from the erroneous idea that it was brought into America by the
Hessian troops, during the Revolution.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hessian</ent><br/
<hw>Hes"sian</hw>, <pos>n.</pos> <sn>1.</sn> <def>A native or inhabitant
of Hesse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mercenary or venal person.</def> <mark>[U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This use is a relic of the patriot hatred of the Hessian
mercenaries who served with the British troops in the Revolutionary
War.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>See <cref>Hessian boots</cref> and
<xex>cloth</xex>, under <er>Hessian</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hessite</ent><br/
<hw>Hess"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[After H.
<etsep>Hess</etsep>.]</ety> <fld>(Min.)</fld> <def>A lead-gray sectile
mineral. It is a telluride of silver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hest</ent><br/
<hw>Hest</hw> <pr>(h<ecr/st)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<aemac/s</ets>, fr. <ets>h<amac/tan</ets> to call, bid. See
<er>Hight</er>, and cf. <er>Behest</er>.]</ety> <def>Command; precept;
injunction.</def> <mark>[Archaic]</mark> <see>See <er>Behest</er>.</see>
<ldquo/At thy <xex>hest</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him that yields obey the victor's <qex>hest</qex>.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet I thy <qex>hest</qex> will all perform, at full.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><ent>Hesternal</ent><br/
<ent>Hestern</ent><br/
<mhw>{ <hw>Hes"tern</hw> <pr>(?)</pr>, <hw>Hes*ter"nal</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hesternus</ets>; akin
to <ets>heri</ets> yesterday.]</ety> <def>Pertaining to yesterday.</def>
<mark>[Obs.]</mark> <see>See <er>Yester</er>, <pos>a.</pos></see>
<rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hesychast</ent><br/
<hw>Hes"y*chast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ hermit,
fr. <?/ to be still or quiet, fr. <?/ still, calm.]</ety> <def>One of a
mystical sect of the Greek Church in the fourteenth century; a
quietist.</def> <rj><au>Brande & C.</au></rj></p>

<p><ent>Hetaira</ent><br/
<ent>Hetaera</ent><br/
<mhw>{ \'d8<hw>He*tae"ra</hw> <pr>(?)</pr>, \'d8<hw>He*tai"ra</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos>; <plu>pl. <plw>-rae</plw>
<pr>(#)</pr></plu>. <ety>[NL. See <er>Hetairism</er>.]</ety> <fld>(Gr.
Antiq.)</fld> <def>A female paramour; a mistress, concubine, or
harlot.</def> -- <wordforms><wf>He*tae"ric</wf>, <wf>He*tai"ric</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hetarism</ent><br/
<ent>Hetairism</ent><br/
<mhw>{ <hw>He*tair"ism</hw> <pr>(?)</pr>, <hw>Het"a*rism</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <?/ a companion, a
concubine, fem. of <?/ a comrade.]</ety> <def>A supposed primitive state
of society, in which all the women of a tribe were held in common.</def>
<au>H. Spencer.</au> -- <wordforms><wf>Het`a*ris"tic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hetchel</ent><br/
<hw>Hetch"el</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Same as
<er>Hatchel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hete</ent><br/
<hw>Hete</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hete</conjf>, later <conjf>Het</conjf>.]</vmorph>
<def><it>Variant of</it> <er>Hote</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But one avow to greate God I <qex>hete</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteracanth</ent><br/
<hw>Het"er*a*canth</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ a spine.]</ety> <fld>(Zool.)</fld>
<def>Having the spines of the dorsal fin unsymmetrical, or thickened
alternately on the right and left sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterarchy</ent><br/
<hw>Het"er*arch`y</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + <ets>-archy</ets>.]</ety> <def>The government
of an alien.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterauxesis</ent><br/
\'d8<hw>Het`e*raux*e"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ the other + <?/ growth.]</ety> <fld>(Bot.)</fld> <def>Unequal
growth of a cell, or of a part of a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hetero-</ent><br/
<hw>Het"er*o-</hw> <pr>(?)</pr>. <ety>[Gr. <grk>"e`teros</grk>
other.]</ety> <def>A combining form signifying <xex>other</xex>,
<xex>other than usual</xex>, <xex>different</xex>; <as>as,
<ex>hetero</ex>clite, <ex>hetero</ex>dox,
<ex>hetero</ex>gamous</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterocarpism</ent><br/
<hw>Het`er*o*car"pism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ fruit.]</ety> <fld>(Bot.)</fld>
<def>The power of producing two kinds of reproductive bodies, as in the
hog peanut <spn>Amphicarpaea bracteata</spn>, in which besides the usual
pods produced from flowers above ground, there are others underground.
In the hog peanut the above-ground flowers are all creamy white or
tinged with purple, as in the photo.</def><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Heterocarpous</ent><br/
<hw>Het`er*o*car"pous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Characterized by heterocarpism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterocephalous</ent><br/
<hw>Het`er*o*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr.<?/ head.]</ety> <fld>(Bot.)</fld>
<def>Bearing two kinds of heads or capitula; -- said of certain
composite plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterocera</ent><br/
\'d8<hw>Het`e*roc"e*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ other + <?/ horn.]</ety> <fld>(Zool.)</fld> <def>A division
of Lepidoptera, including the moths, and hawk moths, which have the
antenn<ae/ variable in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterocercal</ent><br/
<hw>Het`er*o*cer"cal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ tail.]</ety> <fld>(Anat.)</fld>
<def>Having the vertebral column evidently continued into the upper lobe
of the tail, which is usually longer than the lower one, as in
sharks.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 690 --></p>

<p><ent>Heterocercy</ent><br/
<hw>Het"er*o*cer`cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ a tail.]</ety> <fld>(Anat.)</fld>
<def>Unequal development of the tail lobes of fishes; the possession of
a heterocercal tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterochromous</ent><br/
<hw>Het`er*o*chro"mous</hw> <pr>(?; 277)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ color.]</ety> <fld>(Bot.)</fld>
<def>Having the central florets of a flower head of a different color
from those of the circumference.</def></p>

<p><ent>Heterochrony</ent><br/
<ent>Heterochronism</ent><br/
<mhw>{ <hw>Het`er*och"ro*nism</hw> <pr>(?)</pr>,
<hw>Het`er*och"ro*ny</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr.
<?/ of different times; <?/ other + <?/ time.]</ety> <fld>(Biol.)</fld>
<def>In evolution, a deviation from the typical sequence in the
formation of organs or parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroclite</ent><br/
<hw>Het"er*o*clite</hw>, <pos>a.</pos> <ety>[L. <ets>heteroclitus</ets>,
Gr. <?/; <?/ other + <?/ to lean, incline, inflect: cf. F.
<ets>h<eacute/t<eacute/roclite</ets>.]</ety> <def>Deviating from
ordinary forms or rules; irregular; anomalous; abnormal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroclite</ent><br/
<hw>Het"er*o*clite</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Gram.)</fld>
<def>A word which is irregular or anomalous either in declension or
conjugation, or which deviates from ordinary forms of inflection in
words of a like kind; especially, a noun which is irregular in
declension.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any thing or person deviating from the common rule,
or from common forms.</def> <rj><au>Howell.</au></rj></p>

<p><ent>Heteroclitical</ent><br/
<ent>Heteroclitic</ent><br/
<mhw>{ <hw>Het`er*o*clit"ic</hw> <pr>(?)</pr>,
<hw>Het`er*o*clit"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[See <er>Heteroclite</er>.]</ety> <def>Deviating from ordinary
forms or rules; irregular; anomalous; abnormal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroclitous</ent><br/
<hw>Het`er*oc"li*tous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Heteroclitic.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterocyst</ent><br/
<hw>Het"er*o*cyst</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + <ets>cyst</ets>.]</ety> <fld>(Bot.)</fld>
<def>A cell larger than the others, and of different appearance,
occurring in certain alg<ae/ related to nostoc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodactyl</ent><br/
<hw>Het`er*o*dac"tyl</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Heterodactylous.</def> -- <def2><pos>n.</pos> <def>One of the
Heterodactyl<ae/.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodactylae</ent><br/
\'d8<hw>Het`e*ro*dac"ty*l<ae/</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ other + <?/ a finger.]</ety> <fld>(Zool.)</fld>
<def>A group of birds including the trogons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodactylous</ent><br/
<hw>Het`er*o*dac"tyl*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ a toe.]</ety> <fld>(Zool.)</fld>
<def>Having the first and second toes turned backward, as in the
trogons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodont</ent><br/
<hw>Het"er*o*dont</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/, <?/ a tooth.]</ety>
<fld>(Anat.)</fld> <def>Having the teeth differentiated into incisors,
canines, and molars, as in man; -- opposed to
<xex>homodont</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodont</ent><br/
<hw>Het"er*o*dont</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any animal
with heterodont dentition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodox</ent><br/
<hw>Het"er*o*dox</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/; <?/
other + <?/ opinion; cf. F. <ets>h<eacute/t<eacute/rodoxe</ets>.]</ety>
<sn>1.</sn> <def>Contrary to, or differing from, some acknowledged
standard, as the Bible, the creed of a church, the decree of a council,
and the like; not orthodox; heretical; -- said of opinions, doctrines,
books, etc., esp. upon theological subjects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Raw and indigested, <qex>heterodox</qex>, preaching.</q>
<rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Holding heterodox opinions, or doctrines not
orthodox; heretical; -- said of persons.</def>
<rj><au>Macaulay.</au></rj></p>

<p>-- <wordforms><wf>Het"er*o*dox`ly</wf>, <pos>adv.</pos> --
<wf>Het"er*o*dox`ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodox</ent><br/
<hw>Het"er*o*dox</hw>, <pos>n.</pos> <def>An opinion opposed to some
accepted standard.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodoxal</ent><br/
<hw>Het"er*o*dox`al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
orthodox.</def> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodoxy</ent><br/
<hw>Het"er*o*dox`y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf.
F. <ets>h<eacute/t<eacute/rodoxie</ets>.]</ety> <def>An opinion or
doctrine, or a system of doctrines, contrary to some established
standard of faith, as the Scriptures, the creed or standards of a
church, etc.; heresy.</def> <rj><au>Bp. Bull.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterodromous</ent><br/
<hw>Het`er*od"ro*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ to run.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Having spirals of changing direction.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>Moving in opposite directions; --
said of a lever, pulley, etc., in which the resistance and the actuating
force are on opposite sides of the fulcrum or axis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroecious</ent><br/
<hw>Het`er*<oe/"cious</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ house.]</ety> <fld>(Bot.)</fld>
<def>Passing through the different stages in its life history on an
alternation of hosts, as the common wheat-rust fungus (<spn>Puccinia
graminis</spn>), and certain other parasitic fungi; -- contrasted with
<contr>aut<oe/cious</contr>.</def> --
<wordforms><wf>Het`er*<oe/"cism</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Heterogamous</ent><br/
<hw>Het`er*og"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <grk>ga`mos</grk> marriage: cf. F.
<ets>h<eacute/t<eacute/rogame</ets>.]</ety> <fld>(Bot. & Biol.)</fld>
<sd>(a)</sd> <def>The condition of having two or more kinds of flowers
which differ in regard to stamens and pistils, as in the aster.</def>
<sd>(b)</sd> <def>Characterized by heterogamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogamy</ent><br/
<hw>Het`er*og"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Heterogamous</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>The process of fertilization in
plants by an indirect or circuitous method; -- opposed to
<xex>orthogamy</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>That form of alternate generation
in which two kinds of sexual generation, or a sexual and a
parthenogenetic generation, alternate; -- in distinction from
<contr>metagenesis</contr>, where sexual and asexual generations
alternate.</def> <rj><au>Claus & Sedgwick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogangliate</ent><br/
<hw>Het`er*o*gan"gli*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + <ets>gangliate</ets>.]</ety>
<fld>(Physiol.)</fld> <def>Having the ganglia of the nervous system
unsymmetrically arranged; -- said of certain invertebrate
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogene</ent><br/
<hw>Het"er*o*gene</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Heterogenous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogeneal</ent><br/
<hw>Het`er*o*ge"ne*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Heterogeneous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogeneity</ent><br/
<hw>Het`er*o*ge*ne"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>h<eacute/t<eacute/rog<eacute/n<eacute/it<eacute/</ets>.]</ety>
<def>The state of being heterogeneous; contrariety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The difference, indeed the <qex>heterogeneity</qex>, of the two
may be felt.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogeneous</ent><br/
<hw>Het`er*o*ge"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/;
<?/ + <?/ race, kind; akin to E. <ets>kin</ets>: cf. F.
<ets>h<eacute/t<eacute/rog<egrave/ne</ets>.]</ety> <def>Differing in
kind; having unlike qualities; possessed of different characteristics;
dissimilar; -- opposed to <xex>homogeneous</xex>, and said of two or
more connected objects, or of a conglomerate mass, considered in respect
to the parts of which it is made up.</def> --
<wordforms><wf>Het`er*o*ge"ne*ous*ly</wf>, <pos>adv.</pos> --
<wf>Het`er*o*ge"ne*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heterogeneous nouns</b></col> <fld>(Gram.)</fld>,
<cd>nouns having different genders in the singular and plural numbers;
as, <xex>hic locus</xex>, of the masculine gender in the singular, and
<xex>hi loci</xex> and <xex>h<ae/c loca</xex>, both masculine and neuter
in the plural; <xex>hoc c<ae/lum</xex>, neuter in the singular; <xex>hi
c<ae/li</xex>, masculine in the plural.</cd> -- <col><b>Heterogeneous
quantities</b></col> <fld>(Math.)</fld>, <cd>such quantities as are
incapable of being compared together in respect to magnitude, and
surfaces and solids.</cd> -- <col><b>Heterogeneous surds</b></col>
<fld>(Math.)</fld>, <cd>surds having different radical
signs.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogenesis</ent><br/
<hw>Het`er*o*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + <ets>genesis</ets>.]</ety> <sn>1.</sn>
<fld>(Biol.)</fld> <def>Spontaneous generation, so called.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>That method of reproduction in
which the successive generations differ from each other, the parent
organism producing offspring different in habit and structure from
itself, the original form, however, reappearing after one or more
generations; -- opposed to <contr>homogenesis</contr>, or
<contr>gamogenesis</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogenetic</ent><br/
<hw>Het`er*o*ge*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Biol.)</fld> <def>Relating to heterogenesis; <as>as,
<ex>heterogenetic</ex> transformations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogenist</ent><br/
<hw>Het`er*og"e*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>One who believes in the theory of spontaneous generation, or
heterogenesis.</def> <rj><au>Bastian.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogenous</ent><br/
<hw>Het`er*og"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of or pertaining to heterogenesis; heterogenetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogeny</ent><br/
<hw>Het`er*og"e*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>Heterogenesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogonous</ent><br/
<hw>Het`er*og"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Characterized by heterogony.</def> --
<wordforms><wf>Het`er*og"o*nous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogony</ent><br/
<hw>Het`er*og"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ offspring.]</ety> <fld>(Bot.)</fld>
<def>The condition of having two or more kinds of flowers, different as
to the length of their stamens and pistils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterographic</ent><br/
<hw>Het`er*o*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Heterography</er>.]</ety> <def>Employing the same letters to
represent different sounds in different words or syllables; -- said of
methods of spelling; <as>as, the ordinary English orthography is
<ex>heterographic</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterography</ent><br/
<hw>Het`er*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + <ets>-graphy</ets>.]</ety> <def>That method
of spelling in which the same letters represent different sounds in
different words, as in the ordinary English orthography; e. g.,
<xex>g</xex> in <xex>get</xex> and in <xex>ginger</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterogynous</ent><br/
<hw>Het`er*og"y*nous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ a woman, female.]</ety>
<fld>(Zool.)</fld> <def>Having females very unlike the males in form and
structure; -- as certain insects, the males of which are winged, and the
females wingless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterologous</ent><br/
<hw>Het`er*ol"o*gous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ proportion.]</ety> <def>Characterized
by heterology; consisting of different elements, or of like elements in
different proportions; different; -- opposed to <xex>homologous</xex>;
<as>as, <ex>heterologous</ex> organs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Heterologous stimulus</b></col>. <fld>(Physiol.)</fld>
<cd>See under <er>Stimulus</er>.</cd> -- <col><b>Heterologous
tumor</b></col> <fld>(Med.)</fld>, <cd>a tumor differing in structure
from the normal tissues of the body.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterology</ent><br/
<hw>Het`er*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + <ets>-logy</ets>.]</ety> <sn>1.</sn>
<fld>(Biol.)</fld> <def>The absence of correspondence, or relation, in
type of structure; lack of analogy between parts, owing to their being
composed of different elements, or of like elements in different
proportions; variation in structure from the normal form; -- opposed to
<xex>homology</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The connection or relation of
bodies which have partial identity of composition, but different
characteristics and properties; the relation existing between
derivatives of the same substance, or of the analogous members of
different series; <as>as, ethane, ethyl alcohol, acetic aldehyde, and
acetic acid are in <ex>heterology</ex> with each other, though each in
at the same time a member of a distinct homologous series</as>. Cf.
<er>Homology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteromera</ent><br/
\'d8<hw>Het`e*rom"e*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ other + <?/ part.]</ety> <fld>(Zool.)</fld> <def>A division
of Coleoptera, having heteromerous tarsi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteromerous</ent><br/
<hw>Het`er*om"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Heteromera</er>.]</ety> <sn>1.</sn> <fld>(Chem & Crystallog.)</fld>
<def>Unrelated in chemical composition, though similar or indentical in
certain other respects; <as>as, borax and augite are hom<oe/morphous,
but <ex>heteromerous</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>With the parts not corresponding
in number.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Having the femoral
artery developed as the principal artery of the leg; -- said of certain
birds, as the cotingas and pipras.</def> <sd>(b)</sd> <def>Having five
tarsal joints in the anterior and middle legs, but only four in the
posterior pair, as the blister beetles and oil beetles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteromorphic</ent><br/
<hw>Het`er*o*mor"phic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <grk>morfh`</grk> form.]</ety>
<fld>(Biol.)</fld> <def>Deviating from the normal, perfect, or mature
form; having different forms at different stages of existence, or in
different individuals of the same species; -- applied especially to
insects in which there is a wide difference of form between the larva
and the adult, and to plants having more than one form of
flower.</def></p>

<p><ent>Heteromorphy</ent><br/
<ent>Heteromorphism</ent><br/
<mhw>{ <hw>Het`er*o*mor"phism</hw> <pr>(?)</pr>,
<hw>Het`er*o*mor"phy</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<fld>(Biol.)</fld> <def>The state or quality of being
heteromorphic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteromorphous</ent><br/
<hw>Het`er*o*mor"phous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Biol.)</fld> <def>Heteromorphic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteromyaria</ent><br/
\'d8<hw>Het`e*ro*my*a"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ other + <?/ a muscle.]</ety> <fld>(Zool.)</fld>
<def>A division of bivalve shells, including the marine mussels, in
which the two adductor muscles are very unequal. See <er>Dreissena</er>,
and <xex>Illust.</xex> under <er>Byssus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteronereis</ent><br/
\'d8<hw>Het`e*ro*ne*re"is</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hetero-</er>, and <er>Nereis</er>.]</ety> <fld>(Zool.)</fld> <def>A
free-swimming, dimorphic, sexual form of certain species of
Nereis.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this state the head and its appendages are changed in
form, the eyes become very large; more or less of the parapodia are
highly modified by the development of finlike lobes, and branchial
lamell<ae/, and their set<ae/ become longer and bladelike.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteronomous</ent><br/
<hw>Het`er*on"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <grk>no`mos</grk> law.]</ety>
<def>Subject to the law of another.</def>
<rj><au>Krauth-Fleming.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteronomy</ent><br/
<hw>Het`er*on"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Subordination or subjection to the law of another; political
subjection of a community or state; -- opposed to
<xex>autonomy</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metaph.)</fld> <def>A term applied by Kant to those
laws which are imposed on us from without, or the violence done to us by
our passions, wants, or desires.</def>
<rj><au>Krauth-Fleming.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteronym</ent><br/
<hw>Het"er*o*nym</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which is
heteronymous; a thing having a different name or designation from some
other thing; -- opposed to <xex>homonym</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteronymous</ent><br/
<hw>Het`er*on"y*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <grk>"o`nyma</grk>, for
<grk>"o`noma</grk> a name.]</ety> <def>Having different names or
designations; standing in opposite relations.</def> <rj><au>J. Le
Conte.</au></rj></p>

<p>-- <wordforms><wf>Het"er*on"y*mous*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroousian</ent><br/
<hw>Het`er*o*ou`si*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ being, essence.]</ety> <def>Having
different essential qualities; of a different nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroousian</ent><br/
<hw>Het`er*o*ou"si*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>One of those Arians who held that the Son was of a
different substance from the Father.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroousious</ent><br/
<hw>Het`er*o*ou"si*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Heteroousian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropathic</ent><br/
<hw>Het`er*o*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ suffering, fr. <?/, <?/, to
suffer.]</ety> <def>Of or pertaining to the method of heteropathy;
allopathic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropathy</ent><br/
<hw>Het`er*op"a*thy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Heteropathic</er>.]</ety> <fld>(Med.)</fld> <def>That mode of
treating diseases, by which a morbid condition is removed by inducing an
opposite morbid condition to supplant it; allopathy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropelmous</ent><br/
<hw>Het`er*o*pel"mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ the sole of the foot.]</ety>
<fld>(Anat.)</fld> <def>Having each of the two flexor tendons of the
toes bifid, the branches of one going to the first and second toes;
those of the other, to the third and fourth toes. See <xex>Illust.</xex>
in Append.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterophagi</ent><br/
\'d8<hw>Het`e*roph"a*gi</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ other + <?/ to eat.]</ety> <fld>(Zool.)</fld>
<def>Altrices.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterophemist</ent><br/
<hw>Het`er*oph"e*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One liable
to the fault of heterophemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterophemy</ent><br/
<hw>Het`er*oph"e*my</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ voice, speech, fr. <?/ to
speak.]</ety> <def>The unconscious saying, in speech or in writing, of
that which one does not intend to say; -- frequently the very reverse of
the thought which is present to consciousness.</def><-- Freudian slip
--> <rj><au>R. G. White.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterophony</ent><br/
<hw>Het`er*oph"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ voice.]</ety> <fld>(Med.)</fld>
<def>An abnormal state of the voice.</def> <rj><au>Mayne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterophyllous</ent><br/
<hw>Het`er*oph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
other + <?/ leaf: cf. F. <ets>h<eacute/t<eacute/rophylle</ets>.]</ety>
<fld>(Bot.)</fld> <def>Having leaves of more than one shape on the same
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroplasm</ent><br/
<hw>Het"er*o*plasm</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ anything formed or molded.]</ety>
<def>An abnormal formation foreign to the economy, and composed of
elements different from those are found in it in its normal
condition.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroplastic</ent><br/
<hw>Het`er*o*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + <ets>-plastic</ets>.]</ety>
<fld>(Biol.)</fld> <def>Producing a different type of organism;
developing into a different form of tissue, as cartilage which develops
into bone.</def> <rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropod</ent><br/
<hw>Het`er*o*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>h<eacute/t<eacute/ropode</ets>.]</ety> <fld>(Zool.)</fld> <def>One
of the Heteropoda.</def> -- <def2><pos>a.</pos>
<def>Heteropodous.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropoda</ent><br/
\'d8<hw>Het`e*rop"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ other + <ets>-poda</ets>.]</ety> <fld>(Zool.)</fld> <def>An
order of pelagic Gastropoda, having the foot developed into a median
fin. Some of the species are naked; others, as <gen>Carinaria</gen> and
<gen>Atlanta</gen>, have thin glassy shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropodous</ent><br/
<hw>Het`er*op"o*dous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Heteropoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteropter</ent><br/
<hw>Het`er*op"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the
Heteroptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroptera</ent><br/
\'d8<hw>Het`e*rop"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <?/ other + <?/ a wing.]</ety> <fld>(Zool.)</fld> <def>A
suborder of Hemiptera, in which the base of the anterior wings is
thickened. See <er>Hemiptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroptics</ent><br/
<hw>Het`er*op"tics</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + <ets>optics</ets>.]</ety> <def>False
optics.</def> <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heteroscian</ent><br/
<hw>Het`er*os"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/
other + <?/ shadow: cf. F. <ets>h<eacute/t<eacute/roscien</ets>.]</ety>
<def>One who lives either north or south of the tropics, as contrasted
with one who lives on the other side of them; -- so called because at
noon the shadows always fall in opposite directions (the one northward,
the other southward).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterosis</ent><br/
\'d8<hw>Het`e*ro"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ alteration, fr. <?/ other, different.]</ety> <fld>(Rhet.)</fld>
<def>A figure of speech by which one form of a noun, verb, or pronoun,
and the like, is used for another, as in the sentence: <ldquo/What is
life to such as <xex>me</xex>?<rdquo/</def>
<rj><au>Aytoun.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterosomati</ent><br/
\'d8<hw>Het`e*ro*so"ma*ti</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ other + <?/, <?/, body.]</ety> <fld>(Zool.)</fld>
<def>An order of fishes, comprising the flounders, halibut, sole, etc.,
having the body and head asymmetrical, with both eyes on one side.
Called also <altname>Heterosomata</altname>,
<altname>Heterosomi</altname>.</def></p>

<p><ent>Heterosporous</ent><br/
<ent>Heterosporic</ent><br/
<mhw>{ <hw>Het`er*o*spor"ic</hw> <pr>(?)</pr>,
<hw>Het`er*o*spor"ous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Hetero-</ets> + <ets>spore</ets>.]</ety> <fld>(Bot.)</fld>
<def>Producing two kinds of spores unlike each other.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterostyled</ent><br/
<hw>Het"er*o*styled</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having styles of two or more distinct forms or lengths.</def>
<rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterostylism</ent><br/
<hw>Het`er*o*sty"lism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The condition of being heterostyled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterotactous</ent><br/
<hw>Het`er*o*tac"tous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Biol.)</fld> <def>Relating to, or characterized by,
heterotaxy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heterotaxy</ent><br/
<hw>Het"er*o*tax`y</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hetero-</ets> + Gr. <?/ an arrangement, fr. <?/ to
arrange.]</ety> <fld>(Biol.)</fld> <def>Variation in arrangement from
that existing in a normal form; heterogenous arrangement or structure,
<as>as, in botany, the deviation in position of the organs of a plant,
from the ordinary or typical arrangement</as>.</def></p>

<p><ent>Heterotopy</ent><br/
<ent>Heterotopism</ent><br/
<mhw>{ <hw>Het`er*ot"o*pism</hw> <pr>(?)</pr>, <hw>Het`er*ot"o*py</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[<ets>Hetero-</ets> + Gr. <?/
place: cf. F. <ets>h<eacute/t<eacute/rotopie</ets>.]</ety> <sn>1.</sn>
<fld>(Med.)</fld> <def>A deviation from the natural position; -- a term
applied in the case of organs or growths which are abnormal in
situation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>A deviation from the natural
position of parts, supposed to be effected in thousands of years, by the
gradual displacement of germ cells.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 691 --></p>

<p><ent>Heterotricha</ent><br/
\'d8<hw>Het`e*rot"ri*cha</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ other + <?/, gen. <?/, a hair.]</ety> <fld>(Zool.)</fld>
<def>A division of ciliated Infusoria, having fine cilia all over the
body, and a circle of larger ones around the anterior end.</def></p>

<p><ent>Heterotropous</ent><br/
<ent>Heterotropal</ent><br/
<mhw><hw>Het`er*ot"ro*pal</hw> <pr>(?)</pr>, <hw>Het`er*ot"ro*pous</hw>
<pr>(<?/)</pr></mhw>, <pos>a.</pos> <ety>[Gr. <grk>"etero`tropos</grk>
turning another way; <?/ other + <?/ to turn: cf. F.
<ets>h<eacute/t<eacute/rotrope</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having the embryo or ovule oblique or transverse to the funiculus;
amphitropous.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hething</ent><br/
<hw>He"thing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Contempt;
scorn.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hetman</ent><br/
<hw>Het"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hetmans</plw> <pr>(#)</pr>.</plu> <ety>[Pol. <ets>hetman</ets>. Cf.
<er>Ataman</er>.]</ety> <def>A Cossack headman or general. The title of
<xex>chief hetman</xex> is now held by the heir to the throne of
Russia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heuchera</ent><br/
<hw>Heuchera</hw> <pos>n.</pos> <def>A genus of North American herbs
with basal cordate or orbicular leaves and small panicled
flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Heuchera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Heugh</ent><br/
<hw>Heugh</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Hogh</er>.]</ety> <sn>1.</sn> <def>A crag; a cliff; a glen with
overhanging sides.</def> <mark>[Scot. & Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A shaft in a coal pit; a hollow in a quarry.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heuk</ent><br/
<hw>Heuk</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Variant of
<er>Huke</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heulandite</ent><br/
<hw>Heu"land*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[After
<ets>Heuland</ets>, an English mineralogist.]</ety> <fld>(Min.)</fld>
<def>A mineral of the Zeolite family, often occurring in amygdaloid, in
foliated masses, and also in monoclinic crystals with pearly luster on
the cleavage face. It is a hydrous silicate of alumina and
lime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heuristic</ent><br/
<hw>Heu*ris"tic</hw> <pr>(h<usl/*r<icr/s"t<icr/k)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>e"yri`skein</grk> to discover.]</ety> <sn>1.</sn>
<def>Serving to promote discovery or learning; -- used especially of
thories or paradigms which stimulate new ideas for discovering facts in
experimental sciences.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Serving to stimulate people to learn and discover on
their own, especially by encouraging experimental and trial-and-error
methods for solving problems.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Pertaining to or based on trial-and-error and
experimental methods of learning and evaluation.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Computers)</fld> <def>Based on the use of an
efficient trial-and error method to search a space of possible solutions
to a problem, or to find an acceptable approximate solution, when an
exact algorithmic method is unavailable or too time-consuming.</def><br/
[<source>PJC</source>]</p>

<p><ent>Heuristic</ent><br/
<hw>Heu*ris"tic</hw> <pr>(h<usl/*r<icr/s"t<icr/k)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A heuristic method; a specific heuristic
procedure.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A theory or approach which serves to promote
discovery or learning by encouraging experimentation.</def><br/
[<source>PJC</source>]</p>

<p><ent>heuristically</ent><br/
<hw>heu*ris"ti*cal*ly</hw>
<pr>(h<usl/*r<icr/s"t<icr/*k<ait/l*l<ycr/)</pr>, <pos>n.</pos> <def>In a
heuristic manner; by using a heuristic method; by serving as a heuristic
method; <as>as, a <ex>heuristically</ex> guided search technique; a
<ex>heuristically</ex> valuable theory</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hevea</ent><br/
<hw>Hevea</hw> <pos>prop. n.</pos> <def>A small genus of South American
trees yielding latex. It includes the <stype>rubber tree</stype>,
<spn>Hevea brasiliensis</spn>, originally found in South America, but
now used for production of rubber world-wide.</def><br/
<syn><b>Syn. --</b> genus <gen>Hevea</gen>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Heved</ent><br/
<hw>Hev"ed</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The head.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hew</ent><br/
<hw>Hew</hw> <pr>(h<umac/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Hewed</conjf> <pr>(h<umac/d)</pr>;
<pos>p. p.</pos> <conjf>Hewed</conjf> or <conjf>Hewn</conjf>
<pr>(h<umac/n)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hewing</conjf>.]</vmorph> <ety>[AS. <ets>he<aacute/wan</ets>;
akin to D. <ets>houwen</ets>, OHG. <ets>houwan</ets>, G.
<ets>hauen</ets>, Icel. <ets>h<oum/ggva</ets>, Sw. <ets>hugga</ets>,
Dan. <ets>hugge</ets>, Lith. <ets>kova</ets> battle, Russ.
<ets>kovate</ets> to hammer, forge. Cf. <er>Hay</er> cut grass,
<er>Hoe</er>.]</ety> <sn>1.</sn> <def>To cut with an ax; to fell with a
sharp instrument; -- often with <xex>down</xex>, or
<xex>off</xex>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form or shape with a sharp instrument; to cut;
hence, to form laboriously; -- often with <xex>out</xex>; <as>as, to
<ex>hew</ex> out a sepulcher</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Look unto the rock whence ye are <qex>hewn</qex>.</q> <rj><qau>Is.
li. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Rather polishing old works than <qex>hewing</qex> out new.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cut in pieces; to chop; to hack.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hew</qex> them to pieces; hack their bones asunder.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hew</ent><br/
<hw>Hew</hw>, <pos>n.</pos> <def>Destruction by cutting down.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of whom he makes such havoc and such <qex>hew</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hew</ent><br/
<hw>Hew</hw>, <pos>n.</pos> <sn>1.</sn> <def>Hue; color.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Shape; form.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hewe</ent><br/
<hw>Hewe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Hind</er> a
peasant.]</ety> <def>A domestic servant; a retainer.</def>
<mark>[Obs.]</mark> <ldquo/False homely <xex>hewe</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hewer</ent><br/
<hw>Hew"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hews.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hewhole</ent><br/
<hw>Hew"hole`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Hickwall</er>.]</ety> <fld>(Zool.)</fld> <def>The European green
woodpecker. See <er>Yaffle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hewn</ent><br/
<hw>Hewn</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Felled, cut,
or shaped as with an ax; roughly squared; <as>as, a house built of
<ex>hewn</ex> logs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Roughly dressed as with a hammer; <as>as,
<ex>hewn</ex> stone</as>.</def></p>

<p><ent>Hexa</ent><br/
<ent>Hex-</ent><br/
<mhw><hw>Hex-</hw> <pr>(?)</pr>, <hw>Hex"a</hw> <pr>(#)</pr></mhw>.
<ety>[Gr. <grk>"e`x</grk> six. See <er>Six</er>.]</ety> <def>A prefix or
combining form, used to denote <xex>six</xex>, <xex>sixth</xex>, etc.;
<as>as, <ex>hex</ex>atomic, <ex>hexa</ex>basic</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexabasic</ent><br/
<hw>Hex`a*ba"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hexa-</ets>
+ <ets>basic</ets>.]</ety> <fld>(Chem.)</fld> <def>Having six hydrogen
atoms or six radicals capable of being replaced or saturated by bases;
-- said of acids; <as>as, mellitic acid is
<ex>hexabasic</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexacapsular</ent><br/
<hw>Hex`a*cap"su*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hexa-</ets> + <ets>capsular</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having six capsules or seed vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexachord</ent><br/
<hw>Hex"a*chord</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hexa-</ets>
+ Gr. <?/ string, chord: cf. F. <ets>hexacorde</ets>.]</ety>
<fld>(Mus.)</fld> <def>A series of six notes, with a semitone between
the third and fourth, the other intervals being whole tones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexacid</ent><br/
<hw>Hex`ac"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hex-</ets> +
<ets>acid</ets>.]</ety> <fld>(Chem.)</fld> <def>Having six atoms or
radicals capable of being replaced by acids; hexatomic; hexavalent; --
said of bases; <as>as, mannite is a <ex>hexacid</ex>
base</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexactinellid</ent><br/
<hw>Hex*ac`ti*nel"lid</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having six-rayed spicules; belonging to the
<fam>Hexactinellin<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexactinelline</ent><br/
<hw>Hex*ac`ti*nel"line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From NL.
<ets>Hexactinellin<ae/</ets>, fr. Gr. <grk>"e`x</grk> six + a dim. of
<?/, <?/, a ray.]</ety> <fld>(Zool.)</fld> <def>Belonging to the
<fam>Hexactinellin<ae/</fam>, a group of sponges, having six-rayed
siliceous spicules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexactinia</ent><br/
\'d8<hw>Hex`ac*tin"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Hex-</er>, and <er>Actinia</er>.]</ety> <fld>(Zool.)</fld>
<def>The Anthozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexad</ent><br/
<hw>Hex"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>hexas</ets>,
<ets>hexadis</ets>, the number six, Gr. <?/, <?/, fr. <grk>"e`x</grk>
six.]</ety> <fld>(chem.)</fld> <def>An atom whose valence is six, and
which can be theoretically combined with, substituted for, or replaced
by, <xex>six</xex> monad atoms or radicals; <as>as, sulphur is a
<ex>hexad</ex> in sulphuric acid</as>. Also used as an
adjective.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexadactylous</ent><br/
<hw>Hex`a*dac"tyl*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/;
<grk>"e`x</grk> six + <?/ finger: cf. F. <ets>hexadactyle</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having six fingers or toes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexade</ent><br/
<hw>Hex"ade</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hexad</er>.]</ety> <def>A series of six numbers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexadecane</ent><br/
<hw>Hex"a*dec`ane</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Hecdecane</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexagon</ent><br/
<hw>Hex"a*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hexagonum</ets>, Gr. <?/ six-cornered; <grk>"e`x</grk> six (akin to
E. <ets>six</ets>) + <?/ angle.]</ety> <fld>(Geom.)</fld> <def>A plane
figure of six angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regular hexagon</b></col>, <cd>a hexagon in which the
angles are all equal, and the sides are also all equal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexagonal</ent><br/
<hw>Hex*ag"o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hexagonal</ets>.]</ety> <def>Having six sides and six angles;
six-sided.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hexagonal system</b></col>. <fld>(Crystal.)</fld> <cd>See
under <er>Crystallization</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexagonally</ent><br/
<hw>Hex*ag"o*nal*ly</hw>, <pos>adv.</pos> <def>In an hexagonal
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexagony</ent><br/
<hw>Hex*ag"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hexagon.</def>
<mark>[Obs.]</mark> <rj><au>Bramhall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexagram</ent><br/
<hw>Hex"a*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hexa-</ets> +
<ets>-gram</ets>.]</ety> <def>A figure of six lines</def>; specif.:
<sd>(a)</sd> <def>A figure composed of two equal triangles intersecting
so that each side of one triangle is parallel to a side of the other,
and the six points coincide with those of a hexagon.</def> <sd>(b)</sd>
<def>In Chinese literature, one of the sixty-four figures formed of six
parallel lines (continuous or broken), forming the basis of the I Ching
(Yih King), or <ldquo/Book of Changes.<rdquo/</def> <rj><au>S. W.
Williams.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hexagynia</ent><br/
\'d8<hw>Hex`a*gyn"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"e`x</grk> six + <grk>gynh^</grk> a woman, female: cf. F.
<ets>hexagynie</ets>.]</ety> <fld>(Bot.)</fld> <def>A Linn<ae/an order
of plants having six pistils.</def></p>

<p><ent>Hexagynous</ent><br/
<ent>Hexagynian</ent><br/
<mhw><hw>Hex`a*gyn"i*an</hw> <pr>(?)</pr>, <hw>Hex*ag"y*nous</hw>
<pr>(<?/)</pr></mhw>, <pos>a.</pos> <ety>[Cf. F.
<ets>hexagyne</ets>.]</ety> <fld>(Bot.)</fld> <def>Having six
pistils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexahedral</ent><br/
<hw>Hex`a*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos> <def>In the form of a
hexahedron; having six sides or faces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexahedron</ent><br/
<hw>Hex`a*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Hexahedrons</plw> <pr>(#)</pr>, L. <plw>Hexahedra</plw>
<pr>(#)</pr>.</plu> <ety>[<ets>Hexa-</ets> + Gr. <?/ seat, base, fr. <?/
to sit: cf. F. <ets>hexa<egrave/dre</ets>.]</ety> <fld>(Geom.)</fld>
<def>A solid body of six sides or faces.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regular hexahedron</b></col>, <cd>a hexagon having six
equal squares for its sides; a cube.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexahemeron</ent><br/
<hw>Hex`a*hem"er*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>"e`x</grk> six + <?/ day; cf. L. <ets>hexa<eum/meron</ets>, Gr.
<?/.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A term of six days.</def>
<rj><au>Good.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The history of the six day's work of creation, as
contained in the first chapter of Genesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexamerous</ent><br/
<hw>Hex*am"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hexa-</ets> + Gr.<?/ part.]</ety> <fld>(Bot.)</fld> <def>In
six parts; in sixes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexameter</ent><br/
<hw>Hex*am"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/
of six meters; (sc. <?/) hexameter verse; <grk>"e`x</grk> six + <?/
measure: cf. F. <ets>hexam<egrave/tre</ets>. See <er>Six</er>, and
<er>Meter</er>.]</ety> <fld>(Gr. & Lat. Pros.)</fld> <def>A verse of six
feet, the first four of which may be either dactyls or spondees, the
fifth must regularly be a dactyl, and the sixth always a spondee. In
this species of verse are composed the Iliad of Homer and the Aeneid of
Virgil. In English hexameters accent takes the place of
quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leaped like the | roe when he | hears in the | woodland the |
voice of the | huntsman.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Strongly it | bears us a- | long on | swelling and | limitless |
billows,<br/
Nothing be- | fore and | nothing be- | hind but the | sky and the |
ocean.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexameter</ent><br/
<hw>Hex*am"e*ter</hw>, <pos>a.</pos> <def>Having six metrical feet,
especially dactyls and spondees.</def> <rj><au>Holland.</au></rj></p>

<p><ent>Hexametrical</ent><br/
<ent>Hexametric</ent><br/
<mhw>{ <hw>Hex`a*met"ric</hw> <pr>(?)</pr>, <hw>Hex`a*met"ric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Consisting of six metrical
feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexametrist</ent><br/
<hw>Hex*am"e*trist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who writes
in hexameters.</def> <ldquo/The Christian
<xex>hexametrists</xex>.<rdquo/ <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexandria</ent><br/
\'d8<hw>Hex*an"dri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>"e`x</grk> six + <?/, <?/, a man, male: cf. F.
<ets>hexandrie</ets>.]</ety> <fld>(Bot.)</fld> <def>A Linn<ae/an class
of plants having six stamens.</def></p>

<p><ent>Hex-androus</ent><br/
<ent>Hexandrian</ent><br/
<mhw>{ <hw>Hex*an"dri*an</hw> <pr>(?)</pr>, <hw>Hex-an"drous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>hexandre</ets>.]</ety> <fld>(Bot.)</fld> <def>Having six
stamens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexane</ent><br/
<hw>Hex"ane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>"e`x</grk>
six.]</ety> <fld>(Chem.)</fld> <def>Any one of five hydrocarbons,
<chform>C6H14</chform>, of the paraffin series. They are colorless,
volatile liquids, and are so called because the molecule has
<xex>six</xex> carbon atoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexangular</ent><br/
<hw>Hex*an"gu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hex-</ets>
+ <ets>angular</ets>. Cf. <er>Sexangular</er>.]</ety> <def>Having six
angles or corners.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexapetalous</ent><br/
<hw>Hex`a*pet"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hexa-</ets> + <ets>petal</ets>: cf. F.
<ets>hexap<eacute/tale</ets>.]</ety> <fld>(Bot.)</fld> <def>Having six
petals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexaphyllous</ent><br/
<hw>Hex*aph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hexa-</ets> + Gr. <?/ a leaf: cf. F.
<ets>hexaphylle</ets>.]</ety> <fld>(Bot.)</fld> <def>Having six leaves
or leaflets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexapla</ent><br/
\'d8<hw>Hex"a*pla</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>Etym.
<pos>pl.</pos>, but syntactically <pos>sing.</pos></ety> <ety>[NL., fr.
Gr. <?/, fr. <?/, contr. <?/, sixfold.]</ety> <def>A collection of the
Holy Scriptures in six languages or six versions in parallel columns;
particularly, the edition of the Old Testament published by Origen, in
the 3d century.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexapod</ent><br/
<hw>Hex"a*pod</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, <?/,
sixfooted; <grk>"e`x</grk> six + <?/, <?/, foot: cf. F.
<ets>hexapode</ets>.]</ety> <def>Having six feet.</def> --
<def2><pos>n.</pos> <fld>(Zool.)</fld> <def>An animal having six feet;
one of the Hexapoda.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexapoda</ent><br/
\'d8<hw>Hex*ap"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>"e`x</grk> six + <ets>-poda</ets>.]</ety> <fld>(Zool.)</fld>
<def>The true, or six-legged, insects; insects other than myriapods and
arachnids.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Hexapoda have the head, thorax, and abdomen
differentiated, and are mostly winged. They have three pairs of mouth
organs, viz., mandibles, maxill<ae/, and the second maxill<ae/ or labial
palpi; three pairs of thoracic legs; and abdominal legs, which are
present only in some of the lowest forms, and in the larval state of
some of the higher ones. Many (the Metabola) undergo a complete
metamorphosis, having larv<ae/ (known as maggots, grubs, caterpillars)
very unlike the adult, and pass through a quiescent pupa state in which
no food is taken; others (the Hemimetabola) have larv<ae/ much like the
adult, expert in lacking wings, and an active pupa, in which rudimentary
wings appear. See <er>Insecta</er>. The Hexapoda are divided into
several orders.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexapodous</ent><br/
<hw>Hex*ap"o*dous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having six feet; belonging to the Hexapoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexapterous</ent><br/
<hw>Hex*ap"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hexa-</ets> + Gr. <?/ wing.]</ety> <fld>(Bot.)</fld>
<def>Having six processes.</def> <rj><au>Gray.</au></rj></p>

<p><ent>Hexastichon</ent><br/
<ent>Hexastich</ent><br/
<mhw>{ <hw>Hex"a*stich</hw> <pr>(?)</pr>, \'d8<hw>Hex*as"ti*chon</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>hexastichus</ets> of
six rows, lines, or verses, Gr. <?/; <grk>"e`x</grk> six +
<grk>sti`chos</grk> row, line, verse.]</ety> <def>A poem consisting of
six verses or lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexastyle</ent><br/
<hw>Hex"a*style</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ with six
columns; <grk>"e`x</grk> six + column: cf. F.
<ets>hexastyle</ets>.]</ety> <fld>(Arch.)</fld> <def>Having six columns
in front; -- said of a portico or temple.</def> -- <def2><pos>n.</pos>
<def>A hexastyle portico or temple.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexateuch</ent><br/
<hw>Hex"a*teuch`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hexa-</ets>
+ <?/ a tool, a book.]</ety> <def>The first six books of the Old
Testament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexatomic</ent><br/
<hw>Hex`a*tom"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hex-</ets>
+ <ets>atomic</ets>.]</ety> <fld>(Chem.)</fld> <sd>(a)</sd> <def>Having
six atoms in the molecule.</def> <mark>[R.]</mark> <sd>(b)</sd>
<def>Having six replaceable radicals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexavalent</ent><br/
<hw>Hex*av"a*lent</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hexa-</ets> + L. <ets>valens</ets>, <ets>-entis</ets>,
<pos>p. pr.</pos> See <er>Valence</er>.]</ety> <fld>(Chem.)</fld>
<def>Having a valence of six; -- said of hexads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexdecyl</ent><br/
<hw>Hex"de*cyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hex-</ets> +
<ets>decyl</ets>.]</ety> <fld>(Chem.)</fld> <def>The essential radical,
<chform>C16H33</chform>, of hecdecane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexdecylic</ent><br/
<hw>Hex`de*cyl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, hexdecyl or hecdecane; <as>as,
<ex>hexdecylic</ex> alcohol</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexeikosane</ent><br/
<hw>Hex*ei"ko*sane</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hex-</ets> + <ets>eikosane</ets>.]</ety> <fld>(chem.)</fld>
<def>A hydrocarbon, <chform>C26H54</chform>, resembling paraffine; -- so
called because each molecule has <xex>twenty-six</xex> atoms of
carbon.</def> <altsp>[Written also <asp>hexacosane</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexene</ent><br/
<hw>Hex"ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>"e`x</grk>
six.]</ety> <fld>(Chem.)</fld> <def>Same as <er>Hexylene</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexicology</ent><br/
<hw>Hex`i*col"ogy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ state
or habit + <ets>-logy</ets>.]</ety> <def>The science which treats of the
complex relations of living creatures to other organisms, and to their
surrounding conditions generally.</def> <-- = ecology --> <rj><au>St.
George Mivart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexine</ent><br/
<hw>Hex"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>"e`x</grk>
six.]</ety> <fld>(Chem.)</fld> <def>A hydrocarbon,
<chform>C6H10</chform>, of the acetylene series, obtained artificially
as a colorless, volatile, pungent liquid; -- called also
<altname>hexoylene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexoctahedron</ent><br/
<hw>Hex*oc`ta*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hex-</ets> + <ets>octahedron</ets>.]</ety> <fld>(Geom.)</fld>
<def>A solid having forty-eight equal triangular faces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexoic</ent><br/
<hw>Hex*o"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, hexane; <as>as, <ex>hexoic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexokinase</ent><br/
<hw>Hex"o*kin"ase</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hexo</ets>se + <ets>-kinase</ets>.]</ety>
<fld>(Biochem.)</fld> <def>an enzyme catalyzing the transfer of a
phosphate residue from ATP to a hexose, as in the formation of
glucose-6-phosphate from glucose.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hexone</ent><br/
<hw>Hex"one</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hex-</ets> +
<ets>-one</ets>.]</ety> <fld>(Chem.)</fld> <def>A liquid hydrocarbon,
<chform>C6H8</chform>, of the valylene series, obtained from
distillation products of certain fats and gums.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexose</ent><br/
<hw>Hex"ose</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hexa-</ets> +
<ets>-ose</ets>.]</ety> <fld>(Chem.)</fld> <def>Any member of a group of
sugars containing six carbon atoms in the molecule. Some are widely
distributed in nature, esp. in ripe fruits.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hexyl</ent><br/
<hw>Hex"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hex-</ets> +
<ets>-yl</ets>.]</ety> <fld>(chem.)</fld> <def>A univalent organic
radical, <chform>C6H13-</chform>, regarded as the essential residue of
<xex>hexane</xex>, and a related series of compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexylene</ent><br/
<hw>Hex"yl*ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hex-</ets> +
<ets>-yl</ets> + ethl<ets>ene</ets>.]</ety> <fld>(Chem.)</fld> <def>A
colorless, liquid hydrocarbon, <chform>C6H12</chform>, of the ethylene
series, produced artificially, and found as a natural product of
distillation of certain coals; also, any one several isomers of hexylene
proper. Called also <altname>hexene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hexylic</ent><br/
<hw>Hex*yl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(chem.)</fld>
<def>Pertaining to, or derived from, hexyl or hexane; <as>as,
<ex>hexylic</ex> alcohol</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hey</ent><br/
<hw>Hey</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>High</er>.]</ety>
<def>High.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hey</ent><br/
<hw>Hey</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[OE. <ets>hei</ets>;
cf. D. & G. <ets>hei</ets>.]</ety> <sn>1.</sn> <def>An exclamation of
joy, surprise, or encouragement.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cry to set dogs on.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heyday</ent><br/
<hw>Hey"day`</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Cf. G.
<ets>heida</ets>, or <ets>hei da</ets>, D. <ets>hei daar</ets>. Cf.
<er>Hey</er>, and <er>There</er>.]</ety> <def>An expression of frolic
and exultation, and sometimes of wonder.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heyday</ent><br/
<hw>Hey"day`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. for. <ets>high
day</ets>. See <ets>High</ets>, and <er>Day</er>.]</ety> <def>The time
of triumph and exultation; hence, joy, high spirits, frolicsomeness;
wildness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>heyday</qex> in the blood is tame.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>heyday</qex> of their victories.</q> <rj><qau>J. H.
Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heydeguy</ent><br/
<hw>Hey"de*guy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. fr.
<ets>heyday + guise</ets>.]</ety> <def>A kind of country-dance or
round.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj></p>

<p><ent>Heygh</ent><br/
<ent>Heyh</ent><br/
<mhw><hw>Heyh</hw>, <hw>Heygh</hw> <pr>(<?/)</pr></mhw>, <pos>a.</pos>
<def>High.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heyne</ent><br/
<hw>Heyne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>he<aacute/n</ets> low, mean.]</ety> <def>A wretch; a rascal.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Heyten</ent><br/
<hw>Hey"ten</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[Icel.
<ets>h<?/<?/an</ets>.]</ety> <def>Hence.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiation</ent><br/
<hw>Hi*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hiatus</er>.]</ety> <def>Act of gaping.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiatus</ent><br/
<hw>Hi*a"tus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Hiatus</plw>, E. <plw>Hiatuses</plw> <pr>(#)</pr>.</plu> <ety>[L.,
fr. <ets>hiare</ets>, <ets>hiatum</ets>, to gape; akin to E.
<ets>yawn</ets>. See <er>Yawn</er>.]</ety> <sn>1.</sn> <def>An opening;
an aperture; a gap; a chasm; esp., a defect in a manuscript, where some
part is lost or effaced; a space where something is wanting; a
break.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>The concurrence of two vowels in
two successive words or syllables.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hibbertia</ent><br/
<hw>Hibbertia</hw> <pos>n.</pos> <def>A genus of evergreen heathlike or
scandent shrubs of Madagascar, Australasia, and Polynesia.</def><br/
<syn><b>Syn. --</b> genus <gen>Hibbertia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hibernacle</ent><br/
<hw>Hi*ber"na*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hibernaculum</ets> a winter residence, pl. <ets>hibernacula</ets>
winter quarters: cf. F. <ets>hibernacle</ets>. See
<er>Hibernate</er>.]</ety> <def>That which serves for protection or
shelter in winter; winter quarters; <as>as, the <ex>hibernacle</ex> of
an animal or a plant</as>.</def> <rj><au>Martyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hibernaculum</ent><br/
\'d8<hw>Hi`ber*nac"u*lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hibernacle</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A winter
bud, in which the rudimentary foliage or flower, as of most trees and
shrubs in the temperate zone, is protected by closely overlapping
scales.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A little case in which certain
insects pass the winter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Winter home or abiding place.</def> <rj><au>J.
Burroughs.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hibernal</ent><br/
<hw>Hi*ber"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hibernalis</ets>, from the root of <ets>hiems</ets> winter; akin to
Gr. <?/ snow, Skr. <ets>hima</ets> cold, winter, snow: cf. F.
<ets>hibernal</ets>.]</ety> <def>Belonging or relating to winter;
wintry; winterish.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hibernate</ent><br/
<hw>Hi"ber*nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hibernated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hibernating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>hibernare</ets>, <ets>hibernatum</ets>, fr. <ets>hibernus</ets>
wintry. See <er>Hibernal</er>.]</ety> <def>To winter; to pass the season
of winter in close quarters, in a torpid or lethargic state, as certain
mammals, reptiles, and insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Inclination would lead me to <qex>hibernate</qex>, during half the
year, in this uncomfortable climate of Great Britain.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hibernating</ent><br/
<hw>hibernating</hw> <pos>adj.</pos> <def>in a state of suspended
animation; -- of animals that sleep most of the winter.</def>
<mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> dormant, torpid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hibernation</ent><br/
<hw>Hi`ber*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hibernation</ets>.]</ety> <def>The act or state of
hibernating.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hibernian</ent><br/
<hw>Hi*ber"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Hibernia</ets>, Ireland.]</ety> <def>Of or pertaining to Hibernia,
now Ireland; Irish.</def> -- <def2><pos>n.</pos> <def>A native or an
inhabitant of Ireland.</def></def2></p>

<p><ent>Hibernianism</ent><br/
<ent>Hibernicism</ent><br/
<mhw>{ <hw>Hi*ber"ni*cism</hw> <pr>(?)</pr>, <hw>Hi*ber"ni*an*ism</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>An idiom or mode of speech
peculiar to the Irish.</def> <rj><au>Todd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiberno-Celtic</ent><br/
<hw>Hi*ber"no-Celt"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The native
language of the Irish; that branch of the Celtic languages spoken by the
natives of Ireland. Also <xex>adj</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hibiscus</ent><br/
<hw>Hi*bis"cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., marsh mallow;
cf. Gr. <?/.]</ety> <fld>(Bot.)</fld> <def>A genus of plants (herbs,
shrubs, or trees), some species of which have large, showy flowers. Some
species are cultivated in India for their fiber, which is used as a
substitute for hemp. See <er>Althea</er>, <er>Hollyhock</er>, and
<er>Manoe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiccius doctius</ent><br/
<hw>Hic"ci*us doc"ti*us</hw> <pr>(?)</pr>. <ety>[Corrupted fr. L.
<ets>hic est doctus</ets> this is a learned man.]</ety> <def>A
juggler.</def> <mark>[Cant]</mark><-- = hocus pocus? -->
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 692 --></p>

<p><ent>Hiccough</ent><br/
<hw>Hic"cough</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hickup</ets>, <ets>hicket</ets>, <ets>hickock</ets>; prob. of
imitative origin; cf. D. & Dan. <ets>hik</ets>, Sw. <ets>hicka</ets>,
Armor. <ets>hak</ets>, <ets>hik</ets>, W. <ets>ig</ets>, F.
<ets>hoquet</ets>.]</ety> <fld>(Physiol.)</fld> <def>A modified
respiratory movement; a spasmodic inspiration, consisting of a sudden
contraction of the diaphragm, accompanied with closure of the glottis,
so that further entrance of air is prevented, while the impulse of the
column of air entering and striking upon the closed glottis produces a
sound, or hiccough.</def> <altsp>[Written also <asp>hickup</asp> or
hiccup.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiccough</ent><br/
<hw>Hic"cough</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hiccoughed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hiccoughing</conjf>.]</vmorph> <def>To have a hiccough
or hiccoughs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hick</ent><br/
<hw>hick</hw> <pos>n.</pos> <def>A person who is not very intelligent or
interested in culture; a hayseed.</def><br/
<syn><b>Syn. --</b> yokel, rube, yahoo, hayseed, bumpkin,
chawbacon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hick</ent><br/
<hw>hick</hw> <pos>adj.</pos> <sn>1.</sn> <def>rural. Opposite of
<ant>urban</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>characteristic of rural people, especially those not
knowledgeable about matters outside their locality; <as>as,
<ex>hick</ex> ideas; a <ex>hick</ex> town</as>.</def><br/
<syn><b>Syn. --</b> bumpkinly, rustic, unsophisticated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hickie</ent><br/
<ent>hickey</ent><br/
<mhw><hw>hick"ey</hw>, <hw>hick"ie</hw></mhw> <pos>n.</pos> <sn>1.</sn>
<fld>(Elec.)</fld> <def>A device used to adapt a lighting fixture for
mounting in an outlet box, or on a pipe.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A red mark on the skin, caused by a passionate,
sucking kiss at that location.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>a <er>doohickey</er>.</def>
<mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hickory</ent><br/
<hw>Hick"o*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[North American
Indian <ets>pawcohiccora</ets> (Capt. J. Smith) a kind of milk or oily
liquor pressed from pounded hickory nuts.
<ldquo/<ets>Pohickory</ets><rdquo/ is named in a list of Virginia trees,
in 1653, and this was finally shortened to <ldquo/hickory.<rdquo/ <au>J.
H. Trumbull.</au>]</ety> <fld>(Bot.)</fld> <def>An American tree of the
genus <gen>Carya</gen>, of which there are several species. The shagbark
is the <spn>Carya alba</spn>, and has a very rough bark; it affords the
hickory nut of the markets. The pignut, or brown hickory, is the
<spn>Carya glabra</spn>. The swamp hickory is <spn>Carya amara</spn>,
having a nut whose shell is very thin and the kernel bitter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hickory shad</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>The mattowacca, or fall herring.</cd> <sd>(b)</sd> <cd>The gizzard
shad.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hicksite</ent><br/
<hw>Hicks"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A member or follower
of the <ldquo/liberal<rdquo/ party, headed by Elias <xex>Hicks</xex>,
which, because of a change of views respecting the divinity of Christ
and the Atonement, seceded from the conservative portion of the Society
of Friends in the United States, in 1827.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hickup</ent><br/
<hw>Hick"up</hw> <pr>(?)</pr>, <pos>n. & v. i.</pos> <def>See
<er>Hiccough</er>.</def></p>

<p><ent>Hickway</ent><br/
<ent>Hickwall</ent><br/
<mhw>{ <hw>Hick"wall`</hw> <pr>(?)</pr>, <hw>Hick"way`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[OE., also
<ets>hyghwhele</ets>, <ets>highawe</ets>.]</ety> <def>The lesser spotted
woodpecker (<spn>Dendrocopus minor</spn>) of Europe.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hid</ent><br/
<hw>Hid</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Hide</er>. See <er>Hidden</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hidage</ent><br/
<hw>Hid"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <ets>hide</ets>
a quantity of land.]</ety> <fld>(O. Eng. Law.)</fld> <def>A tax formerly
paid to the kings of England for every hide of land.</def>
<altsp>[Written also <asp>hydage</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hidalgo</ent><br/
<hw>Hi*dal"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., contr. fr.
<ets>hijo de algo</ets>, <it>i. e.</it>, son of something;
<ets>hijo</ets> son (fr. LL. <ets>filius</ets>) + <ets>algo</ets>
something, fr. L. <ets>aliquod</ets>. Cf. <er>Fidalgo</er>.]</ety>
<def>A title, denoting a Spanish nobleman of the lower class.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hidden</ent><br/
<hw>Hid"den</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <def>from
<er>Hide</er>. Concealed; put out of view; secret; not known;
mysterious.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hidden fifths</b></col> <it>or</it> <col><b>Hidden
octaves</b></col></mcol> <fld>(Mus.)</fld>, <cd>consecutive fifths or
octaves, not sounded, but suggested or implied in the parallel motion of
two parts towards a fifth or an octave.</cd></cs></p>

<p><syn><b>Syn.</b> -- <er>Hidden</er>, <er>Secret</er>,
<er>Covert</er>.</syn> <usage> <xex>Hidden</xex> may denote either known
to on one; as, a <xex>hidden</xex> disease; or intentionally concealed;
as, a <xex>hidden</xex> purpose of revenge. <xex>Secret</xex> denotes
that the thing is known only to the party or parties concerned; as, a
<xex>secret</xex> conspiracy. <xex>Covert</xex> literally denotes what
is not <xex>open</xex> or avowed; as, a <xex>covert</xex> plan; but is
often applied to what we mean shall be understood, without openly
expressing it; as, a <xex>covert</xex> allusion. <xex>Secret</xex> is
opposed to <xex>known</xex>, and <xex>hidden</xex> to
<xex>revealed</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Bring to light the <qex>hidden</qex> things of darkness.</q>
<rj><qau>1 Cor. iv. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My heart, which by a <qex>secret</qex> harmony<br/
Still moves with thine, joined in connection sweet.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By what best way,<br/
Whether of open war, or <qex>covert</qex> guile,<br/
We now debate.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiddenite</ent><br/
<hw>Hid"den*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[After W. E.
<ets>Hidden</ets>.]</ety> <fld>(Min.)</fld> <def>An emerald-green
variety of spodumene found in North Carolina; lithia emerald, -- used as
a gem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiddenly</ent><br/
<hw>Hid"den*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a hidden
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hide</ent><br/
<hw>Hide</hw> <pr>(h<imac/d)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Hid</conjf> <pr>(h<icr/d)</pr>; <pos>p.
p.</pos> <conjf>Hidden</conjf> <pr>(h<icr/d"d'n)</pr>,
<conjf>Hid</conjf>; <pos>p. pr. & vb. n.</pos> <conjf>Hiding</conjf>
<pr>(h<imac/d"<icr/ng)</pr>.]</vmorph> <ety>[OE. <ets>hiden</ets>,
<ets>huden</ets>, AS. <ets>h<ymac/dan</ets>; akin to Gr.
<grk>key`qein</grk>, and prob. to E. <ets>house</ets>, <ets>hut</ets>,
and perh. to E. <ets>hide</ets> of an animal, and to <ets>hoard</ets>.
Cf. <er>Hoard</er>.]</ety> <sn>1.</sn> <def>To conceal, or withdraw from
sight; to put out of view; to secrete.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A city that is set on an hill can not be <qex>hid</qex>.</q>
<rj><qau>Matt. v. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If circumstances lead me, I will find<br/
Where truth is <qex>hid</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To withhold from knowledge; to keep secret; to
refrain from avowing or confessing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven from all creatures <qex>hides</qex> the book of fate.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To remove from danger; to shelter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the time of trouble he shall <qex>hide</qex> me in his
pavilion.</q> <rj><qau>Ps. xxvi. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hide one's self</b></col>, <cd>to put one's self in a
condition to be safe; to secure protection.</cd> <ldquo/A prudent man
foreseeth the evil, and <xex>hideth himself</xex>.<rdquo/ <au>Prov.
xxii. 3.</au> -- <col><b>To hide the face</b></col>, <cd>to withdraw
favor.</cd> <ldquo/Thou didst <xex>hide thy face</xex>, and I was
troubled.<rdquo/ <au>Ps. xxx. 7.</au> -- <col><b>To hide the face
from</b></col>. <sd>(a)</sd> <cd>To overlook; to pardon.</cd>
<ldquo/<xex>Hide thy face from</xex> my sins.<rdquo/ <au>Ps. li. 9.</au>
<sd>(b)</sd> <cd>To withdraw favor from; to be displeased
with.</cd></cs></p>

<p><syn><b>Syn.</b> -- To conceal; secrete; disguise; dissemble; screen;
cloak; mask; veil. See <er>Conceal</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hide</ent><br/
<hw>Hide</hw>, <pos>v. i.</pos> <def>To lie concealed; to keep one's
self out of view; to be withdrawn from sight or observation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bred to disguise, in public 'tis you <qex>hide</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hide and seek</b></col>, <cd>a play of children, in which
some hide themselves, and others seek them.</cd>
<rj><au>Swift.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hide</ent><br/
<hw>Hide</hw>, <pos>n.</pos> <ety>[AS. <ets>h<imac/d</ets>, earlier
<ets>h<imac/ged</ets>; prob. orig., land enough to support a family; cf.
AS. <ets>h<imac/wan</ets>, <ets>h<imac/gan</ets>, members of a
household, and E. <ets>hind</ets> a peasant.]</ety> <fld>(O. Eng.
Law.)</fld> <sd>(a)</sd> <def>An abode or dwelling.</def> <sd>(b)</sd>
<def>A measure of land, common in Domesday Book and old English
charters, the quantity of which is not well ascertained, but has been
differently estimated at 80, 100, and 120 acres.</def> <altsp>[Written
also <asp>hyde</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hide</ent><br/
<hw>Hide</hw>, <pos>n.</pos> <ety>[OE. <ets>hide</ets>, <ets>hude</ets>,
AS. <ets>h<ymac/d</ets>; akin to D. <ets>huid</ets>, OHG.
<ets>h<umac/t</ets>, G. <ets>haut</ets>, Icel. <ets>h<umac/<edh/</ets>,
Dan. & Sw. <ets>hud</ets>, L. <ets>cutis</ets>, Gr. <grk>ky`tos</grk>;
and cf. Gr. <grk>sky`tos</grk> skin, hide, L. <ets>scutum</ets> shield,
and E. <ets>sky</ets>. <root/13.]</ety> <sn>1.</sn> <def>The skin of an
animal, either raw or dressed; -- generally applied to the undressed
skins of the larger domestic animals, as oxen, horses, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The human skin; -- so called in contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O tiger's heart, wrapped in a woman's <qex>hide</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hide</ent><br/
<hw>Hide</hw> <pr>(h<imac/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hided</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hiding</conjf>.]</vmorph> <def>To flog; to whip.</def>
<mark>[Prov. Eng. & Low, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hide and go seek</ent><br/
<ent>hide-and-seek</ent><br/
<mhw><hw>hide-and-seek</hw>, <hw>hide and go seek</hw></mhw>
<pos>n.</pos> <def>A game played by children, in which one child (who is
<ldquo/it<rdquo/) covers his eyes for a short time while the other
players hide, and then the one who is <ldquo/it<rdquo/ tries to find the
others.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>hideaway</ent><br/
<hw>hideaway</hw> <pos>n.</pos> <def>a hiding place; usually a remote
place used by outlaws.</def><br/
<syn><b>Syn. --</b> hideout, den.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>an area where one can be alone and
undisturbed.</def><br/
<syn><b>Syn. --</b> retreat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hidebound</ent><br/
<hw>Hide"bound`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
the skin adhering so closely to the ribs and back as not to be easily
loosened or raised; -- said of an animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hort.)</fld> <def>Having the bark so close and
constricting that it impedes the growth; -- said of trees.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Untractable; bigoted; obstinately and blindly or
stupidly conservative.</def> <rj><au>Milton. Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Niggardly; penurious.</def> <mark>[Obs.]</mark>
<rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hideous</ent><br/
<hw>Hid"e*ous</hw> <pr>(h<icr/d"<esl/*<ucr/s; 277)</pr>, <pos>a.</pos>
<ety>[OE. <ets>hidous</ets>, OF. <ets>hidous</ets>, <ets>hidos</ets>,
<ets>hidus</ets>, <ets>hisdos</ets>, <ets>hisdous</ets>, F.
<ets>hideux</ets>: cf. OF. <ets>hide</ets>, <ets>hisde</ets>, fright; of
uncertain origin; cf. OHG. <ets>egid<imac/</ets> horror, or L.
<ets>hispidosus</ets>, for <ets>hispidus</ets> rough, bristly, E.
<ets>hispid</ets>.]</ety> <sn>1.</sn> <def>Frightful, shocking, or
offensive to the eyes; dreadful to behold; <as>as, a <ex>hideous</ex>
monster; <ex>hideous</ex> looks</as>.</def> <ldquo/A piteous and
<xex>hideous</xex> spectacle.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Distressing or offensive to the ear; exciting terror
or dismay; <as>as, a <ex>hideous</ex> noise</as>.</def>
<ldquo/<xex>Hideous</xex> cries.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hateful; shocking.</def> <ldquo/Sure, you have some
<xex>hideous</xex> matter to deliver.<rdquo/ <rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Frightful; ghastly; grim; grisly; horrid;
dreadful; terrible.</syn></p>

<p>-- <wordforms><wf>Hid"e*ous*ly</wf>, <pos>adv.</pos> --
<wf>Hid"e*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>hideout</ent><br/
<hw>hide"out</hw> <pr>(h<imac/d"out)</pr>, <pos>n.</pos> <def>a hiding
place; usually a remote place used by outlaws.</def><br/
<syn><b>Syn. --</b> hideaway, den.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hider</ent><br/
<hw>Hid"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hides or
conceals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiding</ent><br/
<hw>Hid"ing</hw>, <pos>n.</pos> <def>The act of hiding or concealing, or
of withholding from view or knowledge; concealment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was the <qex>hiding</qex> of his power.</q> <rj><qau>Hab.
iii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiding</ent><br/
<hw>Hid"ing</hw>, <pos>n.</pos> <def>A flogging.</def>
<mark>[Colloq.]</mark> <rj><au>Charles Reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hidrosis</ent><br/
\'d8<hw>Hi*dro"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written
also, but incorrectly, <asp>idrosis</asp>.]</altsp> <ety>[NL., fr. Gr.
<?/ to sweat, <?/ sweat.]</ety> <sn>1.</sn> <fld>(Physiol.)</fld>
<def>Excretion of sweat; perspiration.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Excessive perspiration; also, any
skin disease characterized by abnormal perspiration.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hidrotic</ent><br/
<hw>Hi*drot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
sudorific.]</ety> <fld>(Med.)</fld> <def>Causing perspiration;
diaphoretic or sudorific.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hidrotic</ent><br/
<hw>Hi*drot"ic</hw>, <pos>n.</pos> <def>A medicine that causes
perspiration; a diaphoretic or a sudorific.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hie</ent><br/
<hw>Hie</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hying</conjf>.]</vmorph> <ety>[OE. <ets>hien</ets>,
<ets>hihen</ets>, <ets>highen</ets>, AS. <ets>higian</ets> to hasten,
strive; cf. L. <ets>ciere</ets> to put in motion, call upon, rouse, Gr.
<?/ to go, E. <ets>cite</ets>.]</ety> <def>To hasten; to go in haste; --
also often with the reciprocal pronoun.</def> <mark>[Rare, except in
poetry]</mark> <ldquo/My husband <xex>hies</xex> him home.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The youth, returning to his mistress, <qex>hies</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hie</ent><br/
<hw>Hie</hw>, <pos>n.</pos> <def>Haste; diligence.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiems</ent><br/
<hw>Hi"ems</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Winter.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierapicra</ent><br/
\'d8<hw>Hi"e*ra*pi"cra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"iero`s</grk> sacred + <?/ bitter.]</ety> <fld>(med.)</fld>
<def>A warming cathartic medicine, made of aloes and canella bark.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierarch</ent><br/
<hw>Hi"er*arch</hw> <pr>(h<imac/"<etil/r*<aum/rk`)</pr>, <pos>n.</pos>
<ety>[LL. <ets>hierarcha</ets>, Gr. <?/; <grk>"iero`s</grk> sacred (akin
to Skr. <ets>ishiras</ets> vigorous, fresh, blooming) + <?/ leader,
ruler, fr. <?/ to lead, rule: cf. F. <ets>hi<eacute/rarque</ets>.]</ety>
<def>One who has high and controlling authority in sacred things; the
chief of a sacred order; <as>as, princely <ex>hierarchs</ex></as>.</def>
<rj><au>Milton.</au></rj></p>

<p><ent>Hierarchic</ent><br/
<ent>Hierarchal</ent><br/
<mhw>{ <hw>Hi"er*arch`al</hw> <pr>(?)</pr>, <hw>Hi`er*arch"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to a hierarch.</def>
<ldquo/The great <xex>hierarchal</xex> standard.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hierarchical</ent><br/
<ent>hierarchic</ent><br/
<mhw><hw>hi`er*arch"ic</hw>, <hw>hi`er*arch"ic*al</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hi<eacute/rarchique</ets>.]</ety> <def>Of or pertaining to a
hierarchy; ordered in a hierarchy.</def> --
<wordforms><wf>Hi`er*arch`ic*al*ly</wf>, <pos>adv.</pos></wordforms>
<syn><b>Syn. --</b> hierarchical, hierarchal.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to a transitive relation between objects
by which they may be ordered into a hierarchy; <as>as, a
<ex>hierarchical</ex> relation</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hierarchism</ent><br/
<hw>Hi"er*arch`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles
or authority of a hierarchy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The more dominant <qex>hierarchism</qex> of the West.</q>
<rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierarchy</ent><br/
<hw>Hi"er*arch`y</hw> <pr>(h<imac/"<etil/r*<aum/rk`<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Hierarchies</plw>
<pr>(h<imac/"<etil/r*<aum/rk`<icr/z)</pr>.</plu> <ety>[Gr.
<grk>'ierarchi`a</grk>: cf. F. <ets>hi<eacute/rarchie</ets>.]</ety>
<sn>1.</sn> <def>Dominion or authority in sacred things.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A body of officials disposed organically in ranks
and orders each subordinate to the one above it; a body of
ecclesiastical rulers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A form of government administered in the church by
patriarchs, metropolitans, archbishops, bishops, and, in an inferior
degree, by priests.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A rank or order of holy beings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Standards and gonfalons . . . for distinction serve<br/
Of <qex>hierarchies</qex>, of orders, and degrees.</q>
<rj><qau>Milton.</qau></rj></p>

<p><sn>5.</sn> <fld>(Math., Logic, Computers)</fld> <def>Any group of
objects ranked so that every one but the topmost is subordinate to a
specified one above it; also, the entire set of ordering relations
between such objects. The ordering relation between each object and the
one above is called a <it>hierarchical relation</it>.</def>
<note>Classification schemes, as in biology, usually form
<ex>hierarchies</ex>.</note><br/
[<source>PJC</source>]</p>

<p><ent>Hieratic</ent><br/
<hw>Hi`er*at"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hieraticus</ets>, Gr. <grk>"ieratiko`s</grk>; akin to
<grk>"iero`s</grk> sacred: cf. F. <ets>hi<eacute/ratique</ets>.]</ety>
<def>Consecrated to sacred uses; sacerdotal; pertaining to
priests.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hieratic character</b></col>, <cd>a mode of ancient
Egyptian writing; a modified form of hieroglyphics, tending toward a
cursive hand and formerly supposed to be the sacerdotal character, as
the <xex>demotic</xex> was supposed to be that of the
people.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>It was a false notion of the Greeks that of the three kinds of
writing used by the Egyptians, two -- for that reason called
hieroglyphic and <qex>hieratic</qex> -- were employed only for sacred,
while the third, the demotic, was employed for secular, purposes. No
such distinction is discoverable on the more ancient Egyptian monuments;
bur we retain the old names founded on misapprehension.</q> <rj><qau>W.
H. Ward (Johnson's Cyc.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierocracy</ent><br/
<hw>Hi`er*oc"ra*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"iero`s</grk> sacred + <?/ to be strong, rule.]</ety>
<def>Government by ecclesiastics; a hierarchy.</def>
<rj><au>Jefferson.</au></rj></p>

<p><ent>Hieroglyphic</ent><br/
<ent>Hieroglyph</ent><br/
<mhw>{ <hw>Hi"er*o*glyph</hw> <pr>(?)</pr>, <hw>Hi`er*o*glyph"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf. F.
<ets>hi<eacute/roglyphe</ets>. See <er>Hieroglyphic</er>,
<pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A sacred character; a character used in picture
writing, as of the ancient Egyptians, Mexicans, etc. Specifically, in
the plural, the picture writing of the ancient Egyptian priests. It is
made up of three, or, as some say, four classes of characters: first,
the <xex>hieroglyphic</xex> proper, or figurative, in which the
representation of the object conveys the idea of the object itself;
second, the <xex>ideographic</xex>, consisting of symbols representing
ideas, not sounds, as an ostrich feather is a symbol of truth; third,
the <xex>phonetic</xex>, consisting of symbols employed as syllables of
a word, or as letters of the alphabet, having a certain sound, as a hawk
represented the vowel <it>a.</it></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any character or figure which has, or is supposed to
have, a hidden or mysterious significance; hence, any unintelligible or
illegible character or mark.</def> <mark>[Colloq.]</mark></p>

<p><ent>Hieroglyphical</ent><br/
<ent>Hieroglyphic</ent><br/
<mhw>{ <hw>Hi`er*o*glyph"ic</hw> <pr>(?)</pr>,
<hw>Hi`er*o*glyph"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[L. <ets>hieroglyphicus</ets>, Gr. <?/; <grk>"iero`s</grk> sacred +
<grk>gly`fein</grk> to carve: cf. F.
<ets>hi<eacute/roglyphique</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Emblematic; expressive of some meaning by
characters, pictures, or figures; <as>as, <ex>hieroglyphic</ex> writing;
a <ex>hieroglyphic</ex> obelisk.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pages no better than blanks to common minds, to his,
hieroglyphical of wisest secrets.</q> <rj><qau>Prof.
Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling hieroglyphics; not decipherable.</def>
<ldquo/An <xex>hieroglyphical</xex> scrawl.<rdquo/ <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>of or pertaining to hieroglyphs.</def>
<wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hieroglyphically</ent><br/
<hw>Hi`er*o*glyph`ic*ally</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In
hieroglyphics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieroglyphist</ent><br/
<hw>Hi`er*og"ly*phist</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <def>One
versed in hieroglyphics.</def> <rj><au>Gliddon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierogram</ent><br/
<hw>Hi"er*o*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"iero`s</grk> sacred + <ets>-gram</ets>.]</ety> <def>A form of
sacred or hieratic writing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierogrammatic</ent><br/
<hw>Hi`er*o*gram"mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hi<eacute/rogrammatique</ets>.]</ety> <def>Written in, or
pertaining to, hierograms; expressive of sacred writing.</def>
<rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierogrammatist</ent><br/
<hw>Hi`er*o*gram"ma*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hi<eacute/rogrammatiste</ets>.]</ety> <def>A writer of hierograms;
also, one skilled in hieroglyphics.</def>
<rj><au>Greenhill.</au></rj></p>

<p><ent>Hierographical</ent><br/
<ent>Hierographic</ent><br/
<mhw>{ <hw>Hi`er*o*graph"ic</hw> <pr>(?)</pr>,
<hw>Hi`er*o*graph"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[L. <ets>hierographicus</ets>, Gr. <?/: cf. F.
<ets>hi<eacute/rographique</ets>.]</ety> <def>Of or pertaining to sacred
writing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierography</ent><br/
<hw>Hi`er*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>"iero`s</grk> sacred + <?/ to write: cf. F.
<ets>hi<eacute/rographie</ets>.]</ety> <def>Sacred writing.</def>
<mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierolatry</ent><br/
<hw>Hi`er*ol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"iero`s</grk> sacred + <?/ worship, <?/ to worship.]</ety> <def>The
worship of saints or sacred things.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj></p>

<p><ent>Hierological</ent><br/
<ent>Hierologic</ent><br/
<mhw>{ <hw>Hi`er*o*log"ic</hw> <pr>(?)</pr>, <hw>Hi`er*o*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>hi<eacute/rologique</ets>.]</ety> <def>Pertaining to
hierology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierologist</ent><br/
<hw>Hi`er*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in,
or whostudies, hierology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierology</ent><br/
<hw>Hi`er*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>"iero`s</grk> sacred + <?/ discourse: cf. F.
<ets>hi<eacute/rologie</ets>.]</ety> <def>A treatise on sacred things;
especially, the science which treats of the ancient writings and
inscriptions of the Egyptians, or a treatise on that science.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieromancy</ent><br/
<hw>Hi"er*o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"iero`s</grk> sacred + <?/ divination: cf. F.
<ets>hi<eacute/romantie</ets>.]</ety> <def>Divination by observing the
objects offered in sacrifice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieromartyr</ent><br/
<hw>Hi"er*o*mar`tyr</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"iero`s</grk> sacred + E. <ets>martyr</ets>.]</ety> <def>A priest
who becomes a martyr.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieromnemon</ent><br/
\'d8<hw>Hi`e*rom*ne"mon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <?/; <grk>"iero`s</grk> sacred + <?/ mindful, fr. <?/ to think on,
remember.]</ety> <fld>(Gr. Antiq.)</fld> <sn>1.</sn> <def>The sacred
secretary or recorder sent by each state belonging to the Amphictyonic
Council, along with the deputy or minister.</def> <rj><au>Liddel &
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A magistrate who had charge of religious matters, as
at Byzantium.</def> <rj><au>Liddel & Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieron</ent><br/
\'d8<hw>Hi"er*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"iero`n</grk>.]</ety> <def>A consecrated place; esp., a
temple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieronymite</ent><br/
<hw>Hi`er*on"y*mite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From St.
<ets>Hieronymus</ets>, or Jerome.]</ety> <fld>(Eccl.)</fld> <def>See
<er>Jeronymite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierophant</ent><br/
<hw>Hi*er"o*phant</hw> <pr>(h<isl/*<ecr/r"<osl/*f<ait/nt <it>or</it>
h<imac/"<etil/r; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>hierophanta</ets>, <ets>hierophantes</ets>, Gr.
<grk>"ierofa`nths</grk>; <grk>"iero`s</grk> sacred + <grk>fai`nein</grk>
to show, make known: cf. F. <ets>hi<eacute/rophante</ets>.]</ety>
<def>The presiding priest who initiated candidates at the Eleusinian
mysteries;</def> <specif>hence,</specif> <def>one who teaches the
mysteries and duties of a religion or an arcane discipline; an
expositor; <as>as, In his television series <ldquo/Cosmos<rdquo/,
<person>Carl Sagan</person> became the foremost <ex>hierophant</ex> of
modern cosmology.</as>.</def> <rj><au>Abp. Potter.</au></rj><br/
<syn><b>Syn. --</b> mystagogue.</syn>
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>an advocate or spokesperson.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hierophantic</ent><br/
<hw>Hi`er*o*phan"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"ierofantiko`s</grk>.]</ety> <def>Of or relating to hierophants or
their teachings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hieroscopy</ent><br/
<hw>Hi`er*os"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ieroskopi`a</grk> divination; <grk>"iero`s</grk> sacred + <?/ to
view.]</ety> <def>Divination by inspection of entrails of victims
offered in sacrifice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierotheca</ent><br/
\'d8<hw>Hi`er*o*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-c<ae/</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr.
Gr. <?/; <grk>"iero`s</grk> sacred + <?/ chest.]</ety> <def>A receptacle
for sacred objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hierourgy</ent><br/
<hw>Hi"er*our`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>"iero`s</grk> sacred + <?/ work.]</ety> <def>A sacred or holy work
or worship.</def> <mark>[Obs.]</mark> <rj><au>Waterland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hifalutin</ent><br/
<hw>Hi`fa*lu"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Highfaluting</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hi-fi</ent><br/
<ent>hifi</ent><br/
<mhw><hw>hifi</hw>, <hw>hi-fi</hw></mhw> <ety>[shortening of
<ets>hi</ets>gh <ets>fi</ets>delity.]</ety> <pos>n.</pos> <def>An
electronic device that plays phonograph records, reproducing the
original sound with a high degree of fidelity. It superseded the older
phonographs, and itself is being displaced in popularity by CD
players.</def><br/
<syn><b>Syn. --</b> hi-fi, high fidelity sound system.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Higgle</ent><br/
<hw>Hig"gle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Higgled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Higgling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf.
<er>Haggle</er>, or <er>Huckster</er>.]</ety> <sn>1.</sn> <def>To hawk
or peddle provisions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To chaffer; to stickle for small advantages in
buying and selling; to haggle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A person accustomed to <qex>higgle</qex> about taps.</q>
<rj><qau>Jeffry.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To truck and <qex>higgle</qex> for a private good.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Higgledy-piggledy</ent><br/
<hw>Hig`gle*dy-pig"gle*dy</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In
confusion; topsy-turvy.</def> <mark>[Colloq.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Higgler</ent><br/
<hw>Hig"gler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
higgles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High</ent><br/
<hw>High</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Hie</er>.]</ety> <def>To hie.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Men must <qex>high</qex> them apace, and make haste.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High</ent><br/
<hw>High</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Higher</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Highest</adjf>.]</amorph> <ety>[OE. <ets>high</ets>,
<ets>hegh</ets>, <ets>hey</ets>, <ets>heh</ets>, AS.
<ets>he<aacute/h</ets>, <ets>h<?/h</ets>; akin to OS. <ets>h<?/h</ets>,
OFries. <ets>hag</ets>, <ets>hach</ets>, D. <ets>hoog</ets>, OHG.
<ets>h<?/h</ets>, G. <ets>hoch</ets>, Icel. <ets>h<?/r</ets>, Sw.
<ets>h<oum/g</ets>, Dan. <ets>h<oum/i</ets>, Goth. <ets>hauhs</ets>, and
to Icel. <ets>haugr</ets> mound, G. <ets>h<uum/gel</ets> hill, Lith.
<ets>kaukaras</ets>.]</ety> <sn>1.</sn> <def>Elevated above any starting
point of measurement, as a line, or surface; having altitude; lifted up;
raised or extended in the direction of the zenith; lofty; tall; <as>as,
a <ex>high</ex> mountain, tower, tree; the sun is
<ex>high</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Regarded as raised up or elevated; distinguished;
remarkable; conspicuous; superior; -- used indefinitely or relatively,
and often in figurative senses, which are understood from the
connection</def>; as --</p>

<p><sd>(a)</sd> <def>Elevated in character or quality, whether moral or
intellectual; pre<eum/minent; honorable; <as>as, <ex>high</ex> aims, or
motives</as>.</def> <ldquo/The <xex>highest</xex> faculty of the
soul.<rdquo/ <rj><au>Baxter.</au></rj></p>

<p><sd>(b)</sd> <def>Exalted in social standing or general estimation,
or in rank, reputation, office, and the like; dignified; <as>as, she was
welcomed in the <ex>highest</ex> circles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was a wight of <qex>high</qex> renown.</q>
<rj><qau>Shak.</qau></rj></p>

<p><sd>(c)</sd> <def>Of noble birth; illustrious; <as>as, of
<ex>high</ex> family</as>.</def></p>

<p><sd>(d)</sd> <def>Of great strength, force, importance, and the like;
strong; mighty; powerful; violent; sometimes, triumphant; victorious;
majestic, etc.; <as>as, a <ex>high</ex> wind; <ex>high</ex>
passions</as>.</def> <ldquo/With rather a <xex>high</xex> manner.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Strong is thy hand, and <qex>high</qex> is thy right hand.</q>
<rj><qau>Ps. lxxxix. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Can heavenly minds such <qex>high</qex> resentment show?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 693 --></p>

<p><sd>(e)</sd> <def>Very abstract; difficult to comprehend or surmount;
grand; noble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both meet to hear and answer such <qex>high</qex> things.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Plain living and <qex>high</qex> thinking are no more.</q>
<rj><qau>Wordsworth.</qau></rj></p>

<p><sd>(f)</sd> <def>Costly; dear in price; extravagant; as, to hold
goods at a <xex>high</xex> price.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If they must be good at so <qex>high</qex> a rate, they know they
may be safe at a cheaper.</q> <rj><qau>South.</qau></rj></p>

<p><sd>(g)</sd> <def>Arrogant; lofty; boastful; proud; ostentatious; --
used in a bad sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An <qex>high</qex> look and a proud heart . . . is sin.</q>
<rj><qau>Prov. xxi. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His forces, after all the <qex>high</qex> discourses, amounted
really but to eighteen hundred foot.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Possessing a characteristic quality in a supreme or
superior degree; <as>as, <ex>high</ex> (<it>i. e</it>., intense) heat;
<ex>high</ex> (<it>i. e.</it>, full or quite) noon; <ex>high</ex>
(<it>i. e.</it>, rich or spicy) seasoning; <ex>high</ex> (<it>i.
e.</it>, complete) pleasure; <ex>high</ex> (<it>i. e.</it>, deep or
vivid) color; <ex>high</ex> (<it>i. e.</it>, extensive, thorough)
scholarship, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>High</qex> time it is this war now ended were.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>High</qex> sauces and spices are fetched from the Indies.</q>
<rj><qau>Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Cookery)</fld> <def>Strong-scented; slightly
tainted; <as>as, epicures do not cook game before it is
<ex>high</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <def>Acute or sharp; -- opposed to
<contr>grave</contr> or <contr>low</contr>; <as>as, a <ex>high</ex>
note</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Phon.)</fld> <def>Made with a high position of some
part of the tongue in relation to the palate, as <emac/ (<emac/ve),
<oomac/ (f<oomac/d). See <xex>Guide to Pronunciation</xex>, <sect/<sect/
10, 11.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>High admiral</b></col>, <cd>the chief admiral.</cd> --
<col><b>High altar</b></col>, <cd>the principal altar in a church.</cd>
-- <col><b>High and dry</b></col>, <cd>out of water; out of reach of the
current or tide; -- said of a vessel, aground or beached.</cd> --
<col><b>High and mighty</b></col> <cd>arrogant; overbearing.</cd>
<mark>[Colloq.]</mark> -- <col><b>High art</b></col>, <cd>art which
deals with lofty and dignified subjects and is characterized by an
elevated style avoiding all meretricious display.</cd> -- <col><b>High
bailiff</b></col>, <cd>the chief bailiff.</cd> -- <mcol><col><b>High
Church</b></col>, <and/ <col><b>Low Church</b></col></mcol>, <cd>two
ecclesiastical parties in the Church of England and the Protestant
Episcopal Church. The high-churchmen emphasize the doctrine of the
apostolic succession, and hold, in general, to a sacramental presence in
the Eucharist, to baptismal regeneration, and to the sole validity of
Episcopal ordination. They attach much importance to ceremonies and
symbols in worship. Low-churchmen lay less stress on these points, and,
in many instances, reject altogether the peculiar tenets of the
high-church school. See <er>Broad Church</er>.</cd> -- <col><b>High
constable</b></col> <fld>(Law)</fld>, <cd>a chief of constabulary. See
<er>Constable</er>, <pos>n.</pos>, 2.</cd> -- <col><b>High commission
court</b></col>, <cd>a court of ecclesiastical jurisdiction in England
erected and united to the regal power by Queen Elizabeth in 1559. On
account of the abuse of its powers it was abolished in 1641.</cd> --
<col><b>High day</b></col> <fld>(Script.)</fld>, <cd>a holy or feast
day.</cd> <au>John xix. 31.</au> -- <col><b>High festival</b></col>
<fld>(Eccl.)</fld>, <cd>a festival to be observed with full
ceremonial.</cd> -- <mcol><col><b>High German</b></col>, <it>or</it>
<col><b>High Dutch</b></col></mcol>. <cd>See under <er>German</er>.</cd>
-- <col><b>High jinks</b></col>, <cd>an old Scottish pastime; hence,
noisy revelry; wild sport.</cd> <mark>[Colloq.]</mark> <ldquo/All the
<xex>high jinks</xex> of the county, when the lad comes of age.<rdquo/
<au>F. Harrison.</au> -- <col><b>High latitude</b></col>
<fld>(Geog.)</fld>, <cd>one designated by the higher figures;
consequently, a latitude remote from the equator.</cd> -- <col><b>High
life</b></col>, <cd>life among the aristocracy or the rich.</cd> --
<col><b>High liver</b></col>, <cd>one who indulges in a rich diet.</cd>
-- <col><b>High living</b></col>, <cd>a feeding upon rich, pampering
food.</cd> -- <col><b>High Mass</b></col>. <fld>(R. C. Ch.)</fld>
<cd>See under <er>Mass</er>.</cd> -- <col><b>High milling</b></col>,
<cd>a process of making flour from grain by several successive grindings
and intermediate sorting, instead of by a single grinding.</cd> --
<col><b>High noon</b></col>, <cd>the time when the sun is in the
meridian.</cd> -- <col><b>High place</b></col> <fld>(Script.)</fld>,
<cd>an eminence or mound on which sacrifices were offered.</cd> --
<col><b>High priest</b></col>. <cd>See in the Vocabulary.</cd> --
<col><b>High relief</b></col>. <fld>(Fine Arts)</fld> <cd>See
<er>Alto-rilievo</er>.</cd> -- <col><b>High school</b></col>. See under
<er>School</er>. <col><b>High seas</b></col> <fld>(Law)</fld>, <cd>the
open sea; the part of the ocean not in the territorial waters of any
particular sovereignty, usually distant three miles or more from the
coast line.</cd> <au>Wharton.</au> -- <col><b>High steam</b></col>,
<cd>steam having a high pressure.</cd> -- <col><b>High
steward</b></col>, <cd>the chief steward.</cd> -- <col><b>High
tea</b></col>, <cd>tea with meats and extra relishes.</cd> --
<col><b>High tide</b></col>, <cd>the greatest flow of the tide; high
water.</cd> -- <col><b>High time</b></col>. <sd>(a)</sd> <cd>Quite time;
full time for the occasion.</cd> <sd>(b)</sd> <cd>A time of great
excitement or enjoyment; a carousal.</cd> <mark>[Slang]</mark> --
<col><b>High treason</b></col>, <cd>treason against the sovereign or the
state, the highest civil offense. See <er>Treason</er>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is now sufficient to speak of high treason as treason
simply, seeing that petty treason, as a distinct offense, has been
abolished. <rj><au>Mozley & W.</au></rj></note></p>

<p>-- <col><b>High water</b></col>, <cd>the utmost flow or greatest
elevation of the tide; also, the time of such elevation.</cd> --
<col><b>High-water mark</b></col>. <sd>(a)</sd> <cd>That line of the
seashore to which the waters ordinarily reach at high water.</cd>
<sd>(b)</sd> <cd>A mark showing the highest level reached by water in a
river or other body of fresh water, as in time of freshet.</cd> --
<col><b>High-water shrub</b></col> <fld>(Bot.)</fld>, <cd>a composite
shrub (<spn>Iva frutescens</spn>), growing in salt marshes along the
Atlantic coast of the United States.</cd> -- <col><b>High
wine</b></col>, <cd>distilled spirits containing a high percentage of
alcohol; -- usually in the plural.</cd> -- <col><b>To be on a high
horse</b></col>, <cd>to be on one's dignity; to bear one's self
loftily.</cd> <mark>[Colloq.]</mark> -- <col><b>With a high
hand</b></col>. <sd>(a)</sd> <cd>With power; in force;
triumphantly.</cd> <ldquo/The children of Israel went out <xex>with a
high hand</xex>.<rdquo/ <au>Ex. xiv. 8.</au> <sd>(b)</sd> <cd>In an
overbearing manner, arbitrarily.</cd> <ldquo/They governed the city
<xex>with a high hand</xex>.<rdquo/ <au>Jowett (Thucyd. ).</au></p></cs>

<p><syn><b>Syn.</b> -- Tall; lofty; elevated; noble; exalted;
supercilious; proud; violent; full; dear. See <er>Tall</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>High</ent><br/
<hw>High</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a high manner; in a
high place; to a great altitude; to a great degree; largely; in a
superior manner; eminently; powerfully.</def> <ldquo/And reasoned
<xex>high</xex>.<rdquo/ <au>Milton.</au> <ldquo/I can not reach so
<xex>high</xex>.<rdquo/ <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>High</xex> is extensively used in the formation of
compound words, most of which are of very obvious signification; as,
<xex>high</xex>-aimed, <xex>high</xex>-arched, <xex>high</xex>-aspiring,
<xex>high</xex>-bearing, <xex>high</xex>-boasting,
<xex>high</xex>-browed, <xex>high</xex>-crested,
<xex>high</xex>-crowned, <xex>high</xex>-designing,
<xex>high</xex>-engendered, <xex>high</xex>-feeding,
<xex>high</xex>-flaming, <xex>high</xex>-flavored,
<xex>high</xex>-gazing, <xex>high</xex>-heaped, <xex>high</xex>-heeled,
<xex>high</xex>-priced, <xex>high</xex>-reared,
<xex>high</xex>-resolved, <xex>high</xex>-rigged,
<xex>high</xex>-seated, <xex>high</xex>-shouldered,
<xex>high</xex>-soaring, <xex>high</xex>-towering,
<xex>high</xex>-voiced, and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>High and low</b></col>, <cd>everywhere; in all supposable
places; <as>as, I hunted <ex>high and low</ex></as>.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>High</ent><br/
<hw>High</hw>, <pos>n.</pos> <sn>1.</sn> <def>An elevated place; a
superior region; a height; the sky; heaven.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>People of rank or high station; <as>as,
<ex>high</ex> and low</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Card Playing)</fld> <def>The highest card dealt or
drawn.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>High, low, jack, and the game</b></col>, <cd>a game at
cards; -- also called <altname>all fours</altname>, <altname>old
sledge</altname>, and <altname>seven up</altname>.</cd> -- <col><b>In
high and low</b></col>, <cd>utterly; completely; in every respect.</cd>
<mark>[Obs.]</mark> <au>Chaucer.</au> -- <col><b>On high</b></col>,
<cd>aloft; above.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The dayspring from <qex>on high</qex> hath visited us.</q>
<rj><qau>Luke i. 78.</qau></rj></p>

<p>-- <col><b>The Most High</b></col>, <cd>the Supreme Being;
God.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>High</ent><br/
<hw>High</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To rise; <as>as, the
sun <ex>higheth</ex></as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>high-and-mighty</ent><br/
<hw>high-and-mighty</hw> <pos>a.</pos> <def>conceited and arrogant;
imperious.</def><br/
[<source>PJC</source>]</p>

<p><ent>highball</ent><br/
<hw>high"ball`</hw> <pr>(h<imac/"b<add/l`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>An alcoholic beverage having a liquor such as whiskey
mixed with water or a carbonated beverage, and usually served with ice
in a tall glass.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Railroads)</fld> <def>A railroad track signal
permitting the engineer to proceed at full speed.</def><br/
[<source>PJC</source>]</p>

<p><ent>Highbinder</ent><br/
<hw>High"bind`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ruffian; one
who hounds, or spies upon, another; app. esp. to the members of certain
alleged societies among the Chinese.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-blown</ent><br/
<hw>High"-blown`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inflated, as with
conceit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>highboard</ent><br/
<hw>highboard</hw> <pos>n.</pos> <def>a high diving board.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Highborn</ent><br/
<hw>High"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of noble or
aristocratic birth. Contrasted with <ant>lowborn</ant> and
<ant>common</ant>.</def> <rj><au>Shak.</au></rj><br/
<syn><b>Syn. --</b> aristocratic, blue-blooded, coroneted, gentle,
patrician, titled, wellborn, upper-class.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Highboy</ent><br/
<hw>High"boy`</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who lives high;
also, in politics, a highflyer.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A kind of tall chest of drawers, with drawers up to
near or above eye level and fouyr legs at the base; it is often divided
into lower and upper sections, with the lower section somewhat wider
than the upper; also called a <altname>tallboy</altname>. Compare
<contr>lowboy</contr>.</def> <mark>[U. S.]</mark> <ldquo/Mahogany
<xex>highboys</xex> glittering with brass handles.<rdquo/ <rj><au>K. L.
Bates.</au></rj><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>High-bred</ent><br/
<hw>High"-bred`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bred in high life;
of pure blood.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>highbrow</ent><br/
<hw>high"brow`</hw> <pos>n.</pos> <def>a person of intellectual or
erudite tastes; an intellectual.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>highbrowed</ent><br/
<ent>highbrow</ent><br/
<mhw><hw>highbrow</hw> <hw>highbrowed</hw></mhw> <pos>adj.</pos>
<def>highly cultured or educated; pertaining to highly educated people;
<as>as, <ex>highbrow</ex> events such as the ballet or opera</as>.</def>
<mark>[informal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-built</ent><br/
<hw>High"-built`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of lofty
structure; tall.</def> <ldquo/<xex>High-built</xex> organs.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>high-built</qex> elephant his castle rears.</q>
<rj><qau>Creech.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>high chair</ent><br/
<ent>highchair</ent><br/
<mhw><hw>high"chair`</hw>, <hw>high" chair`</hw></mhw> <pos>n.</pos>
<def>a chair designed for feeding a very young child, having four long
legs and a footrest and a detachable tray, which rests in front of the
child, holds the food, and also serves as a restraint, to keep the child
from falling out of the chair.</def><br/
<syn><b>Syn. --</b> feeding chair.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-church</ent><br/
<hw>High"-church`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to, or favoring, the party called the High Church, or their doctrines or
policy. See <cref>High Church</cref>, under <er>High</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-churchism</ent><br/
<hw>High"-church`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
principles of the high-church party.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-churchman</ent><br/
<hw>High"-church`man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-men</plw> <pr>(<?/)</pr>.</plu> <def>One who holds high-church
principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-churchman-ship</ent><br/
<hw>High"-church`man-ship</hw>, <pos>n.</pos> <def>The state of being a
high-churchman.</def> <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-colored</ent><br/
<hw>High"-col`ored</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a strong, deep, or glaring color; flushed.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vivid; strong or forcible in representation; hence,
exaggerated; <as>as, <ex>high-colored</ex> description</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-embowed </ent><br/
<hw>High"-em*bowed `</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having lofty
arches.</def> <ldquo/The <xex>high-embowed</xex> roof.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-energy physics</ent><br/
<hw>High`-en"er*gy phys`ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the
branch of <er>particle physics</er> which studies collisions of
particles accelerated to such high energy that new fundamental particles
are generated in the process. The creation of new particles of very high
energy is required to permit the study of the most fundamental relations
between forms of matter, so as to understand the fundamental nature of
matter. The high energies also reproduce the high-temperature conditions
at the earliest phase of the big bang, allowing generation of some data
relevant to understanding the nature and evolution of the
universe.</def><br/
[<source>PJC</source>]</p>

<p><ent>higher</ent><br/
<hw>higher</hw> <pos>adj. prenom.</pos> <sn>1.</sn> <def>advanced in
complexity or elaboration; <as>as, <ex>higher</ex>
mathematics</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to education beyond the secondary
level; <as>as, <ex>higher</ex> education; <ex>higher</ex>
learning</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Higher criticism</ent><br/
<hw>High"er crit"i*cism</hw>. <def>Criticism which includes the study of
the contents, literary character, date, authorship, etc., of any
writing; <as>as, the <ex>higher criticism</ex> of the Pentateuch</as>.
Called also <altname>historical criticism</altname>.</def></p>

<p><q>The comparison of the Hebrew and Greek texts . . . introduces us
to a series of questions affecting the composition, the editing, and the
collection of the sacred books. This class of questions forms the
special subject of the branch of critical science which is usually
distinguished from the verbal criticism of the text by the name of
<qex>higher</qex>, or <qex>historical</qex>, <qex>criticism</qex>.</q>
<rj><qau>W. Robertson Smith.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Highering</ent><br/
<hw>High"er*ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rising higher;
ascending.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In ever <qex>highering</qex> eagle circles.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Higher National Diploma</ent><br/
<hw>Higher National Diploma</hw> <pos>n.</pos> <fld>(Education)</fld>
<def>A certificate awarded for completing a course of vocational
education beyond secondary school, preparing the student for a career in
business or certain practical arts. It is a term used in the United
Kingdom.</def> <mark>[United Kingdom]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>higher programming language</ent><br/
<hw>higher programming language</hw> <pos>n.</pos>
<fld>(Computers)</fld> <def>A computer programming language with an
instruction set allowing one instruction to code for several assembly
language instructions.</def> <note>The aggregation of several
assembly-language instructions into one instruction allows much greater
efficiency in writing computer programs. Most programs are now written
in some higher programming language, such as <stype>BASIC</stype>,
<stype>FORTRAN</stype>, <stype>COBOL</stype>, <stype>C</stype>,
<stype>C++</stype>, <stype>PROLOG</stype>, or
<stype>JAVA</stype>.</note><br/
[<source>PJC</source>]</p>

<p><ent>higher-ranking</ent><br/
<hw>higher-ranking</hw> <pos>adj.</pos> <def>having a rank above that of
another.</def><br/
<syn><b>Syn. --</b> ranking(prenominal), superior.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>higher-up</ent><br/
<hw>high"er-up"</hw>, <pos>n.</pos> <def>A superior officer or official;
a person having greater rank or station or quality than others; -- used
chiefly in <pluf>pl.</pluf></def> <mark>[Slang]</mark><br/
<syn><b>Syn. --</b> superior, superordinate.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Higher thought</ent><br/
<hw>Higher thought</hw>. <def>See <er>New thought</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>highfalutin'</ent><br/
<ent>highfaluting</ent><br/
<ent>highfalutin</ent><br/
<mhw><hw>highfalutin</hw> <hw>highfaluting</hw>
<hw>highfalutin'</hw></mhw> <pos>adj.</pos> <def>Affectedly genteel;
pretentious; haughty; snobbish.</def> <altsp>[Written also
<asp>hifalutin</asp>.]</altsp> <mark>[informal]</mark> <br/
<syn><b>Syn. --</b> grandiose, hifalutin, hoity-toity,
la-di-da.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>highfaluting</ent><br/
<ent>highfalutin</ent><br/
<mhw><hw>high`fa*lu"tin</hw>, <hw>high`fa*lu"ting</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. a corruption of
<ets>highflighting</ets>.]</ety> <def>High-flown, bombastic
language.</def> <altsp>[Written also <asp>hifalutin</asp>.]</altsp>
<mark>[Jocular, U. S.]</mark> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-fed</ent><br/
<hw>High"-fed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pampered; fed
luxuriously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-finished</ent><br/
<hw>High"-fin`ished</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Finished with
great care; polished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High five</ent><br/
<hw>High five</hw>. <sn>1.</sn> <def>See <er>Cinch</er> (the
game).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>a celebratory or mutually
congratulatory gesture between two persons performed by each slapping
the other's raised right hand. Also used as a verb.</def><br/
[<source>PJC</source>]</p>

<p><ent>Highflier</ent><br/
<hw>High"fli`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who is extravagant in pretensions, opinions, or manners; one who is
highfaluting.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>a person of great ability and ambition.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> highflyer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-flown</ent><br/
<hw>High"-flown`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Elevated; proud.</def> <ldquo/<xex>High-flown</xex> hopes.<rdquo/
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Turgid; extravagant; bombastic; inflated; <as>as,
<ex>high-flown</ex> language</as>.</def> <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-flushed</ent><br/
<hw>High"-flushed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Elated.</def>
<rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>highflyer</ent><br/
<hw>highflyer</hw> <pos>n.</pos> <def>Same as
<er>highflier</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Highflying</ent><br/
<hw>High"fly`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Extravagant in opinions or ambition.</def>
<ldquo/<xex>Highflying</xex>, arbitrary kings.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Flying at a high altitude; -- of
airplanes.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Having an excessively high cost or perceived value;
temporarily very successful; -- of objects with respect to a market and
people in their occupations; <as>as, <ex>highflying</ex> internet
stocks; <ex>highflying</ex> executives moving between
companies</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>High-go</ent><br/
<hw>High"-go`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A spree; a
revel.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-handed</ent><br/
<hw>High"-hand`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Overbearing;
oppressive; arbitrary; violent; <as>as, a <ex>high-handed</ex>
act</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-hearted</ent><br/
<hw>High"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of courage
or nobleness; high-souled.</def> --
<wordforms><wf>High"-heart`ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-hoe</ent><br/
<hw>High"-hoe`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European green woodpecker or yaffle.</def> <altsp>[Written also
<asp>high-hoo</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-holder</ent><br/
<hw>High"-hold`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The flicker; -- called also <altname>high-hole</altname>.</def>
<mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>highjack</ent><br/
<hw>highjack</hw> <pos>v. t.</pos> <def>same as <er>hijack</er>.</def>
<mark>[Rare]</mark><br/
<syn><b>Syn. --</b> commandeer, hijack, high-jack, pirate,
expropriate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>highjack</ent><br/
<hw>highjack</hw> <pos>n.</pos> <def>Same as
<er>highjacking</er>.</def><br/
<syn><b>Syn. --</b> hijack.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>highjacking</ent><br/
<hw>highjacking</hw> <pos>n.</pos> <def>The seizure of control of a
vehicle while it is in transit, either to rob it or divert it to an
alternate destination.</def><br/
<syn><b>Syn. --</b> hijacking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Highland</ent><br/
<hw>High"land</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Elevated or
mountainous land; (often in the <pluf>pl.</pluf>) an elevated region or
country; <as>as, the <ex>Highlands</ex> of Scotland</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Highland fling</b></col>, <cd>a dance peculiar to the
Scottish Highlanders; a sort of hornpipe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>highland</ent><br/
<hw>highland</hw> <pos>adj.</pos> <def>of, located in, or characteristic
of high or hilly country. Contrasted to <contr>lowland</contr>.</def>
<mark>[prenominal]</mark> [Narrower terms: <stype>alpestrine, subalpine
</stype>; <stype>alpine</stype>; <stype>mountain(prenominal) </stype>;
<stype>mountainous </stype>]<br/
<syn><b>Syn. --</b> upland.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Highlander</ent><br/
<hw>High"land*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>a
soldier in a Scottish Highland regiment.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An inhabitant of highlands, especially of the
<xex>Highlands</xex> of Scotland.</def> <wns>[wns=2]</wns><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Highlandry</ent><br/
<hw>High"land*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Highlanders,
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>highlight</ent><br/
<hw>highlight</hw> <pos>v. t.</pos> <sn>1.</sn> <def>To emphasize or
call attention to, by moving into the foreground or otherwise making
more prominent.</def><br/
<syn><b>Syn. --</b> foreground, spotlight, play up.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>To make (part of a text or image) more prominent,
especially by making it of a lighter hue or of a different color than
the remaining part.</def><br/
[<source>PJC</source>]</p>

<p><ent>highlight</ent><br/
<hw>highlight</hw> <pos>n.</pos> <def>The part of an image that has the
most intense light.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The most memorable or enjoyable part; -- of events
or activities; <as>as, the <ex>highlight</ex> of our trip was the tour
of the Vatican</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>High-low</ent><br/
<hw>High"-low`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A laced boot, ankle
high.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highly</ent><br/
<hw>High"ly</hw>, <pos>adv.</pos> <def>In a high manner, or to a high
degree; very much; <as>as, <ex>highly</ex> esteemed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>highly-developed</ent><br/
<hw>highly-developed</hw> <pos>adj.</pos> <sn>1.</sn> <def>very complex
or intricate; -- used especially of technology.</def><br/
<syn><b>Syn. --</b> advanced.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>having most of its industrial production in the most
modern state; -- used of countries and societies. Contrasted with
<contr>undeveloped</contr> or <contr>developing</contr>.</def><br/
<syn><b>Syn. --</b> industrialized, advanced, industrial.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>highly-sexed</ent><br/
<hw>highly-sexed</hw> <pos>adj.</pos> <def>having unusually intense
sexual desire or appeal.</def><br/
<syn><b>Syn. --</b> oversexed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Highmen</ent><br/
<hw>High"men</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Loaded dice so
contrived as to turn up high numbers.</def> <mark>[Obs]</mark>
<rj><au>Sir J. Harrington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-mettled</ent><br/
<hw>High"-met`tled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
abundance of mettle; ardent; full of fire; <as>as, a
<ex>high-mettled</ex> steed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-minded</ent><br/
<hw>High"-mind"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Proud; arrogant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not <qex>high-minded</qex>, but fear.</q> <rj><qau>Rom. xi.
20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having, or characterized by, honorable pride; of or
pertaining to elevated principles and feelings; magnanimous; -- opposed
to <xex>mean</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>High-minded</qex>, manly recognition of those truths.</q>
<rj><qau>A. Norton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-mindedness</ent><br/
<hw>High"-mind`ed*ness</hw>, <pos>n.</pos> <def>The quality of being
highminded; nobleness; magnanimity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highmost</ent><br/
<hw>High"most`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Highest.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highness</ent><br/
<hw>High"ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>he<aacute/hnes</ets>.]</ety> <sn>1.</sn> <def>The state of being
high; elevation; loftiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A title of honor given to kings, princes, or other
persons of rank; <as>as, His Royal <ex>Highness</ex></as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-palmed</ent><br/
<hw>High"-palmed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having high antlers; bearing full-grown antlers aloft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>high-pitched</ent><br/
<hw>high-pitched</hw> <pos>adj.</pos> <sn>1.</sn> <def>high in pitch or
frequency; -- used of sounds and voices. Opposite of
<ant>low</ant>.</def> [Narrower terms: <stype>adenoidal, pinched,
nasal</stype>; <stype>altissimo</stype>; <stype>alto</stype>;
<stype>countertenor, alto</stype>; <stype>falsetto</stype>;
<stype>peaky, spiky</stype>; <stype>piping</stype>; <stype>shrill,
sharp</stype>; <stype>screaky, screechy, squeaking, squeaky,
squealing</stype>; <stype>soprano, treble</stype>;
<stype>sopranino</stype>; <stype>tenor</stype>]<br/
<syn><b>Syn. --</b> high.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>set at a sharp or high angle or slant; <as>as, a
<ex>high-pitched</ex> roof</as>.</def><br/
<syn><b>Syn. --</b> steeply pitched, steep.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>high-powered</ent><br/
<ent>high-power</ent><br/
<mhw><hw>high-power</hw> <hw>high-powered</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>vigorously energetic or forceful.</def>
<illu><ex>high-powered</ex> executives</illu><br/
<syn><b>Syn. --</b> high-octane, high-voltage.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>capable of a high degree of magnification; -- used
of optical instruments such as microscopes or telescopes.</def> <illu>a
<ex>high-powered</ex> microscope</illu><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-pressure</ent><br/
<hw>High"-pres`sure</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having or involving a pressure greatly exceeding that of the
atmosphere; -- said of steam, air, water, etc., and of steam, air, or
hydraulic engines, water wheels, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: Urgent; intense; <as>as, a
<ex>high-pressure</ex> business or social life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Using intense psychological pressure or other
incentives to convince others to do things; aggressively persistent;
<as>as, <ex>high-pressure</ex> salesmen; <ex>high-pressure</ex>
tactics</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>High-pressure engine</b></col>, <cd>an engine in which
steam at high pressure is used. It may be either a condensing or a
noncondensing engine. Formerly the term was used only of the latter. See
<er>Steam engine</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>High priest</ent><br/
<hw>High" priest`</hw> <pr>(?)</pr>. <fld>(Eccl.)</fld> <def>A chief
priest; esp., the head of the Jewish priesthood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-priesthood</ent><br/
<hw>High"-priest`hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office,
dignity, or position of a high priest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-priestship</ent><br/
<hw>High"-priest`ship</hw>, <pos>n.</pos>
<def>High-priesthood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-principled</ent><br/
<hw>High"-prin`ci*pled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Possessed
of noble or honorable principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-proof</ent><br/
<hw>High"-proof`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Highly rectified; very strongly alcoholic; <as>as,
<ex>high-proof</ex> spirits</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>So as to stand any test.</def> <ldquo/We are
<xex>high-proof</xex> melancholy.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-raised</ent><br/
<hw>High"-raised`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Elevated; raised aloft; upreared.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Elated with great ideas or hopes.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-reaching</ent><br/
<hw>High"-reach`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Reaching high
or upward; hence, ambitious; aspiring.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-red</ent><br/
<hw>High"-red`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of a strong red
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highroad</ent><br/
<hw>High"road`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A highway; a much
traveled or main road.</def> <mark>[Mostly British]</mark><br/
<syn><b>Syn. --</b> trunk road.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>high road</ent><br/
<hw>high road</hw> <pos>n.</pos> <def>The most ethical and honest
method; -- used mostly in the phrase to <ex>take the high road</ex> (as
in an election campaign). Contrasted with <ex>low road</ex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>high school</ent><br/
<ent>highschool</ent><br/
<mhw><hw>highschool</hw>, <hw>high school</hw></mhw> <pos>n.</pos>
<def>a public secondary school usually including grades 9 through 12;
<as>as, he goes to the neighborhood <ex>highschool</ex></as>.</def><br/
<syn><b>Syn. --</b> senior high school, senior high, high, high
school.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-seasoned</ent><br/
<hw>High"-sea`soned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Enriched with
spice and condiments; hence, exciting; piquant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-sighted</ent><br/
<hw>High"-sight`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Looking upward;
supercilious.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-souled</ent><br/
<hw>High"-souled`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a high or
noble spirit; honorable.</def> <rj><au>E. Everett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-sounding</ent><br/
<hw>High"-sound`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pompous;
noisy; ostentatious; <as>as, <ex>high-sounding</ex> words or
titles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>high-speed</ent><br/
<hw>high-speed</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>fast</er>; <as>as, <ex>fast</ex> film</as>. Opposite of
<ant>slow</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>performed at a high rate of speed; <as>as, a
<ex>high-speed</ex> auto chase on the freeway</as>.</def><br/
<syn><b>Syn. --</b> hot.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-spirited</ent><br/
<hw>High"-spir`it*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
spirit or natural fire; haughty; courageous; impetuous; not brooking
restraint or opposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High steel</ent><br/
<hw>High steel</hw>. <def>Steel containing a high percentage of carbon;
high-carbon steel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>High-stepper</ent><br/
<hw>High"-step`per</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A horse that
moves with a high step or proud gait; hence, a person having a proud
bearing.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>high-stepping</ent><br/
<hw>high-stepping</hw> <pos>adj.</pos> <sn>1.</sn> <def>having or moving
with a high step; <as>as, a <ex>high-stepping</ex> horse</as>.</def><br/
<syn><b>Syn. --</b> high-stepped.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>High-stomached</ent><br/
<hw>High"-stom`ached</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
lofty spirit; haughty.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-strung</ent><br/
<hw>High"-strung`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Strung to a high
pitch; spirited; sensitive; <as>as, a <ex>high-strung</ex>
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-swelling</ent><br/
<hw>High"-swell`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inflated;
boastful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hight</ent><br/
<hw>Hight</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A variant of
<er>Height</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hight</ent><br/
<hw>Hight</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Hight</conjf>, <conjf>Hot</conjf>
<pr>(<?/)</pr>, <pos>p. p.</pos> <conjf>Hight</conjf>,
<conjf>Hote</conjf> (<?/), <conjf>Hoten</conjf> (<?/). See
<er>Hote</er>.]</vmorph> <ety>[OE. <ets>heiten</ets>,
<ets>highten</ets>, <ets>haten</ets>, <ets>hoten</ets>; also
<ets>hight</ets>, <ets>hatte</ets>, <ets>hette</ets>, is called, was
called, AS. <ets>h<amac/tan</ets> to call, name, be called, to command,
promise; also <ets>h<amac/tte</ets> is called, was called; akin to G.
<ets>heissen</ets> to call, be called, bid, Goth. <ets>haitan</ets> to
call, in the passive, to be called.]</ety> <sn>1.</sn> <def>To be called
or named.</def> <mark>[Archaic & Poetic.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the form <xex>hight</xex>, it is used in a passive
sense as a present, meaning <xex>is called</xex> or <xex>named</xex>,
also as a preterite, <xex>was called</xex> or <xex>named</xex>. This
form has also been used as a past participle. See
<er>Hote</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>The great poet of Italy,<br/
That <qex>highte</qex> Dante.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bright was her hue, and Geraldine she <qex>hight</qex>.</q>
<rj><qau>Surrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Entered then into the church the Reverend Teacher.<br/
Father he <qex>hight</qex>, and he was, in the parish.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Childe Harold was he <qex>hight</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To command; to direct; to impel.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But the sad steel seized not where it was <qex>hight</qex><br/
Upon the child, but somewhat short did fall.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To commit; to intrust.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet charge of them was to a porter <qex>hight</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To promise.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He had hold his day, as he had <qex>hight</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hightener</ent><br/
<hw>Hight"en*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
heightens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highth</ent><br/
<hw>Highth</hw> <pr>(h<imac/th or h<imac/tth)</pr>, <pos>n.</pos>
<def><it>Variant</it> of <er>Height</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>High-toned</ent><br/
<hw>High"-toned`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>High
in tone or sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Elevated; high-principled; honorable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In whose <qex>high-toned</qex> impartial mind<br/
Degrees of mortal rank and state<br/
Seem objects of indifferent weight.</q> <rj><qau>Sir W.
Scott.</qau></rj></p>

<p><sn>3.</sn> <def>pretentious, pompous.</def><br/
[<source>PJC</source>]</p>

<p><ent>High-top</ent><br/
<hw>High"-top`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ship's
masthead.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highty-tighty</ent><br/
<hw>High"ty-tigh"ty</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hoity-toity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>high-up</ent><br/
<hw>high-up</hw> <pos>n.</pos> <def>an important or influential
person.</def><br/
<syn><b>Syn. --</b> very important person, VIP, dignitary,
panjandrum.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Highway</ent><br/
<hw>High"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A road or way open
to the use of the public, especially a paved main road or thoroughfare
between towns; in the latter sense it contrasts with <contr>local
street</contr>; <as>as, on the <ex>highways</ex> and
byways</as>.</def></p>

<p><syn><b>Syn.</b> -- Way; road; path; course.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highwayman</ent><br/
<hw>High"way`man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Highwaymen</plw> <pr>(<?/)</pr>.</plu> <def>One who robs on the
public road; a highway robber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Highway robbery</ent><br/
<hw>High"way` rob"ber*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Robbery committed on the public roads.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>An excessively high price or fee; -- used especially
in situations where the buyer has little or no choice but to buy the
item offered.</def><br/
[<source>PJC</source>]</p>

<p><ent>high-voltage</ent><br/
<hw>high-voltage</hw> <pos>adj.</pos> <sn>1.</sn> <def>having, operating
on, or powered by high voltage; <as>as, a <ex>high-voltage</ex>
generator; a <ex>high-voltage</ex> line</as>.</def><br/
<syn><b>Syn. --</b> high-tension.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>same as <er>high-powered</er>.</def><br/
<syn><b>Syn. --</b> high-octane, high-powered, high-power.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>high water</ent><br/
<ent>highwater</ent><br/
<mhw><hw>highwater</hw>, <hw>high water</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>the tide when the water is highest; high tide.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> high tide, high water.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Water at its highest level, as in a river during a
flood.</def><br/
[<source>PJC</source>]</p>

<p><ent>high-water</ent><br/
<hw>high-water</hw> <pos>a.</pos> <def>Pertaining to water at its
highest achieved level; of or pertaining to <er>high water</er>; <as>as,
the <ex>high-water</ex> marks on the walls after a flood</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>High-wrought</ent><br/
<hw>High"-wrought`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Wrought with fine art or skill; elaborate.</def>
<mark>[Obs.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Worked up, or swollen, to a high degree; <as>as, a
<ex>highwrought</ex> passion</as>.</def> <ldquo/A
<xex>high-wrought</xex> flood.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Higre</ent><br/
<hw>Hi"gre</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Eagre</er>.</def> <mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hig-taper</ent><br/
<hw>Hig"-ta`per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Hag-taper</er>.]</ety> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Verbascum</gen> (<spn>Verbascum Thapsus</spn>); the common mullein.
[Also <altname>high-taper</altname> and
<altname>hag-taper</altname>.]</def></p>

<p><ent>Hijra</ent><br/
<ent>Hijera</ent><br/
<mhw><hw>Hij"e*ra</hw> <pr>(?)</pr>, <hw>Hij"ra</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <def>See <er>Hegira</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hike</ent><br/
<hw>Hike</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hiked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hiking</conjf>.]</vmorph> <ety>[Cf. <er>Hitch</er>.]</ety>
<sn>1.</sn> <def>To move with a swing, toss, throw, jerk, or the
like.</def> <mark>[Dial. or Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To raise with a quick movement.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To raise (a price) quickly or significantly in a
single step.</def> <illu>They <ex>hiked</ex> gasoline prices twenty
cents in less than a week.</illu><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Football)</fld> <def>To pass (the ball) from the
center to the quarterback at the start of the play; to <er>snap</er>
(the ball).</def><br/
[<source>PJC</source>]</p>

<p><ent>Hike</ent><br/
<hw>Hike</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To hike
one's self; specif., to go with exertion or effort; to tramp; to march
laboriously.</def> <mark>[Dial. or Colloq.]</mark> <ldquo/If you persist
in heaving and <xex>hiking</xex> like this.<rdquo/
<rj><au>Kipling.</au></rj></p>

<p><q>It's <qex>hike</qex>, <qex>hike</qex>, <qex>hike</qex> (march)
till you stick in the mud, and then you <qex>hike</qex> back again a
little slower than you went.</q> <rj><qau>Scribner's Mag.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>to take a long walk, especially for pleasure or
exercise.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hike</ent><br/
<hw>Hike</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
hiking.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A long walk usually for exercise or pleasure or
exercise; a tramp; a march.</def> <wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><q>With every <qex>hike</qex> there's a few laid out with their hands
crossed.</q> <rj><qau>Scribner's Mag.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>an increase in cost, rate, etc.; <as>as, there was a
dramatic <ex>hike</ex> in gasoline prices; a <ex>hike</ex> in the
interest rates</as>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> rise, boost.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <def>the amount a salary is
increased; <as>as, he got a wage <ex>hike</ex></as>.</def>
<wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> raise, rise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hilal</ent><br/
<hw>Hi"lal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to a
hilum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilar</ent><br/
<hw>Hi"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Belonging to the hilum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilarious</ent><br/
<hw>Hi*la"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hilaris</ets>, <ets>hilarus</ets>, Gr. <?/; cf. <?/ gracious,
kindly.]</ety> <def>Mirthful; noisy; merry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilarity</ent><br/
<hw>Hi*lar"i*ty</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>hilaritas</ets>: cf. F. <ets>hilarit<eacute/</ets>. See
<er>Hilarious</er>.]</ety> <def>Boisterous mirth; merriment;
jollity.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hilarity</xex> differs from <xex>joy</xex>: the
latter, excited by good news or prosperity, is an affection of the mind;
the former, produced by social pleasure, drinking, etc., which rouse the
animal spirits, is more demonstrative.</note></p>

<p><syn><b>Syn.</b> -- Glee; cheerfulness; mirth; merriment; gayety;
joyousness; exhilaration; joviality; jollity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilary term</ent><br/
<hw>Hil"a*ry term`</hw> <pr>(?)</pr>. <def>Formerly, one of the four
terms of the courts of common law in England, beginning on the eleventh
of January and ending on the thirty-first of the same month, in each
year; -- so called from the festival of St. Hilary, January
13th.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Hilary term is superseded by the Hilary sittings,
which commence on the eleventh of January and end on the Wednesday
before Easter.</note> <rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilding</ent><br/
<hw>Hil"ding</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. a corruption
of <ets>hindling</ets>, dim. of <ets>hind</ets>, adj. Cf. Prov. E.
<ets>hilderling</ets>, <ets>hinderling</ets>. See
<er>Hinderling</er>.]</ety> <def>A base, menial wretch.</def> --
<def2><pos>a.</pos> <def>Base; spiritless.</def> <mark>[Obs.]</mark>
</def2> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hile</ent><br/
<hw>Hile</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To hide. See
<er>Hele</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hile</ent><br/
<hw>Hile</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Same as
<er>Hilum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hill</ent><br/
<hw>Hill</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hil</ets>,
<ets>hul</ets>, AS. <ets>hyll</ets>; akin to OD. <ets>hille</ets>,
<ets>hil</ets>, L. <ets>collis</ets>, and prob. to E. <ets>haulm</ets>,
<ets>holm</ets>, and <ets>column</ets>. Cf. 2d <er>Holm</er>.]</ety>
<sn>1.</sn> <def>A natural elevation of land, or a mass of earth rising
above the common level of the surrounding land; an eminence less than a
mountain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every mountain and <qex>hill</qex> shall be made low.</q>
<rj><qau>Is. xl. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The earth raised about the roots of a plant or
cluster of plants. <mark>[U. S.]</mark> See <er>Hill</er>, <pos>v.
t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A single cluster or group of plants growing close
together, and having the earth heaped up about them; <as>as, a
<ex>hill</ex> of corn or potatoes</as>.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hill ant</b></col> <fld>(Zool.)</fld>, <cd>a common ant
(<spn>Formica rufa</spn>), of Europe and America, which makes mounds or
ant-hills over its nests.</cd> -- <col><b>Hill myna</b></col>
<fld>(Zool.)</fld>, <cd>one of several species of birds of India, of the
genus <gen>Gracula</gen>, and allied to the starlings. They are easily
taught to speak many words. <altsp>[Written also <asp>hill
mynah</asp>.]</altsp> See <er>Myna</er>.</cd> -- <col><b>Hill
partridge</b></col> <fld>(Zool.)</fld>, <cd>a partridge of the genus
<gen>Aborophila</gen>, of which numerous species in habit Southern Asia
and the East Indies.</cd> -- <col><b>Hill tit</b></col>
<fld>(Zool.)</fld>, <cd>one of numerous species of small Asiatic singing
birds of the family <fam>Leiotrichid<ae/</fam>. Many are beautifully
colored.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 694 --></p>

<p><ent>Hill</ent><br/
<hw>Hill</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hilled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hilling</conjf>.]</vmorph> <def>To surround with earth; to heap
or draw earth around or upon; <as>as, to <ex>hill</ex>
corn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Showing them how to plant and <qex>hill</qex> it.</q>
<rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilliness</ent><br/
<hw>Hill"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
hilly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilling</ent><br/
<hw>Hill"ing</hw>, <pos>n.</pos> <def>The act or process of heaping or
drawing earth around plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hillock</ent><br/
<hw>Hill"ock</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small hill.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hillside</ent><br/
<hw>Hill"side`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The side or
declivity of a hill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilltop</ent><br/
<hw>Hill"top`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The top of a
hill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilly</ent><br/
<hw>Hill"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Abounding
with hills; uneven in surface; <as>as, a <ex>hilly</ex>
country</as>.</def> <ldquo/<xex>Hilly</xex> steep.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lofty; <as>as, <ex>hilly</ex> empire</as>.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilt</ent><br/
<hw>Hilt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>hilt</ets>,
<ets>hilte</ets>; akin to OHG. <ets>helza</ets>, Prov. G.
<ets>hilze</ets>, Icel. <ets>hjalt</ets>.]</ety> <sn>1.</sn> <def>A
handle; especially, the handle of a sword, dagger, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilted</ent><br/
<hw>Hilt"ed</hw>, <pos>a.</pos> <def>Having a hilt; -- used in
composition; <as>as, basket-<ex>hilted</ex>,
cross-<ex>hilted</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilum</ent><br/
<hw>Hi"lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a little thing,
trifle.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>The eye of a bean or
other seed; the mark or scar at the point of attachment of an ovule or
seed to its base or support; -- called also
<altname>hile</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The part of a gland, or similar
organ, where the blood vessels and nerves enter; the hilus; <as>as, the
<ex>hilum</ex> of the kidney</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hilus</ent><br/
\'d8<hw>Hi"lus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Anat.)</fld> <def>Same as <er>Hilum</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Him</ent><br/
<hw>Him</hw> <pr>(h<icr/m)</pr>, <pos>pron.</pos> <def>Them. See
<er>Hem</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Him</ent><br/
<hw>Him</hw>, <pos>pron.</pos> <ety>[AS. <ets>him</ets>, dat. of
<ets>h<emac/</ets>. <root/183. See <er>He</er>.]</ety> <def>The
objective case of <xex>he</xex>. See <er>He</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Him</qex> that is weak in the faith receive.</q>
<rj><qau>Rom. xiv. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Friends who have given <qex>him</qex> the most sympathy.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In old English <xex>his</xex> and <xex>him</xex> were
respectively the genitive and dative forms of <xex>it</xex> as well as
of <xex>he</xex>. <xex>This use is now obsolete</xex>.
<xex>Poetically</xex>, <xex>him</xex> is sometimes used with the
reflexive sense of <xex>himself</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>I never saw but Humphrey, duke of Gloster,<br/
Did bear <qex>him</qex> like a noble gentleman.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Himalayan</ent><br/
<hw>Hi*ma"la*yan</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Skr.
<ets>him<amac/laya</ets>, prop., the abode of snow.]</ety> <def>Of or
pertaining to the Himalayas, the great mountain chain in Asia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Himantoglossum</ent><br/
<hw>Himantoglossum</hw> <pos>n.</pos> <def>A small genus of terrestrial
orchids of Europe and Mediterranean region.</def><br/
<syn><b>Syn. --</b> genus <gen>Himantoglossum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Himantopus</ent><br/
<hw>Himantopus</hw> <pos>n.</pos> <def>one of two genera of stilts; they
are similar to avocets but with straight bills.</def><br/
<syn><b>Syn. --</b> genus <gen>Himantopus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Himpne</ent><br/
<hw>Himp"ne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hymn.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Himself</ent><br/
<hw>Him*self"</hw> <pr>(?)</pr>, <pos>pron.</pos> <sn>1.</sn> <def>An
emphasized form of the third person masculine pronoun; -- used as a
subject usually with <xex>he</xex>; <as>as, he <ex>himself</ex> will
bear the blame</as>; used alone in the predicate, either in the
nominative or objective case; <as>as, it is <ex>himself</ex> who saved
<ex>himself</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But he <qex>himself</qex> returned from the quarries.</q>
<rj><qau>Judges iii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>David hid <qex>himself</qex> in the field.</q> <rj><qau>1 Sam. xx.
24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord <qex>himself</qex> shall give you a sign.</q>
<rj><qau>Is. vii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who gave <qex>himself</qex> for us, that he might . . . purify
unto <qex>himself</qex> a peculiar people.</q> <rj><qau>Titus ii.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With shame remembers, while <qex>himself</qex> was one<br/
Of the same herd, <qex>himself</qex> the same had done.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Himself</xex> was formerly used instead of
<xex>itself</xex>. See Note under <er>Him</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>It comprehendeth in <qex>himself</qex> all good.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One's true or real character; one's natural temper
and disposition; the state of being in one's right or sane mind (after
unconsciousness, passion, delirium, or abasement); <as>as, the man has
come to <ex>himself</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>By himself</b></col>, <cd>alone; unaccompanied; apart;
sequestered; as, he sits or studies <xex>by himself</xex>.</cd> --
<col><b>To leave one to himself</b></col>, <cd>to withdraw from him; to
let him take his own course.</cd></cs></p>

<p><ent>Himselven</ent><br/
<ent>Himselve</ent><br/
<ent>Himself</ent><br/
<mhw><hw>Him*self"</hw> <pr>(?)</pr>, <hw>Him*selve"</hw>
<pr>(<?/)</pr></mhw>, <hw>Him*selv"en</hw> (<?/), <pos>pron. pl.</pos>
<def>Themselves. See <er>Hemself</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Himselve</ent><br/
<hw>Him*selve"</hw> <pr>(?)</pr>, <pos>pron.</pos> <def>See 1st
<er>Himself</er>.</def> <mark>[Obs.]</mark></p>

<p><ent>Himyaritic</ent><br/
<ent>Himyaric</ent><br/
<mhw>{ <hw>Him*yar"ic</hw> <pr>(?)</pr>, <hw>Him`ya*rit"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to Himyar, an
ancient king of Yemen, in Arabia, or to his successors or people;
<as>as, the <ex>Himjaritic</ex> characters, language, etc.</as>; applied
esp. to certain ancient inscriptions showing the primitive type of the
oldest form of the Arabic, still spoken in Southern Arabia.</def>
<rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hin</ent><br/
<hw>Hin</hw> <pr>(h<icr/n)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>h<imac/n</ets>.]</ety> <def>A Hebrew measure of liquids, containing
three quarts, one pint, one gill, English measure.</def> <rj><au>W. H.
Ward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinayana</ent><br/
<hw>Hinayana</hw> <pos>n.</pos> <sn>1.</sn> <def>a major school of
Buddhism teaching personal salvation through one's own
efforts.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>one of two great schools of Buddhist doctrine
emphasizing personal salvation through one's own efforts; chiefly in Sri
Lanka (Ceylon); Myanmar (Burma); Thailand; Cambodia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hinayanist</ent><br/
<hw>Hinayanist</hw> <pos>n.</pos> <def>an adherent of Hinayana
Buddhism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hind</ent><br/
<hw>Hind</hw> <pr>(h<imac/nd)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hind</ets>; akin to D. <ets>hinde</ets>, OHG. <ets>hinta</ets>, G.
<ets>hinde</ets>, <ets>hindin</ets>, Icel., Sw., & Dan. <ets>hind</ets>,
and perh. to Goth. <ets>hin<thorn/an</ets> to seize (in comp.), E.
<ets>hunt</ets>, or cf. Gr. <grk>kema`s</grk> a young deer.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>The female of the red deer, of which
the male is the stag.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A spotted food fish of the genus
<gen>Epinephelus</gen>, as <spn>Epinephelus apua</spn> of Bermuda, and
<spn>Epinephelus Drummond-hayi</spn> of Florida; -- called also
<altname>coney</altname>, <altname>John Paw</altname>, <altname>spotted
hind</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hind</ent><br/
<hw>Hind</hw>, <pos>n.</pos> <ety>[OE. <ets>hine</ets>, AS.
<ets>h<imac/ne</ets>, <ets>h<imac/na</ets>, orig. gen. pl. of
<ets>h<imac/wan</ets> domestics; akin to Icel. <ets>hj<umac/</ets> man
and wife, domestics, family, Goth. <ets>heiwa</ets>frauja master of the
house, G. <ets>hei</ets>rath marriage; cf. L. <ets>civis</ets> citizen,
E. <ets>city</ets> or E. <ets>home</ets>. Cf. <er>Hide</er> a measure of
land.]</ety> <sn>1.</sn> <def>A domestic; a servant.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A peasant; a rustic; a farm servant.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hind</qex>, that homeward driving the slow steer<br/
Tells how man's daily work goes forward here.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hind</ent><br/
<hw>Hind</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Hinder</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Hindmost</adjf> <pr>(?)</pr>, or <adjf>Hindermost</adjf>
<pr>(<?/)</pr>.]</amorph> <ety>[OE. <ets>hind</ets>, adv., back, AS.
<ets>hindan</ets> behind. See <er>Hinder</er>, <pos>a.</pos>]</ety>
<def>In the rear; -- opposed to <xex>front</xex>; of or pertaining to
the part or end which follows or is behind, in opposition to the part
which leads or is before; <as>as, the <ex>hind</ex> legs or
<ex>hind</ex> feet of a quadruped; the <ex>hind</ex> man in a
procession.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hindberry</ent><br/
<hw>Hind"ber*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hindberie</ets>; akin to OHG. <ets>hintberi</ets>, G.
<ets>himbeere</ets>. So called because hinds or stags are fond of them.
See 1st <er>Hind</er>, and <er>Berry</er>.]</ety> <def>The
raspberry.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hindbrain</ent><br/
<hw>Hind"brain`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hind</ets>,
adj. + <ets>brain</ets>.]</ety> <fld>(Anat.)</fld> <def>The posterior of
the three principal divisions of the brain, including the epencephalon
and metencephalon. Sometimes restricted to the <xex>epencephalon</xex>
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinder</ent><br/
<hw>Hind"er</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>hindere</ets>, AS. hinder, adv., behind; akin to OHG.
<ets>hintar</ets>, prep., behind, G. <ets>hinter</ets>, Goth.
<ets>hindar</ets>; orig. a comparative, and akin to AS. <ets>hine</ets>
hence. See <er>Hence</er>, <er>He</er>, and cf. <er>Hind</er>,
<pos>a.</pos>, <er>Hindmost</er>.]</ety> <def>Of or belonging to that
part or end which is in the rear, or which follows; <as>as, the
<ex>hinder</ex> part of a wagon; the <ex>hinder</ex> parts of a
horse.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was in the <qex>hinder</qex> part of the ship.</q>
<rj><qau>Mark iv. 38.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinder</ent><br/
<hw>Hin"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hindered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hindering</conjf>.]</vmorph> <ety>[OE.
<ets>hindren</ets>, <ets>hinderen</ets>, AS. <ets>hindrian</ets>, fr.
<ets>hinder</ets> behind; akin to D. <ets>hinderen</ets>, G.
<ets>hindern</ets>, OHG. <ets>hintar<?/n</ets>, Icel. & Sw.
<ets>hindra</ets>, Dan. <ets>hindre</ets>. See <er>Hinder</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To keep back or behind; to prevent
from starting or moving forward; to check; to retard; to obstruct; to
bring to a full stop; -- often followed by <xex>from</xex>; <as>as, an
accident <ex>hindered</ex> the coach; drought <ex>hinders</ex> the
growth of plants; to <ex>hinder</ex> me from going.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Them that were entering in ye <qex>hindered</qex>.</q>
<rj><qau>Luke xi. 52.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>hinder</qex> you too long.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To prevent or embarrass; to debar; to shut
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>hinders</qex> younger brothers, being fathers of
families, from having the same right?</q> <rj><qau>Locke.</qau></rj></p>

<p><syn><b>Syn.</b> -- To check; retard; impede; delay; block; clog;
prevent; stop; interrupt; counteract; thwart; oppose; obstruct; debar;
embarrass.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinder</ent><br/
<hw>Hin"der</hw>, <pos>v. i.</pos> <def>To interpose obstacles or
impediments; to be a hindrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This objection <qex>hinders</qex> not but that the heroic action
of some commander . . . may be written.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinderance</ent><br/
<hw>Hin"der*ance</hw> <pr>(?)</pr>. <pos>n.</pos> <def>Same as
<er>Hindrance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinderer</ent><br/
<hw>Hin"der*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, hinders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinderest</ent><br/
<hw>Hind"er*est</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hindermost; --
<pos>superl.</pos> of <er>Hind</er>, <pos>a.</pos></def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinderling</ent><br/
<hw>Hind"er*ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hinderling</ets> one who comes behind his ancestors, fr. AS.
<ets>hinder</ets> behind. See <er>Hinder</er>, <pos>a.</pos>, and cf.
<er>Hilding</er>.]</ety> <def>A worthless, base, degenerate person or
animal.</def> <mark>[Obs.]</mark> <rj><au>Callander.</au></rj></p>

<p><ent>Hindmost</ent><br/
<ent>Hindermost</ent><br/
<mhw>{ <hw>Hind"er*most`</hw>, <hw>Hind"most`</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <ety>[The superlative of <ets>hind</ets>. See
<er>Hind</er>, <pos>a.</pos>]</ety> <ety>[Cf. AS. <ets>hindema</ets>
(akin to Goth. <ets>hindumists</ets>), a superlative from the same
source as the comparative <ets>hinder</ets>. See <er>Hinder</er>, a.,
and cf. <er>Aftermost</er>.]</ety> <def>Furthest in or toward the rear;
last.</def> <ldquo/Rachel and Joseph <xex>hindermost</xex>.<rdquo/
<rj><au>Gen. xxxiii. 2.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hindgut</ent><br/
<hw>Hind"gut`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hind</ets>, a.
+ <ets>gut</ets>.]</ety> <fld>(Anat.)</fld> <def>The posterior part of
the alimentary canal, including the rectum, and sometimes the large
intestine also.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hindi</ent><br/
<hw>Hin"di</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prop. a Per. adj.
meaning, Indian, Hindoo.]</ety> <def>The name given by Europeans to that
form of the Hindustani language which is chiefly spoken by native
Hindus. In employs the Devanagari character, in which Sanskrit is
written.</def> <rj><au>Whitworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hindleys screw</ent><br/
<hw>Hind"ley"s screw`</hw> <pr>(?)</pr>. <fld>(Mech.)</fld> <def>A screw
cut on a solid whose sides are arcs of the periphery of a wheel into the
teeth of which the screw is intended to work. It is named from the
person who first used the form.</def></p>

<p><ent>Hindu</ent><br/
<ent>Hindoo</ent><br/
<mhw>{ <hw>Hin"doo</hw>, <hw>Hin"du</hw> }</mhw> <pr>(?; 277)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Hindoos</plw> <pr>(#)</pr>
<it>or</it> <plw>Hindus</plw>.</plu> <ety>[Per. <ets>Hind<umac/</ets>,
fr. <ets>Hind</ets>, <ets>Hind<umac/st<amac/n</ets>, India. Cf.
<er>Indian</er>.]</ety> <def>A native inhabitant of Hindostan. As an
ethnical term it is confined to the Dravidian and Aryan races; as a
religious name it is restricted to followers of the Veda.</def></p>

<p><ent>Hindu calendar</ent><br/
<ent>Hindoo calendar</ent><br/
<mhw>{<hw>Hin"doo calendar</hw> <it>or</it> <hw>Hindu calendar</hw>
}</mhw>. <def>A lunisolar calendar of India, according to which the year
is divided into twelve months, with an extra month inserted after every
month in which two new moons occur (once in three years).</def>
</p>
<note><p>The intercalary month has the name of the one which precedes it.
The year usually commences about April 11. The months are follows:</p>

<p><table><pre>
Baisakh . . . . . . . . . .    April-May
Jeth . . . . . . . . . . . . . May-June
Asarh . . . . . . . . . . . .  June-July
Sawan (Sarawan) . . . . . . .  July-Aug.
Bhadon . . . . . . . . . . .   Aug.-Sept.
Asin (Kuar). . . . . . . . . . Sept.-Oct.
Katik (Kartik) . . . . . . . . Oct.-Nov.
Aghan . . . . . . . . . . . .  Nov.-Dec.
Pus . . . . . . . . . . . . .  Dec.-Jan.
Magh . . . . . . . . . . . . . Jan.-Feb.
Phagun (Phalgun) . . . . . . . Feb.-March
Chait . . . . . . . . . . . .  March-April
</pre></table><br/
[<source>Webster 1913 Suppl.</source>]</p></note>

<p><ent>Hinduism</ent><br/
<ent>Hindooism</ent><br/
<mhw>{ <hw>Hin"doo*ism</hw>, <hw>Hin"du*ism</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>The religious doctrines and rites of the Hindus;
Brahmanism.</def></p>

<p><ent>Hindustani</ent><br/
<ent>Hindoostani</ent><br/
<ent>Hindoostanee</ent><br/
<mhw>{ <hw>Hin"doo*sta"nee</hw>, <hw>Hin"doo*sta"ni</hw>,
<hw>Hin"du*sta"ni</hw> }</mhw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Hind.
<ets>Hind<umac/st<amac/n<imac/</ets> an Indian, fr. Hind. and Per.
<ets>Hind<umac/st<amac/n</ets> India.]</ety> <def>Of or pertaining to
the Hindoos or their language.</def> -- <def2><pos>n.</pos> <def>The
language of Hindustan; the name given by Europeans to the most generally
spoken of the modern Aryan languages of India. It is Hindi with the
addition of Persian and Arabic words.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hindostani</ent><br/
<hw>Hindostani</hw> <pos>n.</pos> <def>Same as <er>Hindustani</er>. See
<er>Hindoostanee</er>.</def><br/
<syn><b>Syn. --</b> Hindustani, Hindoostani.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hindquarter</ent><br/
<hw>hindquarter</hw> <pos>n.</pos> <def>the back half of a side of meat,
from about the twelfth rib back.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hindquarters</ent><br/
<hw>hindquarters</hw> <pos>n.</pos> <sn>1.</sn> <def>the fleshy part of
the human body at the back of the hip, on which a person sits; teh
buttocks.</def><br/
<syn><b>Syn. --</b> buttocks, arse, butt, backside, bum, buns, can,
fundament, hind end, keister, posterior, prat, rear, rear end, rump,
stern, seat, tail, tail end, tooshie, tush, bottom, behind, derriere,
fanny, ass.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the part of a quadruped that corresponds to the
human buttocks.</def><br/
<syn><b>Syn. --</b> croup, croupe, rump.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hindrance</ent><br/
<hw>Hin"drance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hinder</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>The act of
hindering, or the state of being hindered.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which hinders; an impediment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What various <qex>hindrances</qex> we meet.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Something between a <qex>hindrance</qex> and a help.</q>
<rj><qau>Wordsworth.</qau></rj></p>

<p><syn><b>Syn.</b> -- Impediment; obstruction; obstacle; difficulty;
interruption; check; delay; restraint.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>hindshank</ent><br/
<hw>hindshank</hw> <pos>n.</pos> <def>a cut of meat from the upper part
of a rear leg.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hindsight</ent><br/
<hw>hindsight</hw> <pos>n.</pos> <def>understanding the nature of an
event after it has happened; <as>as, <ex>hindsight</ex> is always
clearer than foresight</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><mcol><col><b>20-20 hindsight</b></col>, <col><b>twenty-twenty
hindsight</b></col></mcol> <cd>Perfect understanding of an event after
it has happened; -- a term usually used with sarcasm in response to
criticism of one's decision, implying that the critic is unfairly
judging the wisdom of the decision in light of information that was not
available when the decision was made.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Hindu</ent><br/
<hw>Hin"du</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hindoo</er>. This is now the more commonly used spelling.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hinduism</ent><br/
<hw>Hinduism</hw> <pos>n.</pos> <sn>1.</sn> <def>the dominant religion
of India; characterized by a caste system anud belief in
reincarnation.</def><br/
<syn><b>Syn. --</b> Hindooism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a complex of beliefs and values and customs
including worship of many gods, especially the Trimurti composed of
Brahma the Creator; Vishnu the preserver; and Shiva the
destroyer.</def><br/
<syn><b>Syn. --</b> Hindooism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hindustan</ent><br/
<hw>Hindustan</hw> <pos>n.</pos> <def>northern region of India where
Hinduism predominates.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hindustani</ent><br/
<hw>Hindustani</hw> <pos>adj.</pos> <def>of or pertaining to Hindustan
or its inhabitants.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hindustani</ent><br/
<hw>Hindustani</hw> <pos>n.</pos> <sn>1.</sn> <def>a native or
inhabitant of Hindustan or India.</def><br/
<syn><b>Syn. --</b> Hindu, Hindoo.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a form of Hindi spoken around Delhi. See
<er>Hindoostanee</er>.</def><br/
<syn><b>Syn. --</b> Hindoostani, Hindoostanee, Hindostani.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hine</ent><br/
<hw>Hine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Hind</er> a
servant.]</ety> <def>A servant; a farm laborer; a peasant; a hind.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Bailiff, herd, nor other <qex>hine</qex>.</q>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinge</ent><br/
<hw>Hinge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>henge</ets>,
<ets>heeng</ets>; akin to D. <ets>heng</ets>, LG. <ets>henge</ets>,
Prov. E. <ets>hingle</ets> a small hinge; connected with
<ets>hang</ets>, v., and Icel. <ets>hengja</ets> to hang. See
<er>Hang</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The hook with its eye, or the joint, on which a
door, gate, lid, etc., turns or swings; a flexible piece, as a strip of
leather, which serves as a joint to turn on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The gate self-opened wide,<br/
On golden <qex>hinges</qex> turning.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That on which anything turns or depends; a governing
principle; a cardinal point or rule; <as>as, this argument was the
<ex>hinge</ex> on which the question turned</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One of the four cardinal points, east, west, north,
or south.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When the moon is in the <qex>hinge</qex> at East.</q>
<rj><qau>Creech.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor slept the winds . . . but rushed abroad.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hinge joint</b></col>. <sd>(a)</sd> <fld>(Anat.)</fld>
<cd>See <er>Ginglymus</er>.</cd> <sd>(b)</sd> <fld>(Mech.)</fld> <cd>Any
joint resembling a hinge, by which two pieces are connected so as to
permit relative turning in one plane.</cd> -- <col><b>To be off the
hinges</b></col>, <cd>to be in a state of disorder or irregularity; to
have lost proper adjustment.</cd> <rj><au>Tillotson.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinge</ent><br/
<hw>Hinge</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hinged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hinging</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To
attach by, or furnish with, hinges.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bend.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinge</ent><br/
<hw>Hinge</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To stand, depend,
hang, or turn, as on a hinge; to depend chiefly for a result or decision
or for force and validity; -- usually with <xex>on</xex> or
<xex>upon</xex>; <as>as, the argument <ex>hinges</ex> on this
point</as>.</def> <rj><au>I. Taylor</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinged</ent><br/
<hw>Hinged</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with
hinges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hingeless</ent><br/
<hw>Hinge"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without a hinge or
joint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hink</ent><br/
<hw>Hink</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A reaping hook.</def>
<rj><au>Knight.</au></rj></p>

<p><ent>Hinny</ent><br/
<ent>Hinniate</ent><br/
<mhw>{ <hw>Hin"ni*ate</hw> <pr>(?)</pr>, <hw>Hin"ny</hw> <pr>(?)</pr>
}</mhw> <pos>v. i.</pos> <ety>[L. <ets>hinnire</ets>.]</ety> <def>To
neigh; to whinny.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinny</ent><br/
<hw>Hin"ny</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Hinnies</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>hinnus</ets>, cf. Gr. <?/.]</ety>
<def>A hybrid between a stallion and an ass; -- correlative of the
<contr>mule</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hinny</ent><br/
<hw>Hin"ny</hw>, <pos>n.</pos> <def>A term of endearment; darling; --
corrupted from <xex>honey</xex>.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hint</ent><br/
<hw>Hint</hw> <pr>(h<icr/nt)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hinted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hinting</conjf>.]</vmorph> <ety>[OE. <ets>henten</ets>,
<ets>hinten</ets>, to seize, to catch, AS. <ets>hentan</ets> to pursue,
take, seize; or Icel. <ets>ymta</ets> to mutter, <ets>ymtr</ets> a
muttering, Dan. <ets>ymte</ets> to whisper. <root/36. Cf.
<er>Hent</er>.]</ety> <def>To bring to mind by a slight mention or
remote allusion; to suggest in an indirect manner; <as>as, to
<ex>hint</ex> a suspicion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Just <qex>hint</qex> a fault and hesitate dislike.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- To suggest; intimate; insinuate; imply.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hint</ent><br/
<hw>Hint</hw>, <pos>v. i.</pos> <def>To make an indirect reference,
suggestion, or allusion; to allude vaguely to something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We whisper, and <qex>hint</qex>, and chuckle.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hint at</b></col>, <cd>to allude to lightly,
indirectly, or cautiously.</cd></cs></p>

<p><syn><b>Syn.</b> -- To allude; refer; glance; touch.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hint</ent><br/
<hw>Hint</hw>, <pos>n.</pos> <def>A remote allusion; slight mention;
intimation; insinuation; a suggestion or reminder, without a full
declaration or explanation; also, an occasion or motive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>hint</qex> of woe<br/
Is common.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hint</qex> malevolent, the look oblique.</q>
<rj><qau>Hannah More.</qau></rj></p>

<p><syn><b>Syn.</b> -- Suggestion; allusion. See
<er>Suggestion</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>hinterland</ent><br/
<hw>hin"ter*land`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.;
<ets>hinter</ets> behind + <ets>land</ets> land.]</ety> <def>a remote
and undeveloped area; originally, the land or region lying behind the
coast district. The term is used esp. with reference to the so-called
<col><b>doctrine of the hinterland</b></col>, sometimes advanced, that
occupation of the coast supports a claim to an exclusive right to
occupy, from time to time, the territory lying inland of the
coast.</def><br/
<syn><b>Syn. --</b> backwoods, back country, boondocks.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Hintingly</ent><br/
<hw>Hint"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a hinting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hip</ent><br/
<hw>Hip</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hipe</ets>,
<ets>huppe</ets>, AS. <ets>hype</ets>; akin to D. <ets>heup</ets>, OHG.
<ets>huf</ets>, G. <ets>h<uum/fte</ets>, Dan. <ets>hofte</ets>, Sw.
<ets>h<oum/ft</ets>, Goth. <ets>hups</ets>; cf. Icel. <ets>huppr</ets>,
and also Gr. <?/ the hollow above the hips of cattle, and Lith.
<ets>kumpis</ets> ham.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The projecting region of the lateral parts of one
side of the pelvis and the hip joint; the haunch; the huckle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>The external angle formed by the
meeting of two sloping sides or skirts of a roof, which have their wall
plates running in different directions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Engin)</fld> <def>In a bridge truss, the place
where an inclined end post meets the top chord.</def>
<rj><au>Waddell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hip bone</b></col> <fld>(Anat.)</fld>, <cd>the innominate
bone; -- called also <altname>haunch bone</altname> and <altname>huckle
bone</altname>.</cd> -- <col><b>Hip girdle</b></col> <fld>(Anat.)</fld>,
<cd>the pelvic girdle.</cd> -- <col><b>Hip joint</b></col>
<fld>(Anat.)</fld>, <cd>the articulation between the thigh bone and hip
bone.</cd> -- <col><b>Hip knob</b></col> <fld>(Arch.)</fld>, <cd>a
finial, ball, or other ornament at the intersection of the hip rafters
and the ridge.</cd> -- <col><b>Hip molding</b></col> <fld>(Arch.)</fld>,
<cd>a molding on the hip of a roof, covering the hip joint of the
slating or other roofing.</cd> -- <col><b>Hip rafter</b></col>
<fld>(Arch.)</fld>, <cd>the rafter extending from the wall plate to the
ridge in the angle of a hip roof.</cd> -- <mcol><col><b>Hip
roof</b></col>, <col><b>Hipped roof</b></col></mcol> <fld>(Arch.)</fld>,
<cd>a roof having sloping ends and sloping sides. See <er>Hip</er>,
<pos>n.</pos>, 2., and <er>Hip</er>, <pos>v. t.</pos>, 3.</cd> --
<col><b>Hip tile</b></col>, <cd>a tile made to cover the hip of a
roof.</cd> -- <mcol><col><b>To catch upon the hip</b></col>, <it>or</it>
<col><b>To have on the hip</b></col></mcol>, <cd>to have or get the
advantage of; -- a figure probably derived from wresting.</cd>
<au>Shak.</au> -- <col><b>To smite hip and thigh</b></col>, <cd>to
overthrow completely; to defeat utterly.</cd> <au>Judg. xv.
8.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hip</ent><br/
<hw>Hip</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hipped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hipping</conjf>.]</vmorph> <sn>1.</sn> <def>To dislocate or
sprain the hip of, to fracture or injure the hip bone of (a quadruped)
in such a manner as to produce a permanent depression of that
side.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw (one's adversary) over one's hip in
wrestling (technically called <xex>cross buttock</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make with a hip or hips, as a roof.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hipped roof</b></col>. <cd>See <cref>Hip roof</cref>,
under <er>Hip</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hip</ent><br/
<hw>Hip</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hepe</ets>, AS.
<ets>he<oacute/pe</ets>; cf. OHG. <ets>hiufo</ets> a bramble
bush.]</ety> <fld>(Bot.)</fld> <def>The fruit of a rosebush, especially
of the English dog-rose (<spn>Rosa canina</spn>); called also
<altname>rose hip</altname>.</def> <altsp>[Written also <asp>hop</asp>,
<asp>hep</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hip tree</b></col> <fld>(Bot.)</fld>, <cd>the
dog-rose.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hip</ent><br/
<hw>Hip</hw>, <pos>interj.</pos> <def>Used to excite attention or as a
signal; as, <xex>hip</xex>, <xex>hip</xex>, hurra!</def></p>

<p><ent>Hipps</ent><br/
<ent>Hip</ent><br/
<mhw><hw>Hip</hw>, <it>or</it> <hw>Hipps</hw> <pr>(<?/)</pr></mhw>,
<pos>n.</pos> <def>See <er>Hyp</er>, <pos>n.</pos></def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hip</ent><br/
<hw>hip</hw>, <pos>a.</pos> <sn>1.</sn> <def>Aware of the latest ideas,
trends, fashions, and developments in popular music and entertainment
culture; not square; -- same as <altname>hep</altname>.</def><br/
<syn><b>Syn. --</b> tuned in.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Aware of the latest fashions and behaving as
expected socially, especially in clothing style and musical taste;
exhibiting an air of casual sophistication; cool; with it; -- used
mostly among young people in the teens to twenties.</def><br/
[<source>PJC</source>]</p>

<p><ent>hipbone</ent><br/
<hw>hipbone</hw> <pos>n.</pos> <def>Either of two large flaring bones,
each forming one half of the <partof>pelvis</partof>; made up of the
<part>ilium</part> and <part>ischium</part> and
<part>pubis</part>.</def><br/
<syn><b>Syn. --</b> innominate bone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hype</ent><br/
<ent>Hipe</ent><br/
<mhw>{<hw>Hipe</hw> <pr>(?)</pr>, <pos>n.</pos> Also <hw>Hype</hw>
}</mhw>. <ety>[Etym. uncertain.]</ety> <fld>(Wrestling)</fld> <def>A
throw in which the wrestler lifts his opponent from the ground, swings
him to one side, knocks up his nearer thigh from the back with the knee,
and throws him on his back.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hipe</ent><br/
<hw>Hipe</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hiped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hiping</conjf> <pr>(?)</pr>.]</vmorph> <fld>(Wrestling)</fld>
<def>To throw by means of a hipe.</def> -- <wordforms><wf>Hip"er</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>hipflask</ent><br/
<hw>hip"flask`</hw> <pos>n.</pos> <def>A small portable flask, usually
made of metal, used to hold liquor.</def><br/
<syn><b>Syn. --</b> pocket flask.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hiphalt</ent><br/
<hw>Hip"halt`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lame in the
hip.</def> <mark>[R.]</mark> <rj><au>Gower.</au></rj></p>

<p><ent>hipless</ent><br/
<hw>hipless</hw> <pos>adj.</pos> <def>having hips which are not
prominent; seeming to have no hips; <as>as, slim and
<ex>hipless</ex></as>; -- of people. Opposite of
<ant>broad-hipped</ant></def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>hipline</ent><br/
<hw>hipline</hw> <pos>n.</pos> <sn>1.</sn> <def>the line formed by
measuring the hip at its greatest part.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the line formed by the lower edge of hiplength
garment.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hip lock</ent><br/
<hw>Hip lock</hw>. <fld>(Wrestling)</fld> <def>A lock in which a close
grip is obtained and a fall attempted by a heave over the hip.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hippe</ent><br/
<ent>Hippa</ent><br/
<mhw>{ <hw>Hip"pa</hw> <pr>(?)</pr>, <hw>Hip"pe</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A genus of marine decapod
crustaceans, which burrow rapidly in the sand by pushing themselves
backward; -- called also <altname>bait bug</altname>. See
<xex>Illust.</xex> under <er>Anomura</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hipparion</ent><br/
\'d8<hw>Hip*pa"ri*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ a pony, dim. of <?/ a horse.]</ety> <fld>(Paleon.)</fld> <def>An
extinct genus of Tertiary mammals allied to the horse, but three-toed,
having on each foot a small lateral hoof on each side of the main
central one. It is believed to be one of the ancestral genera of the
Horse family.</def></p>

<p><ent>hippeastrum</ent><br/
<hw>hippeastrum</hw> <pos>n.</pos> <def>An amaryllis of tropical America
(<spn>Hippeastrum puniceum</spn>) often cultivated as a houseplant for
its showy white to red flowers.</def><br/
<syn><b>Syn. --</b> <spn>Hippeastrum puniceum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hippish</ent><br/
<ent>Hipped</ent><br/
<mhw>{ <hw>Hipped</hw> <pr>(?)</pr>, <hw>Hip"pish</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[From 5th <er>Hip</er>.]</ety> <def>Somewhat
hypochondriac; melancholy. See <er>Hyppish</er>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When we are <qex>hipped</qex> or in high spirits.</q> <rj><qau>R.
L. Stevenson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hipped</ent><br/
<hw>hipped</hw> <pos>adj.</pos> <sn>1.</sn> <def>having hips; or, having
hips of a specified type; -- used in combination; <as>as,
wide-<ex>hipped</ex></as>.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Architecture)</fld> <def>peaked and having sloping
ends rather than gables; -- of roofs; <as>as, a <ex>hipped</ex> roof has
sloping ends rather than gables</as>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> hip-roofed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hippie</ent><br/
<hw>hip"pie</hw> <pos>n.</pos> <def>Someone who rejects the established
culture, dresses casually, and advocates extreme liberalism in politics
and lifestyle. Used especially of those in the late 1960's, mostly in
their late teens and early twenties, who conspicuously rejected
traditional culture by dressing casually, if male wore their hair long,
and wore folksy or used clothing adorned with beads, headbands, and
often flowers; they emphasized the importance of love and direct
personal relations rather than success-oriented businesslike behavior,
strove for spontaneity, sometimes lived communally, and in some cases
tried to expand their consciousness by various psychological techniques
such as meditation, or through the use of consciousness-altering drugs
such as marijuana or LSD. By the end of the Vietnam war in the 1970's,
the numbers of people living a visibly hippie lifestyle had dramatically
decreased, though some people continue to develop similar views and live
with the same outlook.</def><br/
<syn><b>Syn. --</b> hippy, flower child.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>hippo</ent><br/
<hw>hip"po</hw> <pos>n.</pos> <def>Same as
<er>hippopotamus</er>.</def><br/
<syn><b>Syn. --</b> hippopotamus, river horse, Hippopotamus
amphibius.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hippobosca</ent><br/
\'d8<hw>Hip`po*bos"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"i`ppos</grk> horse + <?/ to feed.]</ety> <fld>(Zool.)</fld>
<def>A genus of dipterous insects including the horsefly or horse
tick.</def> -- <wordforms><wf>Hip`po*bos"can</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippoboscidae</ent><br/
<hw>Hippoboscidae</hw> <pos>n.</pos> <def>A natural family of winged or
wingless dipterans: louse flies.</def><br/
<syn><b>Syn. --</b> family <fam>Hippoboscidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hippocamp</ent><br/
<hw>Hip"po*camp</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hippocampus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocampal</ent><br/
<hw>Hip`po*cam"pal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the hippocampus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocampus</ent><br/
<hw>Hip`po*cam"pus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., the sea
horse, Gr. <?/ a hippocampus (in senses 1 and 2); <grk>"i`ppos</grk>
horse + <?/ to bend.]</ety> <sn>1.</sn> <fld>(Class. Myth.)</fld> <def>A
fabulous monster, with the head and fore quarters of a horse joined to
the tail of a dolphin or other fish (<spn>Hippocampus
brevirostris</spn>), -- seen in Pompeian paintings, attached to the
chariot of Neptune.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 695 --></p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A genus of lophobranch fishes of
several species in which the head and neck have some resemblance to
those of a horse; -- called also <altname>sea horse</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They swim slowly, in an erect position, and often cling
to seaweeds by means of the incurved prehensile tail. The male has a
ventral pouch, in which it carries the eggs till hatched.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A name applied to either of two
ridges of white matter in each lateral ventricle of the brain. The
larger is called <xex>hippocampus major</xex> or simply
<xex>hippocampus</xex>. The smaller, <xex>hippocampus minor</xex>, is
called also <altname>ergot</altname> and
<altname>calcar</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocentaur</ent><br/
<hw>Hip`po*cen"taur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hippocentaurus</ets>, Gr. <?/; <grk>"i`ppos</grk> horse + <?/
centaur.]</ety> <fld>(Myth.)</fld> <def>Same as
<er>Centaur</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocras</ent><br/
<hw>Hip"po*cras</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hippocras</ets>, <ets>hypocras</ets>, NL. vinum
<ets>hippocraticum</ets>, lit., wine of Hippocrates.]</ety> <def>A
cordial made of spiced wine, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocrates</ent><br/
<hw>Hip*poc"ra*tes</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A famous Greek
physician and medical writer, born in Cos, about 460 <sc>b.
c.</sc></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hippocrates' sleeve</b></col>, <cd>a conical strainer,
made by stitching together two adjacent sides of a square piece of
cloth, esp. flannel of linen.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocratic</ent><br/
<hw>Hip"po*crat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to Hippocrates, or to his teachings.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hippocratic face</b></col> <ety>[L. <ets>facies
Hippocratica</ets>]</ety>, <cd>the change produced in the countenance by
death, or long sickness, excessive evacuations, excessive hunger, and
the like. The nose is pinched, the eyes are sunk, the temples hollow,
the ears cold and retracted, the skin of the forehead tense and dry, the
complexion livid, the lips pendent, relaxed, and cold; -- so called, as
having been described by Hippocrates.</cd> <au>Dunglison.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocratic oath</ent><br/
<hw>Hippocratic oath</hw>, <def>An oath said to have been dictated by
<persfn>Hippocrates</persfn> to his disciples. Such an oath is still
administered to candidates for graduation in medicine.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ An English translation of the oath reads:<br/
<br/
I swear by Apollo the physician, by Aesculapius, and Health, and
All-heal, and all the gods and goddesses, that according to my ability
and my judgement, I will keep this Oath and this stipulation -- to
reckon him who taught me this Art equally dear to me as my parents, to
share my substance with him, and relieve his necessities if required; to
look upon his offspring in the same footing as my own brothers, and to
teach them this Art, if they wish to learn it, without fee or
stipulation; and that by precept, lecture, and every mode of
instruction, I will impart a knowledge of the Art to my own sons, and of
my teachers, and to disciples bound by a stipulation and oath according
to the law of medicine, but to none others.<br/
<br/
I will follow that system or regimen which, according to my ability and
judgement, I consider for the benefit of my patients, and abstain from
whatever is deleterious and mischievous.<br/
<br/
I will give no deadly medicine to any one if asked, nor suggest any such
counsel; and in like manner I will not give to a woman a pessary to
produce abortion.<br/
<br/
With purity and with holiness I will pass my life and practice my Art. I
will not cut persons labouring under the stone, but will leave this to
be done by men who are practitioners of this work. Into whatever houses
I enter, I will go into them for the benefit of the sick, and will
abstain from every voluntary act of mischief and corruption; and,
further, from the seduction of females or males, of freemen and
slaves.<br/
<br/
Whatever, in connection with my professional service, or not in
connection with it, I see or hear, in the life of men, which ought not
to be spoken of abroad, I will not divulge, as reckoning that all such
should be kept secret.<br/
<br/
While I continue to keep this Oath unviolated, may it be granted to me
to enjoy life and the practice of the Art, respected by all men, in all
times. But should I trespass and violate this Oath, may the reverse be
my lot.</note></p>

<p><ent>Hippocratism</ent><br/
<hw>Hip*poc"ra*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The medical
philosophy or system of Hippocrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocrene</ent><br/
<hw>Hip"po*crene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/;
<grk>"i`ppos</grk> horse + <?/ a fountain.]</ety> <def>A fountain on
Mount Helicon in B<oe/otia, fabled to have burst forth when the ground
was struck by the hoof of Pegasus. Also, its waters, which were supposed
to impart poetic inspiration.</def> <rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor maddening draughts of <qex>Hippocrene</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocrepian</ent><br/
<hw>Hip"po*crep"i*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hippocrepiform</er>.]</ety> <fld>(Zool.)</fld> <def>One of an order
of fresh-water Bryozoa, in which the tentacles are on a lophophore,
shaped like a horseshoe. See <er>Phylactol<ae/ma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippocrepiform</ent><br/
<hw>Hip`po*crep`i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + <?/ shoe + <ets>-form</ets>.]</ety>
<fld>(Bot.)</fld> <def>Shaped like a horseshoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippodame</ent><br/
<hw>Hip"po*dame</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hippopotame</ets>.]</ety> <def>A fabulous sea monster.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippodrome</ent><br/
<hw>Hip"po*drome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hippodromos</ets>, Gr. <?/; <grk>"i`ppos</grk> horse + <?/ course,
fr. <?/ to run: cf. F. <ets>hippodrome</ets>.]</ety> <sn>1.</sn>
<fld>(Gr. Antiq.)</fld> <def>A place set apart for equestrian and
chariot races.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An arena for equestrian performances; a
circus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Sports)</fld> <def>A fraudulent contest with a
predetermined winner.</def> <mark>[Slang, U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hippodrome</ent><br/
<hw>Hip"po*drome</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hippodromed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hippodroming</conjf>.]</vmorph> <fld>(Sports)</fld> <def>To
arrange contests with predetermined winners.</def> <mark>[Slang, U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hippogriff</ent><br/
<hw>Hip"po*griff</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hippogriffe</ets>; cf. It. <ets>ippogrifo</ets>. See
<er>Hippopotamus</er>, <er>Griffon</er>.]</ety> <fld>(Myth.)</fld>
<def>A fabulous winged animal, half horse and half griffin.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippolith</ent><br/
<hw>Hip"po*lith</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + <ets>-lith</ets>.]</ety> <def>A concretion,
or kind of bezoar, from the intestines of the horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippopathology</ent><br/
<hw>Hip`po*pa*thol`o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + E. <ets>pathology</ets>: cf. F.
<ets>hippopathologie</ets>.]</ety> <def>The science of veterinary
medicine; the pathology of the horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippophagi</ent><br/
<hw>Hip*poph"a*gi</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Hippophagous</er>.]</ety> <def>Eaters of horseflesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippophagism</ent><br/
<hw>Hip*poph"a*gism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Hippophagy.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippophagist</ent><br/
<hw>Hip*poph"a*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who eats
horseflesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippophagous</ent><br/
<hw>Hip*poph"a*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + <?/ to eat: cf. F.
<ets>hippophage</ets>.]</ety> <def>Feeding on horseflesh; -- said of
certain nomadic tribes, as the Tartars.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippophagy</ent><br/
<hw>Hip*poph"a*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hippophagie</ets>.]</ety> <def>The act or practice of feeding on
horseflesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippophile</ent><br/
<hw>Hip"po*phile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + <?/ to love.]</ety> <def>One who loves
horses.</def> <rj><au>Holmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippopotamus</ent><br/
<hw>Hip`po*pot"a*mus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
E. <plw>Hippopotamuses</plw> <pr>(#)</pr>, L. <plw>Hippopotami</plw>
<pr>(#)</pr>.</plu> <ety>[L., from Gr.<?/; <grk>"i`ppos</grk> horse +
<?/ river. Cf. <er>Equine</er>.]</ety> <fld>(Zool.)</fld> <def>A large,
amphibious, herbivorous mammal (<spn>Hippopotamus amphibius</spn>),
common in the rivers of tropical Africa. It is allied to the hogs, and
has a very thick, naked skin, a thick and square head, a very large
muzzle, small eyes and ears, thick and heavy body, and short legs. It is
supposed to be the behemoth of the Bible. Called also
<altname>zeekoe</altname>, and <altname>river horse</altname>. A smaller
species (<spn>Hippopotamus Liberiencis</spn>) inhabits Western
Africa.</def><-- pigmy hippopotamus? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippotomy</ent><br/
<hw>Hip*pot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + <?/ to cut: cf. F.
<ets>hippotomie</ets>.]</ety> <def>Anatomy of the horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippuric</ent><br/
<hw>Hip*pu"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"i`ppos</grk> horse + <grk>o"y`ron</grk> urine: cf. F.
<ets>hippurique</ets>.]</ety> <fld>(Physiol. Chem.)</fld> <def>Obtained
from the urine of horses; <as>as, <ex>hippuric</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hippuric acid</b></col>, <cd>a white crystalline
substance, containing nitrogen, present in the urine of herbivorous
animals, and in small quantity in human urine. By the action of acids,
it is decomposed into benzoic acid and glycocoll.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hippurite</ent><br/
<hw>Hip"pu*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ decked
with a horse's tail; <grk>"i`ppos</grk> horse + <?/ tail: cf. F.
<ets>hippurite</ets>.]</ety> <fld>(Paleon.)</fld> <def>A fossil bivalve
mollusk of the genus <gen>Hippurites</gen>, of many species, having a
conical, cup-shaped under valve, with a flattish upper valve or lid.
Hippurites are found only in the Cretaceous rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hip-roofed</ent><br/
<hw>Hip"-roofed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a hip
roof.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hipshot</ent><br/
<hw>Hip"shot`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hip</ets> +
<ets>shot</ets>.]</ety> <def>Having the hip dislocated; hence, having
one hip lower than the other.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hipster</ent><br/
<hw>hip"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[from <ets>Hip</ets>
<pos>a.</pos> + <ets>-ster</ets>.]</ety> <def>A person who is
<er>hip</er>{2}, <pos>a.</pos>.</def><br/
<syn><b>Syn. --</b> hepcat{2}.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Hip tree</ent><br/
<hw>Hip" tree`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>The
dog-rose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hir</ent><br/
<hw>Hir</hw> <pr>(?)</pr>, <pos>pron.</pos> <mark>[Obs.]</mark> <def>See
<er>Here</er>, <pos>pron.</pos></def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hircic</ent><br/
<hw>Hir"cic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hircique</ets>. See <er>Hircin</er>.]</ety> <fld>(Chem.)</fld>
<def>Of, pertaining to, or derived from, mutton suet; -- applied by
Chevreul to an oily acid which was obtained from mutton suet, and to
which he attributed the peculiar taste and smell of that substance. The
substance has also been called <altname>hircin</altname>.</def>
<rj><au>Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hircin</ent><br/
<hw>Hir"cin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>hircus</ets>,
he-goat, buck: cf. F. <ets>hircine</ets>.]</ety> <fld>(Chem.)</fld>
<def>Hircic acid. See <er>Hircic</er>.</def> <mark>[R.]</mark></p>

<p><ent>Hircinous</ent><br/
<ent>Hircine</ent><br/
<mhw>{ <hw>Hir"cine</hw> <pr>(?)</pr>, <hw>Hir"ci*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hircinus</ets>, fr.
<ets>hircus</ets> hegoat: cf. F. <ets>hircin</ets>.]</ety> <sn>1.</sn>
<def>Goatlike; of or pertaining to a goat or the goats.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of a strong goatish smell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hire</ent><br/
<hw>Hire</hw> <pr>(h<etil/r)</pr>, <pos>pron.</pos> <mark>[Obs.]</mark>
<def>See <er>Here</er>, <pos>pron.</pos></def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hire</ent><br/
<hw>Hire</hw> <pr>(h<imac/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hire</ets>, <ets>hure</ets>, AS. <ets>h<ymac/r</ets>; akin to D.
<ets>huur</ets>, G. <ets>heuer</ets>, Dan. <ets>hyre</ets>, Sw.
<ets>hyra</ets>.]</ety> <sn>1.</sn> <def>The price, reward, or
compensation paid, or contracted to be paid, for the temporary use of a
thing or a place, for personal service, or for labor; wages; rent;
pay.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The laborer is worthy of his <qex>hire</qex>.</q> <rj><qau>Luke x.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law.)</fld> <def>A bailment by which the use of a
thing, or the services and labor of a person, are contracted for at a
certain price or reward.</def> <rj><au>Story.</au></rj></p>

<p><syn><b>Syn.</b> -- Wages; salary; stipend; allowance; pay.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hire</ent><br/
<hw>Hire</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hired</conjf> <pr>(h<imac/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hiring</conjf>.]</vmorph> <ety>[OE. <ets>hiren</ets>,
<ets>huren</ets>, AS. <ets>h<ymac/rian</ets>; akin to D.
<ets>huren</ets>, G. <ets>heuern</ets>, Dan. <ets>hyre</ets>, Sw.
<ets>hyra</ets>. See <er>Hire</er>, <pos>n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To procure (any chattel or estate) from another
person, for temporary use, for a compensation or equivalent; to purchase
the use or enjoyment of for a limited time; <as>as, to <ex>hire</ex> a
farm for a year; to <ex>hire</ex> money.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To engage or purchase the service, labor, or
interest of (any one) for a specific purpose, by payment of wages;
<as>as, to <ex>hire</ex> a servant, an agent, or an
advocate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To grant the temporary use of, for compensation; to
engage to give the service of, for a price; to let; to lease; -- now
usually with <xex>out</xex>, and often reflexively; <as>as, he has
<ex>hired</ex> out his horse, or his time</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . have <qex>hired</qex> out themselves for bread.</q>
<rj><qau>1 Sam. ii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hired</ent><br/
<hw>hired</hw> <pos>adj.</pos> <def>performing work for pay; <as>as,
<ex>hired</ex> hands</as>.</def> <note>used in contrast with the owner
or family members who work in an enterprise</note><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hireless</ent><br/
<hw>Hire"less</hw>, <pos>a.</pos> <def>Without hire.</def>
<rj><au>Davenant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hireling</ent><br/
<hw>Hire"ling</hw> <pr>(h<imac/r"l<icr/ng)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<ymac/reling</ets>. See <er>Hire</er>, <pos>n.</pos>, and
<er>-ling</er>.]</ety> <def>One who is hired, or who serves for wages;
esp., one whose motive and interest in serving another are wholly
gainful; a mercenary.</def> <ldquo/Lewd <xex>hirelings</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hireling</ent><br/
<hw>Hire"ling</hw>, <pos>a.</pos> <def>Serving for hire or wages; venal;
mercenary.</def> <ldquo/<xex>Hireling</xex> mourners.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hire and purchase agreement</ent><br/
<ent>Hire purchase agreement</ent><br/
<ent>Hire purchase</ent><br/
<mhw>{ <hw>Hire purchase</hw>, <xex>or, more fully</xex>, <hw>Hire
purchase agreement</hw>, <it>or</it> <hw>Hire and purchase
agreement</hw>}</mhw>. <fld>(Law)</fld> <def>A contract (more fully
called contract of hire with an option of purchase) in which a person
hires goods for a specified period and at a fixed rent, with the added
condition that if he shall retain the goods for the full period and pay
all the installments of rent as they become due the contract shall
determine and the title vest absolutely in him, and that if he chooses
he may at any time during the term surrender the goods and be quit of
any liability for future installments upon the contract. In the United
States such a contract is generally treated as a conditional sale, and
the term <xex>hire purchase</xex> is also sometimes applied to a
contract in which the hirer is not free to avoid future liability by
surrender of the goods. In England, however, if the hirer does not have
this right the contract is a sale.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hirer</ent><br/
<hw>Hir"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
hires.</def></p>

<p><ent>Hirs</ent><br/
<ent>Hires</ent><br/
<mhw><hw>Hires</hw> <pr>(?)</pr>, <hw>Hirs</hw></mhw>, <pos>pron.</pos>
<def>Hers; theirs. See <er>Here</er>, <pos>pron.</pos></def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirsute</ent><br/
<hw>Hir*sute"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hirsutus</ets>; prob. akin to <ets>horridus</ets> horrid. Cf.
<er>Horrid</er>.]</ety> <sn>1.</sn> <def>Rough with hair; set with
bristles; shaggy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rough and coarse; boorish.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cynical and <qex>hirsute</qex> in his behavior.</q> <rj><qau>Life
of A. Wood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Pubescent with coarse or stiff
hairs.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>Covered with hairlike feathers,
as the feet of certain birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirsuteness</ent><br/
<hw>Hir*sute"ness</hw>, <pos>n.</pos> <def>Hairiness.</def>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirtellous</ent><br/
<hw>Hir*tel"lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Dim., fr. L.
<ets>hirtus</ets> hairy.]</ety> <fld>(Bot. & Zool.)</fld> <def>Pubescent
with minute and somewhat rigid hairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirudine</ent><br/
<hw>Hi*ru"dine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the leeches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirudinea</ent><br/
\'d8<hw>Hir`u*din"e*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>hirudo</ets>, <ets>hirudinis</ets>, a leech.]</ety>
<fld>(Zool.)</fld> <def>An order of Annelida, including the leeches; --
called also <altname>Hirudinei</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hirudinean</ent><br/
<hw>hirudinean</hw> <pos>n.</pos> <def>Any of a number of carnivorous or
bloodsucking aquatic or terrestrial worms typically having a sucker at
each end.</def><br/
<syn><b>Syn. --</b> leech, bloodsucker.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hirundinidae</ent><br/
<hw>Hirundinidae</hw> <pos>n.</pos> <def>A natural family of birds
including the swallows and martins.</def><br/
<syn><b>Syn. --</b> family <fam>Hirundinidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hirudo</ent><br/
\'d8<hw>Hi*ru"do</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
leech.]</ety> <fld>(Zool.)</fld> <def>A genus of leeches, including the
common medicinal leech. See <er>Leech</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirundine</ent><br/
<hw>Hi*run"dine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or pertaining to the swallows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hirundo</ent><br/
\'d8<hw>Hi*run"do</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
swallow.]</ety> <fld>(Zool.)</fld> <def>A genus of birds including the
swallows and martins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>His</ent><br/
<hw>His</hw> <pr>(h<icr/z)</pr>, <pos>pron.</pos> <ety>[AS.
<ets>his</ets> of him, his, gen. masc. & neut. of <ets>h<emac/</ets>,
neut. <ets>hit</ets>. See <er>He</er>.]</ety> <sn>1.</sn> <def>Belonging
or pertaining to <xex>him</xex>; -- used as a pronominal adjective or
adjective pronoun; <as>as, tell John <ex>his</ex> papers are ready</as>;
formerly used also for <it>its</it>, but this use is now
obsolete.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No comfortable star did lend <qex>his</qex> light.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who can impress the forest, bid the tree<br/
Unfix <qex>his</qex> earth-bound root?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Also formerly used in connection with a noun simply as a
sign of the possessive. <ldquo/The king <xex>his</xex> son.<rdquo/
<au>Shak.</au> <ldquo/By young Telemachus <xex>his</xex> blooming
years.<rdquo/ <au>Pope.</au> This <xex>his</xex> is probably a
corruption of the old possessive ending -<xex>is</xex> or
-<xex>es</xex>, which, being written as a separate word, was at length
confounded with the pronoun <xex>his</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The possessive of <xex>he</xex>; <as>as, the book is
<ex>his</ex></as>.</def> <ldquo/The sea is <xex>his</xex>, and he made
it.<rdquo/ <rj><au>Ps. xcv. 5.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hisingerite</ent><br/
<hw>His"ing*er*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after W.
<ets>Hisinger</ets>, a Swedish mineralogist.]</ety> <fld>(Min.)</fld>
<def>A soft black, iron ore, nearly earthy, a hydrous silicate of
iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hispanic</ent><br/
<hw>His*pan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Hispanicus</ets>.]</ety> <def>Of or pertaining to Spain or its
language; <as>as, <ex>Hispanic</ex> words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hispanicism</ent><br/
<hw>His*pan"i*cism</hw>, <pos>n.</pos> <def>A Spanish idiom or mode of
speech.</def> <rj><au>Keightley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hispanicize</ent><br/
<hw>His*pan"i*cize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give a
Spanish form or character to; <as>as, to <ex>Hispanicize</ex> Latin
words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hispaniolan</ent><br/
<hw>Hispaniolan</hw> <pos>adj.</pos> <def>of or pertaining to
Haiti.</def><br/
<syn><b>Syn. --</b> Haitian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hispid</ent><br/
<hw>His"pid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hispidus</ets>: cf. F. <ets>hispide</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Rough with bristles or minute spines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot. & Zool.)</fld> <def>Beset with stiff hairs or
bristles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hispidulous</ent><br/
<hw>His*pid"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Dim. of
<ets>hispid</ets>.]</ety> <fld>(Bot. & Zool.)</fld> <def>Minutely
hispid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiss</ent><br/
<hw>Hiss</hw> <pr>(h<icr/s)</pr>. <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hissed</conjf> <pr>(h<icr/st)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hissing</conjf>.]</vmorph> <ety>[AS. <ets>hysian</ets>;
prob. of imitative origin; cf. LG. <ets>hissen</ets>, OD.
<ets>hisschen</ets>.]</ety> <sn>1.</sn> <def>To make with the mouth a
prolonged sound like that of the letter <it>s</it>, by driving the
breath between the tongue and the teeth; to make with the mouth a sound
like that made by a goose or a snake when angered; esp., to make such a
sound as an expression of hatred, passion, or disapproval.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The merchants among the people shall <qex>hiss</qex> at thee.</q>
<rj><qau>Ezek. xxvii. 36.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a similar noise by any means; to pass with a
sibilant sound; <as>as, the arrow <ex>hissed</ex> as it
flew</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shod with steel,<br/
We <qex>hissed</qex> along the polished ice.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiss</ent><br/
<hw>Hiss</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To condemn or express
contempt for by hissing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the tag-rag people did not clap him and <qex>hiss</qex> him,
according as he pleased and displeased them.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><it>Malcolm</it>. What is the newest grief?<br/
<it>Ros</it>. That of an hour's age doth <qex>hiss</qex> the
speaker.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter with a hissing sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The long-necked geese of the world that are ever
<qex>hissing</qex> dispraise.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiss</ent><br/
<hw>Hiss</hw>, <pos>n.</pos> <sn>1.</sn> <def>A prolonged sound like
that letter <it>s</it>, made by forcing out the breath between the
tongue and teeth, esp. as a token of disapprobation or
contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/<qex>Hiss</qex><rdquo/ implies audible friction of breath
consonants.</q> <rj><qau>H. Sweet. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A dismal, universal <qex>hiss</qex>, the sound<br/
Of public scorn.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any sound resembling that above described</def>; as:
<sd>(a)</sd> <def>The noise made by a serpent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But <qex>hiss</qex> for <qex>hiss</qex> returned with forked
tongue.</q> <rj><qau>Milton.</qau></rj></p>

<p><sd>(b)</sd> <def>The note of a goose when irritated.</def>
<sd>(c)</sd> <def>The noise made by steam escaping through a narrow
orifice, or by water falling on a hot stove.</def> <-- or the
high-frequency noise from an electronic audio instrument --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hissing</ent><br/
<hw>Hiss"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of emitting a
hiss or hisses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The occasion of contempt; the object of scorn and
derision.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will make this city desolate, and a <qex>hissing</qex>.</q>
<rj><qau>Jer. xix. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hissingly</ent><br/
<hw>Hiss"ing*ly</hw>, <pos>adv.</pos> <def>With a hissing
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hist</ent><br/
<hw>Hist</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Cf. Dan.
<ets>hys</ets>. <?/. Cf. <er>Hush</er>, <er>Whist</er>.]</ety>
<def>Hush; be silent; -- a signal for silence.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histiology</ent><br/
<hw>His`ti*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + <ets>-logy</ets>.]</ety> <def>Same as
<er>Histology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histogenesis</ent><br/
<hw>His`to*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + E. <ets>genesis</ets>.]</ety>
<fld>(Biol.)</fld> <sd>(a)</sd> <def>The formation and development of
organic tissues; histogeny; -- the opposite of
<xex>histolysis</xex>.</def> <sd>(b)</sd> <def>Germ history of cells,
and of the tissues composed of cells.</def>
<rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histogenetic</ent><br/
<hw>His`to*ge*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Histogeny</er>.]</ety> <fld>(Biol.)</fld> <def>Tissue-producing;
connected with the formation and development of the organic
tissues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histogeny</ent><br/
<hw>His*tog"e*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + root of <grk>gi`gnesqai</grk> to be
born.]</ety> <fld>(Biol.)</fld> <def>Same as
<er>Histogenesis</er>.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histographer</ent><br/
<hw>His*tog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
describes organic tissues; an histologist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histographical</ent><br/
<hw>His"to*graph"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to histography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histography</ent><br/
<hw>His*tog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + <ets>-graphy</ets>.]</ety> <def>A
description of, or treatise on, organic tissues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histohaematin</ent><br/
<hw>His`to*h<ae/m"a*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + E. <ets>h<ae/matin</ets>.]</ety>
<fld>(Physiol.)</fld> <def>One of a class of respiratory pigments,
widely distributed in the animal kingdom, capable of ready oxidation and
reduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histoid</ent><br/
<hw>His"toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + <ets>-oid</ets>.]</ety> <def>Resembling the
normal tissues; <as>as, <ex>histoid</ex> tumors</as>.</def></p>

<p><ent>Histological</ent><br/
<ent>Histologic</ent><br/
<mhw>{ <hw>His`to*log"ic</hw> <pr>(?)</pr>, <hw>His`to*log"ic*al</hw>
}</mhw> <pos>a.</pos> <fld>(Biol.)</fld> <def>Pertaining to histology,
or to the microscopic structure of the tissues of living
organisms.</def> -- <wordforms><wf>His`to*log"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histologist</ent><br/
<hw>His*tol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
histology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histology</ent><br/
<hw>His*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + <ets>-logy</ets>.]</ety> <def>That branch of
biological science, which treats of the minute (microscopic) structure
of animal and vegetable tissues; -- called also
<altname>histiology</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histolysis</ent><br/
\'d8<hw>His*tol"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"isto`s</grk> tissue + <?/ to loosen, dissolve.]</ety>
<fld>(Biol.)</fld> <def>The decay and dissolution of the organic tissues
and of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histolytic</ent><br/
<hw>His`to*lyt"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of or pertaining to histolysis, or the degeneration of
tissues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histonomy</ent><br/
<hw>His*ton"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + <?/ to distribute, regulate.]</ety> <def>The
science which treats of the laws relating to organic tissues, their
formation, development, functions, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histophyly</ent><br/
<hw>His*toph"y*ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"isto`s</grk> tissue + Gr. <?/ clan.]</ety> <fld>(Biol.)</fld>
<def>The tribal history of cells, a division of morphophyly.</def>
<rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historial</ent><br/
<hw>His*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>historialis</ets>: cf. F. <ets>historial</ets>.]</ety>
<def>Historical.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historian</ent><br/
<hw>His*to"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>historien</ets>.]</ety> <sn>1.</sn> <def>A writer of history; a
chronicler; an annalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even the <qex>historian</qex> takes great liberties with
facts.</q> <rj><qau>Sir J. Reynolds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One versed or well informed in history.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Great captains should be good <qex>historians</qex>.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 696 --></p>

<p><ent>historical</ent><br/
<ent>historic</ent><br/
<mhw>{ <hw>his*tor"ic</hw> <pr>(h<icr/s*t<ocr/r"<icr/k)</pr>,
<hw>his*tor"ic*al</hw> <pr>(h<icr/s*t<ocr/r"<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>historicus</ets>, Gr.
<grk>"istoriko`s</grk>: cf. F. <ets>historique</ets>. See
<er>History</er>.]</ety> <def>Of or pertaining to history, or the record
of past events; <as>as, an <ex>historical</ex> poem; the
<ex>historic</ex> page.</as></def> --
<wordforms><wf>His*tor"ic*al*ness</wf>, <pos>n.</pos> --
<wf>His*to*ric"i*ty</wf> <pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q> There warriors frowning in <qex>historic</qex> brass.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>having once lived, existed, or taken place in the
real world; -- contrasted with <contr>legendary</contr>; <as>as, the
<ex>historical</ex> Jesus; doubt that a <ex>historical</ex> Camelot
every existed; actual <ex>historical</ex> events</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>Belonging to the past; <as>as, <ex>historical</ex>
(or historic) times</as>; a <ex>historical</ex> character.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>Within the period of time recorded in written
documents; <as>as, within <ex>historic</ex> times</as>. Opposite of
<ant>prehistoric</ant>.</def><br/
<syn><b>Syn. --</b> diachronic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>5.</sn> <fld>(Linguistics)</fld> <def>Same as
<er>diachronic</er>.</def> <ant>synchronic</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Historical painting</b></col>, <cd>that branch of
painting which represents the events of history.</cd> --
<col><b>Historical sense</b></col>, <cd>that meaning of a passage which
is deduced from the circumstances of time, place, etc., under which it
was written.</cd> -- <col><b>The historic sense</b></col>, <cd>the
capacity to conceive and represent the unity and significance of a past
era or age.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historically</ent><br/
<hw>His*tor"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the
manner of, or in accordance with, history.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historicize</ent><br/
<hw>His*tor"i*cize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To record or
narrate in the manner of a history; to chronicle.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historied</ent><br/
<hw>His"to*ried</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Related in
history.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historier</ent><br/
<hw>His*to"ri*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An
historian.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historiette</ent><br/
\'d8<hw>His`to*ri*ette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., dim.
of <ets>histoire</ets> a history.]</ety> <def>Historical narration on a
small scale; a brief recital; a story.</def>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historify</ent><br/
<hw>His*tor"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<ety>[<ets>History</ets> + <ets>-fy</ets>.]</ety> <def>To record in or
as history.</def> <mark>[R.]</mark> <rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy conquest meet to be <qex>historified</qex>.</q> <rj><qau>Sir
P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historiographer</ent><br/
<hw>His*to`ri*og"ra*pher</hw>
<pr>(h<icr/s*t<omac/`r<icr/*<ocr/g"r<adot/*f<etil/r)</pr>, <pos>n.</pos>
<ety>[L. <ets>historiographus</ets>, Gr. <grk>"istoriogra`fos</grk>;
<grk>"istori`a</grk> history + <grk>gra`fein</grk> to write: cf. F.
<ets>historiographe</ets>.]</ety> <def>An historian; a writer of
history; especially, one appointed or designated to write a history;
also, a title bestowed by some governments upon historians of
distinction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historiographership</ent><br/
<hw>His*to`ri*og"ra*pher*ship</hw>, <pos>n.</pos> <def>The office of an
historiographer.</def> <rj><au>Saintsbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historiography</ent><br/
<hw>His*to`ri*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
employment of an historiographer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historiology</ent><br/
<hw>His*to`ri*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
history + <ets>-logy</ets>.]</ety> <def>A discourse on history.</def>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historionomer</ent><br/
<hw>His*to`ri*on"o*mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
history + <?/ to distribute.]</ety> <def>One versed in the phenomena of
history and the laws controlling them.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>historionomers</qex> will have measured accurately the
sidereal years of races.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Historize</ent><br/
<hw>His"to*rize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To relate as
history; to chronicle; to historicize.</def> <mark>[R.]</mark>
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>History</ent><br/
<hw>His"to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Histories</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>historia</ets>,
Gr. <grk>'istori`a</grk> history, information, inquiry, fr.
<grk>'istwr</grk>, <grk>"istwr</grk>, knowing, learned, from the root of
<?/ to know; akin to E. <ets>wit</ets>. See <er>Wit</er>, and cf.
<er>Story</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A learning or knowing by inquiry; the knowledge of
facts and events, so obtained; hence, a formal statement of such
information; a narrative; a description; a written record; <as>as, the
<ex>history</ex> of a patient's case; the <ex>history</ex> of a
legislative bill.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A systematic, written account of events,
particularly of those affecting a nation, institution, science, or art,
and usually connected with a philosophical explanation of their causes;
a true story, as distinguished from a <xex>romance</xex>; --
distinguished also from <xex>annals</xex>, which relate simply the facts
and events of each year, in strict chronological order; from
<xex>biography</xex>, which is the record of an individual's life; and
from <xex>memoir</xex>, which is history composed from personal
experience, observation, and memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Histories</qex> are as perfect as the historian is wise, and
is gifted with an eye and a soul.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For aught that I could ever read,<br/
Could ever hear by tale or <qex>history</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>histories</qex> of toil could I declare!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>History piece</b></col>, <cd>a representation in
painting, drawing, etc., of any real event, including the actors and the
action.</cd> -- <col><b>Natural history</b></col>, <cd>a description and
classification of objects in nature, as minerals, plants, animals, etc.,
and the phenomena which they exhibit to the senses.</cd></cs></p>

<p><syn><b>Syn.</b> -- Chronicle; annals; relation; narration.</syn>
<usage> -- <er>History</er>, <er>Chronicle</er>, <er>Annals</er>.
<xex>History</xex> is a methodical record of important events which
concern a community of men, usually so arranged as to show the
connection of causes and effects, to give an analysis of motive and
action etc. A <xex>chronicle</xex> is a record of such events,
conforming to the order of time as its distinctive feature.
<xex>Annals</xex> are a chronicle divided up into separate years. By
poetic license <xex>annals</xex> is sometimes used for
<xex>history</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Justly C<ae/sar scorns the poet's lays;<br/
It is to <qex>history</qex> he trusts for praise.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No more yet of this;<br/
For 't is a <qex>chronicle</qex> of day by day,<br/
Not a relation for a breakfast.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Many glorious examples in the <qex>annals</qex> of our
religion.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>History</ent><br/
<hw>His"to*ry</hw>, <pos>v. t.</pos> <def>To narrate or record.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histotomy</ent><br/
<hw>His*tot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ tissue +
<?/ to cut.]</ety> <def>The dissection of organic tissues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histozyme</ent><br/
<hw>His"to*zyme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ tissue +
<?/ leaven.]</ety> <fld>(Physiol. Chem.)</fld> <def>A soluble enzyme
occurring in the animal body, to the presence of which many normal
decompositions and synthetical processes are supposed to be
due.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histrion</ent><br/
<hw>His"tri*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>histrio</ets>: cf. F. <ets>histrion</ets>.]</ety> <def>A
player.</def> <mark>[R.]</mark> <rj><au>Pope.</au></rj></p>

<p><ent>Histrionical</ent><br/
<ent>Histrionic</ent><br/
<mhw>{ <hw>His`tri*on"ic</hw> <pr>(?)</pr>, <hw>His`tri*on"ic*al</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>histrionicus</ets>:
cf. F. <ets>histrionique</ets>. See <er>Histrion</er>.]</ety>
<sn>1.</sn> <def>Of or relating to the stage or a stageplayer; befitting
a theatre; theatrical.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affectedly dramatic; insincerely emotional; --
sometimes used in a bad sense.</def> --
<wordforms><wf>His`tri*on"ic*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Tainted with false and <qex>histrionic</qex> feeling.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histrionicism</ent><br/
<hw>His`tri*on"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
histrionic art; stageplaying.</def> <rj><au>W. Black.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>histrionics</ent><br/
<hw>his`tri*on"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
histrionic art; stageplaying; acting.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Insincere, exaggeratedly emotional or overly
dramatical speech or behavior performed to create an impression rather
than as an expression of true feeling; feigned emotion.</def><br/
[<source>PJC</source>]</p>

<p><ent>Histrionism</ent><br/
<hw>His"tri*o*nism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Theatrical
representation; acting; affectation.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Histrionize</ent><br/
<hw>His"tri*o*nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To act; to
represent on the stage, or theatrically.</def>
<rj><au>Urquhart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hit</ent><br/
<hw>Hit</hw> <pr>(?)</pr>, <pos>pron.</pos> <def>It.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hit</ent><br/
<hw>Hit</hw>, <def><pos>3d pers. sing. pres.</pos> of <er>Hide</er>,
contracted from <xex>hideth</xex>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hit</ent><br/
<hw>Hit</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hit</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hitting</conjf>.]</vmorph> <ety>[OE. <ets>hitten</ets>,
<ets>hutten</ets>, of Scand. origin; cf. Dan. <ets>hitte</ets> to hit,
find, Sw. & Icel. <ets>hitta</ets>.]</ety> <sn>1.</sn> <def>To reach
with a stroke or blow; to strike or touch, usually with force;
especially, to reach or touch (an object aimed at).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I think you have <qex>hit</qex> the mark.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reach or attain exactly; to meet according to the
occasion; to perform successfully; to attain to; to accord with; to be
conformable to; to suit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Birds learning tunes, and their endeavors to <qex>hit</qex> the
notes right.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There you <qex>hit</qex> him; . . . that argument never fails with
him.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose saintly visage is too bright<br/
To <qex>hit</qex> the sense of human sight.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He scarcely <qex>hit</qex> my humor.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To guess; to light upon or discover.</def>
<ldquo/Thou hast <xex>hit</xex> it.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Backgammon)</fld> <def>To take up, or replace by a
piece belonging to the opposing player; -- said of a single unprotected
piece on a point.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hit off</b></col>, <cd>to describe with quick
characteristic strokes; as, <xex>to hit off</xex> a speaker.</cd>
<au>Sir W. Temple.</au> -- <col><b>To hit out</b></col>, <cd>to perform
by good luck.</cd> <mark>[Obs.]</mark> <au>Spenser.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hit</ent><br/
<hw>Hit</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To meet or
come in contact; to strike; to clash; -- followed by <xex>against</xex>
or <xex>on</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If bodies be extension alone, how can they move and <qex>hit</qex>
one against another?</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Corpuscles, meeting with or <qex>hitting</qex> on those bodies,
become conjoined with them.</q> <rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To meet or reach what was aimed at or desired; to
succeed, -- often with implied chance, or luck.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And oft it <qex>hits</qex><br/
Where hope is coldest and despair most fits.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And millions miss for one that <qex>hits</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To hit on</b></col> <it>or</it> <col><b>To hit
upon</b></col></mcol>, <cd>to light upon; to come to by chance; to
discover unexpectedly; <as>as, he <ex>hit on</ex> the solution after
days of trying</as>.</cd> <ldquo/None of them <xex>hit upon</xex> the
art.<rdquo/ <rj><au>Addison.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hit</ent><br/
<hw>Hit</hw>, <pos>n.</pos> <sn>1.</sn> <def>A striking against; the
collision of one body against another; the stroke that touches
anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So he the famed Cilician fencer praised,<br/
And, at each <qex>hit</qex>, with wonder seems amazed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stroke of success in an enterprise, as by a
fortunate chance; <as>as, he made a <ex>hit</ex></as>;</def>
<specif>esp.</specif> <def>A performance, as a musical recording, movie,
or play, which achieved great popularity or acclaim; also used of books
or objects of commerce which become big sellers; <as>as, the new
notebook computer was a big <ex>hit</ex> with business
travellers</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>What late he called a blessing, now was wit,<br/
And God's good providence, a lucky <qex>hit</qex>.</q>
<rj><qau>Pope.</qau></rj></p>

<p><sn>3.</sn> <def>A peculiarly apt expression or turn of thought; a
phrase which hits the mark; <as>as, a happy <ex>hit</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A game won at backgammon after the adversary has
removed some of his men. It counts less than a
<contr>gammon</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Baseball)</fld> <def>A striking of the ball;
<as>as, a safe <ex>hit</ex>; a foul <ex>hit</ex></as>; -- sometimes used
specifically for a <altname>base hit</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An act of murder performed for hire, esp. by a
professional assassin.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Base hit</b></col>, <col><b>Safe hit</b></col>,
<col><b>Sacrifice hit</b></col></mcol>. <fld>(Baseball)</fld> <cd>See
under <er>Base</er>, <er>Safe</er>, etc.</cd></cs></p>

<p><ent>Hit.</ent><br/
<hw>Hit.</hw> <pos>adj.</pos> <def>Having become very popular or
acclaimed; -- said of entertainment performances; <as>as, a <ex>hit</ex>
song, a <ex>hit</ex> movie</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hitch</ent><br/
<hw>Hitch</hw> <pr>(h<icr/ch)</pr>, <pos>v. t.</pos> <ety>[Cf. Scot.
<ets>hitch</ets> a motion by a jerk, and <ets>hatch</ets>,
<ets>hotch</ets>, to move by jerks, also Prov. G. <ets>hiksen</ets>, G.
<ets>hinken</ets>, to limp, hobble; or E. <ets>hiccough</ets>; or
possibly akin to E. <ets>hook</ets>.]</ety> <sn>1.</sn> <def>To become
entangled or caught; to be linked or yoked; to unite; to
cling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Atoms . . . which at length <qex>hitched</qex> together.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move interruptedly or with halts, jerks, or
steps; -- said of something obstructed or impeded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Slides into verse, and <qex>hitches</qex> in a rhyme.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To ease themselves . . . by <qex>hitching</qex> into another
place.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hit the legs together in going, as horses; to
interfere.</def> <mark>[Eng.]</mark> <rj><au>Halliwell.</au></rj></p>

<p><ent>Hitch</ent><br/
<hw>Hitch</hw>, <pos>v. i.</pos> <def>To <er>hitchhike</er>; -- mostly
used in the phrase to <ex>hitch</ex> a ride; <as>as, he <ex>hitched</ex>
his way home; he <ex>hitched</ex> a ride home</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hitch</ent><br/
<hw>Hitch</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hitched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hitching</conjf>.]</vmorph> <sn>1.</sn> <def>To hook; to catch or
fasten as by a hook or a knot; to make fast, unite, or yoke; <as>as, to
<ex>hitch</ex> a horse, or a halter; <ex>hitch</ex> your wagon to a
star</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>To move with hitches; <as>as, he <ex>hitched</ex>
his chair nearer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hitch up</b></col>. <sd>(a)</sd> <cd>To fasten
up.</cd> <sd>(b)</sd> <cd>To pull or raise with a jerk; as, a sailor
<xex>hitches up</xex> his trousers.</cd> <sd>(c)</sd> <cd>To attach, as
a horse, to a vehicle; as, <xex>hitch up</xex> the gray mare.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hitch</ent><br/
<hw>Hitch</hw>, <pos>n.</pos> <sn>1.</sn> <def>A catch; anything that
holds, as a hook; an impediment; an obstacle; an entanglement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of catching, as on a hook, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A stop or sudden halt; a stoppage; an impediment; a
temporary obstruction; an obstacle; <as>as, a <ex>hitch</ex> in one's
progress or utterance; a <ex>hitch</ex> in the
performance.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A sudden movement or pull; a pull up; <as>as, the
sailor gave his trousers a <ex>hitch</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>A knot or noose in a rope which
can be readily undone; -- intended for a temporary fastening; <as>as, a
half <ex>hitch</ex>; a clove <ex>hitch</ex>; a timber <ex>hitch</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Geol.)</fld> <def>A small dislocation of a bed or
vein.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hitchel</ent><br/
<hw>Hitch"el</hw> <pr>(?)</pr>, <pos>n. & v. t.</pos> <def>See
<er>Hatchel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hitchhike</ent><br/
<hw>hitch"hike`</hw> <pr>(h<icr/ch"h<imac/k`)</pr>, <pos>v. i.</pos>
<def>To travel by getting free rides from passing vehicles; <as>as, to
<ex>hitchhike</ex> across the country</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hitchhiker</ent><br/
<hw>hitchhiker</hw> <pos>n.</pos> <def>a person who travels by getting
free rides from passing vehicles; one who hitchhikes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hithe</ent><br/
<hw>Hithe</hw> <pr>(h<imac/<th/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<ymac/<edh/</ets>. Cf. <er>Hide</er> to conceal.]</ety> <def>A
port or small haven; -- used in composition; <as>as, <ex>Lambhithe</ex>,
now <ex>Lambeth</ex></as>.</def> <rj><au>Pennant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hither</ent><br/
<hw>Hith"er</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE.
<ets>hider</ets>, AS. <ets>hider</ets>; akin to Icel.
<ets>h<emac/<edh/ra</ets>, Dan. <ets>hid</ets>, Sw. <ets>hit</ets>,
Goth. <ets>hidr<emac/</ets>; cf. L. <ets>citra</ets> on this side, or E.
<ets>here</ets>, <ets>he</ets>. <root/183. Cf. <er>He</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To this place; -- used with verbs signifying motion,
and implying motion toward the speaker; correlate of <xex>hence</xex>
and <xex>thither</xex>; <as>as, to come or bring
<ex>hither</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To this point, source, conclusion, design, etc.; --
in a sense not physical.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hither</qex> we refer whatsoever belongeth unto the highest
perfection of man.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hither and thither</b></col>, <cd>to and fro; backward
and forward; in various directions.</cd> <ldquo/Victory is like a
traveller, and goeth <xex>hither and thither</xex>.<rdquo/
<rj><au>Knolles.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hither</ent><br/
<hw>Hith"er</hw>, <pos>a.</pos> <sn>1.</sn> <def>Being on the side next
or toward the person speaking; nearer; -- correlate of
<xex>thither</xex> and <xex>farther</xex>; <as>as, on the
<ex>hither</ex> side of a hill</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Applied to time: On the hither side of, younger
than; of fewer years than.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And on the <qex>hither</qex> side, or so she looked,<br/
Of twenty summers.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To the present generation, that is to say, the people a few years
on the <qex>hither</qex> and thither side of thirty, the name of
<person>Charles Darwin</person> stands alongside of those of
<person>Isaac Newton</person> and <person>Michael Faraday</person>.</q>
<rj><qau>Huxley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hithermost</ent><br/
<hw>Hith"er*most`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Nearest on this
side.</def> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hitherto</ent><br/
<hw>Hith"er*to`</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>To
this place; to a prescribed limit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hitherto</qex> shalt thou come, but no further.</q>
<rj><qau>Job xxxviii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Up to this time; as yet; until now.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord hath blessed me <qex>hitherto</qex>.</q> <rj><qau>Josh.
xvii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hitherward</ent><br/
<hw>Hith"er*ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>hiderweard</ets>.]</ety> <def>Toward this place; hither.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Marching <qex>hitherward</qex> in proud array.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hit it off</ent><br/
<hw>hit it off</hw> <pos>v. i.</pos> <def>To get along well together; to
be compatible; to work well together; -- of people in interactive
situations; <as>as, the new chemist <ex>hit it off</ex> immediately with
his supervisor</as>.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Hitlerian</ent><br/
<hw>Hitlerian</hw> <pos>adj.</pos> <def>of or pertaining to Adolf
Hitler; resembling the policies of Hitler.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hitless</ent><br/
<hw>hitless</hw> <pos>adj.</pos> <sn>1.</sn> <fld>(Baseball)</fld>
<def>Having no hits scored; -- of a baseball game (or the pitching) in
which a pitcher allows the opponent no hits; <as>as, a <ex>hitless</ex>
game</as>.</def><br/
<syn><b>Syn. --</b> no-hit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Having no points scored.</def><br/
<syn><b>Syn. --</b> scoreless, goalless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hit man</ent><br/
<hw>hit man</hw> <pos>n.</pos> <sn>1.</sn> <def>A professional murderer,
esp. one working for a criminal organization; also called
<altname>torpedo</altname>.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A slanderer working for political purposes to damage
the reputation of an opponent; a <er>hatchet man</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hit on</ent><br/
<hw>hit on</hw> <pos>v. t.</pos> <def>To make sexual advances toward; --
usually of men making advances to women.</def> <mark>[Colloq.]</mark>
<br/
[<source>PJC</source>]</p>

<p><ent>hit-or-miss</ent><br/
<hw>hit-or-miss</hw> <pos>adj.</pos> <def>performed without care or
close attention; slipshod; careless; -- of the manner of performing a
task. Opposite of <ant>careful</ant>, <ant>conscientious</ant> or
<ant>methodical</ant>.</def><br/
<syn><b>Syn. --</b> haphazard, slapdash, slipshod, sloppy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hitter</ent><br/
<hw>Hit"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
hits or strikes; <as>as, a hard <ex>hitter</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Baseball)</fld> <def>The batter; <as>as, there are
two strikes on the <ex>hitter</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>heavy hitter</b></col> <sn>1.</sn> <cd>A baseball player
who gets many extra-base hits.</cd> <sn>2.</sn> <cd>A person who is very
important or is very effective at his profession.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>hitting</ent><br/
<hw>hitting</hw> <pos>n.</pos> <ety>[<pos>vb. n.</pos> from
<er>hit</er>, <pos>v.</pos>]</ety> <def>The act of striking one thing
against another; <as>as, repeated <ex>hitting</ex> raised a large
bruise</as></def><br/
<syn><b>Syn. --</b> hit, striking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hittite</ent><br/
<hw>Hit"tite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Heb.
<ets>Khitt<imac/m</ets> Hittites.]</ety> <def>A member of an ancient
people (or perhaps group of peoples) whose settlements extended from
Armenia westward into Asia Minor and southward into Palestine. They are
known to have been met along the Orontes as early as 1500 <sc>b.
c.</sc>, and were often at war with the Egyptians and Assyrians.
Especially in the north they developed a considerable civilization, of
which numerous monuments and inscriptions are extant. Authorities are
not agreed as to their race. While several attempts have been made to
decipher the Hittite characters, little progress has yet been
made.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hittorf rays</ent><br/
<hw>Hit"torf rays</hw> <pr>(?)</pr>. <fld>(Elec.)</fld> <def>Rays
(chiefly cathode rays) developed by the electric discharge in Hittorf
tubes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hittorf tube</ent><br/
<hw>Hit"torf tube</hw>. <fld>(Elec.)</fld> <sd>(a)</sd> <def>A highly
exhausted glass tube with metallic electrodes nearly in contact so as to
exhibit the insulating effects of a vacuum. It was used by the German
physicist <person>W. Hittorf</person> (b. 1824).</def> <sd>(b)</sd>
<def>A Crookes tube.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hive</ent><br/
<hw>Hive</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hive</ets>,
<ets>huve</ets>, AS. <ets>h<?/fe</ets>.]</ety> <sn>1.</sn> <def>A box,
basket, or other structure, for the reception and habitation of a swarm
of honeybees.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The bees of one hive; a swarm of bees.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place swarming with busy occupants; a
crowd.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hive</qex> of Roman liars.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hive bee</b></col> <fld>(Zool.)</fld>, <cd>the
honeybee.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hive</ent><br/
<hw>Hive</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hived</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hiving</conjf>.]</vmorph> <sn>1.</sn> <def>To collect into a
hive; to place in, or cause to enter, a hive; <as>as, to <ex>hive</ex> a
swarm of bees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To store up in a hive, as honey; hence, to gather
and accumulate for future need; to lay up in store.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hiving</qex> wisdom with each studious year.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hive</ent><br/
<hw>Hive</hw>, <pos>v. i.</pos> <def>To take shelter or lodgings
together; to reside in a collective body.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiveless</ent><br/
<hw>Hive"less</hw>, <pos>a.</pos> <def>Destitute of a hive.</def>
<rj><au>Gascoigne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hiver</ent><br/
<hw>Hiv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who collects bees
into a hive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hives</ent><br/
<hw>Hives</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot.; perh. akin to E.
<ets>heave</ets>.]</ety> <fld>(Med.)</fld> <sd>(a)</sd> <def>The
croup.</def> <sd>(b)</sd> <def>An eruptive disease <fld>(Varicella
globularis)</fld>, allied to the chicken pox.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hizz</ent><br/
<hw>Hizz</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To hiss.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>HMO</ent><br/
<hw>HMO</hw> <pos>n.</pos> <ety>[acronym for <ets>H</ets>ealth
<ets>M</ets>aintenance <ets>O</ets>rganization.]</ety> <def>A health
maintenance organization; a form of group health insurance that entitles
members to services of participating hospitals and clinics and
physicians.</def> <mark>[acronym]</mark> <br/
<syn><b>Syn. --</b> health maintenance organization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>H. M. S.</ent><br/
<hw>H. M. S.</hw> <pos>n.</pos> <def>A prefix used in the names of
British warships, meaning <sig>His Majesty's Ship</sig> or <sig>Her
Majesty's Ship</sig>; <as>as, <ex>H. M. S.</ex> Pinafore</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>HN</ent><br/
<hw>HN</hw> <pos>n.</pos> <def>a colorless explosive liquid that is
volatile, poisonous, and foul-smelling.</def><br/
<syn><b>Syn. --</b> hydrazoic acid, azoimide.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ho</ent><br/
<hw>Ho</hw> <pr>(?)</pr>, <pos>pron.</pos> <def>Who.</def>
<mark>[Obs.]</mark> <note>In some Chaucer MSS.</note></p>

<p><ent>Hoa</ent><br/
<ent>Ho</ent><br/
<mhw>{ <hw>Ho</hw>, <hw>Hoa</hw> }</mhw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[See <er>Ho</er>, <pos>interj.</pos>, 2.]</ety> <def>A stop; a
halt; a moderation of pace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no <qex>ho</qex> with them.</q>
<rj><qau>Decker.</qau></rj></p>

<p><ent>Ho</ent><br/
<hw>Ho</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Chem.)</fld>
<def>The chemical symbol for Holmium.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hoa</ent><br/
<ent>Ho</ent><br/
<mhw>{ <hw>Ho</hw>, <hw>Hoa</hw> }</mhw> <pr>(h<omac/)</pr>,
<pos>interj.</pos> <ety>[Cf. F. & G. <ets>ho</ets>.]</ety> <sn>1.</sn>
<def>Halloo! attend! -- a call to excite attention, or to give notice of
approach.</def> <ldquo/What noise there, <xex>ho</xex>?<rdquo/
<rj><au>Shak.</au></rj> <ldquo/<qex>Ho</qex>! who's within?<rdquo/
<au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Perhaps corrupted fr. <ets>hold</ets>; but cf. F.
<ets>hau</ets> stop! and E. <ets>whoa</ets>.]</ety> <def>Stop! stand
still! hold! -- a word now used by teamsters, but formerly to order the
cessation of anything.</def> <altsp>[Written also <asp>whoa</asp>, and,
formerly, <asp>hoo</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>The duke . . . pulled out his sword and cried
<ldquo/<qex>Hoo</qex>!<rdquo/</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An herald on a scaffold made an <qex>hoo</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hoactzin</ent><br/
<hw>hoactzin</hw> <pos>n.</pos> <def>A crested ill-smelling South
American bird (<spn>Opisthocomus hoazin</spn>) whose young have claws on
the first and second digits of the wings.</def><br/
<syn><b>Syn. --</b> hoatzin, stinkbird, <spn>Opisthocomus
hoazin</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hoagy</ent><br/
<ent>hoagie</ent><br/
<mhw><hw>hoagie</hw>, <hw>hoagy</hw></mhw> <pos>n.</pos> <def>a large
sandwich on a long crusty roll that is split lengthwise and filled with
meats and cheese (and tomato and onion and lettuce and condiments);
different names are used in different sections of the U. S., such as
<altname>hero</altname>, <altname>grinder</altname>, and
<altname>submarine</altname>.</def><br/
<syn><b>Syn. --</b> bomber, grinder, hero, hero sandwich, hoagie, Cuban
sandwich, Italian sandwich, poor boy, sub, submarine, submarine
sandwich, torpedo, wedge, zep.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoar</ent><br/
<hw>Hoar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>hor</ets>,
<ets>har</ets>, AS. <ets>h<amac/r</ets>; akin to Icel.
<ets>h<amac/rr</ets>, and to OHG. <ets>h<emac/r</ets> illustrious,
magnificent; cf. Icel. <ets>Hei<edh/</ets> brightness of the sky, Goth.
<ets>hais</ets> torch, Skr. <ets>k<emac/tus</ets> light, torch. Cf.
<er>Hoary</er>.]</ety> <sn>1.</sn> <def>White, or grayish white; <as>as,
<ex>hoar</ex> frost; <ex>hoar</ex> cliffs</as>.</def>
<ldquo/<xex>Hoar</xex> waters.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Gray or white with age; hoary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose beard with age is <qex>hoar</qex>.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Old trees with trunks all <qex>hoar</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Musty; moldy; stale.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoar</ent><br/
<hw>Hoar</hw>, <pos>n.</pos> <def>Hoariness; antiquity.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Covered with the awful <qex>hoar</qex> of innumerable ages.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoar</ent><br/
<hw>Hoar</hw>, <pos>v. t.</pos> <ety>[AS. <ets>h<amac/rian</ets> to grow
gray.]</ety> <def>To become moldy or musty.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoard</ent><br/
<hw>Hoard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Hoarding</er>,
2.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoard</ent><br/
<hw>Hoard</hw>, <pos>n.</pos> <ety>[OE. <ets>hord</ets>, AS.
<ets>hord</ets>; akin to OS. <ets>hord</ets>, G. <ets>hort</ets>, Icel.
<ets>hodd</ets>, Goth. <ets>huzd</ets>; prob. from the root of E.
<ets>hide</ets> to conceal, and of L. <ets>custos</ets> guard, E.
<ets>custody</ets>. See <er>Hide</er> to conceal.]</ety> <def>A store,
stock, or quantity of anything accumulated or laid up; a hidden supply;
a treasure; <as>as, a <ex>hoard</ex> of provisions; a <ex>hoard</ex> of
money.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoard</ent><br/
<hw>Hoard</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hoarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hoarding</conjf>.]</vmorph> <ety>[AS. <ets>hordian</ets>.]</ety>
<def>To collect and lay up; to amass and deposit in secret; to store
secretly, or for the sake of keeping and accumulating; <as>as, to
<ex>hoard</ex> grain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoard</ent><br/
<hw>Hoard</hw>, <pos>v. i.</pos> <def>To lay up a store or hoard, as of
money.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>hoard</qex> for those whom he did breed.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarder</ent><br/
<hw>Hoard"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
hoards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarding</ent><br/
<hw>Hoard"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From OF.
<ets>hourd</ets>, <ets>hourt</ets>, barrier, palisade, of German or
Dutch origin; cf. D. <ets>horde</ets> hurdle, fence, G.
<ets>horde</ets>, <ets>h<uum/rde</ets>; akin to E. <ets>hurdle</ets>.
<root/16. See <er>Hurdle</er>.]</ety> <sn>1.</sn> <fld>(Arch.)</fld>
<def>A screen of boards inclosing a house and materials while builders
are at work.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Posted on every dead wall and <qex>hoarding</qex>.</q>
<rj><qau>London Graphic.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fence, barrier, or cover, inclosing, surrounding,
or concealing something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole arrangement was surrounded by a <qex>hoarding</qex>, the
space within which was divided into compartments by sheets of tin.</q>
<rj><qau>Tyndall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoared</ent><br/
<hw>Hoared</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Moldy; musty.</def>
<mark>[Obs.]</mark> <rj><au>Granmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarfrost</ent><br/
<hw>Hoar"frost`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The white
particles formed by the congelation of dew; white frost.</def>
<altsp>[Written also <asp>horefrost</asp>. See <er>Hoar</er>,
<pos>a.</pos>]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>He scattereth the <qex>hoarfrost</qex> like ashes.</q>
<rj><qau>Ps. cxlvii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarhound</ent><br/
<hw>Hoar"hound`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Horehound</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoariness</ent><br/
<hw>Hoar"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Hoary</er>.]</ety> <def>The state of being hoary.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarse</ent><br/
<hw>Hoarse</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Hoarser</adjf> <pr>(?)</pr>, <pos>superl.</pos>
<adjf>Hoarsest</adjf>.]</amorph> <ety>[OE. <ets>hors</ets>, also
<ets>hos</ets>, <ets>has</ets>, AS. <ets>h<amac/s</ets>; akin to D.
<ets>heesch</ets>, G. <ets>heiser</ets>, Icel. <ets>h<amac/ss</ets>,
Dan. <ets>h<ae/s</ets>, Sw. <ets>hes</ets>. Cf. Prov. E.
<ets>heazy</ets>.]</ety> <sn>1.</sn> <def>Having a harsh, rough, grating
voice or sound, as when affected with a cold; making a rough, harsh cry
or sound; <as>as, the <ex>hoarse</ex> raven</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hoarse</qex> resounding shore.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Harsh; grating; discordant; -- said of any
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarsely</ent><br/
<hw>Hoarse"ly</hw>, <pos>adv.</pos> <def>With a harsh, grating sound or
voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarsen</ent><br/
<hw>Hoars"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hoarsened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hoarsening</conjf>.]</vmorph> <def>To make
hoarse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall be obliged to <qex>hoarsen</qex> my voice.</q>
<rj><qau>Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoarseness</ent><br/
<hw>Hoarse"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Harshness or
roughness of voice or sound, due to mucus collected on the vocal cords,
or to swelling or looseness of the cords.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 697 --></p>

<p><ent>Hoarstone</ent><br/
<hw>Hoar"stone`</hw> <pr>(h<omac/r"st<omac/n`)</pr>, <pos>n.</pos>
<def>A stone designating the bounds of an estate; a landmark.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoary</ent><br/
<hw>Hoar"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>White or
whitish.</def> <ldquo/The <xex>hoary</xex> willows.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>White or gray with age; hoar; <as>as, <ex>hoary</ex>
hairs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reverence the <qex>hoary</qex> head.</q> <rj><qau>Dr. T.
Dwight.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> Hence, <def>remote in time past; <as>as, <ex>hoary</ex>
antiquity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Moldy; mossy; musty.</def> <mark>[Obs.]</mark>
<rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>Of a pale silvery gray.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Bot.)</fld> <def>Covered with short, dense, grayish
white hairs; canescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hoary bat</b></col> <fld>(Zool.)</fld>, <cd>an American
bat (<spn>Atalapha cinerea</spn>), having the hair yellowish, or brown,
tipped with white.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoatzin</ent><br/
<hw>Ho"at*zin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Hoazin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoax</ent><br/
<hw>Hoax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. contr. fr.
<ets>hocus</ets>, in <ets>hocus-pocus</ets>.]</ety> <def>A deception for
mockery or mischief; a deceptive trick or story; a practical joke.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoax</ent><br/
<hw>Hoax</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hoaxed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hoaxing</conjf>.]</vmorph> <def>To deceive by a story or a trick,
for sport or mischief; to impose upon sportively.</def>
<rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoaxer</ent><br/
<hw>Hoax"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
hoaxes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoazin</ent><br/
<hw>Hoa"zin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
remarkable South American bird (<spn>Opisthocomus cristatus</spn>); the
crested touraco. By some Zoologists it is made the type of a distinct
order (<ord>Opisthocomi</ord>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hob</ent><br/
<hw>Hob</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. akin to
<ets>hump</ets>. Cf. <er>Hub</er>. ]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The hub of a wheel. See <er>Hub</er>.</def>
<rj><au>Washington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The flat projection or iron shelf at the side of a
fire grate, where things are put to be kept warm.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mech.)</fld> <def>A threaded and fluted hardened
steel cutter, resembling a tap, used in a lathe for forming the teeth of
screw chasers, worm wheels, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A peg, pin, or mark used as a target in some games,
as an iron pin in quoits; also, a game in which such a target is
used.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hob</ent><br/
<hw>Hob</hw>, <pos>n.</pos> <ety>[Orig. an abbrev. of <ets>Robin</ets>,
<ets>Robert</ets>; <ets>Robin Goodfellow</ets> a celebrated fairy, or
domestic spirit. Cf. <er>Hobgoblin</er>, and see <er>Robin</er>.]</ety>
<sn>1.</sn> <def>A fairy; a sprite; an elf.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>From elves, hobs, and fairies, . . . <br/
Defend us, good Heaven !</q> <rj><qau>Beau. & FL.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A countryman; a rustic; a clown.</def>
<mark>[Obs.]</mark> <rj><au>Nares.</au></rj></p>

<p><ent>Hob</ent><br/
<hw>Hob</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The male
ferret.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hobandnob</ent><br/
<ent>Hobanob</ent><br/
<mhw>{ <hw>Hob"a*nob`</hw> <pr>(?)</pr>, <hw>Hob"and*nob`</hw>, }</mhw>
<pos>v. i.</pos> <def>Same as <er>Hobnob</er>.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbism</ent><br/
<hw>Hob"bism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The philosophical
system of <person>Thomas <etsep>Hobbes</etsep></person>, an English
materialist (1588-1679); esp., his political theory that the most
perfect form of civil government is an absolute monarchy with despotic
control over everything relating to law, morals, and religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbist</ent><br/
<hw>Hob"bist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who accepts the
doctrines of <person>Thomas Hobbes</person>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobble</ent><br/
<hw>Hob"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hobbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hobbling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>hobelen</ets>, <ets>hoblen</ets>, freq. of <ets>hoppen</ets> to
hop; akin to D. <ets>hobbelen</ets>, <ets>hoblen</ets>,
<ets>hoppeln</ets>. See <er>Hop</er> to jump, and cf. <er>Hopple</er>
]</ety> <sn>1.</sn> <def>To walk lame, bearing chiefly on one leg; to
walk with a hitch or hop, or with crutches.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The friar was <qex>hobbling</qex> the same way too.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move roughly or irregularly; -- said of style in
writing.</def> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hobbling</qex> versification, the mean diction.</q>
<rj><qau>Jeffreys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobble</ent><br/
<hw>Hob"ble</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To fetter by tying
the legs; to hopple; to clog.</def> <ldquo/ They <xex>hobbled</xex>
their horses.<rdquo/ <rj><au>Dickens</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perplex; to embarrass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobble</ent><br/
<hw>Hob"ble</hw>, <pos>n.</pos> <sn>1.</sn> <def>An unequal gait; a
limp; a halt; <as>as, he has a <ex>hobble</ex> in his gait</as>.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>Hopple</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Difficulty; perplexity; embarrassment.</def>
<rj><au>Waterton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobblebush</ent><br/
<hw>Hob"ble*bush`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A low bush (<spn>Viburnum lantanoides</spn>) having long,
straggling branches and handsome flowers. It is found in the Northern
United States. Called also <altname>shinhopple</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbletehoy</ent><br/
<ent>Hobbledehoy</ent><br/
<mhw>{ <hw>Hob"ble*de*hoy`</hw> <pr>(?)</pr>, <hw>Hob"ble*te*hoy`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <altsp>[Written also
<asp>hobbetyhoy</asp>, <asp>hobbarddehoy</asp>, <asp>hobbedehoy</asp>,
<asp>hobdehoy</asp>.]</altsp> <ety>[ Cf. Prob. E. <ets>hobbledygee</ets>
with a limping movement; also F. <ets>hobereau</ets>, a country squire,
E. <ets>hobby</ets>, and OF. <ets>hoi</ets> to-day; perh. the orig.
sense was, an upstart of to-day.]</ety> <def>A youth between boy and
man; an awkward, gawky young fellow .</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All the men, boys, and <qex>hobbledehoys</qex> attached to the
farm.</q> <rj><qau>Dickens. .</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbler</ent><br/
<hw>Hob"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
hobbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbler</ent><br/
<hw>Hob"bler</hw>, <pos>n.</pos> <ety>[OE. also <ets>hobeler</ets>, OF.
<ets>hobelier</ets>, LL. <ets>hobellarius</ets>. See <er>Hobby</er> a
horse.]</ety> <fld>(Eng. Hist.)</fld> <def>One who by his tenure was to
maintain a horse for military service; a kind of light horseman in the
Middle Ages who was mounted on a hobby.</def> <rj><au>Hallam. Sir J.
Davies.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobble skirt</ent><br/
<hw>Hob"ble skirt</hw>. <def>A woman's skirt so scant at the bottom as
to restrain freedom of movement after the fashion of a hobble.</def> --
<wordforms><wf>Hob"ble-skirt`ed</wf>, <pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hobblingly</ent><br/
<hw>Hob"bling*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With a limping
step.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbly</ent><br/
<hw>Hob"bly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rough; uneven; causing
one to hobble; as a <xex>hobbly</xex> road.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobby</ent><br/
<hw>Hob"by</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hobbies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>hobi</ets>; cf.
OF. <ets>hobe</ets>, <ets>hob<eacute/</ets>, F. <ets>hobereau</ets> a
hobby, a species of falcon. OF. <ets>hober</ets> to move, stir. Cf.
<er>Hobby</er> a horse.]</ety> <fld>(Zool.)</fld> <def>A small,
strong-winged European falcon (<spn>Falco subbuteo</spn>), formerly
trained for hawking.</def></p>

<p><ent>Hobbyhorse</ent><br/
<ent>Hobby</ent><br/
<mhw>{ <hw>Hob"by</hw> <pr>(?)</pr>, <hw>Hob"by*horse`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[OE. <ets>hobin</ets> a nag,
OF. <ets>hobin</ets> hobby; cf. <ets>hober</ets> to stir, move; prob. of
German or Scand. origin; cf. Dan. <ets>hoppe</ets> a mare, dial. Sw.
<ets>hoppa</ets>; perh. akin to E. <ets>hop</ets> to jump.]</ety>
<sn>1.</sn> <def>A strong, active horse, of a middle size, said to have
been originally from Ireland; an ambling nag.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stick, often with the head or figure of a horse,
on which boys make believe to ride.</def> <altsp>[ Usually under the
form <asp>hobbyhorse</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A subject or plan upon which one is constantly
setting off; a favorite and ever-recurring theme of discourse, thought,
or effort; that which occupies one's attention unduly, or to the
weariness of others; a ruling passion.</def> <altsp>[Usually under the
form <asp>hobby</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Not one of them has any <qex>hobbyhorse</qex>, to use the phrase
of Sterne.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobbyhorsical</ent><br/
<hw>Hob`by*hors"ic*al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Pertaining
to, or having, a hobby or whim; eccentric;
whimsical.</def><mark>[Colloq.]</mark> <rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobgoblin</ent><br/
<hw>Hob"gob`lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 2d Hob, and
<er>Goblin</er>.]</ety> <def>A frightful goblin; an imp; a bugaboo;
also, a name formerly given to the household spirit, Robin
Goodfellow.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobiler</ent><br/
<hw>Hob"i*ler</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[See 2d
<er>Hobbler</er>.]</ety> <def>A light horseman. See 2d
<er>Hobbler</er>.</def> <mark>[Obs.]</mark> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobit</ent><br/
<hw>Ho"bit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Howitzer</er>.]</ety> <fld>(Mil.)</fld> <def>A small mortar on a gun
carriage, in use before the howitzer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobnail</ent><br/
<hw>Hob"nail`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[1st <ets>hob +
nail</ets>.]</ety> <sn>1.</sn> <def>A short, sharp-pointed, large-headed
nail, -- used in shoeing houses and for studding the soles of heavy
shoes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A clownish person; a rustic.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hobnail liver</b></col> <fld>(Med.)</fld>, <cd>a disease
in which the liver is shrunken, hard, and covered with projections like
hobnails; one of the forms of cirrhosis of the liver.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobnail</ent><br/
<hw>Hob"nail`</hw>, <pos>v. t.</pos> <def>To tread down roughly, as with
hobnailed shoes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your rights and charters <qex>hobnailed</qex> into slush.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobnailed</ent><br/
<hw>Hob"nailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See with hobnails,
as a shoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobnob</ent><br/
<hw>Hob"nob`</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>habban</ets> to have + <ets>habban</ets> to have not; <ets>ne</ets>
not + <ets>habban</ets> to have. See <er>Have</er>, and cf.
<er>Habnab</er>.]</ety> <sn>1.</sn> <def>Have or have not; -- a familiar
invitation to reciprocal drinking.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>At random; hit or miss. (Obs.)</def>
<rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobnob</ent><br/
<hw>Hob"nob`</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hornobbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hornobbing</conjf>.]</vmorph> <sn>1.</sn> <def>To drink
familiarly (with another).</def> <altsp>[ Written also
<asp>hob-a-nob</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To associate familiarly; to be on intimate terms;
<as>as, to <ex>hobnob</ex> with the political elite</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobnob</ent><br/
<hw>Hob"nob`</hw>, <pos>n.</pos> <def>Familiar, social
intercourse.</def> <rj><au>W. Black.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobo</ent><br/
<hw>Ho"bo</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl. <plw>Hobos</plw> or
<plw>Hoboes</plw> <pr>(#)</pr></plu>. <ety>[Of uncertain origin.]</ety>
<def>A professional tramp; one who spends his life traveling from place
to place, esp. by stealing rides on trains, and begging for a
living.</def> <mark>[U. S.]</mark> -- <wordforms><wf>Ho"bo*ism</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
<syn><b>Syn. --</b> tramp; bum; vagrant; knight of the road.</syn><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hobornob</ent><br/
<hw>Hob"or*nob`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>See
<er>Hobnob</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoboy</ent><br/
<hw>Ho"boy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hautboy or
oboe.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hobson's choice</ent><br/
<hw>Hob"son's choice"</hw> <pr>(?)</pr>. <def>A choice without an
alternative; the thing offered or nothing.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is said to have had its origin in the name of one
<xex>Hobson</xex>, at Cambridge, England, who let horses, and required
every customer to take in his turn the horse which stood next the stable
door.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hocco</ent><br/
<hw>Hoc"co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
crested curassow; -- called also <altname>royal pheasant</altname>. See
<er>Curassow</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hochepot</ent><br/
<hw>Hoche"pot</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hotchpot.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hock</ent><br/
<hw>Hock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from
<ets>Hoch</ets>heim, in Germany.]</ety> <def>A Rhenish wine, of a light
yellow color, either sparkling or still. The name is also given
indiscriminately to all Rhenish wines.</def></p>

<p><ent>Hough</ent><br/
<ent>Hock</ent><br/
<mhw><hw>Hock</hw>, <hw>Hough</hw> <pr>(<?/)</pr></mhw>, <pos>n.</pos>
<ety>[ AS. <ets>h<?/h</ets> the heel; prob. akin to Icel.
<ets>h<amac/sinn</ets> hock sinew, Dan. <ets>hasc</ets>, G.
<ets>hechse</ets>, <ets>h<aum/chse</ets>, LG. <ets>hacke</ets>, D.
<ets>hak</ets>; also to L. <ets>coxa</ets> hip (cf. <er>Cuisses</er>),
Skr. <ets>kaksha</ets> armpit. <root/12. Cf. <er>Heel</er>.]</ety>
<sn>1.</sn> <sd>(a)</sd> <def>The joint in the hind limb of quadrupeds
between the leg and shank, or tibia and tarsus, and corresponding to the
ankle in man.</def> <sd>(b)</sd> <def>A piece cut by butchers, esp. in
pork, from either the front or hind leg, just above the foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The popliteal space; the ham.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hock</ent><br/
<hw>Hock</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To disable by cutting
the tendons of the hock; to hamstring; to hough.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pawn; <as>as, to <ex>hock</ex> one's
jewelry</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hock</ent><br/
<hw>Hock</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of having been
pawned; usually preceded by <it>in</it>; <as>as, all her jewelry is in
<ex>hock</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The state of being in debt; <as>as, it took him two
years to get out of <ex>hock</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hockamore</ent><br/
<hw>Hock"a*more</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Hock</er>.]</ety> <def>A Rhenish wine.</def> <mark>[Obs.]</mark>
<see>See <er>Hock</er>.</see> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hockday</ent><br/
<hw>Hock"day`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>h<omac/cor</ets> mockery, scorn.]</ety> <def>A holiday
commemorating the expulsion of the Danes, formerly observed on the
second Tuesday after Easter; -- called also
<altname>hocktide</altname>.</def> <mark>[Eng.]</mark> <altsp>[Written
also <asp>hokeday</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hockey</ent><br/
<hw>Hock"ey</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Hook</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>A game in which two parties of
players, armed with sticks curved or hooked at the end, attempt to drive
any small object (as a ball or a bit of wood) toward opposite
goals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The stick used by the players.</def> <altsp>[Written
also <asp>hookey</asp> and <asp>hawkey</asp>.]</altsp> <-- ice hockey,
hockey puck --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hockherb</ent><br/
<hw>Hock"herb`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The mallow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hockle</ent><br/
<hw>Hoc"kle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hockled</conjf><pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hockling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From 2d
<er>Hock</er>.]</ety> <sn>1.</sn> <def>To hamstring; to hock; to
hough.</def> <rj><au>Hanmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mow, as stubble.</def>
<rj><au>Mason.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hocus</ent><br/
<hw>Ho"cus</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Hocus-pocus</er>.]</ety> <sn>1.</sn> <def>To deceive or cheat.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To adulterate; to drug; <as>as, liquor is said to be
<ex>hocused</ex> for the purpose of stupefying the drinker</as>.</def>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To stupefy with drugged liquor.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hocus</ent><br/
<hw>Ho"cus</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who cheats or
deceives.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Drugged liquor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hocus-pocus</ent><br/
<hw>Ho"cus-po"cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. invented
by jugglers in imitation of Latin. Cf. <er>Hoax</er>,
<er>Hocus</er>.]</ety> <sn>1.</sn> <def>A term used by magicians or
conjurers in pretended incantations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A juggler or trickster.</def> <mark>[Archaic]</mark>
<rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A magician's trick; a cheat; nonsense.</def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Obfuscating talk or elaborate but meaningless
activity intended to hide a deception or to obscure what is actually
happening; verbal misrepresentation intended to take advantage of you in
some way.</def><br/
<syn><b>Syn. --</b> trickery, slickness, hanky panky, jiggery-pokery,
skulduggery, skullduggery.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Hocus-pocus</ent><br/
<hw>Ho"cus-po"cus</hw>, <pos>v. t.</pos> <def>To cheat.</def>
<mark>[Colloq.]</mark> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hod</ent><br/
<hw>Hod</hw> <pr>(h<ocr/d)</pr>, <pos>n.</pos> <ety>[Prov. E. for
<ets>hold</ets>, <it>i. e.</it>, that which holds. See
<er>Hold</er>.]</ety> <sn>1.</sn> <def>A kind of wooden tray with a
handle, having V-shaped trough, made of wood or metal, attached to a
long handle and usually carried over the shoulder; it is a tool used by
construction workers for carrying bricks or mortar.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A utensil for holding coal; a coal
scuttle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hod carrier</ent><br/
<hw>hod" car`ri*er</hw> <pr>(hocr/d" k<acr/r~r<icr/*<etil/r)</pr>
<pos>n.</pos> <def>A construction worker whose main function is to carry
construction materials in a hod{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hoddengray</ent><br/
<hw>Hod"den*gray`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Perh. akin to
E. <ets>hoiden</ets> rustic, clownish.]</ety> <def>Applied to coarse
cloth made of undyed wool, formerly worn by Scotch peasants.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoddy</ent><br/
<hw>Hod"dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. for
<ets>hooded</ets>.]</ety> <fld>(Zool.)</fld> <def>See <cref>Dun
crow</cref>, under <er>Dun</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoddydoddy</ent><br/
<hw>Hod"dy*dod`dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. E. also
<ets>hoddypeke</ets>, <ets>hoddypoule</ets>,
<ets>hoddymandoddy</ets>.]</ety> <def>An awkward or foolish
person.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hodgepodge</ent><br/
<hw>Hodge"podge`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mixed mass; a
medley. See <er>Hotchpot</er>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hodgkin's disease</ent><br/
<hw>Hodg`kin's dis*ease"</hw> <pr>(?)</pr>. <fld>(Med.)</fld> <def>A
morbid condition characterized by progressive an<ae/mia and enlargement
of the lymphatic glands; -- first described by Dr. <xex>Hodgkin</xex>,
an English physician.</def></p>

<p><ent>Hodiernal</ent><br/
<ent>Hodiern</ent><br/
<mhw>{ <hw>Ho"di*ern</hw> <pr>(?)</pr>, <hw>Ho`di*er"nal</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hodiernus</ets>, fr.
<ets>hodie</ets> today.]</ety> <def>Of this day; belonging to the
present day.</def> <mark>[R.]</mark> <rj><au>Boyle. Quart.
Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hodman</ent><br/
<hw>Hod"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hodmen</plw>(<?/).</plu> <def>A man who carries a hod; a mason's
tender.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hodmandod</ent><br/
<hw>Hod"man*dod</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Dodman</er>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hodograph</ent><br/
<hw>Hod"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.<?/ path +
<ets>graph</ets>.]</ety> <fld>(Math.)</fld> <def>A curve described by
the moving extremity of a line the other end of which is fixed, this
line being constantly parallel to the direction of motion of, and having
its length constantly proportional to the velocity of, a point moving in
any path; -used in investigations respecting central forces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hodometer</ent><br/
<hw>ho*dom"e*ter</hw> <pr>(h<osl/*d<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"odo`metron</grk>, <grk>"odo`metros</grk>,
an instrument for measuring distance; <grk>"odo`s</grk> way, path, road
+ <grk>me`tron</grk> measure: cf. F. <ets>odom<eacute/tre</ets>,
<ets>hodom<eacute/tre</ets>. See also <er>odometer</er>.]</ety> <def>A
device for measuring the length of a path, consisting of a wheel of
known circumference attached to a rod held in the hand, and pushed along
a surface, which is usually the ground or a floor. The number of times
the wheel makes a complete circle multiplied by the circumference is a
measure of the length of the path traversed. It may be used to measure
distances on curved as well as straight paths. A variant which registers
the miles and rods traversed is sometimes used by surveyors.</def><br/
[<source>PJC</source> + <source>1913 Webster</source>]</p>

<p><ent>Hodr</ent><br/
<hw>Hodr</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A blind god; misled
by Loki he kills Balder by throwing a bough of mistletoe.</def><br/
<syn><b>Syn. --</b> Hoth, Hothr, Hoder.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoe</ent><br/
<hw>Hoe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>hoe</ets>, F.
<ets>houe</ets>; of German origin, cf. OHG. <ets>houwa</ets>,
<ets>howa</ets>, G. <ets>haue</ets>, fr. OHG. <ets>houwan</ets> to hew.
See <er>Hew</er> to cut.]</ety> <sn>1.</sn> <def>A tool chiefly for
digging up weeds, and arranging the earth about plants in fields and
gardens. It is made of a flat blade of iron or steel having an eye or
tang by which it is attached to a wooden handle at an acute
angle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The horned or piked dogfish. See
<er>Dogfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dutch hoe</b></col>, <cd>one having the blade set for use
in the manner of a spade.</cd> -- <col><b>Horse hoe</b></col>, <cd>a
kind of cultivator.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoe</ent><br/
<hw>Hoe</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hoed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hoeing</conjf>.]</vmorph> <ety>[Cf. F. <ets>houer</ets>.]</ety>
<def>To cut, dig, scrape, turn, arrange, or clean, with a hoe; <as>as,
to <ex>hoe</ex> the earth in a garden</as>; also, to clear from weeds,
or to loosen or arrange the earth about, with a hoe; <as>as, to
<ex>hoe</ex> corn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hoe one's row</b></col>, <cd>to do one's share of a
job.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoe</ent><br/
<hw>Hoe</hw>, <pos>v. i.</pos> <def>To use a hoe; to labor with a
hoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoecake</ent><br/
<hw>Hoe"cake`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cake of Indian
meal, water, and salt, baked before the fire or in the ashes; -- so
called because often cooked on a hoe.</def> <mark>[Southern
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoemother</ent><br/
<hw>Hoe"moth`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A local Orkney
name; cf. Icel. <ets>h<amac/r</ets>.]</ety> <fld>(Zool.)</fld> <def>The
basking or liver shark; -- called also <altname>homer</altname>. See
<cref>Liver shark</cref>, under <er>Liver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoful</ent><br/
<hw>Ho"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>hogful</ets>,
<ets>hohful</ets>, fr. <ets>hogu</ets> care, anxiety.]</ety>
<def>Careful; wary.</def> <mark>[Obs.]</mark>
<rj><au>Stapleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hog</ent><br/
<hw>Hog</hw> <pr>(h<ocr/g)</pr>, <pos>n.</pos> <ety>[Prob. akin to E.
<ets>hack</ets> to cut, and meaning orig., a castrated boar; cf. also W.
<ets>hwch</ets> swine, sow, Armor. <ets>houc'h</ets>, <ets>hoc'h</ets>.
Cf. <er>Haggis</er>, <er>Hogget</er>, and <er>Hoggerel</er>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>A quadruped of the genus
<gen>Sus</gen>, and allied genera of <fam>Suid<ae/</fam>; esp., the
domesticated varieties of <spn>Sus scrofa</spn>, kept for their fat and
meat, called, respectively, <prod>lard</prod> and <prod>pork</prod>;
swine; porker; specifically, a castrated boar; a barrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The domestic hogs of Siam, China, and parts of Southern
Europe, are thought to have been derived from <spn>Sus
Indicus</spn>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mean, filthy, or gluttonous fellow.</def>
<mark>[Low.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A young sheep that has not been shorn.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>A rough, flat scrubbing broom for
scrubbing a ship's bottom under water.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Paper Manuf.)</fld> <def>A device for mixing and
stirring the pulp of which paper is made.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bush hog</b></col>, <col><b>Ground hog</b></col>,
etc.</mcol>. <cd>See under <er>Bush</er>, <er>Ground</er>, etc.</cd> --
<col><b>Hog caterpillar</b></col> <fld>(Zool.)</fld>, <cd>the larva of
the green grapevine sphinx; -- so called because the head and first
three segments are much smaller than those behind them, so as to make a
resemblance to a hog's snout. See <er>Hawk moth</er>.</cd> --
<col><b>Hog cholera</b></col>, <cd>an epidemic contagious fever of
swine, attended by liquid, fetid, diarrhea, and by the appearance on the
skin and mucous membrane of spots and patches of a scarlet, purple, or
black color. It is fatal in from one to six days, or ends in a slow,
uncertain recovery.</cd> <au>Law (Farmer's Veter. Adviser.)</au> --
<col><b>Hog deer</b></col> <fld>(Zool.)</fld>, <cd>the axis deer.</cd>
-- <col><b>Hog gum</b></col> <fld>(Bot.)</fld>, <cd>West Indian tree
(<spn>Symphonia globulifera</spn>), yielding an aromatic gum.</cd> --
<col><b>Hog of wool</b></col>, <cd>the trade name for the fleece or wool
of sheep of the second year.</cd> -- <col><b>Hog peanut</b></col>
<fld>(Bot.)</fld>, <cd>a kind of earth pea.</cd> -- <col><b>Hog
plum</b></col> <fld>(Bot.)</fld>, <cd>a tropical tree, of the genus
<gen>Spondias</gen> (<spn>Spondias lutea</spn>), with fruit somewhat
resembling plums, but chiefly eaten by hogs. It is found in the West
Indies.</cd> -- <col><b>Hog's bean</b></col> <fld>(Bot.)</fld>, <cd>the
plant henbane.</cd> -- <col><b>Hog's bread</b></col>.<fld>(Bot.)</fld>
<cd>See <er>Sow bread</er>.</cd> -- <col><b>Hog's fennel</b></col>.
<fld>(Bot.)</fld> <cd>See under <er>Fennel</er>.</cd> -- <col><b>Mexican
hog</b></col> <fld>(Zool.)</fld>, <cd>the peccary.</cd> -- <col><b>Water
hog</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Capybara</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hog</ent><br/
<hw>Hog</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hogged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hogging</conjf>.]</vmorph> <sn>1.</sn> <def>To cut short like
bristles; <as>as, to <ex>hog</ex> the mane of a horse</as>.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To scrub with a hog, or scrubbing
broom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hog</ent><br/
<hw>Hog</hw>, <pos>v. i.</pos> <fld>(Naut.)</fld> <def>To become bent
upward in the middle, like a hog's back; -- said of a ship broken or
strained so as to have this form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hogan</ent><br/
<hw>hogan</hw> <pos>n.</pos> <def>An earth-covered Navajo lodge; it is
traditionally built with the entrance facing east.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hogback</ent><br/
<hw>Hog"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Arch.)</fld> <def>An upward curve or very obtuse angle in the
upper surface of any member, as of a timber laid horizontally; -- the
opposite of <contr>camber</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>See <er>Hogframe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>A ridge formed by tilted strata;
hence, any ridge with a sharp summit, and steeply sloping
sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogchain</ent><br/
<hw>Hog"chain`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chain or tie rod,
in a boat or barge, to prevent the vessel from hogging.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogchoker</ent><br/
<hw>Hog"chok`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An American sole (<spn>Achirus lineatus</spn> syn. <spn>Achirus
achirus</spn>), related to the European sole, but of no market
value.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogcote</ent><br/
<hw>Hog"cote`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A shed for swine; a
sty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogfish</ent><br/
<hw>Hog"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A large West Indian and Florida food fish
(<gen>Lachnol<ae/mus</gen>).</def> <sd>(b)</sd> <def>The pigfish or
sailor's choice.</def> <sd>(c)</sd> <def>An American fresh-water fish;
the log perch.</def> <sd>(d)</sd> <def>A large, red, spiny-headed,
European marine fish (<spn>Scorp<ae/na scrofa</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogframe</ent><br/
<hw>Hog"frame`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Steam
Vessels)</fld> <def>A trussed frame extending fore and aft, usually
above deck, and intended to increase the longitudinal strength and
stiffness. Used chiefly in American river and lake steamers. Called also
<altname>hogging frame</altname>, and
<altname>hogback</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogged</ent><br/
<hw>Hogged</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Naut.)</fld>
<def>Broken or strained so as to have an upward curve between the ends.
See <er>Hog</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogger</ent><br/
<hw>Hog"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stocking without a
foot, worn by coal miners at work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoggerel</ent><br/
<hw>Hog"ger*el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the same
source as <ets>hog</ets>; prob. orig., a sheep clipped the first year.
See <er>Hog</er>.]</ety> <def>A sheep of the second year.
<altsp>[Written also <asp>hogrel</asp>.]</altsp>
<xex>Ash</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogger-pipe</ent><br/
<hw>Hog"ger-pipe`</hw> <pr>(h<ocr/g"g<etil/r-p<imac/p`)</pr>,
<pos>n.</pos> <fld>(Mining)</fld> <def>The upper terminal pipe of a
mining pump.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 698 --></p>

<p><ent>Hogger-pump</ent><br/
<hw>Hog"ger-pump"</hw> <pr>(h<ocr/g"g<etil/r-p<ucr/mp`)</pr>,
<pos>n.</pos> <fld>(Mining)</fld> <def>The top pump in the pit.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoggery</ent><br/
<hw>Hog"ger*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hoggish character or
manners; selfishness; greed; beastliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Crime and shame<br/
And all their <qex>hoggery</qex>.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogget</ent><br/
<hw>Hog"get</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See Hog, and
<er>Hoggerel</er>.]</ety> <sn>1.</sn> <def>A young boar of the second
year.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sheep or colt alter it has passed its first
year.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogging</ent><br/
<hw>Hog"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>Drooping at the ends; arching;-in distinction from
<xex>sagging</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hogging frame</b></col>. <cd>See
<er>Hogframe</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoggish</ent><br/
<hw>Hog"gish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Swinish; gluttonous;
filthy; selfish.</def> -- <wordforms><wf>Hog"gish*ly</wf>,
<pos>adv.</pos> -- <wf>Hog"gish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Is not a <qex>hoggish</qex> life the height of some men's
wishes?</q> <rj><qau>Shaftesbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogh</ent><br/
<hw>Hogh</hw> <pr>(h<omac/)</pr>, <pos>n.</pos> <ety>[Icel.
<ets>haugr</ets> hill, mound; akin to E. <ets>high</ets>. See
<er>High</er>.]</ety> <def>A hill; a cliff.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogherd</ent><br/
<hw>Hog"herd</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A swineherd.</def>
<rj><au>W. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogmanay</ent><br/
<hw>Hog`ma*nay"</hw> <pr>(<?/)</pr>, <pos>n.</pos> <def>The old name, in
Scotland, for the last day of the year, on which children go about
singing, and receive a dole of bread or cakes; also, the entertainment
given on that day to a visitor, or the gift given to an applicant.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hognosesnake</ent><br/
<hw>Hog"nose`snake"</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>A
harmless North American snake of the genus <gen>Heterodon</gen>, esp.
<spn>Heterodon platyrhynos</spn>; -- called also <altname>puffing
adder</altname>, <altname>blowing adder</altname>, and <altname>sand
viper</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hognut</ent><br/
<hw>Hog"nut`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The pignut.</def> See <er>Hickory</er>. <sd>(b)</sd>
<def>In England, the <spn>Bunium flexuosum</spn>, a tuberous
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogo</ent><br/
<hw>Ho"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted from F.
<ets>haut go<ucir/t</ets>.]</ety> <def>High flavor; strong scent.</def>
<mark>[Obs.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogpen</ent><br/
<hw>Hog"pen`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pen or sty for
hogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogreeve</ent><br/
<hw>Hog"reeve`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Reeve</er>.]</ety> <def>A civil officer charged with the duty of
impounding hogs running at large.</def> <mark>[New Eng.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogringer</ent><br/
<hw>Hog"ring`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who puts rings
into the snouts of hogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hog's-back</ent><br/
<hw>Hog's"-back`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Geol.)</fld>
<def>A hogback.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogscore</ent><br/
<hw>Hog"score`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Curling)</fld> <def>A distance line drawn across
the rink or course between the middle line and the tee.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogshead</ent><br/
<hw>Hogs"head</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>okshoofd</ets>; akin to Sw. <ets>oxhufvud</ets>, Dan.
<ets>oxehoved</ets>, G. <ets>oxhoft</ets>; apparently meaning orig., ox
head, but it is not known why this name was given. Cf. <er>Ox</er>,
<er>Head</er>.]</ety> <sn>1.</sn> <def>An English measure of capacity,
containing 63 wine gallons, or about 52<frac12/ imperial gallons; a half
pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The London hogshead of beer was 54 beer gallons, the
London hogshead of ale was 48 ale gallons. Elsewhere in England the ale
and beer hogsheads held 51 gallons. These measures are no longer in use,
except for cider.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A large cask or barrel, of indefinite contents; esp.
one containing from 100 to 140 gallons.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogskin</ent><br/
<hw>Hog"skin`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Leather tanned from
a hog's skin. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogsty</ent><br/
<hw>Hog"sty`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hogsties</plw> <pr>(<?/)</pr>.</plu> <def>A pen, house, or
inclosure, for hogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hogwash</ent><br/
<hw>Hog"wash`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Swill.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Meaningless talk; nonsense; balderdash; bunk; --
also used as an interjection, expressing scornful disbelief.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hogweed</ent><br/
<hw>Hog"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A common weed (<spn>Ambrosia artemisi<ae/ge</spn>).
See <er>Ambrosia</er>, 3.</def> <sd>(b)</sd> <def>In England, the
<spn>Heracleum Sphondylium</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoiden</ent><br/
<hw>Hoi"den</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hoydon</ets>
a lout, rustic, OD. <ets>heyden</ets> a heathen, gypsy, vagabond, D.
<ets>heiden</ets>, fr. OD. <ets>heyde</ets> heath, D. <ets>heide</ets>.
See <er>Heathen</er>, <er>Heath</er>.]</ety> <altsp>[Written also
<asp>hoyden</asp>.]</altsp> <sn>1.</sn> <def>A rude, clownish
youth.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rude, bold girl; a romp.</def> <rj><au>H.
Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoiden</ent><br/
<hw>Hoi"den</hw>, <pos>a.</pos> <def>Rustic; rude; bold.</def>
<rj><au>Younq.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoiden</ent><br/
<hw>Hoi"den</hw>, <pos>v. i.</pos> <def>To romp rudely or
indecently.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoidenhood</ent><br/
<hw>Hoi"den*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being a
hoiden.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoidenish</ent><br/
<hw>Hoi"den*ish</hw>, <pos>a.</pos> <def>Like, or appropriate to, a
hoiden.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoise</ent><br/
<hw>Hoise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Hoist</er>.]</ety> <def>To hoist.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . <qex>hoised</qex> up the mainsail to the wind.</q>
<rj><qau>Acts xxvii. 40.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoist</ent><br/
<hw>Hoist</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hoisted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hoisting</conjf>.]</vmorph> <ety>[OE. <ets>hoise</ets>,
<ets>hyse</ets>, OD. <ets>hyssen</ets>, D. <ets>hijshen</ets>; akin to
LG. <ets>hissen</ets>, Dan. <ets>hisse</ets>, Sw.
<ets>hissa</ets>.]</ety> <def>To raise; to lift; to elevate; esp., to
raise or lift to a desired elevation, by means of tackle, as a sail, a
flag, a heavy package or weight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They land my goods, and <qex>hoist</qex> my flying sails.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hoisting</qex> him into his father's throne.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hoisting engine</b></col>, <cd>a steam engine for
operating a hoist.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoist</ent><br/
<hw>Hoist</hw>, <pos>n.</pos> <sn>1.</sn> <def>That by which anything is
hoisted; the apparatus for lifting goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of hoisting; a lift.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The perpendicular
height of a flag, as opposed to the <xex>fly</xex>, or horizontal length
when flying from a staff.</def> <sd>(b)</sd> <def>The height of a
fore-and-aft sail next the mast or stay.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hoist bridge</b></col>, <cd>a drawbridge that is lifted
instead of being swung or drawn aside.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoist</ent><br/
<hw>Hoist</hw>, <pos>p. p.</pos> <def>Hoisted.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is the sport to have the enginer<br/
<qex>Hoist</qex> with his own petar.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoistaway</ent><br/
<hw>Hoist"a*way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mechanical
lift. See <er>Elevator</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoistway</ent><br/
<hw>Hoist"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An opening for the
hoist, or elevator, in the floor of a wareroom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoit</ent><br/
<hw>Hoit</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Gf. W.
<ets>hoetian</ets> to dally, dandle.]</ety> <def>To leap; to caper; to
romp noisily.</def> <mark>[Obs.]</mark> <au>Beau. & Fl.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoity-toity</ent><br/
<hw>Hoi"ty-toi`ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Hoit</er>.]</ety> <def>Thoughtless; giddy; flighty; also, haughty;
patronizing; <as>as, to be in <ex>hoity-toity</ex> spirits, or to assume
<ex>hoity-toity</ex> airs</as>; used also as an exclamation, denoting
surprise or disapprobation, with some degree of contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hoity-toity</qex>! What have I to do with dreams?</q>
<rj><qau>Congreve.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hokeday</ent><br/
<hw>Hoke"day`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hockday</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoker</ent><br/
<hw>Ho"ker</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<omac/cor</ets>.]</ety> <def>Scorn; derision; abusive talk.</def>
<mark>[Obs.]</mark> -- <wordforms><wf>Ho"ker*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hokkaido</ent><br/
<hw>Hok*kai"do</hw> <pr>(h<ocr/k*k<imac/"d<omac/)</pr>, <pos>prop.
n.</pos> <ety>[Jap.]</ety> <def>The northernmost of the main islands of
Japan. Together with the islands of Honshu, Kyushu and Shikoku it forms
the bulk of the land area of Japan.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hol</ent><br/
<hw>Hol</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Whole</er>.]</ety> <def>Whole.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holarctic</ent><br/
<hw>Hol"arc*tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Holo-</ets>
+ <ets>arctic</ets>.]</ety> <def>Of or pert. to the arctic regions
collectively</def>; specif. <fld>(Zo<oum/geography)</fld>,
<def>designating a realm or region including the northern parts of the
Old and the New World. It comprises the <part>Palearctic</part> and
<part>Nearctic</part> regions or subregions.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Holaspidean</ent><br/
<hw>Hol`as*pid"e*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo-</ets> + Gr.<?/, <?/, shield.]</ety> <fld>(Zool.)</fld>
<def>Having a single series of large scutes on the posterior side of the
tarsus; -- said of certain birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holcad</ent><br/
<hw>Hol"cad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>'olka`s</grk>, <grk>-a`dos</grk>, a ship which is towed, a ship of
burden, fr. <grk>'e`lkein</grk> to draw. Gf. <er>Hulk</er>.]</ety>
<def>A large ship of burden, in ancient Greece.</def>
<rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hold</ent><br/
<hw>Hold</hw> <pr>(h<omac/ld)</pr>, <pos>n.</pos> <ety>[D.
<ets>hol</ets> hole, hollow. See <er>Hole</er>.]</ety>
<fld>(Naut.)</fld> <def>The whole interior portion of a vessel below the
lower deck, in which the cargo is stowed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hold</ent><br/
<hw>Hold</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Held</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Holding</conjf>. <conjf>Holden</conjf> <pr>(<?/)</pr>, <pos>p.
p.</pos>, is obs. in elegant writing, though still used in legal
language.]</vmorph> <ety>[OE. <ets>haldan</ets>, D. <ets>houden</ets>,
OHG. <ets>hoten</ets>, Icel. <ets>halda</ets>, Dan. <ets>holde</ets>,
Sw. <ets>h<aring/lla</ets>, <ets>Goth</ets>. <ets>haldan</ets> to feed,
tend (the cattle); of unknown origin. Gf. <er>Avast</er>, <er>Halt</er>,
<er>Hod</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To cause to remain in a given situation, position,
or relation, within certain limits, or the like; to prevent from falling
or escaping; to sustain; to restrain; to keep in the grasp; to
retain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The loops <qex>held</qex> one curtain to another.</q> <rj><qau>Ex.
xxxvi. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy right hand shall <qex>hold</qex> me.</q> <rj><qau>Ps. cxxxix.
10. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They all <qex>hold</qex> swords, being expert in war.</q>
<rj><qau>Cant. iii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In vain he seeks, that having can not <qex>hold</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>France, thou mayst <qex>hold</qex> a serpent by the tongue, . . .
<br/
A fasting tiger safer by the tooth,<br/
Than keep in peace that hand which thou dost <qex>hold</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To retain in one's keeping; to maintain possession
of, or authority over; not to give up or relinquish; to keep; to
defend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We mean to <qex>hold</qex> what anciently we claim<br/
Of deity or empire.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To have; to possess; to be in possession of; to
occupy; to derive title to; <as>as, to <ex>hold</ex>
office</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This noble merchant <qex>held</qex> a noble house.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of him to <qex>hold</qex> his seigniory for a yearly tribute.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And now the strand, and now the plain, they <qex>held</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To impose restraint upon; to limit in motion or
action; to bind legally or morally; to confine; to restrain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We can not <qex>hold</qex> mortality's strong hand.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Death! what do'st? O, <qex>hold</qex> thy blow.</q>
<rj><qau>Grashaw.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He had not sufficient judgment and self-command to <qex>hold</qex>
his tongue.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To maintain in being or action; to carry on; to
prosecute, as a course of conduct or an argument; to continue; to
sustain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hold</qex> not thy peace, and be not still.</q> <rj><qau>Ps.
lxxxiii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Seedtime and harvest, heat and hoary frost,<br/
Shall <qex>hold</qex> their course.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To prosecute, have, take, or join in, as something
which is the result of united action; as to, <xex>hold</xex> a meeting,
a festival, a session, etc.; hence, to direct and bring about
officially; to conduct or preside at; <as>as, the general <ex>held</ex>
a council of war; a judge <ex>holds</ex> a court; a clergyman
<ex>holds</ex> a service.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would <qex>hold</qex> more talk with thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To receive and retain; to contain as a vessel;
<as>as, this pail <ex>holds</ex> milk</as>; hence, to be able to receive
and retain; to have capacity or containing power for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Broken cisterns that can <qex>hold</qex> no water.</q>
<rj><qau>Jer. ii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One sees more devils than vast hell can <qex>hold</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To accept, as an opinion; to be the adherent of,
openly or privately; to persist in, as a purpose; to maintain; to
sustain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stand fast and <qex>hold</qex> the traditions which ye have been
taught.</q> <rj><qau>2 Thes. ii.15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But still he <qex>held</qex> his purpose to depart.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To consider; to regard; to esteem; to account; to
think; to judge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>hold</qex> him but a fool.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall never <qex>hold</qex> that man my friend.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord will not <qex>hold</qex> him guiltless that taketh his
name in vain.</q> <rj><qau>Ex. xx. 7. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To bear, carry, or manage; <as>as he <ex>holds</ex>
himself erect; he <ex>holds</ex> his head high.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him <qex>hold</qex> his fingers thus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To hold a wager</b></col>, <cd>to lay or hazard a
wager.</cd> <au>Swift.</au> -- <col><b>To hold forth</b></col>,
<sd>(a)</sd> <pos>v. t.</pos><cd>to offer; to exhibit; to propose; to
put forward.</cd> <ldquo/The propositions which books <xex>hold
forth</xex> and pretend to teach.<rdquo/ <au>Locke.</au> <sd>(b)</sd>
<pos>v. i.</pos> <cd>To talk at length; to harangue.</cd> -- <col><b>To
held in</b></col>, <cd>to restrain; to curd.</cd> -- <col><b>To hold in
hand</b></col>, <cd>to toy with; to keep in expectation; to have in
one's power.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>O, fie! to receive favors, return falsehoods,<br/
And <qex>hold</qex> a lady in <qex>hand</qex>.</q> <rj><qau>Beaw. &
Fl.</qau></rj></p>

<p>-- <col><b>To hold in play</b></col>, <cd>to keep under control; to
dally with.</cd> <au>Macaulay.</au> -- <col><b>To hold off</b></col>,
<cd>to keep at a distance.</cd> -- <col><b>To hold on</b></col>, <cd>to
hold in being, continuance or position; as, <xex>to hold</xex> a rider
<xex>on</xex>.</cd> -- <col><b>To hold one's day</b></col>, <cd>to keep
one's appointment.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au> --
<col><b>To hold one's own</b></col>. <cd>To keep good one's present
condition absolutely or relatively; not to fall off, or to lose ground;
as, a ship <xex>holds her own</xex> when she does not lose ground in a
race or chase; a man <xex>holds his own</xex> when he does not lose
strength or weight.</cd> -- <col><b>To hold one's peace</b></col>,
<cd>to keep silence.</cd>- <col><b>To hold out</b></col>. <sd>(a)</sd>
<cd>To extend; to offer.</cd> <ldquo/Fortune <xex>holds out</xex> these
to you as rewards.<rdquo/ <au>B. Jonson.</au> <sd>(b)</sd> <cd>To
continue to do or to suffer; to endure.</cd> <ldquo/He can not long
<xex>hold out</xex> these pangs.<rdquo/ <au>Shak.</au> -- <col><b>To
hold up</b></col>. <sd>(a)</sd> <cd>To raise; to lift; as, <xex>hold
up</xex> your head.</cd> <sd>(b)</sd> <cd>To support; to sustain.</cd>
<ldquo/He <xex>holds</xex> himself <xex>up</xex> in
virtue.<rdquo/<au>Sir P. Sidney.</au> <sd>(c)</sd> <cd>To exhibit; to
display; as, he was <xex>held up</xex> as an example.</cd> <sd>(d)</sd>
<cd>To rein in; to check; to halt; as, <xex>hold up</xex> your
horses.</cd> <sd>(e)</sd> <cd>to rob, usually at gunpoint; -- often with
the demand to <ldquo/hold up<rdquo/ the hands.</cd> <sd>(f)</sd> <cd>To
delay.</cd> -- <col><b>To hold water</b></col>. <sd>(a)</sd>
<cd>Literally, to retain water without leaking; hence
(<mark>Fig</mark>.), to be whole, sound, consistent, without gaps or
holes; -- commonly used in a negative sense; as, his statements will not
<xex>hold water</xex>.</cd> <mark>[Colloq.]</mark> <sd>(b)</sd>
<fld>(Naut.)</fld> <cd>To hold the oars steady in the water, thus
checking the headway of a boat.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Hold</ent><br/
<hw>Hold</hw>, <pos>v. i.</pos> <def>In general, to keep one's self in a
given position or condition; to remain fixed. Hence:</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Not to move; to halt; to stop; -- mostly in the
imperative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And damned be him that first cries, <ldquo/<qex>Hold</qex>,
enough!<rdquo/</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not to give way; not to part or become separated; to
remain unbroken or unsubdued.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our force by land hath nobly <qex>held</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not to fail or be found wanting; to continue; to
last; to endure a test or trial; to abide; to persist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While our obedience <qex>holds</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rule <qex>holds</qex> in land as all other commodities.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not to fall away, desert, or prove recreant; to
remain attached; to cleave; -- often with <xex>with</xex>,
<xex>to</xex>, or <xex>for</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He will <qex>hold</qex> to the one and despise the other.</q>
<rj><qau>Matt. vi. 24</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To restrain one's self; to refrain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His dauntless heart would fain have <qex>held</qex><br/
From weeping, but his eyes rebelled.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To derive right or title; -- generally with
<xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My crown is absolute, and <qex>holds</qex> of none.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His imagination <qex>holds</qex> immediately from nature.</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hold on!</b></col> <col><b>Hold up!</b></col>
<cd>wait; stop; forbear.</cd> <mark>[Collog]</mark> -- <col><b>To hold
forth</b></col></mcol>, <cd>to speak in public; to harangue; to
preach.</cd> <au>L'Estrange.</au> -- <col><b>To hold in</b></col>,
<cd>to restrain one's self; as, he wanted to laugh and could hardly
<xex>hold in</xex>.</cd> -- <col><b>To hold off</b></col>, <cd>to keep
at a distance.</cd> -- <col><b>To hold on</b></col>, <cd>to keep fast
hold; to continue; to go on.</cd> <ldquo/The trade <xex>held on</xex>
for many years,<rdquo/ <au>Swift.</au> -- <col><b>To hold out</b></col>,
<cd>to last; to endure; to continue; to maintain one's self; not to
yield or give way.</cd> -- <col><b>To hold over</b></col>, <cd>to remain
in office, possession, etc., beyond a certain date.</cd> --
<mcol><col><b>To hold to</b></col> <it>or</it> <col><b>To hold
with</b></col></mcol>, <cd>to take sides with, as a person or
opinion.</cd> -- <col><b>To hold together</b></col>, <cd>to be joined;
not to separate; to remain in union.</cd> <au>Dryden.</au>
<au>Locke.</au> -- <col><b>To hold up</b></col>. <sd>(a)</sd> <cd>To
support one's self; to remain unbent or unbroken; as, to <xex>hold
up</xex> under misfortunes.</cd> <sd>(b)</sd> <cd>To cease raining; to
cease to stop; as, it <xex>holds up</xex>.</cd> <au>Hudibras.</au>
<sd>(c)</sd> <cd>To keep up; not to fall behind; not to lose
ground.</cd> <au>Collier.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hold</ent><br/
<hw>Hold</hw> <pr>(h<omac/ld)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of holding, as in or with the hands or arms; the manner of holding,
whether firm or loose; seizure; grasp; clasp; grip; possession; -- often
used with the verbs <xex>take</xex> and <xex>lay</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ne have I not twelve pence within mine <qex>hold</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou should'st lay <qex>hold</qex> upon him.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My soul took <qex>hold</qex> on thee.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Take fast <qex>hold</qex> of instruction.</q> <rj><qau>Pror. iv.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The authority or ground to take or keep;
claim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The law hath yet another <qex>hold</qex> on you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Binding power and influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fear . . . by which God and his laws take the surest <qex>hold
of</qex>.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Something that may be grasped; means of
support.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a man be upon an high place without rails or good
<qex>hold</qex>, he is ready to fall.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A place of confinement; a prison; confinement;
custody; guard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . put them in <qex>hold</qex> unto the next day.</q>
<rj><qau>Acts. iv. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>King Richard, he is in the mighty <qex>hold</qex><br/
Of Bolingbroke.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A place of security; a fortified place; a fort; a
castle; -- often called a <altname>stronghold</altname>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>New comers in an ancient <qex>hold</qex></q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mus.)</fld> <def>A character [thus <?/] placed over
or under a note or rest, and indicating that it is to be prolonged; --
called also <altname>pause</altname>, and
<altname>corona</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>holdall</ent><br/
<hw>hold"all`</hw> <pr>(h<omac/ld"<add/l`)</pr>, <pos>n.</pos> <def>a
capacious bag or basket.</def><br/
<syn><b>Syn. --</b> carryall, tote, tote bag.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holdback</ent><br/
<hw>Hold"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Check;
hindrance; restraint; obstacle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The only <qex>holdback</qex> is the affection . . . that we bear
to our wealth.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The projection or loop on the thill of a vehicle. to
which a strap of the harness is attached, to hold back a carriage when
going down hill, or in backing; also, the strap or part of the harness
so used.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holder</ent><br/
<hw>Hold"er</hw>, <pr>(<?/)</pr> <pos>n.</pos> <def>One who is employed
in the hold of a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holder</ent><br/
<hw>Hold"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who, or that which,
holds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who holds land, etc., under another; a
tenant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>The payee of a bill of exchange or
a promissory note, or the one who owns or holds it.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Holder</xex> is much used as the second part of a
compound; as, share<xex>holder</xex>, office<xex>holder</xex>,
stock<xex>holder</xex>,etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holder-forth</ent><br/
<hw>Hold"er-forth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who speaks
in public; an haranguer; a preacher. See <cref>hold forth</cref>
<sd>(b)</sd> under <er>hold</er>.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holdfast</ent><br/
<hw>Hold"fast`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Something used to secure and hold in place something else, as a
long flat-headed nail, a catch a hook, a clinch, a clamp, etc.; hence, a
support.</def> <ldquo/His <xex>holdfast</xex> was gone.<rdquo/
<rj><au>Bp. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A conical or branching body, by
which a seaweed is attached to its support, and differing from a root in
that it is not specially absorbent of moisture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holding</ent><br/
<hw>Hold"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or state of
sustaining, grasping, or retaining.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tenure; a farm or other estate held of
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which holds, binds, or influences.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The burden or chorus of a song.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Holding note</b></col> <fld>(Mus.)</fld>, <cd>a note
sustained in one part, while the other parts move.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>holding company</ent><br/
<hw>holding company</hw> <pos>n.</pos> <fld>(Finance)</fld> <def>A
company that controls other independently incorporated companies by
ownership of most or all of their stock, but does not directly control
the daily operations of those companies.</def><br/
[<source>PJC</source>]</p>

<p><ent>holdout</ent><br/
<hw>holdout</hw> <pos>n.</pos> <sn>1.</sn> <def>a negotiator who hopes
to gain concessions by refusing to come to terms after most other
participants have signed an agreement; <as>as, their star pitcher was a
<ex>holdout</ex> for six weeks</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a refusal by a negotiator to come to terms in the
hope of obtaining a better deal.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>the act of hiding playing cards in a gambling game
so they are available for personal use later.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>holdover</ent><br/
<hw>holdover</hw> <pos>n.</pos> <def>Any person or thing remaining from
a previous period of use, tenure, etc;</def>
<specif>Specifically:</specif> <def>an official who remains in office
after his term.</def><br/
<syn><b>Syn. --</b> hangover.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holdup</ent><br/
<hw>Hold"up</hw> <pr>(h<omac/ld"<ucr/p`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>a robbery, usually at gunpoint.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a delay.</def> <ldquo/What's the
<xex>holdup</xex>?<rdquo/<br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def><er>highway robbery</er>{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hold up</ent><br/
<hw>Hold up</hw> <pr>(h<omac/ld <ucr/p")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To rob, usually at gunpoint or knifepoint.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To delay; <as>as, bad weather <ex>held up</ex> the
satellite launch for two days</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hole</ent><br/
<hw>Hole</hw> <pr>(h<omac/l)</pr>, <pos>a.</pos> <def>Whole.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hole</ent><br/
<hw>Hole</hw> <pr>(h<omac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hol</ets>, <ets>hole</ets>, AS. <ets>hol</ets>, hole, cavern, from
<ets>hol</ets>, a., <ets>hollow</ets>; akin to D. <ets>hol</ets>, OHG.
<ets>hol</ets>, G. <ets>hohl</ets>, Dan. <ets>huul</ets> hollow,
<ets>hul</ets> hole, Sw. <ets>h<aring/l</ets>, Icel. <ets>hola</ets>;
prob. from the root of AS. <ets>helan</ets> to conceal. See
<er>Hele</er>, <er>Hell</er>, and cf. <er>Hold</er> of a ship.]</ety>
<sn>1.</sn> <def>A hollow place or cavity; an excavation; a pit; an
opening in or through a solid body, a fabric, etc.; a perforation; a
rent; a fissure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>holes</qex> where eyes should be.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The blind walls<br/
Were full of chinks and <qex>holes</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The priest took a chest, and bored a <qex>hole</qex> in the
lid.</q> <rj><qau>2 Kings xii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An excavation in the ground, made by an animal to
live in, or a natural cavity inhabited by an animal; hence, a low,
narrow, or dark lodging or place; a mean habitation.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The foxes have <qex>holes</qex>, . . . but the Son of man hath not
where to lay his head.</q> <rj><qau>Luke ix. 58.</qau></rj></p>

<p><sn>3.</sn> <fld>(Games)</fld> <sd>(a)</sd> <def>A small cavity used
in some games, usually one into which a marble or ball is to be played
or driven; hence, a score made by playing a marble or ball into such a
hole, as in golf.</def> <sd>(b)</sd> <fld>(Fives)</fld> <def>At Eton
College, England, that part of the floor of the court between the step
and the pepperbox.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><syn><b>Syn.</b> -- Hollow; concavity; aperture; rent; fissure;
crevice; orifice; interstice; perforation; excavation; pit; cave; den;
cell.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hole and corner</b></col>, <cd>clandestine,
underhand.</cd> <mark>[Colloq.]</mark> <ldquo/The wretched trickery of
<xex>hole</xex> and <xex>corner</xex> buffery.<rdquo/ <au>Dickens.</au>
-- <col><b>Hole board</b></col> <fld>(Fancy Weaving)</fld>, <cd>a board
having holes through which cords pass which lift certain warp threads;
-- called also <altname>compass board</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 699 --></p>

<p><ent>Hole</ent><br/
<hw>Hole</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>holian</ets>. See <er>Hole</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>To cut, dig, or bore a hole or holes in; <as>as, to <ex>hole</ex> a
post for the insertion of rails or bars</as>.</def>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drive into a hole, as an animal, or a billiard
ball.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hole</ent><br/
<hw>Hole</hw>, <pos>v. i.</pos> <def>To go or get into a hole.</def>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hole in the air</ent><br/
<hw>Hole in the air</hw>. <fld>(A<eum/ronautics)</fld> <def>same as
<er>Air hole</er>, above; an <er>air pocket</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Holethnic</ent><br/
<hw>Hol*eth"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a holethnos or parent race.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>holethnic</qex> history of the Arians.</q>
<rj><qau>London Academy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holethnos</ent><br/
<hw>Hol*eth"nos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Holo</ets> +
Gr. <?/ race.]</ety> <def>A parent stock or race of people, not yet
divided into separate branches or tribes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>holey</ent><br/
<hw>holey</hw> <pos>adj.</pos> <def>having pores or holes.</def><br/
<syn><b>Syn. --</b> porous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holibut</ent><br/
<hw>Hol"i*but</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Halibut</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holidam</ent><br/
<hw>Hol"i*dam</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Halidom</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holiday</ent><br/
<hw>Hol"i*day</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Holy</ets> +
<ets>day</ets>.]</ety> <sn>1.</sn> <def>A consecrated day; religious
anniversary; a day set apart in honor of some person, or in
commemoration of some event. See <er>Holyday</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A day of exemption from labor; a day of amusement
and gayety; a festival day.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And young and old come forth to play<br/
On a sunshine <qex>holiday</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A day fixed by law for suspension
of business; a legal holiday.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the United States <xex>legal holidays</xex>, so
called, are determined by law, commonly by the statutes of the several
States. The holidays most generally observed are: the 22d day of
February (Washington's birthday), the 30th day of May (Memorial day),
the 4th day of July (Independence day), the 25th day of December
(Christmas day). In most of the States the 1st day of January is a
holiday. When any of these days falls on Sunday, usually the Monday
following is observed as the holiday. In many of the States a day in the
spring (as Good Friday, or the first Thursday in April), and a day in
the fall (as the last Thursday in November) are now regularly appointed
by Executive proclamation to be observed, the former as a day of fasting
and prayer, the latter as a day of thanksgiving and are kept as
holidays. In England, the days of the greater church feasts (designated
in the calendar by a red letter, and commonly called <xex>red-letter
days</xex>) are observed as general holidays. <xex>Bank holidays</xex>
are those on which, by act of Parliament, banks may suspend business.
Although Sunday is a holiday in the sense of a day when business is
legally suspended, it is not usually included in the general term, the
phrase <ldquo/Sundays and holidays<rdquo/ being more common.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The holidays</b></col>, <cd>any fixed or usual period for
relaxation or festivity; especially, Christmas and New Year's day with
the intervening time.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holiday</ent><br/
<hw>Hol`i*day</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to a
festival; cheerful; joyous; gay.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occurring rarely; adapted for a special
occasion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Courage is but a <qex>holiday</qex> kind of virtue, to be seldom
exercised.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>holier-than-thou</ent><br/
<hw>holier-than-thou</hw> <pos>adj.</pos> <def>being excessively or
hypocritically pious while condemning others as being less virtuous than
oneself.</def><br/
<syn><b>Syn. --</b> pietistic, pietistical, pharisaic, pharisaical,
sanctimonious, self-righteous.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Holily</ent><br/
<hw>Ho"li*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Holy</er>.]</ety> <sn>1.</sn> <def>Piously; with sanctity; in a holy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sacredly; inviolably.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holiness</ent><br/
<hw>Ho"li*ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>h<amac/lignes</ets>.]</ety> <sn>1.</sn> <def>The state or quality
of being holy; perfect moral integrity or purity; freedom from sin;
sanctity; innocence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who is like thee, glorious in <qex>holiness</qex>!</q>
<rj><qau>Ex. xv. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being hallowed, or consecrated to God
or to his worship; sacredness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Israel was <qex>holiness</qex> unto the Lord.</q>
<rj><qau>Jer.ii.3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>His holiness</b></col>, <cd>a title of the pope; --
formerly given also to Greek bishops and Greek emperors.</cd></cs></p>

<p><syn><b>Syn.</b> -- Piety; devotion; godliness; sanctity; sacredness;
righteousness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holing</ent><br/
<hw>Hol"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Hole</er> a
hollow.]</ety> <fld>(Mining)</fld> <def>Undercutting in a bed of coal,
in order to bring down the upper mass.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holla</ent><br/
<hw>Hol"la</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[F.
<ets>hola</ets>; <ets>ho</ets> ho + <ets>l<agrave/</ets> there, fr. L.
<ets>illac</ets> that way, there. Cf. <er>Hollo</er>.]</ety>
<def>Hollo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holla</ent><br/
<hw>Hol"la</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hollaed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hollaing</conjf>.]</vmorph> <def>See <er>Hollo</er>, <pos>v.
i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holland</ent><br/
<hw>Hol"land</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of linen first
manufactured in Holland; a linen fabric used for window shades,
children's garments, etc.; <as>as, brown or unbleached
<ex>hollands</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollandaise</ent><br/
<ent>Hollandaise sauce</ent><br/
<mhw>{ <hw>Hol`lan*daise" sauce</hw>, <it>or</it>
<hw>Hol`lan*daise"</hw> }</mhw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hollandaise</ets>, fem. of <ets>hollandais</ets> Dutch.]</ety>
<fld>(Cookery)</fld> <def>A sauce consisting essentially of a seasoned
emulsion of butter and yolk of eggs with a little lemon juice or
vinegar.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hollander</ent><br/
<hw>Hol"land*er</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <sn>1.</sn>
<def>A native or one of the people of Holland; a Dutchman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A very hard, semi-glazed, green or dark brown brick,
which will not absorb water; -- called also, <altname>Dutch
clinker</altname>.</def> <rj><au>Wagner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollandish</ent><br/
<hw>Hol"land*ish</hw>, <pos>a.</pos> <def>Relating to Holland;
Dutch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollands</ent><br/
<hw>Hol"lands</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Gin made
in Holland.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>See <er>Holland</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollo</ent><br/
<hw>Hol*lo"</hw> <pr>(?)</pr>, <pos>interj. & n.</pos> <ety>[See
<er>Halloo</er>, and cf. <er>Holla</er>.]</ety> <def>Ho there; stop;
attend; hence, a loud cry or a call to attract attention; a
halloo.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And every day, for food or play,<br/
Came to the mariner's <qex>hollo</qex>.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollo</ent><br/
<hw>Hol"lo</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Holloed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Holloing</conjf>.]</vmorph> <ety>[See <er>Hollo</er>,
<ets>interj</ets>., and cf. <er>Halloo</er>.]</ety> <def>To call out or
exclaim; to halloo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holloa</ent><br/
<hw>Hol*loa"</hw> <pr>(?)</pr>, <pos>interj.</pos>, <pos>n. & v.
i.</pos> <def>Same as <er>Hollo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol"low</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>holow</ets>,
<ets>holgh</ets>, <ets>holf</ets>, AS. <ets>holh</ets> a hollow, hole.
Cf. <er>Hole</er>.]</ety> <sn>1.</sn> <def>Having an empty space or
cavity, natural or artificial, within a solid substance; not solid;
excavated in the interior; <as>as, a <ex>hollow</ex> tree; a
<ex>hollow</ex> sphere.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hollow</qex> with boards shalt thou make it.</q> <rj><qau>Ex.
xxvii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Depressed; concave; gaunt; sunken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>hollow</qex> eye and wrinkled brow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Reverberated from a cavity, or resembling such a
sound; deep; muffled; <as>as, a <ex>hollow</ex> roar</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not sincere or faithful; false; deceitful; not
sound; <as>as, a <ex>hollow</ex> heart; a <ex>hollow</ex>
friend.</as></def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hollow newel</b></col> <fld>(Arch.)</fld>, <cd>an opening
in the center of a winding staircase in place of a newel post, the
stairs being supported by the wall; an open newel; also, the stringpiece
or rail winding around the well of such a staircase.</cd> --
<col><b>Hollow quoin</b></col> <fld>(Engin.)</fld>, <cd>a pier of stone
or brick made behind the lock gates of a canal, and containing a hollow
or recess to receive the ends of the gates.</cd> -- <col><b>Hollow
root</b></col>. <fld>(Bot.)</fld> <cd>See <er>Moschatel</er>.</cd> --
<col><b>Hollow square</b></col>. <cd>See <er>Square</er>.</cd> --
<col><b>Hollow ware</b></col>, <cd>hollow vessels; -- a trade name for
cast-iron kitchen utensils, earthenware, etc.</cd></cs></p>

<p><syn><b>Syn.</b>- Concave; sunken; low; vacant; empty; void; false;
faithless; deceitful; treacherous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol"low</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A cavity,
natural or artificial; an unfilled space within anything; a hole, a
cavern; an excavation; as the <xex>hollow</xex> of the hand or of a
tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A low spot surrounded by elevations; a depressed
part of a surface; a concavity; a channel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Forests grew<br/
Upon the barren <qex>hollows</qex>.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I hate the dreadful <qex>hollow</qex> behind the little wood.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol"low</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hollowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hollowing</conjf>.]</vmorph> <def>To make hollow, as by digging,
cutting, or engraving; to excavate.</def> <ldquo/Trees rudely
<xex>hollowed</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol"low</hw>, <pos>adv.</pos> <def>Wholly; completely; utterly; --
chiefly after the verb <xex>to beat</xex>, and often with
<xex>all</xex>; <as>as, this story beats the other all
<ex>hollow</ex></as>. See <er>All</er>, <pos>adv.</pos></def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The more civilized so-called Caucasian races have beaten the Turks
<qex>hollow</qex> in the struggle for existence.</q>
<rj><qau>Darwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol*low"</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[See
<er>Hollo</er>.]</ety> <def>Hollo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol"low</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To shout; to
hollo.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whisperings and <qex>hollowings</qex> are alike to a deaf ear.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow</ent><br/
<hw>Hol"low</hw>, <pos>v. t.</pos> <def>To urge or call by
shouting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has <qex>hollowed</qex> the hounds.</q> <rj><qau>Sir W. Scott.
</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hollowed</ent><br/
<hw>hollowed</hw> <pos>adj.</pos> <def>having a cavity within; <as>as,
canoe made of a <ex>hollowed</ex> log</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hollow-hearted</ent><br/
<hw>Hol"low-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Insincere;
deceitful; not sound and true; having a cavity or decayed spot
within.</def></p>

<p><syn><b>Syn.</b> -- Faithless; dishonest; false;
treacherous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollow-horned</ent><br/
<hw>Hol"low-horned`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having permanent horns with a bony core, as cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollowly</ent><br/
<hw>Hol"low*ly</hw>, <pos>adv.</pos> <def>Insincerely;
deceitfully.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hollowness</ent><br/
<hw>Hol"low*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>State of being
hollow.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Insincerity; unsoundness; treachery.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hollowware</ent><br/
<ent>holloware</ent><br/
<mhw><hw>holloware</hw>, <hw>hollowware</hw></mhw> <pos>n.</pos>
<def>serving dishes of silver having some depth in the bowl; contrasted
with <contr>flatware</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holluschickie</ent><br/
<hw>Hol"lus*chick`ie</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos>
<ety>[Prob. of Russ. <ets>goluishka</ets> bare of possessions,
offspring, etc., fr. <ets>golui<icr/</ets> naked.]</ety>
<fld>(Zool.)</fld> <def>A young male fur seal, esp. one from three to
six years old; -- called also <altname>bachelor</altname>, because
prevented from breeding by the older full-grown males.</def></p>

<p><note><hand/ The <xex>holluschickie</xex> are the seals that may
legally be killed for their skins.</note></p>

<p><q>But he'll lie down on the killing grounds where the
<qex>holluschickie</qex> go.</q> <rj><qau>Kipling.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Holly</ent><br/
<hw>Hol"ly</hw> <pr>(h<omac/l"l<ycr/)</pr>, <pos>adv.</pos>
<def>Wholly.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holly</ent><br/
<hw>Hol"ly</hw> <pr>(h<ocr/l"l<ycr/)</pr>, <pos>n.</pos> <ety>[OE
<ets>holi</ets>, <ets>holin</ets>, AS. <ets>holen</ets>,
<ets>holegn</ets>; akin to D. & G. <ets>hulst</ets>, OHG. <ets>huls
hulis</ets>, W. <ets>celyn</ets>, Armor. <ets>kelen</ets>, Gael.
<ets>cuilionn</ets>, Ir. <ets>cuileann</ets>. Cf. 1st <er>Holm</er>,
<er>Hulver</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A tree or
shrub of the genus <gen>Ilex</gen>. The European species (<spn>Ilex
Aquifolium</spn>) is best known, having glossy green leaves, with a
spiny, waved edge, and bearing berries that turn red or yellow about
Michaelmas.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>holly</xex> is much used to adorn churches and
houses, at Christmas time, and hence is associated with scenes of good
will and rejoicing. It is an evergreen tree, and has a finegrained,
heavy, white wood. Its bark is used as a febrifuge, and the berries are
violently purgative and emetic. The American holly is the <spn>Ilex
opaca</spn>, and is found along the coast of the United States, from
Maine southward.</note> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The holm oak. See 1st
<er>Holm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Holly-leaved oak</b></col> <fld>(Bot.)</fld>, <cd>the
black scrub oak. See <er>Scrub oak</er>.</cd> -- <col><b>Holly
rose</b></col> <fld>(Bot.)</fld>, <cd>a West Indian shrub, with showy,
yellow flowers (<spn>Turnera ulmifolia</spn>).</cd> -- <col><b>Sea
holly</b></col> <fld>(Bot.)</fld>, <cd>a species of Eryngium. See
<er>Eryngium</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hollygrape</ent><br/
<hw>hollygrape</hw> <pos>n.</pos> <def>An ornamental evergreen shrub
(<spn>Mahonia aquifolium</spn>) of the Pacific coast of North America
having dark green pinnate leaves and racemes of yellow flowers followed
by blue-black berries.</def><br/
<syn><b>Syn. --</b> Oregon grape, Oregon holly grape, mountain grape,
holly-leaves barberry, <spn>Mahonia aquifolium</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hollyhock</ent><br/
<hw>Hol"ly*hock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>holihoc</ets>; <ets>holi holy + hoc</ets> mallow, AS.
<ets>hoc</ets>; cf. W. <ets>hocys</ets> mallows, <ets>hocys
bendigaid</ets> hollyhock, lit., blessed mallow. Prob. so named because
brought from the Holy Land. See <er>Holy</er>.]</ety> <fld>(Bot.)</fld>
<def>A species of <gen>Alth<ae/a</gen> (<spn>Alth<ae/a rosea</spn>),
bearing flowers of various colors; -- called also <altname>rose
mallow</altname>.</def> <note>Rose mallow is listed as a variety of
Hibiscus, not Hollyhock in several Web pages. Name change???</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Holm</ent><br/
<hw>Holm</hw> <pr>(h<omac/m; 277)</pr>, <pos>n.</pos> <ety>[OE., prob.
from AS. <ets>holen</ets> holly; as the holly is also called
<ets>holm</ets>. See <er>Holly</er>.]</ety> <fld>(Bot.)</fld> <def>A
common evergreen oak, of Europe (<spn>Quercus Ilex</spn>); -- called
also <altname>ilex</altname>, and <altname>holly</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holm</ent><br/
<hw>Holm</hw> <pr>(h<omac/m)</pr>, <pos>n.</pos> <ety>[AS.
<ets>holm</ets>, usually meaning, sea, water; akin to Icel.
<ets>h<omac/lmr</ets>, <ets>holmr</ets>, an island, Dan.
<ets>holm</ets>, Sw. <ets>holme</ets>, G. <ets>holm</ets>, and prob. to
E. <ets>hill</ets>. Cf. <er>Hill</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An islet in a river.</def> <rj><au>J.
Brand.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Low, flat land.</def>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The soft wind blowing over meadowy <qex>holms</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Holm thrush</b></col> <fld>(Zool.)</fld>, <cd>the missel
thrush.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holmes</ent><br/
<hw>Holmes</hw> <pos>n.</pos> <def><person>Sherlock Holmes</person>, a
fictitious detective in novels by <person>A. Conan
Doyle</person>.</def><br/
<syn><b>Syn. --</b> Sherlock Holmes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holmia</ent><br/
\'d8<hw>Hol"mi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Chem.)</fld> <def>An oxide of holmium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holmium</ent><br/
\'d8<hw>Hol"mi*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Stock<ets>holm</ets>.]</ety> <fld>(Chem.)</fld> <def>A rare element of
atomic number 67 said to be contained in gadolinite. Chemical symbol Ho.
Atomic weight 164.93. Valence +3. It was detected by spectral absorption
bands in 1878 by the <persfn>Delafontaine</persfn> and
<persfn>Soret</persfn>, who called it "Element X". Later the Swedish
chemist <persfn>Cleve</persfn> independently discovered it in erbia, and
named it after his native city Stockholm. The first preparation of pure
Holmia, the yellow oxide, was not made until 1911.</def> <au>HCP61</au>
-- <wordforms><wf>Hol"mic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Holmos</ent><br/
\'d8<hw>Hol"mos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr.<?/.]</ety> <fld>(Greek & Etrus. Antiq.)</fld> <def>A name given to a
vase having a rounded body</def>; esp.: <sd>(a)</sd> <def>A closed
vessel of nearly spherical form on a high stem or pedestal.</def>
<au>Fairholt.</au> <sd>(b)</sd> <def>A drinking cup having a foot and
stem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holo-</ent><br/
<hw>Hol"o-</hw> <pr>(?)</pr>. <def>A combining form fr. Gr.
<grk>"o`los</grk> whole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holoblast</ent><br/
<hw>Hol"o*blast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Holo</ets> +
<ets>-blast</ets>.]</ety> <fld>(Biol.)</fld> <def>an ovum composed
entirely of germinal matter. See <er>Meroblast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holoblastic</ent><br/
<hw>Hol`o*blas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Undergoing complete segmentation; composed entirely of germinal
matter, the whole of the yolk undergoing fission; -- opposed to
<xex>meroblastic</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holocaust</ent><br/
<hw>Hol"o*caust</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>holocaustum</ets>, Gr. <?/, neut. of <?/, <?/, burnt whole;
<grk>"o`los</grk> whole + <grk>kaysto`s</grk> burnt, fr.
<grk>kai`ein</grk> to burn (cf. <er>Caustic</er>): cf. F.
<ets>holocauste</ets>.]</ety> <sn>1.</sn> <def>A burnt sacrifice; an
offering, the whole of which was consumed by fire, among the Jews and
some pagan nations.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sacrifice or loss of many lives, as by the burning
of a theater or a ship.</def> <note>[An extended use not authorized by
careful writers.]</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <def>The mass killing of
millions of Jews by the Nazis during the period from 1933 to 1945 in
Germany and German-occupied lands; usually referred to as <altname>The
Holocaust</altname>. In Hebrew, the same event is referred to by the
word <altname>Shoah</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Holocene</ent><br/
<hw>Holocene</hw> <pos>n.</pos> <sn>1.</sn> <def>The geological period
comprising approximately the last 10,000 years.</def><br/
<syn><b>Syn. --</b> Holocene epoch, Recent epoch.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holocentridae</ent><br/
<hw>Holocentridae</hw> <pos>prop. n.</pos> <def>A natural family of fish
including the squirrelfishes and soldierfishes.</def><br/
<syn><b>Syn. --</b> family <fam>Holocentridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holocentrus</ent><br/
<hw>Holocentrus</hw> <pos>prop. n.</pos> <def>The type genus of the
family <fam>Holocentridae</fam>, comprising some of the
squirrelfishes.</def><br/
<syn><b>Syn. --</b> genus <gen>Holocentrus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>holocephalan</ent><br/
<hw>holocephalan</hw> <pos>n.</pos> <def>A member of the
<ord>Holocephali</ord>, fish with high compressed heads and a bodies
tapering off into a long tail. See also <er>Hoocephali</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Holocephali</ent><br/
\'d8<hw>Hol`o*ceph"a*li</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <grk>"o`los</grk> whole + <grk>kefalh`</grk> head.]</ety>
<fld>(Zool.)</fld> <def>An order of elasmobranch fishes, including,
among living species, only the chim<ae/ras; -- called also
<altname>Holocephala</altname>. See <er>Chim<ae/ra</er>; also
<xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holocryptic</ent><br/
<hw>Hol`o*cryp"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo-</ets> + Gr. <grk>kry`ptein</grk> to conceal.]</ety>
<def>Wholly or completely concealing; incapable of being
deciphered.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Holocryptic cipher</b></col>, <cd>a cipher so constructed
as to afford no clew to its meaning to one ignorant of the
key.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holocrystalline</ent><br/
<hw>Hol`o*crys"tal*line</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo</ets> + <ets>crystalline</ets>.]</ety> <fld>(Min.)</fld>
<def>Completely crystalline; -- said of a rock like granite, all the
constituents of which are crystalline.</def></p>

<p><ent>Holstein-Friesian</ent><br/
<hw>Holstein-Friesian</hw> <pos>n.</pos> <def>A breed of dairy cattle
from North Holland and Friesland; they have a black and white color to
their fur.</def><br/
<syn><b>Syn. --</b> Friesian, Holstein.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hologram</ent><br/
<hw>hol"o*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A photographic
image giving the observer a seemingly three-dimensional view of the
represented object. The three-dimensional effect is produced by exposing
a photographic recording medium to an interference pattern generated by
a coherent beam of light (as from a laser) reflected from the subject,
interacting with a beam directly from the source. The full
three-dimensional effect requires illumination of the image with
coherent light, but less perfect three-dimensional visual effects may
also be observed when the hologram is illuminated with white
light.</def><br/
[<source>PJC</source>]</p>

<p><ent>Holograph</ent><br/
<hw>Hol"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>holographus</ets> entirely autograph, Gr. <grk>"olo`grafos</grk>;
<grk>"o`los</grk> whole + <grk>gra`fein</grk> to write: cf. F.
<ets>holographe</ets>, <ets>olographe</ets>.]</ety> <sn>1.</sn> <def>A
document, as a letter, deed, or will, wholly in the handwriting of the
person from whom it proceeds and whose act it purports to be.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>holograph</ent><br/
<hw>hol"o*graph</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To produce a
holographic image of, by holography.</def><br/
[<source>PJC</source>]</p>

<p><ent>Holographic</ent><br/
<hw>Hol`o*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of
the nature of a holograph; pertaining to holographs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to holography or holograms;
produced by holography.</def><br/
[<source>PJC</source>]</p>

<p><ent>holography</ent><br/
<hw>ho*log"ra*phy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>The process
of producing holograms, usually requiring a source of coherent light, as
from a laser.</def><br/
[<source>PJC</source>]</p>

<p><ent>Holohedral</ent><br/
<hw>Hol`o*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo-</ets> + Gr. <?/ seat, base, fr. <?/ to sit.]</ety>
<fld>(Crystallog.)</fld> <def>Having all the planes required by complete
symmetry, -- in opposition to <contr>hemihedral</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holohemihedral</ent><br/
<hw>Hol`o*hem`i*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo-</ets> + <ets>hemihedral</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Presenting hemihedral forms, in which all
the sectants have halt the whole number of planes.</def>
<rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holometabola</ent><br/
\'d8<hw>Hol`o*me*tab"o*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Holo-</er>, and <er>Metabola</er>.]</ety> <fld>(Zool.)</fld>
<def>Those insects which have a complete metamorphosis;
metabola.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holometabolic</ent><br/
<hw>Hol`o*met`a*bol"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having a complete metamorphosis; -- said of
certain insects, as the butterflies and bees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holometer</ent><br/
<hw>Ho*lom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Holo</ets>
+ <ets>-meter</ets>: cf. F. <ets>holometre</ets>.]</ety> <def>An
instrument for making all kinds of angular measurements.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holophanerous</ent><br/
<hw>Hol`o*phan"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo</ets> + Gr. <?/ visible, fr. <?/ to appear.]</ety>
<fld>(Zool.)</fld> <def>Same as <er>Holometabolic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holophotal</ent><br/
<hw>Hol`o*pho"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Holo</ets>
+ Gr. <?/, <?/, light.]</ety> <fld>(Opt.)</fld> <def>Causing no loss of
light; -- applied to reflectors which throw back the rays of light
without perceptible loss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holophote</ent><br/
<hw>Hol"o*phote</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lamp with lenses
or reflectors to collect the rays of light and throw them in a given
direction; -- used in lighthouses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holophrastic</ent><br/
<hw>Hol`o*phras"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Holo</ets> + Gr. <?/ to speak: cf. F.
<ets>holophrastique</ets>.]</ety> <def>Expressing a phrase or sentence
in a single word, -- as is the case in the aboriginal languages of
America.</def><br/
<syn><b>Syn. --</b> polysynthetic, agglutinative.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holophytic</ent><br/
<hw>Hol`o*phyt"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Holo</ets>
+ Gr.<?/ a plant.]</ety> <def>Wholly or distinctively
vegetable.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Holophytic nutrition</b></col> <pr>(<?/)</pr>, <cd>that
form of nutrition, characteristic of vegetable organisms, in which
carbonic acid, ammonia, and nitrates are absorbed as food, in
distinction from the animal mode of nutrition, by the ingestion of
albuminous matter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holorhinal</ent><br/
<hw>Hol`o*rhi"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Holo</ets>
+ Gr.<?/, nose.]</ety> <fld>(Anat.)</fld> <def>Having the nasal bones
contiguous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holosiderite</ent><br/
<hw>Hol`o*sid"er*ite</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Holo</ets> + <ets>siderite</ets>.]</ety> <fld>(Min.)</fld>
<def>Meteoric iron; a meteorite consisting of metallic iron without
stony matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostean</ent><br/
<hw>Ho*los"te*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Pertaining to the Holostei.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostei</ent><br/
\'d8<hw>Ho*los"te*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>"o`los</grk> whole + <?/ a bone.]</ety> <fld>(Zool.)</fld>
<def>An extensive division of ganoids, including the gar pike, bowfin,
etc.; the bony ganoids. See <xex>Illustration</xex> in
Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holosteric</ent><br/
<hw>Hol`o*ster"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Holo</ets>
+ Gr.<grk>stereo`s</grk> solid.]</ety> <def>Wholly solid; -- said of a
barometer constructed of solid materials to show the variations of
atmospheric pressure without the use of liquids, as the
aneroid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostomata</ent><br/
\'d8<hw>Hol`o*stom"a*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"o`los</grk> whole + <grk>sto`ma</grk>, <grk>-atos</grk>,
mouth.]</ety> <fld>(Zool.)</fld> <def>An artificial division of
gastropods, including those that have an entire aperture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostomate</ent><br/
<hw>Ho*los"to*mate</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Holostomatous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostomatous</ent><br/
<hw>Hol`o*stom"a*tous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having an entire aperture; -- said of many
univalve shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostome</ent><br/
<hw>Hol"o*stome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Holo</ets> +
Gr. <grk>sto`ma</grk> mouth.]</ety> <fld>(Zool.)</fld> <def>One of the
Holostomata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holostraca</ent><br/
\'d8<hw>Ho*los"tra*ca</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"o`los</grk> whole + <?/ shell of a testacean.]</ety>
<fld>(Zool.)</fld> <def>A division of phyllopod Crustacea, including
those that are entirely covered by a bivalve shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holothure</ent><br/
<hw>Hol"o*thure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>holothuria</ets>, pl., a sort of water polyp, Gr. <?/.]</ety>
<fld>(Zool.)</fld> <def>A holothurian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holothurian</ent><br/
<hw>Hol`o*thu"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Belonging to the Holothurioidea.</def> -- <def2><pos>n.</pos>
<def>One of the Holothurioidea.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some of the species of Holothurians are called
<stype>sea cucumbers</stype>, <stype>sea slugs</stype>,
<stype>trepang</stype>, and <stype>b<ecir/che de m<egrave/r</stype>.
Many are used as food, esp. by the Chinese. See
<er>Trepang</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holothurioidea</ent><br/
\'d8<hw>Hol`o*thu`ri*oi"de*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Holothure</er>, and <er>-oid</er>.]</ety>
<fld>(Zool.)</fld> <def>One of the classes of echinoderms.</def>
<note>They have a more or less elongated body, often flattened beneath,
and a circle of tentacles, which are usually much branched, surrounding
the mouth; the skin is more or less flexible, and usually contains
calcareous plates of various characteristic forms, sometimes becoming
large and scalelike. Most of the species have five bands (ambulacra) of
sucker-bearing feet along the sides; in others these are lacking. In one
group (Pneumonophora) two branching internal gills are developed; in
another (Apneumona) these are wanting. Called also
<altname>Holothurida</altname>, <altname>Holothuridea</altname>, and
<altname>Holothuroidea</altname>.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 700 --></p>

<p><ent>Holotricha</ent><br/
\'d8<hw>Ho*lot"ri*cha</hw> <pr>(h<osl/*l<ocr/t"r<icr/*k<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>"o`los</grk> whole +
<grk>qri`x</grk>, <grk>tricho`s</grk>, a hair.]</ety> <fld>(Zool.)</fld>
<def>A group of ciliated Infusoria, having cilia all over the
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holour</ent><br/
<hw>Hol"our</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>holier</ets>.]</ety> <def>A whoremonger.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></p>

<p><ent>Holpen</ent><br/
<ent>Holp</ent><br/
<mhw>{ <hw>Holp</hw> <pr>(?)</pr>, <hw>Hol"pen</hw> <pr>(?)</pr>,
}</mhw> <def><pos>imp. & p. p.</pos> of <er>Help</er>.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holsom</ent><br/
<hw>Hol"som</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wholesome.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holstein</ent><br/
<hw>Hol"stein</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of a breed of cattle, originally from
Schleswig-<etsep>Holstein</etsep>, valued for the large amount of milk
produced by the cows. The color is usually black and white in irregular
patches.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Holster</ent><br/
<hw>Hol"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>holster</ets>; skin to AS. <ets>heolstor</ets> den, cave, fr.
<ets>helan</ets> to conceal, and to Icel. <ets>hulstr</ets> case, Goth.
<ets>hulistr</ets> covering, veil, <ets>huljan</ets> to cover. <root/17.
See <er>Hele</er> to cover, <er>Hell</er>, and cf. <er>Housing</er>,
<er>Houss</er>.]</ety> <def>A leather case for a pistol, carried by a
horseman at the bow of his saddle, or worn on the person suspended from
a belt or shoulder strap.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Holstered</ent><br/
<hw>Hol"stered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bearing
holsters.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holt</ent><br/
<hw>Holt</hw> <pr>(?)</pr>, <def><pos>3d pers. sing. pres.</pos> of
<er>Hold</er>, contr. from <xex>holdeth</xex>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holt</ent><br/
<hw>Holt</hw>, <pos>n.</pos> <ety>[AS. <ets>holt</ets>; akin to LG.
<ets>holt</ets>, D. <ets>hout</ets>, G. <ets>holz</ets>. Icel.
<ets>holt</ets>; cf Gael. & Ir. <ets>coill</ets> wood, Gr. <?/ branch,
shoot.]</ety> <sn>1.</sn> <def>A piece of woodland; especially, a woody
hill.</def> <ldquo/Every <xex>holt</xex> and heath.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She sent her voice though all the holt<br/
Before her, and the park.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A deep hole in a river where there is protection for
fish; also, a cover, a hole, or hiding place.</def> <ldquo/ The fox has
gone to <xex>holt</xex>.<rdquo/ <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holwe</ent><br/
<hw>Hol"we</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hollow.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holy</ent><br/
<hw>Ho"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Holier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Holiest</adjf>.]</amorph> <ety>[OE. <ets>holi</ets>,
<ets>hali</ets>, AS. <ets>h<amac/lig</ets>, fr. <ets>h<ae/l</ets>
health, salvation, happiness, fr. <ets>h<amac/l</ets> whole, well; akin
to OS. <ets>h<?/lag</ets>, D. & G. <ets>heilig</ets>, OHG.
<ets>heilac</ets>, Dan. <ets>hellig</ets>, Sw. <ets>helig</ets>, Icel.
<ets>heilagr</ets>. See <er>Whole</er>, and cf. <er>Halibut</er>,
<er>Halidom</er>, <er>Hallow</er>, <er>Hollyhock</er>.]</ety>
<sn>1.</sn> <def>Set apart to the service or worship of God; hallowed;
sacred; reserved from profane or common use; <xex>holy</xex> vessels; a
<xex>holy</xex> priesthood.</def> <ldquo/<xex>Holy</xex> rites and
solemn feasts.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Spiritually whole or sound; of unimpaired innocence
and virtue; free from sinful affections; pure in heart; godly; pious;
irreproachable; guiltless; acceptable to God.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now through her round of <qex>holy</qex> thought<br/
The Church our annual steps has brought.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Holy Alliance</b></col> <fld>(Hist.)</fld>, <cd>a league
ostensibly for conserving religion, justice, and peace in Europe, but
really for repressing popular tendencies toward constitutional
government, entered into by <person>Alexander I.</person> of Russia,
<person>Francis I.</person> of Austria, and <person>Frederic William
III.</person> of Prussia, at Paris, on the 26th of September, 1815, and
subsequently joined by all the sovereigns of Europe, except the pope and
the king of England.</cd> -- <col><b>Holy bark</b></col>. <cd>See
<er>Cascara sagrada</er>.</cd> -- <col><b>Holy Communion</b></col>.
<cd>See <er>Eucharist</er>.</cd> -- <col><b>Holy family</b></col>
<fld>(Art)</fld>, <cd>a picture in which the infant Christ, his parents,
and others of his family are represented.</cd> -- <col><b>Holy
Father</b></col>, <cd>a title of the pope.</cd> -- <col><b>Holy
Ghost</b></col> <fld>(Theol.)</fld>, <cd>the third person of the
Trinity; the Comforter; the Paraclete.</cd> -- <col><b>Holy
Grail</b></col>. <cd>See <er>Grail</er>.</cd> -- <col><b>Holy
grass</b></col> <fld>(Bot.)</fld>, <cd>a sweet-scented grass
(<spn>Hierochloa borealis</spn> and <spn>Hierochloa alpina</spn>). In
the north of Europe it was formerly strewed before church doors on
saints' days; whence the name. It is common in the northern and western
parts of the United States. Called also <altname>vanilla grass</altname>
<it>or</it> <altname>Seneca grass</altname>.</cd> -- <col><b>Holy
Innocents' day</b></col>, <cd>Childermas day.</cd> -- <col><b>Holy
Land</b></col>, <cd>Palestine, the birthplace of Christianity.</cd> --
<col><b>Holy office</b></col>, <cd>the Inquisition.</cd> -- <col><b>Holy
of holies</b></col> <fld>(Script.)</fld>, <cd>the innermost apartment of
the Jewish tabernacle or temple, where the ark was kept, and where no
person entered, except the high priest once a year.</cd> -- <col><b>Holy
One</b></col>. <sd>(a)</sd> <cd>The Supreme Being; -- so called by way
of emphasis.</cd> <ldquo/ The <xex>Holy One</xex> of Israel.<rdquo/
<au>Is. xliii. 14.</au> <sd>(b)</sd> <cd>One separated to the service of
God.</cd> -- <col><b>Holy orders</b></col>. <cd>See <er>Order</er>.</cd>
-- <col><b>Holy rood</b></col>, <cd>the cross or crucifix, particularly
one placed, in churches. over the entrance to the chancel.</cd> --
<col><b>Holy rope</b></col>, <cd>a plant, the hemp agrimony.</cd> --
<col><b>Holy Saturday</b></col> <fld>(Eccl.)</fld>, <cd>the Saturday
immediately preceding the festival of Easter; the vigil of Easter.</cd>
-- <col><b>Holy Spirit</b></col>, <cd>same as <cref>Holy Ghost</cref>
(above).</cd> -- <col><b>Holy Spirit plant</b></col>. <cd>See <er>Dove
plant</er>.</cd> -- <col><b>Holy thistle</b></col> <fld>(Bot.)</fld>,
<cd>the blessed thistle. See under <er>Thistle</er>.</cd> --
<col><b>Holy Thursday</b></col>. <fld>(Eccl.)</fld> <sd>(a)</sd>
<fld>(Episcopal Ch.)</fld> <cd>Ascension day.</cd> <sd>(b)</sd> <fld>(R.
C. Ch.)</fld> <cd>The Thursday in Holy Week; Maundy Thursday.</cd> --
<col><b>Holy war</b></col>, <cd>a crusade; an expedition carried on by
Christians against the Saracens in the Holy Land, in the eleventh,
twelfth, and thirteenth centuries, for the possession of the holy
places.</cd><-- now used mostly for the Moslem jihad --> -- <col><b>Holy
water</b></col> <fld>(Gr. & R. C. Churches)</fld>, <cd>water which has
been blessed by the priest for sacred purposes.</cd> --
<col><b>Holy-water stoup</b></col>, <cd>the stone stoup or font placed
near the entrance of a church, as a receptacle for holy water.</cd> --
<col><b>Holy Week</b></col> <fld>(Eccl.)</fld>, <cd>the week before
Easter, in which the passion of our Savior is commemorated.</cd> --
<col><b>Holy writ</b></col>, <cd>the sacred Scriptures.</cd> <ldquo/
Word of <xex>holy writ</xex>.<rdquo/ <au>Wordsworth.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holy cross</ent><br/
<hw>Ho"ly cross"</hw> <pr>(?; 115)</pr>. <def>The cross as the symbol of
Christ's crucifixion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Congregation of the Holy Cross</b></col> <fld>(R. C.
Ch.)</fld>, <cd>a community of lay brothers and priests, in France and
the United States, engaged chiefly in teaching and manual Labor.
Originally called <altname>Brethren of St. Joseph</altname>. The
<xex>Sisters of the Holy Cross</xex> engage in similar work.</cd>
<au>Addis & Arnold.</au> -- <col><b>Holy-cross day</b></col>, <cd>the
fourteenth of September, observed as a church festival, in memory of the
exaltation of our Savior's cross.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holyday</ent><br/
<hw>Ho"ly*day`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
religious festival.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A secular festival; a holiday.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Holiday</xex> is the preferable and prevailing
spelling in the second sense. The spelling <xex>holy day or
holyday</xex> in often used in the first sense.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holystone</ent><br/
<hw>Ho"ly*stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A stone used by seamen for scrubbing the decks of ships.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Holystone</ent><br/
<hw>Ho"ly*stone`</hw>, <pos>v. t.</pos> <fld>(Naut.)</fld> <def>To scrub
with a holystone, as the deck of a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homacanth</ent><br/
<hw>Hom"a*canth</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Homo</ets> +
Gr. <?/ a spine.]</ety> <fld>(Zool.)</fld> <def>Having the dorsal fin
spines symmetrical, and in the same line; -- said of certain
fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homage</ent><br/
<hw>Hom"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>homage</ets>, <ets>homenage</ets>, F. <ets>hommage</ets>, LL.
<ets>hominaticum</ets>, <ets>homenaticum</ets>, from L. <ets>homo</ets>
a man, LL. also, a client, servant, vassal; akin to L. <ets>humus</ets>
earth, Gr.<?/ on the ground, and E. <ets>groom</ets> in
bride<ets>groom</ets>. Cf. <er>Bridegroom</er>, <er>Human</er>.]</ety>
<sn>1.</sn> <fld>(Feud. Law)</fld> <def>A symbolical acknowledgment made
by a feudal tenant to, and in the presence of, his lord, on receiving
investiture of fee, or coming to it by succession, that he was his
<xex>man</xex>, or vassal; profession of fealty to a
sovereign.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Respect or reverential regard; deference;
especially, respect paid by external action; obeisance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All things in heaven and earth do her [Law] <qex>homage</qex>.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I sought no <qex>homage</qex> from the race that write.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Reverence directed to the Supreme Being; reverential
worship; devout affection.</def> <rj><au>Chaucer.</au></rj></p>

<p><syn><b>Syn.</b> -- Fealty; submission; reverence; honor;
respect.</syn> <usage> -- <er>Homage</er>, <er>Fealty</er>.
<xex>Homage</xex> was originally the act of a feudal tenant by which he
declared himself, on his knees, to be the <xex>hommage</xex> or bondman
of the lord; hence the term is used to denote reverential submission or
respect. <xex>Fealty</xex> was originally the <xex>fidelity</xex> of
such a tenant to his lord, and hence the term denotes a faithful and
solemn adherence to the obligations we owe to superior power or
authority. We pay our <xex>homage</xex> to men of pre<eum/minent
usefulness and virtue, and profess our <xex>fealty</xex> to the
principles by which they have been guided.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Go, go with <qex>homage</qex> yon proud victors meet !<br/
Go, lie like dogs beneath your masters' feet !</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Man, disobeying,<br/
Disloyal, breaks his <qex>fealty</qex>, and sins<br/
Against the high supremacy of heaven.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homage</ent><br/
<hw>Hom"age</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Homaged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Homaging</conjf>.]</vmorph> <ety>[Cf. OF.
<ets>hommager</ets>.]</ety> <sn>1.</sn> <def>To pay reverence to by
external action.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to pay homage.</def> <mark>[Obs.]</mark>
<rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homageable</ent><br/
<hw>Hom"age*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>hommageable</ets>.]</ety> <def>Subject to homage.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homager</ent><br/
<hw>Hom"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Homage</er>: cf. F. <ets>hommager</ets>.]</ety> <def>One who does
homage, or holds land of another by homage; a vassal.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homalographic</ent><br/
<hw>Hom`a*lo*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Homolographic</er>.</def></p>

<p><ent>Homaloidal</ent><br/
<ent>Homaloid</ent><br/
<mhw>{ <hw>Hom"a*loid</hw> <pr>(h<ocr/m"<adot/*loid)</pr>,
<hw>Hom`a*loid"al</hw> <pr>(-loid"<ait/l)</pr>, }</mhw> <pos>a.</pos>
<ety>[Gr. <grk>"omalo`s</grk> even + <ets>-oid</ets>.]</ety>
<fld>(Geom.)</fld> <def>Flat; even; -- a term applied to surfaces and to
spaces, whether real or imagined, in which the definitions, axioms, and
postulates of Euclid respecting parallel straight lines are assumed to
hold true.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homarus</ent><br/
\'d8<hw>Hom"a*rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>"omarh`s</grk> well adjusted.]</ety> <fld>(Zool.)</fld> <def>A
genus of decapod Crustacea, including the common lobsters.</def> --
<wordforms><wf>Hom"a*roid</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homatropine</ent><br/
<hw>Ho*mat"ro*pine</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Homo-</ets> + <ets>atropine</ets>.]</ety> <fld>(Med.)</fld>
<def>An alkaloid, prepared from atropine, and from other sources. It is
chemically related to atropine, and is used for the same
purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homaxonial</ent><br/
<hw>Hom`ax*o"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + <ets>Gr</ets>. <ets><?/</ets> an axle,
axis.]</ety> <fld>(Biol.)</fld> <def>Relating to that kind of homology
or symmetry, the mathematical conception of organic form, in which all
axes are equal. See under <er>Promorphology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hombre</ent><br/
<hw>hombre</hw> <pos>n.</pos> <ety>[Sp.: a man.]</ety> <def>an informal
term for a youth or man.</def><br/
<syn><b>Syn. --</b> guy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>homburg</ent><br/
<hw>hom"burg</hw> <pos>n.</pos> <ety>[from <etsep>Homburg</etsep>,
Germany, the place of first manufacture.]</ety> <def>A felt hat with a
crown that is creased lengthwise, and a brim that is slightly curled
upward at the edge.</def><br/
<syn><b>Syn. --</b> fedora, felt hat, trilby.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Home</ent><br/
<hw>Home</hw> <pr>(h<omac/m)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Homelyn</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home</ent><br/
<hw>Home</hw> <pr>(h<omac/m; 110)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hom</ets>, <ets>ham</ets>, AS. <ets>h<amac/m</ets>; akin to OS.
<ets>h<emac/m</ets>, D. & G. <ets>heim</ets>, Sw. <ets>hem</ets>, Dan.
<ets>hiem</ets>, Icel. <ets>heimr</ets> abode, world, <ets>heima</ets>
home, Goth. <ets>haims</ets> village, Lith. <ets>k<eum/mas</ets>, and
perh. to Gr. <grk>kw`mh</grk> village, or to E. <ets>hind</ets> a
peasant; cf. Skr. <ets>ksh<emac/ma</ets> abode, place of rest, security,
<ets>kshi</ets> to dwell. <root/20, 220.]</ety> <sn>1.</sn> <def>One's
own dwelling place; the house in which one lives; esp., the house in
which one lives with his family; the habitual abode of one's family;
also, one's birthplace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The disciples went away again to their own <qex>home</qex>.</q>
<rj><qau>John xx. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Home</qex> is the sacred refuge of our life.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Home</qex>! <qex>home</qex>! sweet, sweet
<qex>home</qex>!<br/
There's no place like <qex>home</qex>.</q>
<rj><qau>Payne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One's native land; the place or country in which one
dwells; the place where one's ancestors dwell or dwelt.</def> <ldquo/Our
old <xex>home</xex> [England].<rdquo/ <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The abiding place of the affections, especially of
the domestic affections.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He entered in his house -- his <qex>home</qex> no more,<br/
For without hearts there is no <qex>home</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The locality where a thing is usually found, or was
first found, or where it is naturally abundant; habitat; seat; <as>as,
the <ex>home</ex> of the pine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her eyes are <qex>homes</qex> of silent prayer.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Flandria, by plenty made the <qex>home</qex> of war.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A place of refuge and rest; an asylum; <as>as, a
<ex>home</ex> for outcasts; a <ex>home</ex> for the blind</as>; hence,
esp., the grave; the final rest; also, the native and eternal dwelling
place of the soul.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Man goeth to his long <qex>home</qex>, and the mourners go about
the streets.</q> <rj><qau>Eccl. xii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Baseball)</fld> <def>The <cref>home base</cref>;
<as>as, he started for <ex>home</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At home</b></col>.<sd>(a)</sd> <cd>At one's own house, or
lodgings.</cd> <sd>(b)</sd> <cd>In one's own town or country; as, peace
abroad and <ex>at home</ex>.</cd> <sd>(c)</sd> <cd>Prepared to receive
callers.</cd> -- <col><b>Home department</b></col>, <cd>the department
of executive administration, by which the internal affairs of a country
are managed.</cd> <mark>[Eng.]</mark> <col><b>To be at home on any
subject</b></col>, <cd>to be conversant or familiar with it.</cd> --
<col><b>To feel at home</b></col>, <cd>to be at one's ease.</cd> --
<col><b>To make one's self at home</b></col>, <cd>to conduct one's self
with as much freedom as if at home.</cd></cs></p>

<p><syn><b>Syn.</b> -- Tenement; house; dwelling; abode;
domicile.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home</ent><br/
<hw>Home</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to one's dwelling or country; domestic; not foreign; <as>as
<xex>home</xex> manufactures; <xex>home</xex> comforts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Close; personal; pointed; <as>as, a <ex>home</ex>
thrust</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Games)</fld> <def>In various games, the ultimate
point aimed at in a progress; goal</def>; as: <sd>(a)</sd>
<fld>(Baseball)</fld> <def>The plate at which the batter stands; same as
<cref>home base</cref> and <cref>home plate</cref>.</def> <sd>(b)</sd>
<fld>(Lacrosse)</fld> <def>The place of a player in front of an
opponent's goal; also, the player.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Home base</b></col> <it>or</it> <col><b>Home
plate</b></col></mcol> <fld>(Baseball)</fld>, <cd>the base at which the
batter stands when batting, and which is the last base to be reached in
scoring a run.</cd> -- <mcol><col><b>Home farm</b></col>,
<col><b>grounds</b></col></mcol>, etc., <cd>the farm, grounds, etc.,
adjacent to the residence of the owner.</cd> -- <col><b>Home
lot</b></col>, <cd>an inclosed plot on which the owner's home
stands.</cd> <mark>[U. S.]</mark> -- <col><b>Home rule</b></col>,
<cd>rule or government of an appendent or dependent country, as to all
local and internal legislation, by means of a governing power vested in
the people within the country itself, in contradistinction to a
government established by the dominant country; <as>as, <ex>home
rule</ex> in Ireland</as>. Also used adjectively; as,
<xex>home-rule</xex> members of Parliament.</cd> -- <col><b>Home
ruler</b></col>, <cd>one who favors or advocates home rule.</cd> --
<col><b>Home stretch</b></col> <fld>(Sport.)</fld>, <cd>that part of a
race course between the last curve and the winning post.</cd> --
<col><b>Home thrust</b></col>, <cd>a well directed or effective thrust;
one that wounds in a vital part; hence, in controversy, a personal
attack.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home</ent><br/
<hw>Home</hw>, <pos>adv.</pos> <sn>1.</sn> <def>To one's home or
country; <as>as in the phrases, go <ex>home</ex>, come <ex>home</ex>,
carry <ex>home</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Close; closely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>home</qex> the charge reaches us, has been made out.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They come <qex>home</qex> to men's business and bosoms.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To the place where it belongs; to the end of a
course; to the full length; <as>as, to drive a nail <ex>home</ex>; to
ram a cartridge <ex>home</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wear thy good rapier bare and put it <qex>home</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Home</xex> is often used in the formation of
compound words, many of which need no special definition; as,
<xex>home</xex>-brewed, <xex>home</xex>-built, <xex>home-grown</xex>,
<xex>etc.</xex></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To bring home</b></col>. <cd>See under
<er>Bring</er>.</cd> -- <col><b>To come home</b></col>.<sd>(a)</sd>
<cd>To touch or affect personally. See under <er>Come</er>.</cd>
<sd>(b)</sd> <fld>(Naut.)</fld> <cd>To drag toward the vessel, instead
of holding firm, as the cable is shortened; -- said of an anchor.</cd>
-- <col><b>To haul home the sheets of a sail</b></col>
<fld>(Naut.)</fld>, <cd>to haul the clews close to the sheave hole.</cd>
<rj><au>Totten.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>home</ent><br/
<hw>home</hw> <pr>(h<omac/m)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
return home.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To proceed toward an object or location intended as
a target; -- of missiles which can change course in flight under
internal or external control; usually used with <ptcl>in on</ptcl>;
<as>as, the missile <ex>homed</ex> in on the radar site</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <mark>[fig.]</mark> <def>To arrive at or get closer to an
object sought or an intended goal; used with <ptcl>in on</ptcl>; <as>as,
the repairman quickly <ex>homed</ex> in on the cause of the
malfunction</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>homebody</ent><br/
<hw>home"bod`y</hw> <pos>n.</pos> <def>a person who seldom goes
anywhere; one not given to wandering or travel.</def><br/
<syn><b>Syn. --</b> stay-at-home.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homeborn</ent><br/
<hw>Home"born`</hw> <pr>(h<omac/m"b<ocir/rn`)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Native; indigenous; not foreign.</def>
<rj><au>Donne.</au> <au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the home or family.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fireside enjoyments, <qex>homeborn</qex> happiness.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>home-bound</ent><br/
<ent>homebound</ent><br/
<mhw><hw>home"bound`</hw>, <hw>home"-bound`</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Kept at home, usually due to illness; same as
<er>housebound</er>.</def><br/
<syn><b>Syn. --</b> housebound, shut-in.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home-bred</ent><br/
<hw>Home"-bred`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Bred
at home; domestic; not foreign.</def> <ldquo/ <xex>Home-bred</xex>
mischief.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Benignity and <qex>home-bred</qex> sense.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not polished; rude; uncultivated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Only to me <qex>home-bred</qex> youths belong.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>homebuilder</ent><br/
<hw>homebuilder</hw> <pos>n.</pos> <def>someone who builds houses as a
business.</def><br/
<syn><b>Syn. --</b> housebuilder.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>home-coming</ent><br/
<ent>homecoming</ent><br/
<mhw><hw>home"com`ing</hw>, <hw>home"-com`ing</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>A return home.</def>
<wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><q>Kepeth this child, al be it foul or fayr,<br/
And eek my wyf, unto myn <qex>hoom-cominge</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A social event, usually held annually at colleges
and universities, to welcome visiting alumni; a type of school reunion
for graduates.</def> <wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><ent>Home-driven</ent><br/
<hw>Home"-driv`en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Driven to the
end, as a nail; driven close.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home-dwelling</ent><br/
<hw>Home"-dwell`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Keeping at
home.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home-felt</ent><br/
<hw>Home"-felt`</hw> <pr>(-f<ecr/lt`)</pr>, <pos>a.</pos> <def>Felt in
one's own breast; inward; private.</def> <ldquo/<xex>Home-felt</xex>
quiet.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homefield</ent><br/
<hw>Home"field`</hw> <pr>(-f<emac/ld`)</pr>, <pos>n.</pos> <def>A field
adjacent to its owner's home.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>home-grown</ent><br/
<ent>homegrown</ent><br/
<mhw><hw>homegrown</hw>, <hw>home-grown</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>grown or produced at home or in a specific locality; --
of plants or animals.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> local.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Originating in a particular place or region; <as>as,
<ex>homegrown</ex> talent</as>; -- applied broadly, to people
(especially people with specific skills), products of manufacture,
etc.</def><br/
[<source>PJC</source>]</p>

<p><ent>Home-keeping</ent><br/
<hw>Home"-keep`ing</hw> <pr>(-k<emac/p`<icr/ng)</pr>, <pos>a.</pos>
<def>Staying at home; not gadding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Home-keeping</qex> youth have ever homely wits.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home-keeping</ent><br/
<hw>Home"-keep`ing</hw>, <pos>n.</pos> <def>A staying at home.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeless</ent><br/
<hw>Home"less</hw>, <pos>a.</pos> <ety>[AS.
<ets>h<amac/mleas</ets>.]</ety> <def>Destitute of a home.</def></p>

<p>-- <wordforms><wf>Home"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>homeless</ent><br/
<hw>home"less</hw>, <pos>n. pl.</pos> <def>Those people who have no
permanent residence, especially those who live outdoors due to poverty;
usually used in the definite phrase <altname>the
homeless</altname>.</def></p>

<p><ent>homelessness</ent><br/
<hw>homelessness</hw> <pos>n.</pos> <def>the state or condition of
having no home, especially of living in the streets.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homelike</ent><br/
<hw>Home"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a home;
comfortable; cheerful; cozy; friendly; <as>as, a <ex>homelike</ex>
atmosphere</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homelily</ent><br/
<hw>Home"li*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Plainly;
inelegantly.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeliness</ent><br/
<hw>Home"li*ness</hw>, <pos>n.</pos> <ety>[From <er>Homely</er>.]</ety>
<sn>1.</sn> <def>Domesticity; care of home.</def> <mark>[Obs.]</mark>
<ldquo/Wifely <xex>homeliness</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Familiarity; intimacy.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Plainness; want of elegance or beauty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Coarseness; simplicity; want of refinement; <as>as,
the <ex>homeliness</ex> of manners, or language</as>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeling</ent><br/
<hw>Home"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person or thing
belonging to a home or to a particular country; a native; <as>as, a word
which is a <ex>homeling</ex></as>.</def> <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homely</ent><br/
<hw>Home"ly</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Homelier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Homeliest</adjf>.]</amorph> <ety>[From <er>Home</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Belonging to, or having the
characteristics of, home; domestic; familiar; intimate.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With all these men I was right <qex>homely</qex>, and communed
with, them long and oft.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their <qex>homely</qex> joys, and destiny obscure.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Plain; unpretending; rude in appearance; unpolished;
<as>as, a <ex>homely</ex> garment; a <ex>homely</ex> house;
<ex>homely</ex> fare; <ex>homely</ex> manners.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now Strephon daily entertains<br/
His Chloe in the <qex>homeliest</qex> strains.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of plain or coarse features; uncomely; ugly; --
usually used of people, especially women; -- contrary to
<ant>handsome</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>None so <qex>homely</qex> but loves a looking-glass.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homely</ent><br/
<hw>Home"ly</hw>, <pos>adv.</pos> <def>Plainly; rudely; coarsely;
<as>as, <ex>homely</ex> dressed</as>.</def> <mark>[R.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homelyn</ent><br/
<hw>Home"lyn</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot.
<ets>hommelin</ets>.]</ety> <fld>(Zool)</fld> <def>The European sand ray
(<spn>Raia maculata</spn>); -- called also <altname>home</altname>,
<altname>mirror ray</altname>, and <altname>rough
ray</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homemade</ent><br/
<hw>Home"made`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made at home; of
domestic manufacture; made either in a private family or in one's own
country.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeopath</ent><br/
<hw>Ho"me*o*path</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hom</ets><eacute/<ets>opathe</ets>.]</ety> <def>A practitioner of
homeopathy.</def> <altsp>[Written also
<asp>hom<oe/opath</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 701 --></p>

<p><ent>Homeopathic</ent><br/
<hw>Ho`me*o*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hom<eacute/opathique</ets>.]</ety> <def>Of or pertaining to
homeopathy; according to the principles of homeopathy.</def>
<altsp>[Also <asp>hom<oe/pathic</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeopathically</ent><br/
<hw>Ho`me*o*path"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>According to the practice of homeopathy.</def> <altsp>[Also
<asp>hom<oe/opathically</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeopathist</ent><br/
<hw>Ho`me*op"a*thist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A believer
in, or practitioner of, homeopathy.</def> <altsp>[Written also
<asp>hom<oe/opathist</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homeopathy</ent><br/
<hw>Ho*me*op"a*thy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
likeness of condition or feeling; <?/ like (fr. <?/ same; cf.
<er>Same</er>) + <?/ to suffer: cf. F. <ets>hom<eacute/opathie</ets>.
See <er>Pathos</er>.]</ety> <fld>(Med.)</fld> <def>The art of curing,
founded on resemblances; the theory and its practice that disease is
cured (<xex>tuto</xex>, <xex>cito</xex>, <xex>et jucunde</xex>) by
remedies which produce on a healthy person effects similar to the
symptoms of the complaint under which the patient suffers, the remedies
being usually administered in minute doses. This system was founded by
<person>Dr. Samuel Hahnemann</person>, and is opposed to
<contr>allopathy</contr>, or <contr>heteropathy</contr>.</def>
<altsp>[Written also <asp>hom<oe/opathy</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>home-schooled</ent><br/
<hw>home-schooled</hw> <pos>a.</pos> <def>Receiving or having received
formal education, especially primary or secondary education, at home
rather than in a school. The instruction at home may be accomplished by
parents or by professionals who come to the home; <as>as,
<ex>home-schooled</ex> students often get higher test scores than those
educated in schools</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>homeschooling</ent><br/
<hw>home"school`ing</hw> <pr>(h<omac/m"sk<oomac/"l<icr/ng)</pr>
<pos>n.</pos> <def>The practise of providing formal education,
especially primary or secondary education, at home rather than in a
school.</def><br/
[<source>PJC</source>]</p>

<p><ent>homeostasis</ent><br/
<hw>homeostasis</hw> <pos>n.</pos> <def>The ability and tendency of
certain systems to maintain a relatively constant internal state in
spite of changes in external conditions; this ability is achieved by the
presence of feedback mechanisms which can adjust the state of the system
to compensate for changes in the state caused by the external
environment. It is exemplified in homeothermal biological systems, such
as animals which maintain relatively constant blood temperature and
composition in spite of variations in external temperature or the
composition of the food ingested.</def><br/
[<source>PJC</source>]</p>

<p><ent>homeostatic</ent><br/
<hw>homeostatic</hw> <pos>a.</pos> <def>Of or pertaining to homeostasis;
exhibiting homeostasis.</def><br/
[<source>PJC</source>]</p>

<p><ent>homeostatically</ent><br/
<hw>homeostatically</hw> <pos>adv.</pos> <def>In a homeostatic
manner.</def><br/
[<source>PJC</source>]</p>

<p><ent>homeotherm</ent><br/
<hw>homeotherm</hw> <pos>n.</pos> <fld>(Biol.)</fld> <def>A
homoiothermal animal.</def><br/
<syn><b>Syn. --</b> homoiotherm.</syn><br/
[<source>PJC</source>]</p>

<p><ent>homeothermic</ent><br/
<ent>homeothermal</ent><br/
<mhw><hw>homeothermal</hw>, <hw>homeothermic</hw></mhw> <pos>adj.</pos>
<fld>(Biol.)</fld> <def>having constant and relatively high body
temperature; warm-blooded; same as <er>homoiothermal</er>; -- of birds
and mammals. Contrasted to <ant>poikilothermal</ant>.</def><br/
<syn><b>Syn. --</b> homoiothermic, homoiothermal, homothermic,
homothermal.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>homeothermy</ent><br/
<ent>homeothermism</ent><br/
<mhw><hw>homeothermism</hw>, <hw>homeothermy</hw></mhw> <pos>n.</pos>
<fld>(Biol.)</fld> <def>The process or state of being
homoiothermal.</def><br/
<syn><b>Syn. --</b> homoiothermism, homoiothermy.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Homer</ent><br/
<hw>Hom"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
carrier pigeon remarkable for its ability to return home from a
distance; also called a <altname>homing pigeon</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homer</ent><br/
<hw>Ho"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Hoemother</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homer</ent><br/
<hw>Ho"mer</hw>, <pos>n.</pos> <ety>[Heb. <ets>kh<omac/mer</ets>.]</ety>
<def>A Hebrew measure containing, as a liquid measure, ten baths,
equivalent to fifty-five gallons, two quarts, one pint; and, as a dry
measure, ten ephahs, equivalent to six bushels, two pecks, four
quarts.</def> <altsp>[Written also <asp>chomer</asp>,
<asp>gomer</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homer</ent><br/
<hw>Ho"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Baseball)</fld>
<def>Same as <er>Home run</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Homer</ent><br/
<hw>Homer</hw> <pr>(h<omac/"m<etil/r)</pr>. <ety>[L. Homerus, Gr.
<grk>"O`mhros</grk>, one who puts together; a hostage; a pledge agreed
upon between two parties.]</ety> <def>The poet to whom is assigned by
very ancient tradition the authorship of the Iliad and the Odyssey, and
of certain hymns to the gods ("Homeric Hymns"). Other poems also, as the
"Batrachomyomachia" ("Battle of the Frogs and Mice"), were with less
certainty attributed to him. Of his personality nothing is known. Seven
cities -- Smyrna, Rhodes, Colophon, Salamis (in Cyprus), Chios, Argos,
and Athens -- contended for the honor of being his birthplace: of these,
the best evidence connects him with Smyrna. He was said to have died on
the island of Ios. <bio>The tradition that he lived on the island of
Chios, and in his old age was blind, is supported by the Hymn to the
Delian Apollo. Modern destructive criticism has led to the doubt whether
such a person as Homer existed at all, the great epics which bear that
name being supposed to be, in their existing form, of a composite
character, the product of various persons and ages. It is altogether
probable, however, that the nucleus of the Iliad, at least, was the work
of a single poet of commanding genius. (See Iliad, Odyssey, and the
quotation below.) Various dates have been assigned to Homer. According
to Herodotus he lived about 850 b. c.; others give a later date, and
some a date as early as 1200 b. c. His poems were sung by professional
reciters (rhapsodists, who went from city to city;
<note>Homeridae</note>). They were given substantially their present
form by Pisistratus or his sons Hipparchus and Hippias, who ordered the
rhapsodists to recite them at the Panathenaic festival in their order
and completeness. The present text of the poems, with their division
into books, is based upon the work of the Alexandrine critics.</bio><br/
<br/
<note> We may assume it as certain that there existed in Ionia schools
or fraternities of epic rhapsodists who composed and recited heroic lays
at feasts, and often had friendly contests in these recitations. The
origin of these recitations may be sought in northern Greece, from which
the fashion migrated in early days to Asia Minor. We may assume that
these singers became popular in many parts of Greece, and that they
wandered from court to court, glorifying the heroic ancestors of the
various chiefs. One among them, called Homer, was endowed with a genius
superior to the rest, and struck out a plot capable of nobler and larger
treatment. It is likely that this superiority was not recognized at the
time, and that he remained all his life a singer like the rest, a
wandering minstrel, possibly poor and blind. The listening public
gradually stamped his poem with their approval, they demanded its
frequent recitation, and so this Homer began to attain a great
posthumous fame. But when this fame led people to inquire into his life
and history, it had already passed out of recollection, and men supplied
by fables what they had forgotten or neglected. The rhapsodists,
however, then turned their attention to expanding and perfecting his
poem, which was greatly enlarged and called the Iliad. In doing this
they had recourse to the art of writing, which seems to have been in use
when Homer framed his poem, but which was certainly employed when the
plan was enlarged with episodes. The home of the original Homer seems to
have been about Smyrna, and in contact with both Aeolic and Ionic
legends. His date is quite uncertain: it need not be placed before 800
B. C., and is perhaps later, but not after 700 a. c.</note> <au>Mahaffy,
Hist. of Classical Greek Lit., I. 81.</au></def><br/
[<source>century Dict. 1906</source>]</p>

<p><ent>Home run</ent><br/
<hw>Home" run`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Baseball)</fld>
<def>a complete circuit of the bases made by the batter without being
put out and without an error on the play; also, the hit on which the
batter makes such a circuit; a four-base hit.</def> <note>Most <ex>home
runs</ex> are made when the batter hits a fair ball out of the playing
area on a fly, when the ball cannot be played by the defending team; if
a batter circuits the bases while the ball is still inside the playing
field, it is an <stype>inside-the-park home run</stype>.</note><br/
[<source>PJC</source>]</p>

<p><ent>Homeric</ent><br/
<hw>Ho*mer"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Homericus</ets>, Gr. <grk>"Omhriko`s</grk>.]</ety> <def>Of or
pertaining to <persfn>Homer</persfn>, the most famous of Greek poets;
resembling the poetry of Homer.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homeric verse</b></col>, <cd>hexameter verse; -- so
called because used by Homer in his epics.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homesick</ent><br/
<hw>Home"sick`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pining for home; in
a nostalgic condition.</def> -- <wordforms><wf>Home"sick`ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Home-speaking</ent><br/
<hw>Home"-speak`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Direct,
forcible, and effective speaking.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homespun</ent><br/
<hw>Home"spun</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Spun or
wrought at home; of domestic manufacture; coarse; plain.</def>
<ldquo/<xex>Homespun</xex> country garbs.<rdquo/ <rj><au>W.
Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Plain in manner or style; not elegant; rude;
coarse.</def> <ldquo/Our <xex>homespun</xex> English proverb.<rdquo/
<au>Dryden.</au> <ldquo/Our <xex>homespun</xex> authors.<rdquo/
<au>Addison.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homespun</ent><br/
<hw>Home"spun</hw>, <pos>n.</pos> <sn>1.</sn> <def>Cloth made at home;
<as>as, he was dressed in <ex>homespun</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An unpolished, rustic person.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homestall</ent><br/
<hw>Home"stall`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<amac/msteall</ets>.]</ety> <def>Place of a home; homestead.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homestead</ent><br/
<hw>Home"stead</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<amac/mstede</ets>.]</ety> <sn>1.</sn> <def>The home place; a home
and the inclosure or ground immediately connected with it.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The home or seat of a family; place of
origin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We can trace them back to a <qex>homestead</qex> on the Rivers
Volga and Ural.</q> <rj><qau>W. Tooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The home and appurtenant land and
buildings owned by the head of a family, and occupied by him and his
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homestead law</b></col>. <sd>(a)</sd> <cd>A law
conferring special privileges or exemptions upon owners of homesteads;
esp., a law exempting a homestead from attachment or sale under
execution for general debts. Such laws, with limitations as to the
extent or value of the property, exist in most of the States. Called
also <altname>homestead exemption law</altname>.</cd> <sd>(b)</sd>
<cd>Also, a designation of an Act of Congress authorizing and regulating
the sale of public lands, in parcels of 160 acres each, to actual
settlers.</cd> <mark>[U.S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homesteader</ent><br/
<hw>Home"stead*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who has
entered upon a portion of the public land with the purpose of acquiring
ownership of it under provisions of the homestead law, so called; one
who has acquired a homestead in this manner.</def> <mark>[Local,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>homestretch</ent><br/
<hw>homestretch</hw> <pos>n.</pos> <sn>1.</sn> <def>the straight segment
of a racetrack leading to the finish line.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>[fig.]</mark> <def>The last
or concluding part of any extended activity that has a definite
conclusion; the final phase of any activity; <as>as, the election was
neck-and-neck in the <ex>homestretch</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>home town</ent><br/
<ent>hometown</ent><br/
<mhw><hw>hometown</hw>, <hw>home town</hw></mhw> <pos>n.</pos> <def>the
town (or city) where a person was born or grew up or has his principal
residence; <as>as, he never went back to his <ex>hometown</ex>
again</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homeward</ent><br/
<hw>Home"ward</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Being in the
direction of home; <as>as, the <ex>homeward</ex> way</as>.</def></p>

<p><ent>Homewards</ent><br/
<ent>Homeward</ent><br/
<mhw>{ <hw>Home"ward</hw> <pr>(?)</pr>, <hw>Home"wards</hw>
<pr>(?)</pr>, }</mhw> <pos>adv.</pos> <ety>[AS.
<ets>h<amac/mweard</ets>.]</ety> <def>Toward home; in the direction of
one's house, town, or country.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homeward bound</b></col>, <cd>bound for home; going
homeward; <as>as, the <ex>homeward bound</ex> fleet</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>homework</ent><br/
<hw>homework</hw> <pos>n.</pos> <sn>1.</sn> <def>preparatory school work
done outside school (especially at home).</def><br/
<syn><b>Syn. --</b> prep, preparation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>[fig.]</mark> <def>Studies
or other preparatory work done prior to some activity; -- usually used
of preparations for activities of significance or consequence for the
performer; <as>as, the candidate didn't do her <ex>homework</ex> well
and was outclassed in the debate</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Paid work done at home, especially
piecework.</def><br/
[<source>PJC</source>]</p>

<p><ent>homeworker</ent><br/
<hw>homeworker</hw> <pos>n.</pos> <def>A person who works at home for
pay.</def><br/
[<source>PJC</source>]</p>

<p><ent>homey</ent><br/
<hw>hom"ey</hw> <pr>(h<omac/"m<ycr/)</pr>, <pos>adj.</pos> <def>having a
feeling of home; cozy and comfortable; <as>as, the <ex>homey</ex>
everyday atmosphere; a restaurant with a <ex>homey</ex>
atmosphere</as>.</def><br/
<syn><b>Syn. --</b> homelike, homely, homy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homicidal</ent><br/
<hw>Hom"i*ci`dal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
homicide; tending to homicide; murderous; <as>as, a <ex>homicidal</ex>
maniac</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homicide</ent><br/
<hw>Hom"i*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>homicidium</ets>, fr. <ets>homicida</ets> a man slayer;
<ets>homo</ets> man + <ets>caedere</ets> to cut, kill. See
<er>Homage</er>, and cf. <er>Concise</er>, <er>Shed</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>The killing of one human being by
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Homicide</xex> is of three kinds:
<xex>justifiable</xex>, as when the killing is performed in the exercise
of a right or performance of a duty; <xex>excusable</xex>, as when done,
although not as duty or right, yet without culpable or criminal intent;
and <xex>felonious</xex>, or involving what the law terms malice; the
latter may be either manslaughter or murder.
<au>Bouvier.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who kills another; a manslayer.</def>
<rj><au>Chaucer. Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homiform</ent><br/
<hw>Hom"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>homo</ets>
man + <ets>-form</ets>.]</ety> <def>In human form.</def>
<mark>[Obs.]</mark> <rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homilete</ent><br/
<hw>Hom"i*lete</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
homilist.</def></p>

<p><ent>Homiletical</ent><br/
<ent>Homiletic</ent><br/
<mhw>{ <hw>Hom`i*let"ic</hw> <pr>(?)</pr>, <hw>Hom`i*let"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/: cf. F.
<ets>homil<eacute/tique</ets>. See <er>Homily</er>.]</ety> <sn>1.</sn>
<def>Of or pertaining to familiar intercourse; social; affable;
conversable; companionable.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His virtues active, chiefly, and <qex>homiletical</qex>, not those
lazy, sullen ones of the cloister.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to homiletics; hortatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homiletics</ent><br/
<hw>Hom`i*let"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>homil<eacute/tique</ets>.]</ety> <def>The art of preaching; that
branch of theology which treats of homilies or sermons, and the best
method of preparing and delivering them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homilist</ent><br/
<hw>Hom"i*list</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who prepares
homilies; one who preaches to a congregation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homilite</ent><br/
<hw>Hom"i*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Gr. <?/ to be
in company with.]</ety> <fld>(Min.)</fld> <def>A borosilicate of iron
and lime, near datolite in form and composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homily</ent><br/
<hw>Hom"i*ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Homilies</plw> <pr>(#)</pr>.</plu> <ety>[LL. <ets>homilia</ets>,
Gr. <?/ communion, assembly, converse, sermon, fr. <?/ an assembly, fr.
<?/ same; cf. <?/ together, and <?/ crowd, cf. <?/ to press: cf. F.
<ets>hom<eacute/lie</ets>. See <er>Same</er>.]</ety> <sn>1.</sn> <def>A
discourse or sermon read or pronounced to an audience; a serious
discourse.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A serious or tedious exhortation in private on some
moral point, or on the conduct of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As I have heard my father<br/
Deal out in his long <qex>homilies</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Book of Homilies</b></col>. <cd>A collection of
authorized, printed sermons, to be read by ministers in churches, esp.
one issued in the time of Edward VI., and a second, issued in the reign
of Elizabeth; -- both books being certified to contain a <ldquo/godly
and wholesome doctrine.<rdquo/</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hominal</ent><br/
<hw>hominal</hw> <pos>adj.</pos> <def>Of humankind as a species; <as>as,
the <ex>hominal</ex> kingdom</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homing</ent><br/
<hw>Hom"ing</hw> <pr>(h<omac/m"<icr/ng)</pr>, <pos>p. a.</pos>
<def>Home-returning; -- used specifically of carrier pigeons.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homing pigeon</b></col>, <cd>any pigeon trained to return
home from a distance. Also called <altname>carrier pigeon</altname>.
Most are bred from the domestic pigeon <spn>Columba livia</spn>. Homing
pigeons are used for sending back messages or for flying races. By
carrying the birds away and releasing them at gradually increasing
distances from home, they may be trained to return with more or less
certainty and promptness from distances up to four or five hundred
miles. The birds typically do not stop on their way home, and may
average as much as 60 miles per hour on their return trip. If the
distance is increased much beyond 400 miles, the birds are unable to
cover it without stopping for a prolonged rest, and their return becomes
doubtful. The record for returnig from a distance is close to 1,200
miles. Homing pigeons are not bred for fancy points or special colors,
but for strength, speed, endurance, and intelligence or homing instinct.
Although used since ancient times, <ex>homing pigeons</ex> have been
largely displaced for practical purposes by radio and electronic
communications, but they are still used in some special situations at
the end of the 20th century. They were used in military operations as
recently as in World War II.</cd></cs><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>hominid</ent><br/
<ent>hominian</ent><br/
<mhw><hw>hominian</hw> <hw>hominid</hw></mhw> <pos>adj.</pos>
<def>characterizing the family <fam>Hominidae</fam>, which includes
<spn>Homo sapiens</spn> <varn>sapiens</varn> as well as extinct species
of manlike creatures.</def> [Narrower terms: <stype>human (vs. nonhuman)
</stype>] <source>WordNet 1.5</source>]</p>

<p><ent>hominid</ent><br/
<ent>hominian</ent><br/
<mhw><hw>hominian</hw>, <hw>hominid</hw></mhw> <pos>n.</pos> <def>Any
animal of the family <fam>Hominidae</fam>, including modern man as well
as extinct species of the genera <gen>Homo</gen> and
<gen>Australopithecus</gen>.</def><br/
<syn><b>Syn. --</b> homonid.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Hominidae</ent><br/
<hw>Hominidae</hw> <pos>prop. n.</pos> <def>The natural family of
primates including modern man and the extinct immediate ancestors of
man.</def><br/
<syn><b>Syn. --</b> family <fam>Hominidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hominine</ent><br/
<hw>hominine</hw> <pos>adj.</pos> <def>characteristic of
humankind.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hominoidea</ent><br/
<hw>Hominoidea</hw> <pos>prop. n.</pos> <def>A superfamily of mammals
including anthropoid apes and human beings.</def><br/
<syn><b>Syn. --</b> superfamily <fam>Hominoidea</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hominy</ent><br/
<hw>Hom"i*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From North American
Indian <ets>auh<uacute/minea</ets> parched corn.]</ety> <def>Maize
hulled and broken, and prepared for food by being boiled in water.</def>
<mark>[U.S.]</mark> <altsp>[Written also <asp>homony</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homish</ent><br/
<hw>Hom"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a home or a home
circle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Quiet, cheerful, <qex>homish</qex> hospital life.</q> <rj><qau>E.
E. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hommock</ent><br/
<hw>Hom"mock</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small eminence of a
conical form, of land or of ice; a knoll; a hillock. See
<er>Hummock</er>.</def> <rj><au>Bartram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hommocky</ent><br/
<hw>Hom"mock*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Filled with
hommocks; piled in the form of hommocks; -- said of ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homo-</ent><br/
<hw>Ho"mo-</hw> <pr>(?)</pr>. <def>A combining form from Gr.
<grk>"omo`s</grk>, <sig>one and the same</sig>, <sig>common</sig>,
<sig>joint</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homobasidiomycetes</ent><br/
<hw>Homobasidiomycetes</hw> <pos>n.</pos> <def>A category used in some
classification systems for various basidiomycetous fungi including e.g.
mushrooms and puffballs which are usually placed in the classes
<class>Gasteromycetes</class> and
<class>Hymenomycetes</class>.</def><br/
<syn><b>Syn. --</b> subclass Homobasidiomycetes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homocategoric</ent><br/
<hw>Ho`mo*cat`e*gor"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + <ets>categoric</ets>.]</ety> <fld>(Biol.)</fld>
<def>Belonging to the same category of individuality; -- a morphological
term applied to organisms so related.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homocentric</ent><br/
<hw>Ho`mo*cen"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/: <?/
the same + <?/ center: cf. F. <ets>homocentrique</ets>.]</ety>
<def>Having the same center.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homocercal</ent><br/
<hw>Ho`mo*cer"cal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + Gr. <?/ tail.]</ety> <fld>(Zool.)</fld>
<def>Having the tail nearly or quite symmetrical, the vertebral column
terminating near its base; -- opposed to
<xex>heterocercal</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homocercy</ent><br/
<hw>Ho"mo*cer`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The possession of a homocercal tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homocerebrin</ent><br/
<hw>Ho`mo*cer`e*brin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Homo-</ets> + <ets>rebrin</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A body similar to, or identical with,
cerebrin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homochromous</ent><br/
<hw>Ho`mo*chro"mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + Gr. <?/ color.]</ety> <fld>(Bot.)</fld>
<def>Having all the florets in the same flower head of the same
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodemic</ent><br/
<hw>Ho`mo*dem"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Homo-</ets>
+ 1st <ets>deme</ets>, 2.]</ety> <fld>(Biol.)</fld> <def>A morphological
term signifying development, in the case of multicellular organisms,
from the same unit deme or unit of the inferior orders of
individuality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodermic</ent><br/
<hw>Ho`mo*der"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Relating to homodermy; originating from the same germ
layer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodermy</ent><br/
<hw>Ho"mo*der`my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Homo-</ets>
+ <ets>-derm</ets>.]</ety> <fld>(Biol.)</fld> <def>Homology of the
germinal layers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodont</ent><br/
<hw>Hom"o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Homo-</ets> +
Gr. <?/, <?/, a tooth.]</ety> <fld>(Anat.)</fld> <def>Having all the
teeth similar in front, as in the porpoises; -- opposed to
<xex>heterodont</xex>.</def></p>

<p><ent>Homodromous</ent><br/
<ent>Homodromal</ent><br/
<mhw>{ <hw>Ho*mod"ro*mal</hw> <pr>(?)</pr>, <hw>Ho*mod"ro*mous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Homo-</ets> + Gr. <?/ a
course, running.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>Running in
the same direction; -- said of stems twining round a support, or of the
spiral succession of leaves on stems and their branches.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>Moving in the same direction; --
said of a lever or pulley in which the resistance and the actuating
force are both on the same side of the fulcrum or axis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodynamic</ent><br/
<hw>Ho`mo*dy*nam"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Homodynamous.</def> <rj><au>Quain.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodynamous</ent><br/
<hw>Ho`mo*dy"na*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Pertaining to, or involving, homodynamy; <as>as, successive or
<ex>homodynamous</ex> parts in plants and animals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homodynamy</ent><br/
<hw>Ho`mo*dy"na*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ of
like power; <?/ the same + <?/ power.]</ety> <fld>(Biol.)</fld> <def>The
homology of metameres. See <er>Metamere</er>.</def>
<rj><au>Gegenbaur.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeomeria</ent><br/
\'d8<hw>Ho`m<oe/*o*me"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
from Gr. <?/; <?/ like + <?/ part.]</ety> <def>The state or quality of
being homogeneous in elements or first principles; likeness or identity
of parts.</def></p>

<p><ent>Homoeomerical</ent><br/
<ent>Homoeomeric</ent><br/
<mhw>{ <hw>Ho`m<oe/*o*mer"ic</hw> <pr>(?)</pr>,
<hw>Ho`m<oe/*o*mer"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Pertaining to, or characterized by, sameness of parts; receiving or
advocating the doctrine of homogeneity of elements or first
principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeomerous</ent><br/
<hw>Ho`m<oe/*om"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Having the main artery of the leg parallel with
the sciatic nerve; -- said of certain birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeomery</ent><br/
<hw>Ho`m<oe/*om"e*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ like
+ <ets>-metry</ets>.]</ety> <def>Same as <er>Hom<oe/omeria</er>.</def>
<mark>[Obs.]</mark> <rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeomorphism</ent><br/
<hw>Ho`m<oe/*o*mor"phism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hom<oe/omorphous</er>.]</ety> <def>A near similarity of crystalline
forms between unlike chemical compounds. See
<er>Isomorphism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeomorphous</ent><br/
<hw>Ho`m<oe/*o*mor"phous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
of like form; <?/ like + <grk>morfh`</grk> form.]</ety> <def>Manifesting
hom<oe/omorphism.</def></p>

<p><ent>Homoeopathy</ent><br/
<ent>Homoeopathist</ent><br/
<ent>Homoeopathic</ent><br/
<mhw><hw>Ho`m<oe/*o*path"ic</hw>, <pos>a.</pos>,
<hw>Ho`m<oe/*op"a*thist</hw>, <pos>n.</pos>, <hw>Ho`m<oe/*op"a*thy</hw>,
<pos>n.</pos></mhw> <def>Same as <er>Homeopathic</er>,
<er>Homeopathist</er>, <er>Homeopathy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeothermal</ent><br/
<hw>Ho`m<oe/*o*ther"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Homoiothermal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoeozoic</ent><br/
<hw>Ho`m<oe/*o*zo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ like
+ <?/ life.]</ety> <fld>(Zool.)</fld> <def>Pertaining to, or including,
similar forms or kinds of life; <as>as, <ex>hom<oe/ozoic</ex> belts on
the earth's surface</as>.</def> <rj><au>E. Forbes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogamous</ent><br/
<hw>Ho*mog"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ married
together; <?/ the same + <?/ marriage.]</ety> <fld>(Bot.)</fld>
<def>Having all the flowers alike; -- said of such composite plants as
Eupatorium, and the thistels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogamy</ent><br/
<hw>Ho*mog"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The condition of being homogamous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogangliate</ent><br/
<hw>Ho`mo*gan"gli*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + <ets>gangliate</ets>.]</ety> <fld>(Zool.)</fld>
<def>Having the ganglia of the nervous system symmetrically arranged, as
in certain invertebrates; -- opposed to
<xex>heterogangliate</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogene</ent><br/
<hw>Ho"mo*gene</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>homog<egrave/ne</ets>.]</ety> <def>Homogeneous.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogeneal</ent><br/
<hw>Ho`mo*ge"ne*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Homogeneous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogenealness</ent><br/
<hw>Ho`mo*ge"ne*al*ness</hw>, <pos>n.</pos>
<def>Homogeneousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogeneity</ent><br/
<hw>Ho`mo*ge*ne"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>homog<eacute/n<eacute/it<eacute/</ets>.]</ety> <def>Same as
<er>Homogeneousness</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogeneous</ent><br/
<hw>Ho`mo*ge"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/; <?/
the same + <?/ race, kind: cf. F. <ets>homog<egrave/ne</ets>. See
<er>Same</er>, and <er>Kin</er>.]</ety> <sn>1.</sn> <def>Of the same
kind of nature; consisting of similar parts, or of elements of the like
nature; -- opposed to <xex>heterogeneous</xex>; <as>as,
<ex>homogeneous</ex> particles, elements, or principles;
<ex>homogeneous</ex> bodies.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Alg.)</fld> <def>Possessing the same number of
factors of a given kind; <as>as, a <ex>homogeneous</ex>
polynomial</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogeneousness</ent><br/
<hw>Ho`mo*ge"ne*ous*ness</hw>, <pos>n.</pos> <def>Sameness 9kind or
nature; uniformity of structure or material.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogenesis</ent><br/
<hw>Ho`mo*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Homo-</ets> + <ets>genesis</ets>.]</ety> <fld>(Biol.)</fld>
<def>That method of reproduction in which the successive generations are
alike, the offspring, either animal or plant, running through the same
cycle of existence as the parent; gamogenesis; -- opposed to
<xex>heterogenesis</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogenetic</ent><br/
<hw>Ho`mo*ge*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Homogenous; -- applied to that class of homologies which arise from
similarity of structure, and which are taken as evidences of common
ancestry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>homogenize</ent><br/
<hw>homogenize</hw> <pos>v. t.</pos> <sn>1.</sn> <def>To blend (a
collection of unlike elements) together so as to make the whole uniform
in character, composition, or function.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>To blend separated
liquids together so as to form a uniform emulsion which does not
separate out into its original constituents on standing; -- used
especially of milk; <as>as, most milk sold in cartons is pasteurized and
<ex>homogenized</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>homogenized</ent><br/
<hw>homogenized</hw> <pos>adj.</pos> <sn>1.</sn> <def>formed by blending
unlike elements, especially by reducing one element to particles and
dispersing them throughout another substance.</def>
<hascons>homogeneous</hascons><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>rendered homogeneous.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homogenous</ent><br/
<hw>Ho*mog"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Having a resemblance in structure, due to descent from a common
progenitor with subsequent modification; homogenetic; -- applied both to
animals and plants. See <er>Homoplastic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogeny</ent><br/
<hw>Ho*mog"e*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/ the
same + <?/ race, kind.]</ety> <sn>1.</sn> <def>Joint nature.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The correspondence of common
descent; -- a term used to supersede <xex>homology</xex> by Lankester,
who also used <xex>homoplasy</xex> to denote any superinduced
correspondence of position and structure in parts embryonically distinct
(other writers using the term <xex>homoplasmy</xex>). Thus, there is
<xex>homogeny</xex> between the fore limb of a mammal and the wing of a
bird; but the right and left ventricles of the heart in both are only in
<xex>homoplasy</xex> with each other, these having arisen independently
since the divergence of both groups from a univentricular
ancestor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogonous</ent><br/
<hw>Ho*mog"o*nous</hw>, <pos>a.</pos> <ety>[Gr. <?/. See
<er>Homogeneous</er>.]</ety> <fld>(Bot.)</fld> <def>Having all the
flowers of a plant alike in respect to the stamens and
pistils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homogony</ent><br/
<hw>Ho*mog"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The condition of having homogonous flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homograph</ent><br/
<hw>Hom"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"omo`grafos</grk> with the same letters; <grk>"omo`s</grk> the same
+ <grk>gra`fein</grk> to write.]</ety> <fld>(Philol.)</fld> <def>One of
two or more words identical in orthography, but having different
derivations and meanings; <as>as, <ex>fair</ex>, <pos>n.</pos>, a
market, and <ex>fair</ex>, <pos>a.</pos>, beautiful</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homographic</ent><br/
<hw>Ho`mo*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Employing a single and separate character to represent each sound;
-- said of certain methods of spelling words.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>Possessing the property of
homography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homography</ent><br/
<hw>Ho*mog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That
method of spelling in which every sound is represented by a single
character, which indicates that sound and no other.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>A relation between two figures,
such that to any point of the one corresponds one and but one point in
the other, and vise versa. Thus, a tangent line rolling on a circle cuts
two fixed tangents of the circle in two sets of points that are
homographic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoioptoton</ent><br/
\'d8<hw>Ho*moi`op*to"ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ in a like case; <?/ like + <?/ falling.]</ety>
<fld>(Rhet.)</fld> <def>A figure in which the several parts of a
sentence end with the same case, or inflection generally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>homoiotherm</ent><br/
<hw>homoiotherm</hw> <pos>n.</pos> <fld>(Biol.)</fld> <def>A
homoiothermal animal.</def><br/
<syn><b>Syn. --</b> homeotherm.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Homoiothermic</ent><br/
<ent>Homoiothermal</ent><br/
<mhw><hw>Ho*moi`o*ther"mal</hw>, <hw>Ho*moi`o*therm"ic</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ like + E.
<ets>thermal</ets>.]</ety> <fld>(Physiol.)</fld> <def>Maintaining a
uniform body temperature, usually above the ambient temperature;
h<ae/matothermal; homothermic; warm-blooded; -- applied to warm-bodied
animals such as birds and mammals, because they maintain a nearly
uniform temperature in spite of the great variations in the surrounding
air; in distinct from the <contr>cold-blooded</contr>
(<contr>poikilothermal</contr>) animals, whose body temperature follows
the variations in temperature of the surrounding medium.</def><br/
<syn><b>Syn. --</b> homeothermal, homeothermic, homothermal,
homothermic, homoiothermic.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>homoiothermy</ent><br/
<ent>homoiothermism</ent><br/
<mhw><hw>homoiothermism</hw>, <hw>homoiothermy</hw></mhw> <pos>n.</pos>
<fld>(Biol.)</fld> <def>The process or state of being
homoiothermal.</def><br/
<syn><b>Syn. --</b> homeothermism, homeothermy.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Homoiousian</ent><br/
<hw>Ho`moi*ou"si*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/,
of like substance; <grk>"o`moios</grk> + <grk>o'ysi`a</grk> the
substance, being, essence.]</ety> <fld>(Eccl. Hist.)</fld> <def>One of
the semi-Arians of the 4th century, who held that the Son was of like,
but not the same, essence or substance with the Father; -- opposed to
<xex>homoousian</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoiousian</ent><br/
<hw>Ho`moi*ou"si*an</hw>, <pos>a.</pos> <def>Of or pertaining to
Homoiousians, or their belief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologate</ent><br/
<hw>Ho*mol"o*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Homologated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Homologating</conjf>.]</vmorph> <ety>[LL.
<ets>homologatus</ets>, p. p. of <ets>homologare</ets> to homologate;
Gr. <?/ to assent, agree. See <er>Homologous</er>.]</ety> <fld>(Civ.
Law)</fld> <def>To approve; to allow; to confirm; <as>as, the court
<ex>homologates</ex> a proceeding</as>.</def>
<rj><au>Wheaton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologation</ent><br/
<hw>Ho*mol`o*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>homologation</ets>.]</ety> <fld>(Civ. & Scots Law)</fld>
<def>Confirmation or ratification (as of something otherwise null and
void), by a court or a grantor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homological</ent><br/
<hw>Ho`mo*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
homology; having a structural affinity proceeding from, or base upon,
that kind of relation termed <xex>homology</xex>.</def> --
<wordforms><wf>Ho`mo*log"ic*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologinic</ent><br/
<hw>Ho*mol`o*gin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or characterized by, homology; <as>as,
<ex>homologinic</ex> qualities, or differences</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologize</ent><br/
<hw>Ho*mol"o*gize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Biol.)</fld>
<def>To determine the homologies or structural relations of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologon</ent><br/
\'d8<hw>Ho*mol"o*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>See <er>Homologue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologoumena</ent><br/
\'d8<hw>Hom`o*lo*gou"me*na</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ things conceded, p. p. of <?/ to agree, admit,
concede. See <er>Homologous</er>.]</ety> <def>Those books of the New
Testament which were acknowledged as canonical by the early church; --
distinguished from <xex>antilegomena</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologous</ent><br/
<hw>Ho*mol"o*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
assenting, agreeing; <?/ the same + <?/ speech, discourse, proportion,
<?/ to say, speak.]</ety> <def>Having the same relative position,
proportion, value, or structure.</def> Especially: <sd>(a)</sd>
<fld>(Geom.)</fld> <def>Corresponding in relative position and
proportion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In similar polygons, the corresponding sides, angles, diagonals,
etc., are <qex>homologous</qex>.</q> <rj><qau>Davies & Peck (Math.
Dict.).</qau></rj></p>

<p><sd>(b)</sd> <fld>(Alg.)</fld> <def>Having the same relative
proportion or value, as the two antecedents or the two consequents of a
proportion.</def> <sd>(c)</sd> <fld>(Chem.)</fld> <def>Characterized by
homology; belonging to the same type or series; corresponding in
composition and properties. See <er>Homology</er>, 3.</def> <sd>(d)</sd>
<fld>(Biol.)</fld> <def>Being of the same typical structure; having like
relations to a fundamental type to structure; as, those bones in the
hand of man and the fore foot of a horse are <xex>homologous</xex> that
correspond in their structural relations, that is, in their relations to
the type structure of the fore limb in vertebrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homologous stimulus</b></col>. <fld>(Physiol.)</fld>
<cd>See under <er>Stimulus</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 702 --></p>

<p><ent>Homolographic</ent><br/
<hw>Hom`o*lo*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + Gr. <grk>"o`los</grk> whole + <ets>-graph</ets>
+ <ets>-ic</ets>; but cf. F. <ets>homalographique</ets>, Gr. <?/ even,
level.]</ety> <def>Preserving the mutual relations of parts, especially
as to size and form; maintaining relative proportion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homolographic projection</b></col>, <cd>a method of
constructing geographical charts or maps, so that the surfaces, as
delineated on a plane, have the same relative size as the real surfaces;
that is, so that the relative actual areas of the different countries
are accurately represented by the corresponding portions of the
map.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homologue</ent><br/
<hw>Hom"o*logue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>homologue</ets>. See <er>Homologous</er>.]</ety> <def>That which is
homologous to something else; <as>as, the corresponding sides, etc., of
similar polygons are the <ex>homologues</ex> of each other; the members
or terms of an homologous series in chemistry are the
<ex>homologues</ex> of each other; one of the bones in the hand of man
is the <ex>homologue</ex> of that in the paddle of a
whale.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homology</ent><br/
<hw>Ho*mol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
agreement. See <er>Homologous</er>.]</ety> <sn>1.</sn> <def>The quality
of being homologous; correspondence; relation; <as>as, the
<ex>homology</ex>of similar polygons</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Correspondence or relation in
type of structure in contradistinction to similarity of function; as,
the relation in structure between the leg and arm of a man; or that
between the arm of a man, the fore leg of a horse, the wing of a bird,
and the fin of a fish, all these organs being modifications of one type
of structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Homology</xex> indicates genetic relationship, and
according to Haeckel special homology should be defined in terms of
identity of embryonic origin. See <er>Homotypy</er>, and
<er>Homogeny</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>The correspondence or resemblance
of substances belonging to the same type or series; a similarity of
composition varying by a small, regular difference, and usually attended
by a regular variation in physical properties; <as>as, there is an
<ex>homology</ex> between methane, <chform>CH4</chform>, ethane,
<chform>C2H6</chform>, propane, <chform>C3H8</chform>, etc.</as>, all
members of the paraffin series. In an extended sense, the term is
applied to the relation between chemical elements of the same group;
<as>as, chlorine, bromine, and iodine are said to be in
<ex>homology</ex> with each other</as>. Cf.
<er>Heterology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>General homology</b></col> <fld>(Biol.)</fld>, <cd>the
higher relation which a series of parts, or a single part, bears to the
fundamental or general type on which the group is constituted.</cd>
<au>Owen.</au> -- <col><b>Serial homology</b></col> <fld>(Biol.)</fld>,
<cd>representative or repetitive relation in the segments of the same
organism, -- as in the lobster, where the parts follow each other in a
straight line or series.</cd> <au>Owen.</au> See <er>Homotypy</er>. --
<col><b>Special homology</b></col> <fld>(Biol.)</fld>, <cd>the
correspondence of a part or organ with those of a different animal, as
determined by relative position and connection.</cd>
<au>Owen.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homomallous</ent><br/
<hw>Ho*mom"al*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + Gr. <?/ a lock of wool.]</ety>
<fld>(Bot.)</fld> <def>Uniformly bending or curving to one side; -- said
of leaves which grow on several sides of a stem.</def></p>

<p><ent>Homomorphous</ent><br/
<ent>Homomorphic</ent><br/
<mhw>{ <hw>Ho`mo*mor"phic</hw> <pr>(?)</pr>, <hw>Ho`mo*mor"phous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ the same + <?/
shape.]</ety> <def>Characterized by homomorphism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homomorphism</ent><br/
<hw>Ho`mo*mor"phism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Homomorphous</er>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>Same
as <er>Homomorphy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The possession, in one species of
plants, of only one kind of flowers; -- opposed to
<xex>heteromorphism</xex>, <xex>dimorphism</xex>, and
<xex>trimorphism</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The possession of but one kind of
larv<ae/ or young, as in most insects.</def></p>

<p><-- 4. (Math) A special type of mapping of one mathematical set into
or onto another set . . . --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homomorphy</ent><br/
<hw>Ho"mo*mor`phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Homo-</ets> + Gr. <grk>morfh`</grk> form.]</ety>
<fld>(Biol.)</fld> <def>Similarity of form; resemblance in external
characters, while widely different in fundamental structure; resemblance
in geometric ground form. See <er>Homophyly</er>,
<er>Promorphology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homonomous</ent><br/
<hw>Ho*mon"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of or pertaining to homonomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homonomy</ent><br/
<hw>Ho*mon"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Homo-</ets>
+ Gr. <?/ law.]</ety> <fld>(Biol.)</fld> <def>The homology of parts
arranged on transverse axes.</def> <rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homonym</ent><br/
<hw>Hom"o*nym</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>homonyme</ets>. See <er>Homonymous</er>.]</ety> <def>A word having
the same sound as another, but differing from it in meaning; as the noun
<xex>bear</xex> and the verb <xex>bear</xex>.</def> <altsp>[Written also
<asp>homonyme</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homonymous</ent><br/
<hw>Ho*mon"y*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>homonymus</ets>, Gr. <?/; <?/ the same + <?/, for <?/ name; akin to
E. <ets>name</ets>.]</ety> <sn>1.</sn> <def>Having the same name or
designation; standing in the same relation; -- opposed to
<xex>heteronymous</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the same name or designation, but different
meaning or relation; hence, equivocal; ambiguous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homonymously</ent><br/
<hw>Ho*mon"y*mous*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In an
homonymous manner; so as to have the same name or relation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Equivocally; ambiguously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homonymy</ent><br/
<hw>Ho*mon"y*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf. F.
<ets>homonymie</ets>.]</ety> <sn>1.</sn> <def>Sameness of name or
designation; identity in relations.</def> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Homonymy</qex> may be as well in place as in persons.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sameness of name or designation of things or persons
which are different; ambiguity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoorgan</ent><br/
<hw>Ho`mo*<oum/r"gan</hw> <pr>(?)</pr>. <ety>[<ets>Homo-</ets> +
<ets>organ</ets>.]</ety> <def>Same as <er>Homoplast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoousian</ent><br/
<hw>Ho`mo*ou"si*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/
the same + <?/ being, essence, substance.]</ety> <fld>(Eccl.
Hist.)</fld> <def>One of those, in the 4th century, who accepted the
Nicene creed, and maintained that the Son had the same essence or
substance with the Father; -- opposed to
<xex>homoiousian</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoousian</ent><br/
<hw>Ho`mo*ou"si*an</hw>, <pos>a.</pos> <def>Of or pertaining to the
Homoousians, or to the doctrines they held.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>homophobia</ent><br/
<hw>hom`o*pho"bi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A strong
dislike or fear of homosexuals, especially to an unreasonable
degree.</def><br/
[<source>PJC</source>]</p>

<p><ent>homophobic</ent><br/
<hw>hom`o*pho"bic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disliking or
fearing homosexuals to an unreasonable degree.</def><br/
[<source>PJC</source>]</p>

<p><ent>Homophone</ent><br/
<hw>Hom"o*phone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>homophone</ets>. See <er>Homophonous</er>.]</ety> <sn>1.</sn>
<def>A letter or character which expresses a like sound with
another.</def> <rj><au>Gliddon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A word having the same sound as another, but
differing from it in meaning and usually in spelling; <as>as,
<xex>all</xex> and <xex>awl</xex>; <xex>bare</xex> and <xex>bear</xex>;
<xex>rite</xex>, <xex>write</xex>, <xex>right</xex>, and
<xex>wright</xex>.</as></def></p>

<p><ent>Homophonous</ent><br/
<ent>Homophonic</ent><br/
<mhw>{ <hw>Ho`mo*phon"ic</hw> <pr>(?)</pr>, <hw>Ho*moph"o*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/; <?/ the same + <?/
sound, tone: cf. F. <ets>homophone</ets>.]</ety> <sn>1.</sn>
<fld>(Mus.)</fld> <sd>(a)</sd> <def>Originally, sounding alike; of the
same pitch; unisonous; monodic.</def> <sd>(b)</sd> <def>Now used for
plain harmony, note against note, as opposed to <xex>polyphonic</xex>
harmony, in which the several parts move independently, each with its
own melody.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing the same sound by a different combination
of letters; <as>as, <ex>bay</ex> and <ex>bey</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>homophonous</ent><br/
<hw>ho*moph"o*nous</hw> <pos>adj.</pos> <def>Of or pertaining to a
homophone or homophony; <as>as, <ex>homophonous</ex>
words</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Homophony</ent><br/
<hw>Ho*moph"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf. F.
<ets>homophonie</ets>.]</ety> <sn>1.</sn> <def>Sameness of
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>Sameness of sound;
unison.</def> <sd>(b)</sd> <def>Plain harmony, as opposed to
<xex>polyphony</xex>. See <er>Homophonous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homophylic</ent><br/
<hw>Ho`mo*phyl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Relating to homophily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homophyly</ent><br/
<hw>Ho*moph"y*ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Homo-</ets>
+ Gr. <?/ a clan.]</ety> <fld>(Biol.)</fld> <def>That form of homology
due to common ancestry (phylogenetic homology), in opposition to
<xex>homomorphy</xex>, to which genealogic basis is wanting.</def>
<rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoplasmy</ent><br/
<hw>Ho"mo*plas`my</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Homo-</ets> + Gr. <?/ anything formed, fr. <?/ to form,
mold.]</ety> <fld>(Biol.)</fld> <def>Resemblance between different
plants or animals, in external shape, in general habit, or in organs,
which is not due to descent from a common ancestor, but to similar
surrounding circumstances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoplast</ent><br/
<hw>Hom"o*plast</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>One of the plastids composing the <xex>idorgan</xex> of Haeckel; --
also called <xex>homo<oum/rgan</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoplastic</ent><br/
<hw>Ho`mo*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + <ets>plastic</ets>.]</ety> <def>Of or
pertaining to homoplasty; <as>as, <ex>homoplastic</ex>organs;
<ex>homoplastic</ex> forms.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoplasty</ent><br/
<hw>Ho"mo*plas`ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Homo-</ets> + <ets>plasty</ets>.]</ety> <fld>(Biol.)</fld>
<def>The formation of homologous tissues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoplasy</ent><br/
<hw>Ho*mop"la*sy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Homo-</ets>
+ Gr. <?/ to form, mold.]</ety> <fld>(Biol.)</fld> <def>See
<er>Homogeny</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homopolic</ent><br/
<hw>Ho`mo*pol"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Homo-</ets>
+ <ets>pole</ets>.]</ety> <fld>(Biol.)</fld> <def>In promorphology,
pertaining to or exhibiting that kind of organic form, in which the
stereometric ground form is a pyramid, with <xex>similar poles</xex>.
See <er>Promorphology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homopter</ent><br/
<hw>Ho*mop"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the <suborder>Homoptera</suborder>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homoptera</ent><br/
\'d8<hw>Ho*mop"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ the same, like + <?/ wing.]</ety> <fld>(Zool.)</fld> <def>A
suborder of Hemiptera, in which both pairs of wings are similar in
texture, and do not overlap when folded, as in the cicada. See
<er>Hemiptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homopteran</ent><br/
<hw>Ho*mop"ter*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An homopter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homopterous</ent><br/
<hw>Ho*mop"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Homoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homostyled</ent><br/
<hw>Ho"mo*styled</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Homo-</ets>
+ <ets>style</ets>.]</ety> <fld>(Bot.)</fld> <def>Having only one form
of pistils; -- said of the flowers of some plants.</def>
<rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homosystemic</ent><br/
<hw>Ho`mo*sys*tem"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Homo-</ets> + <ets>systemic</ets>.]</ety> <fld>(Biol.)</fld>
<def>Developing, in the case of multicellular organisms, from the same
embryonic systems into which the secondary unit (gastrula or plant
enbryo) differentiates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotaxia</ent><br/
\'d8<hw>Ho`mo*tax"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>Same as <er>Homotaxis</er>.</def></p>

<p><ent>Homotaxic</ent><br/
<ent>Homotaxial</ent><br/
<mhw>{ <hw>Ho`mo*tax"i*al</hw> <pr>(?)</pr>, <hw>Ho`mo*tax"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Biol.)</fld> <def>Relating to
homotaxis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotaxis</ent><br/
\'d8<hw>Ho`mo*tax"is</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ the same + <?/ arrangement.]</ety> <fld>(Biol.)</fld> <def>Similarly
in arrangement of parts; -- the opposite of
<xex>heterotaxy</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotaxy</ent><br/
<hw>Ho"mo*tax`y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Homotaxis</er>.</def></p>

<p><ent>Homothermous</ent><br/
<ent>Homothermic</ent><br/
<mhw>{ <hw>Ho`mo*ther"mic</hw> <pr>(?)</pr>, <hw>Ho`mo*ther"mous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Homo-</ets> + Gr. <?/
heat.]</ety> <fld>(Physiol.)</fld> <def>Warm-blooded; homoiothermal;
h<ae/matothermal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotonous</ent><br/
<hw>Ho*mot"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>homotonus</ets>, Gr. <?/; <?/ the same + <?/ tone.]</ety> <def>Of
the same tenor or tone; equable; without variation.</def></p>

<p><ent>Homotropous</ent><br/
<ent>Homotropal</ent><br/
<mhw>{ <hw>Ho*mot"ro*pal</hw> <pr>(?)</pr>, <hw>Ho*mot"ro*pous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/; <?/ the same + <?/
turn, fr. <?/ to turn: cf. F. <ets>homotrope</ets>.]</ety> <sn>1.</sn>
<def>Turned in the same direction with something else.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having the radicle of the seed
directed towards the hilum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotypal</ent><br/
<hw>Ho"mo*ty`pal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of the same type of structure; pertaining to a homotype; <as>as,
<ex>homotypal</ex> parts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotype</ent><br/
<hw>Hom"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Homo-</ets> +
<ets>-type</ets>.]</ety> <fld>(Biol.)</fld> <def>That which has the same
fundamental type of structure with something else; thus, the right arm
is the <xex>homotype</xex> of the right leg; one arm is the
<xex>homotype</xex> of the other, etc.</def> <rj><au>Owen.</au></rj></p>

<p><ent>Homotypical</ent><br/
<ent>Homotypic</ent><br/
<mhw>{ <hw>Ho`mo*typ"ic</hw> <pr>(?)</pr>, <hw>Ho`mo*typ"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Biol.)</fld> <def>Same as
<er>Homotypal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homotypy</ent><br/
<hw>Ho"mo*ty`py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Homotype</er>.]</ety> <fld>(Biol.)</fld> <def>A term suggested by
Haeckel to be instead of <xex>serial homology</xex>. See
<er>Homotype</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Homunculus</ent><br/
\'d8<hw>Ho*mun"cu*lus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Homunculi</plw> <pr>(#)</pr>.</plu> <ety>[L.,
dim. of <ets>homo</ets> man.]</ety> <def>A little man; a dwarf; a
manikin.</def> <rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hond</ent><br/
<hw>Hond</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hand.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hone</ent><br/
<hw>Hone</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. F.
<ets>honger</ets> to grumble. <root/37.]</ety> <def>To grumble; pine;
lament; long.</def> <mark>[Dial.Eng. & Southern U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hone</ent><br/
<hw>Hone</hw>, <pos>n.</pos> <ety>[Cf. Icel. <ets>h<umac/n</ets> a
knob.]</ety> <def>A kind of swelling in the cheek.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hone</ent><br/
<hw>Hone</hw>, <pos>n.</pos> <ety>[AS. <ets>h<amac/n</ets>; akin to
Icel. <ets>hein</ets>, OSw. <ets>hen</ets>; cf. Skr.
<ets><cced/<amac/<nsdot/a</ets>, also <ets><cced/<omac/</ets>,
<ets><cced/i</ets>, to sharpen, and E. <ets>cone</ets>. <root/38,
228.]</ety> <def>A stone of a fine grit, or a slab, as of metal, covered
with an abrading substance or powder, used for sharpening cutting
instruments, and especially for setting razors; an oilstone.</def>
<rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hone slate</b></col><cd>See <er>Polishing
slate</er>.</cd> -- <col><b>Hone stone</b></col>, <cd>one of several
kinds of stone used for hones. See <er>Novaculite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hone</ent><br/
<hw>Hone</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Honed</conjf> <pr>(h<omac/nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Honing</conjf>.]</vmorph> <sn>1.</sn> <def>To sharpen on, or
with, a hone; to rub on a hone in order to sharpen; <as>as, to
<ex>hone</ex> a razor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to render more precise or more effective; <as>as, to
<ex>hone</ex> one's skills</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Honest</ent><br/
<hw>Hon"est</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>honest</ets>, <ets>onest</ets>, OF. <ets>honeste</ets>,
<ets>oneste</ets>, F. <ets>honn<ecir/te</ets>, L. <ets>honestus</ets>,
fr. <ets>honos</ets>, <ets>honor</ets>, honor. See
<er>Honor</er>.]</ety> <sn>1.</sn> <def>Decent; honorable; suitable;
becoming.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Belong what <qex>honest</qex> clothes you send forth to
bleaching!</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by integrity or fairness and
straightforwardness in conduct, thought, speech, etc.; upright; just;
equitable; trustworthy; truthful; sincere; free from fraud, guile, or
duplicity; not false; -- said of persons and acts, and of things to
which a moral quality is imputed; <as>as, an <ex>honest</ex> judge or
merchant; an <ex>honest</ex> statement; an <ex>honest</ex> bargain; an
<ex>honest</ex> business; an <ex>honest</ex> book; an <ex>honest</ex>
confession.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>An <qex>honest</qex> man's the noblest work of God.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An <qex>honest</qex> physician leaves his patient when he can
contribute no farther to his health.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Look ye out among you seven men of <qex>honest</qex> report.</q>
<rj><qau>Acts vi. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Provide things <qex>honest</qex> in the sight of all men.</q>
<rj><qau>Rom. xii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Open; frank; <as>as, an <ex>honest</ex>
countenance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Chaste; faithful; virtuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wives may be merry, and yet <qex>honest</qex> too.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Upright; ingenuous; honorable; trusty; faithful;
equitable; fair; just; rightful; sincere; frank; candid;
genuine.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honest</ent><br/
<hw>Hon"est</hw>, <pos>v. t.</pos> <ety>[L. <ets>honestare</ets> to
clothe or adorn with honor: cf. F. <ets>honester</ets>. See
<er>Honest</er>, <pos>a.</pos>]</ety> <def>To adorn; to grace; to honor;
to make becoming, appropriate, or honorable.</def> <mark>[Obs.]</mark>
<rj><au>Abp. Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honestation</ent><br/
<hw>Hon`es*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
honesting; grace; adornment.</def> <mark>[Obs.]</mark> <rj><au>W.
Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honestetee</ent><br/
<hw>Ho*nes"te*tee</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Honesty;
honorableness.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honestly</ent><br/
<hw>Hon"est*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>Honorably; becomingly; decently.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In an honest manner; <as>as, a contract
<ex>honestly</ex> made; to live <ex>honestly</ex>; to speak
<ex>honestly</ex>.</as></def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To come honestly by</b></col>. <sd>(a)</sd> <cd>To get
honestly.</cd> <sd>(b)</sd> <cd>A circumlocution for <xex>to
inherit</xex>; as, <xex>to come honestly by</xex> a feature, a mental
trait, a peculiarity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honesty</ent><br/
<hw>Hon"es*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>honeste</ets>, <ets>oneste</ets>, honor, OF.
<ets>honest<eacute/</ets>, <ets>onest<eacute/</ets> (cf. F.
<ets>honn<ecir/tet<eacute/</ets>), L. <ets>honestas</ets>. See
<er>Honest</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>Honor;
honorableness; dignity; propriety; suitableness; decency.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She derives her <qex>honesty</qex> and achieves her goodness.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality or state of being honest; probity;
fairness and straightforwardness of conduct, speech, etc.; integrity;
sincerity; truthfulness; freedom from fraud or guile.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That we may lead a quiet and peaceable life in all godliness and
<qex>honesty</qex>.</q> <rj><qau>1 Tim. ii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Chastity; modesty.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To lay . . . siege to the <qex>honesty</qex> of this Ford's
wife.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>Satin flower; the name of two
cruciferous herbs having large flat pods, the round shining partitions
of which are more beautiful than the blossom; -- called also
<altname>lunary</altname> and <altname>moonwort</altname>. <spn>Lunaria
biennis</spn> is common honesty; <spn>Lunaria rediva</spn> is perennial
honesty.</def></p>

<p><syn><b>Syn.</b> -- Integrity; probity; uprightness; trustiness;
faithfulness; honor; justice; equity; fairness; candor; plain-dealing;
veracity; sincerity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honewort</ent><br/
<hw>Hone"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An umbelliferous plant of the genus <gen>Sison</gen> (<spn>Sison
Amomum</spn>); -- so called because used to cure a swelling called a
<xex>hone</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honey</ent><br/
<hw>Hon"ey</hw> <pr>(h<ucr/n"<ycr/)</pr>, <pos>n.</pos> <ety>[OE.
<ets>honi</ets>, <ets>huni</ets>, AS. <ets>hunig</ets>; akin to OS.
<ets>honeg</ets>, D. & G. <ets>honig</ets>, OHG. <ets>honag</ets>,
<ets>honang</ets>, Icel. <ets>hunang</ets>, Sw. <ets>h<aring/ning</ets>,
Dan. <ets>honning</ets>, cf. Gr. <grk>ko`nis</grk> dust, Skr.
<ets>ka<nsdot/a</ets> grain.]</ety> <sn>1.</sn> <def>A sweet viscid
fluid, esp. that collected by bees from flowers of plants, and deposited
in the cells of the honeycomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is sweet or pleasant, like
honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>honey</qex> of his language.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Sweet one; -- a term of endearment.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Honey</qex>, you shall be well desired in Cyprus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Honey</xex> is often used adjectively or as the
first part of compound; as, <xex>honey</xex>dew or <xex>honey</xex> dew;
<xex>honey</xex> guide or <xex>honey</xex>guide; <xex>honey</xex> locust
or <xex>honey</xex>-locust.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Honey ant</b></col> <fld>(Zool.)</fld>, <cd>a small ant
(<spn>Myrmecocystus melliger</spn>), found in the Southwestern United
States, and in Mexico, living in subterranean formicares. There are
larger and smaller ordinary workers, and others, which serve as
receptacles or cells for the storage of honey, their abdomens becoming
distended to the size of a currant. These, in times of scarcity,
regurgitate the honey and feed the rest.</cd> -- <col><b>Honey
badger</b></col> <fld>(Zool.)</fld>, <cd>the ratel.</cd> --
<col><b>Honey bear</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Kinkajou</er>.</cd> -- <col><b>Honey buzzard</b></col>
<fld>(Zool.)</fld>, <cd>a bird related to the kites, of the genus
<gen>Pernis</gen>. The European species is <spn>Pernis apivorus</spn>;
the Indian or crested honey buzzard is <spn>Pernis ptilorhyncha</spn>.
They feed upon honey and the larv<ae/ of bees. Called also <altname>bee
hawk</altname>, <altname>bee kite</altname>.</cd> -- <col><b>Honey
guide</b></col> <fld>(Zool.)</fld>, <cd>one of several species of small
birds of the family <fam>Indicatorid<ae/</fam>, inhabiting Africa and
the East Indies. They have the habit of leading persons to the nests to
wild bees. Called also <altname>honeybird</altname>, and
<altname>indicator</altname>.</cd> -- <col><b>Honey harvest</b></col>,
<cd>the gathering of honey from hives, or the honey which is
gathered.</cd> <au>Dryden.</au> -- <col><b>Honey kite</b></col>.
<fld>(Zool.)</fld> <cd>See <cref>Honey buzzard</cref> (above).</cd> --
<col><b>Honey locust</b></col> <fld>(Bot.)</fld>, <cd>a North American
tree (<spn>Gleditschia triacanthos</spn>), armed with thorns, and having
long pods with a sweet pulp between the seeds.</cd> -- <col><b>Honey
month</b></col>. <cd>Same as <er>Honeymoon</er>.</cd> -- <col><b>Honey
weasel</b></col> <fld>(Zool.)</fld>, <cd>the ratel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 703 --></p>

<p><ent>Honey</ent><br/
<hw>Hon"ey</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Honeyed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Honeying</conjf>.]</vmorph> <def>To be gentle, agreeable, or
coaxing; to talk fondly; to use endearments; also, to be or become
obsequiously courteous or complimentary; to fawn.</def>
<ldquo/<xex>Honeying</xex> and making love.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Rough to common men,<br/
But <qex>honey</qex> at the whisper of a lord.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honey</ent><br/
<hw>Hon"ey</hw>, <pos>v. t.</pos> <def>To make agreeable; to cover or
sweeten with, or as with, honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Canst thou not <qex>honey</qex> me with fluent speech?</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honey-bag</ent><br/
<hw>Hon"ey-bag`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The receptacle for honey in a honeybee.</def> <rj><au>Shak.
Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeybee</ent><br/
<hw>Hon"ey*bee`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any bee of the genus <gen>Apis</gen>, which lives in communities
and collects honey, esp. the common domesticated hive bee (<spn>Apis
mellifica</spn>), the Italian bee (<spn>Apis ligustica</spn>), and the
Arabian bee (<spn>Apis fasciata</spn>). The two latter are by many
entomologists considered only varieties of the common hive bee. Each
swarm of bees consists of a large number of workers (barren females),
with, ordinarily, one queen or fertile female, but in the swarming
season several young queens, and a number of males or drones, are
produced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeyberry</ent><br/
<hw>Hon"ey*ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>-berries</plw>.</plu> <def>The fruit of either of two trees having
sweetish berries: <it>(a)</it> An Old World hackberry (<spn>Celtis
australis</spn>). <it>(b)</it> In the West Indies, the genip
(<spn>Melicocca bijuga</spn>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Honeybird</ent><br/
<hw>Hon"ey*bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The honey guide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeycomb</ent><br/
<hw>Hon"ey*comb`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hunigcamb</ets>. See <er>Honey</er>, and 1st <er>Comb</er>.]</ety>
<sn>1.</sn> <def>A mass of hexagonal waxen cells, formed by bees, and
used by them to hold their honey and their eggs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any substance, as a casting of iron, a piece of
worm-eaten wood, or of triple, etc., perforated with cells like a
honeycomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Honeycomb moth</b></col> <fld>(Zool.)</fld>, <cd>the wax
moth.</cd> -- <col><b>Honeycomb stomach</b></col>. <fld>(Anat.)</fld>
<cd>See <er>Reticulum</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeycombed</ent><br/
<hw>Hon"ey*combed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed or
perforated like a honeycomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Each bastion was <qex>honeycombed</qex> with casements.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>honey creeper</ent><br/
<ent>honeycreeper</ent><br/
<mhw><hw>honeycreeper</hw>, <hw>honey creeper</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>Any of a number of small to medium-sized finches of the
Hawaiian islands belonging to the subfamily
<fam>Drepanidae</fam>.</def><br/
<syn><b>Syn. --</b> Hawaiian honeycreeper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>any of numerous species of small, bright, colored,
passerine birds of the family <fam>C<oe/rebid<ae/</fam>, related to the
tanagers and wood warblers, abundant in Central and South America; they
are songbirds with a curved bill for sucking nectar.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Honeydew</ent><br/
<hw>Hon"ey*dew`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
sweet, saccharine substance, found on the leaves of trees and other
plants in small drops, like dew. Two substances have been called by this
name; one exuded from the plants, and the other secreted by certain
insects, esp. aphids.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of tobacco moistened with molasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A <er>honeydew melon</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Honeydew melon</ent><br/
<hw>Hon"ey*dew` mel"on</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A type of
winter melon (<spn>Cucumis melo</spn> <varn>inodorus</varn>) related to
the muskmelon (<spn>Cucumis melo</spn> <varn>reticulatus</varn>), but
having a smooth pale yellowish-green rind and sweet, juicy, light green
flesh. It is slightly ovoid in shape, commonly about 8 to 10 inches long
on the long axis.</def><br/
[<source>PJC</source>]</p>

<p><ent>Honeyed</ent><br/
<hw>Hon"eyed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Covered
with honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sweet, <as>as, <ex>honeyed</ex> words</as>.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>honey-eater</ent><br/
<ent>honey eater</ent><br/
<mhw><hw>honey eater</hw>, <hw>honey-eater</hw></mhw> <pos>n.</pos>
<def>One of numerous species of small passerine birds of the family
<fam>Meliphagid<ae/</fam> having tongue and bill adapted for extracting
nectar, abundant in Australia and Oceania; -- called also
<altname>honeysucker</altname>.</def><br/
<syn><b>Syn. --</b> honeysucker.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>honey flower</ent><br/
<ent>honeyflower</ent><br/
<mhw><hw>honeyflower</hw>, <hw>honey flower</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <fld>(Bot.)</fld> <def>An erect bushy shrub (<spn>Lambertia
formosa</spn>) of eastern Australia having terminal clusters of red
flowers yielding much nectar.</def><br/
<syn><b>Syn. --</b> mountain devil, <spn>Lambertia
formosa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The Australian shrub (<spn>Protea
mellifera</spn>) whose flowers yield honey copiously.</def><br/
<syn><b>Syn. --</b> <spn>Protea mellifera</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld>, <def>An evergreen shrub of the genus
<gen>Melianthus</gen>, a native of the Cape of Good Hope. The flowers
yield much honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeyless</ent><br/
<hw>Hon"ey*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of
honey.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeymoon</ent><br/
<hw>Hon"ey*moon`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
first month after marriage.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vacation taken together by a newly married couple,
usually including a trip away from home.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <mark>[fig.]</mark> <def>Any
initial period of harmony after two or more people or organizations
begin working together; <as>as, the usual <ex>honeymoon</ex> for a newly
elected president was cut short by resumption of partisan sniping over
the budget</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Honey-mouthed</ent><br/
<hw>Hon"ey-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Soft to sweet
in speech; persuasive.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeystone</ent><br/
<hw>Hon"ey*stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mellite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeysucker</ent><br/
<hw>Hon"ey*suck`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Honey eater</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeysuckle</ent><br/
<hw>Hon"ey*suc`kle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>hunis<umac/ge</ets> privet. See <er>Honey</er>, and
<er>Suck</er>.]</ety> <fld>(Bot.)</fld> <def>One of several species of
flowering plants, much admired for their beauty, and some for their
fragrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The honeysuckles are properly species of the genus
<gen>Lonicera</gen>; as, <spn>Lonicera Caprifolium</spn>, and
<spn>Lonicera Japonica</spn>, the commonly cultivated fragrant kinds;
<spn>Lonicera Periclymenum</spn>, the fragrant woodbine of England;
<spn>Lonicera grata</spn>, the American woodbine, and <spn>Lonicera
sempervirens</spn>, the red-flowered trumpet honeysuckle. The European
fly honeysuckle is <spn>Lonicera Xylosteum</spn>; the American,
<spn>Lonicera ciliata</spn>. The American Pinxter flower (<spn>Azalea
nudiflora</spn>) is often called <ex>honeysuckle</ex>, or <xex>false
honeysuckle</xex>. The name <stype>Australian honeysuckle</stype> is
applied to one or more trees of the genus <gen>Banksia</gen>. See
<cref>French honeysuckle</cref>, under <er>French</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeysuckled</ent><br/
<hw>Hon"ey*suc`kled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered with
honeysuckles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honey-sweet</ent><br/
<hw>Hon"ey-sweet`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sweet as
honey.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honey-tongued</ent><br/
<hw>Hon"ey-tongued`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sweet
speaking; persuasive; seductive.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeyware</ent><br/
<hw>Hon"ey*ware`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Badderlocks</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honeywort</ent><br/
<hw>Hon"ey*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A European plant of the genus <gen>Cerinthe</gen>, whose flowers
are very attractive to bees.</def> <rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hong</ent><br/
<hw>Hong</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chinese <ets>hang</ets>,
Canton dialect <ets>hong</ets>, a mercantile house, factory.]</ety>
<def>A mercantile establishment or factory for foreign trade in China,
as formerly at Canton; a succession of offices connected by a common
passage and used for business or storage.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hong merchant</b></col>, <cd>one of the few Chinese
merchants who, previous to the treaty of 1842, formed a guild which had
the exclusive privilege of trading with foreigners.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hong</ent><br/
<hw>Hong</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To hang.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honied</ent><br/
<hw>Hon"ied</hw> <pr>(h<ucr/n"<esl/d)</pr>, <pos>a.</pos> <def>See
<er>Honeyed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honiton lace</ent><br/
<hw>Hon"i*ton lace`</hw> <pr>(?)</pr>. <def>A kind of pillow lace,
remarkable for the beauty of its figures; -- so called because chiefly
made in <etsep>Honiton</etsep>, England.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honk</ent><br/
<hw>Honk</hw> <pr>(h<ocr/<nsm/k)</pr>, <pos>n.</pos> <ety>[Of imitative
origin.]</ety> <fld>(Zool.)</fld> <def>The cry of a wild goose.</def> --
<wordforms><wf>Honk"ing</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honk</ent><br/
<hw>Honk</hw> <pr>(h<ocr/<nsm/k)</pr>, <pos>n.</pos> <sn>1.</sn> <def>To
make a sound like the honk of a goose.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>To sound the horn on
an automobile or other motor vehicle.</def><br/
[<source>PJC</source>]</p>

<p><ent>honker</ent><br/
<hw>honk"er</hw> <pr>(h<ocr/<nsm/k"<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The nose; -- an informal terms used in the U. S.</def>
<wns>[wns=1]</wns> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> beak, hooter, nozzle, snoot, snout,
schnozzle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Something that honks.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Specif.</specif> <def>The common grayish-brown
wild goose (<spn>Branta canadensis</spn>) of North America; the Canada
goose.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> Canada goose, Canadian goose, <spn>Branta
canadensis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>honky</ent><br/
<hw>honky</hw> <pos>n.</pos> <sn>1.</sn> <def>A white (caucasian)
person; -- a term used by some African-Americans, intended to be
disparaging and often taken as offensive.</def> <altsp>[Also spelled
<asp>honkie</asp> and <asp>honkey</asp>.]</altsp><br/
<syn><b>Syn. --</b> whitey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>honky-tonk</ent><br/
<hw>honky-tonk</hw> <pos>n.</pos> <sn>1.</sn> <def>a cheap drinking and
dancing establishment; a cheap and tawdry nightclub.</def><br/
<syn><b>Syn. --</b> barrelhouse.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A district in which honky-tonks{1} are
found.</def><br/
[<source>PJC</source>]</p>

<p><ent>honky-tonk</ent><br/
<hw>honky-tonk</hw> <pos>a.</pos> <def>Pertaining to or resembling a
honky-tonk.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Music)</fld> <def>Pertaining to a style of ragtime
piano music having a melody embellished with chords and syncopated
rhythms, accompanied by a bass in strict two-four or four-four time. It
is often played on an upright piano having its strings muffled to
produce a tinny sound; <as>as, a <ex>honky-tonk</ex> piano</as>.</def>
<au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>Honor</ent><br/
<hw>Hon"or</hw> <pr>(<ocr/n"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>honor</ets>, <ets>honour</ets>, <ets>onour</ets>, <ets>onur</ets>,
OF. <ets>honor</ets>, <ets>onor</ets>, <ets>honur</ets>,
<ets>onur</ets>, <ets>honour</ets>, <ets>onour</ets>, F.
<ets>honneur</ets>, fr. L. <ets>honor</ets>, <ets>honos</ets>.]</ety>
<altsp>[Written also <asp>honour</asp>.]</altsp> <sn>1.</sn> <def>Esteem
due or paid to worth; high estimation; respect; consideration;
reverence; veneration; manifestation of respect or reverence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A prophet is not without <qex>honor</qex>, save in his own
country.</q> <rj><qau>Matt. xiii. 57.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which rightfully attracts esteem, respect, or
consideration; self-respect; dignity; courage; fidelity; especially,
excellence of character; high moral worth; virtue; nobleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Godlike erect, with native <qex>honor</qex> clad.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Purity; chastity; -- a term applied mostly to women,
but becoming uncommon in usage.</def><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><q>If she have forgot<br/
<qex>Honor</qex> and virtue.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A nice sense of what is right, just, and true, with
course of life correspondent thereto; strict conformity to the duty
imposed by conscience, position, or privilege; integrity; uprightness;
trustworthness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Say, what is <qex>honor</qex>? 'T is the finest sense<br/
Of justice which the human mind can frame,<br/
Intent each lurking frailty to disclaim,<br/
And guard the way of life from all offense<br/
Suffered or done.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I could not love thee, dear, so much,<br/
Loved I not <qex>honor</qex> more.</q> <rj><qau>Lovelace.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That to which esteem or consideration is paid;
distinguished position; high rank.</def> <ldquo/Restored me to my
<xex>honors</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have given thee . . . both riches, and <qex>honor</qex>.</q>
<rj><qau>1 Kings iii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou art clothed with <qex>honor</qex> and majesty.</q>
<rj><qau>Ps. civ. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Fame; reputation; credit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some in their actions do woo, and affect <qex>honor</qex> and
reputation.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If my <qex>honor</qex> is meant anything distinct from conscience,
't is no more than a regard to the censure and esteem of the world.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A token of esteem paid to worth; a mark of respect;
a ceremonial sign of consideration; <as>as, he wore an <ex>honor</ex> on
his breast; military <ex>honors</ex>; civil <ex>honors</ex>.</as></def>
<ldquo/Their funeral <xex>honors</xex>.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A cause of respect and fame; a glory; an excellency;
an ornament; <as>as, he is an <ex>honor</ex> to his
nation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A title applied to the holders of certain honorable
civil offices, or to persons of rank; <as>as, His <ex>Honor</ex> the
Mayor</as>. See Note under <er>Honorable</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Feud. Law)</fld> <def>A seigniory or lordship held
of the king, on which other lordships and manors depended.</def>
<rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <pluf>pl.</pluf> <def>Academic or university prizes or
distinctions; <as>as, <ex>honors</ex> in classics</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <pluf>pl.</pluf> <fld>(Whist)</fld> <def>The ace, king,
queen, and jack of trumps. The ten and nine are sometimes called
<contr>Dutch honors</contr>.</def> <rj><au>R. A. Proctor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Affair of honor</b></col>, <cd>a dispute to be decided by
a duel, or the duel itself.</cd> -- <col><b>Court of honor</b></col>,
<cd>a court or tribunal to investigate and decide questions relating to
points of honor; as a court of chivalry, or a military court to
investigate acts or omissions which are unofficerlike or ungentlemanly
in their nature.</cd> -- <col><b>Debt of honor</b></col>, <cd>a debt
contracted by a verbal promise, or by betting or gambling, considered
more binding than if recoverable by law.</cd> -- <col><b>Honor
bright!</b></col> An assurance of truth or fidelity.
<mark>[Colloq.]</mark> -- <col><b>Honor court</b></col> <fld>(Feudal
Law)</fld>, <cd>one held in an honor or seignory.</cd> -- <col><b>Honor
point</b></col>. <fld>(Her.)</fld> <cd>See <er>Escutcheon</er>.</cd> --
<col><b>Honors of war</b></col> <fld>(Mil.)</fld>, <cd>distinctions
granted to a vanquished enemy, as of marching out from a camp or town
armed, and with colors flying.</cd> -- <mcol><col><b>Law of
honor</b></col> <it>or</it> <col><b>Code of honor</b></col></mcol>,
<cd>certain rules by which social intercourse is regulated among persons
of fashion, and which are founded on a regard to reputation.</cd>
<au>Paley.</au> -- <col><b>Maid of honor</b></col>, <sd>(a)</sd> <cd>a
lady of rank, whose duty it is to attend the queen when she appears in
public.</cd> <sd>(b)</sd> <cd>the bride's principle attendant at a
wedding, if unmarried. If married, she is referred to as the <col>matron
of honor</col>.</cd> -- <col><b>On one's honor</b></col>, <cd>on the
pledge of one's honor; as, the members of the House of Lords in Great
Britain, are not under oath, but give their statements or verdicts
<xex>on their honor</xex>.</cd> -- <col><b>Point of honor</b></col>,
<cd>a scruple or nice distinction in matters affecting one's honor; as,
he raised a <xex>point of honor</xex>.</cd> -- <col><b>To do the
honors</b></col>, <cd>to bestow honor, as on a guest; to act as host or
hostess at an entertainment.</cd> <ldquo/To <xex>do the honors</xex> and
to give the word.<rdquo/ <au>Pope.</au> -- <col><b>To do one
honor</b></col>, <cd>to confer distinction upon one.</cd> -- <col><b>To
have the honor</b></col>, <cd>to have the privilege or distinction.</cd>
-- <col><b>Word of honor</b></col>, <cd>an engagement confirmed by a
pledge of honor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honor</ent><br/
<hw>Hon"or</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Honored</conjf> <pr>(<ocr/n"<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Honoring</conjf>.]</vmorph> <ety>[OE.
<ets>honouren</ets>, <ets>onouren</ets>, OF. <ets>honorer</ets>,
<ets>honourer</ets>, F. <ets>honorer</ets>, fr. L. <ets>honorare</ets>,
fr. <ets>honor</ets>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To regard or
treat with honor, esteem, or respect; to revere; to treat with deference
and submission; when used of the Supreme Being, to reverence; to adore;
to worship.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Honor</qex> thy father and thy mother.</q> <rj><qau>Ex. xx.
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That all men should <qex>honor</qex> the Son, even as they
<qex>honor</qex> the Father.</q> <rj><qau>John v. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a custom<br/
More <qex>honor'd</qex> in the breach than the observance.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dignify; to raise to distinction or notice; to
bestow honor upon; to elevate in rank or station; to ennoble; to exalt;
to glorify; hence, to do something to honor; to treat in a complimentary
manner or with civility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus shall it be done to the man whom the king delighten to
<qex>honor</qex>.</q> <rj><qau>Esther vi. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The name of Cassius <qex>honors</qex> this corruption.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>To accept and pay when due;
<as>as, to <ex>honor</ex>a bill of exchange</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honorable</ent><br/
<hw>Hon"or*a*ble</hw> <pr>(<ocr/n"<etil/r*<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[F. <ets>honorable</ets>, L.
<ets>honorabilis</ets>.]</ety> <sn>1.</sn> <def>Worthy of honor; fit to
be esteemed or regarded; estimable; illustrious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy name and <qex>honorable</qex> family.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>High-minded; actuated by principles of honor, or a
scrupulous regard to probity, rectitude, or reputation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Proceeding from an upright and laudable cause, or
directed to a just and proper end; not base; irreproachable; fair;
<as>as, an <ex>honorable</ex> motive</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is this proceeding just and <qex>honorable</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Conferring honor, or produced by noble
deeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Honorable</qex> wounds from battle brought.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Worthy of respect; regarded with esteem; to be
commended; consistent with honor or rectitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Marriage is <qex>honorable</qex> in all.</q> <rj><qau>Heb. xiii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Performed or accompanied with marks of honor, or
with testimonies of esteem; <as>as, an <ex>honorable</ex>
burial</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Of reputable association or use;
respectable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let her descend: my chambers are <qex>honorable</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>An epithet of respect or distinction; <as>as, the
<ex>honorable</ex> Senate; the <ex>honorable</ex>
gentleman.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Honorable</xex> is a title of quality, conferred by
English usage upon the younger children of earls and all the children of
viscounts and barons. The maids of honor, lords of session, and the
supreme judges of England and Ireland are entitled to the prefix. In
American usage, it is a title of courtesy merely, bestowed upon those
who hold, or have held, any of the higher public offices, esp.
governors, judges, members of Congress or of the Senate, mayors, and
often also extended to lower officials, such as city council
members.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Right honorable</b></col>. <cd>See under
<er>Right</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honorableness</ent><br/
<hw>Hon"or*a*ble*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of
being honorable; eminence; distinction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conformity to the principles of honor, probity, or
moral rectitude; fairness; uprightness; reputableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honorably</ent><br/
<hw>Hon"or*a*bly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>In
an honorable manner; in a manner showing, or consistent with,
honor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The reverend abbot . . . <qex>honorably</qex> received him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why did I not more <qex>honorably</qex> starve?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Decently; becomingly.</def> <mark>[Obs.]</mark>
<ldquo/Do this message <xex>honorably</xex>.<rdquo/
<rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Magnanimously; generously; nobly; worthily;
justly; equitably; fairly; reputably.</syn></p>

<p><ent>Honorary</ent><br/
<ent>Honorarium</ent><br/
<mhw>{ \'d8<hw>Hon`o*ra"ri*um</hw> <pr>(?)</pr>, <hw>Hon"or*a*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>honorarium</ets> (sc.
<ets>donum</ets>), fr. <ets>honorarius</ets>. See <er>Honorary</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>A fee offered to professional men
for their services; <as>as, an <ex>honorarium</ex> of one thousand
dollars</as>.</def> <rj><au>S. Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An honorary payment, usually in
recognition of services for which it is not usual or not lawful to
assign a fixed business price.</def> <rj><au>Heumann.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honorary</ent><br/
<hw>Hon"or*a*ry</hw>, <pos>a.</pos> <ety>[L. <ets>honorarius</ets>, fr.
<ets>honor</ets> honor: cf. F. <ets>honoraire</ets>.]</ety> <sn>1.</sn>
<def>Done as a sign or evidence of honor; <as>as, <ex>honorary</ex>
services</as>.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conferring honor, or intended merely to confer honor
without emolument; <as>as, an <ex>honorary</ex> degree</as>.</def>
<ldquo/<xex>Honorary</xex> arches.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Holding a title or place without rendering service
or receiving reward; <as>as, an <ex>honorary</ex> member of a
society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>honored</ent><br/
<hw>honored</hw> <pos>adj.</pos> <sn>1.</sn> <def>of high repute; -- of
people.</def><br/
<syn><b>Syn. --</b> esteemed, prestigious, respected.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>greatly admired.</def><br/
<syn><b>Syn. --</b> glorious, illustrious, magnificent.</syn><br/
[<source>PJC</source>]</p>

<p><ent>honoree</ent><br/
<hw>honoree</hw> <pos>n.</pos> <sn>1.</sn> <def>a recipient of honors in
recognition of noteworthy accomplishments. Correlative of
<inv>honorer</inv> or <inv>conferrer</inv>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Honorer</ent><br/
<hw>Hon"or*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
honors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honorific</ent><br/
<hw>Hon`or*if"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Honor</er>, <er>-fy</er>, and <er>-ic</er>.]</ety> <def>Conferring
honor; tending to honor.</def> <rj><au>London Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honorless</ent><br/
<hw>Hon"or*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of
honor; not honored.</def> <rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>honour</ent><br/
<hw>honour</hw> <pos>n. & v.</pos> <def>Same as <er>honor</er>; --
chiefly British usage.</def> <mark>[Brit.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>honours</ent><br/
<hw>honours</hw> <pos>n.</pos> <def>A university degree with honors; --
a term used in Great Britain.</def> <mark>[Brit.]</mark> <br/
<syn><b>Syn. --</b> honours degree.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Honshu</ent><br/
<hw>Hon"shu</hw> <pos>prop. n.</pos> <ety>[Jap.]</ety> <def>the main
island of Japan. Together with the islands of Hokkaido, Kyushu and
Shikoku it forms the bulk of the land area of Japan.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hont</ent><br/
<hw>Hont</hw> <pr>(h<ocr/nt)</pr>, <pos>n. & v.</pos> <def>See under
<er>Hunt</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Honved</ent><br/
\'d8<hw>Hon"v<eacute/d</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hung.
<ets>honv<emac/d</ets>; <ets>hon</ets> home + <ets>v<emac/d</ets>
defense.]</ety> <sn>1.</sn> <def>The Hungarian army in the revolutionary
war of 1848-49.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>same as <er>Honv<eacute/ds<eacute/g</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Honvedseg</ent><br/
\'d8<hw>Hon"v<eacute/d*s<eacute/g`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[Hung. <ets>honv<emac/ds<emac/g</ets>; <ets>honv<emac/d +
s<emac/g</ets>, an abstract or collective suffix.]</ety>
<fld>(Hungary)</fld> <def>See <er>Army organization</er>,
above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hoo</ent><br/
<hw>Hoo</hw> <pr>(?)</pr>, <pos>interj.</pos> <sn>1.</sn> <def>See
<er>Ho</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hurrah! -- an exclamation of triumphant joy.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hooch</ent><br/
<hw>hooch</hw> <pos>n.</pos> <sn>1.</sn> <def>an illicitly distilled
(and usually inferior) alcoholic liquor.</def> <mark>[slang]</mark>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> hootch.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Military Slang)</fld> <def>A living quarters;</def>
<specif>especially:</specif> <def>a thatched hut in Southeast Asia, or
any living quarters where a serviceman lives together with a local
woman.</def><br/
[<source>PJC</source>]</p>

<p><ent>-hood</ent><br/
<hw>-hood</hw> <pr>(?)</pr>. <ety>[OE. <ets>hod</ets>, <ets>had</ets>,
<ets>hed</ets>, <ets>hede</ets>, etc., person, rank, order, condition,
AS. <ets>h<amac/d</ets>; akin to OS. <ets>h<emac/d</ets>, OHG.
<ets>heit</ets>, G. <ets>-heit</ets>, D. <ets>-heid</ets>, Goth.
<ets>haidus</ets> manner; cf. Skr. <ets>k<emac/tu</ets> brightness,
<ets>cit</ets> to appear, be noticeable, notice. <root/217. Cf.
<er>-head</er>.]</ety> <def>A termination denoting <xex>state</xex>,
<xex>condition</xex>, <xex>quality</xex>, <xex>character</xex>,
<xex>totality</xex>, as in man<xex>hood</xex>, child<xex>hood</xex>,
knight<xex>hood</xex>, brother<xex>hood</xex>. Sometimes it is written,
chiefly in obsolete words, in the form -<xex>head</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hood</ent><br/
<hw>Hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hood</ets>,
<ets>hod</ets>, AS. <ets>h<omac/d</ets>; akin to D. <ets>hoed</ets> hat,
G. <ets>hut</ets>, OHG. <ets>huot</ets>, also to E. <ets>hat</ets>, and
prob. to E. <ets>heed</ets>. <root/13.]</ety> <sn>1.</sn> <def>State;
condition.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How could thou ween, through that disguised <qex>hood</qex><br/
To hide thy state from being understood?</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A covering or garment for the head or the head and
shoulders, often attached to the body garment</def>; especially:
<sd>(a)</sd> <def>A soft covering for the head, worn by women, which
leaves only the face exposed.</def> <sd>(b)</sd> <def>A part of a monk's
outer garment, with which he covers his head; a cowl.</def> <ldquo/All
<xex>hoods</xex> make not monks.<rdquo/ <au>Shak.</au> <sd>(c)</sd>
<def>A like appendage to a cloak or loose overcoat, that may be drawn up
over the head at pleasure.</def> <sd>(d)</sd> <def>An ornamental fold at
the back of an academic gown or ecclesiastical vestment; <as>as, a
master's <ex>hood</ex></as>.</def> <sd>(e)</sd> <def>A covering for a
horse's head.</def> <sd>(f)</sd> <fld>(Falconry)</fld> <def>A covering
for a hawk's head and eyes. See <xex>Illust.</xex> of
<er>Falcon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything resembling a hood in form or use</def>; as:
<sd>(a)</sd> <def>The top or head of a carriage.</def> <sd>(b)</sd>
<def>A chimney top, often contrived to secure a constant draught by
turning with the wind.</def> <sd>(c)</sd> <def>A projecting cover above
a hearth, forming the upper part of the fireplace, and confining the
smoke to the flue.</def> <sd>(d)</sd> <def>The top of a pump.</def>
<sd>(e)</sd> <fld>(Ord.)</fld> <def>A covering for a mortar.</def>
<sd>(f)</sd> <fld>(Bot.)</fld> <def>The hood-shaped upper petal of some
flowers, as of monkshood; -- called also
<altname>helmet</altname>.</def> <au>Gray.</au> <sd>(g)</sd>
<fld>(Naut.)</fld> <def>A covering or porch for a companion
hatch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Shipbuilding)</fld> <def>The endmost plank of a
strake which reaches the stem or stern.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 704 --></p>

<p><ent>Hood</ent><br/
<hw>Hood</hw> <pr>(h<oocr/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hooded</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hooding</conjf>.]</vmorph> <sn>1.</sn> <def>To cover
with a hood; to furnish with a hood or hood-shaped appendage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The friar <qex>hooded</qex>, and the monarch crowned.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover; to hide; to blind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While grace is saying, I'll <qex>hood</qex> mine eyes<br/
Thus with my hat, and sigh and say, <ldquo/Amen.<rdquo/</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hooding end</b></col> <fld>(Shipbuilding)</fld>, <cd>the
end of a hood where it enters the rabbet in the stem post or stern
post.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hood</ent><br/
<hw>Hood</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <ety>[shortened
from <ets>hood</ets>lum.]</ety> <def>Same as <er>hoodlum</er>.</def>
<mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <ety>[shortened from neighbor<ets>hood</ets>.]</ety>
<def>Same as <er>neighborhood</er>.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Hoodcap</ent><br/
<hw>Hood"cap`</hw>, <pos>n.</pos> <def>See <cref>Hooded seal</cref>,
under <er>Hooded</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooded</ent><br/
<hw>Hood"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Covered with a
hood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Furnished with a hood or something like a
hood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hood-shaped;</def> <specif>esp.</specif>
<fld>(Bot.)</fld>, <def>rolled up like a cornet of paper; cuculate, as
the spethe of the Indian turnip.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Having the head
conspicuously different in color from the rest of the plumage; -- said
of birds.</def> <sd>(b)</sd> <def>Having a hoodlike crest or prominence
on the head or neck; <as>as, the <ex>hooded</ex> seal; a <ex>hooded</ex>
snake.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hooded crow</b></col>, <cd>a European crow <fld>(Corvus
cornix)</fld>; -- called also <altname>hoody</altname>, <altname>dun
crow</altname>, and <altname>royston crow</altname>.</cd> --
<col><b>Hooded gull</b></col>, <cd>the European black-headed pewit or
gull.</cd> -- <col><b>Hooded merganser</b></col>. <cd>See
<er>Merganser</er>.</cd> -- <col><b>Hooded seal</b></col>, <cd>a large
North Atlantic seal (<spn>Cystophora cristata</spn>). The male has a
large, inflatible, hoodlike sac upon the head. Called also
<altname>hoodcap</altname>.</cd> -- <col><b>Hooded sheldrake</b></col>,
<cd>the hooded merganser. See <er>Merganser</er>.</cd> -- <col><b>Hooded
snake</b></col>. <cd>See <er>Cobra de capello</er>, <er>Asp</er>,
<er>Haje</er>, etc.</cd> -- <col><b>Hooded warbler</b></col>, <cd>a
small American warbler (<spn>Sylvania mitrata</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoodless</ent><br/
<hw>Hood"less</hw>, <pos>a.</pos> <def>Having no hood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoodlum</ent><br/
<hw>Hood"lum</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A young rowdy; a
rough, lawless fellow; colloquially, called also
<altname>hood</altname>.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Just tell your <ex>hoodlum</ex> friends outside<br/
You ain't got time to take no ride.</q> <rj><au>Yakety-Yak
(Song)</au></rj><br/
[<source>PJC</source>]</p>

<p><ent>Hoodman</ent><br/
<hw>Hood"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The person
blindfolded in the game called hoodman-blind.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoodman-blind</ent><br/
<hw>Hood"man-blind`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An old term
for blindman's buff.</def> <rj><au>Shak.</au></rj></p>

<p><ent>Hood moulding</ent><br/
<ent>Hood molding</ent><br/
<mhw>{ <hw>Hood" mold`ing</hw> <hw>Hood" mould`ing</hw> }</mhw>
<pr>(?)</pr>. <fld>(Arch.)</fld> <def>A projecting molding over the head
of an arch, forming the outermost member of the archivolt; -- called
also <altname>hood mold</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoodoo</ent><br/
<hw>Hoo"doo</hw> <pr>(h<oomac/"d<oomac/)</pr>, <pos>n.</pos> <ety>[Perh.
a var. of <ets>voodoo</ets>.]</ety> <sn>1.</sn> <def>One who causes bad
luck.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>voodoo</er>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Bad luck.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hoodoo</ent><br/
<hw>Hoo"doo</hw>, <pos>v. t.</pos> <def>To be a hoodoo to; to bring bad
luck to by occult influence; to bewitch.</def> <mark>[Colloq., U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hoodoo</ent><br/
<hw>Hoo"doo</hw>, <pos>n.</pos> <def>A natural rock pile or pinnacle of
fantastic shape.</def> <mark>[Western U. S.]</mark> <ldquo/I watched for
hours as the shadows moved through the <xex>hoodoos</xex> in Bryce
Canyon park.<rdquo/<br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>hoodooism</ent><br/
<hw>hoodooism</hw> <pos>n.</pos> <def>Voodoo, a form of religion
practiced chiefly in Caribbean countries (esp.
<country>Haiti</country>); it involves witchcraft and animistic
deities.</def><br/
<syn><b>Syn. --</b> voodoo, vodoun, voodooism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoodwink</ent><br/
<hw>Hood"wink</hw> <pr>(h<oocr/d"w<icr/<nsm/k)</pr>, <pos>v. t.</pos>
<ety>[<ets>Hood</ets> + <ets>wink</ets>.]</ety> <sn>1.</sn> <def>To
blind by covering the eyes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We will blind and <qex>hoodwink</qex> him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover; to hide.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deceive by false appearance; to impose
upon.</def> <ldquo/<xex>Hoodwinked</xex> with kindness.<rdquo/
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoody</ent><br/
<hw>Hood"y</hw> <pr>(h<oocr/d"<ycr/)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The hooded crow; also, in Scotland, the hooded
gull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoof</ent><br/
<hw>Hoof</hw> <pr>(h<oomac/f)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hoofs</plw> <pr>(h<oomac/fs)</pr>, very rarely <plw>Hooves</plw>
<pr>(h<oomac/vz)</pr>.</plu> <ety>[OE. <ets>hof</ets>, AS.
<ets>h<omac/f</ets>; akin to D. <ets>hoef</ets>, G. <ets>huf</ets>, OHG.
<ets>huof</ets>, Icel. <ets>h<omac/fr</ets>, Sw. <ets>hof</ets>, Dan.
<ets>hov</ets>; cf. Russ. <ets>kopuito</ets>, Skr.
<ets><cced/apha</ets>. <root/225.]</ety> <sn>1.</sn> <def>The horny
substance or case that covers or terminates the feet of certain animals,
as horses, oxen, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On burnished <qex>hooves</qex> his war horse trode.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hoofed animal; a beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our cattle also shall go with us; there shall not a
<qex>hoof</qex> be left behind.</q> <rj><qau>Ex. x. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geom.)</fld> <def>See <er>Ungula</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoof</ent><br/
<hw>Hoof</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To walk as
cattle.</def> <mark>[R.]</mark> <rj><au>William Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be on a tramp; to foot.</def> <mark>[Slang,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hoof it</b></col>, <cd>to foot it.</cd> -- <col><b>On
the hoof</b></col>, <cd>of cattle, standing (on the hoof); not
slaughtered.</cd> -- <col><b>beef on the hoof</b></col>, <cd>live
cattle.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hoofbound</ent><br/
<hw>Hoof"bound`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Far.)</fld>
<def>Having a dry and contracted hoof, which occasions pain and
lameness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoofed</ent><br/
<hw>Hoofed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with
hoofs.</def> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hoofer</ent><br/
<hw>hoof"er</hw> <pos>n.</pos> <def>a professional dancer, especially a
tap dancer.</def> <mark>[Show business slang]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hoofing</ent><br/
<hw>hoofing</hw> <pos>n.</pos> <def>a dance in which the steps are more
important than gestures or postures.</def><br/
<syn><b>Syn. --</b> step dancing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoofless</ent><br/
<hw>Hoof"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of
hoofs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hooflike</ent><br/
<hw>hooflike</hw> <pos>adj.</pos> <def>resembling a hoof.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hoofprint</ent><br/
<ent>hoofmark</ent><br/
<mhw><hw>hoofmark</hw>, <hw>hoofprint</hw></mhw> <pos>n.</pos> <def>a
visible impression on a surface made by the hoof of an animal.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hook</ent><br/
<hw>Hook</hw> <pr>(h<oocr/k; 277)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hok</ets>, AS. <ets>h<omac/c</ets>; cf. D. <ets>haak</ets>, G.
<ets>hake</ets>, <ets>haken</ets>, OHG. <ets>h<amac/ko</ets>,
<ets>h<amac/go</ets>, <ets>h<amac/ggo</ets>, Icel. <ets>haki</ets>, Sw.
<ets>hake</ets>, Dan. <ets>hage</ets>. Cf. <er>Arquebuse</er>,
<er>Hagbut</er>, <er>Hake</er>, <er>Hatch</er> a half door,
<er>Heckle</er>.]</ety> <sn>1.</sn> <def>A piece of metal, or other hard
material, formed or bent into a curve or at an angle, for catching,
holding, or sustaining anything; <as>as, a <ex>hook</ex> for catching
fish; a <ex>hook</ex> for fastening a gate; a boat <ex>hook</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That part of a hinge which is fixed to a post, and
on which a door or gate hangs and turns.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An implement for cutting grass or grain; a sickle;
an instrument for cutting or lopping; a billhook.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like slashing Bentley with his desperate <qex>hook</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Steam Engin.)</fld> <def>See <er>Eccentric</er>,
and <er>V-hook</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A snare; a trap.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A field sown two years in succession.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <def>The projecting points of the thigh
bones of cattle; -- called also <altname>hook bones</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Geog.)</fld> <def>A spit or narrow cape of sand or
gravel turned landward at the outer end; <as>as, Sandy <ex>Hook</ex> in
New Jersey</as>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>9.</sn> <fld>(Sports)</fld> <def>The curving motion of a ball, as
in bowling or baseball, curving away from the hand which threw the ball;
in golf, a curving motion in the direction of the golfer who struck the
ball.</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <fld>(Computers)</fld> <def>A procedure within the
encoding of a computer program which allows the user to modify the
program so as to import data from or export data to other
programs.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>By hook or by crook</b></col>, <cd>one way or other; by
any means, direct or indirect.</cd> <au>Milton.</au> <ldquo/In hope her
to attain <xex>by hook or crook</xex>.<rdquo/ <au>Spenser.</au> --
<col><b>Off the hook</b></col>, <cd>freed from some obligation or
difficulty; <as>as, to get <ex>off the hook</ex> by getting someone else
to do the job</as>.</cd> <mark>[Colloq.]</mark> -- <col><b>Off the
hooks</b></col>, <cd>unhinged; disturbed; disordered.</cd>
<mark>[Colloq.]</mark> <ldquo/In the evening, by water, to the Duke of
Albemarle, whom I found mightly <xex>off the hooks</xex> that the ships
are not gone out of the river.<rdquo/ <au>Pepys.</au><-- = out of joint
--> -- <col><b>On one's own hook</b></col>, <cd>on one's own account or
responsibility; by one's self.</cd> <mark>[Colloq. U.S.]</mark>
<au>Bartlett.</au> -- <col><b>To go off the hooks</b></col>, <cd>to
die.</cd> <mark>[Colloq.]</mark> <au>Thackeray.</au> -- <col><b>Bid
hook</b></col>, <cd>a small boat hook.</cd> -- <col><b>Chain
hook</b></col>. <cd>See under <er>Chain</er>.</cd> -- <col><b>Deck
hook</b></col>, <cd>a horizontal knee or frame, in the bow of a ship, on
which the forward part of the deck rests.</cd> -- <col><b>Hook and
eye</b></col>, <cd>one of the small wire hooks and loops for fastening
together the opposite edges of a garment, etc.</cd> -- <col><b>Hook
bill</b></col> <fld>(Zool.)</fld>, <cd>the strongly curved beak of a
bird.</cd> -- <col><b>Hook ladder</b></col>, <cd>a ladder with hooks at
the end by which it can be suspended, as from the top of a wall.</cd> --
<col><b>Hook motion</b></col> <fld>(Steam Engin.)</fld>, <cd>a valve
gear which is reversed by V hooks.</cd> -- <col><b>Hook squid</b></col>,
<cd>any squid which has the arms furnished with hooks, instead of
suckers, as in the genera <gen>Enoploteuthis</gen> and
<gen>Onychteuthis</gen>.</cd> -- <col><b>Hook wrench</b></col>, <cd>a
wrench or spanner, having a hook at the end, instead of a jaw, for
turning a bolthead, nut, or coupling.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hook</ent><br/
<hw>Hook</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hooked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hooking</conjf>.]</vmorph> <sn>1.</sn> <def>To catch or fasten
with a hook or hooks; to seize, capture, or hold, as with a hook, esp.
with a disguised or baited hook; hence, to secure by allurement or
artifice; to entrap; to catch; <as>as, to <ex>hook</ex> a dress; to
<ex>hook</ex> a trout.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hook</qex> him, my poor dear, . . . at any sacrifice.</q>
<rj><qau>W. Collins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To seize or pierce with the points of the horns, as
cattle in attacking enemies; to gore.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To steal.</def> <mark>[Colloq. Eng. &
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hook on</b></col>, <cd>to fasten or attach by, or as
by, hook.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hook</ent><br/
<hw>Hook</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To bend;
to curve as a hook.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move or go with a sudden turn;</def>
<specif>hence</specif> <mark>[Slang or Prov. Eng.]</mark>, <def>to make
off; to clear out; -- often with <xex>it</xex>.</def> <ldquo/Duncan was
wounded, and the escort <xex>hooked</xex> it.<rdquo/
<rj><au>Kipling.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hookah</ent><br/
<hw>Hook"ah</hw> <pr>(h<oocr/k"<adot/)</pr>, <pos>n.</pos> <ety>[Per. or
Ar. <ets>huqqa</ets> a round box or casket, a bottle through which the
fumes pass when smoking tobacco.]</ety> <def>A pipe with a long,
flexible stem, so arranged that the smoke is cooled by being made to
pass through water. Also called <altname>narghile</altname> and
<altname>water pipe</altname>. The <er>hubble-bubble</er> is a simple
form of this device.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hook-and-ladder company</ent><br/
<hw>hook"-and-lad"der com"pa*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
company of firefighters who operate a hook-and-ladder truck; a fire
company; called also <altname>ladder company</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hook and ladder</ent><br/
<ent>hook and ladder truck</ent><br/
<ent>hook-and-ladder truck</ent><br/
<mhw><hw>hook"-and-lad"der truck</hw>, <hw>hook" and lad"der truck</hw>,
<hw>hook" and lad"der</hw></mhw> <pr>(?)</pr>, <pos>n.</pos> <def>A
firefighting truck equipped with a ladder extendable to great length,
for access to the upper stories of buildings; it also carries other
firefighting equipment; called also <altname>ladder
truck</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hook-billed</ent><br/
<hw>hook"-billed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a strongly curved bill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooked</ent><br/
<hw>Hooked</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having the
form of a hook; curvated; <as>as, the <ex>hooked</ex> bill of a
bird</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Provided with a hook or hooks.</def> <ldquo/The
<xex>hooked</xex> chariot.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hookedness</ent><br/
<hw>Hook"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being bent like a hook; incurvation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooker</ent><br/
<hw>Hook"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, hooks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A Dutch vessel with
two masts.</def> <sd>(b)</sd> <def>A fishing boat with one mast, used on
the coast of Ireland.</def> <sd>(c)</sd> <def>A sailor's contemptuous
term for any antiquated craft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooke's gearing</ent><br/
<hw>Hooke's" gear"ing</hw> <pr>(?)</pr>. <ety>[So called from the
inventor.]</ety> <fld>(Mach.)</fld> <def>Spur gearing having teeth
slanting across the face of the wheel, sometimes slanting in opposite
directions from the middle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooke's joint</ent><br/
<hw>Hooke's joint</hw> <pr>(?)</pr>. <ety>[So called from the
inventor.]</ety> <fld>(Mach.)</fld> <def>A universal joint. See under
<er>Universal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hookey</ent><br/
<hw>Hook"ey</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>See
<er>Hockey</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>hooky</er>, <pos>n.</pos>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooklet</ent><br/
<hw>Hook"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little
hook.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hook-nosed</ent><br/
<hw>Hook"-nosed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a hooked
or aquiline nose.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooky</ent><br/
<hw>Hook"y</hw> <pr>(h<oocr/k"<ycr/)</pr>, <pos>a.</pos> <def>Full of
hooks; pertaining to hooks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooky</ent><br/
<hw>Hook"y</hw> <pr>(h<oocr/k"<ycr/)</pr>, <pos>n.</pos> <altsp>[Written
also <asp>hookey</asp>.]</altsp> <ety>[Cf. <er>Hook</er>, <pos>v.
t.</pos>, 3.]</ety> <def>A word used only in the expression <xex>to play
hooky</xex>, to be truant, to run away; -- used mostly of youths absent
from school without a valid reason and without the knowledge of their
parents. Also (figuratively and jocosely), to be absent from duty for
frivolous reasons.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><q>This talk about boys . . . playing ball, and
<ldquo/<qex>hooky</qex>,<rdquo/ and marbles, was all moonshine.</q>
<rj><qau>F. Hopkinson Smith.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hool</ent><br/
<hw>Hool</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Whole.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoolock</ent><br/
<hw>Hoo"lock</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
small black gibbon (<spn>Hylobates hoolock</spn>), found in the
mountains of Assam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoom</ent><br/
<hw>Hoom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Home.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoonoomaun</ent><br/
<hw>Hoo"noo*maun</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An Indian monkey. See <er>Entellus</er>.</def> <altsp>[Written also
<asp>hoonuman</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoop</ent><br/
<hw>Hoop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hope</ets>;
akin to D. <ets>hoep</ets>, <ets>hoepel</ets>.]</ety> <sn>1.</sn> <def>A
pliant strip of wood or metal bent in a circular form, and united at the
ends, for holding together the staves of casks, tubs, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ring; a circular band; anything resembling a hoop,
as the cylinder (cheese hoop) in which the curd is pressed in making
cheese.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A circle, or combination of circles, of thin
whalebone, metal, or other elastic material, used for expanding the
skirts of ladies' dresses; crinoline; -- used chiefly in the
plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though stiff with <qex>hoops</qex>, and armed with ribs of
whale.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A quart pot; -- so called because originally bound
with hoops, like a barrel. Also, a portion of the contents measured by
the distance between the hoops.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An old measure of capacity, variously estimated at
from one to four pecks.</def> <mark>[Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bulge hoop</b></col>, <col><b>Chine hoop</b></col>,
<col><b>Quarter hoop</b></col></mcol>, <cd>the hoop nearest the middle
of a cask, that nearest the end, and the intermediate hoop between these
two, respectively.</cd> -- <col><b>Flat hoop</b></col>, <cd>a wooden
hoop dressed flat on both sides.</cd> -- <col><b>Half-round
hoop</b></col>, <cd>a wooden hoop left rounding and undressed on the
outside.</cd> -- <col><b>Hoop iron</b></col>, <cd>iron in thin narrow
strips, used for making hoops.</cd> -- <col><b>Hoop lock</b></col>,
<cd>the fastening for uniting the ends of wooden hoops by notching and
interlocking them.</cd> -- <col><b>Hoop skirt</b></col>, <cd>a framework
of hoops for expanding the skirts of a woman's dress; -- called also
<altname>hoop petticoat</altname>.</cd> -- <col><b>Hoop snake</b></col>
<fld>(Zool.)</fld>, <cd>a harmless snake of the Southern United States
(<spn>Abaster erythrogrammus</spn>); -- so called from the mistaken
notion that it curves itself into a hoop, taking its tail into its
mouth, and rolls along with great velocity.</cd> -- <col><b>Hoop
tree</b></col> <fld>(Bot.)</fld>, <cd>a small West Indian tree
(<spn>Melia sempervirens</spn>), of the Mahogany family.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoop</ent><br/
<hw>Hoop</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hooped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hooping</conjf>.]</vmorph> <sn>1.</sn> <def>To bind or fasten
with hoops; <as>as, to <ex>hoop</ex> a barrel or
puncheon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To clasp; to encircle; to surround.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoop</ent><br/
<hw>Hoop</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>houpen</ets>; cf. F. <ets>houper</ets> to hoop, to shout; -- a
hunting term, prob. fr. <ets>houp</ets>, an interj. used in calling. Cf.
<er>Whoop</er>.]</ety> <sn>1.</sn> <def>To utter a loud cry, or a sound
imitative of the word, by way of call or pursuit; to shout.</def>
<altsp>[Usually written <asp>whoop</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To whoop, as in whooping cough. See
<er>Whoop</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hooping cough</b></col>. <fld>(Med.)</fld> <cd>See
<er>Whooping cough</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoop</ent><br/
<hw>Hoop</hw>, <pos>v. t.</pos> <ety>[Written also
<ets>whoop</ets>.]</ety> <sn>1.</sn> <def>To drive or follow with a
shout.</def> <ldquo/To be <xex>hooped</xex> out of Rome.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To call by a shout or peculiar cry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoop</ent><br/
<hw>Hoop</hw>, <pos>n.</pos> <sn>1.</sn> <def>A shout; a whoop, as in
whooping cough.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The hoopoe. See
<er>Hoopoe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooper</ent><br/
<hw>Hoop"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Hoop</er>.]</ety> <def>One who hoops casks or tubs; a
cooper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hooper</ent><br/
<hw>Hoop"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <ety>[So
called from its note.]</ety> <def>The European whistling, or wild, swan
(<spn>Olor cygnus</spn>); -- called also <altname>hooper swan</altname>,
<altname>whooping swan</altname>, and <altname>elk</altname>.</def></p>

<p><ent>Hoopoo</ent><br/
<ent>Hoopoe</ent><br/
<mhw>{ <hw>Hoop"oe</hw> <pr>(?)</pr>, <hw>Hoop"oo</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[So called from its cry; cf. L.
<ets>upupa</ets>, Gr. <?/, D. <ets>hop</ets>, F. <ets>huppe</ets>; cf.
also G. wieden<ets>hopf</ets>, OHG. witu<ets>hopfo</ets>, lit., wood
hopper.]</ety> <fld>(Zool.)</fld> <def>A European bird of the genus
<gen>Upupa</gen> (<spn>Upupa epops</spn>), having a beautiful crest,
which it can erect or depress at pleasure, and a slender down-curving
bill. Called also <altname>hoop</altname>, <altname>whoop</altname>. The
name is also applied to several other species of the same genus and
allied genera.</def></p>

<p><ent>hoops</ent><br/
<hw>hoops</hw> <pos>n.</pos> <def>The game of basketball.</def>
<mark>[Slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>hoopskirt</ent><br/
<hw>hoopskirt</hw> <pos>n.</pos> <def>a skirt stiffened with
hoops.</def><br/
<syn><b>Syn. --</b> crinoline.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hoopster</ent><br/
<hw>hoop"ster</hw> <pos>n.</pos> <def>A basketball player.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>hoosgow</ent><br/
<ent>hoosegow</ent><br/
<mhw><hw>hoosegow</hw>, <hw>hoosgow</hw></mhw> <pos>n.</pos> <ety>[from
Mexican Sp. <ets>jusgado</ets> jail, from Sp. <ets>juzgado</ets> court
of justice.]</ety> <def>a jail.</def> <mark>[U. S. western slang]</mark>
<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoosier</ent><br/
<hw>Hoo"sier</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A nickname given to
an inhabitant of the State of Indiana.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoosier State</ent><br/
<hw>Hoo"sier State</hw>. <def>Indiana; -- a nickname of obscure
origin.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hoot</ent><br/
<hw>Hoot</hw> <pr>(h<oomac/t)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Hooted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hooting</conjf>.]</vmorph> <ety>[OE. <ets>hoten</ets>,
<ets>houten</ets>, <ets>huten</ets>; cf. OSw. <ets>huta</ets>, Sw.
<ets>huta ut</ets> to take one up sharply, fr. Sw. <ets>hut</ets>
interj., begone! cf. also W. <ets>hwt</ets> off! off with it! away!
hoot!]</ety> <sn>1.</sn> <def>To cry out or shout in contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Matrons and girls shall <qex>hoot</qex> at thee no more.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make the peculiar cry of an owl.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The clamorous owl that nightly <qex>hoots</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoot</ent><br/
<hw>Hoot</hw>, <pos>v. t.</pos> <def>To assail with contemptuous cries
or shouts; to follow with derisive shouts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Partridge and his clan may <qex>hoot</qex> me for a cheat.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoot</ent><br/
<hw>Hoot</hw>, <pos>n.</pos> <sn>1.</sn> <def>A derisive cry or
shout.</def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The cry of an owl.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A very funny event, person, or experience; <as>as,
watching Jack try to catch that greased pig was a
<ex>hoot</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Hoot owl</b></col> <fld>(Zool.)</fld>, <cd>the barred owl
(<spn>Syrnium nebulosum</spn>). See <er>Barred owl</er>.</cd> --
<col><b>not give a hoot</b></col> <cd>not care at all.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoot down</ent><br/
<hw>Hoot down</hw>, <pos>v. t.</pos> <def>To shout down; to cause (a
speaker) to cease trying to speak by loud derisive shouts.</def><br/
[<source>PJC</source>]</p>

<p><ent>hootenanny</ent><br/
<hw>hoot"en*an*ny</hw> <pos>n.</pos> <sn>1.</sn> <def>An informal social
gathering or concert featuring mostly folk songs, sometimes dancing, and
where the audience often participates in the singing.</def>
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Same as <er>whatchamacallit</er>; a
thingumbob.</def> <mark>[Obsolescent, chiefly dial.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>hooter</ent><br/
<hw>hoot"er</hw> <pos>n.</pos> <sn>1.</sn> <def>the nose.</def>
<mark>[slang]</mark> <br/
<syn><b>Syn. --</b> beak, honker, nozzle, snoot, snout,
schnozzle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An automobile horn.</def> <mark>[Brit.
slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A woman's breast, especially one that is
large.</def> <mark>[vulgar slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hoove</ent><br/
<hw>Hoove</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Allied to
<ets>heave</ets>, <ets>hove</ets>.]</ety> <def>A disease in cattle
consisting in inflammation of the stomach by gas, ordinarily caused by
eating too much green food; tympany; bloating.</def></p>

<p><ent>Hoven</ent><br/
<ent>Hooven</ent><br/
<mhw>{ <hw>Hoov"en</hw> <pr>(?)</pr>, <hw>Ho"ven</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <def>Affected with hoove; <as>as, <ex>hooven</ex>,
or <ex>hoven</ex>, cattle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoover</ent><br/
<hw>Hoover</hw> <pos>n.</pos> <ety>[a trademark.]</ety> <def>a kind of
vacuum cleaner.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hoover</ent><br/
<hw>hoover</hw> <pos>v. t.</pos> <def>to clean with a vacuum
cleaner.</def> <mark>[slang]</mark> <br/
<syn><b>Syn. --</b> vacuum, vacuum-clean.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hop</ent><br/
<hw>Hop</hw> <pr>(h<ocr/p)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hopped</conjf> <pr>(h<ocr/pt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hopping</conjf> <pr>(h<ocr/p"p<icr/ng)</pr>.]</vmorph>
<ety>[OE. <ets>hoppen</ets> to hop, leap, dance, AS. <ets>hoppian</ets>;
akin to Icel. & Sw. <ets>hoppa</ets>, Dan. <ets>hoppe</ets>, D.
<ets>huppelen</ets>, G. <ets>h<uum/pfen</ets>.]</ety> <sn>1.</sn>
<def>To move by successive leaps, as toads do; to spring or jump on one
foot; to skip, as birds do.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Birds] <qex>hopping</qex> from spray to spray.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To walk lame; to limp; to halt.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To dance.</def> <rj><au>Smollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hop</ent><br/
<hw>Hop</hw>, <pos>n.</pos> <sn>1.</sn> <def>A leap on one leg, as of a
boy; a leap, as of a toad; a jump; a spring.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dance; esp., an informal dance of ball.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hop, skip and jump</b></col>, <col><b>Hop, step and
a jump</b></col> <it>or</it> <col><b>Hop, step and
jump</b></col></mcol>, <sn>1.</sn> <cd>a game or athletic sport in which
the participants cover as much ground as possible by a hop, stride, and
jump in succession.</cd> <sn>2.</sn> <cd>a short distance.</cd></cs>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hop</ent><br/
<hw>Hop</hw>, <pos>n.</pos> <ety>[OE. <ets>hoppe</ets>; akin to D.
<ets>hop</ets>, <ets>hoppe</ets>, OHG. <ets>hopfo</ets>, G.
<ets>hopfen</ets>; cf. LL. <ets>hupa</ets>, W. <ets>hopez</ets>, Armor.
<ets>houpez</ets>, and Icel. <ets>humall</ets>, SW. & Dan.
<ets>humle</ets>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A climbing
plant (<spn>Humulus Lupulus</spn>), having a long, twining, annual
stalk. It is cultivated for its fruit (hops).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The catkin or strobilaceous fruit of the hop, much
used in brewing to give a bitter taste.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The fruit of the dog-rose. See
<er>Hip</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hop back</b></col>. <fld>(Brewing)</fld> <cd>See under
1st <er>Back</er>.</cd> -- <col><b>Hop clover</b></col>
<fld>(Bot.)</fld>, <cd>a species of yellow clover having heads like hops
in miniature (<spn>Trifolium agrarium</spn>, and <spn>Trifolium
procumbens</spn>).</cd> -- <col><b>Hop flea</b></col>
<fld>(Zool.)</fld>, <cd>a small flea beetle (<spn>Haltica
concinna</spn>), very injurious to hops.</cd> -- <col><b>Hop
fly</b></col> <fld>(Zool.)</fld>, <cd>an aphid (<spn>Phorodon
humuli</spn>), very injurious to hop vines.</cd> -- <col><b>Hop froth
fly</b></col> <fld>(Zool.)</fld>, <cd>an hemipterous insect
(<spn>Aphrophora interrupta</spn>), allied to the cockoo spits. It often
does great damage to hop vines.</cd> -- <col><b>Hop hornbeam</b></col>
<fld>(Bot.)</fld>, <cd>an American tree of the genus <gen>Ostrya</gen>
(<spn>Ostrya Virginica</spn>) the American ironwood; also, a European
species (<spn>Ostrya vulgaris</spn>).</cd> -- <col><b>Hop moth</b></col>
<fld>(Zool.)</fld>, <cd>a moth (<spn>Hypena humuli</spn>), which in the
larval state is very injurious to hop vines.</cd> -- <col><b>Hop
picker</b></col>, <cd>one who picks hops.</cd> -- <col><b>Hop
pole</b></col>, <cd>a pole used to support hop vines.</cd> --
<col><b>Hop tree</b></col> <fld>(Bot.)</fld>, <cd>a small American tree
(<spn>Ptelia trifoliata</spn>), having broad, flattened fruit in large
clusters, sometimes used as a substitute for hops.</cd> -- <col><b>Hop
vine</b></col> <fld>(Bot.)</fld>, <cd>the climbing vine or stalk of the
hop.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hop</ent><br/
<hw>Hop</hw>, <pos>v. t.</pos> <def>To impregnate with hops.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hop</ent><br/
<hw>Hop</hw>, <pos>v. i.</pos> <def>To gather hops. <usage>[Perhaps only
in the form <er>Hopping</er>, <pos>vb. n.</pos>]</usage></def></p>

<p><ent>Hopbind</ent><br/
<ent>Hopbine</ent><br/
<mhw>{ <hw>Hop"bine`</hw> <pr>(?)</pr>, <hw>Hop"bind`</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <def>The climbing stem of the hop.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hope</ent><br/
<hw>Hope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>h<omac/p</ets> a small bay or inlet.]</ety> <sn>1.</sn> <def>A
sloping plain between mountain ridges.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small bay; an inlet; a haven.</def>
<mark>[Scot.]</mark> <rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hope</ent><br/
<hw>Hope</hw>, <pos>n.</pos> <ety>[AS., <ets>akin to D</ets>.
<ets>hoop</ets>, <ets>hope</ets>, Sw. <ets>hopp</ets>, Dan.
<ets>haab</ets>, MHG. <ets>hoffe</ets>. <ets>Hope</ets> in <ets>forlorn
hope</ets> is different word. See <ets>Forlorn hope</ets>, under
<er>Forlorn</er>.]</ety> <sn>1.</sn> <def>A desire of some good,
accompanied with an expectation of obtaining it, or a belief that it is
obtainable; an expectation of something which is thought to be
desirable; confidence; pleasing expectancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hypocrite's <qex>hope</qex> shall perish.</q> <rj><qau>Job
vii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He wished, but not with <qex>hope</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>New thoughts of God, new <qex>hopes</qex> of Heaven.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who, or that which, gives hope, furnishes ground
of expectation, or promises desired good.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord will be the <qex>hope</qex> of his people.</q>
<rj><qau>Joel iii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A young gentleman of great <qex>hopes</qex>, whose love of
learning was highly commendable.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is hoped for; an object of
hope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lavina is thine elder brother's <qex>hope</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hope</ent><br/
<hw>Hope</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hoped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hoping</conjf>.]</vmorph> <ety>[AS. <ets>hopian</ets>; akin to D.
<ets>hopen</ets>, Sw. <ets>hoppan</ets>, Dan. <ets>haabe</ets>, G.
<ets>hoffen</ets>. See 2nd <er>Hope</er>.]</ety> <sn>1.</sn> <def>To
entertain or indulge hope; to cherish a desire of good, or of something
welcome, with expectation of obtaining it or belief that it is
obtainable; to expect; -- usually followed by <xex>for</xex>.</def>
<ldquo/<xex>Hope</xex> for good success.<rdquo/ <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But I will <qex>hope</qex> continually.</q> <rj><qau>Ps. lxxi.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place confidence; to trust with confident
expectation of good; -- usually followed by <xex>in</xex>.</def>
<ldquo/I <xex>hope</xex> in thy word.<rdquo/ <rj><au>Ps. cxix.
81.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why art thou cast down, O my soul? and why art thou disquieted
within me? <qex>Hope</qex> thou in God.</q> <rj><qau>Ps. xlii.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 705 --></p>

<p><ent>Hope</ent><br/
<hw>Hope</hw> <pr>(h<omac/p)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
desire with expectation or with belief in the possibility or prospect of
obtaining; to look forward to as a thing desirable, with the expectation
of obtaining it; to cherish hopes of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>hope</qex> no other from your majesty.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Charity] <qex>hopeth</qex> all things.</q> <rj><qau>1 Cor. xiii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To expect; to fear.</def> <mark>[Obs.]</mark>
<ldquo/I <xex>hope</xex> he will be dead.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hope</xex> is often used colloquially regarding
uncertainties, with no reference to the future. <ldquo/I <xex>hope</xex>
she takes me to be flesh and blood.<rdquo/</note> <rj><au>Mrs.
Centlivre.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hoped-for</ent><br/
<hw>hoped-for</hw> <pos>adj.</pos> <def>expected and desired. Contrasted
with <contr>unexpected</contr>.</def><br/
<syn><b>Syn. --</b> anticipated, awaited(predicate),
prospective.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hopeful</ent><br/
<hw>Hope"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
hope, or agreeable expectation; inclined to hope; expectant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men of their own natural inclination <qex>hopeful</qex> and
strongly conceited.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having qualities which excite hope; affording
promise of good or of success; <as>as, a <ex>hopeful</ex> youth; a
<ex>hopeful</ex> prospect.</as></def> <ldquo/<xex>Hopeful</xex>
scholars.<rdquo/ <rj><au>Addison.</au></rj></p>

<p>-- <wordforms><wf>Hope"ful*ly</wf>, <pos>adv.</pos> --
<wf>Hope"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopefully</ent><br/
<hw>Hope"ful*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>In a
hopeful manner.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>I hope; if all goes well; <as>as,
<ex>hopefully</ex>, the dress will be ready before the party</as>.</def>
<note>Some prescriptivists object to this usage as being ungrammatical,
but it is very common and well understood. It is usually used to begin a
sentence describing a desired future event.</note><br/
[<source>PJC</source>]</p>

<p><ent>Hopeite</ent><br/
<hw>Hope"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after
Professor <ets>Hope</ets>, of Edinburgh.]</ety> <fld>(Min.)</fld> <def>A
hydrous phosphate of zinc in transparent prismatic crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopeless</ent><br/
<hw>Hope"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Destitute of hope;
having no expectation of good; despairing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am a woman, friendless, <qex>hopeless</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Giving no ground of hope; promising nothing
desirable; desperate; <as>as, a <ex>hopeless</ex> cause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hopeless</qex>word of <ldquo/never to return<rdquo/<br/
Breathe I against thee, upon pain of life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Unhoped for; despaired of.</def> <mark>[Obs.]</mark>
<rj><au>Marston.</au></rj></p>

<p>-- <wordforms><wf>Hope"less*ly</wf>, <pos>adv.</pos> --
<wf>Hope"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoper</ent><br/
<hw>Hop"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hopes.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopingly</ent><br/
<hw>Hop"ing*ly</hw>, <pos>adv.</pos> <def>In a hopeful manner.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoplite</ent><br/
<hw>Hop"lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr. <?/
tool, weapon: cf. F. <ets>hoplite</ets>.]</ety> <fld>(Gr. Antiq.)</fld>
<def>A heavy-armed infantry soldier.</def>
<rj><au>Milford.</au></rj></p>

<p><ent>Hop-thumb</ent><br/
<ent>Hop-o'-my-thumb</ent><br/
<mhw>{ <hw>Hop"-o'-my-thumb"</hw> <pr>(?)</pr>, <hw>Hop"-thumb"</hw>
}</mhw>, <pos>n.</pos> <def>A very diminutive person.</def>
<mark>[Colloq.]</mark> <rj><au>liwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopped</ent><br/
<hw>Hopped</hw> <pr>(?)</pr>, <pos>p. a.</pos> <def>Impregnated with
hops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopper</ent><br/
<hw>Hop"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Hop</er>.]</ety> <sn>1.</sn> <def>One who, or that which,
hops.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A chute, box, or receptacle, usually funnel-shaped
with an opening at the lower part, for delivering or feeding any
material, as to a machine; <as>as, the wooden box with its trough
through which grain passes into a mill by joining or shaking, or a
funnel through which fuel passes into a furnace, or coal, etc.</as>,
into a car.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>See <er>Grasshopper</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>A game. See
<er>Hopscotch</er>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>See
<er>Grasshopper</er>, and <cref>Frog hopper</cref>, <cref>Grape
hopper</cref>, <cref>Leaf hopper</cref>, <cref>Tree hopper</cref>, under
<er>Frog</er>, <er>Grape</er>, <er>Leaf</er>, and <er>Tree</er>.</def>
<sd>(b)</sd> <def>The larva of a cheese fly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>A vessel for carrying waste,
garbage, etc., out to sea, so constructed as to discharge its load by a
mechanical contrivance; -- called also <altname>dumping
scow</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bell and hopper</b></col> <fld>(Metal.)</fld>, <cd>the
apparatus at the top of a blast furnace, through which the charge is
introduced, while the gases are retained.</cd> -- <col><b>Hopper
boy</b></col>, <cd>a rake in a mill, moving in a circle to spread meal
for drying, and to draw it over an opening in the floor, through which
it falls.</cd> -- <col><b>Hopper closet</b></col>, <cd>a water-closet,
without a movable pan, in which the receptacle is a funnel standing on a
draintrap.</cd> -- <col><b>Hopper cock</b></col>, <cd>a faucet or valve
for flushing the hopper of a water-closet.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopperdozer</ent><br/
<hw>Hop"per*doz`er</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hopper</ets> (as in grass<ets>hopper</ets>) + <ets>doze</ets>
or <ets>dose</ets>; because conceived as putting insects to sleep or as
dosing them with poison.]</ety> <fld>(Agric.)</fld> <def>An appliance
for the destruction of insects, consisting of a shallow iron box,
containing kerosene or coated with tar or other sticky substance, which
may be mounted on wheels.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hopperings</ent><br/
<hw>Hop"per*ings</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Gold
Washing)</fld> <def>Gravel retaining in the hopper of a
cradle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoppestere</ent><br/
<hw>Hop`pes*tere"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>An unexplained
epithet used by Chaucer in reference to ships. By some it is defined as
<ldquo/dancing (on the wave)<rdquo/; by others as
<ldquo/opposing,<rdquo/ <ldquo/warlike.<rdquo/</def> <rj><au>T. R.
Lounsbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoppet</ent><br/
<hw>Hop"pet</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A hand
basket; also, a dish used by miners for measuring ore.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An infant in arms.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopping</ent><br/
<hw>Hop"ping</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of one who,
or that which, hops; a jumping, frisking, or dancing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hopping Dick</b></col> <fld>(Zool.)</fld>, <cd>a thrush
of Jamaica (<spn>Merula leucogenys</spn>), resembling the English
blackbird in its familiar manners, agreeable song, and dark
plumage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopping</ent><br/
<hw>Hop"ping</hw>, <pos>n.</pos> <ety>[See 3rd <er>Hop</er>.]</ety>
<def>A gathering of hops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopple</ent><br/
<hw>Hop"ple</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hoppled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hoppling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From <er>Hop</er>;
cf. <er>Hobble</er>.]</ety> <sn>1.</sn> <def>To impede by a hopple; to
tie the feet of (a horse or a cow) loosely together; to hamper; to
hobble; <as>as, to <ex>hopple</ex> an unruly or straying
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To entangle; to hamper.</def> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopple</ent><br/
<hw>Hop"ple</hw>, <pos>n.</pos> <def>A fetter for horses, or cattle,
when turned out to graze; -- chiefly used in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopplebush</ent><br/
<hw>Hop"ple*bush`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hobblebush</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoppo</ent><br/
<hw>Hop"po</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd> <def>A
collector of customs, as at Canton; an overseer of commerce.</def>
<sd>(b)</sd> <def>A tribunal or commission having charge of the revenue
derived from trade and navigation.</def> <mark>[China]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hoppo men</b></col>, <cd>Chinese customhouse
officers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hopsacking</ent><br/
<hw>hopsacking</hw> <pos>n.</pos> <def>a loosely woven coarse fabric of
cotton or linen, used in clothing.</def><br/
<syn><b>Syn. --</b> hopsack.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hopscotch</ent><br/
<hw>Hop"scotch`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A child's game, in
which a player, hopping on one foot, drives a stone from one compartment
to another of a figure traced or scotched on the ground; -- called also
<altname>hoppers</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hop-skip</ent><br/
<hw>hop-skip</hw> <pos>v. i.</pos> <def>to jump lightly.</def><br/
<syn><b>Syn. --</b> hop, skip.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hop, skip, and jump</ent><br/
<ent>hop, skip, and a jump</ent><br/
<mhw><hw>hop", skip", and a jump"</hw>, <hw>hop", skip", and
jump"</hw></mhw> <pos>n.</pos> <def>a short distance; <as>as, it's just
a <ex>hop, skip and a jump</ex> away</as>.</def> <mark>[Colloq.]</mark>
<br/
<syn><b>Syn. --</b> stone's throw.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Hop-thumb</ent><br/
<hw>Hop"-thumb`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hop-o'-my-thumb</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hopyard</ent><br/
<hw>Hop"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A field where hops
are raised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horal</ent><br/
<hw>Ho"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>horalis</ets>,
fr. <ets>hora</ets> hour. See <er>Hour</er>.]</ety> <def>Of or
pertaining to an hour, or to hours.</def> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horaly</ent><br/
<hw>Ho"ra*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Hourly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horary</ent><br/
<hw>Ho"ra*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>horarius</ets>, fr. L. <ets>hora</ets> hour: cf. F.
<ets>horaire</ets>. See <er>Hour</er>.]</ety> <sn>1.</sn> <def>Of or
pertaining to an hour; noting the hours.</def>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occurring once an hour; continuing an hour; hourly;
ephemeral.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Horary</qex>, or soon decaying, fruits of summer.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horary circles</b></col>. <cd>See
<er>Circles</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horatian</ent><br/
<hw>Ho*ra"tian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
<persfn>Horace</persfn>, the Latin poet, or resembling his
style.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horde</ent><br/
<hw>Horde</hw> <pr>(h<omac/rd)</pr>, <pos>n.</pos> <ety>[F.
<ets>horde</ets> (cf. G. <ets>horde</ets>), fr. Turk.
<ets>ord<umac/</ets>, <ets>ord<imac/</ets>, camp; of Tartar
origin.]</ety> <sn>1.</sn> <def>A wandering troop or gang; especially, a
clan or tribe of a nomadic people migrating from place to place for the
sake of pasturage, plunder, etc.; a predatory multitude.</def>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any large group of people or
animals, especially one wandering or moving about; <as>as, the movie
star was surrounded by a <ex>horde</ex> of screaming
fans</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hordeic</ent><br/
<hw>Hor*de"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hordeum</ets> barley.]</ety> <fld>(Chem.)</fld> <def>Pertaining to,
or derived from, barley; <as>as, <ex>hordeic</ex> acid, an acid
identical or isomeric with <ex>lauric</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hordein</ent><br/
<hw>Hor"de*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hordeum</ets> barley.]</ety> <fld>(Chem.)</fld> <def>A peculiar
starchy matter contained in barley. It is a complex mixture.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hordeolum</ent><br/
\'d8<hw>Hor*de"o*lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>hordeolus</ets>, dim. of <ets>hordeum</ets> barley.]</ety>
<fld>(Med.)</fld> <def>A small tumor upon the eyelid, resembling a grain
of barley; a sty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hordock</ent><br/
<hw>Hor"dock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An unidentified
plant mentioned by Shakespeare, perhaps equivalent to
<xex>burdock</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hore</ent><br/
<hw>Hore</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hoar.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horehound</ent><br/
<hw>Hore"hound`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>horehune</ets>, AS. <ets>h<amac/rhune</ets>; <ets>h<amac/r</ets>
hoar, gray + <ets>hune</ets> horehound; cf. L. <ets>cunila</ets> a
species of organum, Gr. <?/, Skr. <ets>kn<?/y</ets> to smell.]</ety>
<fld>(Bot.)</fld> <sn>1.</sn> <def>A plant of the genus
<gen>Marrubium</gen> (<spn>Marrubium vulgare</spn>), which has a bitter
taste, and is a weak tonic, used as a household remedy for colds,
coughing, etc.</def> <altsp>[Written also
<asp>hoarhound</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lozenge or tablet, usually sweetened, containing
extract of horehound, used as a remedy for a cough or a sore
throat.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Fetid horehound</b></col>, <it>or</it>
<col><b>Black horehound</b></col></mcol>, <cd>a disagreeable plant
resembling horehound (<spn>Ballota nigra</spn>).</cd> -- <col><b>Water
horehound</b></col>, <cd>a species of the genus <gen>Lycopus</gen>,
resembling mint, but not aromatic.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horizon</ent><br/
<hw>Ho*ri"zon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>horizon</ets>, fr. Gr. <?/ (sc. <?/) the bounding line, horizon,
fr. <?/ to bound, fr. <?/ boundary, limit.]</ety> <sn>1.</sn> <def>The
line which bounds that part of the earth's surface visible to a
spectator from a given point; the apparent junction of the earth and
sky.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And when the morning sun shall raise his car<br/
Above the border of this <qex>horizon</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>horizon</qex> round<br/
Invested with bright rays.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <sd>(a)</sd> <def>A plane passing
through the eye of the spectator and at right angles to the vertical at
a given place; a plane tangent to the earth's surface at that place;
called distinctively the <xex>sensible horizon</xex>.</def> <sd>(b)</sd>
<def>A plane parallel to the sensible horizon of a place, and passing
through the earth's center; -- called also <altname>rational
horizon</altname> <it>or</it> <altname>celestial
horizon</altname>.</def> <sd>(c)</sd> <fld>(Naut.)</fld> <def>The
unbroken line separating sky and water, as seen by an eye at a given
elevation, no land being visible.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>The epoch or time during which a
deposit was made.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The strata all over the earth, which were formed at the same time,
are said to belong to the same geological <qex>horizon</qex>.</q>
<rj><qau>Le Conte.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Painting)</fld> <def>The chief horizontal line in a
picture of any sort, which determines in the picture the height of the
eye of the spectator; in an extended landscape, the representation of
the natural horizon corresponds with this line.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The limit of a person's range of perception,
capabilities, or experience; <as>as, children raised in the inner city
have limited <ex>horizons</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <mark>[fig.]</mark> <def>A boundary point or line, or a
time point, beyond which new knowledge or experiences may be found;
<as>as, more powerful computers are just over the
<ex>horizon</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Apparent horizon</b></col>. <cd>See under
<er>Apparent</er>.</cd> -- <col><b>Artificial horizon</b></col>, <cd>a
level mirror, as the surface of mercury in a shallow vessel, or a plane
reflector adjusted to the true level artificially; -- used chiefly with
the sextant for observing the double altitude of a celestial body.</cd>
-- <col><b>Celestial horizon</b></col>. <fld>(Astron.)</fld> <cd>See
def. 2, above.</cd> -- <col><b>Dip of the horizon</b></col>
<fld>(Astron.)</fld>, <cd>the vertical angle between the sensible
horizon and a line to the visible horizon, the latter always being below
the former.</cd> -- <mcol><col><b>Rational horizon</b></col>, and
<col><b>Sensible horizon</b></col></mcol>. <fld>(Astron.)</fld> <cd>See
def. 2, above.</cd> -- <col><b>Visible horizon</b></col>. <cd>See
definitions 1 and 2, above.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horizontal</ent><br/
<hw>Hor`i*zon"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>horizontal</ets>.]</ety> <sn>1.</sn> <def>Pertaining to, or near,
the horizon.</def> <ldquo/<xex>Horizontal</xex> misty air.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Parallel to the horizon; on a level; <as>as, a
<ex>horizontal</ex>line or surface</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Measured or contained in a plane of the horizon;
<as>as, <ex>horizontal</ex> distance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horizontal drill</b></col>, <cd>a drilling machine having
a horizontal drill spindle.</cd> -- <col><b>Horizontal engine</b></col>,
<cd>one the piston of which works horizontally.</cd> --
<col><b>Horizontal fire</b></col> <fld>(Mil.)</fld>, <cd>the fire of
ordnance and small arms at point-blank range or at low angles of
elevation.</cd> -- <col><b>Horizontal force</b></col>
<fld>(Physics)</fld>, <cd>the horizontal component of the earth's
magnetic force.</cd> -- <col><b>Horizontal line</b></col>
<fld>(Descriptive Geometry & Drawing)</fld>, <cd>a constructive line,
either drawn or imagined, which passes through the point of sight, and
is the chief line in the projection upon which all verticals are fixed,
and upon which all vanishing points are found.</cd> --
<col><b>Horizontal parallax</b></col>. <cd>See under
<er>Parallax</er>.</cd> -- <col><b>Horizontal plane</b></col>
<fld>(Descriptive Geometry)</fld>, <cd>a plane parallel to the horizon,
upon which it is assumed that objects are projected. See
<er>Projection</er>. It is upon the horizontal plane that the ground
plan of the buildings is supposed to be drawn.</cd> --
<col><b>Horizontal projection</b></col>, <cd>a projection made on a
plane parallel to the horizon.</cd> -- <col><b>Horizontal
range</b></col> <fld>(Gunnery)</fld>, <cd>the distance in a horizontal
plane to which a gun will throw a projectile.</cd> -- <col><b>Horizontal
water wheel</b></col>, <cd>a water wheel in which the axis is vertical,
the buckets or floats revolving in a horizontal plane, as in most
turbines.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horizontality</ent><br/
<hw>Hor`i*zon*tal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>horizontalit<eacute/</ets>.]</ety> <def>The state or quality of
being horizontal.</def> <rj><au>Kirwan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horizontally</ent><br/
<hw>Hor`i*zon"tal*ly</hw>, <pos>adv.</pos> <def>In a horizontal
direction or position; on a level; <as>as, moving
<ex>horizontally</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hormogonium</ent><br/
\'d8<hw>Hor`mo*go*ni"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ a chain + <?/ generation.]</ety> <fld>(Bot.)</fld> <def>A chain
of small cells in certain alg<ae/, by which the plant is
propagated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hormonal</ent><br/
<hw>Hor*mon"al</hw> <pr>(h<ocir/r*m<omac/n"<ait/l)</pr>, <pos>a.</pos>
<def>of, pertaining to, or affected by, hormones.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hormone</ent><br/
<hw>Hor"mone</hw> <pr>(h<ocir/r"m<omac/n)</pr>, <pos>n.</pos> <ety>[From
Gr. <grk>"orma`ein</grk> to excite.]</ety> <sn>1.</sn>
<fld>(Physiological Chem.)</fld> <def>A chemical substance formed in one
organ and carried in the circulation to another organ on which it exerts
a specific effect on cells at a distance from the producing cells;
<as>thus, pituitary <ex>hormones</ex> produced in the brain may have
effects on cells in distant parts of the body.</as>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Physiological Chem.)</fld> <def>a chemical
substance, whether natural or synthetic, that functions like a hormone
in a living organism. <as>Thus, synthetic steroid <ex>hormones</ex> may
be more effective than their natural counterparts</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A substance that controls growth
rate or differentiation in plants; also called
<altname>phytohormone</altname>. The most well-known are the
<stype>auxins</stype> that stimulate growth at the growing tips of
plants, and control root formation and the dropping of leaves; and the
<stype>gibberellins</stype>, which are used in agriculture to promote
plant growth.</def><br/
[<source>PJC</source>]</p>

<p><ent>Horn</ent><br/
<hw>Horn</hw> <pr>(h<ocir/rn)</pr>, <pos>n.</pos> <ety>[AS.
<ets>horn</ets>; akin to D. <ets>horen</ets>, <ets>hoorn</ets>, G.,
Icel., Sw., & Dan. <ets>horn</ets>, Goth. <ets>ha<uacute/rn</ets>, W.,
Gael., & Ir. <ets>corn</ets>, L. <ets>cornu</ets>, Gr.
<grk>ke`ras</grk>, and perh. also to E. <ets>cheer</ets>,
<ets>cranium</ets>, <ets>cerebral</ets>; cf. Skr. <ets><cced/iras</ets>
head. Cf. <er>Carat</er>, <er>Corn</er> on the foot, <er>Cornea</er>,
<er>Corner</er>, <er>Cornet</er>, <er>Cornucopia</er>,
<er>Hart</er>.]</ety> <sn>1.</sn> <def>A hard, projecting, and usually
pointed organ, growing upon the heads of certain animals, esp. of the
ruminants, as cattle, goats, and the like. The hollow horns of the Ox
family consist externally of true horn, and are never shed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The antler of a deer, which is of bone throughout,
and annually shed and renewed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Any natural projection or
excrescence from an animal, resembling or thought to resemble a horn in
substance or form;</def> <specif>esp.:</specif> <sd>(a)</sd> <def>A
projection from the beak of a bird, as in the hornbill.</def>
<sd>(b)</sd> <def>A tuft of feathers on the head of a bird, as in the
horned owl.</def> <sd>(c)</sd> <def>A hornlike projection from the head
or thorax of an insect, or the head of a reptile, or fish.</def>
<sd>(d)</sd> <def>A sharp spine in front of the fins of a fish, as in
the horned pout.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>An incurved, tapering and pointed
appendage found in the flowers of the milkweed
(<gen>Asclepias</gen>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Something made of a horn, or in resemblance of a
horn</def>; as: <sd>(a)</sd> <def>A wind instrument of music;
originally, one made of a horn (of an ox or a ram); now applied to
various elaborately wrought instruments of brass or other metal,
resembling a horn in shape.</def> <ldquo/Wind his <xex>horn</xex> under
the castle wall.<rdquo/ <au>Spenser.</au> See <cref>French horn</cref>,
under <er>French</er>. <sd>(b)</sd> <def>A drinking cup, or beaker, as
having been originally made of the horns of cattle.</def>
<ldquo/<xex>Horns</xex> of mead and ale.<rdquo/ <au>Mason.</au>
<sd>(c)</sd> <def>The cornucopia, or horn of plenty.</def> See
<er>Cornucopia</er>. <ldquo/Fruits and flowers from Amalth<ae/a's
<xex>horn</xex>.<rdquo/ <au>Milton.</au> <sd>(d)</sd> <def>A vessel made
of a horn; esp., one designed for containing powder; anciently, a small
vessel for carrying liquids.</def> <ldquo/Samuel took the
<xex>horn</xex>of oil and anointed him [David].<rdquo/ <au>1 Sam. xvi.
13.</au> <sd>(e)</sd> <def>The pointed beak of an anvil.</def>
<sd>(f)</sd> <def>The high pommel of a saddle; also, either of the
projections on a lady's saddle for supporting the leg.</def>
<sd>(g)</sd> <fld>(Arch.)</fld> <def>The Ionic volute.</def>
<sd>(h)</sd> <fld>(Naut.)</fld> <def>The outer end of a crosstree; also,
one of the projections forming the jaws of a gaff, boom, etc.</def>
<sd>(i)</sd> <fld>(Carp.)</fld> <def>A curved projection on the fore
part of a plane.</def> <sd>(j)</sd> <def>One of the projections at the
four corners of the Jewish altar of burnt offering.</def> <ldquo/Joab .
. . caught hold on the <xex>horns</xex> of the altar.<rdquo/ <au>1 Kings
ii. 28.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>One of the curved ends of a crescent; esp., an
extremity or cusp of the moon when crescent-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The moon<br/
Wears a wan circle round her blunted <qex>horns</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mil.)</fld> <def>The curving extremity of the wing
of an army or of a squadron drawn up in a crescentlike form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sharpening in mooned <qex>horns</qex><br/
Their phalanx.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The tough, fibrous material of which true horns are
composed, being, in the Ox family, chiefly albuminous, with some
phosphate of lime; also, any similar substance, as that which forms the
hoof crust of horses, sheep, and cattle; <as>as, a spoon of
<ex>horn</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Script.)</fld> <def>A symbol of strength, power,
glory, exaltation, or pride.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord is . . . the <qex>horn</qex> of my salvation.</q>
<rj><qau>Ps. xviii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>An emblem of a cuckold; -- used chiefly in the
plural.</def> <ldquo/Thicker than a cuckold's <xex>horn</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>the <er>telephone</er>; <as>as, on the
<ex>horn</ex></as>.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>12.</sn> <def>a body of water shaped like a horn; <as>as, the
Golden <ex>Horn</ex> in Istanbul</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Horn block</b></col>, <cd>the frame or pedestal in which
a railway car axle box slides up and down; -- also called <altname>horn
plate</altname>.</cd> -- <col><b>Horn of a dilemma</b></col>. <cd>See
under <er>Dilemma</er>.</cd> -- <col><b>Horn distemper</b></col>, <cd>a
disease of cattle, affecting the internal substance of the horn.</cd> --
<col><b>Horn drum</b></col>, <cd>a wheel with long curved scoops, for
raising water.</cd> -- <col><b>Horn lead</b></col> <fld>(Chem.)</fld>,
<cd>chloride of lead.</cd> -- <col><b>Horn maker</b></col>, <cd>a maker
of cuckolds.</cd> <mark>[Obs.]</mark> <au>Shak.</au> -- <col><b>Horn
mercury</b></col>. <fld>(Min.)</fld> <cd>Same as <cref>Horn
quicksilver</cref> (below).</cd> -- <col><b>Horn poppy</b></col>
<fld>(Bot.)</fld>, <cd>a plant allied to the poppy (<spn>Glaucium
luteum</spn>), found on the sandy shores of Great Britain and Virginia;
-- called also <altname>horned poppy</altname>.</cd> <au>Gray.</au> --
<col><b>Horn pox</b></col> <fld>(Med.)</fld>, <cd>abortive smallpox with
an eruption like that of chicken pox.</cd> -- <col><b>Horn
quicksilver</b></col> <fld>(Min.)</fld>, <cd>native calomel, or
bichloride of mercury.</cd> -- <col><b>Horn shell</b></col>
<fld>(Zool.)</fld>, <cd>any long, sharp, spiral, gastropod shell, of the
genus <gen>Cerithium</gen>, and allied genera.</cd> -- <col><b>Horn
silver</b></col> <fld>(Min.)</fld>, <cd>cerargyrite.</cd> --
<col><b>Horn slate</b></col>, <cd>a gray, siliceous stone.</cd> --
<mcol><col><b>To pull in one's horns</b></col>, <col><b>To haul in one's
horns</b></col></mcol>, <cd>to withdraw some arrogant pretension; to
cease a demand or withdraw an assertion.</cd> <mark>[Colloq.]</mark> --
<mcol><col><b>To raise the horn</b></col>, <it>or</it> <col><b>To lift
the horn</b></col></mcol> <fld>(Script.)</fld>, <cd>to exalt one's self;
to act arrogantly.</cd> <ldquo/'Gainst them that raised thee dost thou
<xex>lift</xex> thy <xex>horn</xex>?<rdquo/ <au>Milton.</au> --
<col><b>To take a horn</b></col>, <cd>to take a drink of intoxicating
liquor.</cd> <mark>[Low]</mark></cs> <-- blow one's own horn. To call
attention to one's own accomplishments. opposed to "hide one's light
under a bushel" --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horn</ent><br/
<hw>Horn</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To furnish
with horns; to give the shape of a horn to.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to wear horns; to cuckold.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornbeak</ent><br/
<hw>Horn"beak`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fish. See
<er>Hornfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornbeam</ent><br/
<hw>Horn"beam`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Beam</er>.]</ety> <fld>(Bot.)</fld> <def>A tree of the genus
<gen>Carpinus</gen> (<spn>Carpinus Americana</spn>), having a smooth
gray bark and a ridged trunk, the wood being white and very hard. It is
common along the banks of streams in the United States, and is also
called <altname>ironwood</altname>. The English hornbeam is
<spn>Carpinus Betulus</spn>. The American is called also <altname>blue
beech</altname> and <altname>water beech</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hop hornbeam</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Hop</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornbill</ent><br/
<hw>Horn"bill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any bird of the family <fam>Bucerotid<ae/</fam>, of which about
sixty species are known, belonging to numerous genera. They inhabit the
tropical parts of Asia, Africa, and the East Indies, and are remarkable
for having a more or less horn-like protuberance, which is usually large
and hollow and is situated on the upper side of the beak. The size of
the hornbill varies from that of a pigeon to that of a raven, or even
larger. They feed chiefly upon fruit, but some species eat dead
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 706 --></p>

<p><ent>Hornblende</ent><br/
<hw>Horn"blende`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., fr.
<ets>horn</ets> horn + <ets>blende</ets> blende.]</ety>
<fld>(Min.)</fld> <def>The common black, or dark green or brown, variety
of amphibole. (See <er>Amphibole</er>.) It belongs to the aluminous
division of the species, and is also characterized by its containing
considerable iron. Also used as a general term to include the whole
species.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hornblende schist</b></col> <fld>(Geol.)</fld>, <cd>a
hornblende rock of schistose structure.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornblendic</ent><br/
<hw>Horn*blend"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Composed largely
of hornblende; resembling or relating to hornblende.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornblower</ent><br/
<hw>Horn"blow`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hornbl<amac/were</ets>.]</ety> <def>One who, or that which, blows a
horn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornbook</ent><br/
<hw>Horn"book`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
first book for children, or that from which in former times they learned
their letters and rudiments; -- so called because a sheet of horn
covered the small, thin board of oak, or the slip of paper, on which the
alphabet, digits, and often the Lord's Prayer, were written or printed;
a primer.</def> <ldquo/He teaches boys the <xex>hornbook</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A book containing the rudiments of any science or
branch of knowledge; a manual; a handbook.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornbug</ent><br/
<hw>Horn"bug`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
large nocturnal beetle of the genus <gen>Lucanus</gen> (as <spn>Lucanus
capreolus</spn>, and <spn>Lucanus dama</spn>), having long, curved upper
jaws, resembling a sickle. The grubs are found in the trunks of old
trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horned</ent><br/
<hw>Horned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with a horn
or horns; furnished with a hornlike process or appendage; <as>as,
<ex>horned</ex> cattle</as>; having some part shaped like a
horn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>horned</qex> moon with one bright star<br/
Within the nether tip.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horned bee</b></col> <fld>(Zool.)</fld>, <cd>a British
wild bee (<spn>Osmia bicornis</spn>), having two little horns on the
head.</cd> -- <col><b>Horned dace</b></col> <fld>(Zool.)</fld>, <cd>an
American cyprinoid fish (<spn>Semotilus corporialis</spn>) common in
brooks and ponds; the common chub. See <xex>Illust.</xex> of
<er>Chub</er>.</cd> -- <col><b>Horned frog</b></col> <fld>(Zool.)</fld>,
<cd>a very large Brazilian frog (<spn>Ceratophrys cornuta</spn>), having
a pair of triangular horns arising from the eyelids.</cd> --
<col><b>Horned grebe</b></col> <fld>(Zool.)</fld>, <cd>a species of
grebe (<spn>Colymbus auritus</spn>), of Arctic Europe and America,
having two dense tufts of feathers on the head.</cd> -- <col><b>Horned
horse</b></col> <fld>(Zool.)</fld>, <cd>the gnu.</cd> -- <col><b>Horned
lark</b></col> <fld>(Zool.)</fld>, <cd>the shore lark.</cd> --
<col><b>Horned lizard</b></col> <fld>(Zool.)</fld>, <cd>the horned
toad.</cd> -- <col><b>Horned owl</b></col> <fld>(Zool.)</fld>, <cd>a
large North American owl (<spn>Bubo Virginianus</spn>), having a pair of
elongated tufts of feathers on the head. Several distinct varieties are
known; as, the Arctic, Western, dusky, and striped <xex>horned
owls</xex>, differing in color, and inhabiting different regions; --
called also <altname>great horned owl</altname>, <altname>horn
owl</altname>, <altname>eagle owl</altname>, and <altname>cat
owl</altname>. Sometimes also applied to the <altname>long-eared
owl</altname>. See <cref>Eared owl</cref>, under <er>Eared</er>.</cd> --
<col><b>Horned poppy</b></col>. <fld>(Bot.)</fld> <cd>See <cref>Horn
poppy</cref>, under <er>Horn</er>.</cd> -- <col><b>Horned pout</b></col>
<fld>(Zool.)</fld>, <cd>an American fresh-water siluroid fish; the
bullpout.</cd> -- <col><b>Horned rattler</b></col> <fld>(Zool.)</fld>,
<cd>a species of rattlesnake (<spn>Crotalus cerastes</spn>), inhabiting
the dry, sandy plains, from California to Mexico. It has a pair of
triangular horns between the eyes; -- called also
<altname>sidewinder</altname>.</cd> -- <col><b>Horned ray</b></col>
<fld>(Zool.)</fld>, <cd>the sea devil.</cd> -- <col><b>Horned
screamer</b></col> <fld>(Zool.)</fld>, <cd>the kamichi.</cd> --
<col><b>Horned snake</b></col> <fld>(Zool.)</fld>, <cd>the
cerastes.</cd> -- <col><b>Horned toad</b></col> <fld>(Zool.)</fld>,
<cd>any lizard of the genus <gen>Phrynosoma</gen>, of which nine or ten
species are known. These lizards have several hornlike spines on the
head, and a broad, flat body, covered with spiny scales. They inhabit
the dry, sandy plains from California to Mexico and Texas. Called also
<altname>horned lizard</altname>.</cd> -- <col><b>Horned
viper</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Cerastes</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornedness</ent><br/
<hw>Horn"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
being horned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornel</ent><br/
<hw>Horn"el</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
European sand eel.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horneophyton</ent><br/
<hw>Horneophyton</hw> <pos>n.</pos> <def>A genus of Devonian fossil
plants considered one of the earliest forms of vascular land plants; it
is similar to genus <gen>Rhynia</gen> but smaller.</def><br/
<syn><b>Syn. --</b> genus <gen>Horneophyton</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Horner</ent><br/
<hw>Horn"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
works or deal in horn or horns.</def> <mark>[R.]</mark>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who winds or blows the horn.</def>
<mark>[Obs.]</mark> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who horns or cuckolds.</def> <mark>[Obs.]</mark>
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>The British sand lance or sand
eel (<spn>Ammodytes lanceolatus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornet</ent><br/
<hw>Hor"net</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hyrnet</ets>; akin to OHG. <ets>hornaz</ets>, <ets>hornuz</ets>, G.
<ets>horniss</ets>; perh. akin to E. <ets>horn</ets>, and named from the
sound it makes as if blowing the horn; but more prob. akin to D.
<ets>horzel</ets>, Lith. <ets>szirszone</ets>, L.
<ets>crabo</ets>.]</ety> <fld>(Zool.)</fld> <def>A large, strong wasp.
The European species (<spn>Vespa crabro</spn>) is of a dark brown and
yellow color. It is very pugnacious, and its sting is very severe. Its
nest is constructed of a paperlike material, and the layers of comb are
hung together by columns. The American white-faced hornet (<spn>Vespa
maculata</spn>) is larger and has similar habits.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hornet fly</b></col> <fld>(Zool.)</fld>, <cd>any
dipterous insect of the genus <gen>Asilus</gen>, and allied genera, of
which there are numerous species. They are large and fierce flies which
capture bees and other insects, often larger than themselves, and suck
their blood. Called also <altname>hawk fly</altname>, <altname>robber
fly</altname>.</cd> -- <col><b>To stir up a hornet's nest</b></col>,
<cd>to provoke the attack of a swarm of spiteful enemies or spirited
critics.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornfish</ent><br/
<hw>Horn"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hornfisc</ets>.]</ety> <fld>(Zool.)</fld> <def>The garfish or sea
needle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornfoot</ent><br/
<hw>Horn"foot`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having hoofs;
hoofed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornify</ent><br/
<hw>Horn"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Horn</ets>
+ <ets>-fy</ets>.]</ety> <def>To horn; to cuckold.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horning</ent><br/
<hw>Horn"ing</hw>, <pos>n.</pos> <def>Appearance of the moon when
increasing, or in the form of a crescent.</def> <rj><au>J.
Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Letters of horning</b></col> <fld>(Scots Law)</fld>,
<cd>the process or authority by which a person, directed by the decree
of a court of justice to pay or perform anything, is ordered to comply
therewith.</cd> <rj><au>Mozley & W.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornish</ent><br/
<hw>Horn"ish</hw>, <pos>a.</pos> <def>Somewhat like horn;
hard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornito</ent><br/
\'d8<hw>Hor*ni"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A dim. fr. Sp.
<ets>horno</ets> oven, L. <ets>furnus</ets>. See
<er>Furnace</er>.]</ety> <fld>(Geol.)</fld> <def>A low, oven-shaped
mound, common in volcanic regions, and emitting smoke and vapors from
its sides and summit.</def> <rj><au>Humboldt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornless</ent><br/
<hw>Horn"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having no
horn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horn-mad</ent><br/
<hw>Horn"-mad`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Quite mad; --
raving crazy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Did I tell you about Mr. Garrick, that the town are
<qex>horn-mad</qex> after?</q> <rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornotine</ent><br/
<hw>Hor"no*tine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hornotinus</ets> of this year.]</ety> <fld>(Zool.)</fld> <def>A
yearling; a bird of the year.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornowl</ent><br/
<hw>Horn"owl`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Horned Owl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornpike</ent><br/
<hw>Horn"pike`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The garfish.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornpipe</ent><br/
<hw>Horn"pipe`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<sd>(a)</sd> <def>An instrument of music formerly popular in Wales,
consisting of a wooden pipe, with holes at intervals. It was so called
because the bell at the open end was sometimes made of horn.</def>
<sd>(b)</sd> <def>A lively tune played on a hornpipe, for dancing; a
tune adapted for such playing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many a <qex>hornpipe</qex> he tuned to his Phyllis.</q>
<rj><qau>Sir W. Raleigh.</qau></rj></p>

<p><sd>(c)</sd> A dance performed, usually by one person, to such a
tune, and popular among sailors.<-- = sailor's hornpipe --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornpout</ent><br/
<hw>Horn"pout`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <cref>Horned pout</cref>, under <er>Horned</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornsnake</ent><br/
<hw>Horn"snake`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A harmless snake (<spn>Farancia abacura</spn>), found in the
Southern United States. The color is bluish black above, red
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornstone</ent><br/
<hw>Horn"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A siliceous stone, a variety of quartz, closely resembling flint,
but more brittle; -- called also <altname>chert</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horntail</ent><br/
<hw>Horn"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of family (<fam>Urocerid<ae/</fam>) of large hymenopterous
insects, allied to the sawflies. The larv<ae/ bore in the wood of trees.
So called from the long, stout ovipositors of the females.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornwork</ent><br/
<hw>Horn"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Fort.)</fld>
<def>An outwork composed of two demibastions joined by a curtain. It is
connected with the works in rear by long wings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornwort</ent><br/
<hw>Horn"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An aquatic plant (<gen>Ceratophyllum</gen>), with finely divided
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornwrack</ent><br/
<hw>Horn"wrack`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A bryozoan of the genus <gen>Flustra</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horny</ent><br/
<hw>Horn"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Hornier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Horniest</adjf>.]</amorph> <sn>1.</sn> <def>Having horns or
hornlike projections.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Composed or made of horn, or of a substance
resembling horn; of the nature of horn.</def> <ldquo/The
<xex>horny</xex> . . . coat of the eye.<rdquo/
<rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hard; callous.</def> <ldquo/His <xex>horny</xex>
fist.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horny-handed</ent><br/
<hw>Horn"y-hand`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
hands horny and callous from labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hornyhead</ent><br/
<hw>Horn"y*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any North American river chub of the genus <gen>Hybopsis</gen>,
esp. <spn>Hybopsis biguttatus</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horography</ent><br/
<hw>Ho*rog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ hour +
<ets>-graphy</ets>: cf. F. <ets>horographie</ets>.]</ety> <sn>1.</sn>
<def>An account of the hours.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The art of constructing instruments for making the
hours, as clocks, watches, and dials.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horologe</ent><br/
<hw>Hor"o*loge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>horologe</ets>, <ets>orloge</ets>, timepiece, OF.
<ets>horloge</ets>, <ets>orloge</ets>, <ets>oriloge</ets>, F.
<ets>horloge</ets>, L. <ets>horologium</ets>, fr. Gr. <?/; <?/ hour +
<?/ to say, tell. See <er>Hour</er>, and <er>Logic</er>.]</ety>
<sn>1.</sn> <def>A servant who called out the hours.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instrument indicating the time of day; a
timepiece of any kind; a watch, clock, or dial.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horologer</ent><br/
<hw>Ho*rol"o*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A maker or vender
of clocks and watches; one skilled in horology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horological</ent><br/
<hw>Hor`o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>horologicus</ets>, Gr. <?/.]</ety> <def>Relating to a horologe, or
to horology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horologiographer</ent><br/
<hw>Hor`o*lo`gi*og"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Horologiography</er>.]</ety> <def>A maker of clocks, watches, or
dials.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horologiographic</ent><br/
<hw>Hor`o*lo`gi*o*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to horologiography.</def> <rj><au>Chambers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horologiography</ent><br/
<hw>Hor`o*lo`gi*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
horologe + <ets>-graphy</ets>.]</ety> <sn>1.</sn> <def>An account of
instruments that show the hour.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The art of constructing clocks or dials;
horography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horologist</ent><br/
<hw>Ho*rol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
horology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horology</ent><br/
<hw>Ho*rol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Horologe</er>.]</ety> <def>The science of measuring time, or the
principles and art of constructing instruments for measuring and
indicating portions of time, as clocks, watches, dials, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horometer</ent><br/
<hw>Ho*rom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ hour +
<ets>-meter</ets>.]</ety> <def>An instrument for measuring
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horometrical</ent><br/
<hw>Hor`o*met"ric*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging to
horometry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horometry</ent><br/
<hw>Ho*rom"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>horom<eacute/trie</ets>. See <er>Horometer</er>.]</ety> <def>The
art, practice, or method of measuring time by hours and subordinate
divisions.</def> <ldquo/The <xex>horometry</xex> of antiquity.<rdquo/
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horopter</ent><br/
<hw>Ho*rop"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ boundary +
<?/ one who looks.]</ety> <fld>(Opt.)</fld> <def>The line or surface in
which are situated all the points which are seen single while the point
of sight, or the adjustment of the eyes, remains unchanged.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sum of all the points which are seen single, while the point
of sight remains unchanged, is called the <qex>horopter</qex>.</q>
<rj><qau>J. Le Conte.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horopteric</ent><br/
<hw>Hor`op*ter"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Opt.)</fld>
<def>Of or pertaining to the horopter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horoscope</ent><br/
<hw>Hor"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>horoscope</ets>, L. <ets>horoscopus</ets>, fr. Gr. <?/, adj.,
observing hours or times, esp. observing the hour of birth,
<pos>n.</pos>, a horoscope; <?/ hour + <?/ to view, observe. See
<er>Hour</er>, and <er>-scope</er>.]</ety> <sn>1.</sn>
<fld>(Astrol.)</fld> <sd>(a)</sd> <def>The representation made of the
aspect of the heavens at the moment of a person's birth, by which the
astrologer professed to foretell the events of the person's life;
especially, the sign of the zodiac rising above the horizon at such a
moment.</def> <sd>(b)</sd> <def>The diagram or scheme of twelve houses
or signs of the zodiac, into which the whole circuit of the heavens was
divided for the purposes of such prediction of fortune.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The planisphere invented by Jean Paduanus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A table showing the length of the days and nights at
all places.</def> <rj><au>Heyse.</au></rj></p>

<p><ent>Horoscopist</ent><br/
<ent>Horoscoper</ent><br/
<mhw>{ <hw>Hor"o*sco`per</hw> <pr>(?)</pr>, <hw>Ho*ros"co*pist</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>One versed in horoscopy; an
astrologer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horoscopy</ent><br/
<hw>Ho*ros"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
art or practice of casting horoscopes, or observing the disposition of
the stars, with a view to prediction events.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Aspect of the stars at the time of a person's
birth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrendous</ent><br/
<hw>Hor*ren"dous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>horrendus</ets>.]</ety> <def>Fearful; frightful.</def>
<mark>[Obs.]</mark> <rj><au>I. Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrent</ent><br/
<hw>Hor"rent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>horrens</ets>, p. pr. of <ets>horrere</ets> to bristle. See
<er>Horror</er>.]</ety> <def>Standing erect, as bristles; covered with
bristling points; bristled; bristling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rough and <qex>horrent</qex> with figures in strong relief.</q>
<rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With bright emblazonry and <qex>horrent</qex> arms.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrible</ent><br/
<hw>Hor"ri*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>horrible</ets>, <ets>orrible</ets>, OF. <ets>horrible</ets>,
<ets>orrible</ets>, F. <ets>horrible</ets>, fr. L.
<ets>horribilis</ets>, fr. <ets>horrere</ets>. See
<er>Horror</er>.]</ety> <def>Exciting, or tending to excite, horror or
fear; dreadful; terrible; shocking; hideous; <as>as, a <ex>horrible</ex>
sight; a <ex>horrible</ex> story; a <ex>horrible</ex>
murder.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A dungeon <qex>horrible</qex> on all sides round.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Dreadful; frightful; fearful; terrible; awful;
terrific; shocking; hideous; horrid.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horribleness</ent><br/
<hw>Hor"ri*ble*ness</hw>, <pos>n.</pos> <def>The state or quality of
being horrible; dreadfulness; hideousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>horribleness</qex> of the mischief.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horribly</ent><br/
<hw>Hor"ri*bly</hw>, <pos>adv.</pos> <def>In a manner to excite horror;
dreadfully; terribly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrid</ent><br/
<hw>Hor"rid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>horridus</ets>. See <er>Horror</er>, and cf.
<er>Ordure</er>.]</ety> <sn>1.</sn> <def>Rough; rugged; bristling.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Horrid</qex> with fern, and intricate with thorn.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fitted to excite horror; dreadful; hideous;
shocking; hence, very offensive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not in the legions<br/
Of <qex>horrid</qex> hell.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>horrid</qex> things they say.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- Frightful; hideous; alarming; shocking; dreadful;
awful; terrific; horrible; abominable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horridly</ent><br/
<hw>Hor"rid*ly</hw>, <pos>adv.</pos> <def>In a horrid manner.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horridness</ent><br/
<hw>Hor"rid*ness</hw>, <pos>n.</pos> <def>The quality of being
horrid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrific</ent><br/
<hw>Hor*rif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>horrifieus</ets>; <ets>horrere</ets> to be horrible +
<ets>-ficare</ets> (in comp.) to make: cf. F. <ets>horrifique</ets>. See
<er>Horror</er>, <er>-fy</er>.]</ety> <def>Causing horror;
frightful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let . . . nothing ghastly or <qex>horrific</qex> be supposed.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrification</ent><br/
<hw>Hor`ri*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
causes horror.</def> <mark>[R.]</mark> <rj><au>Miss
Edgeworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrify</ent><br/
<hw>Hor"ri*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Horrified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Horrifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>horrificare</ets>. See <er>Horrific</er>.]</ety> <def>To cause to
feel horror; to strike or impress with horror; <as>as, the sight
<ex>horrified</ex> the beholders</as>.</def> <rj><au>E.
Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horripilation</ent><br/
<hw>Hor*rip`i*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>horripilatio</ets>, fr. <ets>horripilare</ets> to bristle;
<ets>horrere</ets> to bristle + <ets>pilus</ets> the hair: cf. F.
<ets>horripilation</ets>.]</ety> <fld>(Med.)</fld> <def>A real or
fancied bristling of the hair of the head or body, resulting from
disease, terror, chilliness, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrisonant</ent><br/
<hw>Hor*ris"o*nant</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Horrisonous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horrisonous</ent><br/
<hw>Hor*ris"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>horrisonus</ets>; <ets>horrere</ets> to be horrible +
<ets>sonus</ets> a sound.]</ety> <def>Sounding dreadfully; uttering a
terrible sound.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horror</ent><br/
<hw>Hor"ror</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Formerly written
<ets>horrour</ets>.]</ety> <ety>[L. <ets>horror</ets>, fr.
<ets>horrere</ets> to bristle, to shiver, to tremble with cold or dread,
to be dreadful or terrible; cf. Skr. <ets>h<?/sh</ets> to
bristle.]</ety> <sn>1.</sn> <def>A bristling up; a rising into
roughness; tumultuous movement.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such fresh <qex>horror</qex> as you see driven through the
wrinkled waves.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A shaking, shivering, or shuddering, as in the cold
fit which precedes a fever; in old medical writings, a chill of less
severity than a <xex>rigor</xex>, and more marked than an
<xex>algor</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A painful emotion of fear, dread, and abhorrence; a
shuddering with terror and detestation; the feeling inspired by
something frightful and shocking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How could this, in the sight of heaven, without <qex>horrors</qex>
of conscience be uttered?</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which excites horror or dread, or is horrible;
gloom; dreariness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Breathes a browner <qex>horror</qex> on the woods.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The horrors</b></col>, <cd>delirium tremens.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 707 --></p>

<p><ent>Horror-sticken</ent><br/
<hw>Hor"ror-stick`en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Struck with
horror; horrified.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blank and <qex>horror-stricken</qex> faces.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horror-struck</ent><br/
<hw>Hor"ror-struck`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Horror-stricken; horrified.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hors de combat</ent><br/
\'d8<hw>Hors` de com`bat"</hw> <pr>(?)</pr>. <ety>[F.]</ety> <def>Out of
the combat; disabled from fighting; out of action.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hors d'oeuvre</ent><br/
\'d8<hw>Hors` d'<oe/uvre"</hw> <pr>(?)</pr>; <plu>pl. <plw>Hors
d'<oe/uveres</plw> <pr>(#)</pr></plu>. <ety>[F., lit., outside of
work.]</ety> <sn>1.</sn> <def>Something unusual or extraordinary.</def>
<mark>[R.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A dish served as a relish, usually at the beginning
of a meal.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Horse</ent><br/
<hw>Horse</hw> <pr>(h<ocir/rs)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hors</ets>; akin to OS. <ets>hros</ets>, D. & OHG. <ets>ros</ets>,
G. <ets>ross</ets>, Icel. <ets>hross</ets>; and perh. to L.
<ets>currere</ets> to run, E. <ets>course</ets>, <ets>current</ets> Cf.
<er>Walrus</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A hoofed
quadruped of the genus <gen>Equus</gen>; especially, the domestic horse
(<spn>Equus caballus</spn>), which was domesticated in Egypt and Asia at
a very early period. It has six broad molars, on each side of each jaw,
with six incisors, and two canine teeth, both above and below. The mares
usually have the canine teeth rudimentary or wanting. The horse differs
from the true asses, in having a long, flowing mane, and the tail bushy
to the base. Unlike the asses it has callosities, or chestnuts, on all
its legs. The horse excels in strength, speed, docility, courage, and
nobleness of character, and is used for drawing, carrying, bearing a
rider, and like purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Many varieties, differing in form, size, color, gait,
speed, etc., are known, but all are believed to have been derived from
the same original species. It is supposed to have been a native of the
plains of Central Asia, but the wild species from which it was derived
is not certainly known. The feral horses of America are domestic horses
that have run wild; and it is probably true that most of those of Asia
have a similar origin. Some of the true wild Asiatic horses do, however,
approach the domestic horse in several characteristics.<br/
Several species of fossil (<gen>Equus</gen>) are known from the later
Tertiary formations of Europe and America. The fossil species of other
genera of the family <fam>Equid<ae/</fam> are also often called
<ex>horses</ex>, in general sense.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The male of the genus <gen>Equus</gen>, in
distinction from the female or male; usually, a castrated
male.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Mounted soldiery; cavalry; -- used without the
plural termination; <as>as, a regiment of <ex>horse</ex></as>; --
distinguished from <contr>foot</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The armies were appointed, consisting of twenty-five thousand
<qex>horse</qex> and foot.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A frame with legs, used to support something;
<as>as, a clothes<ex>horse</ex>, a saw<ex>horse</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A frame of timber, shaped like a horse, on which
soldiers were made to ride for punishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Anything, actual or figurative, on which one rides
as on a horse; a hobby.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mining)</fld> <def>A mass of earthy matter, or rock
of the same character as the wall rock, occurring in the course of a
vein, as of coal or ore; hence, to <xex>take horse</xex> -- said of a
vein -- is to divide into branches for a distance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>See
<er>Footrope</er>, <pos>a.</pos></def> <sd>(b)</sd> <def>A breastband
for a leadsman.</def> <sd>(c)</sd> <def>An iron bar for a sheet traveler
to slide upon.</def> <sd>(d)</sd> <def>A jackstay.</def> <au>W. C.
Russell.</au> <au>Totten.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Student Slang)</fld> <sd>(a)</sd> <def>A
translation or other illegitimate aid in study or examination; -- called
also <altname>trot</altname>, <altname>pony</altname>,
<altname>Dobbin</altname>.</def> <sd>(b)</sd> <def>Horseplay;
tomfoolery.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>10.</sn> <def><er>heroin</er>.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>11.</sn> <def><er>horsepower</er>.</def> <mark>[Colloq.
contraction]</mark><br/
[<source>PJC</source>]</p>

<p><note><hand/ <xex>Horse</xex> is much used adjectively and in
composition to signify <xex>of</xex>, or <xex>having to do with</xex>,
<xex>a horse</xex> or <xex>horses</xex>, <xex>like a horse</xex>, etc.;
as, <xex>horse</xex> collar, <xex>horse</xex> dealer or
<xex>horse</xex>-dealer, <xex>horse</xex>hoe, <xex>horse</xex> jockey;
and hence, often in the sense of <xex>strong</xex>, <xex>loud</xex>,
<xex>coarse</xex>, etc.; as, <xex>horse</xex>laugh, <xex>horse</xex>
nettle or <xex>horse</xex>-nettle, <xex>horse</xex>play,
<xex>horse</xex> ant, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Black horse</b></col>, <col><b>Blood
horse</b></col></mcol>, <cd>etc. See under <er>Black</er>, etc.</cd> --
<col><b>Horse aloes</b></col>, <cd>caballine aloes.</cd> --
<col><b>Horse ant</b></col> <fld>(Zool.)</fld>, <cd>a large ant
(<spn>Formica rufa</spn>); -- called also <altname>horse
emmet</altname>.</cd> -- <col><b>Horse artillery</b></col>, <cd>that
portion of the artillery in which the cannoneers are mounted, and which
usually serves with the cavalry; flying artillery.</cd> -- <col><b>Horse
balm</b></col> <fld>(Bot.)</fld>, <cd>a strong-scented labiate plant
(<spn>Collinsonia Canadensis</spn>), having large leaves and yellowish
flowers.</cd> -- <col><b>Horse bean</b></col> <fld>(Bot.)</fld>, <cd>a
variety of the English or Windsor bean (<spn>Faba vulgaris</spn>), grown
for feeding horses.</cd> -- <col><b>Horse boat</b></col>, <cd>a boat for
conveying horses and cattle, or a boat propelled by horses.</cd> --
<col><b>Horse bot</b></col>. <fld>(Zool.)</fld> <cd>See <er>Botfly</er>,
and <er>Bots</er>.</cd> -- <col><b>Horse box</b></col>, <cd>a railroad
car for transporting valuable horses, as hunters.</cd>
<mark>[Eng.]</mark> -- <mcol><col><b>Horse breaker</b></col> <it>or</it>
<col><b>Horse trainer</b></col></mcol>, <cd>one employed in subduing or
training horses for use.</cd> -- <col><b>Horse car</b></col>.
<sd>(a)</sd> <cd>A railroad car drawn by horses. See under
<er>Car</er>.</cd> <sd>(b)</sd> <cd>A car fitted for transporting
horses.</cd> -- <col><b>Horse cassia</b></col> <fld>(Bot.)</fld>, <cd>a
leguminous plant (<spn>Cassia Javanica</spn>), bearing long pods, which
contain a black, catharic pulp, much used in the East Indies as a horse
medicine.</cd> -- <col><b>Horse cloth</b></col>, <cd>a cloth to cover a
horse.</cd> -- <col><b>Horse conch</b></col> <fld>(Zool.)</fld>, <cd>a
large, spiral, marine shell of the genus Triton. See
<er>Triton</er>.</cd> -- <col><b>Horse courser</b></col>. <sd>(a)</sd>
<cd>One that runs horses, or keeps horses for racing.</cd>
<au>Johnson.</au> <sd>(b)</sd> <cd>A dealer in horses.</cd>
<mark>[Obs.]</mark> <au>Wiseman.</au> -- <col><b>Horse crab</b></col>
<fld>(Zool.)</fld>, <cd>the Limulus; -- called also
<altname>horsefoot</altname>, <altname>horsehoe crab</altname>, and
<altname>king crab</altname>.</cd> -- <col><b>Horse
crevall<eacute/</b></col> <fld>(Zool.)</fld>, <cd>the cavally.</cd><-- a
type of fish --> -- <col><b>Horse emmet</b></col> <fld>(Zool.)</fld>,
<cd>the horse ant.</cd> -- <col><b>Horse finch</b></col>
<fld>(Zool.)</fld>, <cd>the chaffinch.</cd> <mark>[Prov. Eng.]</mark> --
<col><b>Horse gentian</b></col> <fld>(Bot.)</fld>, <cd>fever root.</cd>
-- <col><b>Horse iron</b></col> <fld>(Naut.)</fld>, <cd>a large calking
iron.</cd> -- <col><b>Horse latitudes</b></col>, <cd>a space in the
North Atlantic famous for calms and baffling winds, being between the
westerly winds of higher latitudes and the trade winds.</cd> <au>Ham.
Nav. Encyc.</au> -- <col><b>Horse mackrel</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The common tunny (<spn>Orcynus thunnus</spn>), found on
the Atlantic coast of Europe and America, and in the Mediterranean.</cd>
<sd>(b)</sd> <cd>The bluefish (<spn>Pomatomus saltatrix</spn>).</cd>
<sd>(c)</sd> <cd>The scad.</cd> <sd>(d)</sd> <cd>The name is locally
applied to various other fishes, as the California hake, the black
candlefish, the jurel, the bluefish, etc.</cd> -- <col><b>Horse
marine</b></col> <fld>(Naut.)</fld>, <cd>an awkward, lubbery person; one
of a mythical body of marine cavalry.</cd> <mark>[Slang]</mark> --
<col><b>Horse mussel</b></col> <fld>(Zool.)</fld>, <cd>a large, marine
mussel (<spn>Modiola modiolus</spn>), found on the northern shores of
Europe and America.</cd> -- <col><b>Horse nettle</b></col>
<fld>(Bot.)</fld>, <cd>a coarse, prickly, American herb, the
<spn>Solanum Carolinense</spn>.</cd> -- <col><b>Horse parsley</b></col>.
<fld>(Bot.)</fld> <cd>See <er>Alexanders</er>.</cd> -- <col><b>Horse
purslain</b></col> <fld>(Bot.)</fld>, <cd>a coarse fleshy weed of
tropical America (<spn>Trianthema monogymnum</spn>).</cd> --
<col><b>Horse race</b></col>, <cd>a race by horses; a match of horses in
running or trotting.</cd> -- <col><b>Horse racing</b></col>, <cd>the
practice of racing with horses.</cd> -- <col><b>Horse
railroad</b></col>, <cd>a railroad on which the cars are drawn by
horses; -- in England, and sometimes in the United States, called a
<altname>tramway</altname>.</cd> -- <col><b>Horse run</b></col>
<fld>(Civil Engin.)</fld>, <cd>a device for drawing loaded wheelbarrows
up an inclined plane by horse power.</cd> -- <col><b>Horse
sense</b></col>, <cd>strong common sense.</cd> <mark>[Colloq.
U.S.]</mark> -- <col><b>Horse soldier</b></col>, <cd>a cavalryman.</cd>
-- <col><b>Horse sponge</b></col> <fld>(Zool.)</fld>, <cd>a large,
coarse, commercial sponge (<spn>Spongia equina</spn>).</cd> --
<col><b>Horse stinger</b></col> <fld>(Zool.)</fld>, a large dragon fly.
<mark>[Prov. Eng.]</mark> -- <col><b>Horse sugar</b></col>
<fld>(Bot.)</fld>, <cd>a shrub of the southern part of the United States
(<spn>Symplocos tinctoria</spn>), whose leaves are sweet, and good for
fodder.</cd> -- <col><b>Horse tick</b></col> <fld>(Zool.)</fld>, <cd>a
winged, dipterous insect (<spn>Hippobosca equina</spn>), which troubles
horses by biting them, and sucking their blood; -- called also
<altname>horsefly</altname>, <altname>horse louse</altname>, and
<altname>forest fly</altname>.</cd> -- <col><b>Horse vetch</b></col>
<fld>(Bot.)</fld>, <cd>a plant of the genus <gen>Hippocrepis</gen>
(<spn>Hippocrepis comosa</spn>), cultivated for the beauty of its
flowers; -- called also <altname>horsehoe vetch</altname>, from the
peculiar shape of its pods.</cd> -- <col><b>Iron horse</b></col>, <cd>a
locomotive.</cd> <mark>[Colloq.]</mark> -- <col><b>Salt horse</b></col>,
<cd>the sailor's name for salt beef.</cd> -- <col><b>To look a gift
horse in the mouth</b></col>, <cd>to examine the mouth of a horse which
has been received as a gift, in order to ascertain his age; -- hence, to
accept favors in a critical and thankless spirit.</cd> <au>Lowell.</au>
-- <col><b>To take horse</b></col>. <sd>(a)</sd> <cd>To set out on
horseback.</cd> <au>Macaulay.</au> <sd>(b)</sd> <cd>To be covered, as a
mare.</cd> <sd>(c)</sd> <cd>See definition 7 (above).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse</ent><br/
<hw>Horse</hw> <pr>(h<ocir/rs)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Horsed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Horsing</conjf>.]</vmorph> <ety>[AS.
<ets>horsion</ets>.]</ety> <sn>1.</sn> <def>To provide with a horse, or
with horses; to mount on, or as on, a horse.</def> <ldquo/Being better
<xex>horsed</xex>, outrode me.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sit astride of; to bestride.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To mate with (a mare); -- said of the
male.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To take or carry on the back; <as>as, the keeper,
<ex>horsing</ex> a deer</as>.</def> <rj><au>S. Butler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To place on the back of another, or on a wooden
horse, etc., to be flogged; to subject to such punishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse</ent><br/
<hw>Horse</hw>, <pos>v. i.</pos> <def>To get on horseback.</def>
<mark>[Obs.]</mark> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseback</ent><br/
<hw>Horse"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
back of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An extended ridge of sand, gravel, and boulders, in
a half-stratified condition.</def> <rj><au>Agassiz.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>On horseback</b></col>, <cd>on the back of a horse;
mounted or riding on a horse or horses; in the saddle.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The long journey was to be performed <qex>on horseback</qex>.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>horsebean</ent><br/
<hw>horsebean</hw> <pos>n.</pos> <sn>1.</sn> <def>The seed of the
broad-bean plant.</def><br/
<syn><b>Syn. --</b> broad bean, fava bean.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A large shrub or shrubby tree (<spn>Parkinsonia
aculeata</spn>) having sharp spines and pinnate leaves with small
deciduous leaflets and sweet-scented racemose yellow-orange flowers;
grown as ornamentals or hedging or emergency food for livestock;
originating in tropical America but naturalized in the Southern U.
S.</def><br/
<syn><b>Syn. --</b> Jerusalem thorn, <spn>Parkinsonia
aculeata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>horsebox</ent><br/
<hw>horsebox</hw> <pos>n.</pos> <def>a conveyance (railroad car or
trailer) for transporting racehorses.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>horsebrier</ent><br/
<hw>horsebrier</hw> <pos>n.</pos> <def>a very prickly woody vine
(<spn>Smilax rotundifolia</spn>) of eastern U. S. growing in tangled
masses having tough round stems with shiny leathery leaves and small
greenish flowers followed by clusters of inedible shiny black
berries.</def><br/
<syn><b>Syn. --</b> bullbrier, greenbrier, catbrier, brier, briar,
<spn>Smilax rotundifolia</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>horsecart</ent><br/
<hw>horse"cart`</hw> <pos>n.</pos> <sn>1.</sn> <def>A heavycart drawn by
a horse, used for farm work.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Horsechestnut</ent><br/
<ent>Horse-chestnut</ent><br/
<mhw><hw>Horse`-chest"nut</hw>, <hw>Horse`chest"nut</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <fld>(Bot.)</fld> <def>The large
nutlike seed of a species of <gen>Aesculus</gen> (<spn>Aesculus
Hippocastanum</spn>), formerly ground, and fed to horses, whence the
name. The seed is not considered edible by humans.</def>
<wns>[wns=2]</wns><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The tree itself (<spn>Aesculus
hippocastanum</spn>), which was brought from Constantinople in the
beginning of the sixteenth century, and is now common in the temperate
zones of both hemispheres; it has palmate leaves and large clusters of
white to red flowers followed by brown shiny inedible seeds. The native
American species is also called <altname>buckeye</altname> and
<altname>conker</altname>.</def> <wns>[wns=1]</wns><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>horsecloth</ent><br/
<hw>horsecloth</hw> <pos>n.</pos> <def>a cloth for the trapping of a
horse.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Horse-drench</ent><br/
<hw>Horse"-drench`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
dose of physic for a horse.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The appliance by which the dose is
administered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsefish</ent><br/
<hw>Horse"fish`</hw> <pr>(h<ocir/rs"f<icr/sh`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The moonfish (<spn>Selene
setipinnis</spn>).</def> <sd>(b)</sd> <def>The sauger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseflesh</ent><br/
<hw>Horse"flesh`</hw> <pr>(h<ocir/rs"fl<ecr/sh`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The flesh of horses.</def><br/
<syn><b>Syn. --</b> horsemeat.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>The Chinese eat <qex>horseflesh</qex> at this day.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Horses, generally; the qualities of a horse; <as>as,
he is a judge of <ex>horseflesh</ex></as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horseflesh ore</b></col> <fld>(Min.)</fld>, <cd>a miner's
name for bornite, in allusion to its peculiar reddish color on fresh
facture.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsefly</ent><br/
<hw>Horse"fly`</hw> <pr>(h<ocir/rs"fl<imac/`)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Horseflies</plw>
<pr>(h<ocir/rs"fl<imac/z`)</pr>.</plu> <sn>1.</sn> <fld>(Zool.)</fld>
<def>Any dipterous fly of the family <fam>Tabanidae</fam>, that stings
horses, and sucks their blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Of these flies there are numerous species, both in
Europe and America. They have a large proboscis with four sharp lancets
for piercing the skin. Called also <altname>breeze fly</altname>. See
<xex>Illust.</xex> under <er>Diptera</er>, and <er>Breeze
fly</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The horse tick or forest fly
(<gen>Hippobosca</gen>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsefoot</ent><br/
<hw>Horse"foot`</hw> <pr>(h<ocir/rs"f<oocr/t`)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Horsefeet</plw> <pr>(#)</pr>.</plu> <sn>1.</sn>
<fld>(Bot.)</fld> <def>The coltsfoot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The <gen>Limulus</gen> or
horseshoe crab.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse Guards</ent><br/
<hw>Horse" Guards`</hw> <pr>(h<ocir/rs"g<aum/rdz`)</pr>.
<fld>(Mil.)</fld> <def>A body of cavalry so called; esp., a British
regiment, called the Royal Horse Guards, which furnishes guards of state
for the sovereign.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Horse Guards</b></col>, <cd>a name given to the
former headquarters of the commander in chief of the British army, at
Whitehall in London.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsehair</ent><br/
<hw>Horse"hair`</hw> <pr>(h<ocir/rs"h<acir/r`)</pr>, <pos>n.</pos>
<def>A hair of a horse, especially one from the mane or tail; the hairs
of the mane or tail taken collectively;</def>
<specif>Specifically:</specif> <def>a black shiny fabric made of such
hairs, used commonly in the 1800's as a covering for stuffed furniture
such as chairs and couches.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Horsehair worm</b></col> <fld>(Zool.)</fld>, <cd>the hair
worm or gordius.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsehead</ent><br/
<hw>Horse"head`</hw> <pr>(h<ocir/rs"h<ecr/d`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The silver moonfish (<spn>Selene
vomer</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsehide</ent><br/
<hw>Horse"hide`</hw> <pr>(h<ocir/rs"h<imac/d`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The hide of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Leather made of the hide of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse-jockey</ent><br/
<hw>Horse"-jock`ey</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
professional rider and trainer of race horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trainer and dealer in horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseknop</ent><br/
<hw>Horse"knop`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Knapweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>horse latitude</ent><br/
<hw>horse" lat`i*tude</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Meteorology)</fld> <def>The latitudes from 30<deg/ to 35 <deg/
north or south of the equator. They are subtropical latitudes having
atmospheric high-pressure belts that encircle the Earth, where winds are
light and weather is usually clear, hot and dry. According to legend,
ships traveling to the New World often stagnated in this region and had
to throw dead horses overboard to conserve water for the crew, or eat
them to survive, hence the name horse latitudes. A horse latitude is
created because warm, wet air near the equator rises, cools, and drops
its moisture in heavy rains (creating tropical rainforest areas near the
equator). By the time the air reaches the high altitudes, it is cold and
dry and can not rise further, so it spreads out and moves toward the
poles and near the 30<deg/ north and 30<deg/ south, it begins to sink
toward the earth's surface., preventing moisture from reaching the area
from elsewhere. The regions mark the normal locations of the global
subtropical high pressure systems such as the <i>Bermuda High</i>,
moving a few degrees north or south of their position as the sun moves
in the sky with the seasons. Many of the worlds deserts are found at
these latitudes.</def> <au>University of Michigan Eco-Explorers,
2001</au><br/
[<source>PJC</source>]</p>

<p><ent>Horselaugh</ent><br/
<hw>Horse"laugh`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A loud,
boisterous laugh; a guffaw.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse-leech</ent><br/
<hw>Horse"-leech`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A large blood-sucking leech (<spn>H<ae/mopsis
vorax</spn>), of Europe and Northern Africa. It attacks the lips and
mouths of horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A farrier; a veterinary surgeon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse-leechery</ent><br/
<hw>Horse"-leech`er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The business
of a farrier; especially, the art of curing the diseases of
horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseless</ent><br/
<hw>Horse"less</hw>, <pos>a.</pos> <def>Being without a horse; specif.,
not requiring a horse; -- said of certain vehicles in which horse power
has been replaced by electricity, steam, etc.; <as>as, a
<ex>horseless</ex> carriage or truck</as>. It was used primarily in the
term <ldquo/<ex>horseless</ex> carriage<rdquo/, to refer to automobiles.
By the 1930's when automobiles had become more common than horses for
transportation, the term had lost its currency.</def> <mark>[archaic,
except in a historical context.]</mark> <br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Horse-litter</ent><br/
<hw>Horse"-lit`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A carriage hung
on poles, and borne by and between two horses.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseman</ent><br/
<hw>Horse"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Horsemen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A rider on
horseback; one skilled in the management of horses; a mounted
man.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A mounted soldier; a
cavalryman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A land crab of the
genus <gen>Ocypoda</gen>, living on the coast of Brazil and the West
Indies, noted for running very swiftly.</def> <sd>(b)</sd> <def>A West
Indian fish of the genus <gen>Eques</gen>, as the light-horseman
(<spn>Eques lanceolatus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsemanship</ent><br/
<hw>Horse"man*ship</hw>, <pos>n.</pos> <def>The act or art of riding,
and of training and managing horses; manege.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>horsemeat</ent><br/
<hw>horsemeat</hw> <pos>n.</pos> <def>The flesh of horses used as
food.</def><br/
<syn><b>Syn. --</b> horseflesh.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Horsemint</ent><br/
<hw>Horse"mint`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A coarse American plant of the Mint family
(<spn>Monarda punctata</spn>).</def> <sd>(b)</sd> <def>In England, the
wild mint (<spn>Mentha sylvestris</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsenail</ent><br/
<hw>Horse"nail`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A thin, pointed
nail, with a heavy flaring head, for securing a horseshoe to the hoof; a
horseshoe nail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseplay</ent><br/
<hw>Horse"play`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Rude, boisterous
play.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Too much given to <qex>horseplay</qex> in his raillery.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsepond</ent><br/
<hw>Horse"pond`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pond for
watering horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse power</ent><br/
<hw>Horse" pow`er</hw> <pr>(?)</pr>. <sn>1.</sn> <def>The power which a
horse exerts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A unit of power, used in stating
the power required to drive machinery, and in estimating the
capabilities of animals or steam engines and other prime movers for
doing work. It is the power required for the performance of work at the
rate of 33,000 English units of work per minute; hence, it is the power
that must be exerted in lifting 33,000 pounds at the rate of one foot
per minute, or 550 pounds at the rate of one foot per second, or 55
pounds at the rate of ten feet per second, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The power of a draught horse, of average strength,
working eight hours per day, is about four fifths of a standard
<xex>horse power</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Brake horse power</b></col>, <cd>the net effective power
of a prime mover, as a steam engine, water wheel, etc., in horse powers,
as shown by a friction brake. See <cref>Friction brake</cref>, under
<er>Friction</er>.</cd> -- <col><b>Indicated horse power</b></col>,
<cd>the power exerted in the cylinder of an engine, stated in horse
powers, estimated from the diameter and speed of the piston, and the
mean effective pressure upon it as shown by an indicator. See
<er>Indicator</er>.</cd> -- <col><b>Nominal horse power</b></col>
<fld>(Steam Engine)</fld>, <cd>a term still sometimes used in England to
express certain proportions of cylinder, but having no value as a
standard of measurement.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A machine worked by a horse, for driving other
machinery; a horse motor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horse-radish</ent><br/
<hw>Horse"-rad`ish</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A plant of the genus <gen>Nasturtium</gen> (<spn>Nasturtium
Armoracia</spn>), allied to scurvy grass, having a root of a pungent
taste, much used, when grated, as a condiment and in medicine.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horse-radish tree</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Moringa</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horserake</ent><br/
<hw>Horse"rake`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rake drawn by a
horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>horseshit</ent><br/
<hw>horseshit</hw> <pos>n.</pos> <def>A ludicrously false
statement.</def> <mark>[Vulgar slang]</mark> <br/
<syn><b>Syn. --</b> bullshit, bull, Irish bull, shit, crap, bunk,
bunkum, buncombe, guff, rot, hogwash, dogshit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>horse show</ent><br/
<ent>horseshow</ent><br/
<mhw><hw>horse"show`</hw>, <hw>horse" show`</hw></mhw> <pos>n.</pos>
<def>a competitive exhibition of horses.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Horseshoe</ent><br/
<hw>Horse"shoe`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A shoe
for horses, consisting of a narrow plate of iron in form somewhat like
the letter <sansserif>U</sansserif>, nailed to a horse's hoof.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything shaped like a horseshoe, such as a U-shaped
bend in a river.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The Limulus or horseshoe
crab.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>A game in which horseshoes or
horseshoe-shaped objects (usually made of metal) are thrown at either of
two stakes fixed in the ground at a distance of 30 to 40 feet apart. The
player stands at or near one stake and throws several the horseshoes at
the other stake. Points are scored when the player throws the horseshoe
so that it surrounds the stake; fewer points are scored if the horseshoe
is close to but not surrounding the stake. The players take turns and
the first player to achieve the target score wins; <as>as,
<ldquo/almost<rdquo/ only counts with hand grenades or in
<ex>horseshoes</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Horsehoe head</b></col> <fld>(Med.)</fld>, <cd>an old
name for the condition of the skull in children, in which the sutures
are too open, the coronal suture presenting the form of a horsehoe.</cd>
<au>Dunglison.</au> -- <col><b>Horsehoe magnet</b></col>, <cd>an
artificial magnet in the form of a horsehoe.</cd> -- <col><b>Horsehoe
nail</b></col>. <cd>See <er>Horsenail</er>.</cd> -- <col><b>Horsehoe
nose</b></col> <fld>(Zool.)</fld>, <cd>a bat of the genus
<gen>Rhinolophus</gen>, having a nasal fold of skin shaped like a
horsehoe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseshoeing</ent><br/
<hw>Horse"shoe`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
employment of shoeing horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseshoer</ent><br/
<hw>Horse"sho`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who shoes
horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsetail</ent><br/
<hw>Horse"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A leafless plant, with hollow and rushlike stems.
It is of the genus <gen>Equisetum</gen>, and is allied to the ferns. See
<xex>Illust.</xex> of <er>Equisetum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A Turkish standard, denoting rank.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Commanders are distinguished by the number of
<xex>horsetails</xex> carried before them. Thus, the sultan has seven,
the grand vizier five, and the pashas three, two, or one.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Shrubby horsetail</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Joint-fir</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>horse-trade</ent><br/
<hw>horse-trade</hw> <pos>v. i. & t.</pos> <def>to negotiate with much
give and take.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>horse-trading</ent><br/
<hw>horse-trading</hw> <pos>n.</pos> <def>negotiation accompanied by
mutual concessions and shrewd bargaining.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>horse-trail</ent><br/
<hw>horse-trail</hw> <pos>n.</pos> <def>a trail for horses.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Horseweed</ent><br/
<hw>Horse"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A composite plant (<spn>Erigeron Canadensis</spn>), which is a
common weed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsewhip</ent><br/
<hw>Horse"whip`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A whip for
horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsewhip</ent><br/
<hw>Horse"whip`</hw>, <pos>v. t.</pos> <def>To flog or chastise with a
horsewhip.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsewoman</ent><br/
<hw>Horse"wom`an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Horsewomen</plw> <pr>(<?/)</pr>.</plu> <def>A woman who rides on
horseback.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsewood</ent><br/
<hw>Horse"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A West Indian tree (<spn>Calliandra latifolia</spn>) with showy,
crimson blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horseworm</ent><br/
<hw>Horse"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The larva of a
botfly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsiness</ent><br/
<hw>Hors"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
condition or quality of being a horse; that which pertains to a
horse.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fondness for, or interest in, horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsly</ent><br/
<hw>Hors"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Horselike.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horsy</ent><br/
<hw>Hors"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
suggestive of, a horse, or of horse racing; <as>as, <ex>horsy</ex>
manners; garments of fantastically <ex>horsy</ex> fashions.</as></def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortation</ent><br/
<hw>Hor*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hortatio</ets>, fr. <ets>hortari</ets> to incite, exhort, fr.
<ets>hori</ets> to urge.]</ety> <def>The act of exhorting, inciting, or
giving advice; exhortation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortative</ent><br/
<hw>Hor"ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hortativus</ets>.]</ety> <def>Giving exhortation; advisory;
exhortative.</def> <rj><au>Bullokar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 708 --></p>

<p><ent>Hortative</ent><br/
<hw>Hor"ta*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An
exhortation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortatory</ent><br/
<hw>Hor"ta*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hortatorius</ets>.]</ety> <def>Giving exhortation or advise;
encouraging; exhortatory; inciting; <as>as, a <ex>hortatory</ex>
speech</as>.</def> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortensial</ent><br/
<hw>Hor*ten"sial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hortensius</ets>, <ets>hortensis</ets>, fr. <ets>hortus</ets>
garden; akin to E. <ets>yard</ets> an inclosure.]</ety> <def>Fit for a
garden.</def> <mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horticultor</ent><br/
<hw>Hor"ti*cul`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>hortus</ets> garden + <ets>cultor</ets> a cultivator,
<ets>colere</ets> to cultivate.]</ety> <def>One who cultivates a
garden.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horticultural</ent><br/
<hw>Hor`ti*cul"tur*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>horticultural</ets>.]</ety> <def>Of or pertaining to horticulture,
or the culture of gardens or orchards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horticulture</ent><br/
<hw>Hor"ti*cul`ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hortus</ets> garden + <ets>cultura</ets> culture: cf. F.
<ets>horticulture</ets>. See <er>Yard</er> an inclosure, and
<er>Culture</er>.]</ety> <def>The cultivation of a garden or orchard;
the art of cultivating gardens or orchards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Horticulturist</ent><br/
<hw>Hor`ti*cul"tur*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
practices horticulture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortulan</ent><br/
<hw>Hor"tu*lan</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hortulanus</ets>; <ets>hortus</ets> garden.]</ety> <def>Belonging
to a garden.</def> <mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortus siccus</ent><br/
\'d8<hw>Hor"tus sic"cus</hw> <pr>(?)</pr>. <ety>[L., a dry
garden.]</ety> <def>A collection of specimens of plants, dried and
preserved, and arranged systematically; an herbarium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hortyard</ent><br/
<hw>Hort"yard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An orchard.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hosanna</ent><br/
<hw>Ho*san"na</hw> <pr>(h<osl/*z<acr/n"n<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hosannas</plw> <pr>(-n<adot/z)</pr>.</plu>
<ety>[Gr. <?/, fr. Heb. <ets>h<omac/sh<imac/'<amac/h nn<amac/</ets>save
now, save, we pray, <ets>h<omac/sh<imac/a'</ets> to save (Hiphil, a
causative form, of <ets>y<amac/sha'</ets>) + <ets>n<amac/</ets>, a
particle.]</ety> <def>A Hebrew exclamation of praise to the Lord, or an
invocation of blessings.</def> <ldquo/<xex>Hosanna</xex> to the
Highest.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hosanna</qex> to the Son of David.</q> <rj><qau>Matt. xxi.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hose</ent><br/
<hw>Hose</hw> <pr>(h<omac/z)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hose</plw>, formerly <plw>Hosen</plw> <pr>(h<omac/"z'n)</pr>.</plu>
<ety>[AS. <ets>hose</ets>; akin to D. <ets>hoos</ets>, G.
<ets>hose</ets> breeches, OHG. <ets>hosa</ets>, Icel. <ets>hosa</ets>
stocking, gather, Dan. <ets>hose</ets> stocking; cf. Russ.
<ets>koshulia</ets> a fur jacket.]</ety> <sn>1.</sn> <def>Close-fitting
trousers or breeches, as formerly worn, reaching to the knee.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These men were bound in their coats, their <qex>hosen</qex>, and
their hats, and their other garments.</q> <rj><qau>Dan. iii.
21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His youthful <qex>hose</qex>, well saved, a world too wide<br/
For his shrunk shank.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Covering for the feet and lower part of the legs; a
stocking or stockings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A flexible pipe, made of leather, India rubber, or
other material, and used for conveying fluids, especially water, from a
faucet, hydrant, or fire engine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hose carriage</b></col>, <col><b>Hose
cart</b></col>, <it>or</it> <col><b>Hose truck</b></col></mcol>, <cd>a
wheeled vehicle fitted for conveying hose for extinguishing fires.</cd>
-- <col><b>Hose company</b></col>, <cd>a company of men appointed to
bring and manage hose in the extinguishing of fires.</cd>
<mark>[U.S.]</mark> -- <col><b>Hose coupling</b></col>, <cd>coupling
with interlocking parts for uniting hose, end to end.</cd> --
<col><b>Hose wrench</b></col>, <cd>a spanner for turning hose couplings,
to unite or disconnect them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hosen</ent><br/
<hw>Ho"sen</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Hose</er>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hosepipe</ent><br/
<hw>hosepipe</hw> <pos>n.</pos> <def>A flexible pipe for conveying a
liquid or gas.</def><br/
<syn><b>Syn. --</b> hose.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hosier</ent><br/
<hw>Ho"sier</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who deals in hose
or stocking, or in goods knit or woven like hose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hosiery</ent><br/
<hw>Ho"sier*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
business of a hosier.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Stockings, in general; goods knit or woven like
hose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospice</ent><br/
<hw>Hos"pice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>hospitium</ets> hospitality, a place where strangers are
entertained, fr. <ets>hospes</ets> stranger, guest. See <er>Host</er> a
landlord.]</ety> <def>A convent or monastery which is also a place of
refuge or entertainment for travelers on some difficult road or pass, as
in the Alps; <as>as, the <ex>Hospice</ex> of the Great St</as>.
Bernard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitable</ent><br/
<hw>Hos"pi*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>hospitable</ets>, LL. <ets>hospitare</ets> to receive as a guest.
See <er>Host</er> a landlord.]</ety> <sn>1.</sn> <def>Receiving and
entertaining strangers or guests with kindness and without reward; kind
to strangers and guests; characterized by hospitality.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proceeding from or indicating kindness and
generosity to guests and strangers; <as>as, <ex>hospitable</ex>
rites</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To where you taper cheers the vale<br/
With <qex>hospitable</qex> ray.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitableness</ent><br/
<hw>Hos"pi*ta*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
hospitable; hospitality.</def> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitably</ent><br/
<hw>Hos"pi*ta*bly</hw>, <pos>adv.</pos> <def>In a hospitable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitage</ent><br/
<hw>Hos"pi*tage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>hospitagium</ets>, for L. <ets>hospitium</ets>. See
<er>Hospice</er>.]</ety> <def>Hospitality.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospital</ent><br/
<hw>Hos"pi*tal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>hospital</ets>, <ets>ospital</ets>, F. <ets>h<ocir/pital</ets>, LL.
<ets>hospitale</ets> (or perh. E. <ets>hospital</ets> is directly from
the Late Latin), from L. <ets>hospitalis</ets> relating to a guest,
<ets>hospitalia</ets> apartments for guests, fr. <ets>hospes</ets>
guest. See <er>Host</er> a landlord, and cf. <er>Hostel</er>,
<er>Hotel</er>, <er>Spital</er>.]</ety> <sn>1.</sn> <def>A place for
shelter or entertainment; an inn.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A building in which the sick, injured, or infirm are
received and treated; a public or private institution founded for
reception and cure, or for the refuge, of persons diseased in body or
mind, or disabled, infirm, or dependent, and in which they are treated
either at their own expense, or more often by charity in whole or in
part; a tent, building, or other place where the sick or wounded of an
army cared for.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hospital ship</b></col>, <cd>a vessel fitted up for a
floating hospital.</cd> -- <col><b>Hospital Sunday</b></col>, <cd>a
Sunday set apart for simultaneous contribution in churches to hospitals;
as, the London <xex>Hospital Sunday</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospital</ent><br/
<hw>Hos"pi*tal</hw>, <pos>a.</pos> <ety>[L. <ets>hospitalis</ets>: cf.
OF. <ets>hospital</ets>.]</ety> <def>Hospitable.</def>
<mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitaler</ent><br/
<hw>Hos"pi*tal*er</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>hospitaller</asp>.]</altsp> <ety>[F. <ets>hospitalier</ets>. See
<er>Hospital</er>, and cf. <er>Hostler</er>.]</ety> <sn>1.</sn> <def>One
residing in a hospital, for the purpose of receiving the poor, the sick,
and strangers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of an order of knights who built a hospital at
Jerusalem for pilgrims, <sc>A. D.</sc> 1042. They were called
<xex>Knights of St. John of Jerusalem</xex>, and after the removal of
the order to Malta, <xex>Knights of Malta</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hospitalization</ent><br/
<ent>hospitalisation</ent><br/
<mhw><hw>hospitalisation</hw>, <hw>hospitalization</hw></mhw>
<pos>n.</pos> <def>medical care in a hospital; also, the period during
which one receives care in a hospital.</def><br/
<syn><b>Syn. --</b> hospital care.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hospitalisation insurance</ent><br/
<hw>hospitalisation insurance</hw> <pos>n.</pos> <def>A form of
<isa>medical insurance</isa> that pays for all or part of the fees for a
person's residence and treatment in a hospital.</def><br/
[<source>PJC</source>]</p>

<p><ent>hospitalise</ent><br/
<hw>hos"pi*tal*ise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To place (a
person) in a hospital in order to receive medical treatment, for
observation, or for rest.</def> <mark>[Chiefly Brit.]</mark> <br/
<syn><b>Syn. --</b> hospitalize.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Hospitalism</ent><br/
<hw>Hos"pi*tal*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>A vitiated condition of the body, due to long confinement in a
hospital, or the morbid condition of the atmosphere of a
hospital.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitality</ent><br/
<hw>Hos`pi*tal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hospitalities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>hospitalitas</ets>: cf. F. <ets>hospitalit<eacute/</ets>.]</ety>
<def>The act or practice of one who is hospitable; reception and
entertainment of strangers or guests without reward, or with kind and
generous liberality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Given to <qex>hospitality</qex>.</q> <rj><qau>Rom. xii.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And little recks to find the way to heaven<br/
By doing deeds of <qex>hospitality</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitalize</ent><br/
<hw>Hos"pi*tal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<fld>(Med.)</fld> <def>To render (a building) unfit for habitation, by
long continued use as a hospital.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place (a person) in a hospital in order to
receive medical treatment, observation, or for rest.</def><br/
<syn><b>Syn. --</b> hospitalise.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Hospitate</ent><br/
<hw>Hos"pi*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>hospitatus</ets>, p. p. of <ets>hospitari</ets> to be a guest, fr.
<ets>hospes</ets> guest.]</ety> <def>To receive hospitality; to be a
guest.</def> <mark>[Obs.]</mark> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitate</ent><br/
<hw>Hos"pi*tate</hw>, <pos>v. t.</pos> <def>To receive with hospitality;
to lodge as a guest.</def> <mark>[Obs.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospitium</ent><br/
\'d8<hw>Hos*pi"ti*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Hospice</er>.]</ety> <sn>1.</sn> <def>An inn; a lodging; a
hospice.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An inn of court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hospodar</ent><br/
\'d8<hw>Hos"po*dar`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A Slav. word;
cf. Russ. <ets>gospodare</ets> lord, master.]</ety> <def>A title borne
by the princes or governors of Moldavia and Wallachia before those
countries were united as Rumania.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Host</ent><br/
<hw>Host</hw> <pr>(h<omac/st)</pr>, <pos>n.</pos> <ety>[LL.
<ets>hostia</ets> sacrifice, victim, from <ets>hostire</ets> to
strike.]</ety> <fld>(R. C. Ch.)</fld> <def>The consecrated wafer,
believed to be the body of Christ, which in the Mass is offered as a
sacrifice; also, the bread before consecration.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the Latin Vulgate the word was applied to the Savior
as being an offering for the sins of men.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Host</ent><br/
<hw>Host</hw> <pr>(h<omac/st)</pr>, <pos>n.</pos> <ety>[OE.
<ets>host</ets>, <ets>ost</ets>, OF. <ets>host</ets>, <ets>ost</ets>,
fr. L. <ets>hostis</ets> enemy, LL., army. See <er>Guest</er>, and cf.
<er>Host</er> a landlord.]</ety> <sn>1.</sn> <def>An army; a number of
men gathered for war.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>host</qex> so great as covered all the field.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any great number or multitude; a throng.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And suddenly there was with the angel a multitude of the heavenly
<qex>host</qex> praising God.</q> <rj><qau>Luke ii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All at once I saw a crowd,<br/
A <qex>host</qex>, of golden daffodils.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Host</ent><br/
<hw>Host</hw> <pr>(h<omac/st)</pr>, <pos>n.</pos> <ety>[OE.
<ets>host</ets>, <ets>ost</ets>, OF. <ets>hoste</ets>, <ets>oste</ets>,
F. <ets>h<ocir/te</ets>, from L. <ets>hospes</ets> a stranger who is
treated as a guest, he who treats another as his guest, a hostl prob.
fr. <ets>hostis</ets> stranger, enemy (akin to E. <ets>guest</ets> a
visitor) + <ets>potis</ets> able; akin to Skr. <ets>pati</ets> master,
lord. See <er>Host</er> an army, <er>Possible</er>, and cf.
<er>Hospitable</er>, <er>Hotel</er>.]</ety> <sn>1.</sn> <def>One who
receives or entertains another, whether gratuitously or for
compensation; one from whom another receives food, lodging, or
entertainment; a landlord.</def> <au>Chaucer.</au> <ldquo/Fair
<xex>host</xex> and Earl.<rdquo/ <au>Tennyson.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Time is like a fashionable <qex>host</qex>,<br/
That slightly shakes his parting guest by the hand.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Any animal or plant affording
lodgment or subsistence to a parasitic or commensal organism. <as>Thus a
tree is a <ex>host</ex> of an air plant growing upon it</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Host</ent><br/
<hw>Host</hw>, <pos>v. t.</pos> <def>To give entertainment to.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Host</ent><br/
<hw>Host</hw>, <pos>v. i.</pos> <def>To lodge at an inn; to take up
entertainment.</def> <mark>[Obs.]</mark> <ldquo/Where you shall
<xex>host</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hosta</ent><br/
<hw>Hosta</hw> <pos>prop. n.</pos> <def>A genus of robust East Asian
clump-forming perennial herbs having racemose flowers: plantain lilies;
sometimes placed in the family <fam>Hostaceae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Hosta</gen>, Funka, genus
<gen>Funka</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hostaceae</ent><br/
<hw>Hostaceae</hw> <pos>prop. n.</pos> <def>One of many families or
subfamilies into which some classification systems subdivide the
Liliaceae but not widely accepted; includes genus Hosta.</def><br/
<syn><b>Syn. --</b> family <fam>Hostaceae</fam>, Funkaceae, family
<fam>Funkaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hostage</ent><br/
<hw>Hos"tage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hostage</ets>, OF. <ets>hostage</ets>, <ets>ostage</ets>, F.
<ets><ocir/tage</ets>, LL. <ets>hostaticus</ets>, <ets>ostaticum</ets>,
for <ets>hospitaticum</ets>, fr. L. <ets>hospes</ets> guest, host. The
first meaning is, the state of a guest, hospitality; hence, the state of
a hostage (treated as a guest); and both these meanings occur in Old
French. See <er>Host</er> a landlord.]</ety> <def>A person given as a
pledge or security for the performance of the conditions of a treaty or
stipulations of any kind, on the performance of which the person is to
be released.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>hostages</qex> I have, so have you mine;<br/
And we shall talk before we fight.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that hath a wife and children hath given <qex>hostages</qex> to
fortune.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostel</ent><br/
<hw>Hos"tel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hostel</ets>, <ets>ostel</ets>, OF. <ets>hostel</ets>,
<ets>ostel</ets>, LL. <ets>hospitale</ets>, <ets>hospitalis</ets>, fr.
L. <ets>hospitalis</ets>. See <er>Hospital</er>, and cf.
<er>Hotel</er>.]</ety> <sn>1.</sn> <def>An inn.</def>
<mark>[Archaic]</mark> <rj><au>Poe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So pass I <qex>hostel</qex>, hall, and grange.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small, unendowed college in Oxford or
Cambridge.</def> <mark>[Obs.]</mark> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hosteler</ent><br/
<hw>Hos"tel*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hostel</er>, and cf. <er>Hostler</er>.]</ety> <sn>1.</sn> <def>The
keeper of a hostel or inn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A student in a hostel, or small unendowed college in
Oxford or Cambridge.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostelry</ent><br/
<hw>Hos"tel*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hostelrie</ets>, <ets>hostelrye</ets>, <ets>ostelrie</ets>, OF.
<ets>hostelerie</ets>, fr. <ets>hostel</ets>. See
<er>Hostel</er>.]</ety> <def>An inn; a lodging house.</def>
<mark>[Archaic]</mark> <au>Chaucer.</au> <ldquo/Homely brought up in a
rude <xex>hostelry</xex>.<rdquo/ <au>B. Jonson.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Come with me to the <qex>hostelry</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostess</ent><br/
<hw>Host"ess</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hostesse</ets>, <ets>ostesse</ets>. See <er>Host</er> a
landlord.]</ety> <sn>1.</sn> <def>A female host; a woman who hospitably
entertains guests at her house.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman who entertains guests for compensation; a
female innkeeper.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostess-ship</ent><br/
<hw>Host"ess-ship</hw>, <pos>n.</pos> <def>The character, personality,
or office of a hostess.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostie</ent><br/
<hw>Hos"tie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See 1st
<er>Host</er>.]</ety> <def>The consecrated wafer; the host.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostile</ent><br/
<hw>Hos"tile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hostilis</ets>, from <ets>hostis</ets> enemy: cf. F.
<ets>hostile</ets>. See <er>Host</er> an army.]</ety> <def>Belonging or
appropriate to an enemy; showing the disposition of an enemy; showing
ill will and malevolence, or a desire to thwart and injure; occupied by
an enemy or enemies; inimical; unfriendly; <as>as, a <ex>hostile</ex>
force; <ex>hostile</ex> intentions; a <ex>hostile</ex> country;
<ex>hostile</ex> to a sudden change.</as></def></p>

<p><syn><b>Syn.</b> -- Warlike; inimical; unfriendly; antagonistic;
opposed; adverse; opposite; contrary; repugnant.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostile</ent><br/
<hw>Hos"tile</hw>, <pos>n.</pos> <def>An enemy; esp., an American Indian
in arms against the whites; -- commonly in the plural.</def>
<mark>[Colloq.]</mark> <rj><au>P. H. Sheridan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostilely</ent><br/
<hw>Hos"tile*ly</hw>, <pos>adv.</pos> <def>In a hostile
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hostile takeover</ent><br/
<hw>hostile takeover</hw> <pos>n.</pos> <fld>(Finance)</fld> <def>the
purchase of a controlling interest in a publicly-traded company against
the wishes of the current management.</def> <note>A person who is the
main principal in performing such a buyout is called a <er>corporate
raider</er>.</note><br/
<syn><b>Syn. --</b> hostile buyout.</syn><br/
[<source>PJC</source>]</p>

<p><ent>hostilities</ent><br/
<hw>hostilities</hw> <pos>n. pl.</pos> <sn>1.</sn> <def>a legal state
created by a declaration of war and ended by official declaration,
during which the international rules of war apply.</def><br/
<syn><b>Syn. --</b> war, state of war, hot war.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>We have showed ourselves generous adversaries . . . and have
carried on even our <qex>hostilities</qex> with humanity.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>acts of overt warfare.</def><br/
<syn><b>Syn. --</b> belligerency.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hostility</ent><br/
<hw>Hos*til"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hostilities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>hostilitas</ets>: cf. F. <ets>hostilit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>State of being hostile; public or private enemy;
unfriendliness; animosity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hostility</qex> being thus suspended with France.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act of an open enemy; a hostile deed; especially
in the plural, acts of warfare; attacks of an enemy. See
<er>hostilities</er></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He who proceeds to wanton <qex>hostility</qex>, often provokes an
enemy where he might have a friend.</q> <rj><qau>Crabb.</qau></rj></p>

<p><syn><b>Syn.</b> -- Animosity; enmity; opposition; violence;
aggression; contention; warfare.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostilize</ent><br/
<hw>Hos"til*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
hostile; to cause to become an enemy.</def> <mark>[Obs.]</mark>
<rj><au>A. Seward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hosting</ent><br/
<hw>Host"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Host</er>
an army.]</ety> <mark>[Obs.]</mark> <sn>1.</sn> <def>An encounter; a
battle.</def> <ldquo/Fierce <xex>hosting</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A muster or review.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostler</ent><br/
<hw>Hos"tler</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hosteler</ets>, <ets>osteler</ets>, innkeeper, OF.
<ets>hostelier</ets>, F. <ets>h<ocir/telier</ets>. See <er>Hostel</er>,
and cf. <er>Hospitaler</er>, <er>Hosteler</er>.]</ety> <sn>1.</sn>
<def>An innkeeper. <mark>[Obs.]</mark> See <er>Hosteler</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The person who has the care of horses at an inn or
stable; hence, any one who takes care of horses; a groom; -- so called
because the innkeeper formerly attended to this duty in
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Railroad)</fld> <def>The person who takes charge of
a locomotive when it is left by the engineer after a trip.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hostless</ent><br/
<hw>Host"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inhospitable.</def>
<mark>[Obs.]</mark> <ldquo/A <xex>hostless</xex> house.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Host plant</ent><br/
<hw>Host plant</hw>. <fld>(Agric.)</fld> <def>A plant which aids,
shelters, or protects another plant in its growth, as those which are
used for nurse crops.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hostry</ent><br/
<hw>Host"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hosterie</ets>, <ets>osterie</ets>, OF. <ets>hosterie</ets>. See
<er>Host</er> a landlord.]</ety> <sn>1.</sn> <def>A hostelry; an inn or
lodging house.</def> <mark>[Obs.]</mark> <rj><au>Marlowe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stable for horses.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot</ent><br/
<hw>Hot</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Hote</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot</ent><br/
<hw>Hot</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Hotter</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Hottest</adjf> <pr>(?)</pr>.]</amorph> <ety>[OE. <ets>hot</ets>,
<ets>hat</ets>, AS. <ets>h<amac/t</ets>; akin to OS.
<ets>h<emac/t</ets>, D. <ets>heet</ets>, OHG. <ets>heiz</ets>, G.
<ets>heiss</ets>, Icel. <ets>heitr</ets>, Sw. <ets>het</ets>, Dan.
<ets>heed</ets>, <ets>hed</ets>; cf. Goth. <ets>heit<omac/</ets> fever,
<ets>hais</ets> torch. Cf. <er>Heat</er>.]</ety> <sn>1.</sn> <def>Having
much sensible heat; exciting the feeling of warmth in a great degree;
very warm; -- opposed to <xex>cold</xex>, and exceeding <xex>warm</xex>
in degree; <as>as, a <ex>hot</ex> stove; <ex>hot</ex> water or
air.</as></def> <ldquo/A <xex>hot</xex>venison pasty.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by heat, ardor, or animation; easily
excited; firely; vehement; passionate; violent; eager.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Achilles is impatient, <qex>hot</qex>, and revengeful.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There was mouthing in <qex>hot</qex> haste.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lustful; lewd; lecherous.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Acrid; biting; pungent; <as>as, <ex>hot</ex> as
mustard</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hot bed</b></col> <fld>(Iron Manuf.)</fld>, <cd>an iron
platform in a rolling mill, on which hot bars, rails, etc., are laid to
cool.</cd> -- <col><b>Hot wall</b></col> <fld>(Gardening)</fld>, <cd>a
wall provided with flues for the conducting of heat, to hasten the
growth of fruit trees or the ripening of fruit.</cd> -- <col><b>Hot
well</b></col> <fld>(Condensing Engines)</fld>, <cd>a receptacle for the
hot water drawn from the condenser by the air pump. This water is
returned to the boiler, being drawn from the hot well by the feed
pump.</cd> -- <col><b>In hot water</b></col> (<mark>Fig.</mark>), <cd>in
trouble; in difficulties.</cd> <mark>[Colloq.]</mark></cs></p>

<p><syn><b>Syn.</b> -- Burning; fiery; fervid; glowing; eager; animated;
brisk; vehement; precipitate; violent; furious; ardent; fervent;
impetuous; irascible; passionate; hasty; excitable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotbed</ent><br/
<hw>Hot"bed`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Gardening)</fld> <def>A bed of earth heated by fermenting manure
or other substances, and covered with glass, intended for raising early
plants, or for nourishing exotics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place which favors rapid growth or development;
<as>as, a <ex>hotbed</ex> of sedition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot blast</ent><br/
<hw>Hot" blast`</hw> <pr>(?)</pr>. <def>See under
<er>Blast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot-blooded</ent><br/
<hw>Hot"-blood`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having hot
blood; excitable; high-spirited; irritable; ardent;
passionate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot-brained</ent><br/
<hw>Hot"-brained`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ardent in
temper; violent; rash; impetuous; <as>as, <ex>hot-brained</ex>
youth</as>.</def> <rj><au>Dryden.</au></rj></p>

<p><ent>Hot pot</ent><br/
<ent>Hot bulb</ent><br/
<mhw>{<hw>Hot bulb</hw>, <hw>Hot pot</hw>}</mhw>.
<fld>(Internal-combustion Engines)</fld> <def>See <er>Semi-diesel</er>,
below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hotchkiss gun</ent><br/
<hw>Hotch"kiss gun</hw> <pr>(?)</pr> <ety>[After <person>Benjamin B.
<etsep>Hotchkiss</etsep></person> (1826-85), American inventor.]</ety>
<def>A built-up, rifled, rapid-fire gun of oil-tempered steel, having a
rectangular breechblock which moves horizontally or vertically in a
mortise cut completely through the jacket. It is made in
France.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hotchpotch</ent><br/
<ent>Hotchpot</ent><br/
<mhw>{ <hw>Hotch"pot`</hw> <pr>(?)</pr>, <hw>Hotch"potch`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[F. <ets>hochepot</ets>, fr.
<ets>hocher</ets> to shake + <ets>pot</ets> pot; both of Dutch or German
origin; cf. OD. <ets>hutspot</ets> hotchpotch, D. <ets>hotsen</ets>,
<ets>hutsen</ets>, to shake. See <er>Hustle</er>, and <er>Pot</er>, and
cf. <er>Hodgepodge</er>.]</ety> <sn>1.</sn> <def>A mingled mass; a
confused mixture; a stew of various ingredients; a hodgepodge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A mixture or <qex>hotchpotch</qex> of many tastes.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A blending of property for equality
of division, as when lands given in frank-marriage to one daughter were,
after the death of the ancestor, blended with the lands descending to
her and to her sisters from the same ancestor, and then divided in equal
portions among all the daughters. In modern usage, a mixing together, or
throwing into a common mass or stock, of the estate left by a person
deceased and the amounts advanced to any particular child or children,
for the purpose of a more equal division, or of equalizing the shares of
all the children; the property advanced being accounted for at its value
when given.</def> <rj><au>Bouvier. Tomlins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term has been applied in cases of salvage.
<xex>Story</xex>. It corresponds in a measure with <xex>collation</xex>
in the civil and Scotch law. See <er>Collation</er>.</note>
<rj><au>Bouvier. Tomlins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotcockles</ent><br/
<hw>Hot"coc`kles</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hot</ets> +
<ets>cockle</ets>, <ets>cockle</ets> being perh. corrupt. fr.
<ets>knuckle</ets>. Cf. F. <ets>main chaude</ets> (lit., hot hand)
hotcockles.]</ety> <def>A childish play, in which one covers his eyes,
and guesses who strikes him or his hand placed behind him.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hot cross bun</ent><br/
<hw>hot" cross bun`</hw> <pr>(-b<ucr/n`)</pr>, <pos>n.</pos> <def>A bun
or cake marked with a cross of icing, and intended to be eaten on Good
Friday; called also <altname>cross bun</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hot dog</ent><br/
<hw>hot" dog`</hw> <pr>(h<ocr/t" d<add/g`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A frankfurter.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A sandwich consisting of a hot dog inserted in a
partly split elongated roll, usually garnished with mustard, and
sometimes also with relish, sauerkraut, or a pickle. A hot dog garnished
with a chili mix is called a <stype>chili dog</stype>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A person who performs a complex and difficult
athletic maneuver, usually to show off his/her skill.</def><br/
[<source>PJC</source>]</p>

<p><ent>hot dog</ent><br/
<hw>hot" dog"</hw> <pr>(h<ocr/t" d<add/g")</pr>, <pos>exclamation</pos>
<def>An expression of delight.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hote</ent><br/
<hw>Hote</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>pres. &
imp.</pos> <conjf>Hatte</conjf> <pr>(?)</pr>, <conjf>Hot</conjf>
<pr>(<?/)</pr>, etc.; <pos>p. p.</pos> <conjf>Hote</conjf>,
<conjf>Hoten</conjf> <pr>(<?/)</pr>, <conjf>Hot</conjf>, etc. See
<er>Hight</er>, <er>Hete</er>.]</vmorph> <sn>1.</sn> <def>To command; to
enjoin.</def> <mark>[Obs.]</mark> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To promise.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be called; to be named.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There as I was wont to <qex>hote</qex> Arcite,<br/
Now hight I Philostrate, not worth a mite.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hotei-chiku</ent><br/
<hw>hotei-chiku</hw> <pos>n.</pos> <def>A small bamboo
(<spn>Phyllostachys aurea</spn>) of Southeast China having slender culms
flexuous when young.</def><br/
<syn><b>Syn. --</b> fishpole bamboo, gosan-chiku, <spn>Phyllostachys
aurea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hotel</ent><br/
<hw>Ho*tel"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>h<ocir/tel</ets>, OF. <ets>hostel</ets>. See
<er>Hostel</er>.]</ety> <sn>1.</sn> <def>A house for entertaining
strangers or travelers; an inn or public house, of the better
class.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In France, the mansion or town residence of a person
of rank or wealth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotel-de-ville</ent><br/
\'d8<hw>H<ocir/tel`-de-ville"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A city hall or townhouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotel-Dieu</ent><br/
\'d8<hw>H<ocir/tel`-Dieu"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A hospital.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hotelman</ent><br/
<ent>hotelkeeper</ent><br/
<ent>hotelier</ent><br/
<mhw><hw>hotelier</hw>, <hw>hotelkeeper</hw>, <hw>hotelman</hw></mhw>
<pos>n.</pos> <def>an owner or manager of a hotel or hotels.</def><br/
<syn><b>Syn. --</b> hotelkeeper, hotel manager, hotelman,
hosteller.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoten</ent><br/
<hw>Hot"en</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Hote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotfoot</ent><br/
<hw>Hot"foot`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In haste;
foothot.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot-head</ent><br/
<hw>Hot"-head`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A violent,
passionate person; a hasty or impetuous person; <as>as, the rant of a
<ex>hot-head</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot-headed</ent><br/
<hw>Hot"-head`ed</hw>, <pos>a.</pos> <def>quickly and easily aroused to
anger; fiery; violent; rash; hasty; impetuous; vehement; <as>as, a
<ex>hot-headed</ex> commander</as>.</def> <wns>[wns=1]</wns>
<rj><au>Macaulay.</au></rj><br/
<syn><b>Syn. --</b> choleric, irascible, hotheaded, hot-tempered,
quick-tempered, short-tempered.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>hotheaded</ent><br/
<hw>hotheaded</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>hot-headed</er>.</def><br/
<syn><b>Syn. --</b> choleric, irascible, hot-headed, hot-tempered,
quick-tempered, short-tempered.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>liable to act with undue haste and without
consideration.</def><br/
<syn><b>Syn. --</b> brainish, impulsive, impetuous, madcap,
tearaway(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hothouse</ent><br/
<hw>Hot"house`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A house
kept warm to shelter tender plants and shrubs from the cold air; a place
in which the plants of warmer climates may be reared, and fruits
ripened.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bagnio, or bathing house.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A brothel; a bagnio.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Pottery)</fld> <def>A heated room for drying green
ware.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 709 --></p>

<p><ent>Hot-livered</ent><br/
<hw>Hot"-liv`ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of an excitable
or irritable temperament; irascible.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotly</ent><br/
<hw>Hot"ly</hw>, <pos>adv.</pos> <ety>[From <er>Hot</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>In a hot or fiery manner;
ardently; vehemently; violently; hastily; <as>as, a <ex>hotly</ex>
pursued</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a lustful manner; lustfully.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot-mouthed</ent><br/
<hw>Hot"-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Headstrong.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>hot-mouthed</qex> beast that bears against the curb.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotness</ent><br/
<hw>Hot"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state
of being hot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Heat or excitement of mind or manner; violence;
vehemence; impetuosity; ardor; fury.</def> <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotpress</ent><br/
<hw>Hot"press`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To apply heat
to, in conjunction with mechanical pressure, for the purpose of giving a
smooth and glossy surface, or to express oil, etc.; <as>as, to
<ex>hotpress</ex> paper, linen, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotpressed</ent><br/
<hw>Hot"pressed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pressed while
heat is applied. See <er>Hotpress</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hot-short</ent><br/
<hw>Hot"-short`</hw>, <pos>a.</pos> <ety>[Cf.
<er>Cold-short</er>.]</ety> <fld>(Metal.)</fld> <def>Brittle when
heated, esp. beyond a red heat; <as>as, <ex>hot-short</ex>
iron</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hotshot</ent><br/
<hw>Hot"shot`</hw>, <pos>n.</pos> <def>a successful, self-confident
person who is regarded by others as highly skilled; -- sometimes used
ironically in reference to aggressive persons whose opinion of their own
talents is considered exaggerated.</def><br/
[<source>PJC</source>]</p>

<p><ent>hotshot</ent><br/
<hw>hot"shot`</hw>, <pos>a.</pos> <sn>1.</sn> <def>highly talented,
self-confident and successful.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>flamboyantly displaying one's skills.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hot-spirited</ent><br/
<hw>Hot"-spir`it*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a fiery
spirit; hot-headed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hotspur</ent><br/
<hw>Hot"spur`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hot</ets> +
<ets>spur</ets>.]</ety> <def>A rash, hot-headed man.</def>
<rj><au>Holinshed.</au></rj></p>

<p><ent>Hotspurred</ent><br/
<ent>Hotspur</ent><br/
<mhw>{ <hw>Hot"spur`</hw>, <hw>Hot"spurred`</hw> <pr>(?)</pr> }</mhw>,
<pos>a.</pos> <def>Violent; impetuous; headstrong.</def>
<rj><au>Spenser. Peacham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hottentot</ent><br/
<hw>Hot"ten*tot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>Hottentot</ets>; -- so called from <ets>hot</ets> and
<ets>tot</ets>, two syllables of frequent occurrence in their language.
<au>Wedgwood.</au>]</ety> <sn>1.</sn> <fld>(Ethnol.)</fld> <def>One of a
degraded<-- "pastoral", in MW10 --> and savage race of South Africa,
with yellowish brown complexion, high cheek bones, and wooly hair
growing in tufts.</def><-- = The tribes speaking Khoisan; Bushman(? any
difference?) --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language of the Hottentots, which is remarkable
for its clicking sounds; the <altname>Khoisan</altname>
language.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Hottentot cherry</b></col> <fld>(Bot.)</fld>, <cd>a South
African plant of the genus <gen>Cassine</gen> (<spn>Cassine
maurocenia</spn>), having handsome foliage, with generally inconspicuous
white or green flowers.</cd> <au>Loudon.</au> -- <col><b>Hottentot's
bread</b></col>. <fld>(Bot.)</fld> <cd>See <cref>Elephant's foot</cref>
<sd>(a)</sd>, under <er>Elephant</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hottentotism</ent><br/
<hw>Hot"ten*tot*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A term
employed to describe one of the varieties of stammering.</def>
<rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hottonia</ent><br/
<hw>Hottonia</hw> <pos>n.</pos> <def>A genus of aquatic herbs.</def><br/
<syn><b>Syn. --</b> genus <gen>Hottonia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hot-wire</ent><br/
<hw>hot-wire</hw> <pos>v. t.</pos> <def>to start (a car) by using a wire
instead of a key, as when stealing the car; the wire is connected to
points in the ignition circuit that bypass the key.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Houdah</ent><br/
<hw>Hou"dah</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Howdah</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hough</ent><br/
<hw>Hough</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Hock</er>, a
joint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hough</ent><br/
<hw>Hough</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Houghed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Houghing</conjf>.]</vmorph> <def>Same as <er>Hock</er>, to
hamstring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hough</ent><br/
<hw>Hough</hw>, <pos>n.</pos> <ety>[Cf. D. <ets>hak</ets>. Cf.
<er>Hack</er>.]</ety> <def>An adz; a hoe.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hough</ent><br/
<hw>Hough</hw>, <pos>v. t.</pos> <def>To cut with a hoe.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>houhere</ent><br/
<hw>houhere</hw> <pos>n.</pos> <def>A small tree or shrub (<spn>Hoheria
populnea</spn>) of New Zealand having a profusion of axillary clusters
of honey-scented paper-white flowers and whose bark is used for
cordage.</def><br/
<syn><b>Syn. --</b> lacebark, ribbonwood, <spn>Hoheria
populnea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Houlet</ent><br/
<hw>Hou"let</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>An
owl. See <er>Howlet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoult</ent><br/
<hw>Hoult</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A piece of woodland; a
small wood. <mark>[Obs.]</mark> See <er>Holt</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hound</ent><br/
<hw>Hound</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hound</ets>,
<ets>hund</ets>, dog, AS. <ets>hund</ets>; akin to OS. & OFries.
<ets>hund</ets>, D. <ets>hond</ets>, G. <ets>hund</ets>, OHG.
<ets>hunt</ets>, Icel. <ets>hundr</ets>, Dan. & Sw. <ets>hund</ets>,
Goth. <ets>hunds</ets>, and prob. to Lith. <ets>sz<?/</ets>, Ir. & Gael.
<ets>cu</ets>, L. <ets>canis</ets>, Gr. <?/, <?/, Skr.
<ets><cced/van</ets>. <root/229. Cf. <er>Canine</er>, <er>Cynic</er>,
<er>Kennel</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A variety of
the domestic dog, usually having large, drooping ears, esp. one which
hunts game by scent, as the foxhound, bloodhound, deerhound, but also
used for various breeds of fleet hunting dogs, as the greyhound,
boarhound, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hounds</qex> and greyhounds, mongrels, spaniels, curs.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A despicable person.</def> <ldquo/Boy! false
<xex>hound</xex>!<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A houndfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(Naut.)</fld> <def>Projections at
the masthead, serving as a support for the trestletrees and top to rest
on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A side bar used to strengthen portions of the
running gear of a vehicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To follow the hounds</b></col>, <cd>to hunt with
hounds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hound</ent><br/
<hw>Hound</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hounded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hounding</conjf>.]</vmorph> <sn>1.</sn> <def>To set on the chase;
to incite to pursuit; <as>as, to <ex>hound</ex>a dog at a hare; to
<ex>hound</ex> on pursuers.</as></def> <rj><au>Abp.
Bramhall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hunt or chase with hounds, or as with
hounds.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houndfish</ent><br/
<hw>Hound"fish</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any small shark of the genus <gen>Galeus</gen> or
<gen>Mustelus</gen>, of which there are several species, as the smooth
houndfish (<spn>Galeus canis</spn>), of Europe and America; -- called
also <altname>houndshark</altname>, and
<altname>dogfish</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The European nursehound, or small-spotted dogfish, is
<spn>Scyllium canicula</spn>; the rough houndfish, or large-spotted
dogfish, is <spn>Scyllium catulus</spn>. The name has also sometimes
been applied to the bluefish (<spn>Pomatomus saltatrix</spn>), and to
the silver gar.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hounding</ent><br/
<hw>Hound"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
hounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>The part of a mast below the
hounds and above the deck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hound's-tongue</ent><br/
<hw>Hound's"-tongue`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hundes tunge</ets>.]</ety> <fld>(Bot.)</fld> <def>A biennial weed
(<spn>Cynoglossum officinale</spn>), with soft tongue-shaped leaves, and
an offensive odor. It bears nutlets covered with barbed or hooked
prickles. Called also <altname>dog's-tongue</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houp</ent><br/
<hw>Houp</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Hoopoe</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hour</ent><br/
<hw>Hour</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hour</ets>,
<ets>our</ets>, <ets>hore</ets>, <ets>ure</ets>, OF. <ets>hore</ets>,
<ets>ore</ets>, <ets>ure</ets>, F. <ets>heure</ets>, L. <ets>hora</ets>,
fr. Gr. <?/, orig., a definite space of time, fixed by natural laws;
hence, a season, the time of the day, an hour. See <er>Year</er>, and
cf. <er>Horologe</er>, <er>Horoscope</er>.]</ety> <sn>1.</sn> <def>The
twenty-fourth part of a day; sixty minutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The time of the day, as expressed in hours and
minutes, and indicated by a timepiece; as, what is the <xex>hour</xex>?
At what <xex>hour</xex> shall we meet?</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fixed or appointed time; conjuncture; a particular
time or occasion; <as>as, the <ex>hour</ex> of greatest peril; the man
for the <ex>hour</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Woman, . . . mine <qex>hour</qex> is not yet come.</q>
<rj><qau>John ii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This is your <qex>hour</qex>, and the power of darkness.</q>
<rj><qau>Luke xxii. 53.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(R. C. Ch.)</fld> <def>Certain
prayers to be repeated at stated times of the day, as matins and
vespers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A measure of distance traveled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vilvoorden, three <qex>hours</qex> from Brussels.</q> <rj><qau>J.
P. Peters.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>After hours</b></col>, <cd>after the time appointed for
one's regular labor.</cd> -- <col><b>Canonical hours</b></col>. <cd>See
under <er>Canonical</er>.</cd> -- <col><b>Hour angle</b></col>
<fld>(Astron.)</fld>, <cd>the angle between the hour circle passing
through a given body, and the meridian of a place.</cd> -- <col><b>Hour
circle</b></col>. <fld>(Astron.)</fld> <sd>(a)</sd> <cd>Any circle of
the sphere passing through the two poles of the equator; esp., one of
the circles drawn on an artificial globe through the poles, and dividing
the equator into spaces of 15<deg/, or one hour, each.</cd> <sd>(b)</sd>
<cd>A circle upon an equatorial telescope lying parallel to the plane of
the earth's equator, and graduated in hours and subdivisions of hours of
right ascension.</cd> <sd>(c)</sd> <cd>A small brass circle attached to
the north pole of an artificial globe, and divided into twenty-four
parts or hours. It is used to mark differences of time in working
problems on the globe.</cd> -- <col><b>Hour hand</b></col>, <cd>the hand
or index which shows the hour on a timepiece.</cd> -- <col><b>Hour
line</b></col>. <sd>(a)</sd> <fld>(Astron.)</fld> <cd>A line indicating
the hour.</cd> <sd>(b)</sd> <fld>(Dialing)</fld> <cd>A line on which the
shadow falls at a given hour; the intersection of an hour circle which
the face of the dial.</cd> -- <col><b>Hour plate</b></col>, <cd>the
plate of a timepiece on which the hours are marked; the dial.</cd>
<au>Locke.</au> -- <col><b>Sidereal hour</b></col>, <cd>the
twenty-fourth part of a sidereal day.</cd> -- <col><b>Solar
hour</b></col>, <cd>the twenty-fourth part of a solar day.</cd> --
<col><b>The small hours</b></col>, <cd>the early hours of the morning,
as one o'clock, two o'clock, etc.</cd><-- also "wee hours" --> --
<col><b>To keep good hours</b></col>, <cd>to be regular in going to bed
early.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hourglass</ent><br/
<hw>Hour"glass`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An instrument for
measuring time, especially the interval of an hour. It consists of a
glass vessel having two compartments, from the uppermost of which a
quantity of sand, water, or mercury occupies an hour in running through
a small aperture unto the lower.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A similar instrument measuring any other interval of
time takes its name from the interval measured; as, a <stype>half-hour
glass</stype>, a <stype>half-minute glass</stype>. A <stype>three-minute
glass</stype> is sometimes called an <xex>egg-glass</xex>, from being
used to time the boiling of eggs.<-- also = egg timer --></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houri</ent><br/
<hw>Hou"ri</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Houris</plw> <pr>(#)</pr>.</plu> <ety>[Per.
<ets>h<umac/r<imac/</ets>, <ets>h<umac/r<amac/</ets>,
<ets>h<umac/r</ets>; akin to Ar. <ets>h<umac/r</ets>, pl. of
<ets>ahwar</ets> beautiful-eyed, black-eyed.]</ety> <def>A nymph of
paradise; -- so called by the Muslims.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hourly</ent><br/
<hw>Hour"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Happening or done
every hour; occurring hour by hour; frequent; often repeated; renewed
hour by hour; continual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>hourly</qex> expectation of a martyrdom.</q>
<rj><qau>Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hourly</ent><br/
<hw>Hour"ly</hw>, <pos>adv.</pos> <def>Every hour; frequently;
continually.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Great was their strife, which <qex>hourly</qex> was renewed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hours</ent><br/
<hw>Hours</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[A translation of L.
<ets>Horae</ets> (Gr. <?/). See <er>Hour</er>.]</ety> <fld>(Myth.)</fld>
<def>Goddess of the seasons, or of the hours of the day.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lo! where the rosy-blosomed <qex>Hours</qex>,<br/
Fair Venus' train, appear.</q> <rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housage</ent><br/
<hw>Hous"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>House</er>.]</ety> <def>A fee for keeping goods in a house.</def>
<mark>[R.]</mark> <rj><au> Chambers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>House</ent><br/
<hw>House</hw> <pr>(hous)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Houses</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>hous</ets>,
<ets>hus</ets>, AS. <ets>h<?/s</ets>; akin to OS. & OFries.
<ets>h<?/s</ets>, D. <ets>huis</ets>, OHG. <ets>h<?/s</ets>, G.
<ets>haus</ets>, Icel. <ets>h<?/s</ets>, Sw. <ets>hus</ets>, Dan.
<ets>huus</ets>, Goth. gud<ets>h<?/s</ets>, house of God, temple; and
prob. to E. <ets>hide</ets> to conceal. See <er>Hide</er>, and cf.
<er>Hoard</er>, <er>Husband</er>, <er>Hussy</er>,
<er>Husting</er>.]</ety> <sn>1.</sn> <def>A structure intended or used
as a habitation or shelter for animals of any kind; but especially, a
building or edifice for the habitation of man; a dwelling place, a
mansion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Houses</qex> are built to live in; not to look on.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bees with smoke and doves with noisome stench<br/
Are from their hives and <qex>houses</qex> driven away.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Household affairs; domestic concerns; particularly
in the phrase <xex>to keep house</xex>. See below.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Those who dwell in the same house; a
household.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One that feared God with all his <qex>house</qex>.</q>
<rj><qau>Acts x. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A family of ancestors, descendants, and kindred; a
race of persons from the same stock; a tribe; especially, a noble family
or an illustrious race; <as>as, the <ex>house</ex> of Austria; the
<ex>house</ex> of Hanover; the <ex>house</ex> of Israel.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The last remaining pillar of their <qex>house</qex>,<br/
The one transmitter of their ancient name.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One of the estates of a kingdom or other government
assembled in parliament or legislature; a body of men united in a
legislative capacity; <as>as, the <ex>House</ex> of Lords; the
<ex>House</ex> of Commons; the <ex>House</ex> of Representatives; also,
a quorum of such a body. See <er>Congress</er>, and
<er>Parliament</er>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Com.)</fld> <def>A firm, or commercial
establishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A public house; an inn; a hotel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Astrol.)</fld> <def>A twelfth part of the heavens,
as divided by six circles intersecting at the north and south points of
the horizon, used by astrologers in noting the positions of the heavenly
bodies, and casting horoscopes or nativities. The houses were regarded
as fixed in respect to the horizon, and numbered from the one at the
eastern horizon, called the <xex>ascendant</xex>, <xex>first
house</xex>, or <xex>house of life</xex>, downward, or in the direction
of the earth's revolution, the stars and planets passing through them in
the reverse order every twenty-four hours.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A square on a chessboard, regarded as the proper
place of a piece.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>An audience; an assembly of hearers, as at a
lecture, a theater, etc.; <as>as, a thin or a full
<ex>house</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>The body, as the habitation of the soul.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This mortal <qex>house</qex> I'll ruin,<br/
Do C<ae/sar what he can.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <usage>[With an adj., as <xex>narrow</xex>,
<xex>dark</xex>, etc.]</usage> <def>The grave.</def> <ldquo/The narrow
<xex>house</xex>.<rdquo/ <rj><au>Bryant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>House</xex> is much used adjectively and as the
first element of compounds. The sense is usually obvious; as,
<xex>house</xex> cricket, <xex>house</xex>maid, <xex>house</xex>
painter, <xex>house</xex>work.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>House ant</b></col> <fld>(Zool.)</fld>, <cd>a very small,
yellowish brown ant (<spn>Myrmica molesta</spn>), which often infests
houses, and sometimes becomes a great pest.</cd> -- <col><b>House of
bishops</b></col> <fld>(Prot. Epis. Ch.)</fld>, <cd>one of the two
bodies composing a general convertion, the other being House of Clerical
and Lay Deputies.</cd> -- <col><b>House boat</b></col>, <cd>a covered
boat used as a dwelling.</cd> -- <col><b>House of call</b></col>, <cd>a
place, usually a public house, where journeymen connected with a
particular trade assemble when out of work, ready for the
<xex>call</xex> of employers.</cd> <mark>[Eng.]</mark><-- modern name?
--> <au>Simonds.</au> -- <col><b>House car</b></col>
<fld>(Railroad)</fld>, <cd>a freight car with inclosing sides and a
roof; a box car.</cd> -- <col><b>House of correction</b></col>. <cd>See
<er>Correction</er>.</cd> -- <col><b>House cricket</b></col>
<fld>(Zool.)</fld>, <cd>a European cricket (<spn>Gryllus
domesticus</spn>), which frequently lives in houses, between the bricks
of chimneys and fireplaces. It is noted for the loud chirping or
stridulation of the males.</cd> -- <col><b>House dog</b></col>, <cd>a
dog kept in or about a dwelling house.</cd> -- <col><b>House
finch</b></col> <fld>(Zool.)</fld>, <cd>the burion.</cd> --
<col><b>House flag</b></col>, <cd>a flag denoting the commercial house
to which a merchant vessel belongs.</cd> -- <col><b>House fly</b></col>
<fld>(Zool.)</fld>, <cd>a common fly (esp. <spn>Musca domestica</spn>),
which infests houses both in Europe and America. Its larva is a maggot
which lives in decaying substances or excrement, about sink drains,
etc.</cd> -- <col><b>House of God</b></col>, <cd>a temple or
church.</cd> -- <col><b>House of ill fame</b></col>. <cd>See <cref>Ill
fame</cref> under <er>Ill</er>, <pos>a.</pos></cd> -- <col><b>House
martin</b></col> <fld>(Zool.)</fld>, <cd>a common European swallow
(<spn>Hirundo urbica</spn>). It has feathered feet, and builds its nests
of mud against the walls of buildings. Called also <altname>house
swallow</altname>, and <altname>window martin</altname>.</cd> --
<col><b>House mouse</b></col> <fld>(Zool.)</fld>, <cd>the common mouse
(<spn>Mus musculus</spn>).</cd> -- <col><b>House physician</b></col>,
<cd>the resident medical adviser of a hospital or other public
institution.</cd> -- <col><b>House snake</b></col> <fld>(Zool.)</fld>,
<cd>the milk snake.</cd> -- <col><b>House sparrow</b></col>
<fld>(Zool.)</fld>, <cd>the common European sparrow (<spn>Passer
domesticus</spn>). It has recently been introduced into America, where
it has become very abundant, esp. in cities. Called also <altname>thatch
sparrow</altname>.</cd> -- <col><b>House spider</b></col>
<fld>(Zool.)</fld>, <cd>any spider which habitually lives in houses.
Among the most common species are <spn>Theridium tepidariorum</spn> and
<spn>Tegenaria domestica</spn>.</cd> -- <col><b>House surgeon</b></col>,
<cd>the resident surgeon of a hospital.</cd> -- <col><b>House
wren</b></col> <fld>(Zool.)</fld>, <cd>the common wren of the Eastern
United States (<spn>Troglodytes a<eum/don</spn>). It is common about
houses and in gardens, and is noted for its vivacity, and loud musical
notes. See <er>Wren</er>.</cd> -- <col><b>Religious house</b></col>,
<cd>a monastery or convent.</cd> -- <col><b>The White House</b></col>,
<cd>the official residence of the President of the United States; --
hence, colloquially, the office of President.</cd><-- also, a parliament
building in Moscow --> -- <col><b>To bring down the house</b></col>.
<cd>See under <er>Bring</er>.</cd> -- <col><b>To keep house</b></col>,
<cd>to maintain an independent domestic establishment.</cd> --
<col><b>To keep open house</b></col>, <cd>to entertain friends at all
times.</cd></cs></p>

<p><syn><b>Syn.</b> -- Dwelling; residence; abode. See
<er>Tenement</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>House</ent><br/
<hw>House</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Housed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Housing</conjf>.]</vmorph> <ety>[AS. <ets>h<?/sian</ets>.]</ety>
<sn>1.</sn> <def>To take or put into a house; to shelter under a roof;
to cover from the inclemencies of the weather; to protect by covering;
<as>as, to <ex>house</ex> one's family in a comfortable home; to
<ex>house</ex> farming utensils; to <ex>house</ex>
cattle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>At length have <qex>housed</qex> me in a humble shed.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>House</qex> your choicest carnations, or rather set them
under a penthouse.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drive to a shelter.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To admit to residence; to harbor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Palladius wished him to <qex>house</qex> all the Helots.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To deposit and cover, as in the grave.</def>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>To stow in a safe place; to take
down and make safe; <as>as, to <ex>house</ex> the upper
spars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>House</ent><br/
<hw>House</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To take shelter or
lodging; to abide to dwell; to lodge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You shall not <qex>house</qex> with me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astrol.)</fld> <def>To have a position in one of
the houses. See <er>House</er>, <pos>n.</pos>, 8.</def> <ldquo/Where
Saturn <xex>houses</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>houseboat</ent><br/
<hw>houseboat</hw> <pos>n.</pos> <def>a barge that is designed and
equipped for use as a dwelling.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Housebote</ent><br/
<hw>House"bote`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>House</ets>
+ <ets>bote</ets>.]</ety> <fld>(Law)</fld> <def>Wood allowed to a tenant
for repairing the house and for fuel. This latter is often called
<xex>firebote</xex>. See <er>Bote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>housebound</ent><br/
<hw>housebound</hw> <pos>adj.</pos> <def>confined to the home, usually
due to illness.</def><br/
<syn><b>Syn. --</b> homebound, shut-in.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housebreak</ent><br/
<hw>house"break`</hw> <pos>v. t.</pos> <def>to train a pet to live
cleanly in a house, especially by training it to defecate and urinate in
designated boxes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Housebreaker</ent><br/
<hw>House"break`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
guilty of the crime of housebreaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housebreaking</ent><br/
<hw>House"break`ing</hw>, <pos>n.</pos> <def>The act of breaking open
and entering, with a felonious purpose, the dwelling house of another,
whether done by day or night. See <er>Burglary</er>, and <cref>To break
a house</cref>, under <er>Break</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>housebroken</ent><br/
<hw>housebroken</hw> <pos>adj.</pos> <def>trained to urinate and
defecate outside or in a special place, such as a litter box; <as>as,
<ex>housebroken</ex> pets; -- of pet animals</as>.</def><br/
<syn><b>Syn. --</b> house-trained, housetrained.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Housebuilder</ent><br/
<hw>House"build`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One whose
business is to build houses; a housewright.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housecarl</ent><br/
<hw>House"carl`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>huscarle</ets>. See <er>House</er>, and <er>Carl</er>.]</ety>
<fld>(Eng. Arch<ae/ol.)</fld> <def>A household servant; also, one of the
bodyguard of King Canute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>housecoat</ent><br/
<hw>housecoat</hw> <pos>n.</pos> <def>a loose dressing gown for
women.</def><br/
<syn><b>Syn. --</b> negligee, neglige, peignoir, wrapper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housecraft</ent><br/
<hw>housecraft</hw> <pos>n.</pos> <def>skill in domestic
management.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housedog</ent><br/
<hw>housedog</hw> <pos>n.</pos> <def>a dog trained to guard a
house.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housefather</ent><br/
<hw>housefather</hw> <pos>n.</pos> <def>a man in charge of children in
an institution.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housefly</ent><br/
<hw>house"fly`</hw> <pos>n.</pos> <sn>1.</sn> <def>common fly
(<spn>Musca domestica</spn>) that frequents human habitations and
spreads many diseases.</def><br/
<syn><b>Syn. --</b> <spn>Musca domestica</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>houseful</ent><br/
<hw>houseful</hw> <pos>n.</pos> <def>as many as a house will
accommodate; <as>as, they entertained a <ex>houseful</ex> of
guests</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>house guest</ent><br/
<ent>houseguest</ent><br/
<mhw><hw>houseguest</hw>, <hw>house guest</hw></mhw> <pos>n.</pos>
<def>a guest entertained and staying overnight in one's house for one or
more nights.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Household</ent><br/
<hw>House"hold`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Those
who dwell under the same roof and compose a family.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And calls, without affecting airs,<br/
His <qex>household</qex> twice a day to prayers.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A line of ancestry; a race or house.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Household</ent><br/
<hw>House"hold`</hw>, <pos>a.</pos> <def>Belonging to the house and
family; domestic; <as>as, <ex>household</ex> furniture;
<ex>household</ex> affairs.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Household bread</b></col>, <cd>bread made in the house
for common use; hence, bread that is not of the finest quality.</cd>
<mark>[Obs.]</mark> -- <col><b>Household gods</b></col> <fld>(Rom.
Antiq.)</fld>, <cd>the gods presiding over the house and family; the
<xex>Lares</xex> and <xex>Penates</xex>; hence, all objects endeared by
association with home.</cd> -- <col><b>Household troops</b></col>,
<cd>troops appointed to attend and guard the sovereign or his
residence.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Householder</ent><br/
<hw>House"hold`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The master or
head of a family; one who occupies a house with his family.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Towns in which almost every <qex>householder</qex> was an English
Protestant.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Compound householder</b></col>. <cd>See
<er>Compound</er>, <pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 710 --></p>

<p><ent>house-keep</ent><br/
<ent>housekeep</ent><br/
<mhw><hw>housekeep</hw>, <hw>house-keep</hw></mhw> <pos>v. i.</pos>
<def>to take care of all household-related business.</def><br/
<syn><b>Syn. --</b> house-keep, maintain a household, keep
house.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Housekeeper</ent><br/
<hw>House"keep`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who occupies a house with his family; a householder; the master or
mistress of a family.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who does, or oversees, the work of keeping
house; <as>as, his wife is a good <ex>housekeeper</ex></as>; often, a
woman hired to superintend the servants of a household and manage the
ordinary domestic affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who exercises hospitality, or has a plentiful
and hospitable household.</def> <mark>[Obs.]</mark> <rj><au>Sir H.
Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who keeps or stays much at home.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You are manifest <qex>housekeeper</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A house dog.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housekeeping</ent><br/
<hw>House"keep`ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of
occupying a dwelling house as a householder.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Care of domestic concerns; management of a house and
home affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hospitality; a liberal and hospitable table; a
supply of provisions.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Tell me, softly and hastily, what's in the pantry?<br/
Small <qex>housekeeping</qex> enough, said Ph<oe/be.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housekeeping</ent><br/
<hw>House"keep`ing</hw>, <pos>a.</pos> <def>Domestic; used in a family;
<as>as, <ex>housekeeping</ex> commodities</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housel</ent><br/
<hw>Hou"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>housel</ets>, <ets>husel</ets>, AS. <ets>h<umac/sel</ets>; akin to
Icel. <ets>h<umac/sl</ets>, Goth. <ets>hunsl</ets> a sacrifice.]</ety>
<def>The eucharist.</def> <mark>[Archaic]</mark> <rj><au>Rom. of R.</au>
<au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housel</ent><br/
<hw>Hou"sel</hw>, <pos>v. t.</pos> <ety>[AS.
<ets>h<umac/slian</ets>.]</ety> <def>To administer the eucharist
to.</def> <mark>[Archaic]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houseleek</ent><br/
<hw>House"leek`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>House</ets>
+ <ets>leek</ets>.]</ety> <fld>(Bot.)</fld> <def>A succulent plant of
the genus <gen>Sempervivum</gen> (<spn>Sempervivum tectorum</spn>),
originally a native of subalpine Europe, but now found very generally on
old walls and roofs. It is very tenacious of life under drought and
heat; -- called also <altname>ayegreen</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houseless</ent><br/
<hw>House"less</hw>, <pos>a.</pos> <def>Destitute of the shelter of a
house; shelterless; homeless; <as>as, a <ex>houseless</ex>
wanderer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houselessness</ent><br/
<hw>House"less*ness</hw>, <pos>n.</pos> <def>The state of being
houseless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houseline</ent><br/
<hw>House"line`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A small line of three strands used for seizing; -- called also
<altname>housing</altname>.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houseling</ent><br/
<hw>House"ling`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Housling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housemaid</ent><br/
<hw>House"maid`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female servant
employed to do housework, esp. to take care of the rooms.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Housemaid's knee</b></col> <fld>(Med.)</fld>, <cd>a
swelling over the knee, due to an enlargement of the bursa in the front
of the kneepan; -- so called because frequently occurring in servant
girls who work upon their knees.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>houseman</ent><br/
<hw>houseman</hw> <pos>n.</pos> <def>an advanced student or graduate in
medicine gaining supervised practical experience in a hospital or other
medical institution.</def> <mark>[British]</mark> <br/
<syn><b>Syn. --</b> intern, interne, internist, medical
intern.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housemaster</ent><br/
<hw>housemaster</hw> <pos>n.</pos> <def>A teacher in charge of a school
boardinghouse.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Housemate</ent><br/
<hw>House"mate`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dwells in
the same house with another.</def> <rj><au>R. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>houseplant</ent><br/
<hw>houseplant</hw> <pos>n.</pos> <def>any of a variety of plants grown
indoors for decorative purposes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>house-proud</ent><br/
<hw>house-proud</hw> <pos>adj.</pos> <def>proud of one's house or its
furnishings or upkeep.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>house-raising</ent><br/
<hw>house-raising</hw> <pos>n.</pos> <def>A gathering for the
construction of a house by a group of neighbors, usually in a rural
community, and sometimes accomplished in a single day; similar to a
<contr>barn-raising</contr>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Houseroom</ent><br/
<hw>House"room`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Room or place in a
house; <as>as, to give any one <ex>houseroom</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>house-to-house</ent><br/
<hw>house-to-house</hw> <pos>adj.</pos> <def>omitting no one; proceeding
from the door of one house to that of the next; <as>as,
<ex>house-to-house</ex> canvassing</as>.</def><br/
<syn><b>Syn. --</b> door-to-door.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housetop</ent><br/
<hw>house"top`</hw> <pos>n.</pos> <def>The roof of a house, especially
the flat part of a roof; <as>as, shout it from the
<ex>housetops</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>house-trained</ent><br/
<hw>house-trained</hw> <pos>adj.</pos> <def>same as
<er>housebroken</er>.</def><br/
<syn><b>Syn. --</b> housebroken, housetrained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>housetrained</ent><br/
<hw>housetrained</hw> <pos>adj.</pos> <def>same as
<er>housebroken</er>.</def><br/
<syn><b>Syn. --</b> housebroken, house-trained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Housewarming</ent><br/
<hw>House"warm`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A feast or
merry-making made by or for a family or business firm on taking
possession of a new house or premises.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housewife</ent><br/
<hw>House"wife`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>House</ets>
+ <ets>wife.</ets> Cf. <er>Hussy</er>.]</ety> <sn>1.</sn> <def>The wife
of a householder; the mistress of a family; the female head of a
household.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He a good husband, a good <qex>housewife</qex> she.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pr>(Usually pronounced <?/.)</pr> <ety>[See
<er>Hussy</er>, in this sense.]</ety> <def>A little case or bag for
materials used in sewing, and for other articles of female work; --
called also <altname>hussy</altname>.</def> <altsp>[Written also
<asp>huswife</asp>.]</altsp> <rj><au>P. Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A hussy.</def> <mark>[R.]</mark> <altsp>[Usually
written <asp>huswife</asp>.]</altsp> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Sailor's housewife</b></col>, <cd>a
ditty-bag.</cd></cs></p>

<p><ent>Housewive</ent><br/
<ent>Housewife</ent><br/
<mhw>{ <hw>House"wife`</hw> <pr>(?)</pr>, <hw>House"wive`</hw>
<pr>(?)</pr>, }</mhw> <pos>v. t.</pos> <def>To manage with skill and
economy, as a housewife or other female manager; to economize.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Conferred those moneys on the nuns, which since they have well
<qex>housewived</qex>.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housewifely</ent><br/
<hw>House"wife`ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining or
appropriate to a housewife; domestic; economical; prudent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A good sort of woman, ladylike and <qex>housewifely</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housewifery</ent><br/
<hw>House"wif`er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The business of
the mistress of a family; female management of domestic
concerns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housework</ent><br/
<hw>House"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The work belonging
to housekeeping; especially, kitchen work, sweeping, scrubbing, bed
making, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housewright</ent><br/
<hw>House"wright`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A builder of
houses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housing</ent><br/
<hw>Hous"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>House</er>.
In some of its senses this word has been confused with the following
word.]</ety> <sn>1.</sn> <def>The act of putting or receiving under
shelter; the state of dwelling in a habitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which shelters or covers; houses, taken
collectively.</def> <rj><au>Fabyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>The space taken out
of one solid, to admit the insertion of part of another, as the end of
one timber in the side of another.</def> <sd>(b)</sd> <def>A niche for a
statue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>A frame or support for holding
something in place, such as a piece of machinery, journal boxes,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>That portion of a
mast or bowsprit which is beneath the deck or within the vessel.</def>
<sd>(b)</sd> <def>A covering or protection, as an awning over the deck
of a ship when laid up.</def> <sd>(c)</sd> <def>A houseline. See
<er>Houseline</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Housing</ent><br/
<hw>Hous"ing</hw>, <pos>n.</pos> <ety>[From <er>Houss</er>.]</ety>
<sn>1.</sn> <def>A cover or cloth for a horse's saddle, as an ornamental
or military appendage; a saddlecloth; a horse cloth; in plural,
trappings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An appendage to the hames or collar of a
harness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>housings</ent><br/
<hw>housings</hw> <pos>n.</pos> <sn>1.</sn> <def>same as 2nd
<er>housing</er>, n.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Housling</ent><br/
<hw>Hous"ling</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Housel</er>.]</ety> <def>Sacramental; <as>as, <ex>housling</ex>
fire</as>.</def> <mark>[R.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houss</ent><br/
<hw>Houss</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>housse</ets>,
LL. <ets>hulcia</ets>, fr. OHG. <ets>hulst</ets>; akin to E.
<ets>holster</ets>. See <er>Holster</er>, and cf. 2d
<er>Housing</er>.]</ety> <def>A saddlecloth; a housing.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houstonia</ent><br/
\'d8<hw>Hous*to"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So named
after Dr. William <ets>Houston</ets>, an English surgeon and
botanist.]</ety> <fld>(Bot.)</fld> <def>A genus of small rubiaceous
herbs, having tetramerous salveform blue or white flower. There are
about twenty species, natives of North America. Also, a plant of this
genus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Houtou</ent><br/
\'d8<hw>Hou"tou</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From its
note.]</ety> <fld>(Zool.)</fld> <def>A beautiful South American
motmot.</def> <rj><au>Waterton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houttuynia</ent><br/
<hw>Houttuynia</hw> <pos>n.</pos> <def>A genus of plants having only one
species; East Asian low-growing plant of wet places.</def><br/
<syn><b>Syn. --</b> genus <gen>Houttuynia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Houve</ent><br/
<hw>Houve</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>h<umac/fe</ets>.]</ety> <def>A head covering of various kinds; a
hood; a coif; a cap.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Houyhnhnm</ent><br/
<hw>Hou*yhnhnm"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the race of
horses described by Swift in his imaginary travels of <person>Lemuel
Gulliver</person>. The Houyhnhnms were endowed with reason and noble
qualities; subject to them were Yahoos, a race of brutes having the form
and all the worst vices of men.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hove</ent><br/
<hw>Hove</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Heave</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hove short</b></col>, <col><b>Hove
to</b></col></mcol>. <cd>See <cref>To heave a cable short</cref>,
<cref>To heave a ship to</cref>, etc., under
<er>Heave</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hove</ent><br/
<hw>Hove</hw>, <pos>v. i. & t.</pos> <def>To rise; to swell; to heave;
to cause to swell.</def> <mark>[Obs. or Scot.]</mark> <rj><au>Holland.
Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hove</ent><br/
<hw>Hove</hw>, <pos>v. i.</pos> <ety>[OE. <ets>hoven</ets>. See
<er>Hover</er>.]</ety> <def>To hover around; to loiter; to lurk.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hovel</ent><br/
<hw>Hov"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hovel</ets>,
<ets>hovil</ets>, prob. a dim. fr. AS. <ets>hof</ets> house; akin to D.
& G. <ets>hof</ets> court, yard, Icel. <ets>hof</ets> temple; cf. Prov.
E. <ets>hove</ets> to take shelter, <ets>heuf</ets> shelter,
home.]</ety> <sn>1.</sn> <def>An open shed for sheltering cattle, or
protecting produce, etc., from the weather.</def> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A poor cottage; a small, mean house; a
hut.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Porcelain Manuf.)</fld> <def>A large conical brick
structure around which the firing kilns are grouped.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hovel</ent><br/
<hw>Hov"el</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hoveled</conjf> <pr>(?)</pr> or <conjf>Hovelled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Hoveling</conjf> or
<conjf>Hovelling</conjf>.]</vmorph> <def>To put in a hovel; to
shelter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>hovel</qex> thee with swine, and rogues forlon.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The poor are <qex>hoveled</qex> and hustled together.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoveler</ent><br/
<hw>Hov"el*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who assists in
saving life and property from a wreck; a coast boatman.</def>
<altsp>[Written also <asp>hoveller</asp>.]</altsp> <mark>[Prov.
Eng.]</mark> <rj><au>G. P. R. James.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoveling</ent><br/
<hw>Hov"el*ing</hw>, <pos>n.</pos> <def>A method of securing a good
draught in chimneys by covering the top, leaving openings in the sides,
or by carrying up two of the sides higher than the other two.</def>
<altsp>[Written also <asp>hovelling</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoven</ent><br/
<hw>Ho"ven</hw> <pr>(?)</pr>, <mark>obs. <or/ archaic</mark>
<def><pos>p. p.</pos> of <er>Heave</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoven</ent><br/
<hw>Ho"ven</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Affected with the
disease called <xex>hoove</xex>; <as>as, <ex>hoven</ex>
cattle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hover</ent><br/
<hw>Hov"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
doubtful.]</ety> <def>A cover; a shelter; a protection.</def>
<mark>[Archaic]</mark> <rj><au>Carew.</au> <au>C.
Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hover</ent><br/
<hw>Hov"er</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hovered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hovering</conjf>.]</vmorph> <ety>[OE. <ets>hoveren</ets>, and
<ets>hoven</ets>, prob. orig., to abide, linger, and fr. AS.
<ets>hof</ets> house; cf. OFries. <ets>hovia</ets> to receive into one's
house. See <er>Hovel</er>.]</ety> <sn>1.</sn> <def>To hang fluttering in
the air, or on the wing; to remain in flight or floating about or over a
place or object; to be suspended in the air above something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Great flights of birds are <qex>hovering</qex> about the bridge,
and settling on it.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>hovering</qex> mist came swimming o'er his sight.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hang about; to move to and fro near a place,
threateningly, watchfully, or irresolutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Agricola having sent his navy to <qex>hover</qex> on the
coast.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hovering</qex> o'er the paper with her quill.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hoya</ent><br/
<hw>hoya</hw> <pos>n.</pos> <sn>1.</sn> <def>any plant of the genus Hoya
having fleshy leaves and usually nectariferous flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hovercraft</ent><br/
<hw>hov"er*craft</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A vehicle that
rides over water or land supported by the pressure of a stream of air
generated by downward-thrusting fans, and is propelled forward by an air
propeller; also called <altname>ACV</altname> and <altname>air-cushioned
vehicle</altname>.</def> <mark>[Mostly found in Great
Britain]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hoverer</ent><br/
<hw>Hov"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A device in an
incubator for protecting the young chickens and keeping them
warm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hover-hawk</ent><br/
<hw>Hov"er-hawk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The kestrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoveringly</ent><br/
<hw>Hov"er*ing*ly</hw>, <pos>adv.</pos> <def>In a hovering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>How</ent><br/
<hw>How</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE. <ets>how</ets>,
<ets>hou</ets>, <ets>hu</ets>, <ets>hwu</ets>, AS. <ets>h<?/</ets>, from
the same root as <ets>hw<amac/</ets>, <ets>hw<ae/t</ets>, who, what,
pron. interrog.; akin to OS. <ets>hw<omac/</ets>w, D. <ets>hoe</ets>,
cf. G. <ets>wie</ets> how, Goth. <ets>hw<emac/</ets> wherewith,
<ets>hwaiwa</ets> how. <root/182. See <er>Who</er>, and cf.
<er>Why</er>.]</ety> <sn>1.</sn> <def>In what manner or way; by what
means or process.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>How</qex> can a man be born when he is old?</q> <rj><qau>John
iii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To what degree or extent, number or amount; in what
proportion; by what measure or quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, <qex>how</qex> love I thy law! it is my meditation all the
day.</q> <rj><qau>Ps. cxix. 97.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>how</qex> much they would diminish the present extent of
the sea, so much they would impair the fertility, and fountains, and
rivers of the earth.</q> <rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>For what reason; from what cause.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>How</qex> now, my love! why is your cheek so pale?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In what state, condition, or plight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>How</qex>, and with what reproach, shall I return?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>By what name, designation, or title.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>How</qex> art thou called?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>At what price; how dear.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>How</qex> a score of ewes now?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>How</xex> is used in each sense, interrogatively,
interjectionally, and relatively; it is also often employed to emphasize
an interrogation or exclamation. <ldquo/<xex>How</xex> are the mighty
fallen!<rdquo/ <au>2 Sam. i. 27.</au> Sometimes, also, it is used as a
noun; -- as, the <xex>how</xex>, the when, the wherefore.
<au>Shelley.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me beg you -- don't say <ldquo/<qex>How</qex>?<rdquo/ for
<ldquo/What?<rdquo/</q> <rj><qau>Holmes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howadji</ent><br/
\'d8<hw>How*adj"i</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.]</ety>
<sn>1.</sn> <def>A traveler.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A merchant; -- so called in the East because
merchants were formerly the chief travelers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howbeit</ent><br/
<hw>How*be"it</hw> <pr>(?)</pr>, <pos>conj.</pos> <ety>[<ets>How</ets> +
<ets>be</ets> + <ets>it</ets>.]</ety> <def>Be it as it may;
nevertheless; notwithstanding; although; albeit; yet; but;
however.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Moor -- <qex>howbeit</qex> that I endure him not -<br/
Is of a constant, loving, noble nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howdah</ent><br/
<hw>How"dah</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>hawdaj</ets>.]</ety> <def>A seat or pavilion, generally covered,
fastened on the back of an elephant, for the rider or riders.</def>
<altsp>[Written also <asp>houdah</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howdy</ent><br/
<hw>How"dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot., also
<ets>houdy-</ets> wife. Of uncertain origin; cf. OSw.
<ets>jordgumma</ets>; or perh. fr. E. <ets>how d'ye</ets>.]</ety> <def>A
midwife.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howel</ent><br/
<hw>How"el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tool used by coopers
for smoothing and chamfering their work, especially the inside of
casks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howel</ent><br/
<hw>How"el</hw>, <pos>v. t.</pos> <def>To smooth; to plane; <as>as, to
<ex>howel</ex> a cask</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howell</ent><br/
<hw>How"ell</hw>, <pos>n.</pos> <def>The upper stage of a porcelain
furnace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>However</ent><br/
<hw>How*ev"er</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[Sometimes
contracted into <ets>howe'er</ets>.]</ety> <sn>1.</sn> <def>In whatever
manner, way, or degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>However</qex> yet they me despise and spite.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Howe'er</qex> the business goes, you have made fault.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>At all events; at least; in any case.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our chief end is to be freed from all, if it may be,
<qex>however</qex> from the greatest evils.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>However</ent><br/
<hw>How*ev"er</hw>, <pos>conj.</pos> <def>Nevertheless; notwithstanding;
yet; still; though; <as>as, I shall not oppose your design; I can not,
<ex>however</ex>, approve of it.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>In your excuse your love does little say;<br/
You might <qex>howe'er</qex> have took a better way.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>However</er>, <er>At least</er>,
<er>Nevertheless</er>, <er>Yet</er>.</syn> <usage> These words, as here
compared, have an adversative sense in reference to something referred
to in the context. <xex>However</xex> is the most general, and leads to
a final conclusion or decision. Thus we say, the truth,
<xex>however</xex>, has not yet fully come out; <it>i.e.</it>, such is
the speaker's conclusion in view of the whole case. So also we say,
<xex>however</xex>, you may rely on my assistance to that amount; <it>i.
e.</it>, at all events, whatever may happen, this is my final decision.
<xex>At least</xex> is adversative in another way. It points out the
utmost concession that can possibly be required, and still marks the
adversative conclusion; <as>as, <ex>at least</ex>, this must be done;
whatever may be our love of peace, we must <ex>at least</ex> maintain
the rights of conscience</as>. <ex>Nevertheless</ex> denotes that though
the concession be fully made, it has no bearing of the question; <as>as,
<ex>nevertheless</ex>, we must go forward</as>. <ex>Yet</ex> signifies
that however extreme the supposition or fact comceded may be, the
consequence which might naturally be expected does not and will not
follow; <as>as, though I should die with thee, <ex>yet</ex> will I not
deny thee; though he slay me, <ex>yet</ex> will I trust in him</as>. Cf.
<er>But</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howitz</ent><br/
<hw>How"itz</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A howitzer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howitzer</ent><br/
<hw>How"itz*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>haubitze</ets>, formerly <ets>hauffnitz</ets>, Bohem.
<ets>haufnice</ets>, orig., a sling.]</ety> <fld>(Mil.)</fld>
<sd>(a)</sd> <def>A gun so short that the projectile, which was hollow,
could be put in its place by hand; a kind of mortar.</def>
<mark>[Obs.]</mark> <sd>(b)</sd> <def>A short, light, largebore cannon,
usually having a chamber of smaller diameter than the rest of the bore,
and intended to throw large projectiles with comparatively small
charges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howker</ent><br/
<hw>How"ker</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>Same as <er>Hooker</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howl</ent><br/
<hw>Howl</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Howled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Howling</conjf>.]</vmorph> <ety>[OE. <ets>houlen</ets>,
<ets>hulen</ets>; akin to D. <ets>huilen</ets>, MHG. <ets>hiulen</ets>,
<ets>hiuweln</ets>, OHG. <ets>hiuwil<omac/n</ets> to exult,
<ets>h<?/wo</ets> owl, Dan. <ets>hyle</ets> to howl.]</ety> <sn>1.</sn>
<def>To utter a loud, protracted, mournful sound or cry, as dogs and
wolves often do.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And dogs in corners set them down to <qex>howl</qex>.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Methought a legion of foul fiends<br/
Environ'd me about, and <qex>howled</qex> in my ears.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter a sound expressive of distress; to cry
aloud and mournfully; to lament; to wail.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Howl</qex> ye, for the day of the Lord is at hand.</q>
<rj><qau>Is. xiii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make a noise resembling the cry of a wild
beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wild <qex>howled</qex> the wind.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Howling monkey</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Howler</er>, 2.</cd> -- <col><b>Howling wilderness</b></col>, <cd>a
wild, desolate place inhabited only by wild beasts.</cd> <au>Deut.
xxxii. 10.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howl</ent><br/
<hw>Howl</hw>, <pos>v. t.</pos> <def>To utter with outcry.</def>
<ldquo/Go . . . <xex>howl</xex> it out in deserts.<rdquo/
<rj><au>Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howl</ent><br/
<hw>Howl</hw>, <pos>n.</pos> <sn>1.</sn> <def>The protracted, mournful
cry of a dog or a wolf, or other like sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A prolonged cry of distress or anguish; a
wail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howler</ent><br/
<hw>Howl"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
howls.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any South American monkey of the
genus <gen>Mycetes</gen>. Many species are known. They are arboreal in
their habits, and are noted for the loud, discordant howling in which
they indulge at night.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howlet</ent><br/
<hw>Howl"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Equiv. to
<ets>owlet</ets>, influenced by <ets>howl</ets>: cf. F.
<ets>hulotte</ets>, OHG. <ets>h<?/wela</ets>, <ets>hiuwela</ets>.]</ety>
<fld>(Zool.)</fld> <def>An owl; an owlet.</def> <altsp>[Written also
<asp>houlet</asp>.]</altsp> <rj><au>R. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howp</ent><br/
<hw>Howp</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To cry out; to
whoop.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howso</ent><br/
<hw>How"so</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Howsoever.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howsoever</ent><br/
<hw>How`so*ev"er</hw> <pr>(?)</pr>, <pos>adj. & conj.</pos>
<ety>[<ets>How</ets> + <ets>so</ets> + <ets>ever</ets>.]</ety>
<sn>1.</sn> <def>In what manner soever; to whatever degree or extent;
however.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am glad he's come, <qex>howsoever</qex> he comes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Although; though; however.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Howve</ent><br/
<hw>Howve</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hood. See
<er>Houve</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hoya</ent><br/
<hw>hoya</hw> <pos>n.</pos> <sn>1.</sn> <def>any plant of the genus Hoya
having fleshy leaves and usually nectariferous flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hox</ent><br/
<hw>Hox</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>Hock</er>.
<root/12.]</ety> <def>To hock; to hamstring. See <er>Hock</er>.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoy</ent><br/
<hw>Hoy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>heu</ets>, or
Flem. <ets>hui</ets>.]</ety> <fld>(Naut.)</fld> <def>A small coaster
vessel, usually sloop-rigged, used in conveying passengers and goods
from place to place, or as a tender to larger vessels in port.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hoy</qex> went to London every week.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoy</ent><br/
<hw>Hoy</hw>, <pos>interj.</pos> <ety>[D. <ets>hui</ets>. Cf.
<er>Ahoy</er>.]</ety> <def>Ho! Halloe! Stop!</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hoya</ent><br/
<hw>hoya</hw> <pos>n.</pos> <def>Any plant of the genus <gen>Hoya</gen>
having fleshy leaves and usually nectariferous flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hoyden</ent><br/
<hw>Hoy"den</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hoiden</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hoyman</ent><br/
<hw>Hoy"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hoymen</plw> <pr>(<?/)</pr>.</plu> <def>One who navigates a
hoy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A common <qex>hoyman</qex> to carry goods by water for hire.</q>
<rj><qau>Hobart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>HQ</ent><br/
<hw>HQ</hw> <pos>n.</pos> <ety>[acronym]</ety> <def>Headquarters, the
place from which a commander performs the functions of
command.</def><br/
<syn><b>Syn. --</b> headquarters, military headquarters.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hr</ent><br/
<hw>hr</hw> <pos>n.</pos> <ety>[abbreviation]</ety> <def>An abbreviation
for <er>hour</er>, the period of time equal to 1/24th of a
day.</def><br/
<syn><b>Syn. --</b> hour, 60 minutes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>HSV-I</ent><br/
<ent>HSV-1</ent><br/
<ent>HS1</ent><br/
<mhw><hw>HS1</hw>, <hw>HSV-1</hw>, <hw>HSV-I</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>Herpes simplex 1, a herpes virus that causes oral
herpes; also called <altname>type I Herpes</altname>.</def><br/
<syn><b>Syn. --</b> herpes simplex 1.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>HSV-II</ent><br/
<ent>HSV-2</ent><br/
<ent>HS2</ent><br/
<mhw><hw>HS2</hw>, <hw>HSV-2</hw>, <hw>HSV-II</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>Herpes simplex 2, a herpes virus that can cause genital
herpes; also called <altname>type II Herpes</altname>.</def><br/
<syn><b>Syn. --</b> herpes simplex 2.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hsien</ent><br/
<hw>Hsien</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin.]</ety> <def>An
administrative subdivision of a <partof>fu</partof>, or department, or
of an independent chow; also, the seat of government of such a
district.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>huamachil</ent><br/
<hw>huamachil</hw> <pos>n.</pos> <def>A common thorny tropical American
tree (<spn>Pithecellobium dulce</spn>) having terminal racemes of yellow
flowers followed by sickle-shaped or circinate edible pods and yielding
good timber and a yellow dye and mucilaginous gum.</def><br/
<syn><b>Syn. --</b> manila tamarind, camachile, wild tamarind,
<spn>Pithecellobium dulce</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Huanaco</ent><br/
\'d8<hw>Hua*na"co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Guanaco</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huaracho</ent><br/
<ent>huaraches</ent><br/
<ent>Huarache</ent><br/
<mhw>\'d8<hw>Hua*ra"che</hw>, <hw>hua*ra"ches</hw>,
\'d8<hw>Hua*ra"cho</hw> <pr>(?)</pr></mhw>, <pos>n.</pos>; <plu>pl.
<plw>Huarachos</plw> <pr>(#)</pr></plu>. <ety>[Amer. Sp., also
<ets>guaracha</ets>, <ets>guarache</ets>, <ets>huarache</ets>, prob. of
Mexican origin.]</ety> <def>A kind of low-heeled sandal with the upper
consisting of interwoven leather strips; -- usually used in
<pluf>pl.</pluf></def> <mark>[Southern U. S. & Mex.]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Huascaran</ent><br/
<hw>Huascaran</hw> <pos>prop. n.</pos> <def>a mountain in Peru, 22,205
feet high.</def> <mark>[proper name]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>huastorium</ent><br/
<hw>huastorium</hw> <pos>n.</pos> <def>a rootlike attachment in
parasitic plants that penetrates and obtains food from the
host.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hub</ent><br/
<hw>Hub</hw> <pr>(h<ucr/b)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Hob</er>.]</ety> <sn>1.</sn> <def>The central part, usually
cylindrical, of a wheel; the nave. See <xex>Illust.</xex> of <er>Axle
box</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The hilt of a weapon.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A rough protuberance or projecting obstruction;
<as>as, a <ex>hub</ex> in the road</as>. <mark>[U.S.]</mark> See
<er>Hubby</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A goal or mark at which quoits, etc., are
cast.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Diesinking)</fld> <def>A hardened, engraved steel
punch for impressing a device upon a die, used in coining,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A screw hob. See <er>Hob</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A block for scotching a wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The central location within which activities tend to
concentrate, or from which activities radiate outward; a focus of
activity.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <specif>Hence:</specif> <fld>(Aeronautics)</fld> <def>A
large airport used as a central transfer station for an airline,
permitting economic air transportation between remote locations by
directing travellers through the hub, often changing planes at the hub,
and thus keeping the seat occupancy rate on the airplanes high. The
<ex>hub</ex> together with the <ecol><b>feeder lines</b></ecol> from
remote locations constitute the so-called <col><b>hub and spoke
system</b></col> of commercial air passenger transportation. A
commercial airline may have more than one such <ex>hub</ex>.</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <def>The city of Boston, Massachusetts referred to
locally by the nickname <altname>The Hub</altname>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Hub plank</b></col> <fld>(Highway Bridges)</fld>, <cd>a
horizontal guard plank along a truss at the height of a wagon-wheel
hub.</cd> -- <col><b>Up to the hub</b></col>, <cd>as far as possible in
embarrassment or difficulty, or in business, like a wheel sunk in mire;
deeply involved.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hubble-bubble</ent><br/
<hw>Hub"ble-bub`ble</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tobacco
pipe, so arranged that the smoke passes through water, making a bubbling
noise, whence its name. In India, the bulb containing the water is often
a cocoanut shell. It is a simple type of <er>hookah</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hubble Space Telescope</ent><br/
<ent>Hubble Telescope</ent><br/
<mhw><hw>Hub"ble Tel"e*scope</hw>, <hw>Hub"ble Space
Tel"e*scope</hw></mhw> <pr>(?)</pr>, <pos>n.</pos> <def>A large
astronomical optical telescope placed into orbit around the earth, from
which, in the absence of absorption and distortion by the earth's
atmosphere, clear high-resolution images of astronomical objects can be
obtained in the visible, infrared, and ultraviolet wavelengths. The
telescope was launched into orbit on April 24, 1990. Since then the
telescope has taken thousands of images, many of them unique, recording
never before seen astronomical phenomena. Service missions were
performed in 1993 and 1997, during which astronauts upgraded or replaced
equipment on the telescope.</def><br/
[<source>PJC</source>]</p>

<p><-- p. 711 --></p>

<p><ent>Hubbub</ent><br/
<hw>Hub"bub</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Whoobub</er>,
<er>Whoop</er>, <er>Hoop</er>, <pos>v. i.</pos>]</ety> <def>A loud noise
of many confused voices; a tumult; uproar.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>hubbub</qex> of unmeaning words.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hubby</ent><br/
<hw>Hub"by</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of hubs or
protuberances; <as>as, a road that has been frozen while muddy is
<ex>hubby</ex></as>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hubby</ent><br/
<hw>hub"by</hw> <pr>(h<ucr/b"b<ycr/)</pr>, <pos>n.</pos>
<def>Husband.</def> <mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hubnerite</ent><br/
<hw>H<uum/b"ner*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[After
<ets>H<uum/bner</ets>, who analyzed it.]</ety> <fld>(Min.)</fld> <def>A
mineral of brownish black color, occurring in columnar or foliated
masses. It is native <altname>manganese tungstate</altname>.</def></p>

<p><ent>Huchen</ent><br/
<ent>Huch</ent><br/
<mhw>{ \'d8<hw>Huch</hw> <pr>(?)</pr>, \'d8<hw>Hu"chen</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[G.]</ety> <fld>(Zool.)</fld>
<def>A large salmon (<spn>Salmo hucho</spn> <it>or</it> <spn>Salvelinus
hucho</spn>) inhabiting the Danube; -- called also
<altname>huso</altname>, and <altname>bull trout</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huck</ent><br/
<hw>Huck</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See <er>Hawk</er> to
offer for sale, <er>Huckster</er>.]</ety> <def>To higgle in
trading.</def> <mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckaback</ent><br/
<hw>Huck"a*back</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. orig.,
peddler's wares; cf. LG. <ets>hukkebak</ets> pickback. Cf.
<er>Huckster</er>.]</ety> <def>A kind of linen cloth with raised
figures, used for towelings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckle</ent><br/
<hw>Huc"kle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. dim. of Prov.
E. <ets>huck</ets>a hook, and so named from its round shape. See
<er>Hook</er>.]</ety> <sn>1.</sn> <def>The hip; the haunch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bunch or part projecting like the hip.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Huckle bone</b></col>. <sd>(a)</sd> <cd>The hip bone; the
innominate bone.</cd> <sd>(b)</sd> <cd>A small bone of the ankle;
astragalus.</cd> <mark>[R.]</mark> <rj><au>Udall.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckle-backed</ent><br/
<hw>Huc"kle-backed`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Round-shouldered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckleberry</ent><br/
<hw>Huc"kle*ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Whortleberry</er>.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The
edible black or dark blue fruit of several species of the American genus
<gen>Gaylussacia</gen>, shrubs nearly related to the blueberries
(<gen>Vaccinium</gen>), and formerly confused with them. The commonest
huckelberry comes from <spn>Gaylussacia resinosa</spn>.</def>
<sd>(b)</sd> <def>The shrub that bears the berries. Called also
whortleberry.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Squaw huckleberry</b></col>. <cd>See
<er>Deeberry</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckster</ent><br/
<hw>Huck"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hukstere</ets>, <ets>hukster</ets>, OD. <ets>heukster</ets>, D.
<ets>heuker</ets>; akin to D. <ets>huiken</ets> to stoop, bend, OD.
<ets>huycken</ets>, <ets>huken</ets>, G. <ets>hocken</ets>, to squat,
Icel. <ets>h<?/ka</ets>; -- the peddler being named from his stooping
under the load on his back. Cf. <er>Hawk</er> to offer for sale.]</ety>
<sn>1.</sn> <def>A retailer of small articles, of provisions, and the
like; a peddler; a hawker.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mean, trickish fellow.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckster</ent><br/
<hw>Huck"ster</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Huckstered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Huckstering</conjf>.]</vmorph> <def>To deal in small articles, or
in petty bargains.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hucksterage</ent><br/
<hw>Huck"ster*age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The business of
a huckster; small dealing; peddling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ignoble <qex>huckster</qex> age of piddling tithes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hucksterer</ent><br/
<hw>Huck"ster*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A huckster.</def>
<rj><au>Gladstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those <qex>huckster</qex>ers or money-jobbers.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huckstress</ent><br/
<hw>Huck"stress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
huckster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hud</ent><br/
<hw>Hud</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Hood</er> a
covering.]</ety> <def>A huck or hull, as of a nut.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huddle</ent><br/
<hw>Hud"dle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Huddled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Huddling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. OE.
<ets>hoderen</ets>, <ets>hodren</ets>, to cover, keep, warm; perh. akin
to OE. <ets>huden</ets>, <ets>hiden</ets>, to hide, E. <ets>hide</ets>,
and orig. meaning, to get together for protection in a safe place. Cf.
<er>Hide</er> to conceal.]</ety> <def>To press together promiscuously,
from confusion, apprehension, or the like; to crowd together confusedly;
to press or hurry in disorder; to crowd.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cattle <qex>huddle</qex>d on the lea.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Huddling</qex> together on the public square . . . like a
herd of panic-struck deer.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huddle</ent><br/
<hw>Hud"dle</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To crowd (things)
together to mingle confusedly; to assemble without order or
system.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our adversary, <qex>huddling</qex> several suppositions together,
. . . makes a medley and confusion.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To do, make, or put, in haste or roughly; hence, to
do imperfectly; -- usually with a following preposition or adverb;
<as>as, to <ex>huddle on</ex>; to <ex>huddle up</ex>; to <ex>huddle
together</ex>.</as></def> <ldquo/<xex>Huddle</xex> up a peace.<rdquo/
<rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him forescat his work with timely care,<br/
Which else is <qex>huddled</qex> when the skies are fair.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now, in all haste, they <qex>huddle</qex> on<br/
Their hoods, their cloaks, and get them gone.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huddle</ent><br/
<hw>Hud"dle</hw>, <pos>n.</pos> <def>A crowd; a number of persons or
things crowded together in a confused manner; tumult; confusion.</def>
<ldquo/A <xex>huddle</xex> of ideas.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huddler</ent><br/
<hw>Hud"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who huddles
things together.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hudge</ent><br/
<hw>Hudge</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mining)</fld> <def>An
iron bucket for hoisting coal or ore.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hudibrastic</ent><br/
<hw>Hu`di*bras"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Similar to, or
in the style of, the poem <ldquo/<xex>Hudibras</xex>,<rdquo/ by Samuel
Butler; in the style of doggerel verse.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hudsonia</ent><br/
<hw>Hudsonia</hw> <pos>n.</pos> <def>A genus of small evergreen
subshrubs of North America.</def><br/
<syn><b>Syn. --</b> genus <gen>Hudsonia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hudsonian</ent><br/
<hw>Hud*so"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Hudson's Bay or to the Hudson River; <as>as, the <ex>Hudsonian</ex>
curlew</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hue</ent><br/
<hw>Hue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hew</ets>,
<ets>heow</ets>, color, shape, form, AS. <ets>hiw</ets>,
<ets>heow</ets>; akin to Sw. <ets>hy</ets> skin, complexion, Goth.
<ets>hiwi</ets> form, appearance.]</ety> <sn>1.</sn> <def>Color or shade
of color; tint; dye.</def> <ldquo/Flowers of all <xex>hue</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hues</qex> of the rich unfolding morn.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Painting)</fld> <def>A predominant shade in a
composition of primary colors; a primary color modified by combination
with others.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hue</ent><br/
<hw>Hue</hw>, <pos>n.</pos> <ety>[OE. <ets>hue</ets>, <ets>huer</ets>,
to hoot, shout, prob. fr. OF. <ets>hu</ets> an exclamation.]</ety>
<def>A shouting or vociferation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hue and cry</b></col> <fld>(Law)</fld>, <cd>a loud outcry
with which felons were anciently pursued, and which all who heard it
were obliged to take up, joining in the pursuit till the malefactor was
taken; in later usage, a written proclamation issued on the escape of a
felon from prison, requiring all persons to aid in retaking him.</cd>
<rj><au>Burrill.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hued</ent><br/
<hw>Hued</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having color; -- usually
in composition; <as>as, bright-<ex>hued</ex>;
many-<ex>hued</ex>.</as></def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hueless</ent><br/
<hw>Hue"less</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>hiwle<aacute/s</ets>. See <er>Hue</er> color.]</ety> <def>Destitute
of color.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huer</ent><br/
<hw>Hu"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who cries out or
gives an alarm; specifically, a balker; a conder. See
<er>Balker</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huff</ent><br/
<hw>Huff</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Huffed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Huffing</conjf>.]</vmorph> <ety>[Cf. OE. <ets>hoove</ets> to puff
up, blow; prob. of imitative origin.]</ety> <sn>1.</sn> <def>To swell;
to enlarge; to puff up; <as>as, <ex>huffed</ex> up with air</as>.</def>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To treat with insolence and arrogance; to chide or
rebuke with insolence; to hector; to bully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You must not presume to <qex>huff</qex> us.</q>
<rj><qau>Echard.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Draughts)</fld> <def>To remove from the board (the
piece which could have captured an opposing piece). See <er>Huff</er>,
<pos>v. i.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huff</ent><br/
<hw>Huff</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To enlarge; to swell
up; <as>as, bread <ex>huffs</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bluster or swell with anger, pride, or arrogance;
to storm; to take offense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This senseless arrogant conceit of theirs made them
<qex>huff</qex> at the doctrine of repentance.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Draughts)</fld> <def>To remove from the board a man
which could have captured a piece but has not done so; -- so called
because it was the habit to blow upon the piece.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huff</ent><br/
<hw>Huff</hw>, <pos>n.</pos> <sn>1.</sn> <def>A swell of sudden anger or
arrogance; a fit of disappointment and petulance or anger; a rage.</def>
<ldquo/Left the place in a <xex>huff</xex>.<rdquo/ <rj><au>W.
Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A boaster; one swelled with a false opinion of his
own value or importance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lewd, shallow-brained <qex>huffs</qex> make atheism and contempt
of religion the sole badge . . . of wit.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To take huff</b></col>, <cd>to take offence.</cd>
<rj><au>Cowper.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huffcap</ent><br/
<hw>Huff"cap`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A blusterer; a
bully.</def> <mark>[Obs.]</mark> -- <def2><pos>a.</pos> <def>Blustering;
swaggering.</def> <mark>[Obs.]</mark> <au>Bp. Hall.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huffer</ent><br/
<hw>Huff"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bully; a
blusterer.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huffiness</ent><br/
<hw>Huff"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
huffish; petulance; bad temper.</def> <rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huffingly</ent><br/
<hw>Huff"ing*ly</hw>, <pos>adv.</pos> <def>Blusteringly;
arrogantly.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>huffingly</qex> doth this bonny Scot ride.</q>
<rj><qau>Old Ballad.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huffish</ent><br/
<hw>Huff"ish</hw>, <pos>a.</pos> <def>Disposed to be blustering or
arrogant; petulant.</def> -- <wordforms><wf>Huff"ish*ly</wf>,
<pos>adv.</pos> -- <wf>Huff"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huffy</ent><br/
<hw>Huff"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Puffed up;
<as>as, <ex>huffy</ex> bread</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by arrogance or petulance; easily
offended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hug</ent><br/
<hw>Hug</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hugged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hugging</conjf>.]</vmorph> <ety>[Prob. of Scand. origin; cf. Dan.
<ets>sidde paa huk</ets> to squat, Sw. <ets>huka sig</ets> to squat,
Icel. <ets>h<?/ka</ets>. Cf. <er>Huckster</er>.]</ety> <sn>1.</sn>
<def>To cower; to crouch; to curl up.</def> <mark>[Obs.]</mark>
<rj><au>Palsgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To crowd together; to cuddle.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hug</ent><br/
<hw>Hug</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To press closely within
the arms; to clasp to the bosom; to embrace.</def> <ldquo/And
<xex>huggen</xex> me in his arms.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hold fast; to cling to; to cherish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>hug</qex> deformities if they bear our names.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>To keep close to; <as>as, to
<ex>hug</ex> the land; to <ex>hug</ex> the wind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hug one's self</b></col>, <cd>to congratulate one's
self; to chuckle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hug</ent><br/
<hw>Hug</hw>, <pos>n.</pos> <def>A close embrace or clasping with the
arms, as in affection or in wrestling.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huge</ent><br/
<hw>Huge</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Huger</adjf> <pr>(?)</pr>; <pos>superl.</pos> <adjf>Hugest</adjf>
<pr>(?)</pr>.]</amorph> <ety>[OE. <ets>huge</ets>, <ets>hoge</ets>, OF.
<ets>ahuge</ets>, <ets>ahoge</ets>.]</ety> <def>Very large; enormous;
immense; excessive; -- used esp. of material bulk, but often of
qualities, extent, etc.; <as>as, a <ex>huge</ex> ox; a <ex>huge</ex>
space; a <ex>huge</ex> difference.</as></def> <ldquo/The <xex>huge</xex>
confusion.<rdquo/ <au>Chapman.</au> <ldquo/A <xex>huge</xex>
filly.<rdquo/ <au>Jer. Taylor.</au> -- <wordforms><wf>Huge"ly</wf>,
<pos>adv.</pos> -- <wf>Huge"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Doth it not flow as <qex>hugely</qex> as the sea.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Enormous; gigantic; colossal; immense;
prodigious; vast.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hugger</ent><br/
<hw>Hug"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hugs or
embraces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hugger</ent><br/
<hw>Hug"ger</hw>, <pos>v. t. & i.</pos> <def>To conceal; to lurk
ambush.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hugger-mugger</ent><br/
<hw>Hug"ger-mug`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot.
<ets>huggrie-muggrie</ets>; Prov. E. <ets>hugger</ets> to lie in ambush,
<ets>mug</ets> mist, <ets>muggard</ets> sullen.]</ety> <sn>1.</sn>
<def>Privacy; secrecy. Commonly in the phrase <xex>in
hugger-mugger</xex>, with haste and secrecy.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Many things have been done in <qex>hugger-mugger</qex>.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confusion; disorder.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hugger-mugger</ent><br/
<hw>Hug"ger-mug`ger</hw>, <pos>a.</pos> <sn>1.</sn> <def>Secret;
clandestine; sly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confused; disorderly; slovenly; mean; <as>as,
<ex>hugger-mugger</ex> doings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hugging</ent><br/
<hw>hugging</hw> <pos>n.</pos> <def>Affectionate embracing;
caressing.</def><br/
<syn><b>Syn. --</b> caressing, cuddling, fondling, kissing, necking,
petting, smooching, snuggling.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Huggle</ent><br/
<hw>Hug"gle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Freq. of
<ets>hug</ets>.]</ety> <def>To hug.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>hug-me-tight</ent><br/
<hw>hug-me-tight</hw> <pos>n.</pos> <def>A woman's fitted
jacket.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hugoesque</ent><br/
<hw>Hugoesque</hw> <pos>adj.</pos> <def>of, pertaining to, or in the
style of <person>Victor Hugo</person>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hugueninia</ent><br/
<hw>Hugueninia</hw> <pos>n.</pos> <sn>1.</sn> <def>A genus having only
one species, the tansy-leaved rocket.</def><br/
<syn><b>Syn. --</b> genus <gen>Hugueninia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Huguenot</ent><br/
<hw>Hu"gue*not</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., properly a
dim. of <ets>Hugues</ets>. The name is probably derived from the
Christian name (<ets>Huguenot</ets>) of some person conspicuous as a
reformer.]</ety> <fld>(Eccl. Hist.)</fld> <def>A French Protestant of
the period of the religious wars in France in the 16th
century.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huguenotism</ent><br/
<hw>Hu"gue*not*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>huguenotisme</ets>.]</ety> <def>The religion of the Huguenots in
France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hugy</ent><br/
<hw>Hu"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Vast.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huia bird</ent><br/
<hw>Hu"ia bird`</hw> <pr>(?)</pr>. <ety>[Native name; -- so called from
its cry.]</ety> <fld>(Zool.)</fld> <def>A New Zealand starling
(<spn>Heteralocha acutirostris</spn>), remarkable for the great
difference in the form and length of the bill in the two sexes, that of
the male being sharp and straight, that of the female much longer and
strongly curved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huisher</ent><br/
<hw>Hui"sher</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Usher</er>.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huisher</ent><br/
<hw>Hui"sher</hw>, <pos>v. t.</pos> <def>To usher.</def>
<mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huke</ent><br/
<hw>Huke</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>huque</ets>,
LL. <ets>huca</ets>; cf. D. <ets>huik</ets>.]</ety> <def>An outer
garment worn in Europe in the Middle Ages.</def> <altsp>[Written also
<asp>heuk</asp> and <asp>hyke</asp>.]</altsp> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulan</ent><br/
<hw>Hu"lan</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Uhlan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulch</ent><br/
<hw>Hulch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Hunch</er>.]</ety> <def>A hunch.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulchy</ent><br/
<hw>Hulch"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Swollen;
gibbous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulk</ent><br/
<hw>Hulk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hulke</ets> a
heavy ship, AS. <ets>hulc</ets> a light, swift ship; akin to D.
<ets>hulk</ets> a ship of burden, G. <ets>holk</ets>, OHG.
<ets>holcho</ets>; perh. fr. LL. <ets>holcas</ets>, Gr. <?/, prop., a
ship which is towed, fr. <?/ to draw, drag, tow. Cf. <er>Wolf</er>,
<er>Holcad</er>.]</ety> <sn>1.</sn> <def>The body of a ship or decked
vessel of any kind; esp., the body of an old vessel laid by as unfit for
service.</def> <ldquo/Some well-timbered <xex>hulk</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A heavy ship of clumsy build.</def>
<rj><au>Skeat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything bulky or unwieldly.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Shear hulk</b></col>, <cd>an old ship fitted with an
apparatus to fix or take out the masts of a ship.</cd> -- <col><b>The
hulks</b></col>, <cd>old or dismasted ships, formerly used as
prisons.</cd> <mark>[Eng.]</mark> <au>Dickens.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulk</ent><br/
<hw>Hulk</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. MLG.
<ets>holken</ets> to hollow out, Sw. <ets>h<aring/lka</ets>.]</ety>
<def>To take out the entrails of; to disembowel; <as>as, to
<ex>hulk</ex> a hare</as>.</def> <mark>[R.]</mark> <rj><au>Beau. &
Fl.</au></rj></p>

<p><ent>Hulky</ent><br/
<ent>Hulking</ent><br/
<mhw>{ <hw>Hulk"ing</hw>, <hw>Hulk"y</hw> <pr>(?)</pr>, }</mhw>
<pos>a.</pos> <def>Bulky; unwieldy; of great size and bulk;
ponderous.</def> <mark>[R.]</mark> <ldquo/A huge <xex>hulking</xex>
fellow.<rdquo/ <rj><au>H. Brooke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hull</ent><br/
<hw>Hull</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hul</ets>,
<ets>hol</ets>, shell, husk, AS. <ets>hulu</ets>; akin to G.
<ets>h<uum/lle</ets> covering, husk, case, <ets>h<uum/llen</ets> to
cover, Goth. <ets>huljan</ets> to cover, AS. <ets>helan</ets> to hele,
conceal. <root/17. See <er>Hele</er>, <pos>v. t.</pos>,
<er>Hell</er>.]</ety> <sn>1.</sn> <def>The outer covering of anything,
particularly of a nut or of grain; the outer skin of a kernel; the
husk.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[In this sense perh. influenced by D. <ets>hol</ets>
hold of a ship, E. <ets>hold</ets>.]</ety> <fld>(Naut.)</fld> <def>The
frame or body of a vessel, exclusive of her masts, yards, sails, and
rigging.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Deep in their <qex>hulls</qex> our deadly bullets light.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hull down</b></col>, <cd>said of a ship so distant that
her hull is concealed by the convexity of the sea.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hull</ent><br/
<hw>Hull</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hulled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hulling</conjf>.]</vmorph> <sn>1.</sn> <def>To strip off or
separate the hull or hulls of; to free from integument; <as>as, to
<ex>hull</ex> corn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pierce the hull of, as a ship, with a cannon
ball.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hull</ent><br/
<hw>Hull</hw>, <pos>v. i.</pos> <def>To toss or drive on the water, like
the hull of a ship without sails.</def> <mark>[Obs.]</mark>
<rj><au>Shak. Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hullabaloo</ent><br/
<hw>Hul`la*ba*loo"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. a
corruption of <ets>hurly-burly</ets>.]</ety> <def>A confused noise;
uproar; tumult.</def> <mark>[Colloq.]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulled</ent><br/
<hw>Hulled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived of the
hulls.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hulled corn</b></col>, <cd>kernels of maize prepared for
food by removing the hulls.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huller</ent><br/
<hw>Hull"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, hulls; especially, an agricultural machine for removing the hulls
from grain; a hulling machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hullo</ent><br/
<hw>Hul*lo"</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>See
<er>Hollo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hully</ent><br/
<hw>Hull"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having or containing
hulls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huloist</ent><br/
<hw>Hu"lo*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hyloist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulotheism</ent><br/
<hw>Hu"lo*the*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hylotheism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hulver</ent><br/
<hw>Hul"ver</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hulfere</ets>; prob. akin to E. <ets>holly</ets>.]</ety>
<def>Holly, an evergreen shrub or tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hum</ent><br/
<hw>Hum</hw> <pr>(h<ucr/m)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hummed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Humming</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Of
imitative origin; cf. G. <ets>hummen</ets>, D. <ets>hommelen</ets>.
<root/15.]</ety> <sn>1.</sn> <def>To make a low, prolonged sound, like
that of a bee in flight; to drone; to murmur; to buzz; <as>as, a top
<ex>hums</ex></as>.</def> <rj><au>P. Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Still <qex>humming</qex> on, their drowsy course they keep.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a nasal sound, like that of the letter
<xex>m</xex> prolonged, without opening the mouth, or articulating; to
mumble in monotonous undertone; to drone.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cloudy messenger turns me his back,<br/
And <qex>hums</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. <er>Hum</er>, <ets>interj</ets>.]</ety> <def>To
make an inarticulate sound, like <xex>h'm</xex>, through the nose in the
process of speaking, from embarrassment or a affectation; to
hem.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To express satisfaction by a humming
noise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here the spectators <qex>hummed</qex>.</q> <rj><qau>Trial of the
Regicides.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly the habit of audiences was to express
gratification by humming and displeasure by hissing.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To have the sensation of a humming noise; <as>as, my
head <ex>hums</ex>, -- a pathological condition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hum</ent><br/
<hw>Hum</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To sing with shut mouth;
to murmur without articulation; to mumble; <as>as, to <ex>hum</ex> a
tune</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express satisfaction with by humming.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To flatter by approving; to cajole; to impose on; to
humbug.</def> <mark>[Colloq. & Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hum</ent><br/
<hw>Hum</hw>, <pos>n.</pos> <sn>1.</sn> <def>A low monotonous noise, as
of bees in flight, of a swiftly revolving top, of a wheel, or the like;
a drone; a buzz.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The shard-borne beetle with his drowsy <qex>hums</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any inarticulate and buzzing sound</def>; as:
<sd>(a)</sd> <def>The confused noise of a crowd or of machinery, etc.,
heard at a distance; <as>as, the <ex>hum</ex> of
industry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But 'midst the crowd, the <qex>hum</qex>, the shock of men.</q>
<rj><qau>Byron.</qau></rj></p>

<p><sd>(b)</sd> <def>A buzz or murmur, as of approbation.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An imposition or hoax.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[Cf. <er>Hem</er>, <pos>interj.</pos>]</ety> <def>An
inarticulate nasal sound or murmur, like <xex>h'm</xex>, uttered by a
speaker in pause from embarrassment, affectation, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These shrugs, these <qex>hums</qex> and ha's.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[Perh. so called because strongly
intoxicating.]</ety> <def>A kind of strong drink formerly used.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Venous hum</b></col>. <cd>See under
<er>Venous</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hum</ent><br/
<hw>Hum</hw>, <pos>interj.</pos> <ety>[Cf. <er>Hem</er>,
<ets>interj</ets>.]</ety> <def>Ahem; hem; an inarticulate sound uttered
in a pause of speech implying doubt and deliberation.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Human</ent><br/
<hw>Hu"man</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>humanus</ets>;
akin to <ets>homo</ets> man: cf. F. <ets>humain</ets>. See
<er>Homage</er>, and cf. <er>Humane</er>, <er>Omber</er>.]</ety>
<def>Belonging to man or mankind; having the qualities or attributes of
a man; of or pertaining to man or to the race of man; <as>as, a
<ex>human</ex> voice; <ex>human</ex> shape; <ex>human</ex> nature;
<ex>human</ex> sacrifices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To err is <qex>human</qex>; to forgive, divine.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Human</ent><br/
<hw>Hu"man</hw>, <pos>n.</pos> <def>A human being.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sprung of <qex>humans</qex> that inhabit earth.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>humans</qex> often find ourselves in strange position.</q>
<rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanate</ent><br/
<hw>Hu"man*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>humanatus</ets>.]</ety> <def>Indued with humanity.</def>
<mark>[Obs.]</mark> <rj><au>Cranmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humane</ent><br/
<hw>Hu*mane"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>humanus</ets>: cf. F. <ets>humain</ets>. See <er>Human</er>.]</ety>
<sn>1.</sn> <def>Pertaining to man; human.</def> <mark>[Obs.]</mark>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the feelings and inclinations creditable to
man; having a disposition to treat other human beings or animals with
kindness; kind; benevolent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of an exceeding courteous and <qex>humane</qex> inclination.</q>
<rj><qau>Sportswood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Humanizing; exalting; tending to refine.</def></p>

<p><syn><b>Syn.</b> -- Kind; sympathizing; benevolent; mild;
compassionate; gentle; tender; merciful.</syn></p>

<p>-- <wordforms><wf>Hu*mane"ly</wf>, <pos>adv.</pos> --
<wf>Hu*mane"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 712 --></p>

<p><ent>Humanics</ent><br/
<hw>Hu*man"ics</hw> <pr>(h<usl/*m<acr/n"<icr/ks)</pr>, <pos>n.</pos>
<def>The study of human nature.</def> <mark>[R.]</mark> <rj><au>T. W.
Collins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanify</ent><br/
<hw>Hu*man"i*fy</hw> <pr>(h<usl/*m<acr/n"<icr/*f<imac/)</pr>, <pos>v.
t.</pos> <def>To make human; to invest with a human personality; to
incarnate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>humanifying</qex> of the divine Word.</q> <rj><qau>H. B.
Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanism</ent><br/
<hw>Hu"man*ism</hw> <pr>(h<umac/"m<ait/n*<icr/z'm)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Human nature or disposition; humanity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[She] looked almost like a being who had rejected with
indifference the attitude of sex for the loftier quality of abstract
<qex>humanism</qex>.</q> <rj><qau>T. Hardy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The study of the humanities; polite
learning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A doctrine or ethical point of view that emphasizes
the dignity and worth of individual people, rejects claims of
supernatural influences on humans, and stresses the need for people to
achieve improvement of society and self-fulfillment through reason and
to develop human-oriented ethical values without theism.</def><br/
[<source>PJC</source>]</p>

<p><ent>humanisation</ent><br/
<hw>humanisation</hw> <pos>n.</pos> <def>Same as
<er>humanization</er>.</def> <mark>[Chiefly Brit.]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>humanise</ent><br/
<hw>humanise</hw> <pos>v.</pos> <def>Same as <er>humanize</er>.</def>
<mark>[Chiefly Brit.]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Humanist</ent><br/
<hw>Hu"man*ist</hw> <pr>(h<umac/"m<ait/n*<icr/st)</pr> , <pos>n.</pos>
<ety>[Cf. F. <ets>humaniste</ets>.]</ety> <sn>1.</sn> <def>One of the
scholars who in the field of literature proper represented the movement
of the Renaissance, and early in the 16th century adopted the name
<xex>Humanist</xex> as their distinctive title.</def>
<rj><au>Schaff-Herzog.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who pursues the study of the humanities, or
polite literature.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One versed in knowledge of human nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person with a strong concern for human welfare,
especially one who emphasizes the dignity and worth of individual
people, rejecting claims of supernatural influences on humans, and
stressing the need for people to achieve improvement of society and
self-fulfillment through reason and to develop human-oriented ethical
values without theism; an adherent of humanism.</def><br/
[<source>PJC</source>]</p>

<p><ent>Humanistic</ent><br/
<hw>Hu`man*is"tic</hw> <pr>(h<umac/`m<ait/n*<icr/s"t<icr/k)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to humanity; <as>as,
<ex>humanistic</ex> devotion</as>.</def> <rj><au>Caird.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to polite literature.</def> <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of, related to, or adhering to, humanism{4};
humanitarian{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Humanitarian</ent><br/
<hw>Hu*man`i*ta"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Theol. & Ch. Hist.)</fld> <def>Pertaining to humanitarians, or to
humanitarianism; <as>as, a <ex>humanitarian</ex> view of Christ's
nature</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Philos.)</fld> <def>Content with right affections
and actions toward man; ethical, as distinguished from religious;
believing in the perfectibility of man's nature without supernatural
aid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Benevolent; philanthropic.</def>
<mark>[Recent]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanitarian</ent><br/
<hw>Hu*man`i*ta"ri*an</hw>, <pos>n.</pos> <ety>[From
<er>Humanity</er>.]</ety> <sn>1.</sn> <fld>(Theol. & Ch. Hist.)</fld>
<def>One who denies the divinity of Christ, and believes him to have
been merely human.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Philos.)</fld> <def>One who limits the sphere of
duties to human relations and affections, to the exclusion or
disparagement of the religious or spiritual.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who is actively concerned in promoting the
welfare of humans and human societies; a philanthropist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanitarianism</ent><br/
<hw>Hu*man`i*ta"ri*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Theol. & Ch. Hist.)</fld> <def>The distinctive tenet of the
humanitarians in denying the divinity of Christ; also, the whole system
of doctrine based upon this view of Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Philos.)</fld> <def>The doctrine that man's
obligations are limited to, and dependent alone upon, man and the human
relations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanitian</ent><br/
<hw>Hu`ma*ni"tian</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
humanist.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanity</ent><br/
<hw>Hu*man"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Humanities</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>humanitas</ets>:
cf. F. <ets>humanit<eacute/</ets>. See <er>Human</er>.]</ety>
<sn>1.</sn> <def>The quality of being human; the peculiar nature of man,
by which he is distinguished from other beings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mankind collectively; the human race.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But hearing oftentimes<br/
The still, and music <qex>humanity</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a debt we owe to <qex>humanity</qex>.</q> <rj><qau>S. S.
Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The quality of being humane; the kind feelings,
dispositions, and sympathies of man; especially, a disposition to
relieve persons or animals in distress, and to treat all creatures with
kindness and tenderness.</def> <ldquo/The common offices of
<xex>humanity</xex> and friendship.<rdquo/ <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Mental cultivation; liberal education; instruction
in classical and polite literature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Polished with <qex>humanity</qex> and the study of witty
science.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <pluf>pl.</pluf> (With definite article) <def>The
branches of polite or elegant learning; as language, rhetoric, poetry,
and the ancient classics; belles-letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The cultivation of the languages, literature, history,
and arch<ae/ology of Greece and Rome, were very commonly called
<xex>liter<ae/ humaniores</xex>, or, in English, the
<xex>humanities</xex>, . . . by way of opposition to the <xex>liter<ae/
divin<ae/</xex>, or divinity.</note> <rj><au>G. P. Marsh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanization</ent><br/
<hw>Hu*man`i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
humanizing.</def> <rj><au>M. Arnold.</au></rj><br/
<syn><b>Syn. --</b> humanisation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanize</ent><br/
<hw>Hu"man*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Humanized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Humanizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>humaniser</ets>.]</ety> <sn>1.</sn> <def>To render human or humane;
to soften; to make gentle by overcoming cruel dispositions and rude
habits; to refine or civilize.</def> <altsp>[Also spelled
<asp>humanise</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Was it the business of magic to <qex>humanize</qex> our natures
with compassion?</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give a human character or expression to.</def>
<ldquo/<xex>Humanized</xex> divinities.<rdquo/
<rj><au>Caird.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>To convert into something human or
belonging to man; <as>as, to <ex>humanize</ex> vaccine
lymph</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanize</ent><br/
<hw>Hu"man*ize</hw>, <pos>v. i.</pos> <def>To become or be made more
humane; to become civilized; to be ameliorated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By the original law of nations, war and extirpation were the
punishment of injury. <qex>Humanizing</qex> by degrees, it admitted
slavery instead of death; a further step was the exchange of prisoners
instead of slavery.</q> <rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanizer</ent><br/
<hw>Hu"man*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who renders
humane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humankind</ent><br/
<hw>Hu"man*kind`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mankind.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>humanlike</ent><br/
<hw>humanlike</hw> <pos>adj.</pos> <def>resembling a human.</def>
[Narrower terms: <stype>human (vs. nonhuman) </stype>]<br/
<syn><b>Syn. --</b> anthropomorphic, anthropomorphous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Humanly</ent><br/
<hw>Hu"man*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a human manner;
after the manner of men; according to the knowledge or wisdom of men;
<as>as, the present prospects, <ex>humanly</ex> speaking, promise a
happy issue</as>.</def> <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Kindly; humanely.</def> <mark>[Obs.]</mark>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humanness</ent><br/
<hw>Hu"man*ness</hw>, <pos>n.</pos> <def>The quality or state of being
human.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humate</ent><br/
<hw>Hu"mate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>humus</ets>
the earth, ground.]</ety> <fld>(Chem.)</fld> <def>A salt of humic
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humation</ent><br/
<hw>Hu*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>humatio</ets>, fr. <ets>humare</ets> to cover with earth, to inter,
fr. <ets>humus</ets> the earth, ground. See <er>Homage</er>.]</ety>
<def>Interment; inhumation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbird</ent><br/
<hw>Hum"bird`</hw> <pr>(h<ucr/m"b<etil/rd)</pr>, <pos>n.</pos>
<def>Humming bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humble</ent><br/
<hw>Hum"ble</hw> <pr>(h<ucr/m"b'l; 277)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Humbler</adjf>
<pr>(h<ucr/m"bl<etil/r)</pr>; <pos>superl.</pos> <adjf>Humblest</adjf>
<pr>(h<ucr/m"bl<ecr/st)</pr>.]</amorph> <ety>[F., fr. L.
<ets>humilis</ets> on the ground, low, fr. <ets>humus</ets> the earth,
ground. See <er>Homage</er>, and cf. <er>Chameleon</er>,
<er>Humiliate</er>.]</ety> <sn>1.</sn> <def>Near the ground; not high or
lofty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy <qex>humble</qex> nest built on the ground.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not pretentious or magnificent; unpretending;
unassuming; modest; <as>as, a <ex>humble</ex> cottage</as>. Used to
describe objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Thinking lowly of one's self; claiming little for
one's self; not proud, arrogant, or assuming; thinking one's self
ill-deserving or unworthy, when judged by the demands of God; lowly;
weak; modest. Used to describe people.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God resisteth the proud, but giveth grace unto the
<qex>humble</qex>.</q> <rj><qau>Jas. iv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She should be <qex>humble</qex> who would please.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Without a <qex>humble</qex> imitation of the divine Author of our
. . . religion we can never hope to be a happy nation.</q>
<rj><qau>Washington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Humble plant</b></col> <fld>(Bot.)</fld>, <cd>a species
of sensitive plant, of the genus <gen>Mimosa</gen> (<spn>Mimosa
sensitiva</spn>).</cd> -- <col><b>To eat humble pie</b></col>, <cd>to
endure mortification; to submit or apologize abjectly; to yield
passively to insult or humiliation; -- a phrase derived from a pie made
of the entrails or <xex>humbles</xex> of a deer, which was formerly
served to servants and retainers at a hunting feast. See
<er>Humbles</er>.</cd> <au>Halliwell.</au> <au>Thackeray.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humble</ent><br/
<hw>Hum"ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hornless. See
<er>Hummel</er>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humble</ent><br/
<hw>Hum"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Humbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Humbling</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To
bring low; to reduce the power, independence, or exaltation of; to
lower; to abase; to humiliate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here, take this purse, thou whom the heaven's plagues<br/
Have <qex>humbled</qex> to all strokes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The genius which <qex>humbled</qex> six marshals of France.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make humble or lowly in mind; to abase the pride
or arrogance of; to reduce the self-sufficiently of; to make meek and
submissive; -- often used reflexively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Humble</qex> yourselves therefore under the mighty hand of
God, that he may exalt you.</q> <rj><qau>1 Pet. v. 6.</qau></rj></p>

<p><syn><b>Syn.</b> -- To abase; lower; depress; humiliate; mortify;
disgrace; degrade.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humblebee</ent><br/
<hw>Hum"ble*bee`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>humbilbee</ets>, <ets>hombulbe</ets>; cf. D. <ets>hommel</ets>, G.
<ets>hummel</ets>, OHG. <ets>humbal</ets>, Dan. <ets>humle</ets>, Sw.
<ets>humla</ets>; perh. akin to <ets>hum</ets>. <root/15. Cf.
<er>Bumblebee</er>.]</ety> <fld>(Zool.)</fld> <def>The bumblebee.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humblehead</ent><br/
<hw>Hum"ble*head`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Humble</ets> + <ets>-head</ets>.]</ety> <def>Humble condition
or estate; humility.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbleness</ent><br/
<hw>Hum"ble*ness</hw>, <pos>n.</pos> <def>The quality of being humble;
humility; meekness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbler</ent><br/
<hw>Hum"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, humbles some one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbles</ent><br/
<hw>Hum"bles</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[See
<er>Nombles</er>.]</ety> <def>Entrails of a deer.</def> <altsp>[Written
also <asp>umbles</asp>.]</altsp> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humblesse</ent><br/
<hw>Hum"blesse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.]</ety>
<def>Humbleness; abasement; low obeisance.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au> <au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbly</ent><br/
<hw>Hum"bly</hw>, <pos>adv.</pos> <def>With humility; lowly.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbug</ent><br/
<hw>Hum"bug`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr.
<ets>hum</ets> to impose on, deceive + <ets>bug</ets> a frightful
object.]</ety> <sn>1.</sn> <def>An imposition under fair pretenses;
something contrived in order to deceive and mislead; a trick by
cajolery; a hoax.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A spirit of deception; cajolery;
trickishness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who deceives or misleads; a deceitful or
trickish fellow; an impostor.</def> <rj><au>Sir J.
Stephen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbug</ent><br/
<hw>Hum"bug`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Humbugged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Humbugging</conjf> <pr>(?)</pr>.]</vmorph> <def>To deceive; to
impose; to cajole; to hoax.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbugger</ent><br/
<hw>Hum"bug`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
humbugs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humbuggery</ent><br/
<hw>Hum"bug`ger*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The practice of
imposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humdrum</ent><br/
<hw>Hum"drum`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Monotonous; dull;
commonplace.</def> <ldquo/A <xex>humdrum</xex> crone.<rdquo/
<rj><au>Bryant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humdrum</ent><br/
<hw>Hum"drum`</hw>, <pos>n.</pos> <sn>1.</sn> <def>A dull fellow; a
bore.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Monotonous and tedious routine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dissatisfied with <qex>humdrum</qex>.</q> <rj><qau>The
Nation.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A low cart with three wheels, drawn by one
horse.</def></p>

<p><ent>Humectate</ent><br/
<ent>Humect</ent><br/
<mhw>{ <hw>Hu*mect"</hw> <pr>(?)</pr>, <hw>Hu*mec"tate</hw>
<pr>(?)</pr>, }</mhw> <pos>v. t.</pos> <ety>[L. <ets>humectare</ets>,
<ets>humectatum</ets>, fr. <ets>humectus</ets> moist, fr.
<ets>humere</ets> to be moist: cf. F. <ets>humecter</ets>.]</ety>
<def>To moisten; to wet.</def> <mark>[Obs.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humectant</ent><br/
<hw>Hu*mec"tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>humectans</ets>, p. pr.]</ety> <def>Diluent.</def> --
<def2><pos>n.</pos> <def>A diluent drink or medicine.</def></def2>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humectation</ent><br/
<hw>Hu`mec*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>humectatio</ets>: cf. F. <ets>humectation</ets>.]</ety> <def>A
moistening.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humective</ent><br/
<hw>Hu*mec"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
moisten.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humeral</ent><br/
<hw>Hu"mer*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>humerus</ets> the shoulder: cf. F.
<ets>hum<eacute/ral</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or
pertaining to the humerus, or upper part of the arm; brachial.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Humeral veil</b></col> <fld>(R. C. Ch.)</fld>, <cd>a
long, narrow veil or scarf of the same material as the vestments, worn
round the shoulders by the officiating priest or his attendant at Mass,
and used to protect the sacred vessels from contact with the
hands.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humerus</ent><br/
\'d8<hw>Hu"me*rus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Humeri</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Anat.)</fld>
<sd>(a)</sd> <def>The bone of the brachium, or upper part of the arm or
fore limb.</def> <sd>(b)</sd> <def>The part of the limb containing the
humerus; the brachium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humic</ent><br/
<hw>Hu"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>humus</ets>
the earth, ground: cf. F. <ets>humique</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, vegetable mold; <as>as,
<ex>humic</ex> acid</as>. See <er>Humin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humicubation</ent><br/
<hw>Hu`mi*cu*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>humus</ets> the ground + <ets>cubare</ets> to lie down.]</ety>
<def>The act or practice of lying on the ground.</def>
<mark>[Obs.]</mark> <rj><au>Abp. Bramhall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humid</ent><br/
<hw>Hu"mid</hw> <pr>(h<umac/"m<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>humidus</ets>, <ets>umidus</ets>, fr. <ets>humere</ets>,
<ets>umere</ets>, to be moist; akin to <ets>uvidus</ets> moist, Gr.
<grk>"ygro`s</grk>, Skr. <ets>uksh</ets> to wet, sprinkle, and Icel.
<ets>v<oum/kr</ets> moist, and perh. to E. <ets>ox</ets>: cf. F.
<ets>humide</ets>.]</ety> <def>Containing sensible moisture; damp;
moist; <as>as, a <ex>humid</ex>air or atmosphere</as>; somewhat wet or
watery; <as>as, <ex>humid</ex> earth</as>; consisting of water or
vapor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Evening cloud, or <qex>humid</qex> bow.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>humidification</ent><br/
<hw>humidification</hw> <pos>n.</pos> <def>The act or process of
increasing the moisture content; -- usually used of gases, especially
air.</def><br/
<syn><b>Syn. --</b> moisturization.</syn><br/
[<source>PJC</source>]</p>

<p><ent>humidifier</ent><br/
<hw>humidifier</hw> <pos>n.</pos> <def>A device that increases the
moisture content of the air; -- used to avoid excessive dryness in
buildings, which can cause irritation to the throat. Compare
<contr>dehumidifier</contr>.</def><br/
<syn><b>Syn. --</b> moisturization.</syn><br/
[<source>PJC</source>]</p>

<p><ent>humidify</ent><br/
<hw>humidify</hw> <pos>v. t.</pos> <def>to render (gases, especially
air) humid or to increase the moisture content of; <as>as, We have a
machine that <ex>humidifies</ex> the air in the house</as>.</def><br/
<syn><b>Syn. --</b> moisturize, make humid, make more humid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Humidity</ent><br/
<hw>Hu*mid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>humidit<eacute/</ets>.]</ety> <sn>1.</sn> <def>Moisture; dampness;
a moderate degree of wetness, which is perceptible to the eye or touch;
-- used especially of the atmosphere, or of anything which has absorbed
moisture from the atmosphere, as clothing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>The content of water
vapor in the air, expressed as a percent of the maximum amount of water
vapor that the air can hold at the given temperature; also called
<altname>relative humidity</altname>. The capacity of the air to hold
moisture increases with temperature, so if the temperature changes
without changing the absolute content of the atmospheric moisture, the
relative humidity will also change.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>relative humidity</b></col> <cd>Same as
<er>humidity</er>{2}.</cd></cs><br/
[<source>PJC</source>]</p>

<p><note><hand/ In hygrometrical reports (as of the United States Signal
Service) complete saturation of the air by water vapor is designated by
a <ex>relative humidity</ex> of 100, and its partial saturation by
smaller numbers in direct proportion to the actual content of water
vapor.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humidness</ent><br/
<hw>Hu"mid*ness</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Humidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humifuse</ent><br/
<hw>Hu"mi*fuse</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>humus</ets> ground + <ets>fusus</ets>, p. p. of <ets>fundere</ets>
to spread.]</ety> <fld>(Bot.)</fld> <def>Spread over the surface of the
ground; procumbent.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humiliant</ent><br/
<hw>Hu*mil"i*ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>humilians</ets>, p. pr. of <ets>humiliare</ets>.]</ety>
<def>Humiliating; humbling.</def> <ldquo/<xex>Humiliant</xex>
thoughts.<rdquo/ <mark>[R.]</mark> <rj><au>Mrs. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humiliate</ent><br/
<hw>Hu*mil"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Humiliated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Humiliating</conjf>.]</vmorph> <ety>[L.
<ets>humiliatus</ets>, p. p. of <ets>humiliare</ets>. See
<er>Humble</er>.]</ety> <def>To reduce to a lower position in one's own
eyes, or in the eyes of others; to cause a loss of pride or dignity; to
humble; to mortify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We stand <qex>humiliated</qex> rather than encouraged.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>humiliated</ent><br/
<hw>humiliated</hw> <pos>adj.</pos> <def>brought low in condition or
status; reduced in dignity; humbled; mortified.</def><br/
<syn><b>Syn. --</b> broken, crushed, humbled, low, mortified.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>humiliating</ent><br/
<hw>humiliating</hw> <pos>adj.</pos> <def>causing humiliation.</def>
[Narrower terms: <stype>undignified (vs. dignified)</stype>]<br/
<syn><b>Syn. --</b> demeaning, humbling, mortifying.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Humiliation</ent><br/
<hw>Hu*mil`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>humiliatio</ets>: cf. F. <ets>humiliation</ets>.]</ety> <sn>1.</sn>
<def>The act of humiliating or humbling; abasement of pride;
mortification.</def> <rj><au>Bp. Hopkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being humiliated, humbled, or reduced
to lowliness or submission.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The former was a <qex>humiliation</qex> of Deity; the latter a
<qex>humiliation</qex> of manhood.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humility</ent><br/
<hw>Hu*mil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Humilities</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>humilite</ets>,
OF. <ets>humilit<eacute/</ets>, <ets>humelit<eacute/</ets>, F.
<ets>humilit<eacute/</ets>, fr. L. <ets>humiliatis</ets>. See
<er>Humble</er>.]</ety> <sn>1.</sn> <def>The state or quality of being
humble; freedom from pride and arrogance; lowliness of mind; a modest
estimate of one's own worth; a sense of one's own unworthiness through
imperfection and sinfulness; self-abasement; humbleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Serving the Lord with all <qex>humility</qex> of mind.</q>
<rj><qau>Acts xx. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act of submission or courtesy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With these <qex>humilities</qex> they satisfied the young
king.</q> <rj><qau>Sir J. Davies.</qau></rj></p>

<p><syn><b>Syn.</b> -- Lowliness; humbleness; meekness; modesty;
diffidence.</syn> <usage> -- <er>Humility</er>, <er>Modesty</er>,
<er>Diffidence</er>. <xex>Diffidence</xex> is a distrust of our powers,
combined with a fear lest our failure should be censured, since a dread
of failure unconnected with a dread of censure is not usually called
<xex>diffidence</xex>. It may be carried too far, and is not always,
like modesty and humility, a virtue. <xex>Modesty</xex>, without
supposing self-distrust, implies an unwillingness to put ourselves
forward, and an absence of all over-confidence in our own powers.
<xex>Humility</xex> consists in rating our claims low, in being willing
to waive our rights, and take a lower place than might be our due. It
does not require of us to underrate ourselves.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humin</ent><br/
<hw>Hu"min</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>humus</ets>
the earth, ground.]</ety> <fld>(Chem.)</fld> <def>A bitter, brownish
yellow, amorphous substance, extracted from vegetable mold, and also
produced by the action of acids on certain sugars and carbohydrates; --
called also <altname>humic acid</altname>, <altname>ulmin</altname>,
<altname>gein</altname>, <altname>ulmic</altname> or <altname>geic
acid</altname>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humiri</ent><br/
\'d8<hw>Hu*mi"ri</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From native
name.]</ety> <fld>(Bot.)</fld> <def>A fragrant balsam obtained from
Brazilian trees of the genus <gen>Humirium</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humite</ent><br/
<hw>Hum"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after Sir A.
<etsep>Hume</etsep>.]</ety> <fld>(Min.)</fld> <def>A mineral of a
transparent vitreous brown color, found in the ejected masses of
Vesuvius. It is a silicate of iron and magnesia, containing
fluorine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummel</ent><br/
<hw>Hum"mel</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Hamble</er>.]</ety> <def>To separate from the awns; -- said of
barley.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummel</ent><br/
<hw>Hum"mel</hw>, <pos>a.</pos> <def>Having no awns or no horns; <as>as,
<ex>hummel</ex>corn; a <ex>hummel</ex> cow.</as></def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummeler</ent><br/
<hw>Hum"mel*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>hummeller</ets>.]</ety> <def>One who, or a machine which,
hummels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummer</ent><br/
<hw>Hum"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, hums; one who applauds by humming.</def>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A humming bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humming</ent><br/
<hw>Hum"ming</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Emitting a murmuring
sound; droning; murmuring; buzzing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humming</ent><br/
<hw>Hum"ming</hw>, <pos>n.</pos> <def>A sound like that made by bees; a
low, murmuring sound; a hum.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hummingale</b></col>, <cd>lively or strong ale.</cd>
<au>Dryden.</au> -- <col><b>Humming-bird moth</b></col>
<fld>(Zool.)</fld>, <cd>a hawk moth. See <cref>Hawk moth</cref>, under
<er>Hawk</er>, the bird.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>humming bird</ent><br/
<ent>hummingbird</ent><br/
<mhw><hw>hummingbird</hw>, <hw>humming bird</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld>, <def>any bird of the family
<fam>Trochilid<ae/</fam>, of which over one hundred genera are known,
including about four hundred species. They are found only in America and
are most abundant in the tropics. They are mostly of very small size
with long slender bills adapted to sucking nectar from flowers, and are
noted for the very brilliant iridescent colors of their plumage and
their peculiar habit of hovering about flowers while vibrating their
wings very rapidly with a humming noise; the wings are specialized for
hovering flight, but they can also dart forward and fly quite rapidly.
They feed both upon the nectar of flowers and upon small insects. The
common humming bird or <stype>ruby-throat</stype> of the Eastern United
States is <spn>Trochilus colubris</spn>. Several other species are found
in the Western United States. See <er>Calliope</er>, and
<er>Ruby-throat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummock</ent><br/
<hw>Hum"mock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. a dim. of
<ets>hump</ets>. See <er>Hump</er>.]</ety> <sn>1.</sn> <def>A rounded
knoll or hillock; a rise of ground of no great extent, above a level
surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ridge or pile of ice on an ice field.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Timbered land. See <er>Hammock</er>.</def>
<mark>[Southern U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummocking</ent><br/
<hw>Hum"mock*ing</hw>, <pos>n.</pos> <def>The process of forming
hummocks in the collision of Arctic ice.</def>
<rj><au>Kane.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummocky</ent><br/
<hw>Hum"mock*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding in
hummocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hummum</ent><br/
<hw>Hum"mum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Per. or Ar.
<ets>hamm<amac/n</ets>.]</ety> <def>A sweating bath or place for
sweating.</def> <rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humor</ent><br/
<hw>Hu"mor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>humour</ets>,
OF. <ets>humor</ets>, <ets>umor</ets>, F. <ets>humeur</ets>, L.
<ets>humor</ets>, <ets>umor</ets>, moisture, fluid, fr.
<ets>humere</ets>, <ets>umere</ets>, to be moist. See
<er>Humid</er>.]</ety> <altsp>[Written also <asp>humour</asp>.]</altsp>
<sn>1.</sn> <def>Moisture, especially, the moisture or fluid of animal
bodies, as the chyle, lymph, etc.; <as>as, the <ex>humors</ex> of the
eye, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The ancient physicians believed that there were four
humors (the blood, phlegm, yellow bile or choler, and black bile or
melancholy), on the relative proportion of which the temperament and
health depended.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A vitiated or morbid animal fluid,
such as often causes an eruption on the skin.</def> <ldquo/A body full
of <xex>humors</xex>.<rdquo/ <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>State of mind, whether habitual or temporary (as
formerly supposed to depend on the character or combination of the
fluids of the body); disposition; temper; mood; <as>as, good
<ex>humor</ex>; ill <ex>humor</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Examine how your <qex>humor</qex> is inclined,<br/
And which the ruling passion of your mind.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A prince of a pleasant <qex>humor</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I like not the <qex>humor</qex> of lying.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>Changing and uncertain states of
mind; caprices; freaks; vagaries; whims.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is my friend all perfection, all virtue and discretion? Has he not
<qex>humors</qex> to be endured?</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That quality of the imagination which gives to ideas
an incongruous or fantastic turn, and tends to excite laughter or mirth
by ludicrous images or representations; a playful fancy;
facetiousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For thy sake I admit<br/
That a Scot may have <qex>humor</qex>, I'd almost said wit.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A great deal of excellent <qex>humor</qex> was expended on the
perplexities of mine host.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Aqueous humor</b></col>, <col><b>Crystalline
humor</b></col> <it>or</it> <col><b>Crystalline lens</b></col>,
<col><b>Vitreous humor</b></col></mcol>. <fld>(Anat.)</fld> <cd>See
<er>Eye</er>.</cd> -- <col><b>Out of humor</b></col>, <cd>dissatisfied;
displeased; in an unpleasant frame of mind.</cd></cs></p>

<p><syn><b>Syn.</b> -- Wit; satire; pleasantry; temper; disposition;
mood; frame; whim; fancy; caprice. See <er>Wit</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 713 --></p>

<p><ent>Humor</ent><br/
<hw>Hu"mor</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Humored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Humoring</conjf>.]</vmorph> <sn>1.</sn> <def>To comply with the
humor of; to adjust matters so as suit the peculiarities, caprices, or
exigencies of; to adapt one's self to; to indulge by skillful
adaptation; <as>as, to <ex>humor</ex> the mind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is my part to invent, and the musician's to <qex>humor</qex>
that invention.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To help on by indulgence or compliant treatment; to
soothe; to gratify; to please.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>humor</qex> me when I am sick.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- To gratify; to indulge. See
<er>Gratify</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humoral</ent><br/
<hw>Hu"mor*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>humoral</ets>.]</ety> <def>Pertaining to, or proceeding from, the
humors; <as>as, a <ex>humoral</ex> fever</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Humoral pathology</b></col> <fld>(Med.)</fld>, <cd>the
pathology, or doctrine of the nature of diseases, which attributes all
morbid phenomena to the disordered condition of the fluids or humors of
the body.</cd></cs><-- antiquated --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humoralism</ent><br/
<hw>Hu"mor*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Med.)</fld> <def>The state or quality of being humoral.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>The doctrine that diseases proceed
from the humors; humorism.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humoralist</ent><br/
<hw>Hu"mor*al*ist</hw>, <pos>n.</pos> <def>One who favors the humoral
pathology or believes in humoralism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorism</ent><br/
<hw>Hu"mor*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Med.)</fld> <def>The theory founded on the influence which the
humors were supposed to have in the production of disease;
Galenism.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manner or disposition of a humorist;
humorousness.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorist</ent><br/
<hw>Hu"mor*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>humoriste</ets>.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>One who
attributes diseases of the state of the humors.</def>
<mark>[archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who has some peculiarity or eccentricity of
character, which he indulges in odd or whimsical ways.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Roger de Coverley] . . . was a great <qex>humorist</qex> in
all parts of his life.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who displays humor in speaking or writing; one
who has a facetious fancy or genius; a wag; a droll; especially, one who
writes or tells jokes as a profession.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The reputation of wits and <qex>humorists</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humoristic</ent><br/
<hw>Hu`mor*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining
to, or resembling, a humorist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorize</ent><br/
<hw>Hu"mor*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To humor.</def>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorless</ent><br/
<hw>Hu"mor*less</hw>, <pos>a.</pos> <def>Destitute of humor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorous</ent><br/
<hw>Hu"mor*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>humorosus</ets>, <ets>umorosus</ets>, moist. See
<er>Humor</er>.]</ety> <sn>1.</sn> <def>Moist; humid; watery.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All founts wells, all deeps <qex>humorous</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subject to be governed by humor or caprice;
irregular; capricious; whimsical.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Rough as a storm and <qex>humorous</qex> as the wind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Full of humor; jocular; exciting laughter; playful;
<as>as, a <ex>humorous</ex> story or author; a <ex>humorous</ex>
aspect.</as></def></p>

<p><syn><b>Syn.</b> -- Jocose; facetious; witty; pleasant;
merry.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorously</ent><br/
<hw>Hu"mor*ous*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>Capriciously;
whimsically.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We resolve rashly, sillily, or <qex>humorously</qex>.</q>
<rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Facetiously; wittily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorousness</ent><br/
<hw>Hu"mor*ous*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>Moodiness;
capriciousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Facetiousness; jocularity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorsome</ent><br/
<hw>Hu"mor*some</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Moody;
whimsical; capricious.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The commons do not abet <qex>humorsome</qex>, factious arms.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Jocose; witty; humorous.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorsomely</ent><br/
<hw>Hu"mor*some*ly</hw>, <pos>adv.</pos> <def>Pleasantly;
humorously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humorsomeness</ent><br/
<hw>Hu"mor*some*ness</hw>, <pos>n.</pos> <def>Quality of being
humorsome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>humour</ent><br/
<hw>humour</hw> <pos>n.</pos> <def>same as <er>humor</er>.</def>
<mark>[Chiefly Brit.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>humourous</ent><br/
<hw>humourous</hw> <pos>adj.</pos> <def>same as <er>humorous</er>;
causing amusement or laughter.</def> [Narrower terms: <stype>bantering,
facetious, tongue-in-cheek, witty </stype>; <stype>boisterous,
knockabout, slapstick </stype>; <stype>buffoonish, clownish,
zany</stype>; <stype>comic, comical, funny, laughable, risible </stype>;
<stype>droll, waggish </stype>; <stype>dry, ironic, ironical, pawky, wry
</stype>; <stype>farcical, ludicrous, ridiculous </stype>;
<stype>Gilbertian </stype>; <stype>hilarious, uproarious </stype>;
<stype>jesting, jocose, jocular, jocund, joking</stype>; <stype>merry,
mirthful</stype>; <stype>seriocomic, seriocomical </stype>;
<stype>tragicomic, tragicomical </stype>; <stype>killing,
sidesplitting</stype>] <see>Also See: <er>pleasing</er>.</see><br/
<syn><b>Syn. --</b> humorous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hump</ent><br/
<hw>Hump</hw> <pr>(h<ucr/mp)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>homp</ets> a lump, LG. <ets>hump</ets> heap, hill, stump, possibly
akin to E. <ets>heap</ets>. Cf. <er>Hunch</er>.]</ety> <sn>1.</sn>
<def>A protuberance; especially, the protuberance formed by a crooked
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A fleshy protuberance on the back
of an animal, as a camel or whale.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Railroad)</fld> <def>a portion of a switchyard with
a slanting track in which freight cars may coast without an engine and
be sorted through a series of switches.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hump</ent><br/
<hw>Hump</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To form
into a hump; to make hump-shaped; to hunch; -- often with
<xex>up</xex>.</def></p>

<p><q>The cattle were very uncomfortable, standing <qex>humped</qex> up
in the bushes.</q> <rj><qau>T. Roosvelt.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To put or carry on the (humped) back; to shoulder;
hence, to carry, in general.</def> <mark>[Slang, Australia]</mark></p>

<p><q>Having collected a sufficient quantity, we <qex>humped</qex> it
out of the bush.</q> <rj><qau>C. L. Money.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>To bend or gather together for strenuous effort, as
in running; to do or effect by such effort; to exert; -- usually
reflexively or with <xex>it</xex>; <as>as, you must <ex>hump</ex>
yourself</as>.</def> <mark>[Slang, U. S.]</mark></p>

<p><q>A half dozen other negroes, some limping and all scared, were
<qex>humping</qex> it across a meadow.</q> <rj><qau>McClure's
Mag.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <fld>(Railroad)</fld> <def>to sort freight cars by means
of a hump.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>to engage in sexual intercourse with.</def>
<mark>[Vulgar Slang, U. S.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Humpback</ent><br/
<hw>Hump"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Hunchback</er>.]</ety> <sn>1.</sn> <def>A crooked back; a humped
back.</def> <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A humpbacked person; a hunchback.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any whale of the
genus <gen>Megaptera</gen>, characterized by a hump or bunch on the
back. Several species are known. The most common ones in the North
Atlantic are <spn>Megaptera longimana</spn> of Europe, and
<spn>Megaptera osphyia</spn> of America; that of the California coasts
is <spn>Megaptera versabilis</spn>.</def> <sd>(b)</sd> <def>A small
salmon (<spn>Oncorhynchus gorbuscha</spn>), of the northwest coast of
America; the <er>humpbacked salmon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humpbacked</ent><br/
<hw>Hump"backed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a humped
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humpbacked salmon</ent><br/
<hw>Hump"backed` salm"on</hw>. <def>A small salmon (<spn>Oncorhynchus
gorbuscha</spn>) which ascends the rivers of the Pacific coast from
California to Alaska, and also on the Asiatic side. In the breeding
season the male has a large dorsal hump and distorted jaws.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Humpback whale</ent><br/
<hw>Hump"back` whale</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the
<er>humpback{3}</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Humped</ent><br/
<hw>Humped</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a hump, as the
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humph</ent><br/
<hw>Humph</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Of imitative
origin.]</ety> <def>An exclamation denoting surprise, or contempt,
doubt, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humpless</ent><br/
<hw>Hump"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without a
hump.</def> <rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hump-shouldered</ent><br/
<hw>Hump"-shoul`dered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having high,
hunched shoulders.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humpy</ent><br/
<hw>Hump"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of humps or
bunches; covered with protuberances; humped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humstrum</ent><br/
<hw>Hum"strum`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An instrument out
of tune or rudely constructed; music badly played.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Humulin</ent><br/
<hw>Hu"mu*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>Humulus</ets>, the genus including the hop.]</ety> <def>An extract
of hops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Humus</ent><br/
\'d8<hw>Hu"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., the earth,
ground, soil.]</ety> <def>That portion of the soil formed by the
decomposition of animal or vegetable matter. It is a valuable
constituent of soils.</def> <rj><au>Graham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hun</ent><br/
<hw>Hun</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>Hunni</ets>, also
<ets>Chunni</ets>, and <ets>Chuni</ets>; cf. AS. <ets>H<?/nas</ets>,
<ets>H<?/ne</ets>, OHG. <ets>H<?/ni</ets>, G. <ets>Hunnen</ets>.]</ety>
<def>One of a warlike nomadic people of Northern Asia who, in the 5th
century, under Atilla, invaded and conquered a great part of
Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunch</ent><br/
<hw>Hunch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. akin to
<ets>huckle</ets>; cf. <ets>hump</ets>, <ets>hunch</ets>,
<ets>bunch</ets>, <ets>hunk</ets>.]</ety> <sn>1.</sn> <def>A hump; a
protuberance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lump; a thick piece; <as>as, a <ex>hunch</ex> of
bread</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A push or thrust, as with the elbow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A strong, intuitive impression that something will
happen; -- said to be from the gambler's superstition that it brings
luck to touch the hump of a hunchback.</def> <mark>[Colloq. or
Slang]</mark> <ldquo/Get a <xex>hunch</xex>, bet a bunch.<rdquo/<br/
<syn><b>Syn. --</b> presentiment, premonition.</syn>
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Hunch</ent><br/
<hw>Hunch</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hunched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hunching</conjf>.]</vmorph> <sn>1.</sn> <def>To push or jostle
with the elbow; to push or thrust suddenly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To thrust out a hump or protuberance; to crook, as
the back.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunchback</ent><br/
<hw>Hunch"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Humpback</er>.]</ety> <def>A back with a hunch or hump; also, a
hunchbacked person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunchbacked</ent><br/
<hw>Hunch"backed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a humped
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hunched</ent><br/
<hw>hunched</hw> <pos>adj.</pos> <def>having the back and shoulders
rounded; not erect; -- of people.</def><br/
<syn><b>Syn. --</b> round-backed, round-shouldered, stooped, stooping,
crooked.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hundred</ent><br/
<hw>Hun"dred</hw> <pr>(h<ucr/n"dr<ecr/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hundred</ets>, AS. <ets>hundred</ets> a territorial division;
<ets>hund</ets> hundred + a word akin to Goth.
<ets>ga-ra<thorn/jan</ets> to count, L. <ets>ratio</ets> reckoning,
account; akin to OS. <ets>hunderod</ets>, <ets>hund</ets>, D.
<ets>hondred</ets>, G. <ets>hundert</ets>, OHG. also <ets>hunt</ets>,
Icel. <ets>hundra<edh/</ets>, Dan. <ets>hundrede</ets>, Sw.
<ets>hundra</ets>, <ets>hundrade</ets>, Goth. <ets>hund</ets>, Lith.
<ets>szimtas</ets>, Russ. <ets>sto</ets>, W. <ets>cant</ets>, Ir.
<ets>cead</ets>, L. <ets>centum</ets>, Gr. <grk>"ekato`s</grk>, Skr.
<ets><cced/ata</ets>. <root/309. Cf. <er>Cent</er>, <er>Century</er>,
<er>Hecatomb</er>, <er>Quintal</er>, and <er>Reason</er>.]</ety>
<sn>1.</sn> <def>The product of ten multiplied by ten, or the number of
ten times ten; a collection or sum, consisting of ten times ten units or
objects; five score. Also, a symbol representing one hundred units, as
100 or C.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With many <qex>hundreds</qex> treading on his heels.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word <xex>hundred</xex>, as well as
<xex>thousand</xex>, <xex>million</xex>, etc., often takes a plural
form. We may say <xex>hundreds</xex>, or many <xex>hundreds</xex>,
meaning individual objects or units, but with an ordinal numeral
adjective in constructions like five <xex>hundreds</xex>, or eight
<xex>hundreds</xex>, it is usually intended to consider each hundred as
a separate aggregate; as, ten <xex>hundreds</xex> are one
thousand.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A division of a country in England, supposed to have
originally contained a <xex>hundred</xex> families, or
freemen.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hundred court</b></col>, <cd>a court held for all the
inhabitants of a hundred.</cd> <mark>[Eng.]</mark>
<rj><au>Blackstone.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hundred</ent><br/
<hw>Hun"dred</hw>, <pos>a.</pos> <def>Ten times ten; five score; <as>as,
a <ex>hundred</ex> dollars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hundreder</ent><br/
<hw>Hun"dred*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
inhabitant or freeholder of a hundred.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A person competent to serve on a
jury, in an action for land in the hundred to which he
belongs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who has the jurisdiction of a hundred; and
sometimes, a bailiff of a hundred.</def> <rj><au>Blount.
Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hundredfold</ent><br/
<hw>Hun"dred*fold`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hundred times
as much or as many.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall receive as <qex>hundredfold</qex> now in this time.</q>
<rj><qau>Mark x. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hundredth</ent><br/
<hw>Hun"dredth</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Coming
last of a hundred successive individuals or units.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Forming one of a hundred equal parts into which
anything is divided; the tenth of a tenth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hundredth</ent><br/
<hw>Hun"dredth</hw>, <pos>n.</pos> <def>One of a hundred equal parts
into which one whole is, or may be, divided; the quotient of a unit
divided by a hundred.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hundredweight</ent><br/
<hw>Hun"dred*weight`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
denomination of weight, containing 100, 112, or 120 pounds avoirdupois,
according to differing laws or customs. By the legal standard of England
it is 112 pounds. In most of the United States, both in practice and by
law, it is 100 pounds avoirdupois, the corresponding ton of 2,000
pounds, sometimes called the <xex>short</xex> ton, being the legal
ton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hung</ent><br/
<hw>Hung</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Hang</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hung beef</b></col>, <cd>the fleshy part of beef slightly
salted and hung up to dry; dried beef.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungarian</ent><br/
<hw>Hun*ga"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Hungary or to the people of Hungary.</def> -- <def2><pos>n.</pos>
<def>A native or one of the people of Hungary.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hungarian grass</b></col>. <cd>See <cref>Italian
millet</cref>, under <er>Millet</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungary</ent><br/
<hw>Hun"ga*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A country in Central
Europe, formerly a part of the Austro-Hungarian Empire.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Hungary water</b></col>, <cd>a distilled
<ldquo/water,<rdquo/ made from dilute alcohol aromatized with rosemary
flowers, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunger</ent><br/
<hw>Hun"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hungor</ets>; akin to OFries. <ets>hunger</ets>, D.
<ets>honger</ets>, OS. & OHG. <ets>hungar</ets>, G. <ets>hunger</ets>,
Icel. <ets>hungr</ets>, Sw. & Dan. <ets>hunger</ets>, Goth.
<ets>h<?/hrus</ets> hunger, <ets>huggrjan</ets> to hunger.]</ety>
<sn>1.</sn> <def>An uneasy sensation occasioned normally by the want of
food; a craving or desire for food.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The sensation of hunger is usually referred to the
stomach, but is probably dependent on excitation of the sensory nerves,
both of the stomach and intestines, and perhaps also on indirect
impressions from other organs, more or less exhausted from lack of
nutriment.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any strong eager desire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O sacred <qex>hunger</qex> of ambitious minds!</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For <qex>hunger</qex> of my gold I die.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunger</ent><br/
<hw>Hun"ger</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hungered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hungering</conjf>.]</vmorph> <ety>[OE. <ets>hungren</ets>, AS.
<ets>hyngrian</ets>. See <er>Hunger</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To feel the craving or uneasiness occasioned by want of
food; to be oppressed by hunger.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have an eager desire; to long.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blessed are they which do <qex>hunger</qex> and thirst after
righteouness.</q> <rj><qau>Matt. v. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunger</ent><br/
<hw>Hun"ger</hw>, <pos>v. t.</pos> <def>To make hungry; to
famish.</def></p>

<p><ent>Hunger-bitten</ent><br/
<ent>Hunger-bit</ent><br/
<mhw>{ <hw>Hun"ger-bit`</hw> <pr>(?)</pr>, <hw>Hun"ger-bit`ten</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pinched or weakened by
hunger.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungered</ent><br/
<hw>Hun"gered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hungry; pinched for
food.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungerer</ent><br/
<hw>Hun"ger*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hungers;
one who longs.</def> <rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungerly</ent><br/
<hw>Hun"ger*ly</hw>, <pos>a.</pos> <def>Wanting food; starved.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungerly</ent><br/
<hw>Hun"ger*ly</hw>, <pos>adv.</pos> <def>With keen appetite.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunger-starve</ent><br/
<hw>Hun"ger-starve`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To starve
with hunger; to famish.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungred</ent><br/
<hw>Hun"gred</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hungered;
hungry.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hungrily</ent><br/
<hw>Hun"gri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Hunger</er>.]</ety> <def>In a hungry manner; voraciously.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hungriness</ent><br/
<hw>hungriness</hw> <pos>n.</pos> <sn>1.</sn> <def>The state of being
hungry; a need for food.</def><br/
<syn><b>Syn. --</b> hunger.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An intense desire.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hungry</ent><br/
<hw>Hun"gry</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Hungrier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Hungriest</adjf>.]</amorph> <ety>[AS. <ets>hungrid</ets>. See
<er>Hunger</er>.]</ety> <sn>1.</sn> <def>Feeling hunger; having a keen
appetite; feeling uneasiness or distress from want of food; hence,
having an eager desire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Showing hunger or a craving desire;
voracious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cruel, <qex>hungry</qex> foam.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cassius has a lean and <qex>hungry</qex> look.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not rich or fertile; poor; barren; starved; <as>as,
a <ex>hungry</ex> soil</as>.</def> <ldquo/The <xex>hungry</xex>
beach.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunk</ent><br/
<hw>Hunk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Hunch</er>.]</ety> <sn>1.</sn> <def>A large lump or piece; a hunch;
<as>as, a <ex>hunk</ex> of bread</as>.</def> <mark>[Colloq.]</mark></p>

<p><sn>2.</sn> <def>a sexually attractive, well-built man.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hunker</ent><br/
<hw>Hun"ker</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Originally, a nickname
for a member of the conservative section of the Democratic party in New
York; hence, one opposed to progress in general; a fogy.</def>
<mark>[Political Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunker down</ent><br/
<hw>Hun"ker down</hw> <pr>(?)</pr>, <pos>v.</pos> <sn>1.</sn> <def>to
crouch or squat; to sit on one's haunches.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>to settle in at a location for an extended period;
-- also (figuratively) to maintain a position and resist yielding to
some pressure, as of public opinion.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>to take shelter, literally or figuratively; to
assume a defensive position to resist difficulties.</def> <ldquo/We
<ex>hunkered down</ex> to ride out the storm in an abandoned
cabin.<rdquo/<br/
[<source>PJC</source>]</p>

<p><q>While many businessmen were <ex>hunkering down</ex> for another
bust after the lean years of the Second World War and the Great
Depression before it, Taylor and company correctly reckoned it was the
dawn of an era of prosperity and growth.</q> <rj><qau>Richard Siklos
[Shades of Black, 1995]</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>Hunkerism</ent><br/
<hw>Hun"ker*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Excessive
conservatism; hostility to progress.</def> <mark>[Political Cant,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunkers</ent><br/
<hw>Hun"kers</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[See
<er>Hunker</er>.]</ety> <def>In the phrase <xex>on one's hunkers</xex>,
in a squatting or crouching position; haunches.</def> <mark>[Scot. &
Local, U. S.]</mark></p>

<p><q>Sit <qex>on your hunkers</qex> -- and pray for the bridge.</q>
<rj><qau>Kipling.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hunks</ent><br/
<hw>Hunks</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A covetous, sordid man; a miser; a
niggard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pray make your bargain with all the prudence and selfishness of an
old <qex>hunks</qex>.</q> <rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunky</ent><br/
<hw>Hunk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Perh. fr.
<er>Hunk</er>.]</ety> <def>All right; in a good condition; also, even;
square.</def> <mark>[Slang, U. S.]</mark><-- hunky dory? --></p>

<p><q>He . . . began to shoot; began to get
<ldquo/<qex>hunky</qex><rdquo/ with all those people who had been
plugging at him.</q> <rj><qau>Stephen Crane.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hunnemannia</ent><br/
<hw>Hunnemannia</hw> <pos>n.</pos> <sn>1.</sn> <def>A genus with only
one species, the golden cup.</def><br/
<syn><b>Syn. --</b> genus <gen>Hunnemania</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hunnish</ent><br/
<hw>Hunnish</hw> <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to the
Huns.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Like the Huns; barbarous, cruel, and
destructive.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hunt</ent><br/
<hw>Hunt</hw> <pr>(h<ucr/nt)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hunted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Hunting</conjf>.]</vmorph> <ety>[AS. <ets>huntian</ets> to hunt;
cf. <ets>hentan</ets> to follow, pursue, Goth. <ets>hin<?/an</ets> (in
comp.) to seize. <root/36. Cf. <er>Hent</er>.]</ety> <sn>1.</sn> <def>To
search for or follow after, as game or wild animals; to chase; to pursue
for the purpose of catching or killing; to follow with dogs or guns for
sport or exercise; <as>as, to <ex>hunt</ex> a deer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a dog, he <qex>hunts</qex> in dreams.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To search diligently after; to seek; to pursue; to
follow; -- often with <xex>out</xex> or <xex>up</xex>; <as>as, to
<ex>hunt</ex> up the facts; to <ex>hunt</ex> out
evidence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Evil shall <qex>hunt</qex> the violent man to overthrow him.</q>
<rj><qau>Ps. cxl. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To drive; to chase; -- with <xex>down</xex>,
<xex>from</xex>, <xex>away</xex>, etc.; <as>as, to <ex>hunt</ex> down a
criminal; he was <ex>hunted</ex> from the parish.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To use or manage in the chase, as hounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>hunts</qex> a pack of dogs.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To use or traverse in pursuit of game; <as>as, he
<ex>hunts</ex> the woods, or the country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Change Ringing)</fld> <def>To move or shift the
order of (a bell) in a regular course of changes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hunt</ent><br/
<hw>Hunt</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To follow the chase; to
go out in pursuit of game; to course with hounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Esau went to the field to <qex>hunt</qex> for venison.</q>
<rj><qau>Gen. xxvii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To seek; to pursue; to search; -- with
<xex>for</xex> or <xex>after</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He after honor <qex>hunts</qex>, I after love.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>To be in a state of instability
of movement or forced oscillation, as a governor which has a large
movement of the balls for small change of load, an arc-lamp clutch
mechanism which moves rapidly up and down with variations of current, or
the like; also, to seesaw, as a pair of alternators working in
parallel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <fld>(Change Ringing)</fld> <def>To shift up and down in
order regularly.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>To hunt counter</b></col>, <cd>to trace the scent
backward in hunting, as a hound to go back on one's steps.</cd>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunt</ent><br/
<hw>Hunt</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or practice of
chasing wild animals; chase; pursuit; search.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hunt</qex> is up; the morn is bright and gray.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The game secured in the hunt.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pack of hounds.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An association of huntsmen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A district of country hunted over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every landowner within the <qex>hunt</qex>.</q> <rj><qau>London
Field.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunt-counter</ent><br/
<hw>Hunt"-count`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A worthless dog
that runs back on the scent; a blunderer.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunte</ent><br/
<hw>Hunt"e</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hunta</ets>.]</ety> <def>A hunter.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunter</ent><br/
<hw>Hunt"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
hunts wild animals either for sport or for food; a huntsman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dog that scents game, or is trained to the chase;
a hunting dog.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A horse used in the chase; especially, a
thoroughbred, bred and trained for hunting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who hunts or seeks after anything, as if for
game; <as>as, a fortune <ex>hunter</ex> a place
<ex>hunter</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No keener <qex>hunter</qex> after glory breathes.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>A kind of spider. See
<cref>Hunting spider</cref>, under <er>Hunting</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A hunting watch, or one of which the crystal is
protected by a metallic cover.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hunter's room</b></col>, <cd>the lunation after the
harvest moon.</cd> -- <col><b>Hunter's screw</b></col>
<fld>(Mech.)</fld>, <cd>a differential screw, so named from the
inventor. See under <er>Differential</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunterian</ent><br/
<hw>Hun*te"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Discovered or
described by John <ets>Hunter</ets>, an English surgeon; <as>as, the
<ex>Hunterian</ex> chancre</as>. See <er>Chancre</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunting</ent><br/
<hw>Hunt"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The pursuit of game
or of wild animals.</def> <rj><au>A. Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Happy hunting grounds</b></col>, <cd>the region to which,
according to the belief of American Indians, the souls of warriors and
hunters pass after death, to be happy in hunting and feasting.</cd>
<au>Tylor.</au> -- <col><b>Hunting box</b></col>. <cd>Same As
<cref>Hunting lodge</cref> (below).</cd> -- <col><b>Hunting
cat</b></col> <fld>(Zool.)</fld>, <cd>the cheetah.</cd> --
<col><b>Hunting cog</b></col> <fld>(Mach.)</fld>, <cd>a tooth in the
larger of two geared wheels which makes its number of teeth prime to the
number in the smaller wheel, thus preventing the frequent meeting of the
same pairs of teeth.</cd> -- <col><b>Hunting dog</b></col>
<fld>(Zool.)</fld>, <cd>the hyena dog.</cd> -- <col><b>Hunting
ground</b></col>, <cd>a region or district abounding in game; esp.
(<pluf>pl.</pluf>), the regions roamed over by the North American
Indians in search of game.</cd> -- <col><b>Hunting horn</b></col>, <cd>a
bulge; a horn used in the chase. See <er>Horn</er>, and
<er>Bulge</er>.</cd> -- <col><b>Hunting leopard</b></col>
<fld>(Zool.)</fld>, <cd>the cheetah.</cd> -- <col><b>Hunting
lodge</b></col>, <cd>a temporary residence for the purpose of
hunting.</cd> -- <col><b>Hunting seat</b></col>, <cd>a hunting
lodge.</cd> <au>Gray.</au> -- <col><b>Hunting shirt</b></col>, <cd>a
coarse shirt for hunting, often of leather.</cd> -- <col><b>Hunting
spider</b></col> <fld>(Zool.)</fld>, <cd>a spider which hunts its prey,
instead of catching it in a web; a wolf spider.</cd> -- <col><b>Hunting
watch</b></col>. <cd>See <er>Hunter</er>, 6.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huntress</ent><br/
<hw>Hunt"ress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who hunts or
follows the chase; <as>as, the <ex>huntress</ex> Diana</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huntsman</ent><br/
<hw>Hunts"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Huntsmen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>One who
hunts, or who practices hunting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The person whose office it is to manage the chase or
to look after the hounds.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Huntsman's cup</b></col> <fld>(Bot.)</fld>, <cd>the
sidesaddle flower, or common American pitcher plant (<spn>Sarracenia
purpurea</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 714 --></p>

<p><ent>Huntsmanship</ent><br/
<hw>Hunts"man*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
practice of hunting, or the qualification of a hunter.</def>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hunt's-up</ent><br/
<hw>Hunt's"-up`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tune played on
the horn very early in the morning to call out the hunters; hence, any
arousing sound or call.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Time plays the <qex>hunt's-up</qex> to thy sleepy head.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurden</ent><br/
<hw>Hur"den</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Hurds</er>.]</ety> <def>A coarse kind of linen; -- called also
<altname>harden</altname>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurdle</ent><br/
<hw>Hur"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hurdel</ets>, <ets>hirdel</ets>, AS. <ets>hyrdel</ets>; akin to D.
<ets>horde</ets>, OHG. <ets>hurt</ets>, G. <ets>h<uum/rde</ets> a
hurdle, fold, pen, Icel. <ets>hur<?/</ets> door, Goth.
<ets>ha<uacute/rds</ets>, L. <ets>cratis</ets> wickerwork, hurdle, Gr.
<?/, Skr. <ets>k<?/t</ets> to spin, <ets>c<?/t</ets> to bind, connect.
<root/16. Cf. <er>Crate</er>, <er>Grate</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>A movable frame of wattled twigs, osiers, or withes and
stakes, or sometimes of iron, used for inclosing land, for folding sheep
and cattle, for gates, etc.; also, in fortification, used as revetments,
and for other purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In England, a sled or crate on which criminals were
formerly drawn to the place of execution.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An artificial barrier, variously constructed, over
which men or horses leap in a race.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hurdle race</b></col>, <cd>a race in which artificial
barriers in the form of hurdles, fences, etc., must be
leaped.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurdle</ent><br/
<hw>Hur"dle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hurdleed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hurdleing</conjf> <pr>(?)</pr>.]</vmorph> <def>To hedge, cover,
make, or inclose with hurdles.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurdlework</ent><br/
<hw>Hur"dle*work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Work after
manner of a hurdle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurds</ent><br/
<hw>Hurds</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hards</er>.]</ety> <def>The coarse part of flax or hemp;
hards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurdy-gurdy</ent><br/
<hw>Hur"dy-gur`dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. of
imitative origin.]</ety> <sn>1.</sn> <def>A stringed instrument,
lutelike in shape, in which the sound is produced by the friction of a
wheel turned by a crank at the end, instead of by a bow, two of the
strings being tuned as drones, while two or more, tuned in unison, are
modulated by keys.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In California, a water wheel with radial buckets,
driven by the impact of a jet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurkaru</ent><br/
<hw>Hur*ka"ru</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>hark<amac/ra</ets>]</ety> <def>In India, a running footman; a
messenger.</def> <altsp>[Written also <asp>hurkaroo</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurl</ent><br/
<hw>Hurl</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hurled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hurling</conjf>.]</vmorph> <ety>[OE. <ets>hurlen</ets>,
<ets>hourlen</ets>; prob. contracted fr. OE. <ets>hurtlen</ets> to
hurtle, or probably akin to E. <ets>whirl</ets>. <root/16. See
<er>Hurtle</er>.]</ety> <sn>1.</sn> <def>To send whirling or whizzing
through the air; to throw with violence; to drive with great force;
<as>as, to <ex>hurl</ex> a stone or lance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>hurl'd</qex> them headlong to their fleet and main.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To emit or utter with vehemence or impetuosity;
<as>as, to <ex>hurl</ex> charges or invective</as>.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. <er>Whirl</er>.]</ety> <def>To twist or
turn.</def> <ldquo/<xex>Hurled</xex> or crooked feet.<rdquo/
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurl</ent><br/
<hw>Hurl</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To hurl one's self; to
go quickly.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perform the act of hurling something; to throw
something (at another).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God shall <qex>hurl</qex> at him and not spare.</q> <rj><qau>Job
xxvii. 22 (Rev. Ver. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To play the game of hurling. See
<er>Hurling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurl</ent><br/
<hw>Hurl</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of hurling or
throwing with violence; a cast; a fling.</def>
<rj><au>Congreve.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tumult; riot; hurly-burly.</def> <mark>[Obs.]</mark>
<rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Hat Manuf.)</fld> <def>A table on which fiber is
stirred and mixed by beating with a bowspring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurlbat</ent><br/
<hw>Hurl"bat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Whirlbat</er>.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurlbone</ent><br/
<hw>Hurl"bone`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>See
<er>Whirlbone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Far.)</fld> <def>A bone near the middle of the
buttock of a horse.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurler</ent><br/
<hw>Hurl"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hurls, or
plays at hurling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurling</ent><br/
<hw>Hurl"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of throwing
with force.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of game at ball, formerly played.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hurling</qex> taketh its denomination from throwing the
ball.</q> <rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurlwind</ent><br/
<hw>Hurl"wind`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A whirlwind.</def>
<mark>[Obs.]</mark> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurly</ent><br/
<hw>Hur"ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hurler</ets> to howl.]</ety> <def>Noise; confusion;
uproar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That, with the <qex>hurly</qex>, death itself awakes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurly-burly</ent><br/
<hw>Hur"ly-bur`ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Reduplicated
fr. OE. <ets>hurly</ets> confusion: cf. F. <ets>hurler</ets> to howl,
yell, L. <ets>ululare</ets>; or cf. E. <ets>hurry</ets>.]</ety>
<def>Tumult; bustle; confusion.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All places were filled with tumult and <qex>hurly-burly</qex>.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huronian</ent><br/
<hw>Hu*ro"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Named from Lake
<ets>Huron</ets>.]</ety> <fld>(Geol.)</fld> <def>Of or pertaining to
certain non-fossiliferous rocks on the borders of Lake Huron, which are
supposed to correspond in time to the latter part of the Arch<ae/an
age.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huron-Iroquous</ent><br/
<hw>Hu"ron-Ir`o*quous"</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Ethnol.)</fld> <def>A linguistic group of warlike North American
Indians, belonging to the same stock as the Algonquins, and including
several tribes, among which were the Five Nations. They formerly
occupied the region about Lakes Erie and Ontario, and the larger part of
New York.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurons</ent><br/
<hw>Hu"rons</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing><it>sing.</it>
<singf>Huron</singf>.</sing> <fld>(Ethnol.)</fld> <def>A powerful and
warlike tribe of North American Indians of the Algonquin stock. They
formerly occupied the country between Lakes Huron, Erie, and Ontario,
but were nearly exterminated by the Five Nations about 1650.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurr</ent><br/
<hw>Hurr</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Hurry</er>.]</ety> <def>To make a rolling or burring sound.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>R is the dog's letter, and <qex>hurreth</qex> in the sound.</q>
<rj><qau>B. Jonson.</qau></rj></p>

<p><ent>Hurra</ent><br/
<ent>Hurrah</ent><br/
<mhw>{ <hw>Hur*rah"</hw> <hw>Hur*ra"</hw> }</mhw> <pr>(?)</pr>,
<pos>interj.</pos> <ety>[Cf. G., Dan., & Sw. <ets>hurra</ets>. Cf.
<er>Huzza</er>.]</ety> <def>A word used as a shout of joy, triumph,
applause, encouragement, or welcome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hurrah</qex>! <qex>hurrah</qex>! for Ivry and Henry of
Navarre.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurrah</ent><br/
<hw>Hur*rah"</hw>, <pos>n.</pos> <def>A cheer; a shout of joy,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hurrah's nest</b></col>, <cd>state of utmost
confusion.</cd> <mark>[Colloq. U.S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>A perfect <qex>hurrah's nest</qex> in our kitchen.</q>
<rj><qau>Mrs. Stowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurrah</ent><br/
<hw>Hur*rah"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To utter hurrahs;
to huzza.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurrah</ent><br/
<hw>Hur*rah"</hw>, <pos>v. t.</pos> <def>To salute, or applaud, with
hurrahs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurricane</ent><br/
<hw>Hur"ri*cane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>hurracan</ets>; orig. a Carib word signifying, a high wind.]</ety>
<def>A violent storm, characterized by extreme fury and sudden changes
of the wind, and generally accompanied by rain, thunder, and lightning;
-- especially prevalent in the East and West Indies. Also used
figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like the smoke in a <qex>hurricane</qex> whirl'd.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Each guilty thought to me is<br/
A dreadful <qex>hurricane</qex>.</q> <rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hurricane bird</b></col> <fld>(Zool.)</fld>, <cd>the
frigate bird.</cd> -- <col><b>Hurricane deck</b></col>.
<fld>(Naut.)</fld> <cd>See under <er>Deck</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurricano</ent><br/
<hw>Hur`ri*ca"no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hurricanoes</plw> <pr>(#)</pr>.</plu> <def>A waterspout; a
hurricane.</def> <mark>[Obs.]</mark> <au>Drayton.</au> <ldquo/You
cataracts and <xex>hurricanoes</xex>, spout.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurried</ent><br/
<hw>Hur"ried</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Urged on;
hastened; going or working at speed; <as>as, a <ex>hurried</ex> writer;
a <ex>hurried</ex> life.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Done in a hurry; hence, imperfect; careless; <as>as,
a <ex>hurried</ex> job</as>.</def> <ldquo/A <xex>hurried</xex>
meeting.<rdquo/ <rj><au>Milton.</au></rj></p>

<p>-- <wordforms><wf>Hur"ried*ly</wf>, <pos>adv.</pos> --
<wf>Hur"ried*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurrier</ent><br/
<hw>Hur"ri*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hurries or
urges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurries</ent><br/
<hw>Hur"ries</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A staith or framework
from which coal is discharged from cars into vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurry</ent><br/
<hw>Hur"ry</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hurried</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hurrying</conjf>.]</vmorph> <ety>[OE. <ets>horien</ets>; cf. OSw.
<ets>hurra</ets> to whirl round, dial. Sw. <ets>hurr</ets> great haste,
Dan. <ets>hurre</ets> to buzz, Icel. <ets>hurr</ets> hurly-burly, MHG.
<ets>hurren</ets> to hurry, and E. <ets>hurr</ets>, <ets>whir</ets> to
hurry; all prob. of imitative origin.]</ety> <sn>1.</sn> <def>To hasten;
to impel to greater speed; to urge on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Impetuous lust <qex>hurries</qex> him on.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>hurried</qex> him abroad a bark.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To impel to precipitate or thoughtless action; to
urge to confused or irregular activity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And wild amazement <qex>hurries</qex> up and down<br/
The little number of your doubtful friends.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to be done quickly.</def></p>

<p><syn><b>Syn.</b> -- To hasten; precipitate; expedite; quicken;
accelerate; urge.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurry</ent><br/
<hw>Hur"ry</hw>, <pos>v. i.</pos> <def>To move or act with haste; to
proceed with celerity or precipitation; <as>as, let us
<ex>hurry</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hurry up</b></col>, <cd>to make haste.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurry</ent><br/
<hw>Hur"ry</hw>, <pos>n.</pos> <def>The act of hurrying in motion or
business; pressure; urgency; bustle; confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ambition raises a tumult in the soul, it inflames the mind, and
puts into a violent <qex>hurry</qex> of thought.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Haste; speed; dispatch. See
<er>Haste</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurryingly</ent><br/
<hw>Hur"ry*ing*ly</hw>, <pos>adv.</pos> <def>In a hurrying
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurry-skurry</ent><br/
<hw>Hur"ry-skur`ry</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[An imitative
word; cf. Sw. <ets>skorra</ets> to rattle, snarl, E.
<ets>scurry</ets>.]</ety> <def>Confusedly; in a bustle.</def>
<mark>[Obs.]</mark> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurst</ent><br/
<hw>Hurst</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hurst</ets>,
AS. <ets>hyrst</ets>; akin to OHG. <ets>hurst</ets>, <ets>horst</ets>,
wood, thicket, G. <ets>horst</ets> the nest of a bird of prey, an
eyerie, thicket.]</ety> <def>A wood or grove; -- a word used in the
composition of many names, as in Hazle<xex>hurst</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurt</ent><br/
<hw>Hurt</hw>, <pos>n.</pos> <fld>(Mach.)</fld> <sd>(a)</sd> <def>A band
on a trip-hammer helve, bearing the trunnions.</def> <sd>(b)</sd> <def>A
husk. See <er>Husk</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurt</ent><br/
<hw>Hurt</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hurt</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hurting</conjf>.]</vmorph> <ety>[OE. <ets>hurten</ets>,
<ets>hirten</ets>, <ets>horten</ets>, <ets>herten</ets>; prob. fr. OF.
<ets>hurter</ets>, <ets>heurter</ets>, to knock, thrust, strike, F.
<ets>heurter</ets>; cf. W. <ets>hyrddu</ets> to push, drive, assault,
<ets>hwrdd</ets> a stroke, blow, push; also, a ram, the orig. sense of
the verb thus perhaps being, to butt as a ram; cf. D. <ets>horten</ets>
to push, strike, MHG. <ets>hurten</ets>, both prob. fr. Old
French.]</ety> <sn>1.</sn> <def>To cause physical pain to; to do bodily
harm to; to wound or bruise painfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hurt</qex> lion groans within his den.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To impair the value, usefulness, beauty, or pleasure
of; to damage; to injure; to harm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Virtue may be assailed, but never <qex>hurt</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To wound the feelings of; to cause mental pain to;
to offend in honor or self-respect; to annoy; to grieve.</def> <ldquo/I
am angry and <xex>hurt</xex>.<rdquo/ <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurter</ent><br/
<hw>Hurt"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>A bodily injury causing
pain; a wound, bruise, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pains of sickness and <qex>hurts</qex> . . . all men feel.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An injury causing pain of mind or conscience; a
slight; a stain; as of sin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But the jingling of the guinea helps the <qex>hurt</qex> that
Honor feels.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Injury; damage; detriment; harm; mischief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou dost me yet but little <qex>hurt</qex>.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Wound; bruise; injury; harm; damage; loss;
detriment; mischief; bane; disadvantage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurter</ent><br/
<hw>Hurt"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who hurts or does
harm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall not be a <qex>hurter</qex>, if no helper.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurter</ent><br/
<hw>Hurt"er</hw>, <pos>n.</pos> <ety>[F. <ets>heurtoir</ets>, lit., a
striker. See <er>Hurt</er>, <pos>v. t.</pos>]</ety> <def>A butting
piece; a strengthening piece, esp.: <fld>(Mil.)</fld> A piece of wood at
the lower end of a platform, designed to prevent the wheels of gun
carriages from injuring the parapet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurtful</ent><br/
<hw>Hurt"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to impair or
damage; injurious; mischievous; occasioning loss or injury; <as>as,
<ex>hurtful</ex> words or conduct</as>.</def></p>

<p><syn><b>Syn.</b> -- Pernicious; harmful; baneful; prejudicial;
detrimental; disadvantageous; mischievous; injurious; noxious;
unwholesome; destructive.</syn></p>

<p>-- <wordforms><wf>Hurt"ful*ly</wf>, <pos>adv.</pos> --
<wf>Hurt"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>hurting</ent><br/
<hw>hurting</hw> <pos>n.</pos> <def>a feeling of pain.</def><br/
<syn><b>Syn. --</b> pain.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hurting</ent><br/
<hw>hurting</hw> <pos>adj.</pos> <sn>1.</sn> <def>aching when
touched.</def><br/
<syn><b>Syn. --</b> sensitive, sore, tender.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>In distress; experiencing difficulty; <as>as, with
the dollar exchange rate so high, companies dependent on exports are
really <ex>hurting</ex></as>.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Hurtle</ent><br/
<hw>Hur"tle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hurtled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hurtling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>hurtlen</ets>, freq. of <ets>hurten</ets>. See <er>Hurt</er>,
<pos>v. t.</pos>, and cf. <er>Hurl</er>.]</ety> <sn>1.</sn> <def>To meet
with violence or shock; to clash; to jostle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Together <qex>hurtled</qex> both their steeds.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move rapidly; to wheel or rush suddenly or with
violence; to whirl round rapidly; to skirmish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now <qex>hurtling</qex> round, advantage for to take.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Down the <qex>hurtling</qex> cataract of the ages.</q> <rj><qau>R.
L. Stevenson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make a threatening sound, like the clash of arms;
to make a sound as of confused clashing or confusion; to
resound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The noise of battle <qex>hurtled</qex> in the air.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The earthquake sound<br/
<qex>Hurtling</qex> 'death the solid ground.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurtle</ent><br/
<hw>Hur"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To move
with violence or impetuosity; to whirl; to brandish.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His harmful club he gan to <qex>hurtle</qex> high.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To push; to jostle; to hurl.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And he <qex>hurtleth</qex> with his horse adown.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurtleberry</ent><br/
<hw>Hur"tle*ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Huckleberry</er>, <er>Whortleberry</er>.]</ety> <def>See
<er>Whortleberry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hurtless</ent><br/
<hw>Hurt"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Doing no injury;
harmless; also, unhurt; without injury or harm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gentle dame so <qex>hurtless</qex> and so true.</q>
<rj><qau>Spenser.</qau></rj></p>

<p>-- <wordforms><wf>Hurt"less*ly</wf>, <pos>adv.</pos> --
<wf>Hurt"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husband</ent><br/
<hw>Hus"band</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hosebonde</ets>, <ets>husbonde</ets>, a husband, the master of the
house or family, AS. <ets>h<?/sbonda</ets> master of the house;
<ets>h<?/s</ets> house + <ets>bunda</ets>, <ets>bonda</ets>,
householder, husband; prob. fr. Icel. <ets>h<?/sb<omac/ndi</ets> house
master, husband; <ets>h<?/s</ets> house + <ets>b<?/andi</ets> dwelling,
inhabiting, p. pr. of <ets>b<?/a</ets> to dwell; akin to AS.
<ets>b<?/an</ets>, Goth. <ets>bauan</ets>. See <er>House Be</er>, and
cf. <er>Bond</er> a slave, <er>Boor</er>.]</ety> <sn>1.</sn> <def>The
male head of a household; one who orders the economy of a family.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cultivator; a tiller; a husbandman.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The painful <qex>husband</qex>, plowing up his ground.</q>
<rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He is the neatest <qex>husband</qex> for curious ordering his
domestic and field accommodations.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who manages or directs with prudence and
economy; a frugal person; an economist.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God knows how little time is left me, and may I be a good
<qex>husband</qex>, to improve the short remnant left me.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A married man; a man who has a wife; -- the
correlative to <xex>wife</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>husband</qex> and wife are one person in law.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The male of a pair of animals.</def>
<mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A ship's husband</b></col> <fld>(Naut.)</fld>, <cd>an
agent representing the owners of a ship, who manages its expenses and
receipts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husband</ent><br/
<hw>Hus"band</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Husbanded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Husbanding</conjf>.]</vmorph> <sn>1.</sn> <def>To direct and
manage with frugality; to use or employ to good purpose and the best
advantage; to spend, apply, or use, with economy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For my means, I'll <qex>husband</qex> them so well,<br/
They shall go far.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cultivate, as land; to till.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Land so trim and rarely <qex>husbanded</qex>.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To furnish with a husband.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husbandable</ent><br/
<hw>Hus"band*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being husbanded, or managed with economy.</def>
<rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husbandage</ent><br/
<hw>Hus"band*age</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The commission or compensation allowed to a ship's
husband.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husbandless</ent><br/
<hw>Hus"band*less</hw>, <pos>a.</pos> <def>Destitute of a husband.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husbandly</ent><br/
<hw>Hus"band*ly</hw>, <pos>a.</pos> <def>Frugal; thrifty.</def>
<mark>[R.]</mark> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husbandman</ent><br/
<hw>Hus"band*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Husbandmen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The master
of a family.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A farmer; a cultivator or tiller of the
ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husbandry</ent><br/
<hw>Hus"band*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Care
of domestic affairs; economy; domestic management; thrift.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There's <qex>husbandry</qex> in heaven;<br/
Their candles are all out.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The business of a husbandman, comprehending the
various branches of agriculture; farming.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Husbandry</qex> supplieth all things necessary for food.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hush</ent><br/
<hw>Hush</hw> <pr>(h<ucr/sh)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hushed</conjf> <pr>(h<ucr/sht)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Hushing</conjf>.]</vmorph> <ety>[OE.
<ets>huschen</ets>, <ets>hussen</ets>, prob. of imitative origin; cf.
LG. <ets>hussen</ets> to lull to sleep, G. <ets>husch</ets> quick, make
haste, be silent.]</ety> <sn>1.</sn> <def>To still; to silence; to calm;
to make quiet; to repress the noise or clamor of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My tongue shall <qex>hush</qex> again this storm of war.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To appease; to allay; to calm; to soothe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With thou, then,<br/
<qex>Hush</qex> my cares?</q> <rj><qau>Otway.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>hush'd</qex> my deepest grief of all.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To hush up</b></col>, <cd>to procure silence concerning;
to suppress; to keep secret.</cd> <ldquo/This matter is <xex>hushed
up</xex>.<rdquo/ <rj><au>Pope.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hush</ent><br/
<hw>Hush</hw>, <pos>v. i.</pos> <def>To become or to keep still or
quiet; to become silent; -- esp. used in the imperative, as an
exclamation; be still; be silent or quiet; make no noise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hush</qex>, idle words, and thoughts of ill.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But all these strangers' presence every one did
<qex>hush</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hush</ent><br/
<hw>Hush</hw>, <pos>n.</pos> <def>Stillness; silence; quiet.</def>
<mark>[R.]</mark> <ldquo/It is the <xex>hush</xex> of night.<rdquo/
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hush money</b></col>, <cd>money paid to secure silence,
or to prevent the disclosure of facts.</cd>
<rj><au>Swift.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hush</ent><br/
<hw>Hush</hw>, <pos>a.</pos> <def>Silent; quiet.</def>
<ldquo/<xex>Hush</xex> as death.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hushed</ent><br/
<hw>hushed</hw> <pr>(h<ucr/sht)</pr>, <pos>adj.</pos> <sn>1.</sn>
<def>having the sound level reduced; -- especially used of the noise of
conversation; <as>as, speaking in <ex>hushed</ex> tones</as>.</def><br/
<syn><b>Syn. --</b> muted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having relatively little noise; <as>as, a
<ex>hushed</ex> church</as>.</def><br/
<syn><b>Syn. --</b> quiet.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hushed-up</ent><br/
<hw>hushed-up</hw> <pos>adj.</pos> <def>kept secret; -- used of reports;
<as>as, <ex>hushed-up</ex> stories sometimes leak out</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Husher</ent><br/
<hw>Hush"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An usher.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hushing</ent><br/
<hw>Hush"ing</hw>, <pos>n.</pos> <fld>(Mining)</fld> <def>The process of
washing ore, or of uncovering mineral veins, by a heavy discharge of
water from a reservoir; flushing; -- also called
<altname>booming</altname> and <altname>hydraulic
mining</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Husk</ent><br/
<hw>Husk</hw> <pr>(h<ucr/sk)</pr>, <pos>n.</pos> <ety>[Prob. for
<ets>hulsk</ets>, and from the same root as <ets>hull</ets> a husk. See
<er>Hull</er> a husk.]</ety> <sn>1.</sn> <def>The external covering or
envelope of certain fruits or seeds; glume; hull; rind; in the United
States, especially applied to the covering of the ears of
maize.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The supporting frame of a run of
millstones.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Husks of the prodigal son</b></col> <fld>(Bot.)</fld>,
<cd>the pods of the carob tree. See <er>Carob</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husk</ent><br/
<hw>Husk</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Husked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Husking</conjf>.]</vmorph> <def>To strip off the external
covering or envelope of; <as>as, to <ex>husk</ex> Indian
corn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husked</ent><br/
<hw>Husked</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Covered
with a husk.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Stripped of husks; deprived of husks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huskily</ent><br/
<hw>Hus"ki*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Husky</er>.]</ety> <def>In a husky manner; dryly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huskiness</ent><br/
<hw>Hus"ki*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being
husky.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Roughness of sound; harshness; hoarseness; <as>as,
<ex>huskiness</ex> of voice</as>.</def> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 715 --></p>

<p><ent>Husking</ent><br/
<hw>Husk"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or process of stripping off husks, as from Indian corn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A meeting of neighbors or friends to assist in
husking maize; -- called also</def> <xex>husking bee</xex>.
<mark>[U.S.]</mark> <ldquo/A red ear in the <xex>husking</xex>.<rdquo/
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husky</ent><br/
<hw>Husk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Husk</er>,
<pos>n.</pos>]</ety> <def>Abounding with husks; consisting of
husks.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husky</ent><br/
<hw>Hus"ky</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prob. for
<ets>husty</ets>; cf. OE. <ets>host</ets> cough, AS.
<ets>hw<omac/sta</ets>; akin to D. <ets>hoest</ets>, G.
<ets>husten</ets>, OHG. <ets>huosto</ets>, Icel. <ets>h<omac/sti</ets>.
See <er>Wheeze</er>.]</ety> <def>Rough in tone; harsh; hoarse; raucous;
<as>as, a <ex>husky</ex> voice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Husky</ent><br/
<hw>Hus"ky</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Powerful; strong;
burly.</def> <mark>[Colloq., U. S.]</mark></p>

<p><q>A good, <qex>husky</qex> man to pitch in the barnyard.</q>
<rj><qau>Hamlin Garland.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Husky</ent><br/
<hw>Hus"ky</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl. <plw>-kies</plw>
<pr>(#)</pr></plu>. <ety>[Cf. <er>Eskimo</er>.]</ety> <sn>1.</sn>
<def>An Eskimo.</def> <mark>[archaic]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>The Eskimo language.</def>
<mark>[archaic]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>an Eskimo dog, especially a breed of strong
heavy-coated dogs used to pull dogsleds in the Northern regions of North
America.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Huso</ent><br/
<hw>Hu"so</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. G.
<ets>hausen</ets>, and E. <ets>isin</ets>glass.]</ety>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A large European sturgeon
(<spn>Huso huso</spn> or <spn>Acipenser huso</spn>), inhabiting the
region of the Black and Caspian Seas. It sometimes attains a length of
more than twelve feet, and a weight of two thousand pounds. Called also
<altname>hausen</altname> and <altname>beluga</altname>. It is the
source of the finest and most esteemed caviar.</def> <sd>(b)</sd>
<def>The huchen, a large salmon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hussar</ent><br/
<hw>Hus*sar"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hung.
<ets>husz<aacute/r</ets>, from <ets>husz</ets> twenty, because under
King Matthais I., in the fifteenth century, every twenty houses were to
furnish one horse soldier; cf. G. <ets>husar</ets>, F.
<ets>houssard</ets>, <ets>hussard</ets>, from the same source.]</ety>
<fld>(Mil.)</fld> <def>Originally, one of the national cavalry of
Hungary and Croatia; now, one of the light cavalry of European
armies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hussite</ent><br/
<hw>Huss"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld>
<def>A follower of John <xex>Huss</xex>, the Bohemian reformer, who was
adjudged a heretic and burnt alive in 1415.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hussy</ent><br/
<hw>Hus"sy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Contr. fr.
<ets>huswife</ets>.]</ety> <sn>1.</sn> <def>A housewife or
housekeeper.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A worthless woman or girl; a forward wench; a jade;
-- used as a term of contempt or reproach.</def>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pert girl; a frolicsome or sportive young woman;
-- used jocosely.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hussy</ent><br/
<hw>Hus"sy</hw>, <pos>n.</pos> <ety>[From Icel. <ets>h<?/si</ets> a
case, prob. fr. <ets>h<?/s</ets> house. See <er>House</er>, and cf.
<er>Housewife</er> a bag, <er>Huswife</er> a bag.]</ety> <def>A case or
bag. See <er>Housewife</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hustings</ent><br/
<hw>Hus"tings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[OE.
<ets>husting</ets> an assembly, coucil, AS. <ets>h<?/sting</ets>; of
Scand. origin; cf. Icel. <ets>h<?/s<?/ing</ets>; <ets>h<?/s</ets> home +
<ets><?/ing</ets> thing, assembly, meeting; akin to Dan. & Sw.
<ets>ting</ets>, E. <ets>thing</ets>. See <er>House</er>, and
<er>Thing</er>.]</ety> <sn>1.</sn> <def>A court formerly held in several
cities of England; specif., a court held in London, before the lord
mayor, recorder, and sheriffs, to determine certain classes of suits for
the recovery of lands within the city. In the progress of law reform
this court has become unimportant.</def> <rj><au>Mozley &
W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any one of the temporary courts held for the
election of members of the British Parliament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The platform on which candidates for Parliament
formerly stood in addressing the electors.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When the rotten <qex>hustings</qex> shake<br/
In another month to his brazen lies.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hustle</ent><br/
<hw>Hus"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hustled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hustling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[D.
<ets>hustelen</ets> to shake, fr. <ets>husten</ets> to shake. Cf.
<er>Hotchpotch</er>.]</ety> <def>To shake together in confusion; to
push, jostle, or crowd rudely; to handle roughly; <as>as, to
<ex>hustle</ex> a person out of a room</as>.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hustle</ent><br/
<hw>Hus"tle</hw>, <pos>v. i.</pos> <def>To push or crows; to force one's
way; to move hastily and with confusion; a hurry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leaving the king, who had <qex>hustled</qex> along the floor with
his dress worfully arrayed.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huswife</ent><br/
<hw>Hus"wife</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>huswif</ets>; <ets>hus</ets> house + <ets>wif</ets> wife. Cf.
<er>Hussy</er> a housewife, <er>Housewife</er>.]</ety> <altsp>[Written
also <asp>housewife</asp>.]</altsp> <sn>1.</sn> <def>A female
housekeeper; a woman who manages domestic affairs; a thrifty
woman.</def> <ldquo/The bounteous <xex>huswife</xex> Nature.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>huswife</qex> is she that do labor doth fall.</q>
<rj><qau>Tusser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A worthless woman; a hussy.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[See <er>Hussy</er> a bag.]</ety> <def>A case for
sewing materials. See <er>Housewife</er>.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huswife</ent><br/
<hw>Hus"wife</hw>, <pos>v. t.</pos> <def>To manage with frugality; --
said of a woman.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huswifely</ent><br/
<hw>Hus"wife*ly</hw>, <pos>a.</pos> <def>Like a huswife; capable;
economical; prudent.</def> -- <def2><pos>adv.</pos> <def>In a huswifely
manner.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huswifery</ent><br/
<hw>Hus"wife*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The business of a
housewife; female domestic economy and skill.</def>
<rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hut</ent><br/
<hw>Hut</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hotte</ets>;
akin to D. <ets>hut</ets>, G. <ets>h<uum/tte</ets>, OHG.
<ets>hutta</ets>, Dan. <ets>hytte</ets>, Sw. <ets>hydda</ets>; and F.
<ets>hutte</ets>, of G. origin; all akin to E. <ets>hide</ets> to
conceal. See <er>Hude</er> to conceal.]</ety> <def>A small house, hovel,
or cabin; a mean lodge or dwelling; a slightly built or temporary
structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Death comes on with equal footsteps<br/
To the hall and <qex>hut</qex></q>. <rj><qau>Bp. Coxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hutch</ent><br/
<hw>Hutch</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hutted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hutting</conjf>.]</vmorph> <def>To place in huts; to
live in huts; <as>as, to <ex>hut</ex> troops in winter
quarters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The troops <qex>hutted</qex> among the heights of Morristown.</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hutch</ent><br/
<hw>Hutch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>hucche</ets>,
<ets>huche</ets>, <ets>hoche</ets>, F. <ets>huche</ets>, LL.
<ets>hutica</ets>.]</ety> <sn>1.</sn> <def>A chest, box, coffer, bin,
coop, or the like, in which things may be stored, or animals kept;
<as>as, a grain <ex>hutch</ex>; a rabbit <ex>hutch</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A measure of two Winchester bushels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mining)</fld> <def>The case of a flour
bolt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <sd>(a)</sd> <def>A car on low
wheels, in which coal is drawn in the mine and hoisted out of the
pit.</def> <sd>(b)</sd> <def>A jig for washing ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bolting hutch</b></col>, <col><b>Booby
hutch</b></col></mcol>, <cd>etc. See under <er>Bolting</er>,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hutch</ent><br/
<hw>Hutch</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hutched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hutching</conjf>.]</vmorph> <sn>1.</sn> <def>To hoard or lay up,
in a chest.</def> <mark>[R.]</mark> <ldquo/She <xex>hutched</xex> the .
. . ore.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>To wash (ore) in a box or
jig.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hutchunsonian</ent><br/
<hw>Hutch`un*so"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A follower
of John <xex>Hutchinson</xex> of Yorkshire, England, who believed that
the Hebrew Scriptures contained a complete system of natural science and
of theology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huttonian</ent><br/
<hw>Hut*to"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to what
is now called the <xex>Plutonic</xex> theory of the earth, first
advanced by Dr. James <xex>Hutton</xex>.</def>
<rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huttoning</ent><br/
<hw>Hut"ton*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So named after
two English bonesetters, Richard and Robert <etsep>Hutton</etsep>, who
made it a part of their method.]</ety> <fld>(Med.)</fld> <def>Forcible
manipulation of a dislocated, stiff, or painful joint.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Huxter</ent><br/
<hw>Hux"ter</hw> <pr>(?)</pr>, <pos>n. & v. i.</pos> <def>See
<er>Huckster</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huyghenian</ent><br/
<hw>Huy*ghe"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or invented by, Christian <xex>Huyghens</xex>, a Dutch astronomer of the
seventeenth century; <as>as, the <ex>Huyghenian</ex>
telescope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Huyghenian eyepiece</b></col><cd>See under
<er>Eyepiece</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huzz</ent><br/
<hw>Huzz</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[An onomatop<oe/a.
<root/43. Cf. <er>Buzz</er>.]</ety> <def>To buzz; to murmur.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Huzzing and burring in the preacher's ear.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huzza</ent><br/
<hw>Huz*za"</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Cf. G.
<ets>hussa</ets>, <ets>husa</ets>, interj., hurrah, huzza. <root/43. Cf.
<er>Hurrah</er>.]</ety> <def>A word used as a shout of joy, exultation,
approbation, or encouragement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huzza</ent><br/
<hw>Huz"za</hw>, <pos>n.</pos> <def>A shout of <xex>huzza</xex>; a
cheer; a hurrah.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They made a great <qex>huzza</qex> or shout.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huzza</ent><br/
<hw>Huz*za"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Huzzaed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Huzzaing</conjf>.]</vmorph> <def>To shout huzza; to
cheer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Huzza</ent><br/
<hw>Huz*za"</hw>, <pos>v. t.</pos> <def>To receive or attend with
huzzas.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>huzzaed</qex> into the court.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hy</ent><br/
<hw>Hy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>High.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyacine</ent><br/
<hw>Hy"a*cine</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hyacinth.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyacinth</ent><br/
<hw>Hy"a*cinth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hyacinthus</ets> a kind of flower, prob. the iris, gladiolus, or
larkspur, also a kind of gem, perh. the sapphire; as, a proper name,
<ets>Hyacinthus</ets>, a beautiful Laconian youth, beloved by Apollo,
fr. Gr. <?/, <?/: cf. F. <ets>hyacinthe</ets>. Cf. <er>Jacinth</er>. The
hyacinth was fabled to have sprung from the blood of
<ets>Hyacinthus</ets>, who was accidentally slain by Apollo.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>A bulbous plant of the
genus <gen>Hyacinthus</gen>, bearing beautiful spikes of fragrant
flowers. <spn>Hyacinthus orientalis</spn> is a common variety.</def>
<sd>(b)</sd> <def>A plant of the genus <gen>Camassia</gen>
(<spn>Camassia Farseri</spn>), called also <altname>Eastern
camass</altname>; wild hyacinth.</def> <sd>(c)</sd> <def>The name also
given to <spn>Scilla Peruviana</spn>, a Mediterranean plant, one variety
of which produces white, and another blue, flowers; -- called also, from
a mistake as to its origin, <altname>Hyacinth of
Peru</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>A red variety of zircon, sometimes
used as a gem. See <er>Zircon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyacinth bean</b></col> <fld>(Bot.)</fld>, <cd>a climbing
leguminous plant (<spn>Dolichos Lablab</spn>), related to the true bean.
It has dark purple flowers and fruit.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyacinthian</ent><br/
<hw>Hy`a*cin"thi*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hyacinthine.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyacinthine</ent><br/
<hw>Hy`a*cin"thine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hyacinthinus</ets>, Gr. <?/.]</ety> <def>Belonging to the hyacinth;
resembling the hyacinth; in color like the hyacinth.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His curling locks like <qex>hyacinthine</qex> flowers.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hyacinthine</qex> boy, for whom<br/
Morn well might break and April bloom.</q>
<rj><qau>Emerson.</qau></rj></p>

<p><ent>Hyades</ent><br/
<hw>Hyades</hw> <pos>n.</pos> <fld>(Greek mythology)</fld> <def>The
seven daughters of Atlas and half-sisters of the Pleiades; they nurtured
the infant Dionysus and Zeus placed them among the stars as a
reward.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyads</ent><br/
<ent>Hyades</ent><br/
<mhw>{ <hw>Hy"a*des</hw> <pr>(?)</pr>, <hw>Hy"ads</hw> <pr>(?)</pr>,
}</mhw> <pos>n. pl.</pos> <ety>[L. <ets>Hyades</ets>, Gr. <?/.]</ety>
<fld>(Astron.)</fld> <def>A cluster of five stars in the face of the
constellation Taurus, supposed by the ancients to indicate the coming of
rainy weather when they rose with the sun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thro' scudding drifts the rainy <qex>Hyades</qex><br/
Vext the dim sea.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyaena</ent><br/
<mhw><hw>hyaena</hw>, <hw>hy*<ae/"na</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>Same as <er>Hyena</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyaenidae</ent><br/
<hw>Hyaenidae</hw> <pos>prop. n.</pos> <def>A natural family of canids
comprising the hyenas.</def><br/
<syn><b>Syn. --</b> family <fam>Hyaenidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyalea</ent><br/
\'d8<hw>Hy*a"le*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ glassy, fr. <grk>"y`alos</grk> glass.]</ety> <fld>(Zool.)</fld>
<def>A pteropod of the genus <gen>Cavolina</gen>. See
<er>Pteropoda</er>, and <xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalescence</ent><br/
<hw>Hy`a*les"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hyaline</er>.]</ety> <def>The process of becoming, or the state of
being, transparent like glass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyalin</ent><br/
<hw>hyalin</hw> <pos>n.</pos> <def>a glassy translucent material that
occurs in hyaline cartilage or in certain skin conditions.</def><br/
<syn><b>Syn. --</b> hyaline.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyaline</ent><br/
<hw>Hy"a*line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hyalinus</ets>, Gr. <?/, fr. <grk>"y`alos</grk> glass: cf. F.
<ets>hyalin</ets>.]</ety> <def>Glassy; resembling glass; consisting of
glass; transparent, like crystal.</def> <ldquo/<xex>Hyaline</xex>
spaces.<rdquo/ <rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyaline</ent><br/
<hw>Hy"a*line</hw>, <pos>n.</pos> <sn>1.</sn> <def>A poetic term for the
sea or the atmosphere.</def> <ldquo/The clear <xex>hyaline</xex>, the
glassy sea.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our blood runs amazed 'neath the calm <qex>hyaline</qex>.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The pellucid substance, present
in cells in process of development, from which, according to some
embryologists, the cell nucleus originates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physiol. Chem.)</fld> <def>The main constituent of
the walls of hydatid cysts; a nitrogenous body, which, by decomposition,
yields a dextrogyrate sugar, susceptible of alcoholic
fermentation.</def> <rj><au>Gamgee.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalite</ent><br/
<hw>Hy"a*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`alos</grk> glass: cf. F. <ets>hyalite</ets>.]</ety>
<fld>(Min.)</fld> <def>A pellucid variety of opal in globules looking
like colorless gum or resin; -- called also <altname>M<uum/ller's
glass</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalograph</ent><br/
<hw>Hy*al"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`alos</grk> glass + <ets>graph</ets>.]</ety> <def>An instrument
for tracing designs on glass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalography</ent><br/
<hw>Hy`a*log"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Art of writing
or engraving on glass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyaloid</ent><br/
<hw>Hy"a*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ glassy,
transparent; <grk>"y`alos</grk> glass + <?/ appearance: cf. F.
<ets>hyalo<ium/de</ets>.]</ety> <fld>(Anat.)</fld> <def>Resembling
glass; vitriform; transparent; hyaline; <as>as, the <ex>hyaloid</ex>
membrane, a very delicate membrane inclosing the vitreous humor of the
eye</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalonema</ent><br/
\'d8<hw>Hy`a*lo*ne"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"y`alos</grk> glass + <?/ a thread.]</ety> <fld>(Zool.)</fld>
<def>A genus of hexactinelline sponges, having a long stem composed of
very long, slender, transparent, siliceous fibres twisted together like
the strands of a color. The stem of the Japanese species (<spn>Hyalonema
Sieboldii</spn>), called <stype>glass-rope</stype>, has long been in use
as an ornament. See <er>Glass-rope</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalophane</ent><br/
<hw>Hy*al"o*phane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`alos</grk> glass + <?/ to appear.]</ety> <fld>(Min.)</fld>
<def>A species of the feldspar group containing barium. See
<er>Feldspar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalospongia</ent><br/
\'d8<hw>Hy`a*lo*spon"gi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"y`alos</grk> glass + <?/ a sponge.]</ety>
<fld>(Zool.)</fld> <def>An order of vitreous sponges, having glassy
six-rayed, siliceous spicules; -- called also
<altname><ord>Hexactinellin<ae/</ord></altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyalotype</ent><br/
<hw>Hy*al"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`alos</grk> glass + <ets>-type</ets>.]</ety> <def>A photographic
picture copied from the negative on glass; a photographic
transparency.</def> <rj><au>R. Hunt.</au></rj></p>

<p><ent>Hybernation</ent><br/
<ent>Hybernate</ent><br/
<ent>Hybernacle</ent><br/
<mhw>{ <hw>Hy*ber"na*cle</hw> <pr>(?)</pr>, <hw>Hy"ber*nate</hw>
<pr>(?)</pr>, <hw>Hy`ber*na"tion</hw> <pr>(?)</pr>. }</mhw> <def>See
<er>Hibernacle</er>, <er>Hibernate</er>, <er>Hibernation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyblaean</ent><br/
<hw>Hy*bl<ae/"an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Hyblaeus</ets>.]</ety> <def>Pertaining to <city>Hybla</city>, an
ancient town of Sicily, famous for its bees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybodont</ent><br/
<hw>Hyb"o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ hump +
<?/, <?/, a tooth.]</ety> <fld>(Paleon.)</fld> <def>Of, pertaining to,
or resembling, an extinct genus of sharks (<gen>Hybodus</gen>),
especially in the form of the teeth, which consist of a principal median
cone with smaller lateral ones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybodus</ent><br/
\'d8<hw>Hyb"o*dus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hybodont</er>.]</ety> <fld>(Paleon.)</fld> <def>An extinct genus of
sharks having conical, compressed teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybrid</ent><br/
<hw>Hy"brid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hybrida</ets>, <ets>hibrida</ets>, prob. allied to Gr. <?/
wantonness (as if unbridled, lawless, unnatural), perh. akin to Gr.
<grk>"ype`r</grk> over, E. <ets>over</ets>: cf. F.
<ets>hybride</ets>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>The
offspring of the union of two animals or plants derived from
recognizably different genetic lines, as two distinct species, or two
strains of the same species with known genetic differences; an animal or
plant produced from the mixture of two genetic lines. See
<er>Mongrel</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Philol.)</fld> <def>A word composed of elements
which belong to different languages.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>anything derived by a mixture of components or
characteristics from two distinctly different sources; <as>as, a musical
<ex>hybrid</ex>; a DNA-RNA <ex>hybrid</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hybrid</ent><br/
<hw>Hy"brid</hw>, <pos>a.</pos> <sn>1.</sn> <def>Produced from the
mixture of two genetically distinct strains; <as>as, plants of
<ex>hybrid</ex> nature</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>derived by a mixture of characteristics from two
distinctly different sources; <as>as, a <ex>hybrid</ex> musical style; a
<ex>hybrid</ex> DNA molecule</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hybridism</ent><br/
<hw>Hy"brid*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being hybrid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridist</ent><br/
<hw>Hy"brid*ist</hw>, <pos>n.</pos> <def>One who hybridizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridity</ent><br/
<hw>Hy*brid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Hybridism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridizable</ent><br/
<hw>Hy"brid*i`za*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
forming a hybrid, or of being subjected to a hybridizing process;
capable of producing a hybrid by union with another species or
stock.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hybridizable</qex> genera are rarer than is generally
supposed, even in gardens where they are so often operated upon, under
circumstances most favorable to the production of hybrids.</q>
<rj><qau>J. D. Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridization</ent><br/
<hw>Hy`brid*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
hybridizing, or the state of being hybridized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridize</ent><br/
<hw>Hy"brid*i`ze</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Hybridized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hybridizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
render hybrid; to produce by mixture of stocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridize</ent><br/
<hw>Hy"brid*ize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <fld>(Biol.)</fld>
<def>To produce hybrid offspring; to interbreed; to cross.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hybridizer</ent><br/
<hw>Hy"brid*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
hybridizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hybridous</ent><br/
<hw>Hy"brid*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Hybrid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydage</ent><br/
<hw>Hyd"age</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld> <def>A
land tax. See <er>Hidage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydantoic</ent><br/
<hw>Hy`dan*to"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, hydantoin. See
<er>Glycoluric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydantoin</ent><br/
<hw>Hy*dan"to*in</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hyd</ets>rogen + all<ets>antion</ets>.]</ety>
<fld>(Chem.)</fld> <def>A derivative of urea, <chform>C3H4N2O2</chform>,
obtained from allantion, as a white, crystalline substance, with a
sweetish taste; -- called also <altname>glycolyl
urea</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydatid</ent><br/
<hw>Hy"da*tid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/, a
watery vesicle under the upper eyelid, fr. <grk>"y`dwr</grk>,
<grk>"y`datos</grk>, water: cf. F. <ets>hydatide</ets>.]</ety>
<fld>(Zool.)</fld> <def>A membranous sac or bladder filled with a
pellucid fluid, found in various parts of the bodies of animals, but
unconnected with the tissues. It is usually formed by parasitic worms,
esp. by larval tapeworms, as Echinococcus and C<oe/nurus. See these
words in the Vocabulary.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydatid of Morgagni</b></col> <fld>(Anat.)</fld>, <cd>one
of the small pedunculated bodies found between the testicle and the head
of the epididymis, and supposed to be a remnant of the M<uum/llerian
duct.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydatiform</ent><br/
<hw>Hy*dat"i*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydatid</ets> + <ets>-form</ets>.]</ety> <def>Resembling a
hydatid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydatoid</ent><br/
<hw>Hy"da*toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"y`dwr</grk>, <grk>"y`datos</grk>, water + <ets>-oid</ets>.]</ety>
<fld>(Anat.)</fld> <def>Resembling water; watery; aqueous;
hyaloid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydr-</ent><br/
<hw>Hy"dr-</hw> <pr>(?)</pr>. <def>See under <er>Hydro-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydra</ent><br/
<hw>Hy"dra</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Hydras</plw> <pr>(#)</pr>, L. <plw>Hydr<ae/</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>hydra</ets>, Gr. <grk>"y`dra</grk>;
akin to <grk>"y`dwr</grk> water. See <er>Otter</er> the animal,
<er>Water</er>.]</ety> <sn>1.</sn> <fld>(Class. Myth.)</fld> <def>A
serpent or monster in the lake or marsh of Lerna, in the Peloponnesus,
represented as having many heads, one of which, when cut off, was
immediately succeeded by two others, unless the wound was cauterized. It
was slain by Hercules. Hence, a terrible monster.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gorgons, and <qex>Hydras</qex>, and Chimeras dire.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: A multifarious evil, or an evil having many
sources; not to be overcome by a single effort.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Any small fresh-water hydroid of
the genus <gen>Hydra</gen>, usually found attached to sticks, stones,
etc., by a basal sucker.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The body is a simple tube, having a mouth at one
extremity, surrounded by a circle of tentacles with which it captures
its prey. Young hydras bud out from the sides of the older ones, but
soon become detached and are then like their parent. Hydras are
remarkable for their power of repairing injuries; for if the body be
divided in pieces, each piece will grow into a complete hydra, to which
fact the name alludes. The zooids or hydranths of marine hydroids are
sometimes called <xex>hydras</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Astron.)</fld> <def>A southern constellation of
great length lying southerly from Cancer, Leo, and Virgo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrachnid</ent><br/
<hw>Hy*drach"nid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydr-</ets>
+ ar<ets>achnid</ets>.]</ety> <fld>(Zool.)</fld> <def>An aquatic mite of
the genus <gen>Hydrachna</gen>. The hydrachnids, while young, are
parasitic on fresh-water mussels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydracid</ent><br/
<hw>Hy*drac"id</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydr-</ets> +
<ets>acid</ets>: cf. F. <ets>hydracide</ets>.]</ety> <fld>(Chem.)</fld>
<def>An acid containing hydrogen; -- sometimes applied to distinguish
acids like hydrochloric, hydrofluoric, and the like, which contain no
oxygen, from the oxygen acids or oxacids. See <er>Acid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydracrylic</ent><br/
<hw>Hy`dra*cryl"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydr-</ets> + <ets>acrylic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an isomeric variety of lactic acid
that breaks down into acrylic acid and water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydractinian</ent><br/
<hw>Hy`drac*tin"i*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hydra</er>, and <er>Actinia</er>.]</ety> <fld>(Zool.)</fld> <def>Any
species or marine hydroids, of the genus <gen>Hydractinia</gen> and
allied genera. These hydroids form, by their rootstalks, a firm,
chitinous coating on shells and stones, and esp. on spiral shells
occupied by hermit crabs. See <xex>Illust.</xex> of
<er>Athecata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 716 --></p>

<p><ent>Hydraemia</ent><br/
\'d8<hw>Hy*dr<ae/"mi*a</hw> <pr>(h<isl/*dr<emac/"m<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>"y`dwr</grk> water +
<grk>a"i^ma</grk> blood.]</ety> <fld>(Med.)</fld> <def>An abnormally
watery state of the blood; an<ae/mia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydragogue</ent><br/
<hw>Hy"dra*gogue</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hydragogus</ets> conveying off water, Gr. <?/; <grk>"y`dwr</grk>
water + <?/ to lead: cf. F. <ets>hydragogue</ets>.]</ety>
<fld>(Med.)</fld> <def>Causing a discharge of water; expelling serum
effused into any part of the body, as in dropsy.</def> --
<def2><pos>n.</pos> <def>A hydragogue medicine, usually a cathartic or
diuretic.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydramide</ent><br/
<hw>Hy*dram"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydr-</ets>
+ <ets>-amide</ets>.]</ety> <fld>(Chem.)</fld> <def>One of a group of
crystalline bodies produced by the action of ammonia on certain
aldehydes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydramine</ent><br/
<hw>Hy*dram"ine</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydr</ets>oxyl + <ets>amine</ets>.]</ety> <fld>(Chem.)</fld>
<def>One of a series of artificial, organic bases, usually produced as
thick viscous liquids by the action of ammonia on ethylene oxide. They
have the properties both of alcohol and amines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrangea</ent><br/
<hw>Hy*dran"ge*a</hw> <pr>(?)</pr>, <pos>peop. n.</pos> <ety>[NL., fr.
Gr. <grk>"y`dwr</grk> water + <?/ vessel, capsule: cf. F.
<ets>hydrang<eacute/e</ets>.]</ety> <fld>(Bot.)</fld> <def>A genus of
shrubby plants bearing opposite leaves and large heads of showy flowers,
white, or of various colors. <spn>Hydrangea hortensis</spn>, the common
garden species, is a native of China or Japan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrangeaceae</ent><br/
<hw>Hydrangeaceae</hw> <pos>prop. n.</pos> <def>A natural family of
plants including the hydrangeas, sometimes included in the family
<fam>Saxifragaceae</fam>.</def><br/
<syn><b>Syn. --</b> family <fam>Hydrangeaceae</fam>, hydrangea
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hydrant</ent><br/
<hw>Hy"drant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ to irrigate,
fr. <grk>"y`dwr</grk> water. See <er>Hydra</er>.]</ety> <def>A discharge
pipe with a valve and spout at which water may be drawn from the mains
of waterworks; a water plug.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydranth</ent><br/
<hw>Hy"dranth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydra</ets> +
Gr. <?/ a flower.]</ety> <fld>(Zool.)</fld> <def>One of the nutritive
zooids of a hydroid colony. Also applied to the proboscis or manubrium
of a hydroid medusa. See <xex>Illust.</xex> of
<er>Hydroidea</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrargochloride</ent><br/
<hw>Hy*drar"go*chlo"ride</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydrarg</ets>yrum + <ets>chloride</ets>.]</ety>
<fld>(Chem.)</fld> <def>A compound of the bichloride of mercury with
another chloride.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrargyrate</ent><br/
<hw>Hy*drar"gy*rate</hw> <pr>(h<isl/*dr<aum/r"j<icr/*r<asl/t)</pr>,
<pos>a.</pos> <def>Of or pertaining to mercury; containing, or
impregnated with, mercury.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrargyrism</ent><br/
<hw>Hy*drar"gy*rism</hw> <pr>(h<isl/*dr<aum/r"j<icr/*r<icr/z'm)</pr>,
<pos>n.</pos> <fld>(Med.)</fld> <def>A diseased condition produced by
poisoning with hydrargyrum, or mercury; mercurialism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrargyrum</ent><br/
<hw>Hy*drar"gy*rum</hw> <pr>(h<isl/*dr<aum/r"j<icr/*r<ucr/m)</pr>,
<pos>n.</pos> <ety>[NL., fr. L. <ets>hydrargyrus</ets>, Gr.
<grk>"ydra`rgyros</grk>; <grk>"y`dwr</grk> water + <grk>'a`rgyros</grk>
silver.]</ety> <fld>(Chem.)</fld> <def>Quicksilver; mercury.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrarthrosis</ent><br/
\'d8<hw>Hy`drar*thro"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hydro-</er>, 1, and <er>Arthrosis</er>.]</ety> <fld>(Med.)</fld>
<def>An effusion of watery liquid into the cavity of a joint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrastine</ent><br/
<hw>Hy*dras"tine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>An alkaloid, found in the rootstock of the golden seal
(<spn>Hydrastis Canadensis</spn>), and extracted as a bitter, white,
crystalline substance. It is used as a tonic and febrifuge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydra-tainted</ent><br/
<hw>Hy"dra-taint`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dipped in the
gall of the fabulous hydra; poisonous; deadly.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrate</ent><br/
<hw>Hy"drate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`dwr</grk> water: cf. F. <ets>hydrate</ets>.]</ety>
<fld>(Chem.)</fld> <sd>(a)</sd> <def>A compound formed by the union of
water with some other substance, generally forming a neutral body, as
certain crystallized salts.</def> <sd>(b)</sd> <def>A substance which
does not contain water as such, but has its constituents (hydrogen,
oxygen, hydroxyl) so arranged that water may be eliminated; hence, a
derivative of, or compound with, hydroxyl; hydroxide; <as>as, ethyl
<ex>hydrate</ex>, or common alcohol; calcium <ex>hydrate</ex>, or slaked
lime.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrate</ent><br/
<hw>Hy"drate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hydrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hydrating</conjf> <pr>(?)</pr>.]</vmorph> <def>To form
into a hydrate; to combine with water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrated</ent><br/
<hw>Hy"dra*ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed into a
hydrate; combined with water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydration</ent><br/
<hw>Hy*dra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The act of becoming, or state of being, a hydrate.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Water of hydration</b></col> <fld>(Chem.)</fld>,
<cd>water chemically combined with some substance to form a hydrate; --
distinguished from <contr>water of
crystallization</contr>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydraulic</ent><br/
<hw>Hy*drau"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>hydraulique</ets>, L. <ets>hydraulicus</ets>, fr. Gr. <?/, <?/, a
water organ; <grk>"y`dwr</grk> water + <?/ flute, pipe. See
<er>Hydra</er>.]</ety> <def>Of or pertaining to hydraulics, or to fluids
in motion; conveying, or acting by, water; <as>as, an <ex>hydraulic</ex>
clock, crane, or dock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydraulic accumulator</b></col>, <cd>an accumulator for
hydraulic machinery of any kind. See <er>Accumulator</er>, 2.</cd> --
<col><b>Hydraulic brake</b></col>, <cd>a cataract. See
<er>Cataract</er>, 3.</cd> -- <col><b>Hydraulic cement</b></col>, <cd>a
cement or mortar made of hydraulic lime, which will harden under
water.</cd> -- <col><b>Hydraulic elevator</b></col>, <cd>a lift operated
by the weight or pressure of water.</cd> -- <col><b>Hydraulic
jack</b></col>. <cd>See under <er>Jack</er>.</cd> -- <col><b>Hydraulic
lime</b></col>, <cd>quicklime obtained from hydraulic limestone, and
used for cementing under water, etc.</cd> -- <col><b>Hydraulic
limestone</b></col>, <cd>a limestone which contains some clay, and which
yields a quicklime that will set, or form a firm, strong mass, under
water.</cd> -- <col><b>Hydraulic main</b></col> <fld>(Gas Works)</fld>,
<cd>a horizontal pipe containing water at the bottom into which the ends
of the pipes from the retorts dip, for passing the gas through water in
order to remove ammonia.</cd> -- <col><b>Hydraulic mining</b></col>,
<cd>a system of mining in which the force of a jet of water is used to
wash down a bank of gold-bearing gravel or earth.</cd> <mark>[Pacific
Coast]</mark> -- <col><b>Hydraulic press</b></col>, <cd>a hydrostatic
press. See under <er>Hydrostatic</er>.</cd> -- <col><b>Hydraulic
propeller</b></col>, <cd>a device for propelling ships by means of a
stream of water ejected under water rearward from the ship.</cd> --
<col><b>Hydraulic ram</b></col>, <cd>a machine for raising water by
means of the energy of the moving water of which a portion is to be
raised. When the rush of water through the main pipe <figref>d</figref>
shuts the valve at <figref>a</figref>, the momentum of the current thus
suddenly checked forces part of it into the air chamber
<figref>b</figref>, and up the pipe <figref>c</figref>, its return being
prevented by a valve at the entrance to the air chamber, while the
dropping of the valve <figref>a</figref> by its own weight allows
another rush through the main pipe, and so on alternately.</cd> --
<col><b>Hydraulic valve</b></col>. <fld>(Mach.)</fld> <sd>(a)</sd> <cd>A
valve for regulating the distribution of water in the cylinders of
hydraulic elevators, cranes, etc.</cd> <sd>(b)</sd> <fld>(Gas
Works)</fld> <cd>An inverted cup with a partition dipping into water,
for opening or closing communication between two gas mains, the open
ends of which protrude about the water.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydraulical</ent><br/
<hw>Hy*drau"lic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hydraulic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydraulicon</ent><br/
<hw>Hy*drau"li*con</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hydraulic</er>.]</ety> <fld>(Mus.)</fld> <def>An ancient musical
instrument played by the action of water; a water organ.</def>
<altsp>[Written also <asp>hydraulis</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydraulics</ent><br/
<hw>Hy*drau"lics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hydraulique</ets>.]</ety> <def>That branch of science, or of
engineering, which treats of fluids in motion, especially of water, its
action in rivers and canals, the works and machinery for conducting or
raising it, its use as a prime mover, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ As a science, hydraulics includes hydrodynamics, or the
principles of mechanics applicable to the motion of water; as a branch
of engineering, it consists in the practical application of the
mechanics of fluids to the control and management of water with
reference to the wants of man, including canals, waterworks, hydraulic
machines, pumps, water wheels, etc. Some writers treat hydraulics and
hydrostatics as subdivisions of hydrodynamics.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrazine</ent><br/
<hw>Hy"dra*zine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydr-</ets>
+ <ets>azo-</ets> + <ets>-ine</ets>.]</ety> <fld>(Chem.)</fld> <def>Any
one of a series of nitrogenous bases, resembling the amines and produced
by the reduction of certain nitroso and diazo compounds; <as>as, methyl
<ex>hydrazine</ex>, phenyl <ex>hydrazine</ex>, etc.</as> They are
derivatives of hydrazine proper, <chform>H2N.NH2</chform>, which is a
doubled amido group, recently (1887) isolated as a stable, colorless
gas, with a peculiar, irritating odor. As a base it forms distinct
salts. Called also <altname>diamide</altname>,
<altname>amidogen</altname>, (or more properly
<altname>diamidogen</altname>), etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrencephsloid</ent><br/
<hw>Hy"dren*ceph"s*loid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydrencephal</ets>us + <ets>-oid</ets>.]</ety>
<fld>(Med.)</fld> <def>Same as <er>Hydrocephaloid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydria</ent><br/
\'d8<hw>Hy"dri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <fld>(Gr. Antiq.)</fld> <def>A water jar; esp., one with a
large rounded body, a small neck, and three handles. Some of the most
beautiful Greek vases are of this form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydriad</ent><br/
<hw>Hy"dri*ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/, of
the water, fr. <grk>"y`dwr</grk> water.]</ety> <fld>(Myth.)</fld> <def>A
water nymph.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydric</ent><br/
<hw>Hy"dric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Hydrogen</er>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
containing, hydrogen; <as>as, <ex>hydric</ex> oxide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydric dioxide</b></col>. <fld>(Chem.)</fld> <cd>See
<cref>Hydrogen dioxide</cref>, under <er>Hydrogen</er>.</cd> --
<col><b>Hydric oxide</b></col> <fld>(Chem.)</fld>, <cd>water.</cd> --
<col><b>Hydric sulphate</b></col> <fld>(Chem.)</fld>, <cd>hydrogen
sulphate or sulphuric acid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydride</ent><br/
<hw>Hy"dride</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydr-</ets> +
<ets>ide</ets>.]</ety> <fld>(Chem.)</fld> <def>A compound of the binary
type, in which hydrogen is united with some other element.</def><--
spec., with a more electropositive element --></p>

<p><cs><col><b>lith"i*um hy"dride</b></col> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <cd>A hydride of lithium, <chform>LiH</chform>,
commonly used as a powerful reducing agent in organic
chemistry.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Hydriform</ent><br/
<hw>Hy"dri*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hydra</ets>
+ <ets>-form</ets>.]</ety> <fld>(Zool.)</fld> <def>Having the form or
structure of a hydra.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrina</ent><br/
\'d8<hw>Hy*dri"na</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Hydra</er>.]</ety> <fld>(Zool.)</fld> <def>The group of hydroids to
which the fresh-water hydras belong.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydriodate</ent><br/
<hw>Hy*dri"o*date</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hydriodate</ets>.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Hydriodide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydriodic</ent><br/
<hw>Hy`dri*od"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hydr-</ets>
+ <ets>iodic</ets>: cf. F. <ets>hydriodique</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or derived from, hydrogen and
iodine; -- said of an acid (<chform>HI</chform>) produced by the
combination of these elements.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydriodic acid</b></col> <fld>(Chem.)</fld>, <cd>a
pungent, colorless gas, <chform>HI</chform>, usually prepared as a
solution in water. It is strong reducing agent. Called also
<altname>hydrogen iodide</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydriodide</ent><br/
<hw>Hy*dri"o*dide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A compound of hydriodic acid with a base; -- distinguished from an
<contr>iodide</contr>, in which only the iodine combines with the
base.</def></p>

<p><ent>Hydro</ent><br/
<hw>Hy"dro</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
hydro-a<eum/roplane.</def> <mark>[obsolescent]</mark> <br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>hydroelectric power; -- also used
attributively.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hydr-</ent><br/
<ent>Hydro-</ent><br/
<mhw>{ <hw>Hy"dro-</hw> <pr>(?)</pr>, <hw>Hy"dr-</hw>. }</mhw>
<sn>1.</sn> <def>A combining form from Gr. <?/, <?/, water (see
<er>Hydra</er>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A combining form of
<xex>hydrogen</xex>, indicating <xex>hydrogen as an ingredient</xex>,
<as>as <ex>hydro</ex>chloric; or a <ex>reduction product obtained by
hydrogen</ex>, as <ex>hydro</ex>quinone.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydro-aeroplane</ent><br/
<hw>Hy"dro-a"<eum/r*o*plane`</hw>. <fld>(A<eum/ronautics)</fld> <def>An
a<eum/roplane with a boatlike or other understructure that enables it to
travel on, or to rise from the surface of, a body of water by its own
motive power; -- now usually referred to as a
<altname>seaplane</altname>.</def> <mark>[obsolescent]</mark> <br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Hydrobarometer</ent><br/
<hw>Hy`dro*ba*rom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>barometer</ets>.]</ety> <def>An
instrument for determining the depth of the sea water by its
pressure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrobiplane</ent><br/
<hw>Hy"dro*bi"plane</hw>, <pos>n.</pos> <def>A hydro-a<eum/roplane
having two supporting planes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hydrobilirubin</ent><br/
<hw>Hy`dro*bil`i*ru"bin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>bilirubin</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A body formed from bilirubin, identical with
urobilin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrobranchiata</ent><br/
\'d8<hw>Hy`dro*bran`chi*a"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"y`dwr</grk> water + <?/ gills.]</ety>
<fld>(Zool.)</fld> <def>An extensive artificial division of gastropod
mollusks, including those that breathe by gills, as contrasted with the
Pulmonifera.</def> -- <wordforms><wf>Hy`dro*bran"chi*ate</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrobromate</ent><br/
<hw>Hy`dro*bro"mate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Same as <er>Hydrobromide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrobromic</ent><br/
<hw>Hy`dro*bro"mic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>bromic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Composed of hydrogen and bromine; <as>as,
<ex>hydrobromic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrobromic acid</b></col> <fld>(Chem.)</fld>, <cd>a
colorless, pungent, corrosive gas, <chform>HBr</chform>, usually
collected as a solution in water. It resembles hydrochloric acid, but is
weaker and less stable. Called also <altname>hydrogen
bromide</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrobromide</ent><br/
<hw>Hy`dro*bro"mide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A compound of hydrobromic acid with a base; -- distinguished from a
<xex>bromide</xex>, in which only the bromine unites with the
base.</def><-- analogous to hydrochloride or hydriodide --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocarbon</ent><br/
<hw>Hy`dro*car"bon</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>carbon</ets>.]</ety>
<fld>(Chem.)</fld> <def>A compound containing only hydrogen and carbon,
as methane, benzene, etc.; also, by extension, any of their
derivatives.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Hydrocarbon burner</b></col>,
<col><b>furnace</b></col>, <col><b>stove</b></col></mcol>, <cd>a burner,
furnace, or stove with which liquid fuel, as petroleum, is
used.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocarbonaceous</ent><br/
<hw>Hy`dro*car`bo*na"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of the
nature, or containing, hydrocarbons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocarbonate</ent><br/
<hw>Hy`dro*car"bon*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd>
<fld>(Old Chem.)</fld> <def>A hydrocarbon.</def> <mark>[Obs.]</mark>
<sd>(b)</sd> <fld>(Chem.)</fld> <def>A hydrous carbonate, as
malachite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocarbostyril</ent><br/
<hw>Hy`dro*car`bo*sty"ril</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>carbostyril</ets>.]</ety>
<fld>(Chem.)</fld> <def>A white, crystalline, nitrogenous hydrocarbon,
<chform>C9H9NO</chform>, obtained from certain derivatives of cinnamic
acid and closely related to quinoline and carbostyril.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocarburet</ent><br/
<hw>Hy`dro*car"bu*ret</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>carburet</ets>.]</ety>
<fld>(Chem.)</fld> <def>Carbureted hydrogen; also, a hydrocarbon.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocaulus</ent><br/
<hw>Hy`dro*cau"lus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hydrocauli</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>"y`dwr</grk> water + <?/ a stalk.]</ety> <fld>(Zool.)</fld>
<def>The hollow stem of a hydroid, either simple or branched. See
<xex>Illust.</xex> of <er>Gymnoblastea</er> and
<er>Hydroidea</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocele</ent><br/
<hw>Hy`dro*cele</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/;
<grk>"y`dwr</grk> water + <?/ tumor.]</ety> <fld>(Med.)</fld> <def>A
collection of serous fluid in the areolar texture of the scrotum or in
the coverings, especially in the serous sac, investing the testicle or
the spermatic cord; dropsy of the testicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocephalic</ent><br/
<hw>Hy`dro*ce*phal"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to,
or connected with, hydrocephalus, or dropsy of the brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocephaloid</ent><br/
<hw>Hy`dro*ceph"a*loid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydrocephalus</ets> + <ets>-oid</ets>.]</ety>
<fld>(Med.)</fld> <def>Resembling hydrocephalus.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrocephaloid affection</b></col> <fld>(Med.)</fld>,
<cd>the group of symptoms which follow exhausting diarrhea in young
children, resembling those of acute hydrocephalus, or tubercular
meningitis.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocephalous</ent><br/
<hw>Hy`dro*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
hydrocephalus.</def> <ldquo/<xex>Hydrocephalous</xex> offspring.<rdquo/
<rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocephalus</ent><br/
<hw>Hy`dro*ceph"a*lus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ hydrocephalus; <grk>"y`dwr</grk> water + <?/ head.]</ety>
<fld>(Med.)</fld> <def>An accumulation of liquid within the cavity of
the cranium, especially within the ventricles of the brain; dropsy of
the brain. It is due usually to tubercular meningitis. When it occurs in
infancy, it often enlarges the head enormously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrochlorate</ent><br/
<hw>Hy`dro*chlo"rate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Same as <er>Hydrochloride</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrochloric</ent><br/
<hw>Hy`dro*chlo"ric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>chloric</ets>: cf. F.
<ets>hydrochlorique</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to,
or compounded of, chlorine and hydrogen gas; <as>as,
<ex>hydrochloric</ex> acid</as>; chlorhydric.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrochloric acid</b></col> <fld>(Chem.)</fld>,
<cd>hydrogen chloride; a colorless, corrosive gas, <chform>HCl</chform>,
of pungent, suffocating odor. It is made in great quantities in the soda
process, by the action of sulphuric acid on common salt. It has a great
affinity for water, and the commercial article is a strong solution of
the gas in water. It is a typical acid, and is an indispensable agent in
commercial and general chemical work. Called also <altname>muriatic
acid</altname> and <altname>chlorhydric acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrochloride</ent><br/
<hw>Hy`dro*chlo"ride</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A compound of hydrochloric acid with a base; -- distinguished from
a <xex>chloride</xex>, where only chlorine unites with the
base.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocorallia</ent><br/
\'d8<hw>Hy`dro*co*ral"li*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Hydra</er>, and <er>Coral</er>.]</ety>
<fld>(Zool.)</fld> <def>A division of Hydroidea, including those genera
that secrete a stony coral, as <xex>Millepora</xex> and
<xex>Stylaster</xex>. Two forms of zooids in life project from small
pores in the coral and resemble those of other hydroids. See
<er>Millepora</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocyanate</ent><br/
<hw>Hy`dro*cy"a*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Hydrocyanide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocyanic</ent><br/
<hw>Hy`dro*cy*an"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>anic</ets>: cf. F.
<ets>hydrocyanique</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to,
or derived from the combination of, hydrogen and cyanogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrocyanic acid</b></col> <fld>(Chem.)</fld>, <cd>a
colorless, mobile, volatile liquid, <chform>HCN</chform>, having a
characteristic peach-blossom odor. It is one of the most deadly poisons.
It is made by the action of sulphuric acid on yellow prussiate of
potassium (potassium ferrocyanide), and chemically resembles
hydrochloric and hydrobromic acids. Called also <altname>prussic
acid</altname>, <altname>hydrogen cyanide</altname>, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrocyanide</ent><br/
<hw>Hy`dro*cy"a*nide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A compound of hydrocyanic acid with a base; -- distinguished from a
<contr>cyanide</contr>, in which only the cyanogen so
combines.</def></p>

<p><ent>Hydrodynamical</ent><br/
<ent>Hydrodynamic</ent><br/
<mhw>{ <hw>Hy`dro*dy*nam"ic</hw> <pr>(?)</pr>,
<hw>Hy`dro*dy*nam"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>dynamic</ets>, <ets>-ical</ets>: cf.
F. <ets>hydrodynamique</ets>.]</ety> <def>Pertaining to, or derived
from, the dynamical action of water of a liquid; of or pertaining to
water power.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrodynamic friction</b></col>, <cd>friction produced by
the viscosity of a liquid in motion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrodynamics</ent><br/
<hw>Hy`dro*dy*nam"ics</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>dynamics</ets>: cf. F.
<ets>hydrodynamique</ets>.]</ety> <def>That branch of the science of
mechanics which relates to fluids, or, as usually limited, which treats
of the laws of motion and action of nonelastic fluids, whether as
investigated mathematically, or by observation and experiment; the
principles of dynamics, as applied to water and other fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is sometimes used as a general term, including
both hydrostatics and hydraulics, together with pneumatics and
acoustics. See <er>Hydraulics</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrodynamometer</ent><br/
<hw>Hy`dro*dy`na*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>dynamometer</ets>.]</ety> <def>An
instrument to measure the velocity of a liquid current by the force of
its impact.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydro-electric</ent><br/
<hw>Hy`dro-e*lec"tric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>electric</ets>.]</ety> <def>Pertaining
to, employed in, or produced by, the evolution of electricity by means
of a battery in which water or steam is used.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydro-electric machine</b></col> <fld>(Physics)</fld>,
<cd>an apparatus invented by <person>Sir William Armstrong</person> of
England for generating electricity by the escape of high-pressure steam
from a series of jets connected with a strong boiler, in which the steam
is produced.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydro-extractor</ent><br/
<hw>Hy`dro-ex*tract"or</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>extractor</ets>.]</ety> <def>An
apparatus for drying anything, as yarn, cloth, sugar, etc., by
centrifugal force; a centrifugal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroferricyanic</ent><br/
<hw>Hy`dro*fer`ri*cy*an"ic</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>ferricyanic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or containing, or obtained from,
hydrogen, ferric iron, and cyanogen; <as>as, <ex>hydroferricyanic</ex>
acid</as>. See <er>Ferricyanic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroferrocyanic</ent><br/
<hw>Hy`dro*fer`ro*cy*an"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>ferrocyanic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or containing, or obtained from,
hydrogen, ferrous iron, and cyanogen; <as>as, <ex>hydroferrocyanic</ex>
acid</as>. See <er>Ferrocyanic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrofluate</ent><br/
<hw>Hy`dro*flu"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A supposed compound of hydrofluoris acid and a base; a
fluoride.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrofluoric</ent><br/
<hw>Hy`dro*flu*or"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>fluoric</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or containing, hydrogen and
fluorine; fluohydric; <as>as, <ex>hydrofluoric</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrofluoric acid</b></col> <fld>(Chem.)</fld>, <cd>a
colorless, mobile, volatile liquid, <chform>HF</chform>, very corrosive
in its action, and having a strong, pungent, suffocating odor. It is
produced by the action of sulphuric acid on fluorite, and is usually
collected as a solution in water. It attacks all silicates, as glass or
porcelain, is the agent employed in etching glass, and is preserved only
in vessels of platinum, lead, caoutchouc, or gutta-percha.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 717 --></p>

<p><ent>Hydrofluosilicate</ent><br/
<hw>Hy`dro*flu`o*sil"i*cate</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A salt of hydrofluosilic acid; a silicofluoride.
See <er>Silicofluoride</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrofluosilicic</ent><br/
<hw>Hy`dro*flu`o*si*lic"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>fluo</ets>rine +
<ets>silicic</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
denoting, a compound consisting of a double fluoride of hydrogen and
silicon; silicofluoric. See <er>Silicofluoric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogalvanic</ent><br/
<hw>Hy`dro*gal*van"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>galvanic</ets>.]</ety> <def>Pertaining
to, produced by, or consisting of, electricity evolved by the action or
use of fluids; <as>as, <ex>hydrogalvanic</ex> currents</as>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogen</ent><br/
<hw>Hy"dro*gen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydro-</ets>,
1 + <ets>-gen</ets>: cf. F. <ets>hydrog<egrave/ne</ets>. So called
because water is generated by its combustion. See <er>Hydra</er>.]</ety>
<fld>(Chem.)</fld> <def>A gaseous element, colorless, tasteless, and
odorless, the lightest known substance, being fourteen and a half times
lighter than air (hence its use in filling balloons), and over eleven
thousand times lighter than water. It is very abundant, being an
ingredient of water and of many other substances, especially those of
animal or vegetable origin. It may by produced in many ways, but is
chiefly obtained by the action of acids (as sulphuric) on metals, as
zinc, iron, etc. It is very inflammable, and is an ingredient of coal
gas and water gas. It is standard of chemical equivalents or combining
weights, and also of valence, being the typical monad. Symbol H. Atomic
weight 1.</def><-- At. wt. = 1.008 using carbon as 12.000 --><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Although a gas, hydrogen is chemically similar to the
metals in its nature, having the properties of a weak base. It is, in
all acids, the base which is replaced by metals and basic radicals to
form salts. Like all other gases, it is condensed by great cold and
pressure to a liquid which freezes and solidifies by its own
evaporation. It is absorbed in large quantities by certain metals (esp.
palladium), forming alloy-like compounds; hence, in view of
quasi-metallic nature, it is sometimes called
<altname>hydrogenium</altname>. It is the typical reducing agent, as
opposed to oxidizers, as oxygen, chlorine, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bicarbureted hydrogen</b></col>, <cd>an old name for
ethylene.</cd> -- <col><b>Carbureted hydrogen gas</b></col>. <cd>See
under <er>Carbureted</er>.</cd> -- <col><b>Hydrogen dioxide</b></col>,
<cd>a thick, colorless liquid, <chform>H2O2</chform>, resembling water,
but having a bitter, sour taste, produced by the action of acids on
barium peroxide. It decomposes into water and oxygen, and is
manufactured in large quantities for an oxidizing and bleaching agent.
Called also <altname>oxygenated water</altname>.<-- usually "hydrogen
peroxide", or "peroxide" in weak solutions used as an antiseptic
--></cd> -- <col><b>Hydrogen oxide</b></col>, <cd>a chemical name for
water, H2O.</cd> -- <col><b>Hydrogen sulphide</b></col>, <cd>a colorless
inflammable gas, <chform>H2S</chform>, having the characteristic odor of
bad eggs, and found in many mineral springs. It is produced by the
action of acids on metallic sulphides, and is an important chemical
reagent. Called also <altname>sulphureted
hydrogen</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogenate</ent><br/
<hw>Hy"dro*gen*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hydrogenated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Hydrogenating</conjf>
<pr>(?)</pr>.]</vmorph> <fld>(Chem.)</fld> <def>To
hydrogenize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogenation</ent><br/
<hw>Hy`dro*gen*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The act of combining with hydrogen, or the state
of being so combined.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogenide</ent><br/
<hw>Hy"dro*gen*ide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A binary compound containing hydrogen; a hydride. <mark>[R.]</mark>
See <er>Hydride</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogenium</ent><br/
<hw>Hy`dro*ge"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hydrogen</er>.]</ety> <fld>(Chem.)</fld> <def>Hydrogen; -- called
also in view of its supposed metallic nature.</def>
<rj><au>Graham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogenize</ent><br/
<hw>Hy"dro*gen*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hydrogenized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Hydrogenizing</conjf>
<pr>(?)</pr>.]</vmorph> <fld>(Chem.)</fld> <def>To combine with
hydrogen; to treat with, or subject to the action of, hydrogen; to
reduce; -- contrasted with <xex>oxidize</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogenous</ent><br/
<hw>Hy*drog"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to hydrogen; containing hydrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrognosy</ent><br/
<hw>Hy*drog"no*sy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ knowledge.]</ety> <def>A treatise
upon, or a history and description of, the water of the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrogode</ent><br/
<hw>Hy"drog*ode</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydrog</ets>en + Gr. <?/ way. path.]</ety> <fld>(Elec.)</fld>
<def>The negative pole or cathode.</def> <mark>[Obs. & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrographer</ent><br/
<hw>Hy*drog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled in
the hydrography; one who surveys, or draws maps or charts of, the sea,
lakes, or other waters, with the adjacent shores; one who describes the
sea or other waters.</def> <rj><au>Boyle.</au></rj></p>

<p><ent>Hydrographical</ent><br/
<ent>Hydrographic</ent><br/
<mhw>{ <hw>Hy`dro*graph"ic</hw> <pr>(?)</pr>,
<hw>Hy`dro*graph"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of
or relating to hydrography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrography</ent><br/
<hw>Hy*drog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>-graphy</ets>: cf. F.
<ets>hydrographie</ets>.]</ety> <sn>1.</sn> <def>The art of measuring
and describing the sea, lakes, rivers, and other waters, with their
phenomena.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That branch of surveying which embraces the
determination of the contour of the bottom of a harbor or other sheet of
water, the depth of soundings, the position of channels and shoals, with
the construction of charts exhibiting these particulars.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroguret</ent><br/
<hw>Hy*drog"u*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Hydrogen</er>.]</ety> <fld>(Chem.)</fld> <def>A hydride.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroid</ent><br/
<hw>Hy"droid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hydra</ets> +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Related to, or
resembling, the hydra; of or pertaining to the Hydroidea.</def> --
<def2><pos>n.</pos> <def>One of the Hydroideas.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroidea</ent><br/
\'d8<hw>Hy*droi"de*a</hw>, <pos>n. pl.</pos> <ety>[NL. See
<er>Hydra</er>, and <er>-oid</er>.]</ety> <fld>(Zool.)</fld> <def>An
extensive order of Hydrozoa or Acaleph<ae/.</def> <altsp>[Written also
<asp>Hydroida</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This order includes the hydras and the free-swimming
hydromedus<ae/, together with a great variety of marine attached
hydroids, many of which grow up into large, elegantly branched forms,
consisting of a vast number of zooids (hydranths, gonophores, etc.),
united by hollow stems. All the zooids of a colony are produced from one
primary zooid, by successive buddings. The Siphonophora have also been
included in this order by some writers. See <er>Gymnoblastea</er>,
<er>Hydromedusa</er>, <er>Gonosome</er>, <er>Gonotheca</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrokinetic</ent><br/
<hw>Hy`dro*ki*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>kinetic</ets>.]</ety> <def>Of or
pertaining to the motions of fluids, or the forces which produce or
affect such motions; -- opposed to <contr>hydrostatic</contr>.</def>
<rj><au>Sir W. Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrolase</ent><br/
<hw>Hy"dro*lase</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydrol</ets>ysis + <ets>-ase</ets>.]</ety> <sn>1.</sn>
<fld>(Chem.)</fld> <def>an enzyme which causes the splitting of a
chemical bond with the addition of the elements of water; a hydrolytic
enzyme. Formerly called a <altname>hydrolytic ferment</altname>.</def>
<note>There are many known <ex>hydrolases</ex>, including nearly all of
the digestive enzymes. Among the <ex>hydrolases</ex> are the
<stype>esterases</stype>, which split ester bonds and
<stype>amidases</stype>, which split amide bonds, and among the latter
are the <stype>proteases</stype> and <stype>peptidases</stype>, which
split peptide bonds, such as those found in proteins.</note><br/
[<source>PJC</source>]</p>

<p><ent>Hydrological</ent><br/
<hw>Hy`dro*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to hydrology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrologist</ent><br/
<hw>Hy*drol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled in
hydrology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrology</ent><br/
<hw>Hy*drol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>-logy</ets>: cf. F.
<ets>hydrologie</ets>.]</ety> <def>The science of water, its properties,
phenomena, and distribution over the earth's surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrolysis</ent><br/
<hw>Hy*drol"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>-lysis</ets>.]</ety>
<fld>(Chem.)</fld> <def>A chemical process causing the splitting of a
chemical bond by the addition of the elements of water. <as>Where the
bond which is split is not part of a ring structure, this process causes
formation of two compounds from one compound plus water, as in the
<ex>hydrolysis</ex> of the ester bonds of fats during
<stype>saponification</stype></as>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Hydrolytic</ent><br/
<hw>Hy`dro*lyt"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ to loose.]</ety> <sn>1.</sn>
<fld>(Chem.)</fld> <def>Tending to remove or separate water; eliminating
water.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>of, pertaining to, or accompanied
by <er>hydrolysis</er>.</def><br/
[<source>PJC</source>]</p>

<p><q><qex>Hydrolytic</qex> agents, such as sulphuric acid or caustic
alkali.</q> <rj><qau>Encyc. Brit.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrolytic ferment</b></col> <fld>(Physiol. Chem.)</fld>,
<cd>an enzyme (formerly referred to as a <it>ferment</it>), which acts
only in the presence of water, and which causes the substance acted upon
to take up a molecule of water, resulting in the splitting of a chemical
bond and often splitting one compound into two. Thus, diastase of malt,
ptyalin of saliva, and boiling dilute sulphuric acid all convert starch
by hydration into dextrin and sugar. Nearly all of the digestive enzymes
are hydrolytic in their action. Since 1910 such an enzyme is usually
referred to as a <altname><er>hydrolase</er></altname> or
<altname><er>hydrolytic enzyme</er></altname>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hydromagnesite</ent><br/
<hw>Hy`dro*mag"ne*site</hw>
<pr>(h<imac/`dr<osl/*m<acr/g"n<esl/*s<imac/t)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>magnesite</ets>.]</ety>
<fld>(Min.)</fld> <def>A hydrous carbonate of magnesia occurring in
white, earthy, amorphous masses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromancy</ent><br/
<hw>Hy"dro*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>-mancy</ets>: cf. F.
<ets>hydromancie</ets>.]</ety> <def>Divination by means of water, --
practiced by the ancients.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromantic</ent><br/
<hw>Hy`dro*man"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hydromantique</ets>.]</ety> <def>Of or pertaining to divination by
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromechanics</ent><br/
<hw>Hy`dro*me*chan"ics</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>mechanics</ets>.]</ety> <def>That
branch of physics which treats of the mechanics of liquids, or of their
laws of equilibrium and of motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromedusa</ent><br/
\'d8<hw>Hy`dro*me*du"sa</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hydromedus<ae/</plw> <pr>(#)</pr>.</plu>
<ety>[NL. See <er>Hydra</er>, and <er>Medusa</er>.]</ety>
<fld>(Zool.)</fld> <def>Any medusa or jellyfish which is produced by
budding from a hydroid. They are called also
<altname>Craspedota</altname>, and <altname>naked-eyed
medus<ae/</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Such medus<ae/ are the reproductive zooids or
gonophores, either male or female, of the hydroid from which they arise,
whether they become free or remain attached to the hydroid colony. They
in turn produce the eggs from which the hydroids are developed. The name
is also applied to other similar medus<ae/ which are not known to bud
from a hydroid colony, and even to some which are known to develop
directly from the eggs, but which in structure agree essentially with
those produced from hydroids. See <er>Hydroidea</er>, and
<er>Gymnoblastea</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromel</ent><br/
<hw>Hy"dro*mel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hydromel</ets>, <ets>hydromeli</ets>, Gr. <?/; <grk>"y`dwr</grk>
water + <?/ honey: cf. F. <ets>hydromel</ets>.]</ety> <def>A liquor
consisting of honey diluted in water, and after fermentation called
<xex>mead</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromellonic</ent><br/
<hw>Hy`dro*mel*lon"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Cyamellone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometallurgical</ent><br/
<hw>Hy`dro*met`al*lur"gic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to hydrometallurgy; involving the use of liquid reagents in
the treatment or reduction of ores.</def> --
<wordforms><wf>Hy`dro*met`al*lur"gic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometallurgy</ent><br/
<hw>Hy`dro*met"al*lur`gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>metallurgy</ets>.]</ety> <def>The art
or process of assaying or reducing ores by means of liquid
reagents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometeor</ent><br/
<hw>Hy`dro*me"te*or</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>meteor</ets>.]</ety> <def>A meteor or
atmospheric phenomenon dependent upon the vapor of water; -- in the
<pluf>pl.</pluf>, a general term for the whole aqueous phenomena of the
atmosphere, as rain, snow, hail, etc.</def>
<rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometeorological</ent><br/
<hw>Hy`dro*me`te*or`o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of
or pertaining to hydrometeorology, or to rain, clouds, storms,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometeorology</ent><br/
<hw>Hy`dro*me`te*or*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>meteorology</ets>.]</ety> <def>That
branch of meteorology which relates to, or treats of, water in the
atmosphere, or its phenomena, as rain, clouds, snow, hail, storms,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometer</ent><br/
<hw>Hy*drom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>-meter</ets>: cf. F.
<ets>hydrom<egrave/tre</ets>.]</ety> <sn>1.</sn> <fld>(Physics)</fld>
<def>An instrument for determining the specific gravities of liquids,
and thence the strength spirituous liquors, saline solutions,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is usually made of glass with a graduated stem, and
indicates the specific gravity of a liquid by the depth to which it
sinks in it, the zero of the scale marking the depth to which it sinks
in pure water. Extra weights are sometimes used to adapt the scale to
liquids of different densities.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instrument, variously constructed, used for
measuring the velocity or discharge of water, as in rivers, from
reservoirs, etc., and called by various specific names according to its
construction or use, as <altname>tachometer</altname>,
<altname>rheometer</altname>, <altname>hydrometer</altname>,
<altname>pendulum</altname>, etc.; a current gauge.</def></p>

<p><ent>Hydrometrical</ent><br/
<ent>Hydrometric</ent><br/
<mhw>{ <hw>Hy`dro*met"ric</hw> <pr>(?)</pr>, <hw>Hy`dro*met"ric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>hydrom<egrave/trique</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to an hydrometer, or to the determination of the specific
gravity of fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to measurement of the velocity,
discharge, etc., of running water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Made by means of an hydrometer; <as>as,
<ex>hydrometric</ex> observations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrometric pendulum</b></col>, <cd>a species of
hydrometer consisting of a hollow ball of ivory or metal suspended by a
treated from the center of a graduated quadrant, and held in a stream to
measure the velocity of the water by the inclination given to the
thread; a kind of current gauge.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometrograph</ent><br/
<hw>Hy`dro*met"ro*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ measure + <ets>-graph</ets>.]</ety>
<def>An instrument for determining and recording the quantity of water
discharged from a pipe, orifice, etc., in a given time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrometry</ent><br/
<hw>Hy*drom"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hydrom<egrave/trique</ets>.]</ety> <sn>1.</sn> <def>The art of
determining the specific gravity of liquids, and thence the strength of
spirituous liquors, saline solutions, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The art or operation of measuring the velocity or
discharge of running water, as in rivers, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydromica</ent><br/
<hw>Hy`dro*mi"ca</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>mica</ets>.]</ety> <fld>(Min.)</fld>
<def>A variety of potash mica containing water. It is less elastic than
ordinary muscovite.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydromica schist</b></col> <fld>(Min.)</fld>, <cd>a mica
schist characterized by the presence of hydromica. It often has a silky
luster and almost soapy feel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydronephrosis</ent><br/
\'d8<hw>Hy`dro*ne*phro"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
Gr. <grk>"y`dwr</grk> water + <?/ a kidney.]</ety> <fld>(Med.)</fld>
<def>An accumulation of urine in the pelvis of the kidney, occasioned by
obstruction in the urinary passages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropath</ent><br/
<hw>Hy"dro*path</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hydropathe</ets>.]</ety> <def>A hydropathist.</def></p>

<p><ent>Hydropathical</ent><br/
<ent>Hydropathic</ent><br/
<mhw>{ <hw>Hy`dro*path"ic</hw> <pr>(?)</pr>, <hw>Hy`dro*path"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to
hydropathy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropathist</ent><br/
<hw>Hy*drop"a*thist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
practices hydropathy; a water-cure doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropathy</ent><br/
<hw>Hy*drop"a*thy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/, <?/, to suffer.]</ety> <def>The
water cure; a mode of treating diseases by the copious and frequent use
of pure water, both internally and externally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroperitoneum</ent><br/
\'d8<hw>Hy`dro*per`i*to*ne"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
See <er>Hydro-</er>, and <er>Peritoneum</er>.]</ety> <fld>(Med.)</fld>
<def>Same as <er>Ascites</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophane</ent><br/
<hw>Hy"dro*phane</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ to show, appear: cf. F.
<ets>hydrophane</ets>.]</ety> <fld>(Min.)</fld> <def>A semitranslucent
variety of opal that becomes translucent or transparent on immersion in
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophanous</ent><br/
<hw>Hy*droph"a*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Min.)</fld>
<def>Made transparent by immersion in water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophid</ent><br/
<hw>Hy"dro*phid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ a small serpent.]</ety>
<fld>(Zool.)</fld> <def>Any sea snake of the genus <gen>Hydrophys</gen>
and allied genera. These snakes are venomous, live upon fishes, and have
a flattened tail for swimming.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophlorone</ent><br/
<hw>Hy`dro*phlo"rone</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>phlorone</ets>.]</ety>
<fld>(Chem.)</fld> <def>A white, crystalline benzene derivative,
<chform>C8H10O2</chform>, obtained by the reduction of
phlorone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophobia</ent><br/
<hw>Hy`dro*pho"bi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/; <grk>"y`dwr</grk> water + <?/ fear: cf. F.
<ets>hydrophobie</ets>.]</ety> <fld>(Med.)</fld> <sd>(a)</sd> <def>An
abnormal dread of water, said to be a symptom of canine madness;
hence:</def> <sd>(b)</sd> <def>A viral disease transmitted by a bite
from, or inoculation with the saliva of, a rabid creature, of which the
chief symptoms are, a sense of dryness and constriction in the throat,
causing difficulty in deglutition, and a marked heightening of reflex
excitability, producing convulsions whenever the patient attempts to
swallow, or is disturbed in any way, as by the sight or sound of water;
rabies; canine madness.</def> <altsp>[Written also
<asp>hydrophoby</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophobic</ent><br/
<hw>Hy`dro*phob"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hydrophobicus</ets>, Gr. <?/: cf. F.
<ets>hydrophobique</ets>.]</ety> <def>Of or pertaining to hydrophobia;
producing or caused by rabies; <as>as, <ex>hydrophobic</ex> symptoms;
the <ex>hydrophobic</ex> poison.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophoby</ent><br/
<hw>Hy"dro*pho`by</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hydrophobia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophora</ent><br/
\'d8<hw>Hy*droph"o*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. E. <ets>hydra</ets> + Gr. <grk>fe`rein</grk> to bear.]</ety>
<fld>(Zool.)</fld> <def>The Hydroidea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophore</ent><br/
<hw>Hy"dro*phore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`dwr</grk> water + <grk>fe`rein</grk> to bear.]</ety> <def>An
instrument used for the purpose of obtaining specimens of water from any
desired depth, as in a river, a lake, or the ocean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophyllium</ent><br/
\'d8<hw>Hy`dro*phyl"li*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hydrophyllia</plw> <pr>(#)</pr>, E.
<plw>Hydrophylliums</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>"y`dwr</grk> water + <?/ a leaf.]</ety> <fld>(Zool.)</fld> <def>One
of the flat, leaflike, protective zooids, covering other zooids of
certain Siphonophora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophyte</ent><br/
<hw>Hy"dro*phyte</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ + <?/
plant: cf. F. <ets>hydrophyte</ets>.]</ety> <def>An aquatic plant; an
alga.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrophytology</ent><br/
<hw>Hy*droph`y*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets> + <ets>phyte</ets> + <ets>-logy</ets>.]</ety>
<def>The branch of botany which treats of water plants.</def></p>

<p><ent>Hydropical</ent><br/
<ent>Hydropic</ent><br/
<mhw>{ <hw>Hy*drop"ic</hw> <pr>(?)</pr>, <hw>Hy*drop"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hydropicus</ets>, Gr.
<?/: cf. F. <ets>hydropique</ets>. See <er>Dropsy</er>.]</ety>
<def>Dropsical, or resembling dropsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every lust is a kind of <qex>hydropic</qex> distemper, and the
more we drink the more we shall thirst.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropically</ent><br/
<hw>Hy*drop"ic*al*ly</hw>, <pos>adv.</pos> <def>In a hydropical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropiper</ent><br/
\'d8<hw>Hy"dro*pi`per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"y`dwr</grk> water + L. <ets>piper</ets> a pepper.]</ety>
<fld>(Bot.)</fld> <def>A species (<spn>Polygonum Hydropiper</spn>) of
knotweed with acrid foliage; water pepper; smartweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroplane</ent><br/
<hw>Hy"dro*plane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hydro-</ets>, 1 + <ets>plane</ets>.]</ety> <sn>1.</sn> <def>A
plane, or any of a number of planes, projecting from the hull of a
submarine boat, which by being elevated or depressed cause the boat,
when going ahead, to sink or rise, after the manner of an
a<eum/roplane.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A projecting plane or fin on a hydroplane{3} to lift
the moving boat on top of the water; also, a gliding boat.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>a powered surface boat fitted with planes
(hydroplanes{2}) projecting below the hull, designed to lift the boat,
when moving rapidly, so that the hull itself is lifted out of the water
and the boat is supported by the hydrodynamic forces of the water on the
hydroplanes{2}, thus permitting higher speeds; formerly called a
<altname>gliding boat</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Hydroplane</ent><br/
<hw>Hy"dro*plane</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>Of a boat, to
move through water while supported by hydroplanes{3} (see
<er>hydroplane{3}</er>, above).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>to move through a body of water supported by the
hydrodynamic forces on a surface, similar in principle to a
<er>hydroplane{3}</er>; -- said, e. .g, of automobiles skidding on a
shallow patch of water on a road when moving at high speed, thus causing
the tires to lose contact with the road surface.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hydropneumatic</ent><br/
<hw>Hy`dro*pneu*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>pneumatic</ets>: cf. F.
<ets>hydropneumatique</ets>.]</ety> <def>Pertaining to, or depending
upon, both liquid and gaseous substances; <as>as,
<ex>hydropneumatic</ex> apparatus for collecting gases over water or
other liquids</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropneumatic gun carriage</ent><br/
<hw>Hy`dro*pneu*mat"ic gun carriage</hw>. <fld>(Ordnance)</fld> <def>A
disappearing gun carriage in which the recoil is checked by cylinders
containing liquid and air, the air when compressed furnishing the power
for restoring the gun to the firing position. It is used with some
English and European heavy guns.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hydropsy</ent><br/
<hw>Hy"drop`sy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dropsy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydropult</ent><br/
<hw>Hy"dro*pult</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ to hurl.]</ety> <def>A machine for
throwing water by hand power, as a garden engine, a fire extinguisher,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroquinone</ent><br/
<hw>Hy`dro*qui"none</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>quinone</ets>.]</ety>
<fld>(Chem.)</fld> <def>A white crystalline substance,
<chform>C6H4(OH)2</chform>, obtained by the reduction of quinone. It is
a diacid phenol, resembling, and metameric with, pyrocatechin and
resorcin. Called also <altname>dihydroxy benzene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrorhiza</ent><br/
\'d8<hw>Hy`dro*rhi"za</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hydrorhiz<ae/</plw> <pr>(#)</pr>, E.
<plw>Hydrorhizas</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. E.
<ets>hydra</ets> + Gr. <?/ a root.]</ety> <fld>(Zool.)</fld> <def>The
rootstock or decumbent stem by which a hydroid is attached to other
objects. See <xex>Illust.</xex> under <er>Hydroidea</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosalt</ent><br/
<hw>Hy"dro*salt`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>salt</ets>.]</ety> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>A salt supposed to be formed by a hydracid and a
base.</def> <sd>(b)</sd> <def>An acid salt.</def> <mark>[R.]</mark>
<sd>(c)</sd> <def>A hydrous salt; a salt combined with water of
hydration or crystallization.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 718 --></p>

<p><ent>Hydroscope</ent><br/
<hw>Hy"dro*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>-scope</ets>.]</ety> <sn>1.</sn>
<def>An instrument designed to mark the presence of water, especially in
air.</def> <rj><au>Weale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of water clock, used anciently for measuring
time, the water tricking from an orifice at the end of a graduated
tube.</def></p>

<p><ent>Hydrosoma</ent><br/
<ent>Hydrosome</ent><br/
<mhw>{ <hw>Hy"dro*some</hw> <pr>(?)</pr>, \'d8<hw>Hy`dro*so"ma</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[NL. <ets>hydrosoma</ets>. See
<er>Hydra</er>, and <er>-some</er> body.]</ety> <fld>(Zool.)</fld>
<def>All the zooids of a hydroid colony collectively, including the
nutritive and reproductive zooids, and often other kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosorbic</ent><br/
<hw>Hy`dro*sor"bic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>sorbic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an acid obtained
from sorbic acid when this takes up hydrogen; <as>as,
<ex>hydrosorbic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosphere</ent><br/
<hw>Hy"dro*sphere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hydro-</ets>, 1 + <ets>sphere</ets>.]</ety> <sn>1.</sn>
<fld>(Meteor.)</fld> <def>The aqueous vapor of the entire
atmosphere.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Phys. Geog.)</fld> <def>The aqueous envelope of the
earth, including the ocean, all lakes, streams, and underground waters,
and the aqueous vapor in the atmosphere.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hydrostat</ent><br/
<hw>Hy"dro*stat</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
contrivance or apparatus to prevent the explosion of steam
boilers.</def></p>

<p><sn>2.</sn> <def>A device, usually electrical, for indicating or
regulating the height of water in a reservoir or receptacle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hydrostatical</ent><br/
<ent>Hydrostatic</ent><br/
<mhw>{ <hw>Hy`dro*stat"ic</hw> <pr>(?)</pr>, <hw>Hy`dro*stat"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Hydro-</ets>, 1 + Gr. <?/
causing to stand: cf. F. <ets>hydrostatique.</ets> See
<er>Static</er>.]</ety> <def>Of or relating to hydrostatics; pertaining
to, or in accordance with, the principles of the equilibrium of
fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The first discovery made in <qex>hydrostatics</qex> since the time
of Archimedes is due to Stevinus.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydrostatic balance</b></col>, <cd>a balance for weighing
substances in water, for the purpose of ascertaining their specific
gravities.</cd> -- <col><b>Hydrostatic bed</b></col>, <cd>a water
bed.</cd> -- <col><b>Hydrostatic bellows</b></col>, <cd>an apparatus
consisting of a water-tight bellowslike case with a long, upright tube,
into which water may be poured to illustrate the hydrostatic
paradox.</cd> -- <col><b>Hydrostatic paradox</b></col>, <cd>the
proposition in hydrostatics that any quantity of water, however small,
may be made to counterbalance any weight, however great; or the law of
the equality of pressure of fluids in all directions.</cd> --
<col><b>Hydrostatic press</b></col>, <cd>a machine in which great force,
with slow motion, is communicated to a large plunger by means of water
forced into the cylinder in which it moves, by a forcing pump of small
diameter, to which the power is applied, the principle involved being
the same as in the hydrostatic bellows. Also called <altname>hydraulic
press</altname>, and <altname>Bramah press</altname>. In the
illustration, <figref>a</figref> is a pump with a small plunger
<figref>b</figref>, which forces the water into the cylinder
<figref>c</figref>, thus driving upward the large plunder
<figref>d</figref>, which performs the reduced work, such as compressing
cotton bales, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrostatically</ent><br/
<hw>Hy`dro*stat"ic*al*ly</hw>, <pos>adv.</pos> <def>According to
hydrostatics, or to hydrostatic principles.</def>
<rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrostatician</ent><br/
<hw>Hy`dro*sta*ti"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
versed or skilled in hydrostatics.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrostatics</ent><br/
<hw>Hy`dro*stat"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hydrostatique</ets>.]</ety> <fld>(Physics)</fld> <def>The branch of
science which relates to the pressure and equilibrium of nonelastic
fluids, as water, mercury, etc.; the principles of statics applied to
water and other liquids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphate</ent><br/
<hw>Hy`dro*sul"phate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Same as <er>Hydrosulphurent</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphide</ent><br/
<hw>Hy`dro*sul"phide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>One of a series of compounds, derived from hydrogen sulphide by the
replacement of half its hydrogen by a base or basic radical; <as>as,
potassium <ex>hydrosulphide</ex>, <chform>KSH</chform></as>. The
hydrosulphides are analogous to the hydrates and include the
mercaptans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphite</ent><br/
<hw>Hy`dro*sul"phite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A saline compound of hydrosulphurous acid and a base.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphuret</ent><br/
<hw>Hy`dro*sul"phu*ret</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A hydrosulphide.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphureted</ent><br/
<hw>Hy`dro*sul"phu*ret`ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Combined with hydrogen sulphide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphuric</ent><br/
<hw>Hy`dro*sul*phu"ric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>sulphuric</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or derived from, hydrogen and
sulphur; <as>as, <ex>hydrosulphuric</ex> acid, a designation applied to
the solution of hydrogen sulphide in water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrosulphurous</ent><br/
<hw>Hy`dro*sul"phur*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an acid obtained
by the reduction of sulphurous acid. See <cref>Hyposulphurous
acid</cref>, under <er>Hyposulphurous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotellurate</ent><br/
<hw>Hy`dro*tel"lu*rate</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A salt formed by the union of hydrotelluric acid
and the base.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotelluric</ent><br/
<hw>Hy`dro*tel*lu"ric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>telluric</ets>.]</ety>
<fld>(Chem.)</fld> <def>Formed by hydrogen and tellurium; <as>as,
<ex>hydrotelluric</ex> acid, or hydrogen telluride</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotheca</ent><br/
\'d8<hw>Hy`dro*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hydrothec<ae/</plw> <pr>(#)</pr>, E.
<plw>Hydrothecas</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. E.
<ets>hydra</ets> + Gr. <?/ a box.]</ety> <fld>(Zool.)</fld> <def>One of
the calicles which, in some Hydroidea (Thecaphora), protect the
hydrants. See <xex>Illust.</xex> of <er>Hydroidea</er>, and
<er>Campanularian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotherapeutics</ent><br/
<hw>Hy`dro*ther`a*peu"tics</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>therapeutics</ets>.]</ety>
<fld>(Med.)</fld> <def>A system of treating disease by baths and mineral
waters.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hydrotherapy</ent><br/
<hw>Hy`dro*ther"a*py</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>therapy</ets>.]</ety>
<fld>(Med.)</fld> <def>See <er>Hydropathy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrothermal</ent><br/
<hw>Hy`dro*ther"mal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>thermal</ets>.]</ety> <sn>1.</sn>
<def>Of or pertaining to hot water; -- used esp. with reference to the
action of heated waters in dissolving, redepositing, and otherwise
producing mineral changes within the crust of the globe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>of, pertaining to, or using the hot waters or steam
found at special locations within the earth's crust; <as>as,
<ex>hydrothermal</ex> power generation</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hydrothorax</ent><br/
<hw>Hy`dro*tho"rax</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + <ets>thorax</ets>.]</ety> <fld>(Med.)</fld>
<def>An accumulation of serous fluid in the cavity of the
chest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotic</ent><br/
<hw>Hy*drot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"y`dwr</grk> water: cf. Gr. <?/ moisture, F.
<ets>hydrotique</ets>.]</ety> <def>Causing a discharge of water or
phlegm.</def> -- <def2><pos>n.</pos> <fld>(Med.)</fld> <def>A hydrotic
medicine.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotical</ent><br/
<hw>Hy*drot"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hydrotic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotrope</ent><br/
<hw>Hy"dro*trope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 1 + Gr. <?/ to turn, direct.]</ety> <def>A
device for raising water by the direct action of steam; a
pulsometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotropic</ent><br/
<hw>Hy`dro*trop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Hydrotrope</er>.]</ety> <fld>(Bot.)</fld> <def>Turning or bending
towards moisture, as roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrotropism</ent><br/
<hw>Hy*drot"ro*pism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A tendency towards moisture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>In a broader sense, any curvature
or turning induced in certain growing plant organs under the influence
of moisture.</def></p>

<p><note><hand/ When the movement is toward the moisture, as is the case
in most roots, the phenomenon is called <stype>positive
hydrotropism</stype>; when away from the moisture, as in the case of
hyphae of certain fungi, <stype>negative
hydrotropism</stype>.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hydrous</ent><br/
<hw>Hy"drous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"y`dwr</grk> water.]</ety> <sn>1.</sn> <def>Containing water;
watery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Containing water of hydration or
crystallization.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroxanthane</ent><br/
<hw>Hy`dro*xan"thane</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A persulphocyanate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroxanthic</ent><br/
<hw>Hy`dro*xan"thic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>xanthic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Persulphocyanic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroxide</ent><br/
<hw>Hy*drox"ide</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydro-</ets>, 2 + <ets>oxide</ets>.]</ety> <fld>(Chem.)</fld>
<def>A hydrate; a substance containing hydrogen and oxygen, made by
combining water with an oxide, and yielding water by elimination. The
hydroxides are regarded as compounds of hydroxyl, united usually with
basic element or radical; <as>as, calcium <ex>hydroxide</ex> ethyl
<ex>hydroxide</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroxy-</ent><br/
<hw>Hy*drox"y-</hw> <pr>(?)</pr>. <fld>(Chem.)</fld> <def>A combining
form, also used adjectively, indicating <xex>hydroxyl</xex> as an
ingredient.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hydroxy acid</b></col> <fld>(Chem.)</fld>, <cd>an organic
acid, having (besides the hydroxyl group of the carboxyl radical) an
alcoholic hydroxyl group, and thus having the qualities of an alcohol in
addition to its acid properties; as, lactic and tartaric acids are
<xex>hydroxy</xex> acids.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroxyl</ent><br/
<hw>Hy*drox"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydro-</ets>,
2 + <ets>ox</ets>ygen + <ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A
compound radical, or unsaturated group, <chform>HO</chform>, consisting
of one atom of hydrogen and one of oxygen. It is a characteristic part
of the hydrates, the alcohols, the oxygen acids, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydroxylamine</ent><br/
<hw>Hy*drox`yl*am"ine</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hydroxyl</ets> + <ets>amine</ets>.]</ety> <fld>(Chem.)</fld>
<def>A nitrogenous, organic base, <chform>NH2.OH</chform>, resembling
ammonia, and produced by a modified reduction of nitric acid. It is
usually obtained as a volatile, unstable solution in water. It acts as a
strong reducing agent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hydroxymethyl</ent><br/
<hw>hydroxymethyl</hw> <pos>n.</pos> <def>a methyl radical with a
hydroxyl group replacing one of the hydrogen atoms.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hydroxyproline</ent><br/
<hw>hydroxyproline</hw> <pos>n.</pos> <def>A crystalline amino acid
(<chform>C5H9NO3</chform>), a hydroxylated proline, obtained by
hydrolysis of gelatin or collagen. Chemically it is
<chname>4-hydroxy-L-proline</chname>. It is classified as nonessential
for growth in rats.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Hydrozoa</ent><br/
\'d8<hw>Hy`dro*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
E. <ets>hydra</ets> + Gr. <grk>zw^,on</grk> an animal.]</ety>
<fld>(Zool.)</fld> <def>The Acaleph<ae/; one of the classes of
c<oe/lenterates, including the Hydroidea, Discophora, and
Siphonophora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrozoal</ent><br/
<hw>Hy`dro*zo"al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Hydrozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrozoon</ent><br/
\'d8<hw>Hy`dro*zo"<oum/n</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hydrozoa</plw> <pr>(#)</pr>, E.
<plw>Hydrozo<oum/ns</plw> <pr>(#)</pr>.</plu> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>One of the Hydrozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydruret</ent><br/
<hw>Hy"dru*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hydro-</ets>,
2]</ety> <fld>(Chem.)</fld> <def>A binary compound of hydrogen; a
hydride.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hydrus</ent><br/
\'d8<hw>Hy"drus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a water
serpent; also, a certain constellation, Gr. <grk>"y`dros</grk>.]</ety>
<fld>(Astron.)</fld> <def>A constellation of the southern hemisphere,
near the south pole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hye</ent><br/
<hw>Hye</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Hie</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyemal</ent><br/
<hw>Hy*e"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hyemalis</ets>, or better <ets>hiemalis</ets>, fr.
<ets>hyems</ets>, <ets>hiems</ets>, winter: cf. F.
<ets>hy<eacute/mal</ets>.]</ety> <def>Belonging to winter; done in
winter.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyemate</ent><br/
<hw>Hy"e*mate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>hiemare</ets>, <ets>hiematum</ets>. See <er>Hyemal</er>.]</ety>
<def>To pass the winter.</def> <mark>[Obs. & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyemation</ent><br/
<hw>Hy`e*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hiematio</ets>.]</ety> <sn>1.</sn> <def>The passing of a winter in
a particular place; a wintering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of affording shelter in winter.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyen</ent><br/
<hw>Hy"en</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hy<egrave/ne</ets>.]</ety> <def>A hyena.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyena</ent><br/
<hw>Hy*e"na</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hyenas</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>hyaena</ets>, Gr.
<?/, orig., a sow, but usually, a Libyan wild beast, prob., the hyena,
fr. <?/ hog: cf. F. <ets>hy<egrave/ne</ets>. See <er>Sow</er> female
hog.]</ety> <fld>(Zool.)</fld> <def>Any carnivorous mammal of the family
<fam>Hy<ae/nid<ae/</fam>, doglike nocturnal mammals of Africa and
southern Asia, of which three living species are known. They are large
and strong, but cowardly. They feed chiefly on carrion, and are
nocturnal in their habits.</def> <altsp>[Written also
<asp>hy<ae/na</asp>.]</altsp><br/
<syn><b>Syn. --</b> hyaena.</syn><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The striped hyena (<spn>Hy<ae/na striata</spn>) inhabits
Southern Asia and a large part of Africa. The brown hyena (<spn>Hy<ae/na
brunnea</spn>), and the spotted hyena (<spn>Crocuta maculata</spn>), are
found in Southern Africa. The extinct cave hyena (<spn>Hy<ae/na
spel<ae/a</spn>) inhabited England and France.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cave hyena</b></col>. <cd>See under <er>Cave</er>.</cd>
-- <col><b>Hyena dog</b></col> <fld>(Zool.)</fld>, <cd>a South African
canine animal (<spn>Lycaon venaticus</spn>), which hunts in packs,
chiefly at night. It is smaller than the common wolf, with very large,
erect ears, and a bushy tail. Its color is reddish or yellowish brown,
blotched with black and white. Called also <altname>hunting
dog</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyetal</ent><br/
<hw>Hy"e*tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ rain, from
<?/ to rain.]</ety> <def>Of or pertaining to rain; descriptive of the
distribution of rain, or of rainy regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyetograph</ent><br/
<hw>Hy"e*to*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ rain +
<ets>-graph</ets>.]</ety> <def>A chart or graphic representation of the
average distribution of rain over the surface of the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyetographic</ent><br/
<hw>Hy`e*to*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to to hyetography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyetography</ent><br/
<hw>Hy`e*tog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The branch of
physical science which treats of the geographical distribution of
rain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyetology</ent><br/
<hw>Hy`e*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ + rain
<ets>-logy</ets>.]</ety> <def>The science which treats of the
precipitation of rain, snow, etc.</def> --
<wordforms><wf>Hy`e*to*log"ic*al</wf> <pr>(<?/)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hygeia</ent><br/
<hw>Hy*ge"ia</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>Hygea</ets>,
<ets>Hygia</ets>, fr. Gr. <?/, <?/, health, <?/, Hygeia, fr. <?/ sound,
healthy.]</ety> <fld>(Classic Myth.)</fld> <def>The goddess of health,
daughter of Esculapius.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygeian</ent><br/
<hw>Hy*ge"ian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to Hygeia,
the goddess of health; of or pertaining to health, or its
preservation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygeist</ent><br/
<hw>Hy"ge*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled in
hygiena; a hygienist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygieist</ent><br/
<hw>Hy"gie*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
hygienist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygiene</ent><br/
<hw>Hy"gi*ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hygi<egrave/ne</ets>. See <er>Hygeia</er>.]</ety> <def>That
department of sanitary science which treats of the preservation of
health, esp. of households and communities; a system of principles or
rules designated for the promotion of health.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygienic</ent><br/
<hw>Hy`gi*en"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hygi<eacute/nique</ets>.]</ety> <def>Of or pertaining to health or
hygiene; sanitary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygienics</ent><br/
<hw>Hy`gi*en"ics</hw>, <pos>n.</pos> <def>The science of health;
hygiene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygienism</ent><br/
<hw>Hy"gi*en*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Hygiene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygienist</ent><br/
<hw>Hy"gi*en*ist</hw>, <pos>n.</pos> <def>One versed in
hygiene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygiology</ent><br/
<hw>Hy`gi*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ health
+ <ets>-logy</ets>.]</ety> <def>A treatise on, or the science of, the
preservation of health.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrine</ent><br/
<hw>Hy"grine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Gr. <?/
moist.]</ety> <fld>(Chem.)</fld> <def>An alkaloid associated with
cocaine in coca leaves (<spn>Erythroxylon coca</spn>), and extracted as
a thick, yellow oil, having a pungent taste and odor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrodeik</ent><br/
<hw>Hy"gro*deik</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet,
moist, and <?/ to show.]</ety> <fld>(Physics)</fld> <def>A form of
hygrometer having wet and dry bulb thermometers, with an adjustable
index showing directly the percentage of moisture in the air,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrograph</ent><br/
<hw>Hy"gro*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet +
<ets>-graph</ets>.]</ety> <fld>(Physics)</fld> <def>An instrument for
recording automatically the variations of the humidity of the
atmosphere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrology</ent><br/
<hw>Hy*grol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet +
<ets>-logy</ets>: cf. F. <ets>hygrologie</ets>.]</ety> <fld>(Med.)</fld>
<def>The science which treats of the fluids of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrometer</ent><br/
<hw>Hy*grom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet,
moist + <ets>-meter</ets>: cf. F. <ets>hygrom<egrave/tre</ets>.]</ety>
<fld>(Physics)</fld> <def>An instrument for measuring the degree of
moisture of the atmosphere.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Daniell's hygrometer</b></col>, <cd>a form of hygrometer
consisting of a bent glass tube terminating in two bulbs, the one
covered with muslin, the other of black glass, and containing ether and
a thermometer. Ether being poured on the muslin, the black ball, cooled
by the evaporation of the ether within, is soon covered with dew; at
this moment, the inclosed thermometer gives the dew-point, and this,
compared with the reading of one in the air, determines the
humidity.</cd></cs></p>

<p><ent>Hygrometrical</ent><br/
<ent>Hygrometric</ent><br/
<mhw>{ <hw>Hy`gro*met"ric</hw> <pr>(?)</pr>, <hw>Hy`gro*met"ric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>hygrom<eacute/trique</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to hygrometry; made with, or according to, the hygrometer;
<as>as, <ex>hygrometric</ex> observations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Readily absorbing and retaining moisture; <as>as,
<ex>hygrometric</ex> substances, like potash</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrometry</ent><br/
<hw>Hy*grom"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hygrom<eacute/trie</ets>.]</ety> <fld>(Physics)</fld> <def>That
branch of physics which relates to the determination of the humidity of
bodies, particularly of the atmosphere, with the theory and use of the
instruments constructed for this purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrophanous</ent><br/
<hw>Hy*groph"a*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ wet +
<?/ to show.]</ety> <def>Having such a structure as to be diaphanous
when moist, and opaque when dry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrophthalmic</ent><br/
<hw>Hy`groph*thal"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ wet
+ E. <ets>ophthalmic</ets>.]</ety> <fld>(Anat.)</fld> <def>Serving to
moisten the eye; -- sometimes applied to the lachrymal ducts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygroplasm</ent><br/
<hw>Hy"gro*plasm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet +
<?/ form, mold.]</ety> <fld>(Biol.)</fld> <def>The fluid portion of the
cell protoplasm, in opposition to <xex>stereoplasm</xex>, the solid or
insoluble portion. The latter is supposed to be partly nutritive and
partly composed of idioplasm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygroscope</ent><br/
<hw>Hy"gro*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet +
<ets>-scope</ets>: cf. F. <ets>hygroscope</ets>.]</ety>
<fld>(Physics)</fld> <def>An instrument which shows whether there is
more or less moisture in the atmosphere, without indicating its
amount.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygroscopic</ent><br/
<hw>Hy`gro*scop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hygroscopique</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to,
or indicated by, the hygroscope; not readily manifest to the senses, but
capable of detection by the hygroscope; <as>as, glass is often covered
with a film of <ex>hygroscopic</ex> moisture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the property of readily imbibing moisture
from the atmosphere, or of the becoming coated with a thin film of
moisture, as glass, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygroscopicity</ent><br/
<hw>Hy`gro*sco*pic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The property possessed by vegetable tissues of
absorbing or discharging moisture according to circumstances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hygrostatics</ent><br/
<hw>Hy`gro*stat"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wet +
<?/. See <er>Statics</er>.]</ety> <def>The science or art of comparing
or measuring degrees of moisture.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyke</ent><br/
<hw>Hyke</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Haik</er>, and
<er>Huke</er>.</def></p>

<p><ent>Hyksos</ent><br/
<hw>Hyk"sos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr. Egypt.
<ets>hikshasu</ets> chiefs of the Bedouins, shepherds.]</ety> <def>A
dynasty of Egyptian kings, often called the <altname>Shepherd
kings</altname>, of foreign origin, who, according to the narrative of
Manetho, ruled for about 500 years, forming the XVth and XVIth
dynasties. It is now considered that the XVIth is merely a double of the
XVth dynasty, and that the total period of the six Hyksos kings was
little more than 100 years. It is supposed that they were Asiatic
Semites.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hylaeosaurus</ent><br/
<ent>Hylaeosaur</ent><br/
<mhw>{ <hw>Hy"l<ae/*o*saur`</hw> <pr>(?)</pr>,
\'d8<hw>Hy`l<ae/*o*sau"rus</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[NL. <ets>hylaeosaurus</ets>, fr. Gr. <?/ belonging to a forest
(fr. <?/ wood) + <?/ a lizard.]</ety> <fld>(Paleon.)</fld> <def>A large
Wealden dinosaur from the Tilgate Forest, England. It was about twenty
feet long, protected by bony plates in the skin, and armed with
spines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylarchical</ent><br/
<hw>Hy*lar"chi*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ wood,
matter + <?/: cf. F. <ets>hylarchique</ets>. See
<er>Archical</er>.]</ety> <def>Presiding over matter.</def>
<mark>[Obs.]</mark> <rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyleosaur</ent><br/
<hw>Hy"le*o*saur"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hyl<ae/osaur</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylic</ent><br/
<hw>Hyl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
matter; material; corporeal; <as>as, <ex>hylic</ex>
influences</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylicist</ent><br/
<hw>Hy"li*cist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ adj.,
material, fr. <?/ wood, matter.]</ety> <def>A philosopher who treats
chiefly of matter; one who adopts or teaches hylism.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 719 --></p>

<p><ent>Hylism</ent><br/
<hw>Hy"lism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wood,
matter.]</ety> <fld>(Metaph.)</fld> <def>A theory which regards matter
as the original principle of evil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylobate</ent><br/
<hw>Hy"lo*bate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ one that
walks or inhabits the woods: <?/ a wood + <?/ to go.]</ety>
<fld>(Zool.)</fld> <def>Any species of the genus <gen>Hylobates</gen>; a
gibbon, or long-armed ape. See <er>Gibbon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylodes</ent><br/
\'d8<hw>Hy*lo"des</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ woody, wooded, muddy; <?/ a wood + <grk>e'i^dos</grk> form.]</ety>
<fld>(Zool.)</fld> <def>The piping frog (<spn>Hyla Pickeringii</spn>), a
small American tree frog, which in early spring, while breeding in
swamps and ditches, sings with high, shrill, but musical,
notes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyloism</ent><br/
<hw>Hy"lo*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hylotheism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyloist</ent><br/
<hw>Hy"lo*ist</hw>, <pos>n.</pos> <ety>[Gr. <?/ wood, matter.]</ety>
<def>Same as <er>Hylotheist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylopathism</ent><br/
<hw>Hy*lop"a*thism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ matter
+ <?/, <?/, to suffer.]</ety> <def>The doctrine that matter is
sentient.</def> <rj><au>Krauth-Fleming.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylopathist</ent><br/
<hw>Hy*lop"a*thist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
believes in hylopathism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylophagous</ent><br/
<hw>Hy*loph"a*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ wood +
<?/ to eat.]</ety> <fld>(Zool.)</fld> <def>Eating green shoots, as
certain insects do.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylotheism</ent><br/
<hw>Hy"lo*the*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wood,
matter + <?/ God.]</ety> <def>The doctrine of belief that matter is God,
or that there is no God except matter and the universe; pantheism. See
<er>Materialism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylotheist</ent><br/
<hw>Hy"lo*the*ist</hw>, <pos>n.</pos> <def>One who believes in
hylotheism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylozoic</ent><br/
<hw>Hy`lo*zo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to hylozoism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylozoism</ent><br/
<hw>Hy`lo*zo"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wood,
matter + <?/ life, fr. <?/ to live: cf. F.
<ets>hylozo<ium/sme</ets>.]</ety> <def>The doctrine that matter
possesses a species of life and sensation, or that matter and life are
inseparable.</def> <mark>[R.]</mark> <rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hylozoist</ent><br/
<hw>Hy`lo*zo"ist</hw>, <pos>n.</pos> <def>A believer in hylozoism.</def>
<rj><au>A. Tucker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymar</ent><br/
<hw>Hy*mar"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
wild ass of Persia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymen</ent><br/
<hw>Hy"men</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>"ymh`n</grk>
skin, membrane.]</ety> <fld>(Anat.)</fld> <def>A fold of mucous membrane
often found at the orifice of the vagina in virgins; the vaginal
membrane. It is usually torn by sexual intercourse.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hymen</ent><br/
<hw>Hy"men</hw>, <pos>n.</pos> <ety>[L., fr. Gr. <?/.]</ety> <sn>1.</sn>
<fld>(Class Myth.)</fld> <def>A fabulous deity; according to some, the
son of Apollo and Urania, according to others, of Bacchus and Venus. He
was the god of marriage, and presided over nuptial
solemnities.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till <qex>Hymen</qex> brought his love-delighted hour,<br/
There dwelt no joy in Eden's rosy bower.</q>
<rj><qau>Campbell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Marriage; union as if by marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hymen</qex> of element and race.</q>
<rj><qau>Emerson.</qau></rj></p>

<p><ent>hymenal</ent><br/
<hw>hymenal</hw> <pos>adj.</pos> <def>Same as
<er>hymeneal</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hymenean</ent><br/
<ent>Hymeneal</ent><br/
<mhw>{ <hw>Hy`me*ne"al</hw> <pr>(?)</pr>, <hw>Hy`me*ne"an</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hymeneius</ets>,
<pos>a.</pos>, also <ets>Hymenaeus</ets>, <pos>n.</pos>, Hymen, Gr. <?/
the wedding song, also <?/ Hymen: cf. F.
<ets>hym<eacute/n<eacute/al</ets>,
<ets>hym<eacute/n<eacute/en</ets>.]</ety> <def>Of or pertaining to
marriage; <as>as, <ex>hymeneal</ex> rites</as>.</def>
<rj><au>Pope.</au></rj></p>

<p><ent>Hymenean</ent><br/
<ent>Hymeneal</ent><br/
<mhw>{ <hw>Hy`me*ne"al</hw>, <hw>Hy`me*ne"an</hw>, }</mhw> <pos>n.</pos>
<def>A marriage song.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenium</ent><br/
\'d8<hw>Hy*me"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
L. <plw>Hymenia</plw> <pr>(#)</pr>, E. <plw>Hymeniums</plw>
<pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/ a membrane.]</ety>
<fld>(Bot.)</fld> <def>The spore-bearing surface of certain fungi, as
that on the gills of a mushroom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenogastrales</ent><br/
<hw>Hymenogastrales</hw> <pos>n.</pos> <def>An order of fungi sometimes
placed in subclass Homobasidiomycetes.</def><br/
<syn><b>Syn. --</b> order Hymenogastrales.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hymenogeny</ent><br/
<hw>Hy`me*nog"e*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
membrane + root of <grk>gi`gnesqai</grk> to be born.]</ety> <def>The
production of artificial membranes by contact of two fluids, as albumin
and fat, by which the globules of the latter are surrounded by a thin
film of the former.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenomycetes</ent><br/
\'d8<hw>Hy`me*no*my*ce"tes</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ a membrane + <?/, <?/, a mushroom.]</ety>
<fld>(Bot.)</fld> <def>One of the great divisions of fungi, containing
those species in which the hymenium is completely exposed.</def>
<rj><au>M. J. Berkley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenophore</ent><br/
<hw>Hy*men"o*phore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
membrane + <grk>fe`rein</grk> to bear.]</ety> <fld>(Bot.)</fld>
<def>That part of a fungus which is covered with the hymenium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenopter</ent><br/
<hw>Hy`me*nop"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hym<eacute/nopt<egrave/re</ets>.]</ety> <fld>(Zool.)</fld> <def>One
of the Hymenoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenoptera</ent><br/
\'d8<hw>Hy`me*nop"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ membrane-winged; <?/ skin, membrane + <?/ wing.]</ety>
<fld>(Zool.)</fld> <def>An extensive order of insects, including the
bees, ants, ichneumons, sawflies, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They have four membranous wings, with few reticulations,
and usually with a thickened, dark spot on the front edge of the
anterior wings. In most of the species, the tongue, or lingua, is
converted into an organ for sucking honey, or other liquid food, and the
mandibles are adapted for biting or cutting. In one large division
(<suborder>Aculeata</suborder>), including the bees, wasps, and ants,
the females and workers usually have a sting, which is only a modified
ovipositor.</note></p>

<p><ent>Hymenopterous</ent><br/
<ent>Hymenopteral</ent><br/
<mhw>{ <hw>Hy`me*nop"ter*al</hw> <pr>(?)</pr>,
<hw>Hy`me*nop"ter*ous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Zool.)</fld> <def>Like, or characteristic of, the Hymenoptera;
pertaining to the Hymenoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymenopteran</ent><br/
<hw>Hy`me*nop"ter*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Hymenoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hymenopteron</ent><br/
<hw>hymenopteron</hw> <pos>n.</pos> <def>Same as
<er>hymenopteran</er>.</def><br/
<syn><b>Syn. --</b> hymenopterous insect, hymenopteran,
hymnenopter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hymn</ent><br/
<hw>Hymn</hw> <pr>(h<icr/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hympne</ets>, <ets>ympne</ets>, F. <ets>hymne</ets>, OF. also
<ets>ymne</ets>, L. <ets>hymnus</ets>, Gr. <?/; perh. akin to <?/ web,
<?/ to weave, and so to E. <ets>weave</ets>.]</ety> <def>An ode or song
of praise or adoration; especially, a religious ode, a sacred lyric; a
song of praise or thanksgiving intended to be used in religious service;
<as>as, the Homeric <ex>hymns</ex>; Watts'
<ex>hymns</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Admonishing one another in psalms and <qex>hymns</qex>.</q>
<rj><qau>Col. iii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where angels first should practice <qex>hymns</qex>, and
string<br/
Their tuneful harps.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hymn book</b></col>, <cd>a book containing a collection
of hymns, as for use in churches; a hymnal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymn</ent><br/
<hw>Hymn</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Hymned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hymning</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. L.
<ets>hymnire</ets>, Gr. <?/.]</ety> <def>To praise in song; to worship
or extol by singing hymns; to sing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>hymn</qex> the bright of the Lord.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their praise is <qex>hymned</qex> by loftier harps than mine.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymn</ent><br/
<hw>Hymn</hw>, <pos>v. i.</pos> <def>To sing in praise or
adoration.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnal</ent><br/
<hw>Hym"nal</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A collection of hymns;
a hymn book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnic</ent><br/
<hw>Hym"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hymnique</ets>.]</ety> <def>Relating to hymns, or sacred
lyrics.</def> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymning</ent><br/
<hw>Hymn"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Praising with hymns;
singing.</def> <ldquo/The <xex>hymning</xex> choir.<rdquo/ <rj><au>G.
West.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymning</ent><br/
<hw>Hymn"ing</hw>, <pos>n.</pos> <def>The singing of hymns.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnist</ent><br/
<hw>Hym"nist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A writer of
hymns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnody</ent><br/
<hw>Hym"no*dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/ a hymn
+ <?/ a song, a singing.]</ety> <def>Hymns, considered collectively;
hymnology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnographer</ent><br/
<hw>Hym*nog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who writes on the subject of hymns.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A writer or composed of hymns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnography</ent><br/
<hw>Hym*nog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ hymn +
<ets>graphy</ets>.]</ety> <def>The art or act of composing
hymns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnologist</ent><br/
<hw>Hym*nol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A composer or
compiler of hymns; one versed in hymnology.</def>
<rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hymnology</ent><br/
<hw>Hym*nol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ hymn +
<ets>-logy</ets>: cf. F. <ets>hymnologie</ets>.]</ety> <sn>1.</sn>
<def>The hymns or sacred lyrics composed by authors of a particular
country or period; <as>as, the <ex>hymnology</ex> of the eighteenth
century</as>; also, the collective body of hymns used by any particular
church or religious body; <as>as, the Anglican
<ex>hymnology</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A knowledge of hymns; a treatise on hymns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hympne</ent><br/
<hw>Hymp"ne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hymn.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyndreste</ent><br/
<hw>Hynd"reste</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Hinderest</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyne</ent><br/
<hw>Hyne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A servant. See
<er>Hine</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyo-</ent><br/
<hw>Hy"o-</hw> <pr>(?)</pr>. <ety>[See <er>Hyod</er>.]</ety> <def>A
prefix used in anatomy, and generally denoting <sig>connection with the
hyoid bone</sig> or <xex>arch</xex>; <as>as, <ex>hyo</ex>glossal,
<ex>hyo</ex>mandibular, <ex>hyo</ex>mental, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoganoidei</ent><br/
\'d8<hw>Hy`o*ga*noi"de*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Hyo-</er>, and <er>Canoidei</er>.]</ety> <fld>(Zool.)</fld>
<def>A division of ganoid fishes, including the gar pikes and
bowfins.</def> -- <wordforms><wf>Hy`o*ga"noid</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoglossal</ent><br/
<hw>Hy`o*glos"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hyo-</ets>
+ Gr. <?/ tongue.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd> <def>Pertaining
to or connecting the tongue and hyodean arch; <as>as, the
<ex>hyoglossal</ex> membrane</as>.</def> <sd>(b)</sd> <def>Of or
pertaining to the hyoglossus muscle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoglossus</ent><br/
\'d8<hw>Hy`o*glos"sus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
<ets>hyo-</ets> hyo- + Gr. <grk>glw^ssa</grk> tongue.]</ety>
<fld>(Anat.)</fld> <def>A flat muscle on either side of the tongue,
connecting it with the hyoid bone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoid</ent><br/
<hw>Hy"oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ fr. the letter
<UPSILON/ + <grk>e'i^dos</grk> form: cf. F.
<ets>hyo<ium/de</ets>.]</ety> <sn>1.</sn> <def>Having the form of an
arch, or of the Greek letter upsilon [<UPSILON/].</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Of or pertaining to the bony or
cartilaginous arch which supports the tongue. Sometimes applied to the
tongue itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyoid arch</b></col> <fld>(Anat.)</fld>, <cd>the arch of
cartilaginous or bony segments, which connects the base of the tongue
with either side of the skull.</cd> -- <col><b>Hyoid bone</b></col>
<fld>(Anat.)</fld>, <cd>the bone in the base of the tongue, the middle
part of the hyoid arch.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoid</ent><br/
<hw>Hy"oid</hw>, <pos>n.</pos> <def>The hyoid bone.</def></p>

<p><ent>Hyoidean</ent><br/
<ent>Hyoideal</ent><br/
<mhw>{ <hw>Hy*oid"e*al</hw> <pr>(?)</pr>, <hw>Hy*oid"e*an</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Same as <er>Hyoid</er>,
<it>a.</it></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyomandibular</ent><br/
<hw>Hy`o*man*dib"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hyo-</ets> + <ets>mandibular</ets>.]</ety> <fld>(Anat.)</fld>
<def>Pertaining both to the hyoidean arch and the mandible or lower jaw;
<as>as, the <ex>hyomandibular</ex> bone or cartilage, a segment of the
hyoid arch which connects the lower jaw with the skull in
fishes</as>.</def> -- <def2><pos>n.</pos> <def>The hyomandibular bone or
cartilage.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyomental</ent><br/
<hw>Hy`o*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hyo-</ets>
+ <ets>mental</ets> of the chin.]</ety> <fld>(Anat.)</fld> <def>Between
the hyoid bone and the lower jaw, pertaining to them; suprahyoid;
submaxillary; <as>as, the <ex>hyomental</ex> region of the front of the
neck</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyopastron</ent><br/
<hw>Hy`o*pas"tron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Hyo-</ets>
+ <ets>plastron</ets>.]</ety> <fld>(Zool.)</fld> <def>The second lateral
plate in the plastron of turtles; -- called also
<altname>hyosternum</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoscine</ent><br/
<hw>Hy*os"cine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hyoscyamus</er>.]</ety> <fld>(Chem.)</fld> <def>An alkaloid found
with hyoscyamine (with which it is also isomeric) in henbane, and
extracted as a white, amorphous, semisolid substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoscyamine</ent><br/
<hw>Hy`os*cy"a*mine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Hyoscyamus</er>.]</ety> <fld>(Chem.)</fld> <def>An alkaloid found in
henbane (<spn>Hyoscyamus niger</spn>), and regarded as its active
principle. It is also found with other alkaloids in the thorn apple and
deadly nightshade. It is extracted as a white crystalline substance,
with a sharp, offensive taste. <ex>Hyoscyamine</ex> is isomeric with
atropine, is very poisonous, and is used as a medicine for neuralgia,
like belladonna. Called also <altname>hyoscyamia</altname>,
<altname>duboisine</altname>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyoscyamus</ent><br/
\'d8<hw>Hy`os*cy"a*mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
Gr. <?/; <?/ a sow, hog + <?/ a bean.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A genus of poisonous plants of the Nightshade
family; henbane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>The leaves of the black henbane
(<spn>Hyoscyamus niger</spn>), used in neuralgic and pectoral
troubles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyosternal</ent><br/
<hw>Hy`o*ster"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hyo-</ets>
+ <ets>ternal</ets>.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd> <def>Between
the hyoid bone and the sternum, or pertaining to them; infrahyoid;
<as>as, the <ex>hyosternal</ex> region of the neck</as>.</def>
<sd>(b)</sd> <def>Pertaining to the hyosternum of turtles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyosternum</ent><br/
\'d8<hw>Hy`o*ster"num</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hyo-</ets> + <ets>sternum</ets>.]</ety> <fld>(Anat.)</fld>
<def>See <er>Hyoplastron</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyostylic</ent><br/
<hw>Hy`o*styl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hyo-</ets>
+ Gr. <?/ a pillar.]</ety> <fld>(Anat.)</fld> <def>Having the mandible
suspended by the hyomandibular, or upper part of the hyoid arch, as in
fishes, instead of directly articulated with the skull as in mammals; --
said of the skull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyp</ent><br/
<hw>Hyp</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An abbreviation of
<xex>hypochonaria</xex>; -- usually in plural.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven send thou hast not got the <qex>hyps</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyp</ent><br/
<hw>Hyp</hw>, <pos>v. t.</pos> <def>To make melancholy.</def>
<mark>[Colloq.]</mark> <rj><au>W. Irving.</au></rj></p>

<p><ent>Hypethral</ent><br/
<ent>Hypaethral</ent><br/
<mhw>{ <hw>Hy*p<ae/"thral</hw>, <hw>Hy*pe"thral</hw> <pr>(?)</pr>
}</mhw>, <pos>a.</pos> <ety>[L. <ets>hypaethrus</ets> in the open air,
uncovered, Gr. <?/; <?/ under + <?/ ether, the clear sky.]</ety>
<fld>(Arch.)</fld> <def>Exposed to the air; wanting a roof; -- applied
to a building or part of a building.</def> <rj><au>Gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypallage</ent><br/
<hw>Hy*pal"la*ge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/,
prop., interchange, exchange, fr, <?/ to interchange; <?/ under + <?/ to
change.]</ety> <fld>(Gram.)</fld> <def>A figure consisting of a
transference of attributes from their proper subjects to others. Thus
Virgil says, <ldquo/<xex>dare classibus austros</xex>,<rdquo/ to give
the winds to the fleets, instead of <xex>dare classibus austris</xex>,
to give the fleets to the winds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hypallage</qex>, of which Virgil is fonder than any other
writer, is much the gravest fault in language.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypallelomorph</ent><br/
<hw>Hyp`al*le"lo*morph</hw>, <pos>n.</pos> <def>See
<er>Allelomorph</er>.</def></p>

<p><ent>Hypanthium</ent><br/
\'d8<hw>Hy*pan"thi*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hypanthia</plw> <pr>(#)</pr>, E.
<plw>Hypanthiums</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>"ypo</grk> beneath + <grk>'a`nqos</grk> flower.]</ety>
<fld>(Bot.)</fld> <def>A fruit consisting in large part of a receptacle,
enlarged below the calyx, as in the <gen>Calycanthus</gen>, the rose
hip, and the pear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypapophysis</ent><br/
\'d8<hw>Hy`pa*poph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hypapophyles</plw> <pr>(#)</pr>.</plu> <ety>[NL.
See <er>Hypo-</er>, and <er>Apophysis</er>.]</ety> <fld>(Anat.)</fld>
<def>A process, or other element, of a vertebra developed from the
ventral side of the centrum, as h<ae/mal spines, and chevron
bones.</def> -- <wordforms><wf>Hy`pa*po*phys"i*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyparterial</ent><br/
<hw>Hy`par*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hypo-</ets> + <ets>arterial</ets>.]</ety> <fld>(Anat.)</fld>
<def>Situated below an artery; applied esp. to the branches of the
bronchi given off below the point where the pulmonary artery crosses the
bronchus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypaspist</ent><br/
<hw>Hy*pas"pist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/.]</ety>
<fld>(Gr. Antiq.)</fld> <def>A shield-bearer or armor-bearer.</def>
<rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypaxial</ent><br/
<hw>Hy*pax"i*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Hypo-</ets>
+ <ets>axial</ets>.]</ety> <fld>(Anat.)</fld> <def>Beneath the axis of
the skeleton; subvertebral; hyposkeletal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyper-</ent><br/
<hw>Hy"per-</hw> <pr>(?)</pr>. <ety>[Gr. <grk>"ype`r</grk> over, above;
akin to L. <ets>super</ets>, E. <ets>over</ets>. See <er>Over</er>, and
cf. <er>Super-</er>.]</ety> <sn>1.</sn> <def>A prefix signifying
<xex>over</xex>, <xex>above</xex>; <as>as, <ex>hyper</ex>physical,
<ex>hyper</ex>thyrion</as>; also, <xex>above measure</xex>,
<xex>abnormally great</xex>, <xex>excessive</xex>; <as>as,
<ex>hyper</ex><ae/mia, <ex>hyper</ex>bola, <ex>hyper</ex>critical,
<ex>hyper</ex>secretion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A prefix equivalent to
<xex>super-</xex> or <xex>per-</xex>; as <xex>hyper</xex>oxide, or
<xex>per</xex>oxide. <mark>[Obs.]</mark> See <er>Per-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyperactive</ent><br/
<hw>hyperactive</hw> <pos>a.</pos> <def>Exhibiting
hyperactivity.</def><br/
[<source>PJC</source>]</p>

<p><ent>hyperactivity</ent><br/
<hw>hyperactivity</hw> <pos>n.</pos> <def>An unusually high level of
activity; -- used especially with respect to children who move around
frequently and do not sit still very long, most noticeably in school. It
is sometimes associated with <er>attention deficit
disorder</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hyperaemia</ent><br/
\'d8<hw>Hy`per*<ae/"mi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ype`r</grk> over + <grk>a"i^ma</grk> blood.]</ety>
<fld>(Med.)</fld> <def>A superabundance or congestion of blood in an
organ or part of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Active hyper<ae/mia</b></col>, <cd>congestion due to
increased flow of blood to a part.</cd> -- <col><b>Passive
hyper<ae/mia</b></col>, <cd>interchange due to obstruction in the return
of blood from a part.</cd></cs></p>

<p>-- <wordforms><wf>Hy`per*<ae/"mic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperaesthesia</ent><br/
\'d8<hw>Hy`per*<ae/s*the"si*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>"ype`r</grk> over + <?/ sense,
perception.]</ety> <fld>(Med. & Physiol.)</fld> <def>A state of exalted
or morbidly increased sensibility of the body, or of a part of it.</def>
-- <wordforms><wf>Hy`per*<ae/s*thet"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperapophysis</ent><br/
\'d8<hw>Hy`per*a*poph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hyperapophyses</plw> <pr>(#)</pr>.</plu>
<ety>[NL. See <er>Hyper-</er>, and <er>Apophysis</er>.]</ety>
<fld>(Anat.)</fld> <def>A lateral and backward-projecting process on the
dorsal side of a vertebra.</def> --
<wordforms><wf>Hy`per*ap`o*phys"i*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperaspist</ent><br/
<hw>Hy`per*as"pist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr.
<?/ to cover with a shield; <grk>"ype`r</grk> over + <?/ shield.]</ety>
<def>One who holds a shield over another; hence, a defender.</def>
<mark>[Obs.]</mark> <rj><au>Chillingworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbaric</ent><br/
<hw>Hy`per*bar"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>hyper-</ets> + <ets>baric</ets>.]</ety> <sn>1.</sn> <def>Of,
pertaining to, or using a pressure that is greater than normal
atmospheric pressure; <as>as, a <ex>hyperbaric</ex> chamber, where
divers may decompress slowly to avoid the bends</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Of, pertaining to, or using an oxygen pressure that
is greater than that at normal atmospheric pressure; <as>as, a
<ex>hyperbaric</ex> tent to provide additional oxygen to patients with
breathing difficulty</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hyperbatic</ent><br/
<hw>Hy`per*bat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to an hyperbaton; transposed; inverted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbaton</ent><br/
\'d8<hw>Hy*per"ba*ton</hw> <pr>(h<imac/*p<etil/r"b<adot/*t<ocr/n)</pr>,
<pos>n.</pos> <ety>[L., fr. Gr. <grk>"ype`rbaton</grk>, fr.
<grk>"yperbato`s</grk> transposed, fr. <grk>"yperbai`nein</grk> to step
over; <grk>"ype`r</grk> over + <grk>bai`nein</grk> to step.]</ety>
<fld>(Gram.)</fld> <def>A figurative construction, changing or inverting
the natural order of words or clauses; <as>as, <ldquo/echoed the
hills<rdquo/ for <ldquo/the hills echoed</as>.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With a violent <qex>hyperbaton</qex> to transpose the text.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbola</ent><br/
<hw>Hy*per"bo*la</hw> <pr>(h<imac/*p<etil/r"b<osl/*l<adot/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"yperbolh`</grk>, prop., an overshooting,
excess, <it>i. e.</it>, of the angle which the cutting plane makes with
the base. See <er>Hyperbole</er>.]</ety> <fld>(Geom.)</fld> <def>A curve
formed by a section of a cone, when the cutting plane makes a greater
angle with the base than the side of the cone makes. It is a plane curve
such that the difference of the distances from any point of it to two
fixed points, called <xex>foci</xex>, is equal to a given distance. See
<er>Focus</er>. If the cutting plane be produced so as to cut the
opposite cone, another curve will be formed, which is also an hyperbola.
Both curves are regarded as branches of the same hyperbola. See
<xex>Illust.</xex> of <xex>Conic section</xex>, and
<er>Focus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbole</ent><br/
<hw>Hy*per"bo*le</hw> <pr>(h<imac/*p<etil/r"b<osl/*l<esl/)</pr>,
<pos>n.</pos> <ety>[L., fr. Gr <grk>"yperbolh`</grk>, prop., an
overshooting, excess, fr. Gr. <grk>"yperba`llein</grk> to throw over or
beyond; <grk>"ype`r</grk> over + <grk>ba`llein</grk> to throw. See
<er>Hyper-</er>, <er>Parable</er>, and cf. <er>Hyperbola</er>.]</ety>
<fld>(Rhet.)</fld> <def>A figure of speech in which the expression is an
evident exaggeration of the meaning intended to be conveyed, or by which
things are represented as much greater or less, better or worse, than
they really are; a statement exaggerated fancifully, through excitement,
or for effect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our common forms of compliment are almost all of them extravagant
<qex>hyperboles</qex>.</q> <rj><qau>Blair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Somebody has said of the boldest figure in rhetoric, the
<qex>hyperbole</qex>, that it lies without deceiving.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><ent>Hyperbolical</ent><br/
<ent>Hyperbolic</ent><br/
<mhw>{ <hw>Hy`per*bol"ic</hw> <pr>(h<imac/`p<etil/r*b<ocr/"<icr/k)</pr>,
<hw>Hy`per*bol"ic*al</hw>
<pr>(h<imac/`p<etil/r*b<ocr/"<icr/*k<ait/l)</pr>, }</mhw> <pos>a.</pos>
<ety>[L. <ets>hyperbolicus</ets>, Gr. <grk>"yperboliko`s</grk>: cf. F.
<ets>hyperbolique</ets>.]</ety> <sn>1.</sn> <fld>(Math.)</fld>
<def>Belonging to the hyperbola; having the nature of the
hyperbola.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rhet.)</fld> <def>Relating to, containing, or of
the nature of, hyperbole; exaggerating or diminishing beyond the fact;
exceeding the truth; <as>as, an <ex>hyperbolical</ex>
expression</as>.</def> <ldquo/This <xex>hyperbolical</xex>
epitaph.<rdquo/ <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyperbolic functions</b></col> <fld>(Math.)</fld>,
<cd>certain functions which have relations to the hyperbola
corresponding to those which sines, cosines, tangents, etc., have to the
circle; and hence, called <stype>hyperbolic sines</stype>,
<stype>hyperbolic cosines</stype>, etc.</cd> -- <col><b>Hyperbolic
logarithm</b></col>. <cd>See <er>Logarithm</er>.</cd> --
<col><b>Hyperbolic spiral</b></col> <fld>(Math.)</fld>, <cd>a spiral
curve, the law of which is, that the distance from the pole to the
generating point varies inversely as the angle swept over by the radius
vector.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 720 --></p>

<p><ent>Hyperbolically</ent><br/
<hw>Hy`per*bol"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<fld>(Math.)</fld> <def>In the form of an hyperbola.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rhet.)</fld> <def>With exaggeration; in a manner to
express more or less than the truth.</def> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperboliform</ent><br/
<hw>Hy`per*bol"i*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hyperbola</ets> + <ets>-form</ets>.]</ety> <def>Having the
form, or nearly the form, of an hyperbola.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbolism</ent><br/
<hw>Hy*per"bo*lism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>hyperbolisme</ets>.]</ety> <def>The use of hyperbole.</def>
<rj><au>Jefferson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbolist</ent><br/
<hw>Hy*per"bo*list</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who uses
hyperboles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbolize</ent><br/
<hw>Hy*per"bo*lize</hw> <pr>(?)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hyperbolized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Hyperbolizing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Cf. F. <ets>hyperboliser</ets>.]</ety>
<def>To speak or write with exaggeration.</def> <rj><au>Bp.
Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperbolize</ent><br/
<hw>Hy*per"bo*lize</hw>, <pos>v. t.</pos> <def>To state or represent
hyperbolically.</def> <rj><au>Fotherby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperboloid</ent><br/
<hw>Hy*per"bo*loid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hyperbola</ets> + <ets>-oid</ets>: cf. F.
<ets>hyperbolo<ium/de</ets>.]</ety> <fld>(Geom.)</fld> <def>A surface of
the second order, which is cut by certain planes in hyperbolas; also,
the solid, bounded in part by such a surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyperboloid of revolution</b></col>, <cd>an hyperboloid
described by an hyperbola revolving about one of its axes. The surface
has two separate sheets when the axis of revolution is the transverse
axis, but only one when the axis of revolution is the conjugate axis of
the hyperbola.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperboloid</ent><br/
<hw>Hy*per"bo*loid</hw>, <pos>a.</pos> <fld>(Geom.)</fld> <def>Having
some property that belongs to an hyperboloid or hyperbola.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperborean</ent><br/
<hw>Hy`per*bo"re*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hyperboreus</ets>, Gr. <?/; <grk>"ype`r</grk> over, beyond + <?/.
See <er>Boreas</er>.]</ety> <sn>1.</sn> <fld>(Greek Myth.)</fld> <def>Of
or pertaining to the region beyond the North wind, or to its
inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Northern; belonging to, or inhabiting, a region in
very far north; most northern; hence, very cold; fright, <as>as, a
<ex>hyperborean</ex> coast or atmosphere</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hyperborean</qex> or frozen sea.</q> <rj><qau>C. Butler
(1633).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperborean</ent><br/
<hw>Hy`per*bo"re*an</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Greek
Myth.)</fld> <def>One of the people who lived beyond the North wind, in
a land of perpetual sunshine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inhabitant of the most northern
regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercarbureted</ent><br/
<hw>Hy`per*car"bu*ret`ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Having an excessive proportion of carbonic acid;
-- said of bicarbonates or acid carbonates.</def> <altsp>[Written also
<asp>hypercarburetted</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercatalectic</ent><br/
<hw>Hy`per*cat`a*lec"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>hypercatalecticus</ets>, <ets>hypercatalectus</ets>, Gr. <?/: cf.
F. <ets>hypercatalectique</ets>. See <er>Hyper-</er>, and
<er>Catalectic</er>.]</ety> <fld>(Pros.)</fld> <def>Having a syllable or
two beyond measure; <as>as, a <ex>hypercatalectic</ex>
verse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperchloric</ent><br/
<hw>Hy`per*chlo"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>See <er>Perchloric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperchromatism</ent><br/
<hw>Hy`per*chro"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
condition of having an unusual intensity of color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercritic</ent><br/
<hw>Hy`per*crit"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hyper-</ets> + <ets>critic</ets>: cf. F.
<ets>hypercritique</ets>.]</ety> <def>One who is critical beyond measure
or reason; a carping critic; a captious censor.</def>
<ldquo/<xex>Hypercritics</xex> in English poetry.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercritic</ent><br/
<hw>Hy`per*crit"ic</hw>, <pos>a.</pos> <def>Hypercritical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercritical</ent><br/
<hw>Hy`per*crit"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Over critical; unreasonably or unjustly critical; carping;
captious.</def> <ldquo/<xex>Hypercritical</xex> readers.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excessively nice or exact.</def>
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercritically</ent><br/
<hw>Hy`per*crit"ic*al*ly</hw>, <pos>adv.</pos> <def>In a hypercritical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercriticise</ent><br/
<hw>Hy`per*crit"i*cise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
criticise with unjust severity; to criticise captiously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypercriticism</ent><br/
<hw>Hy`per*crit"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Excessive
criticism, or unjust severity or rigor of criticism; zoilism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hypercube</ent><br/
<hw>hypercube</hw> <pos>n.</pos> <def>A mathematical object existing in
more than three dimensions, analogous to the cube in that each
two-dimensional facet of the surface is a square; a generalization of a
cube in more than three dimensions.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hyperdicrotic</ent><br/
<hw>Hy`per*di*crot"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Excessive dicrotic; <as>as, a
<ex>hyperdicrotic</ex> pulse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperdicrotism</ent><br/
<hw>Hy`per*di"cro*tism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>A hyperdicrotic condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperdicrotous</ent><br/
<hw>Hy`per*di"cro*tous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Hyperdicrotic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperdulia</ent><br/
\'d8<hw>Hy`per*du*li"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hyper-</ets> + <ets>dulia</ets>: cf. F.
<ets>hyperdulie</ets>.]</ety> <fld>(R. C. Ch.)</fld> <def>Veneration or
worship given to the Virgin Mary as the most exalted of mere creatures;
higher veneration than dulia.</def> <rj><au>Addis &
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperduly</ent><br/
<hw>Hy"per*du`ly</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hyperdulia.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperesthesia</ent><br/
<hw>Hy`per*es*the"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hyper<ae/sthesia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyperegol</ent><br/
<hw>Hy"per*gol</hw> <pr>(h<imac/"p<etil/r*g<ocr/)</pr>, <pos>a.</pos>
<fld>(Rocketry)</fld> <def>A substance which can form one of a pair of
hypergolic substances. See <er>hypergolic</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hyperegolic</ent><br/
<hw>Hy`per*gol"ic</hw> <pr>(h<imac/`p<etil/r*g<ocr/"<icr/k)</pr>,
<pos>a.</pos> <fld>(Rocketry)</fld> <def>Igniting spontaneously when
mixed together; -- used of pairs of substances which react violently
with evolution of heat when mixed, as for example hydrazine and nitrogen
tetroxide. Such combinations of substances are convenient for use in
liquid-fueled rockets, as they do not require a source of
ignition.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypericum</ent><br/
\'d8<hw>Hy*per"i*cum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, <?/; <?/ under, among + <?/, <?/, heath, heather.]</ety>
<fld>(Bot.)</fld> <def>A genus of plants, generally with dotted leaves
and yellow flowers; -- called also <altname>St.
John's-wort</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyperinflation</ent><br/
<hw>hyperinflation</hw> <pos>n.</pos> <def>an unusually rapid rate of
monetary inflation, as when prices rise more than 100 per cent per
year.</def> <note>A famous example occurred in Germany after the first
World War, reaching its peak in the period 1923. When the hyperinflation
ended by 1924, the value of the mark had decreased by more than one
trillion times compared to its value in 1914. Periods of lesser
hyperinflation have occurred in many other countries, as in Russia in
1994.</note><br/
[<source>PJC</source>]</p>

<p><ent>Hyperinosis</ent><br/
\'d8<hw>Hy`per*i*no"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ype`r</grk> over + <?/, <?/, strength, fiber.]</ety>
<fld>(Med.)</fld> <def>A condition of the blood, characterized by an
abnormally large amount of fibrin, as in many inflammatory
diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperion</ent><br/
<hw>Hy*pe"ri*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <fld>(Class Myth.)</fld> <def>The god of the sun; in the
later mythology identified with Apollo, and distinguished for his
beauty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So excellent a king; that was, to this,<br/
<qex>Hyperion</qex> to a satyr.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperkinesis</ent><br/
\'d8<hw>Hy`per*ki*ne"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ype`r</grk> over + <?/ motion.]</ety> <fld>(Med.)</fld>
<def>Abnormally increased muscular movement; spasm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperkinetic</ent><br/
<hw>Hy`per*ki*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to hyperkinesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypermetamorphosis</ent><br/
<hw>Hy`per*met`a*mor"pho*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hyper-</ets> + <ets>metamorphosis</ets>.]</ety>
<fld>(Zool.)</fld> <def>A kind of metamorphosis, in certain insects, in
which the larva itself undergoes remarkable changes of form and
structure during its growth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypermeter</ent><br/
<hw>Hy*per"me*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ beyond
all measure; <grk>"ype`r</grk> over, beyond + <?/ measure: cf. F.
<ets>hyperm<egrave/tre</ets>.]</ety> <sn>1.</sn> <fld>(Pros.)</fld>
<def>A verse which has a redundant syllable or foot; a hypercatalectic
verse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, anything exceeding the ordinary
standard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a man rises beyond six foot, he is an
<qex>hypermeter</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypermetrical</ent><br/
<hw>Hy`per*met"ric*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
redundant syllable; exceeding the common measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypermetrical verse</b></col> <fld>(Gr. & Lat.
Pros.)</fld>, <cd>a verse which contains a syllable more than the
ordinary measure.</cd></cs></p>

<p><ent>Hypermetropy</ent><br/
<ent>Hypermetropia</ent><br/
<mhw>{ \'d8<hw>Hy`per*me*tro"pi*a</hw> <pr>(?)</pr>,
<hw>Hy`per*met"ro*py</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL.
<ets>hypermetropia</ets>, fr. Gr. <?/ excessive + <?/, <?/, the eye. See
<er>Hypermeter</er>.]</ety> <def>An abnormal condition of the eye in
which, through shortness of the eyeball or fault of the refractive
media, the rays of light come to a focus behind the retina, making
vision for distant objects better than for near objects; farsightedness;
-- now most commonly called <altname>hyperopia</altname>. Cf.
<er>Emmetropia</er>.</def> <mark>[Obsolescent]</mark> <br/
<syn><b>Syn. --</b> hyperopia, farsightedness,
longsightedness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In <xex>hypermetropia</xex>, vision for distant objects,
although not better absolutely, is better than that for near objects,
and hence, the individual is said to be farsighted. It is corrected by
the use of convex glasses.</note></p>

<p>-- <wordforms><wf>Hy`per*me*trop"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypermyriorama</ent><br/
\'d8<hw>Hy`per*myr`i*o*ra"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <?/ beyond + <?/ countless + <?/ view.]</ety> <def>A show or
exhibition having a great number of scenes or views.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hypernym</ent><br/
<hw>hypernym</hw> <pos>n.</pos> <def>a word that is more generic or more
abstract than a given word; a word designating a class of which the
given word is a member. Inverse of <inv>subtype</inv> and
<inv>hyponym</inv>.</def><br/
<syn><b>Syn. --</b> superordinate, superordinate word.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hypernymy</ent><br/
<hw>hypernymy</hw> <pos>n.</pos> <def>the relation of being
superordinate or belonging to a higher (more abstract) rank or class.
Inverse of <inv>hyponymy</inv>.</def><br/
<syn><b>Syn. --</b> superordination.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyperoartia</ent><br/
\'d8<hw>Hy`per*o*ar"ti*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>An order of marsipobranchs
including the lampreys. The suckerlike moth contains numerous teeth; the
nasal opening is in the middle of the head above, but it does not
connect with the mouth. See <er>Cyclostoma</er>, and
<er>Lamprey</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperodontidae</ent><br/
<hw>Hyperodontidae</hw> <pos>prop. n.</pos> <def>A natural family of
cetaceans comprising the beaked whales; in some, especially former,
classifications it included in the family
<fam>Physeteridae</fam>.</def><br/
<syn><b>Syn. --</b> Ziphiidae, family <fam>Ziphiidae</fam>, family
<fam>Hyperodontidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hyperon</ent><br/
<hw>hyperon</hw> <pos>n.</pos> <fld>(Physics)</fld> <def>Any baryon that
is not a nucleon; it is an unstable particle with a mass greater than
that of a neutron.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyperoodon</ent><br/
<hw>Hyperoodon</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld> <def>The
mammalian genus comprised of the bottle-nosed whales.</def><br/
<syn><b>Syn. --</b> genus <gen>Hyperoodon</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hyperope</ent><br/
<hw>hy"per*ope</hw> <pos>n.</pos> <def>a person with
hyperopia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyperopia</ent><br/
\'d8<hw>Hy`per*o"pi*a</hw>
<pr>(h<imac/`p<etil/r*<omac/"p<icr/*<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>"ype`r</grk> over + <grk>'w`ps</grk>,
<grk>'wpo`s</grk>, the eye.]</ety> <def>An abnormal condition of the eye
in which, through shortness of the eyeball or fault of the refractive
media, the rays of light come to a focus behind the retina, making
vision for distant objects better than for near objects; farsightedness;
-- called also <altname>hypermetropia</altname>. Cf.
<er>Emmetropia</er>.</def> -- <wordforms><wf>Hy`per*op"tic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
<syn><b>Syn. --</b> hypermetropia, farsightedness,
longsightedness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperorganic</ent><br/
<hw>Hy`per*or*gan"ic</hw>
<pr>(h<imac/`p<etil/r*<ocir/r*g<acr/n"<icr/k)</pr>, <pos>a.</pos>
<ety>[Pref. <ets>hyper-</ets> + <ets>organic</ets>.]</ety> <def>Higher
than, or beyond the sphere of, the organic.</def> <rj><au>Sir W.
Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyperorthodox</ent><br/
<hw>hy`per*or"tho*dox</hw>
<pr>(h<imac/`p<etil/r*<ocir/r"th<osl/*d<ocr/ks)</pr>, <pos>a.</pos>
<def>Orthodox to an excessive degree.</def><br/
<syn><b>Syn. --</b> ultraorthodox.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Hyperorthodoxy</ent><br/
<hw>Hy`per*or"tho*dox`y</hw>
<pr>(h<imac/`p<etil/r*<ocir/r"th<osl/*d<ocr/ks`<ycr/)</pr>,
<pos>n.</pos> <def>Orthodoxy pushed to excess.</def><br/
<syn><b>Syn. --</b> ultraorthodoxy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperotreta</ent><br/
\'d8<hw>Hy`per*o*tre"ta</hw>
<pr>(h<imac/`p<etil/r*<osl/*tr<emac/"t<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"yperw`,n</grk> the palate + <grk>trhto`s</grk>
perforated.]</ety> <fld>(Zool.)</fld> <def>An order of marsipobranchs,
including the Myxine or hagfish and the genus <gen>Bdellostoma</gen>.
They have barbels around the mouth, one tooth on the palate, and a
communication between the nasal aperture and the throat. See
<er>Hagfish</er>.</def> <altsp>[Written also
<asp>Hyperotreti</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperoxide</ent><br/
<hw>Hy`per*ox"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A compound having a relatively large percentage of oxygen; a
peroxide.</def> <mark>[Obs.]</mark></p>

<p><ent>Hyperoxygenized</ent><br/
<ent>Hyperoxygenated</ent><br/
<mhw>{ <hw>Hy`per*ox"y*gen*a`ted</hw> <pr>(?)</pr>,
<hw>Hy`per*ox"y*gen*ized</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Chem.)</fld> <def>Combined with a relatively large amount of
oxygen; -- said of higher oxides.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperoxymuriate</ent><br/
<hw>Hy`per*ox`y*mu"ri*ate</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A perchlorate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperoxymuriatic</ent><br/
<hw>Hy`per*ox`y*mu`ri*at"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Perchloric; <as>as, <ex>hyperoxymuriatic</ex>
acid</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperphysical</ent><br/
<hw>Hy`per*phys"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Above or
transcending physical laws; supernatural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those who do not fly to some <qex>hyperphysical</qex>
hypothesis.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperplasia</ent><br/
\'d8<hw>Hy`per*pla"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ype`r</grk> over + <?/ conformation, fr. <?/ to mold.]</ety>
<fld>(Med. & Biol.)</fld> <def>An increase in, or excessive growth of,
the normal elements of any part.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Hyperplasia</xex> relates to the formation of new
elements, <xex>hypertrophy</xex> being an increase in bulk of
preexisting normal elements.</note> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperplastic</ent><br/
<hw>Hy`per*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of
or pertaining to hyperplasia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Tending to excess of formative
action.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperpnoea</ent><br/
\'d8<hw>Hy`perp*n<oe/"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ype`r</grk> over + <?/, <?/, breath.]</ety>
<fld>(Physiol.)</fld> <def>Abnormal breathing, due to slightly deficient
arterialization of the blood; -- in distinction from
<contr>eupn<oe/a</contr>. See <er>Eupn<oe/a</er>, and
<er>Dispn<oe/a</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperpyrexia</ent><br/
\'d8<hw>Hy`per*py*rex"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hyper-</er>, and <er>Pyrexia</er>.]</ety> <fld>(Med.)</fld> <def>A
condition of excessive fever; an elevation of temperature in a disease,
in excess of the limit usually observed in that disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypersecretion</ent><br/
<hw>Hy`per*se*cre"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>Morbid or excessive secretion, as in
catarrh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypersensibility</ent><br/
<hw>Hy`per*sen`si*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hyper<ae/sthesia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hypersonic</ent><br/
<hw>hy`per*son"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hyper-</ets> + <ets>sonic</ets>.]</ety> <fld>(Aeronautics)</fld>
<def>Pertaining to or moving at a speed greatly in excess of the speed
of sound, usually meaning greater than mach 5. All speeds in excess of
the speed of sound are <contr>supersonic</contr>, but to be
<ex>hypersonic</ex> requires even higher speed.</def><br/
[<source>PJC</source>]</p>

<p><ent>hyperspace</ent><br/
<hw>hy"per*space</hw> <pr>(h<imac/"p<etil/r*sp<amac/s)</pr>,
<pos>n.</pos> <ety>[Pref. <ets>hyper-</ets> + <ets>space</ets>.]</ety>
<fld>(Geom.)</fld> <def>A mathematical space having more than three
dimensions. It is a mathematical construct and is not intended to
represent the structure of the common physical space in which matter
exists.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>hypersphere</ent><br/
<hw>hy"per*sphere</hw> <pr>(h<imac/"p<etil/r*sf<emac/r)</pr>,
<pos>n.</pos> <def>A mathematical object existing in more than three
dimensions, analogous to the sphere in that all points on the surface
are equidistant from the central point; a generalization of a sphere in
more than three dimensions.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypersthene</ent><br/
<hw>Hy"per*sthene</hw> <pr>(h<imac/"p<etil/r*sth<emac/n)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"ype`r</grk> over + <grk>sqe`nos</grk>
strength: cf. F. <ets>hyperst<egrave/ne</ets>.]</ety> <fld>(Min.)</fld>
<def>An orthorhombic mineral of the pyroxene group, of a grayish or
greenish black color, often with a peculiar bronzelike luster (schiller)
on the cleavage surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypersthenic</ent><br/
<hw>Hy`per*sthen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Min.)</fld>
<def>Composed of, or containing, hypersthene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hypertension</ent><br/
<hw>hypertension</hw> <pos>n.</pos> <def>abnormally high blood pressure;
especially, the chronic condition associated with persistent high blood
pressure.</def><br/
[<source>PJC</source>]</p>

<p><ent>hypertensive</ent><br/
<hw>hypertensive</hw> <pos>n.</pos> <sn>1.</sn> <def>having abnormally
high blood pressure.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Causing high blood pressure.</def><br/
[<source>PJC</source>]</p>

<p><ent>hypertensive</ent><br/
<hw>hypertensive</hw> <pos>n.</pos> <def>A person who suffers from
persistently high blood pressure.</def><br/
[<source>PJC</source>]</p>

<p><ent>hyperthermy</ent><br/
<ent>hyperthermia</ent><br/
<mhw><hw>hyperthermia</hw>, <hw>hyperthermy</hw></mhw> <pos>n.</pos>
<def>abnormally high body temperature.</def><br/
<syn><b>Syn. --</b> hyperthermy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyperthetical</ent><br/
<hw>Hy`per*thet"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/;
<grk>"ype`r</grk> over + <grk>tiqe`nai</grk> to place.]</ety>
<def>Exaggerated; excessive; hyperbolical.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hyperthetical</qex> or superlative . . . expression.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyperthyrion</ent><br/
\'d8<hw>Hy`per*thyr"i*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/; <grk>"ype`r</grk> over + <?/ door.]</ety> <fld>(Arch.)</fld>
<def>That part of the architrave which is over a door or
window.</def></p>

<p><ent>hypertonic</ent><br/
<hw>hy`per*ton"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hyper-</ets> + <ets>tonic</ets>.]</ety> <fld>(Physiology,
Biochemistry)</fld> <def>Having a higher osmotic pressure than a
comparison solution; -- of an aqueous solution. Increasing the
concentration of dissolved solids increases the osmotic pressure, and
thus the tonicity of a solution. Opposite of <ant>hypotonic</ant> and
contrasting with <contr>isotonic</contr>.</def> <wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><q>A knowledge of the colligative properties of solutions . . . is
essential for one to understand fully the principles involved in
rendering intravenous solutions isotonic with blood serum, or opthalmic
solutions isotonic with lachrymal fluid. Solutions thus adjusted produce
less shock and much less irritation than those which are hypotonic or
<qex>hypertonic</qex>, and present-day practise recognizes the
desirability of making the necessary adjustments whenever possible.</q>
<rj><qau>Cook & Martin (Remington's Practice of Pharmacy, Tenth Ed.:
Mack Publ., Easton Pa., 1951)</qau></rj></p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>Having an osmotic
pressure greater than that of blood plasma, which is approximately that
of a 0.2 normal solution of sodium chloride. Cells taken from a medium
of normal physiological osmolality and placed in a hypertonic medium
will shrink.</def> <wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>in a state of abnormally high tension; -- of
muscle.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> pumped-up.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hyperthyroidism</ent><br/
<hw>hyperthyroidism</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>An
abnormality of the thyroid gland characterized by the pathologically
excessive production of thyroid hormones; -- also, the resulting
condition characterized by increased metabolism, weight loss, rapid
heart rate, high blood pressure, an enlarged thyroid gland and sometimes
exophthalmos. It leads to, and may be confirmed by, high plasma levels
of triiodothyronine or thyroxin.</def><br/
<syn><b>Syn. --</b> thyrotoxicosis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hypertrophical</ent><br/
<ent>Hypertrophic</ent><br/
<mhw>{ <hw>Hy`per*troph"ic</hw> <pr>(?)</pr>,
<hw>Hy`per*troph"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Cf. F. <ets>hypertrophique</ets>.]</ety> <fld>(Med. & Biol.)</fld>
<def>Of or pertaining to hypertrophy; affected with, or tending to,
hypertrophy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypertrophied</ent><br/
<hw>Hy*per"tro*phied</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med. &
Biol.)</fld> <def>Excessively developed; characterized by
hypertrophy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypertrophy</ent><br/
<hw>Hy*per"tro*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ype`r</grk> over, beyond + <?/ nourishment, fr. <?/ to nourish:
cf. F. <ets>hypertrophie</ets>.]</ety> <fld>(Med. & Biol.)</fld> <def>A
condition of overgrowth or excessive development of an organ or part; --
the opposite of <ant>atrophy</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyperventilate</ent><br/
<hw>hyperventilate</hw> <pos>v. i.</pos> <def>to breathe rapidly and
deeply; to breathe excessively; <as>as, The mountain climber started to
<ex>hyperventilate</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hyperventilation</ent><br/
<hw>hyperventilation</hw> <pos>n.</pos> <sn>1.</sn> <def>The act or
process of hyperventilating; breathing rapidly and deeply.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A condition in which alveolar
carbon dioxide concentration is markedly lower than normal, usually due
to breathing rapidly and deeply.</def><br/
[<source>PJC</source>]</p>

<p><ent>hypha</ent><br/
<hw>hypha</hw> <pr>(#)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>hyphae</plw> <pr>(#)</pr>.</plu> <def>any of the threadlike
filaments forming the mycelium of a fungus. See
<er>hyphae</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyphantria</ent><br/
<hw>Hyphantria</hw> <pos>n.</pos> <def>A genus of moths whose larvae are
called <er>fall webworms</er>.</def><br/
<syn><b>Syn. --</b> genus <gen>Hyphantria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyphae</ent><br/
\'d8<hw>Hy"ph<ae/</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>"yfh`</grk> a web.]</ety> <fld>(Bot.)</fld> <def>The long,
branching filaments of which the mycelium (and the greater part of the
plant) of a fungus is formed. They are also found enveloping the gonidia
of lichens, making up a large part of their structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyphen</ent><br/
<hw>Hy"phen</hw> <pr>(h<imac/"f<ecr/n)</pr>, <pos>n.</pos> <ety>[L., fr.
Gr. <grk>"yfe`n</grk>, fr. <grk>"yf "e`n</grk> under one, into one,
together, fr. <?/ under + <?/, neut. of <?/ one. See
<er>Hypo-</er>.]</ety> <fld>(Print.)</fld> <def>A mark or short dash,
thus [-], placed at the end of a line which terminates with a syllable
of a word, the remainder of which is carried to the next line; or
between the parts of many a compound word; as in <xex>fine-leaved</xex>,
<xex>clear-headed</xex>. It is also sometimes used to separate the
syllables of words.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyphen</ent><br/
<hw>Hy"phen</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Hyphened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Hyphening</conjf>.]</vmorph> <def>To connect with, or separate
by, a hyphen, as two words or the parts of a word.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyphenated</ent><br/
<hw>Hy"phen*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>United by
hyphens; hyphened; <as>as, a <ex>hyphenated</ex> or hyphened
word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyphenated American</ent><br/
<hw>Hyphenated American</hw>. <def>An American who is referred to by a
hyphenated term with the first word indicating an origin in a foreign
country, and the second term being <ldquo/American<rdquo/, as
<stype>Irish-American</stype>, <stype>Italian-American</stype>,
<stype>African-American</stype>, <stype>Asian-American</stype>.</def>
<mark>Used in reference to Americans of foreign birth or ancestry. When
used of Americans of European ancestry, it is often used to refer to
those who have a strong attachment to the ancestral country or its
culture. It implies that the individual is imperfectly assimilated into
American culture, and is sometimes used derogatively.</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hyphomycetes</ent><br/
\'d8<hw>Hy`pho*my*ce"tes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ a web + <?/, <?/, a mushroom.]</ety> <fld>(Bot.)</fld>
<def>One of the great division of fungi, containing those species which
have naked spores borne on free or only fasciculate threads.</def>
<rj><au>M. J. Berkley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypidiomorphic</ent><br/
<hw>Hy*pid`i*o*mor"phic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>idiomorphic</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Partly idiomorphic; -- said of rock a
portion only of whose constituents have a distinct crystalline
form.</def> -- <wordforms><wf>Hy*pid`i*o*mor"phic*al*ly</wf>
<pr>(#)</pr>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypinosis</ent><br/
\'d8<hw>Hyp`i*no"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ under + <?/, <?/ strength, fiber.]</ety> <fld>(Med.)</fld> <def>A
diminution in the normal amount of fibrin present in the
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnagogic</ent><br/
<hw>Hyp`na*gog"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ sleep +
<?/ a carrying away.]</ety> <def>Leading to sleep; -- applied to the
illusions of one who is half asleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnobate</ent><br/
<hw>Hyp"no*bate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Gr. <?/
sleep + <?/ to go.]</ety> <def>A somnambulist.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnocyst</ent><br/
<hw>Hyp"no*cyst</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ sleep +
E. <ets>cyst</ets>.]</ety> <fld>(Biol.)</fld> <def>A cyst in which some
unicellular organisms temporarily inclose themselves, from which they
emerge unchanged, after a period of drought or deficiency of food. In
some instances, a process of spore formation seems to occur within such
cysts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnogenic</ent><br/
<hw>Hyp`no*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ sleep +
root of <grk>gi`gnesqai</grk> to be born.]</ety> <fld>(Physiol.)</fld>
<def>Relating to the production of hypnotic sleep; <as>as, the so-called
<ex>hypnogenic</ex> pressure points, pressure upon which is said to
cause an attack of hypnotic sleep</as>.</def> <rj><au>De
Watteville.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnologist</ent><br/
<hw>Hyp*nol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
versed in hypnology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnology</ent><br/
<hw>Hyp*nol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ sleep +
<ets>-logy</ets>.]</ety> <def>A treatise on sleep; the doctrine of
sleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnoscope</ent><br/
<hw>Hyp"no*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ +
<ets>-scope</ets>.]</ety> <fld>(Physiol.)</fld> <def>An instrument for
ascertaining the susceptibility of a person to hypnotic
influences.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hypnosis</ent><br/
\'d8<hw>Hyp*no"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ sleep.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>Supervention of
sleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The condition of being hypnotized or the process of
hypnotizing a person; hypnotism{1}.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Hypnotic</ent><br/
<hw>Hyp*not"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ inclined
to sleep, putting to sleep, fr. <?/ to lull to sleep, fr. <?/ sleep;
akin to L. <ets>somnus</ets>, and E. <ets>somnolent</ets>: cf. F.
<ets>hypnotique</ets>.]</ety> <sn>1.</sn> <def>Having the quality of
producing sleep; tending to produce sleep; soporific.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to hypnotism; in a state of
hypnotism; liable to hypnotism; <as>as, a <ex>hypnotic</ex>
condition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnotic</ent><br/
<hw>Hyp*not"ic</hw>, <pos>n.</pos> <sn>1.</sn> <def>Any agent that
produces, or tends to produce, sleep; an opiate; a soporific; a
narcotic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who exhibits the phenomena of, or is
subject to, hypnotism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnotism</ent><br/
<hw>Hyp"no*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ sleep:
cf. F. <ets>hypnotisme</ets>.]</ety> <sn>1.</sn> <def>A form of sleep or
trance, in some respects resembling somnambulism, but brought on by
artificial means, in which there is an unusual suspension of some
powers, and an unusual activity of others, especially a heightened
susceptibility to suggestion. It is induced by an action upon the
nerves, through the medium of the senses, by causing the subject to gaze
steadily at a very bright object held before the eyes, or on an
oscillating object, or by pressure upon certain points of the surface of
the body, usually accompanied by the speaking of the hypnotist in quiet
soothing tones. Called also <altname>hypnosis</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The science which deals with the induction and
properties of the hypnotic state.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypnotist</ent><br/
<hw>Hyp"no*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person who
hypnotizes another, especially one who is professionally trained in the
technique.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypnotization</ent><br/
<hw>Hyp`no*ti*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of producing hypnotism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnotize</ent><br/
<hw>Hyp"no*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Hypnotized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Hypnotizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
induce hypnotism in; to place in a state of hypnotism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnotizer</ent><br/
<hw>Hyp"no*ti`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
hypnotizes; a hypnotist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypnum</ent><br/
\'d8<hw>Hyp"num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
moss.]</ety> <fld>(Bot.)</fld> <def>The largest genus of true mosses;
feather moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypo-</ent><br/
<hw>Hy"po-</hw> <pr>(?)</pr>. <ety>[Gr. <?/ under, beneath; akin to L.
<ets>sub</ets>. See <er>Sub-</er>.]</ety> <sn>1.</sn> <def>A prefix
signifying a <xex>less quantity</xex>, or a <xex>low state</xex> or
<xex>degree</xex>, of that denoted by the word with which it is joined,
or position <xex>under</xex> or <xex>beneath</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A prefix denoting that the
element to the name of which it is prefixed enters with a <xex>low
valence</xex>, or in a <xex>low state of oxidization</xex>, usually the
<xex>lowest</xex>, into the compounds indicated; <as>as,
<ex>hypo</ex>sulphurous acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypo</ent><br/
<hw>Hy"po</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hypochondria.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypo</ent><br/
<hw>Hy"po</hw>, <pos>n.</pos> <ety>[Abbrev. from
<ets>hyposulphite</ets>.]</ety> <fld>(Photog.)</fld> <def>Sodium
hyposulphite, or thiosulphate, a solution of which is used as a bath to
wash out the unchanged silver salts in a picture.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoarian</ent><br/
<hw>Hy`po*a"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to a hypoarion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoarion</ent><br/
\'d8<hw>Hy`po*a"ri*on</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hypoaria</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr.
Gr. <grk>"ypo`</grk> beneath + <?/ a little egg.]</ety>
<fld>(Anat.)</fld> <def>An oval lobe beneath each of the optic lobes in
many fishes; one of the inferior lobes.</def>
<rj><au>Owen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoblast</ent><br/
<hw>Hy"po*blast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>-blast</ets>.]</ety> <fld>(Biol.)</fld> <def>The
inner or lower layer of the blastoderm; -- called also
<altname>endoderm</altname>, <altname>entoderm</altname>, and sometimes
<altname>hypoderm</altname>. See <xex>Illust.</xex> of
<er>Blastoderm</er>, <er>Delamination</er>, and
<er>Ectoderm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoblastic</ent><br/
<hw>Hy`po*blas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Relating to, or connected with, the hypoblast; <as>as, the
<ex>hypoic</ex> sac</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypobole</ent><br/
<hw>Hy*pob"o*le</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
throwing under, a suggesting; <?/ under + <?/ to throw.]</ety>
<fld>(Rhet.)</fld> <def>A figure in which several things are mentioned
that seem to make against the argument, or in favor of the opposite
side, each of them being refuted in order.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypobranchial</ent><br/
<hw>Hy`po*bran"chi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>branchial</ets>.]</ety> <fld>(Anat.)</fld>
<def>Pertaining to the segment between the basibranchial and the
ceratobranchial in a branchial arch.</def> -- <def2><pos>n.</pos> <def>A
hypobranchial bone or cartilage.</def></def2></p>

<p><ent>Hypocarpium</ent><br/
<ent>Hypocarp</ent><br/
<mhw>{ <hw>Hy"po*carp</hw> <pr>(?)</pr>, \'d8<hw>Hy`po*car"pi*um</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>hypocarpium</ets>,
fr. Gr. <grk>"ypo`</grk> beneath + <?/ fruit.]</ety> <fld>(Bot.)</fld>
<def>A fleshy enlargement of the receptacle, or for the stem, below the
proper fruit, as in the cashew. See <xex>Illust.</xex> of
<er>Cashew</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 721 --></p>

<p><ent>Hypocarpogean</ent><br/
<hw>Hy`po*car`po*ge"an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ fruit + <?/ earth.]</ety> <fld>(Bot.)</fld>
<def>Producing fruit below the ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocaust</ent><br/
<hw>Hyp"o*caust</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>hypocaustum</ets>, Gr. <?/; <?/ under + <?/ to burn: cf. F.
<ets>hypocauste</ets>.]</ety> <fld>(Anc. Arch.)</fld> <def>A furnace,
esp. one connected with a series of small chambers and flues of tiles or
other masonry through which the heat of a fire was distributed to rooms
above. This contrivance, first used in bath, was afterwards adopted in
private houses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochlorite</ent><br/
<hw>Hy`po*chlo"rite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of hypochlorous acid; <as>as, a calcium
<ex>hypochloride</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochlorous</ent><br/
<hw>Hy`po*chlo"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>chlorous</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, chlorine having a valence lower
than in chlorous compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypochlorous acid</b></col> <fld>(Chem.)</fld>, <cd>an
acid derived from chlorine, not known in a pure state, but forming
various salts, called hypochlorites.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondres</ent><br/
<hw>Hy`po*chon"dres</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>hypocondres</ets>, formerly spely <ets>hypochondres</ets>.]</ety>
<def>The hypochondriac regions. See <er>Hypochondrium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondria</ent><br/
<hw>Hy`po*chon"dri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Med.)</fld> <def>An excessive concern about one's own health,
particularly a morbid worry about illnesses which a person imagines are
affecting him, often focusing on specific symptoms; also called
<altname>hypochondriasis</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Hypochondriac</ent><br/
<hw>Hy`po*chon"dri*ac</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
affocated in the hypochondrium: cf. F. <ets>hypocondriaque</ets>,
formerly spelt <ets>hypochondriaque</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to hypochondria, or the hypochondriac regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affected, characterized, or produced, by
hypochondriasis.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypochondriac region</b></col> <fld>(Anat.)</fld>, <cd>a
region on either side of the abdomen beneath the cartilages of the false
ribs, beside the epigastric, and above the lumbar, region.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondriac</ent><br/
<hw>Hy`po*chon"dri*ac</hw>, <pos>n.</pos> <def>A person affected with
hypochondria.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had become an incurable <qex>hypochondriac</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondriacal</ent><br/
<hw>Hy`po*chon"dri*a*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Hypochondriac</er>, 2.</def> --
<wordforms><wf>Hy`po*chon"dri*a*cal*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondriacism</ent><br/
<hw>Hy`po*chon"dri*a*cism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>Hypochondriasis.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondriasis</ent><br/
<hw>Hy`po*chon"dri*a*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So
named because supposed to have its seat in the hypochondriac regions.
See <er>Hypochondriac</er>, <er>Hypochondrium</er>, and cf.
<er>Hyp</er>, 1st <er>Hypo</er>.]</ety> <fld>(Med.)</fld> <def>A mental
disorder in which melancholy and gloomy views torment the affected
person, particularly concerning his own health; a morbid and deluded
belief that one is afflicted with disease.</def><br/
<syn><b>Syn. --</b> hypochondria.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondriasm</ent><br/
<hw>Hy`po*chon"dri*asm</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>Hypochondriasis.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondrium</ent><br/
\'d8<hw>Hy`po*chon"dri*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hypochondria</plw> <pr>(#)</pr>, E.
<plw>Hypochondriums</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. Gr. <?/,
from <?/ under the cartilage of the breastbone; <?/ under + <?/
cartilage.]</ety> <fld>(Anat.)</fld> <def>Either of the hypochondriac
regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypochondry</ent><br/
<hw>Hy`po*chon"dry</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Hypochondriasis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocist</ent><br/
<hw>Hyp"o*cist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a plant
growing on the roots of the <ets>Cistus</ets>.]</ety> <def>An astringent
inspissated juice obtained from the fruit of a plant (<spn>Cytinus
hypocistis</spn>), growing from the roots of the <gen>Cistus</gen>, a
small European shrub.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocleidium</ent><br/
\'d8<hw>Hy`po*clei"di*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hypocleida</plw> <pr>(#)</pr>, E.
<plw>Hypocleidiums</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/
under + <?/ a little key.]</ety> <fld>(Anat.)</fld> <def>A median
process on the furculum, or merrythought, of many birds, where it is
connected with the sternum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocoristic</ent><br/
<hw>Hyp`o*co*ris"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/; <?/
under + <?/ to caress.]</ety> <def>Endearing; diminutive; <as>as, the
<ex>hypocoristic</ex> form of a name</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hypocoristic</qex> or pet form of William.</q>
<rj><qau>Dr. Murray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocrateriform</ent><br/
<hw>Hyp`o*cra*ter"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <grk>krath`r</grk> cup + <ets>-form</ets>.]</ety>
<fld>(Bot.)</fld> <def>hypocraterimorphous; salver-shaped.</def>
<rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocraterimorphous</ent><br/
<hw>Hyp`o*cra*ter`i*mor"phous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[Pref. <ets>hypo-</ets> + Gr. <grk>krath`r</grk> bowl +
<grk>morfh`</grk> form.]</ety> <fld>(Bot.)</fld> <def>Salver-shaped;
having a slender tube, expanding suddenly above into a bowl-shaped or
spreading border, as in the blossom of the phlox and the
lilac.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocrisy</ent><br/
<hw>Hy*poc"ri*sy</hw> <pr>(h<icr/*p<ocr/k"r<icr/*s<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Hypocrisies</plw>
<pr>(-s<icr/z)</pr>.</plu> <ety>[OE. <ets>hypocrisie</ets>,
<ets>ypocrisie</ets>, OF. <ets>hypocrisie</ets>, <ets>ypocrisie</ets>,
F. <ets>hypocrisie</ets>, L. <ets>hypocrisis</ets>, fr. Gr.
<grk>"ypo`krisis</grk> the playing a part on the stage, simulation,
outward show, fr. <grk>"ypokri`nesqai</grk> to answer on the stage, to
play a part; <grk>"ypo`</grk> under + <grk>kri`nein</grk> to decide; in
the middle voice, to dispute, contend. See <er>Hypo-</er>, and
<er>Critic</er>.]</ety> <def>The act or practice of a hypocrite; a
feigning to be what one is not, or to feel what one does not feel; a
dissimulation, or a concealment of one's real character, disposition, or
motives; especially, the assuming of false appearance of virtue or
religion; a simulation of goodness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hypocrisy</qex> is the necessary burden of villainy.</q>
<rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hypocrisy</qex> is the homage vice pays to virtue.</q>
<rj><qau>La Rochefoucauld (Trans. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocrite</ent><br/
<hw>Hyp"o*crite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>hypocrita</ets>, Gr. <?/ one who plays a part on the stage, a
dissembler, feigner. See <er>Hypocrisy</er>.]</ety> <def>One who plays a
part; especially, one who, for the purpose of winning approbation of
favor, puts on a fair outside seeming; one who feigns to be other and
better than he is; a false pretender to virtue or piety; one who
simulates virtue or piety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>hypocrite's</qex> hope shall perish.</q> <rj><qau>Job
viii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I dare swear he is no <qex>hypocrite</qex>, but prays from his
heart.</q> <rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Deceiver; pretender; cheat. See
<er>Dissembler</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocritely</ent><br/
<hw>Hyp"o*crite*ly</hw>, <pos>adv.</pos> <def>Hypocritically.</def>
<mark>[R.]</mark> <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocritic</ent><br/
<hw>Hyp`o*crit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Hypocritical</er>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocritical</ent><br/
<hw>Hyp`o*crit"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/: cf.
F. <ets>hypocritique</ets>.]</ety> <def>Of or pertaining to a hypocrite,
or to hypocrisy; <as>as, a <ex>hypocritical</ex>person; a
<ex>hypocritical</ex> look; a <ex>hypocritical</ex>
action.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Hypocritical</qex> professions of friendship and of pacific
intentions were not spared.</q> <rj><qau>Macaulay.</qau></rj></p>

<p>-- <wordforms><wf>Hyp`o*crit"ic*al*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocrystalline</ent><br/
<hw>Hyp`o*crys"tal*line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>crystalline</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Partly crystalline; -- said of rock which
consists of crystals imbedded in a glassy ground mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypocycloid</ent><br/
<hw>Hy`po*cy"cloid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>cycloid</ets>: cf. F.
<ets>hypocyclo<ium/de</ets>.]</ety> <fld>(Geom.)</fld> <def>A curve
traced by a point in the circumference of a circle which rolls on the
concave side in the fixed circle. Cf. <er>Epicycloid</er>, and
<er>Trochoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypodactylum</ent><br/
\'d8<hw>Hyp`o*dac"ty*lum</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-tyla</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr.
Gr. <grk>"ypo`</grk> beneath + <?/ a finger, toe.]</ety>
<fld>(Zool.)</fld> <def>The under side of the toes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoderm</ent><br/
<hw>Hyp"o*derm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>-derm</ets>.]</ety> <fld>(Biol.)</fld> <def>Same
as <er>Hypoblast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoderma</ent><br/
\'d8<hw>Hyp`o*der"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hypo</er>, and <er>derma</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>A layer of tissue beneath the epidermis in plants, and performing
the physiological function of strengthening the epidermal tissue. In
phanerogamous plants it is developed as
<xex>collenchyma</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>An inner cellular layer which
lies beneath the chitinous cuticle of arthropods, annelids, and some
other invertebrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypodermatic</ent><br/
<hw>Hyp`o*der*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hypodermic.</def></p>

<p>-- <wordforms><wf>Hyp`o*der*mat"ic*al*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypodermic</ent><br/
<hw>Hyp`o*der"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Hypoderma</er>.]</ety> <def>Of or pertaining to the parts under the
skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypodermic medication</b></col>, <cd>the application of
remedies under the epidermis, usually by means of a small syringe,
called the hypodermic syringe.</cd></cs></p>

<p>-- <wordforms><wf>Hyp`o*der"mic*al*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>hypodermic</ent><br/
<hw>hyp`o*der"mic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A <er>hypodermic
needle</er>{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypodermic needle</ent><br/
<hw>Hyp`o*der"mic need"le</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A small slender hollow metallic tube, sharp-pointed at one end and
fitted at the other end with an adapter of larger internal diameter,
designed for introduction of liquids directly into the bloodstream or
other parts of the body of an animal.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a <er>hypodermic needle{1}</er> together with an
attached syringe.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypodermic syringe</ent><br/
<hw>Hyp`o*der"mic syr"inge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a small
syringe designed for use together with a <er>hypodermic needle{1}</er>
for injection of liquids directly under the skin, or into other parts of
the body of an animal.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypodermis</ent><br/
\'d8<hw>Hyp`o*der"mis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hypo-</er>, and <er>Derma</er>.]</ety> <sn>1.</sn>
<fld>(Biol.)</fld> <def>Same as <er>Hypoblast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Same as <er>Hypoderma</er>,
2.</def></p>

<p><ent>Hypodicrotous</ent><br/
<ent>Hypodicrotic</ent><br/
<mhw>{ <hw>Hyp`o*di*crot"ic</hw> <pr>(?)</pr>,
<hw>Hyp`o*di"cro*tous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Exhibiting retarded dicrotism; <as>as, a
<ex>hypodicrotic</ex> pulse curve</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogaeic</ent><br/
<hw>Hyp`o*g<ae/"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <grk>gai^a</grk>, <grk>gh^</grk>, earth.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or obtained from, the peanut, or
earthnut (<spn>Arachis hypog<ae/a</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypog<ae/ic acid</b></col> <fld>(Chem.)</fld>, <cd>an
acid in the oil of the earthnut, in which it exists as a glyceride, and
from which it is extracted as a white, crystalline
substance.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogastric</ent><br/
<hw>Hyp`o*gas"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>hypogastrique</ets>. See <er>Hypogastrium</er>.]</ety>
<fld>(Anat.)</fld> <def>Of or pertaining to the hypogastrium or the
hypogastric region.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypogastric region</b></col>. <sd>(a)</sd> <cd>The lower
part of the abdomen.</cd> <sd>(b)</sd> <cd>An arbitrary division of the
abdomen below the umbilical and between the two iliac
regions.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogastrium</ent><br/
\'d8<hw>Hyp`o*gas"tri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/; <?/ under + <?/ belly.]</ety> <fld>(Anat.)</fld> <def>The lower
part of the abdomen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogean</ent><br/
<hw>Hyp`o*ge"an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ earth.]</ety> <fld>(Bot.)</fld>
<def>Hypogeous.</def> <altsp>[Written also
<asp>hypog<ae/an</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogene</ent><br/
<hw>Hyp"o*gene</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + the root of Gr. <grk>gi`gnesqai</grk> to be born: cf.
F. <ets>hypog<egrave/ne</ets>.]</ety> <fld>(Geol.)</fld> <def>Formed or
crystallized at depths beneath the earth's surface; -- said of granite,
gneiss, and other rocks, whose crystallization is believed of have taken
place beneath a great thickness of overlying rocks. Opposed to
<contr>epigene</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogeous</ent><br/
<hw>Hyp`o*ge"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Hypogean</er>.]</ety> <fld>(Bot.)</fld> <def>Growing under ground;
remaining under ground; ripening its fruit under ground.</def>
<altsp>[Written also <asp>hypog<ae/ous</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogeum</ent><br/
\'d8<hw>Hyp`o*ge"um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hypogea</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. Gr. <?/, <?/,
subterranean; <?/ under + <?/, <?/, the earth.]</ety> <fld>(Anc.
Arch.)</fld> <def>The subterraneous portion of a building, as in
amphitheaters, for the service of the games; also, subterranean
galleries, as the catacombs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoglossal</ent><br/
<hw>Hyp`o*glos"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ the tongue.]</ety> <fld>(Anat.)</fld>
<def>Under the tongue; -- applied esp., in the higher vertebrates, to
the twelfth or last pair of cranial nerves, which are distributed to the
base of the tongue.</def> -- <def2><pos>n.</pos> <def>One of the
hypoglossal nerves.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypognatous</ent><br/
<hw>Hy*pog"na*tous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ the jaw.]</ety> <fld>(Zool.)</fld>
<def>Having the maxilla, or lower jaw, longer than the upper, as in the
skimmer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogyn</ent><br/
<hw>Hyp"o*gyn</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>An
hypogynous plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypogynous</ent><br/
<hw>Hy*pog"y*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ woman, female: cf. F.
<ets>hypogyne</ets>.]</ety> <fld>(Bot.)</fld> <def>Inserted below the
pistil or pistils; -- said of sepals, petals, and stamens; having the
sepals, petals, and stamens inserted below the pistil; -- said of a
flower or a plant.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypohyal</ent><br/
<hw>Hy`po*hy"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Greek letter <?/.]</ety> <fld>(Anat.)</fld>
<def>Pertaining to one or more small elements in the hyoidean arch of
fishes, between the caratohyal and urohyal.</def> -- <def2><pos>n.</pos>
<def>One of the hypohyal bones or cartilages.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyponastic</ent><br/
<hw>Hy`po*nas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ pressed close.]</ety> <fld>(Bot.)</fld>
<def>Exhibiting a downward convexity caused by unequal growth. Cf.
<er>Epinastic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyponasty</ent><br/
<hw>Hy`po*nas"ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Downward convexity, or convexity of the inferior surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyponitrite</ent><br/
<hw>Hy`po*ni"trite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of hyponitrous acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyponitrous</ent><br/
<hw>Hy`po*ni"trous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>nitrous</ets>.]</ety> <fld>(Chem.)</fld>
<def>Containing or derived from nitrogen having a lower valence than in
nitrous compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyponitrous acid</b></col> <fld>(Chem.)</fld>, <cd>an
unstable nitrogen acid, <chform>NOH</chform>, whose salts are produced
by reduction of the nitrates, although the acid itself is not isolated
in the free state except as a solution in water; -- called also
<altname>nitrosylic acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>hyponym</ent><br/
<hw>hyponym</hw> <pos>n.</pos> <fld>(linguistics)</fld> <def>a word that
is more specific (less abstract) than a given word; a term designating a
class which is a subtype of the given word; a subcategory; a subtype.
Inverse of <inv>hypernym</inv>; <as>as, <ldquo/dog<rdquo/ is a
<ex>hyponym</ex> of <ldquo/mammal<rdquo/, and <ldquo/mammal<rdquo/ is a
<ex>hyponym</ex> of <ldquo/vertebrate<rdquo/</as>.</def><br/
<syn><b>Syn. --</b> subordinate, subordinate word.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>hyponymy</ent><br/
<hw>hyponymy</hw> <pos>n.</pos> <fld>(Linguistics)</fld> <def>The state
or quality of being a hyponym; <as>as, <ex>hyponymy</ex> is symbolized
by the tag <ldquo/hypon<rdquo/</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Hypopharynx</ent><br/
\'d8<hw>Hy`po*phar"ynx</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Hypo-</er>, and <er>Pharynx</er>.]</ety> <fld>(Zool.)</fld> <def>An
appendage or fold on the lower side of the pharynx, in certain
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophosphate</ent><br/
<hw>Hy`po*phos"phate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of hypophosphoric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophosphite</ent><br/
<hw>Hy`po*phos"phite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of hypophosphorous acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophosphoric</ent><br/
<hw>Hy`po*phos*phor"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>phosphoric</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, or containing, phosphorus in a
lower state of oxidation than in phosphoric compounds; <as>as,
<ex>hypophosphoric</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypophosphoric acid</b></col> <fld>(Chem.)</fld>, <cd>an
acid, <chform>P2H4O6</chform>, produced by the slow oxidation of moist
phosphorus, and isolated only as a solution in water. It is regarded as
a condensation product of one molecule of phosphoric acid with one of
phosphorous acid, by partial dehydration.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophosphorous</ent><br/
<hw>Hy`po*phos"phor*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>phosphorous</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or containing, phosphorus in a lower state of
oxidation than in phosphoric compounds; <as>as, <ex>hypophosphorous</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypophosphorous acid</b></col> <fld>(Chem.)</fld> <cd>,
an acid, <chform>H3PO2</chform>, whose salts are produced by the action
of barium hygrate on phosphorus. It may be obtained from its water
solution, by exaporation and freezing, as a white crystalline substance.
It is a powerful reducing agent.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophyllous</ent><br/
<hw>Hy*poph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ leaf.]</ety> <fld>(Bot.)</fld> <def>Being or
growing on the under side of a leaf, as the fruit dots of
ferns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophysial</ent><br/
<hw>Hy`po*phys"i*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the hypophysis; pituitary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypophysis</ent><br/
\'d8<hw>Hy*poph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ under + <?/ nature, origin.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <def>See <cref>Pituitary body</cref>, under
<er>Pituitary</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Cataract.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoplastron</ent><br/
<hw>Hy`po*plas"tron</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hypoplastra</plw> <pr>(#)</pr>.</plu> <ety>[Pref. <ets>hypo-</ets>
+ <ets>plastron</ets>.]</ety> <fld>(Anat.)</fld> <def>The third lateral
plate in the plastron of turtles; -- called also
<altname>hyposternum</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoptilum</ent><br/
\'d8<hw>Hy*pop"ti*lum</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hypoptila</plw> <pr>(#)</pr>, E.
<plw>Hypoptilums</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>"ypo`</grk> beneath + <?/ down.]</ety> <fld>(Zool.)</fld> <def>An
accessory plume arising from the posterior side of the stem of the
contour feathers of many birds; -- called also
<altname>aftershaft</altname>. See <xex>Illust.</xex> of
<er>Feather</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyporadius</ent><br/
\'d8<hw>Hy`po*ra"di*us</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hyporadii</plw> <pr>(#)</pr>.</plu> <ety>[Pref.
<ets>hypo-</ets> + <ets>radius</ets>.]</ety> <fld>(Zool.)</fld> <def>One
of the barbs of the hypoptilum, or aftershaft of a feather. See
<er>Feather</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyporhachis</ent><br/
\'d8<hw>Hy`po*rha"chis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hyporhachides</plw> <pr>(#)</pr>.</plu>
<ety>[NL., fr. Gr. <grk>"ypo`</grk> beneath + <?/ spine.]</ety>
<fld>(Zool.)</fld> <def>The stem of an aftershaft or hypoptilum.</def>
<altsp>[Written also <asp>hyporachis</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyposkeletal</ent><br/
<hw>Hy`po*skel"e*tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>skeletal</ets>.]</ety> <fld>(Anat.)</fld>
<def>Beneath the endoskeleton; hypaxial; <as>as, the
<ex>hyposkeletal</ex> muscles</as>; -- opposed to
<xex>episkeletal</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypospadias</ent><br/
\'d8<hw>Hy`po*spa"di*as</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ypo`</grk> beneath + <grk>spa`n</grk> to draw, tear.]</ety>
<fld>(Med.)</fld> <def>A deformity of the penis, in which the urethra
opens upon its under surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypostasis</ent><br/
<hw>Hy*pos"ta*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hypostases</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. Gr. <?/
subsistence, substance, fr. <?/ to stand under; <?/ under + <?/ to
stand, middle voice of <?/ to cause to stand. See <er>Hypo-</er>, and
<er>Stand</er>.]</ety> <sn>1.</sn> <def>That which forms the basis of
anything; underlying principle; a concept or mental entity conceived or
treated as an existing being or thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>Substance; subsistence; essence;
person; personality; -- used by the early theologians to denote any one
of the three subdivisions of the Godhead, the Father, Son, and Holy
Spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Council of Alexandria (<sc>a. d.</sc> 362) defined
<xex>hypostasis</xex> as synonymous with <xex>person</xex>.
<rj><au>Schaff-Herzog.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Principle; an element; -- used by the alchemists in
speaking of salt, sulphur, and mercury, which they considered as the
three principles of all material bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>That which is deposited at the
bottom of a fluid; sediment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypostasize</ent><br/
<hw>Hy*pos"ta*size</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make into
a distinct substance; to conceive or treat as an existing being; to
hypostatize.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The pressed Newtonians . . . refused to <qex>hypostasize</qex> the
law of gravitation into an ether.</q> <rj><qau>Coleridge.</qau></rj></p>

<p><ent>Hypostatical</ent><br/
<ent>Hypostatic</ent><br/
<mhw>{ <hw>Hy`po*stat"ic</hw> <pr>(?)</pr>, <hw>Hy`po*stat"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/: cf. F.
<ets>hypostatique</ets>.]</ety> <sn>1.</sn> <def>Relating to hypostasis,
or substance; hence, constitutive, or elementary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The grand doctrine of the chymists, touching their three
<qex>hypostatical</qex> principles.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Personal, or distinctly personal; relating to the
divine hypostases, or substances.</def> <rj><au>Bp.
Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>Depending upon, or due to,
deposition or setting; <as>as, <ex>hypostatic</ex> cognestion,
cognestion due to setting of blood by gravitation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypostatic union</b></col> <fld>(Theol.)</fld>, <cd>the
union of the divine with the human nature of Christ.</cd>
<rj><au>Tillotson.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypostatically</ent><br/
<hw>Hy`po*stat"ic*al*ly</hw>, <pos>adv.</pos> <def>In a hypostatic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypostatize</ent><br/
<hw>Hy*pos"ta*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To make into, or regarded as, a separate and distinct
substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Looked upon both species and genera as <qex>hypostatized</qex>
universals.</q> <rj><qau>Pop. Sci. Monthly.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To attribute actual or personal existence to.</def>
<rj><au>Sir W. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyposternum</ent><br/
\'d8<hw>Hy`po*ster"num</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Hyposterna</plw> <pr>(#)</pr>, E.
<plw>Hyposternums</plw> <pr>(#)</pr>.</plu> <ety>[Pref. <ets>hypo-</ets>
+ <ets>sternum</ets>.]</ety> <fld>(Anat.)</fld> <def>See
<er>Hypoplastron</er>.</def></p>

<p><ent>Hypostoma</ent><br/
<ent>Hypostome</ent><br/
<mhw>{ <hw>Hy"po*stome</hw> <pr>(?)</pr>, \'d8<hw>Hy*pos"to*ma</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>hypostoma</ets>, fr.
Gr. <grk>"ypo`</grk> beneath + <?/ mouth.]</ety> <fld>(Zool.)</fld>
<def>The lower lip of trilobites, crustaceans, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypostrophe</ent><br/
<hw>Hy*pos"tro*phe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, fr. <?/ to turn round or back; <?/ under + <?/ to turn.]</ety>
<fld>(Med.)</fld> <sd>(a)</sd> <def>The act of a patient turning
himself.</def> <sd>(b)</sd> <def>A relapse, or return of a
disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 722 --></p>

<p><ent>Hypostyle</ent><br/
<hw>Hy"po*style</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ resting
on pillars; <?/ under + <?/ a pillar.]</ety> <fld>(Arch.)</fld>
<def>Resting upon columns; constructed by means of columns; --
especially applied to the great hall at Karnak.</def></p>

<p><ent>Hyposulphate</ent><br/
<hw>Hy`po*sul"phate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of hyposulphuric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyposulphite</ent><br/
<hw>Hy`po*sul"phite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>A salt of what was formerly called hyposulphurous
acid; a thiosulphate.</def> <mark>[Obs.]</mark> <sd>(b)</sd> <def>A salt
of hyposulphurous acid proper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyposulphuric</ent><br/
<hw>Hy`po*sul*phur"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>sulphuric</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or containing, sulphur in a lower state of oxidation
than in the sulphuric compounds; <as>as, <ex>hyposulphuric</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyposulphuric acid</b></col>, <cd>an acid,
<chform>H2S2O6</chform>, obtained by the action of manganese dioxide on
sulphur dioxide, and known only in a watery solution and in its salts;
-- called also <altname>dithionic acid</altname>. See
<er>Dithionic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyposulphurous</ent><br/
<hw>Hy`po*sul"phur*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>sulphurous</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or containing, sulphur, all, or a part, in a low
state of oxidation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyposulphurous acid</b></col>. <sd>(a)</sd>
<cd>Thiosulphuric acid.</cd> <mark>[Obs.]</mark> <sd>(b)</sd> <cd>An
acid, <chform>H2SO2</chform>, obtained by the reduction of sulphurous
acid. It is not obtained in the free state, but in an orange-yellow
water solution, which is a strong reducing and bleaching agent. Called
also <altname>hydrosulphurous acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypotarsus</ent><br/
\'d8<hw>Hy`po*tar"sus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Hypotarsi</plw> <pr>(#)</pr>.</plu> <ety>[NL. See
<er>Hypo-</er>, and <er>Tarsus</er>.]</ety> <fld>(Anat.)</fld> <def>A
process on the posterior side of the tarsometatarsus of many birds; the
calcaneal process.</def> -- <wordforms><wf>Hy`po*tar"sal</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms></p>

<p><ent>Hypothenuse</ent><br/
<ent>Hypotenuse</ent><br/
<mhw>{ <hw>Hy*pot"e*nuse</hw> <pr>(?)</pr>, <hw>Hy*poth"e*nuse</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[L. <ets>hypotenusa</ets>, Gr.
<?/, prob., subtending (sc. <?/), fr. <?/ to stretch under, subtend; <?/
under + <?/ to stretch. See <er>Subtend</er>.]</ety> <fld>(Geom.)</fld>
<def>The side of a right-angled triangle that is opposite to the right
angle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothec</ent><br/
<hw>Hy*poth"ec</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>hypoth<egrave/que</ets>. See <er>Hypotheca</er>.]</ety> <fld>(Scot.
Law)</fld> <def>A landlord's right, independently of stipulation, over
the stocking (cattle, implements, etc.), and crops of his tenant, as
security for payment of rent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypotheca</ent><br/
\'d8<hw>Hy`po*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/ a thing subject to some obligation, fr. <?/ to put under, put down,
pledge. See <er>Hypothesis</er>.]</ety> <fld>(Rom. Law)</fld> <def>An
obligation by which property of a debtor was made over to his creditor
in security of his debt.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It differed from pledge in regard to possession of the
property subject to the obligation; pledge requiring, simple hypotheca
not requiring, possession of it by the creditor. The modern mortgage
corresponds very closely with it.</note> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothecate</ent><br/
<hw>Hy*poth"e*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Hypothecated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Hypothecating</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[LL. <ets>hypothecatus</ets>, p. p. of
<ets>hypothecare</ets> to pledge, fr. L. <ets>hypotheca</ets> pledge,
security. See <er>Hypotheca</er>.]</ety> <fld>(Law)</fld> <def>To
subject, as property, to liability for a debt or engagement without
delivery of possession or transfer of title; to pledge without delivery
of possession; to mortgage, as ships, or other personal property; to
make a contract by bottomry. See <er>Hypothecation</er>,
<er>Bottomry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had found the treasury empty and the pay of the navy in arrear.
He had no power to <qex>hypothecate</qex> any part of the public
revenue. Those who lent him money lent it on no security but his bare
word.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothecation</ent><br/
<hw>Hy*poth`e*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>hypothecatio</ets>.]</ety> <sn>1.</sn> <fld>(Civ. Law)</fld>
<def>The act or contract by which property is hypothecated; a right
which a creditor has in or to the property of his debtor, in virtue of
which he may cause it to be sold and the price appropriated in payment
of his debt. This is a right in the thing, or <xex>jus in
re</xex>.</def> <rj><au>Pothier. B. R. Curtis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There are but few cases, if any, in our law, where an
<qex>hypothecation</qex>, in the strict sense of the Roman law, exists;
that is a pledge without possession by the pledgee.</q>
<rj><qau>Story.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the modern civil law, this contract has no
application to movable property, not even to ships, to which and their
cargoes it is most frequently applied in England and America. See
<er>Hypothecate</er>.</note> <rj><au>B. R. Curtis. Domat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law of Shipping)</fld> <def>A contract whereby, in
consideration of money advanced for the necessities of the ship, the
vessel, freight, or cargo is made liable for its repayment, provided the
ship arrives in safety. It is usually effected by a bottomry bond. See
<er>Bottomry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term is often applied to mortgages of
ships.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothecator</ent><br/
<hw>Hy*poth"e*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who hypothecates or pledges anything as security for the
repayment of money borrowed.</def></p>

<p><ent>Hypothenar</ent><br/
<ent>Hypothenal</ent><br/
<mhw>{ <hw>Hy*poth"e*nal</hw> <pr>(?)</pr>, <hw>Hy*poth"e*nar</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Pref. <ets>hypo-</ets> +
<ets>thenar</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to
the prominent part of the palm of the hand above the base of the little
finger, or a corresponding part in the forefoot of an animal; <as>as,
the <ex>hypothenar</ex> eminence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothenar</ent><br/
<hw>Hy*poth"e*nar</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>The hypothenar eminence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothenusal</ent><br/
<hw>Hy*poth`e*nu"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to hypothenuse.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothenuse</ent><br/
<hw>Hy*poth"e*nuse</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Hypotenuse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothesis</ent><br/
<hw>Hy*poth"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Hypotheses</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/
foundation, supposition, fr. <?/ to place under, <?/ under + <?/ to put.
See <er>Hypo-</er>, <er>Thesis</er>.]</ety> <sn>1.</sn> <def>A
supposition; a proposition or principle which is supposed or taken for
granted, in order to draw a conclusion or inference for proof of the
point in question; something not proved, but assumed for the purpose of
argument, or to account for a fact or an occurrence; <as>as, the
<ex>hypothesis</ex> that head winds detain an overdue
steamer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An <qex>hypothesis</qex> being a mere supposition, there are no
other limits to <qex>hypotheses</qex> than those of the human
imagination.</q> <rj><qau>J. S. Mill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Natural Science)</fld> <def>A tentative theory or
supposition provisionally adopted to explain certain facts, and to guide
in the investigation of others; hence, frequently called a <xex>working
hypothesis</xex>.</def></p>

<p><syn><b>Syn.</b> -- Supposition; assumption. See
<er>Theory</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Nebular hypothesis</b></col>. <cd>See under
<er>Nebular</er>.</cd></cs></p>

<p><ent>Hypothetical</ent><br/
<ent>Hypothetic</ent><br/
<mhw>{ <hw>Hy`po*thet"ic</hw> <pr>(?)</pr>, <hw>Hy`po*thet"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hypotheticus</ets>,
Gr. <?/: cf. F. <ets>hypoth<eacute/tique</ets>.]</ety>
<def>Characterized by, or of the nature of, an hypothesis; conditional;
assumed without proof, for the purpose of reasoning and deducing proof,
or of accounting for some fact or phenomenon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Causes <qex>hypothetical</qex> at least, if not real, for the
various phenomena of the existence of which our experience informs
us.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hypothetical baptism</b></col> <fld>(Ch. of Eng.)</fld>,
<cd>baptism administered to persons in respect to whom it is doubtful
whether they have or have not been baptized before.</cd>
<rj><au>Hook.</au></rj></cs></p>

<p>-- <wordforms><wf>Hy`po*thet"ic*al*ly</wf>,
<pos>adv.</pos></wordforms> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypothetist</ent><br/
<hw>Hy*poth"e*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
proposes or supports an hypothesis.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypotrachelium</ent><br/
\'d8<hw>Hy`po*tra*che"li*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
fr. Gr. <?/; <?/ under + <?/ neck.]</ety> <fld>(Arch.)</fld> <def>Same
as <er>Gorgerin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypotricha</ent><br/
\'d8<hw>Hy*pot"ri*cha</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"ypo`</grk> beneath + <?/, <?/, a hair.]</ety>
<fld>(Zool.)</fld> <def>A division of ciliated Infusoria in which the
cilia cover only the under side of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypotrochoid</ent><br/
<hw>Hy`po*tro"choid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>trochoid</ets>.]</ety> <fld>(Geom.)</fld> <def>A
curve, traced by a point in the radius, or radius produced, of a circle
which rolls upon the concave side of a fixed circle. See
<er>Hypocycloid</er>, <er>Epicycloid</er>, and
<er>Trochoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypotyposis</ent><br/
\'d8<hw>Hy`po*ty*po"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/, fr. <?/ to sketch out; <?/ under + <?/ to impress.]</ety>
<fld>(Rhet.)</fld> <def>A vivid, picturesque description of scenes or
events.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypoxanthin</ent><br/
<hw>Hy`po*xan"thin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>hypo-</ets> + <ets>xanthin</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A crystalline, nitrogenous substance, closely related
to xanthin and uric acid, widely distributed through the animal body,
but especially in muscle tissue; -- called also
<altname>sarcin</altname>, <altname>sarkin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypozoic</ent><br/
<hw>Hy`po*zo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <grk>zw^,on</grk> an animal.]</ety>
<fld>(Geol.)</fld> <def>Anterior in age to the lowest rocks which
contain organic remains.</def> <rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyppish</ent><br/
<hw>Hyp"pish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Hyp</er>.]</ety> <def>Affected with hypochondria; hypped.</def>
<altsp>[Written also <asp>hyppish</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyppogriff</ent><br/
<hw>Hyp"po*griff</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Hyppogriff</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypsiloid</ent><br/
<hw>Hyp"si*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <UPSILON/,
the Greek letter called <ldquo/upsilon<rdquo/ + <ets>-oid</ets>.]</ety>
<fld>(Anat.)</fld> <def>Resembling the Greek letter <UPSILON/ in form;
hyoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypsometer</ent><br/
<hw>Hyp*som"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ height
+ <ets>-meter</ets>.]</ety> <fld>(Physics)</fld> <def>An instrument for
measuring heights by observation of barometric pressure; esp., one for
determining heights by ascertaining the boiling point of water. It
consists of a vessel for water, with a lamp for heating it, and an
inclosed thermometer for showing the temperature of
ebullition.</def></p>

<p><ent>Hypsometrical</ent><br/
<ent>Hypsometric</ent><br/
<mhw>{ <hw>Hyp`so*met"ric</hw> <pr>(?)</pr>, <hw>Hyp`so*met"ric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to
hypsometry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypsometry</ent><br/
<hw>Hyp*som"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That branch of
the science of geodesy which has to do with the measurement of heights,
either absolutely with reference to the sea level, or
relatively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hypsiprymnodon</ent><br/
<hw>Hypsiprymnodon</hw> <pos>n.</pos> <def>A genus of marsupials
comprising the musk kangaroos.</def><br/
<syn><b>Syn. --</b> genus <gen>Hypsiprymnodon</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hypural</ent><br/
<hw>Hy*pu"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>hypo-</ets> + Gr. <?/ tail.]</ety> <fld>(Anat.)</fld> <def>Under
the tail; -- applied to the bones which support the caudal fin rays in
most fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyracoid</ent><br/
<hw>Hy"ra*coid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Hyracoidea.</def> -- <def2><pos>n.</pos>
<def>One of the Hyracoidea.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyracoidea</ent><br/
\'d8<hw>Hyr`a*coi"de*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Hyrax</er>, and <er>oid</er>.]</ety> <fld>(Zool.)</fld> <def>An
order of small hoofed mammals, comprising the single living genus
<gen>Hyrax</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyracotherium</ent><br/
<hw>Hyracotherium</hw> <pos>n.</pos> <def>An extinct horse genus,
formerly called genus <altname>Eohippus</altname>.</def><br/
<syn><b>Syn. --</b> genus <gen>Hyracotherium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hyrax</ent><br/
\'d8<hw>Hy"rax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
shrew mouse.]</ety> <fld>(Zool.)</fld> <def>Any animal of the genus
<gen>Hyrax</gen>, of which about four species are known. They constitute
the order <ord>Hyracoidea</ord>. The best known species are the daman
(<spn>Hyrax Syriacus</spn>) of Palestine, and the klipdas (<spn>Hyrax
capensis</spn>) of South Africa. Other species are <spn>Hyrax
arboreus</spn> and <spn>Hyrax Sylvestris</spn>, the former from
Southern, and the latter from Western, Africa. See
<er>Daman</er>.</def></p>

<p><ent>Hyrcan</ent><br/
<ent>Hyrcanian</ent><br/
<mhw>{ <hw>Hyr*ca"ni*an</hw> <pr>(?)</pr>, <hw>Hyr"can</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to Hyrcania,
an ancient country or province of Asia, southeast of the Caspian (which
was also called the Hyrcanian) Sea.</def> <ldquo/The <xex>Hyrcan</xex>
tiger.<rdquo/ <ldquo/<xex>Hyrcanian</xex> deserts.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyrse</ent><br/
<hw>Hyrse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G. <ets>hirse</ets>,
OHG. <ets>hirsi</ets>.]</ety> <fld>(Bot.)</fld> <def>Millet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyrst</ent><br/
<hw>Hyrst</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wood. See
<er>Hurst</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyson</ent><br/
<hw>Hy"son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin.
<ets>hi-tshun</ets>, lit., first crop, or blooming spring.]</ety> <def>A
fragrant kind of green tea.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hyson skin</b></col>, <cd>the light and inferior leaves
separated from the hyson by a winnowing machine.</cd>
<rj><au>M<lsquo/Culloch.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyssop</ent><br/
<hw>Hys"sop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>hysope</ets>, <ets>ysope</ets>, OF. <ets>ysope</ets>, F.
<ets>hysope</ets>, <ets>hyssope</ets>, L. <ets>hysopum</ets>,
<ets>hyssopum</ets>, <ets>hyssopus</ets>, Gr. <?/, <?/, an aromatic
plant, fr. Heb. <ets><emac/sov</ets>.]</ety> <def>A plant (<spn>Hyssopus
officinalis</spn>). The leaves have an aromatic smell, and a warm,
pungent taste.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The hyssop of Scripture is supposed to be a species of
caper (<spn>Capparis spinosa</spn>), but probably the name was used for
several different plants.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hyssopus</ent><br/
<hw>Hyssopus</hw> <pos>n.</pos> <def>A Eurasian genus of perennial herbs
or subshrubs.</def><br/
<syn><b>Syn. --</b> genus <gen>Hyssopus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Hysteranthous</ent><br/
<hw>Hys`ter*an"thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
after + <?/ flower.]</ety> <fld>(Bot.)</fld> <def>Having the leaves
expand after the flowers have opened.</def>
<rj><au>Henslow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysteresis</ent><br/
\'d8<hw>Hys`te*re"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ to be behind, to lag.]</ety> <fld>(Physics)</fld> <def>A lagging
or retardation of the effect, when the forces acting upon a body are
changed, as if from velocity or internal friction; a temporary
resistance to change from a condition previously induced, observed in
magnetism, thermoelectricity, etc., on reversal of polarity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysteretic</ent><br/
<hw>Hys`ter*et"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Elec.)</fld>
<def>Of or pertaining to hysteresis.</def> <cs>-- <col><b>Hysteretic
constant</b></col>, <cd>the hysteretic loss in ergs per cubic centimeter
per cycle.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Hysteria</ent><br/
<hw>Hys*te"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf. F.
<ets>hyst<eacute/rie</ets>. See <er>Hysteric</er>.]</ety>
<fld>(Med.)</fld> <def>A nervous affection, occurring almost exclusively
in women, in which the emotional and reflex excitability is exaggerated,
and the will power correspondingly diminished, so that the patient loses
control over the emotions, becomes the victim of imaginary sensations,
and often falls into paroxism or fits.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The chief symptoms are convulsive, tossing movements of
the limbs and head, uncontrollable crying and laughing, and a choking
sensation as if a ball were lodged in the throat. The affection presents
the most varied symptoms, often simulating those of the gravest
diseases, but generally curable by mental treatment alone.</note></p>

<p><ent>Hysterical</ent><br/
<ent>Hysteric</ent><br/
<mhw>{ <hw>Hys*ter"ic</hw> <pr>(?)</pr>, <hw>Hys*ter"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>hystericus</ets>, Gr.
<?/, fr. <grk>"yste`ra</grk> the womb; perh. akin to <?/ latter, later,
and E. <ets>utter</ets>, <ets>out</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to hysteria.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With no <qex>hysteric</qex> weakness or feverish excitement, they
preserved their peace and patience.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a state of hysteria; affected, or troubled, with
hysterics; uncontrollably emotional; convulsive, fitful.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In a state of panic or behaving in a wild irrational
manner, due to fear or emotional trauma.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Resembling hysteria; <as>as, <ex>hysterical</ex>
laughter</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>hysterical</ent><br/
<hw>hys*ter"ic*al</hw> <pos>a.</pos> <def>Extremely funny.</def>
<mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Hysterics</ent><br/
<hw>Hys*ter"ics</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <fld>(Med.)</fld>
<def>Hysteria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysteroepilepsy</ent><br/
<hw>Hys`ter*o*ep"i*lep`sy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Hysteria</ets> + <ets>epilepsy</ets>.]</ety>
<fld>(Med.)</fld> <def>A disease resembling hysteria in its nature, and
characterized by the occurrence of epileptiform convulsions, which can
often be controlled or excited by pressure on the ovaries, and upon
other definite points in the body.</def> --
<wordforms><wf>Hys`ter*o*ep`i*lep"tic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysterogenic</ent><br/
<hw>Hys`ter*o*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Hyste</ets>ria + root of Gr. <grk>gi`gnesqai</grk> to be
born.]</ety> <fld>(Physiol.)</fld> <def>Producing hysteria; <as>as, the
<ex>hysterogenic</ex>pressure points on the surface of the body,
pressure upon which is said both to produce and arrest an attack of
hysteria</as>.</def> <rj><au>De Watteville.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysterology</ent><br/
<hw>Hys`ter*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/
the latter + <?/ discourse: cf. F.
<ets>hyst<eacute/rologie</ets>.]</ety> <fld>(Rhet.)</fld> <def>A figure
by which the ordinary course of thought is inverted in expression, and
the last put first; -- called also <altname>hysteron
proteron</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysteron proteron</ent><br/
\'d8<hw>Hys"te*ron prot"e*ron</hw> <pr>(?)</pr>. <ety>[NL., fr. Gr.
<grk>"y`steros</grk> the latter, following + <grk>pro`teros</grk>
before, others, sooner.]</ety> <fld>(Rhet.)</fld> <sd>(a)</sd> <def>A
figure in which the natural order of sense is reversed; hysterology;
<as>as, <ex>valet atque vivit</ex>, <ldquo/he is well and
lives</as>.<rdquo/</def> <sd>(b)</sd> <def>An inversion of logical
order, in which the conclusion is put before the premises, or the thing
proved before the evidence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysterophyte</ent><br/
<hw>Hys*ter"o*phyte</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"y`steros</grk> following + <grk>fyto`n</grk> plant.]</ety>
<fld>(Bot.)</fld> <def>A plant, like the fungus, which lives on dead or
living organic matter.</def> -- <wordforms><wf>Hys`ter*oph"y*tal</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hysterotomy</ent><br/
<hw>Hys`ter*ot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"yste`ra</grk> womb + <grk>te`mnein</grk> to cut: cf. F.
<ets>hyst<eacute/rotomie</ets>.]</ety> <fld>(Med.)</fld> <def>The act of
cutting into the uterus, as in C<ae/sarean section. See under
<er>C<ae/sarean</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hystricine</ent><br/
<hw>Hys"tri*cine</hw> <pr>(h<icr/s"tr<icr/*s<icr/n)</pr>, <pos>a.</pos>
<ety>[See <er>Hystrix</er>.]</ety> <fld>(Zool.)</fld> <def>Like or
pertaining to the porcupines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hystricomorphous</ent><br/
<hw>Hys`tri*co*mor"phous</hw>
<pr>(h<icr/s`tr<icr/*k<osl/*m<ocir/r"f<ucr/s)</pr>, <pos>a.</pos>
<ety>[<ets>Hystrix</ets> + Gr. <grk>morfh`</grk> form.]</ety>
<fld>(Zool.)</fld> <def>Like, or allied to, the porcupines; -- said of a
group (<fam>Hystricomorpha</fam>) of rodents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hystrix</ent><br/
<hw>Hys"trix</hw> <pr>(h<icr/s"tr<icr/ks)</pr>, <pos>prop. n.</pos>
<ety>[Gr. <grk>"y`strix</grk> porcupine.]</ety> <fld>(Zool.)</fld>
<def>A genus of rodents, including the porcupine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Hythe</ent><br/
<hw>Hythe</hw> <pr>(h<imac/<th/)</pr>, <pos>n.</pos> <def>A small haven.
See <er>Hithe</er>.</def> <mark>[Obs.]</mark></p>

<p><-- bottom of page 722. Next page is 723, starting "I" --></p>

<p><q>A dictionary containing a natural history requires too many
<qex>hands</qex>, as well as too much time, ever to be hoped for.</q>
<rj><qau>Locke.</qau></rj></p>


<-- Local variables: -->
<-- mode: sgml -->
<-- fill-column: 72 -->
<-- End: -->
