<-- This file is part 13 of the GNU version of
    The Collaborative International Dictionary of English (GCIDE)

    Copyright (C) 1992-2012 Patrick J. Cassidy
    Copyright (C) 2012-2024 Sergey Poznyakoff

    GCIDE is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.

    GCIDE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this copy of GCIDE.  If not, see <http://www.gnu.org/licenses/>.
-->

<p><centered><point26>M.</point26></centered></p>

<p><ent>M</ent><br/
<hw>M</hw> <pr>(<ecr/m)</pr>. <sn>1.</sn> <def>M, the thirteenth letter
of the English alphabet, is a vocal consonant, and from the manner of
its formation, is called the <xex>labio-nasal</xex> consonant. See
<xex>Guide to Pronunciation</xex>, <sect/<sect/ 178-180, 242.</def><br/
[<source>1913 Webster</source>]</p>

<note>
<p>The letter M came into English from the Greek, through the
Latin, the form of the Greek letter being further derived from the
Ph<oe/nician, and ultimately, it is believed, from the Egyptian.
Etymologically M is related to <xex>n</xex>, in li<xex>me</xex>,
li<xex>n</xex>den; <xex>emm</xex>et, a<it>n</it>t; also to
<xex>b</xex>.<br/
[<source>1913 Webster</source>]</p>

<p> M is readily followed by <xex>b</xex> and <xex>p</xex>. the position
of the lips in the formation of both letters being the same. The
relation of <xex>b</xex> and <xex>m</xex> is the same as that of
<xex>d</xex> and <xex>t</xex> to <xex>n</xex>. and that of <xex>g</xex>
and <xex>k</xex> to <xex>ng</xex>.<br/
[<source>1913 Webster</source>]</p></note>

<p><sn>2.</sn> <def>As a numeral, M stands for one thousand, both in
English and Latin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>M</ent><br/
<hw>M</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Print.)</fld> <def>A
quadrat, the face or top of which is a perfect square; also, the size of
such a square in any given size of type, used as the unit of measurement
for that type: 500 m's of pica would be a piece of matter whose length
and breadth in pica m's multiplied together produce that number.</def>
<altsp>[Written also <asp>em</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(law)</fld> <def>A brand or stigma, having the shape
of an M, formerly impressed on one convicted of manslaughter and
admitted to the benefit of clergy.</def><br/
[<source>1913 Webster</source>]</p>

<p><col><b>M roof</b></col> <fld>(Arch.)</fld>, <cd>a kind of roof
formed by the junction of two common roofs with a valley between them,
so that the section resembles the letter M.</cd><br/
[<source>1913 Webster</source>]</p>

<p><ent>M-1</ent><br/
<hw>M-1</hw> <pos>n.</pos> <def>A semiautomatic rifle which was standard
issue to infantrymen in the United States Army in the mid-20th
century.</def><br/
<syn><b>Syn. --</b> Garand rifle, Garand, M-1 rifle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>M1</ent><br/
<hw>M1</hw> <pos>n.</pos> <def>The narrowest measure of the money
supply, comprising the currency in circulation plus demand deposits or
checking account balances.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>M2</ent><br/
<hw>M2</hw> <pos>n.</pos> <def>A measure of the money supply broader
than M1 but narrower than M3, comprising M1 plus net time deposits
(other than large certificates of deposit).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>M3</ent><br/
<hw>M3</hw> <pos>n.</pos> <def>A broad measure of the money supply,
comprising M2 plus deposits at nonbanks such as savings and loan
associations.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ma</ent><br/
<hw>Ma</hw> <pr>(m<aum/)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Mamma</er>.]</ety> <sn>1.</sn> <def>A child's word for
<sig>mother</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Hind.]</ety> <def>In Oriental countries, a
respectful form of address given to a woman; mother.</def> <au>Balfour
(Cyc. of India).</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ma</ent><br/
\'d8<hw>Ma</hw>, <pos>conj.</pos> <ety>[It.]</ety> <fld>(Mus.)</fld>
<def>But; -- used in cautionary phrases; <as>as, <ldquo/Vivace,
<ex>ma</ex> non troppo presto<rdquo/ (i. e., lively, <xex>but</xex> not
too quick)</as>.</def> <rj><au>Moore (Encyc. of Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maa</ent><br/
<hw>Maa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>New</er> a
gull.]</ety> <fld>(Zool.)</fld> <def>The common European gull
(<spn>Larus canus</spn>); -- called also <altname>mar</altname>. See
<er>New</er>, a gull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maad</ent><br/
<hw>Maad</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> <mord>of
<er>Make</er>.</mord> <def>Made.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maalin</ent><br/
<hw>Maa"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The sparrow hawk.</def> <sd>(b)</sd> <def>The
kestrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maalox</ent><br/
<hw>Maalox</hw> <pos>n.</pos> <def>A trademark for an antacid.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ma'am</ent><br/
<hw>Ma'am</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Madam; my lady; -- a
colloquial contraction of <xex>madam</xex> often used in direct address,
and sometimes as an appellation.</def><br/
<syn><b>Syn. --</b> dame, madam, madame, lady, gentlewoman.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maara shell</ent><br/
<hw>Ma"a*ra shell`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>A large,
pearly, spiral, marine shell (<spn>Turbo margaritaceus</spn>), from the
Pacific Islands. It is used as an ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maasha</ent><br/
\'d8<hw>Ma*ash"a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An East Indian
coin, of about one tenth of the weight of a rupee.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maat</ent><br/
<hw>Maat</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Mate</er>,
<pos>a.</pos>]</ety> <def>Dejected; sorrowful; downcast.</def>
<mark>[Obs.]</mark> <ldquo/So piteous and so <xex>maat</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mab</ent><br/
<hw>Mab</hw> <pr>(m<acr/b)</pr>, <pos>prop. n.</pos> <ety>[Cf. W.
<ets>mad</ets> a male child, a boy.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A slattern.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>[capitalized]</mark> <def>The name of a female
fairy, esp. the queen of the fairies; and hence, sometimes, any
fairy.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mabble</ent><br/
<hw>Mab"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To wrap up.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mabby</ent><br/
<hw>Mab"by</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A spirituous liquor or
drink distilled from potatoes; -- used in the Barbadoes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mabolo</ent><br/
\'d8<hw>Ma*bo"lo</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A kind of persimmon tree (<spn>Diospyros discolor</spn>) from the
Philippine Islands, now introduced into the East and West Indies. It
bears an edible fruit as large as a quince.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mac</ent><br/
<hw>Mac</hw> <pos>prop. n.</pos> <def>Shortened form of
<altname>Macintosh</altname>, a brand name for a personal computer;
<as>as, the latest <ex>Mac</ex> has great new features</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mac</ent><br/
<hw>Mac</hw> <pr>(?)</pr>. <ety>[Gael., son.]</ety> <def>A prefix, in
names of Scotch origin, signifying <sig>son</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mac</ent><br/
<hw>mac</hw> <pos>n.</pos> <def>Shortened form of
<altname>mackintosh</altname>, a waterproof raincoat made of rubberized
fabric.</def><br/
<syn><b>Syn. --</b> mackintosh, mac, mack.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>macabre</ent><br/
<hw>macabre</hw> <pr>(m<adot/*k<aum/"b<etil/r)</pr> <pos>adj.</pos>
<sn>1.</sn> <def>portraying human injury or death in a way so as to
inspiring shock or horror; gruesome; ghastly; <as>as, <ex>macabre</ex>
tortures conceived by madmen</as>.</def> <altsp>[Also spelled
<asp>macaber</asp>.]</altsp><br/
<syn><b>Syn. --</b> ghastly, grisly, gruesome, lurid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Pertaining to or portraying the grim aspects of
death, or the allegorical <cref>dance of death</cref>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macaca</ent><br/
<hw>Macaca</hw> <pos>prop. n.</pos> <def>A genus of macaques including
the rhesus monkey (<spn>Macaca mulatta</spn>), much used in laboratory
biomedical research. Formerly called
<altname>Macacus</altname>.</def><br/
<syn><b>Syn. --</b> genus <gen>Macaca</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macaca mulatta</ent><br/
<hw>Macaca mulatta</hw> <pos>n.</pos> <def>The rhesus monkey of South
Asia; used in medical research.</def><br/
<syn><b>Syn. --</b> rhesus, rhesus monkey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macaca radiata</ent><br/
<hw>Macaca radiata</hw> <pos>n.</pos> <def>An Indian macaque with a
bonnetlike tuft of hair.</def><br/
<syn><b>Syn. --</b> bonnet macaque, bonnet monkey, capped macaque, crown
monkey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macaca sylvana</ent><br/
<hw>Macaca sylvana</hw> <pos>n.</pos> <def>The Barbary ape, a tailless
macaque of rocky cliffs and forests of Northwest Africa and
Gibralter.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macaco</ent><br/
\'d8<hw>Ma*ca"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Pg.
<ets>macaco</ets>.]</ety> <fld>(Zool.)</fld> <def>Any one of several
species of lemurs, as the ruffed lemur (<spn>Lemur macaco</spn>), and
the ring-tailed lemur (<spn>Lemur catta</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macacus</ent><br/
\'d8<hw>Ma*ca"cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., a word of
African origin. Cf. <er>Macaco</er>, <er>Macaque</er>.]</ety>
<fld>(Zool.)</fld> <def>A genus of monkeys, found in Asia and the East
Indies, now usually called <altname>Macaca</altname>. They have short
tails and prominent eyebrows. See also <er>Macaca</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macadam</ent><br/
<hw>macadam</hw> <pos>n.</pos> <def>The broken stone used in macadamized
roadways.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A paved surface formed of compressed layers of
broken rocks held together with tar.</def><br/
<syn><b>Syn. --</b> tartarmac, macadam.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>macadamized</ent><br/
<ent>macadam</ent><br/
<mhw><hw>macadam</hw> <hw>macadamized</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>paved with macadam{2}.</def><br/
<syn><b>Syn. --</b> asphalt, tarmac, tarmacadam.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>macadamia</ent><br/
<hw>macadamia</hw> <pos>n.</pos> <sn>1.</sn> <def>any tree of the genus
<gen>Macadamia</gen>, especially <spn>Macadamia
ternifolia</spn>.</def><br/
<syn><b>Syn. --</b> macadamia tree.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A <er>macadamia nut</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>macadamia nut</ent><br/
<hw>macadamia nut</hw> <pos>n.</pos> <def>The hard-shelled nut of the
<spn>Macadamia ternifolia</spn>, or the delicious edible nut without its
shell; large quantities are produced in Hawaii and sold
commercially.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macadamization</ent><br/
<hw>Mac*ad`am*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
process or act of macadamizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macadamize</ent><br/
<hw>Mac*ad"am*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Macadamized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Macadamizing</conjf>.]</vmorph> <ety>[From <person>John
Loudon <etsep>McAdam</etsep></person>, who introduced the process into
Great Britain in 1816.]</ety> <def>To cover, as a road, or street,
parking lot, playground, or other flat area, with <er>macadam</er>, so
as to form a smooth, hard, convex surface.</def><br/
<syn><b>Syn. --</b> tarmac.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macadam road</ent><br/
<hw>Mac*ad"am road`</hw> <pr>(?)</pr>. <ety>[See
<er>Macadamize</er>.]</ety> <def>A macadamized road.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macamba</ent><br/
<hw>macamba</hw> <pos>n.</pos> <def>A tropical American feather palm
(<spn>Acrocomia aculeata</spn>) having a swollen spiny trunk and edible
nuts.</def><br/
<syn><b>Syn. --</b> grugru, gri gri, grugru palm, <spn>Acrocomia
aculeata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macao</ent><br/
<hw>Ma*ca"o</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
macaw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macao</ent><br/
<hw>Ma*ca"o</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A territory in
South China, on the Zhu Jiang river on the South China sea, formerly a
territory of Portugal. Also, the capital city of this
territory.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macaque</ent><br/
\'d8<hw>Ma`caque"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Macacus</er>.]</ety> <fld>(Zool.)</fld> <def>Any one of several
species of short-tailed monkeys of the genus <gen>Macaca</gen> (formerly
<gen>Macacus</gen>), found in rocky regions of Asia and Africa; <as>as,
<spn>Macaca maurus</spn>, the moor <ex>macaque</ex> of the East
Indies</as>.</def> <note><spn>Macaca mulatta</spn> is the <stype>Rhesus
monkey</stype>, much used in biomedical research, and namesake of the Rh
factor used in blood typing (due to discovery of that factor in the
<it>Rh</it>esus monkey).</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Macaranga gum</ent><br/
<hw>Mac`a*ran"ga gum`</hw> <pr>(?)</pr>. <def>A gum of a crimson color,
obtained from a tree (<spn>Macaranga Indica</spn>) that grows in the
East Indies. It is used in taking impressions of coins, medallions,
etc., and sometimes as a medicine.</def> <rj><au>Balfour (Cyc. of
India).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>macarena</ent><br/
<hw>macarena</hw> <pos>n.</pos> <def>a dance performed by dancers in a
line, or several lines, consisting mainly of hand and arm movements;
also, the name of the song to which the dance is usually performed. It
became popular in 1996.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macarize</ent><br/
<hw>Mac"a*rize</hw>, <pos>v. t.</pos> <ety>[Gr. <?/ to bless.]</ety>
<def>To congratulate.</def> <mark>[Oxford Univ. Cant]</mark>
<rj><au>Whately.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macaroni</ent><br/
<hw>Mac`a*ro"ni</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Macaronis</plw> <pr>(#)</pr>, or <plw>Macaronies</plw>.</plu>
<ety>[Prov. It. <ets>macaroni</ets>, It. <ets>maccheroni</ets>, fr. Gr.
<?/ happiness, later, a funeral feast, fr. <?/ blessed, happy. Prob. so
called because eaten at such feasts in honor of the dead; cf. Gr. <?/
blessed, i. e., dead. Cf. <er>Macaroon</er>.]</ety> <sn>1.</sn>
<def>Long slender tubes made of a paste chiefly of a wheat flour such as
semolina, and used as an article of food; a form of Italian
<isa>pasta</isa>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A paste similarly prepared is largely used as food in
Persia, India, and China, but is not commonly made tubular like the
Italian <xex>macaroni</xex>.</note> <rj><au>Balfour (Cyc. of
India).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A medley; something droll or extravagant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A sort of droll or fool.</def> <mark>[Obs.]</mark>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A finical person; a fop; -- applied especially to
English fops of about 1775, who affected the mannerisms and clothing of
continental Europe.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]<-- See lyrics of Yankee Doodle --></p>

<p><sn>5.</sn> <pluf>pl.</pluf> <fld>(U. S. Hist.)</fld> <def>The
designation of a body of Maryland soldiers in the Revolutionary War,
distinguished by a rich uniform.</def> <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macaronic</ent><br/
<ent>Macaronian</ent><br/
<mhw>{ <hw>Mac`a*ro"ni*an</hw> <pr>(?)</pr>, <hw>Mac`a*ron"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. It.
<ets>maccheronico</ets>, F. <ets>macaronique</ets>.]</ety> <sn>1.</sn>
<def>Pertaining to, or like, macaroni (originally a dish of mixed food);
hence, mixed; confused; jumbled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the burlesque composition called
macaronic; <as>as, <ex>macaronic</ex> poetry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macaronic</ent><br/
<hw>Mac`a*ron"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
heap of things confusedly mixed together; a jumble.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of burlesque composition, in which the
vernacular words of one or more modern languages are intermixed with
genuine Latin words, and with hybrid formed by adding Latin terminations
to other roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macaroon</ent><br/
<hw>Mac`a*roon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>macaron</ets>, It. <ets>maccherone</ets>. See
<er>Macaroni</er>.]</ety> <sn>1.</sn> <def>A small cake, composed
chiefly of the white of eggs, almonds or coconut, and sugar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A finical fellow, or macaroni.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macartney</ent><br/
<hw>Ma*cart"ney</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Lord
<etsep>Macartney</etsep>.]</ety> <fld>(Zool.)</fld> <def>A fire-backed
pheasant. See <er>Fireback</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macassar oil</ent><br/
<hw>Ma*cas`sar oil"</hw> <pr>(?)</pr> <pos>n.</pos> <def>A kind of oil
formerly used in dressing the hair; -- so called because originally
obtained from <etsep>Macassar</etsep>, a district of the Island of
Celebes. Also, an imitation of the same, of perfumed castor oil and
olive oil. Cf. <er>antimacassar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macau</ent><br/
<hw>Ma*ca"u</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>Same as
<er>Macao</er>, the territory.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macauco</ent><br/
\'d8<hw>Ma*cau"co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of several species of small lemurs, as <spn>Lemur
murinus</spn>, which resembles a rat in size.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macavahu</ent><br/
\'d8<hw>Ma`ca*va"hu</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small Brazilian monkey (<spn>Callithrix torquatus</spn>), --
called also <altname>collared teetee</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macaw</ent><br/
<hw>Ma*caw"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the native name
in the Antilles.]</ety> <fld>(Zool.)</fld> <def>Any parrot of the genus
<gen>Ara</gen>, <gen>Sittace</gen>, or <gen>Macrocercus</gen>. About
eighteen species are known, all of them found in Central and South
America. They are large and have a very long tail, a strong hooked bill,
and a naked space around the eyes. The voice is harsh, and the colors
are brilliant and strongly contrasted; they are among the largest and
showiest of parrots. Different species names have been given to the same
macaw, as for example the <stype>Hyacinthine macaw</stype>, which has
been variously classified as <spn>Anodorhyncus hyacynthinus</spn>,
<spn>Anodorhyncus maximiliani</spn>, and <spn>Macrocercus
hyacynthinus</spn>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><-- e.g. Scarlet macaw --> <-- Insert: Illustration of Blue and
Yellow Macaw --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Macaw bush</b></col> <fld>(Bot.)</fld>, <cd>a West Indian
name for a prickly kind of nightshade (<spn>Solanum
mammosum</spn>).</cd> -- <mcol><col><b>Macaw palm</b></col>,
<col><b>Macaw tree</b></col></mcol> <fld>(Bot.)</fld>, <cd>a tropical
American palm (<spn>Acrocomia fusiformis</spn> and other species) having
a prickly stem and pinnately divided leaves. Its nut yields a yellow
butter, with the perfume of violets, which is used in making violet
soap. Called also <altname>grugru palm</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maccabean</ent><br/
<hw>Mac`ca*be"an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to <person>Judas Maccabeus</person> or to the Maccabees;
<as>as, the <ex>Maccabean</ex> princes; <ex>Maccabean</ex>
times.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maccabees</ent><br/
<hw>Mac"ca*bees</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <sn>1.</sn>
<def>The name given in later times to the Asmonaeans, a family of Jewish
patriots, who headed a religious revolt in the reign of
<person>Antiochus IV.</person>, 168-161 <sc>b. c.</sc>, which led to a
period of freedom for Israel.</def> <rj><au>Schaff-Herzog.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The name of two ancient historical books, which give
accounts of Jewish affairs in or about the time of the Maccabean
princes, and which are received as canonical books in the Roman Catholic
Church, but are included in the Apocrypha by Protestants. Also applied
to three books, two of which are found in some MSS. of the
Septuagint.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 879 --></p>

<p><ent>Maccoboy</ent><br/
<ent>Maccaboy</ent><br/
<mhw>{ <hw>Mac"ca*boy</hw> <pr>(?)</pr>, <hw>Mac"co*boy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[From a district in the Island
of Martinique where it is made: cf. F. <ets>macouba</ets>.]</ety> <def>A
kind of snuff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maccaroni wheat</ent><br/
<hw>maccaroni wheat</hw> <pos>n.</pos> <def>A type of wheat
(<spn>Triticum durum</spn>) with hard dark-colored kernels high in
gluten and used for bread and pasta; grown especially in South Russia,
North Africa, and North central North America.</def><br/
<syn><b>Syn. --</b> durum, durum wheat, hard wheat, <spn>Triticum
durum</spn>, <spn>Triticum turgidum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macco</ent><br/
<hw>Mac"co</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A gambling game in
vogue in the eighteenth century.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mace</ent><br/
<hw>Mace</hw> <pr>(m<amac/s)</pr>, <pos>n.</pos> <ety>[Jav. & Malay.
<ets>m<amac/s</ets>, fr. Skr. <ets>m<amac/sha</ets> a bean.]</ety>
<def>A money of account in China equal to one tenth of a tael; also, a
weight of 57.98 grains.</def> <rj><au>S. W. Williams.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mace</ent><br/
<hw>Mace</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>macis</ets>, L.
<ets>macis</ets>, <ets>macir</ets>, Gr. <?/; cf. Skr.
<ets>makar</ets>anda the nectar or honey of a flower, a fragrant
mango.]</ety> <fld>(Bot.)</fld> <def>A kind of spice; the aril which
partly covers nutmegs. See <er>Nutmeg</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <stype>Red mace</stype> is the aril of <spn>Myristica
tingens</spn>, and <stype>white mace</stype> that of <spn>Myristica
Otoba</spn>, -- East Indian trees of the same genus with the nutmeg
tree.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mace</ent><br/
<hw>Mace</hw>, <pos>n.</pos> <ety>[OF. <ets>mace</ets>, F.
<ets>masse</ets>, from (assumed) L. <ets>matea</ets>, of which the dim.
<ets>mateola</ets> a kind of mallet or beetle, is found.]</ety>
<sn>1.</sn> <def>A heavy staff or club of metal; a spiked club; -- used
as weapon in war before the general use of firearms, especially in the
Middle Ages, for breaking metal armor.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Death with his <qex>mace</qex> petrific . . . smote.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A staff borne by, or carried
before, a magistrate as an ensign of his authority.</def> <ldquo/Swayed
the royal <xex>mace</xex>.<rdquo/ <rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An officer who carries a mace as an emblem of
authority; a macebearer.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A knobbed mallet used by curriers in dressing
leather to make it supple.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Billiards)</fld> <def>A rod for playing billiards,
having one end suited to resting on the table and pushed with one
hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mace</ent><br/
<hw>Mace</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[Trademark.]</ety>
<def>A chemical preparation containing tear gas in a solvent, packaged
in the form of a spray, and used to temporarily incapacitate people,
such as rioters or criminals, by causing intense eye and skin
irritation; also called <altname>chemical mace</altname>. It is designed
to be a non-lethal weapon for defending against violent
people.</def><br/
[<source>PJC</source>]</p>

<p><ent>mace bearer</ent><br/
<ent>macebearer</ent><br/
<mhw><hw>macebearer</hw>, <hw>mace bearer</hw></mhw> <pos>n.</pos>
<def>an official who carries the mace of office before persons in
authority.</def><br/
<syn><b>Syn. --</b> mace, macer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macedoine</ent><br/
\'d8<hw>Ma`c<eacute/`doine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.,
apparently the same word as <ets>Mac<eacute/doine</ets>
Macedonia.]</ety> <def>A kind of mixed dish, as of cooked vegetables
with white sauce, sweet jelly with whole fruit, mixed diced fruits or
vegetables etc.; served hot or cold;</def> <specif>Also,</specif>
<mark>(fig.)</mark>, <def>a medley.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Macedonia</ent><br/
<ent>Macedon</ent><br/
<mhw><hw>Macedon</hw>, <hw>Macedonia</hw></mhw> <pos>prop. n.</pos>
<sn>1.</sn> <def>The ancient kingdom of <person>Phillip II</person> and
<person>Alexander the Great</person> in the Southeastern Balkans that is
now part of Greece, Bulgaria and the independent republic of Macedonia
that was part of the former Yugoslavia.</def><br/
<syn><b>Syn. --</b> Macedonia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The modern republic of Macedonia, population
2,033,964, which was formerly one of the constituent republics of
<country>Yugoslavia</country>. It became independent on November 17,
1991, after a referendum held on September 9, 1991. Its capital city is
<city>Skopje</city>. The currency is the Denar. The ethnic composition
is approximately 65% Macedonians, 21.73% Albanians, 3.79 Turks, 2.56%
Romanians, 2.10% Serbs, and 0.38% Vlachs. Its language is Macedonian,
which uses the Cyrillic alphabet. Its second largest city is
<city>Bitola</city> (pop. 84,002).<br/
At independence in 1991 a new Constitution was adopted, which proclaimed
the Republic of Macedonia a sovereign and independent state. On april 8,
1993, the Republic of Macedonia became a member of the United Nations
Organization. Due to the pressure of Greece, which was concerned about
possible claims on part of its territory, it was admitted under the name
of the <altname>Former Yugoslav Republic of Macedonia</altname>.<br/
The Republic of Macedonia is situated in the center of the the Balkan
Peninsula and has a unique strategic position at the junction of the
main routes which have for millenia linked the West to the Orient. It
covers an area of 25,713 square killometres and borders with Bulgaria to
the east, Greece to the south, Albania to the west and Serbia to the
north. With the 1913 treaty of Bucharest, the territory of Macedonia,
mainly populated with macedonians, was divided between Greece, Serbia
and Bulgaria. Vardar Macedonia (the territory of today's Republic of
Macedonia) became part of the newly established Kingdom of Serbs, Croats
and Slovenes - later known as the Kingdom of Yugoslavia - which existed
until 1941. The larger part of Macedonia, geographically known as Aegean
Macedonia, covering an area of 34,356 sqare kilometres, was incorporated
into Greece. The territory of Pirin Macedonia (6,798 sqare kilometres)
was assigned to Bulgaria.<br/
In World War II Macedonians started to struggle against the fascist
occupiers on October 11, 1941. The First Session of ASNOM (The
Anti-Fascist Assembly of the National Liberation of Macedonia) was held
on August 2, 1944. It finally crowned the process of the historical
establishment of the Macedonian state and was the basis for its
soveregnity, and integrity. Macedonia (Socialistic Republic of
Macedonia) became part of Tito's Yugoslavia and remained part until
independence in 1991.</def> <au>Goce Vasilevski</au><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A region in northern Greece with its capital at
Thessalonica.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macedonian</ent><br/
<hw>Mac`e*do"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Macedonius</ets>, Gr. <?/.]</ety> <fld>(Geog.)</fld>
<def>Belonging, or relating, to Macedonia.</def> -- <def2><pos>n.</pos>
<def>A native or inhabitant of Macedonia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macedonian</ent><br/
<hw>Mac`e*do"ni*an</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One
of a certain religious sect, followers of <etsep>Macedonius</etsep>,
Bishop of Constantinople, in the fourth century, who held that the
<person>Holy Ghost</person> was a creature, like the angels, and a
servant of the <persfn>Father</persfn> and the
<persfn>Son</persfn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macedonianism</ent><br/
<hw>Mac`e*do"ni*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
doctrines of <persfn>Macedonius</persfn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macer</ent><br/
<hw>Ma"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>massier</ets>.
See <er>Mace</er> staff.]</ety> <def>A mace bearer; an officer of a
court.</def> <rj><au>P. Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macerate</ent><br/
<hw>Mac"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Macerated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Macerating</conjf>.]</vmorph> <ety>[L.
<ets>maceratus</ets>, p. p. of <ets>macerare</ets> to make soft, weaken,
enervate; cf. Gr. <?/ to knead.]</ety> <sn>1.</sn> <def>To make lean; to
cause to waste away.</def> <mark>[Obs. or R.]</mark>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To subdue the appetites of by poor and scanty diet;
to mortify.</def> <rj><au>Baker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To soften by steeping in a liquid, with or without
heat; to wear away or separate the parts of by steeping; <as>as, to
<ex>macerate</ex> animal or vegetable fiber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macerater</ent><br/
<hw>Mac"er*a`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, macerates; an apparatus for converting paper or fibrous matter
into pulp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maceration</ent><br/
<hw>Mac`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maceratio</ets>: cf. F. <ets>mac<eacute/ration</ets>.]</ety>
<def>The act or process of macerating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macerative</ent><br/
<hw>mac`er*a"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Accompanied by
or characterized by maceration.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Machaeranthera</ent><br/
<hw>Machaeranthera</hw> <pos>n.</pos> <def>A genus of wildflowers of
Western North America.</def><br/
<syn><b>Syn. --</b> genus <gen>Machaeranthera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Machairodus</ent><br/
<ent>Machaerodus</ent><br/
<mhw>{ \'d8<hw>Ma*chae"ro*dus</hw>
<pr>(m<adot/*k<emac/"r<osl/*d<ucr/s)</pr>, \'d8<hw>Ma*chai"ro*dus</hw>
<pr>(m<adot/*k<imac/"r<osl/*d<ucr/s)</pr>, }</mhw> <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>ma`chaira</grk> dagger + <grk>'odoy`s</grk>
tooth.]</ety> <fld>(Paleon.)</fld> <def>A genus of extinct mammals
allied to the cats, and having in the upper jaw canine teeth of
remarkable size and strength; -- hence called <altname>saber-toothed
tigers</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machete</ent><br/
\'d8<hw>Ma*che"te</hw> <pr>(m<adot/*sh<ecr/t"<esl/; <it>Sp.</it>
m<adot/*ch<amac/"t<asl/)</pr>, <pos>n.</pos> <ety>[Sp.]</ety> <def>A
large heavy knife resembling a broadsword, often two or three feet in
length, -- used by the inhabitants of Spanish America as a hatchet to
cut their way through thickets, and for various other purposes.</def>
<rj><au>J. Stevens.</au></rj><br/
<syn><b>Syn. --</b> matchet.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machiavellian</ent><br/
<ent>Machiavelian</ent><br/
<mhw><hw>Mach`i*a*vel"ian</hw>, <hw>Mach`i*a*vel"lian</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <ety>[From
<persfn><etsep>Machiavel</etsep></persfn> (also called
<persfn>Machiavelli</persfn>), an Italian writer, secretary and
historiographer to the republic of Florence.]</ety> <def>Of or
pertaining to <persfn>Machiavelli</persfn>, or to his supposed
principles for conduct of government, as enunciated in his tract
<booki>The Prince</booki>; politically cunning; characterized by
duplicity, political expediency, unscrupulous cunning, or bad faith;
crafty.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Machiavellian</ent><br/
<ent>Machiavelian</ent><br/
<mhw><hw>Mach`i*a*vel"ian</hw>, <hw>Mach`i*a*vel"lian</hw></mhw>,
<pos>n.</pos> <def>One who adopts the principles of
<persfn>Machiavelli</persfn>; a cunning and unprincipled
politician.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machiavellianism</ent><br/
<ent>Machiavelism</ent><br/
<mhw>{ <hw>Mach"i*a*vel*ism</hw> <pr>(?)</pr>,
<hw>Mach`i*a*vel"lian*ism</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[Cf. F. <ets>machiav<eacute/lisme</ets>; It.
<ets>machiavellismo</ets>.]</ety> <def>The supposed principles of
<persfn>Machiavelli</persfn>, or practice in conformity to them;
political artifice, intended to favor arbitrary power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machicolated</ent><br/
<hw>Ma*chic"o*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>machicolatus</ets>, p. p. of <ets>machicolare</ets>,
<ets>machicollare</ets>. See <er>Machicolation</er>.]</ety> <def>Having
machicolations.</def> <ldquo/<xex>Machicolated</xex> turrets.<rdquo/
<rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machicolation</ent><br/
<hw>Mach`i*co*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. LL.
<ets>machicolamentum</ets>, <ets>machacolladura</ets>, F.
<ets>m<acir/chicolis</ets>, <ets>m<acir/checoulis</ets>; perh. fr. F.
<ets>m<egrave/che</ets> match, combustible matter + OF.
<ets>coulis</ets>, <ets>couleis</ets>, flowing, fr. OF. & F.
<ets>couler</ets> to flow. Cf. <er>Match</er> for making fire, and
<er>Cullis</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Mil. Arch.)</fld> <def>An opening between the
corbels which support a projecting parapet, or in the floor of a gallery
or the roof of a portal, for shooting or dropping missiles upon
assailants attacking the base of the walls. Also, the construction of
such defenses, in general, when of this character. See
<xex>Illusts</xex>. of <er>Battlement</er> and
<er>Castle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of discharging missiles or pouring burning
or melted substances upon assailants through such apertures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machicoulis</ent><br/
\'d8<hw>Ma`chi`cou`lis"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<acir/chicoulis</ets>.]</ety> <fld>(Mil. Arch.)</fld> <def>Same as
<er>Machicolation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>machilid</ent><br/
<hw>mach"i*lid</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wingless insect
living in dark moist places, as under tree trunks; they make erratic
leaps when disturbed; called also <altname>jumping
bristletail</altname>.</def><br/
<syn><b>Syn. --</b> jumping bristletail.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Machilidae</ent><br/
<hw>Machilidae</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A natural
family of insects including the jumping bristletails.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Machinal</ent><br/
<hw>Ma*chin"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>machinalis</ets>: cf. F. <ets>machinal</ets>.]</ety> <def>Of or
pertaining to machines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machinate</ent><br/
<hw>Mach"i*nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Machinated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Machinating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>machinatus</ets>, p. p. of <ets>machinari</ets> to devise, plot.
See <er>Machine</er>.]</ety> <def>To plan; to contrive; esp., to form a
scheme with the purpose of doing harm; to contrive artfully; to
plot.</def> <ldquo/How long will you <xex>machinate</xex>!<rdquo/
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machinate</ent><br/
<hw>Mach"i*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To contrive, as
a plot; to plot; <as>as, to <ex>machinate</ex> evil</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machination</ent><br/
<hw>Mach`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>machinatio</ets>: cf. F. <ets>machination</ets>.]</ety> <sn>1.</sn>
<def>The act of machinating.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is devised; a device; a hostile or
treacherous scheme; an artful design or plot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Devilish <qex>machinations</qex> come to naught.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His ingenious <qex>machinations</qex> had failed.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machinator</ent><br/
<hw>Mach"i*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who machinates, or forms a scheme with evil designs; a plotter
or artful schemer.</def> <rj><au>Glanvill. Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machine</ent><br/
<hw>Ma*chine"</hw> <pr>(m<adot/*sh<emac/n")</pr>, <pos>n.</pos>
<ety>[F., fr. L. <ets>machina</ets> machine, engine, device, trick, Gr.
<grk>mhchanh`</grk>, from <grk>mh^chos</grk> means, expedient. Cf.
<er>Mechanic</er>.]</ety> <sn>1.</sn> <def>In general, any combination
of bodies so connected that their relative motions are constrained, and
by means of which force and motion may be transmitted and modified, as a
screw and its nut, or a lever arranged to turn about a fulcrum or a
pulley about its pivot, etc.; especially, a construction, more or less
complex, consisting of a combination of moving parts, or simple
mechanical elements, as wheels, levers, cams, etc., with their supports
and connecting framework, calculated to constitute a prime mover, or to
receive force and motion from a prime mover or from another machine, and
transmit, modify, and apply them to the production of some desired
mechanical effect or work, as weaving by a loom, or the excitation of
electricity by an electrical machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <xex>machine</xex> is most commonly applied to
such pieces of mechanism as are used in the industrial arts, for
mechanically shaping, dressing, and combining materials for various
purposes, as in the manufacture of cloth, etc. Where the effect is
chemical, or other than mechanical, the contrivance is usually
denominated an <xex>apparatus</xex> or <xex>device</xex>, not a machine;
as, a <xex>bleaching apparatus</xex>. Many large, powerful, or specially
important pieces of mechanism are called <xex>engines</xex>; as, a
<xex>steam engine</xex>, <xex>fire engine</xex>, <xex>graduating
engine</xex>, etc. Although there is no well-settled distinction between
the terms <xex>engine</xex> and machine among practical men, there is a
tendency to restrict the application of the former to contrivances in
which the operating part is not distinct from the motor.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any mechanical contrivance, as the wooden horse with
which the Greeks entered Troy; a coach; a bicycle.</def>
<rj><au>Dryden.</au> <au>Southey.</au> <au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person who acts mechanically or at the will of
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A combination of persons acting together for a
common purpose, with the agencies which they use; <as>as, the social
<ex>machine</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole <qex>machine</qex> of government ought not to bear upon
the people with a weight so heavy and oppressive.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A political organization arranged and controlled by
one or more leaders for selfish, private or partisan ends; the Tammany
<ex>machine</ex>.</def> <mark>[Political Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Supernatural agency in a poem, or a superhuman being
introduced to perform some exploit.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Elementary machine</b></col>, <cd>a name sometimes given
to one of the simple mechanical powers. See under
<er>Mechanical</er>.</cd> -- <col><b>Infernal machine</b></col>. <cd>See
under <er>Infernal</er>.</cd> -- <col><b>Machine gun</b></col>.<cd>See
under <er>Gun.</er></cd> -- <col><b>Machine screw</b></col>, <cd>a screw
or bolt adapted for screwing into metal, in distinction from one which
is designed especially to be screwed into wood.</cd> -- <col><b>Machine
shop</b></col>, <cd>a workshop where machines are made, or where metal
is shaped by cutting, filing, turning, etc.</cd> -- <col><b>Machine
tool</b></col>, <cd>a machine for cutting or shaping wood, metal, etc.,
by means of a tool; especially, a machine, as a lathe, planer, drilling
machine, etc., designed for a more or less general use in a machine
shop, in distinction from a machine for producing a special article as
in manufacturing.</cd> -- <col><b>Machine twist</b></col>, <cd>silken
thread especially adapted for use in a sewing machine.</cd> --
<col><b>Machine work</b></col>, <cd>work done by a machine, in
contradistinction to that done by hand labor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machine</ent><br/
<hw>Ma*chine"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Machined</conjf> <pr>(m<adot/*sh<emac/nd")</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Machining</conjf>.]</vmorph> <def>To subject to the
action of machinery; to make, cut, shape, or modify with a machine; to
effect by aid of machinery; to print with a printing machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>machine bolt</ent><br/
<hw>machine bolt</hw> <pos>n.</pos> <def>A threaded hexagonal or
square-headed bolt with a nut; it is tightened with a wrench and used to
connect metal parts.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine code</ent><br/
<hw>machine code</hw> <pos>n.</pos> <fld>(Computers) </fld> <def>Same as
<er>machine language</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine-driven</ent><br/
<ent>machine-controlled</ent><br/
<mhw><hw>machine-controlled</hw> <hw>machine-driven</hw></mhw>
<pos>adj.</pos> <def>same as <er>automated</er>.</def><br/
<syn><b>Syn. --</b> automated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine gun</ent><br/
<hw>machine gun</hw> <pos>n.</pos> <def>A fully automatic rapid-firing
rifle, which continues to fire bullets repeatedly as long as the trigger
is depressed; lighter versions may be carried in the hands, and heavier
versions may be mounted on a tripod, vehicle, or other mount. The
lighweight versions are sometimes called a <stype>submachine
gun</stype>.</def><br/
[<source>PJC</source>]</p>

<p><ent>machine gun</ent><br/
<ent>machine-gun</ent><br/
<mhw><hw>machine-gun</hw>, <hw>machine gun</hw></mhw> <pos>a.</pos>
<def>Occurring in rapid succession, like the firing of a <er>machine
gun</er>; <as>as, Tom was a persuasive speaker, with a smooth deep
voice, polysyllabic vocabulary, and a <ex>machine-gun</ex> articulation
that overwhelmed listeners</as>.</def><br/
<syn><b>Syn. --</b> rapid-fire.</syn><br/
[<source>PJC</source>]</p>

<p><ent>machine gunner</ent><br/
<hw>machine gunner</hw> <pos>n.</pos> <def>A soldier who operates a
machine gun.</def><br/
[<source>PJC</source>]</p>

<p><ent>machine language</ent><br/
<hw>machine language</hw> <pos>n.</pos> <fld>(Computers)</fld> <def>a
set of instructions{3} in a binary form that can be executed directly by
the CPU of a computer without translation by a computer
program.</def><br/
<syn><b>Syn. --</b> machine code, binary code.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>machine-like</ent><br/
<ent>machinelike</ent><br/
<mhw><hw>machinelike</hw>, <hw>machine-like</hw></mhw> <pos>adj.</pos>
<def>behaving in an unthinking manner, like the functioning of a
machine; <as>as, <ex>machine-like</ex> fools</as>.</def><br/
<syn><b>Syn. --</b> automatic, automaton-like, automatonlike,
machinelike, robotlike.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine-made</ent><br/
<hw>machine-made</hw> <pos>adj.</pos> <def>made by a machine. Contrasted
with <ant>handmade</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine-oriented language</ent><br/
<hw>machine-oriented language</hw> <pos>n.</pos> <def>A programming
language designed for use on a specific class of computers.</def><br/
<syn><b>Syn. --</b> computer language, computer-oriented language,
machine language.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine pistol</ent><br/
<hw>machine pistol</hw> <pos>n.</pos> <def>A fully automatic pistol; a
small submachine gun.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Machiner</ent><br/
<hw>Ma*chin"er</hw> <pr>(m<adot/*sh<emac/n"<etil/r)</pr>, <pos>n.</pos>
<def>One who or operates a machine; a machinist{2}.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>machine-readable</ent><br/
<hw>ma*chin"e-read"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Computers)</fld> <def>Readable by a machine;</def>
<specif>especially,</specif> <def>available on a data-storage medium in
a binary format that can be rapidly converted by standard input devices
into data in a computer memory; <as>as, the CIDE dictionary is a
<ex>machine-readable</ex> dictionary</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Machinery</ent><br/
<hw>Ma*chin"er*y</hw> <pr>(m<adot/*sh<emac/n"<etil/r*<ycr/)</pr>,
<pos>n.</pos> <ety>[From <er>Machine</er>: cf. F.
<ets>machinerie</ets>.]</ety> <sn>1.</sn> <def>Machines, in general, or
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The working parts of a machine, engine, or
instrument; <as>as, the <ex>machinery</ex> of a watch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The supernatural means by which the action of a
poetic or fictitious work is carried on and brought to a catastrophe; in
an extended sense, the contrivances by which the crises and conclusion
of a fictitious narrative, in prose or verse, are effected.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>machinery</qex>, madam, is a term invented by the
critics, to signify that part which the deities, angels, or demons, are
made to act in a poem.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The means and appliances by which anything is kept
in action or a desired result is obtained; a complex system of parts
adapted to a purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An indispensable part of the <qex>machinery</qex> of state.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The delicate inflexional <qex>machinery</qex> of the Aryan
languages.</q> <rj><qau>I. Taylor (The Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>machine screw</ent><br/
<hw>machine screw</hw> <pos>n.</pos> <def>A type of screw used either
with a nut or with a tapped hole; it has a slotted head which can be
driven by a screwdriver.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine shop</ent><br/
<hw>machine shop</hw> <pos>n.</pos> <def>A small business or a room
within a business establishment where metal is cut and shaped etc., by
machine tools.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine tool</ent><br/
<hw>machine tool</hw> <pos>n.</pos> <def>A power-driven machine for
cutting or shaping or finishing metals or other materials.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>machine translation</ent><br/
<hw>ma*chine" trans*la"tion</hw> <pos>n.</pos> <fld>(Computers)</fld>
<def>The translation of human language from one language to another by a
computer; -- a branch of <branchof>artificial
intelligence</branchof>.</def><br/
<syn><b>Syn. --</b> computer translation, automatic
translation.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Machining</ent><br/
<hw>Ma*chin"ing</hw>, <pos>a.</pos> <def>Of or pertaining to the
machinery of a poem; acting or used as a machine.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Machinist</ent><br/
<hw>Ma*chin"ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>machiniste</ets>.]</ety> <sn>1.</sn> <def>A constructor of machines
and engines; one versed in the principles of machines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One skilled in the use of machine tools.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person employed to shift scenery in a
theater.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>machismo</ent><br/
<hw>machismo</hw> <pos>n.</pos> <sn>1.</sn> <def>A strong, and by some
considered exaggerated, sense of manly pride, associated with an
attitude that the proper expression of masculinity includes virility,
courage, and an entitlement to dominate, especially over
women.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>An exaggerated sense of power entitling one to
dominate others; <as>as, the civilian authorities occasionally need to
rein in the military's <ex>machismo</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>machmeter</ent><br/
<hw>machmeter</hw> <pos>n.</pos> <def>an instrument for measuring the
speed of an aircraft relative to the speed of sound.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mach number</ent><br/
<hw>mach number</hw> <pos>n.</pos> <fld>(aeronautics)</fld> <def>The
ratio of the speed of a moving body to the speed of sound.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macho</ent><br/
<hw>Ma"cho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<fld>(Zool.)</fld> <def>The striped mullet of California (<spn>Mugil
cephalus</spn>, syn. <spn>Mugil Mexicanus</spn>).</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>macho</ent><br/
<hw>ma"cho</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Sp.]</ety> <def>Manly,
especially with an assertive and domineering manner toward
women.</def><br/
[<source>PJC</source>]</p>

<p><ent>MACHO</ent><br/
<hw>MACHO</hw> <pr>(m<aum/"k<osl/)</pr>, <pos>n.</pos> <ety>[acronym
from <ets>M</ets>assive <ets>A</ets>strophysical <ets>C</ets>ompact
<ets>H</ets>alo <ets>O</ets>bject.]</ety> <def>A form of <isa>dark
matter</isa> in distant outer space unobservable except by its
gravitational effect, and believed to be at least part of the
<ldquo/missing matter<rdquo/ which is unobservable as ordinary stars,
but helps keep galaxies from flying apart; MACHOS are massive but
compact objects such as neutron stars or brown dwarfs, which can be
detected (with difficulty) by their effect in bending light from distant
light sources, such as other galaxies. This can occur if by rare chance
a MACHO passes in front of a more distant visible object, and the light
from that object becomes temporarily amplified by the MACHO acting as a
gravitational lens. Some MACHOs have been discovered in the halo of dark
matter that surrounds our milky way. It is, however, questionable
whether the amount of such matter is sufficient to explain the ability
of galaxies to stay together in spite of rotation rates that would cause
them to fly apart if the only matter present was that observable as
visible stars.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macilency</ent><br/
<hw>Mac"i*len*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Macilent</er>.]</ety> <def>Leanness.</def> <mark>[Obs.]</mark>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macilent</ent><br/
<hw>Mac"i*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>macilentus</ets>, fr. <ets>macies</ets> leanness, <ets>macere</ets>
to be lean.]</ety> <def>Lean; thin.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macintosh</ent><br/
<hw>Mac"in*tosh</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Same
as <er>Mackintosh</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Trademark.]</ety> <fld>(Computers)</fld> <def>A
brand of personal computer featuring an integrated system in which the
hardware and system-operating software were designed by or under the
control of a single company, the <corpn>Apple Computer
Corporation</corpn>; among personal computers, distinguished from the
<contr>IBM-compatible</contr> or <contr>Intel-based</contr> series of
computers.</def><br/
[<source>PJC</source>]</p>

<p><ent>mack</ent><br/
<hw>mack</hw> <pos>n.</pos> <def>A <er>mackintosh</er>; -- a shortened
form.</def><br/
<syn><b>Syn. --</b> macintosh, mackintosh, mac.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mackenzie</ent><br/
<hw>Mackenzie</hw> <pos>peop. n.</pos> <def>a Canadian river; flows into
the Beaufort Sea.</def><br/
<syn><b>Syn. --</b> Mackenzie River.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mackerel</ent><br/
<hw>Mack"er*el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>maquerel</ets>, F. <ets>maquereau</ets>, fr. D. <ets>makelaar</ets>
mediator, agent, fr. <ets>makelen</ets> to act as agent.]</ety> <def>A
pimp; also, a bawd.</def> <mark>[Obs.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mackerel</ent><br/
<hw>Mack`er*el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>maquerel</ets>, F. <ets>maquereau</ets> (LL.
<ets>macarellus</ets>), prob. for <ets>maclereau</ets>, fr. L.
<ets>macula</ets> a spot, in allusion to the markings on the fish. See
<er>Mail</er> armor.]</ety> <fld>(Zool.)</fld> <def>Any species of the
genus <gen>Scomber</gen> of the family <fam>Scombridae</fam>, and of
several related genera. They are finely formed and very active oceanic
fishes. Most of them are highly prized for food.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common mackerel (<spn>Scomber scombrus</spn>), which
inhabits both sides of the North Atlantic, is one of the most important
food fishes. It is mottled with green and blue. The Spanish mackerel
(<spn>Scomberomorus maculatus</spn>), of the American coast, is covered
with bright yellow circular spots.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bull mackerel</b></col>, <col><b>Chub
mackerel</b></col></mcol>. <fld>(Zool.)</fld> <cd>See under
<er>Chub</er>.</cd> -- <col><b>Frigate mackerel</b></col>. <cd>See under
<er>Frigate</er>.</cd> -- <col><b>Horse mackerel</b></col> . <cd>See
under <er>Horse</er>.</cd> -- <col><b>Mackerel bird</b></col>
<fld>(Zool.)</fld>, <cd>the wryneck; -- so called because it arrives in
England at the time when mackerel are in season.</cd> --
<col><b>Mackerel cock</b></col> <fld>(Zool.)</fld>, <cd>the Manx
shearwater; -- so called because it precedes the appearance of the
mackerel on the east coast of Ireland.</cd> -- <col><b>Mackerel
guide</b></col>. <fld>(Zool.)</fld> <cd>See <er>Garfish</er>
<sd>(a)</sd>.</cd> -- <col><b>Mackerel gull</b></col> <fld>(Zool.)</fld>
<cd>any one of several species of gull which feed upon or follow
mackerel, as the kittiwake.</cd> -- <col><b>Mackerel midge</b></col>
<fld>(Zool.)</fld>, <cd>a very small oceanic gadoid fish of the North
Atlantic. It is about an inch and a half long and has four barbels on
the upper jaw. It is now considered the young of the genus
<gen>Onos</gen>, or <gen>Motella</gen>.</cd> -- <col><b>Mackerel
plow</b></col>, <cd>an instrument for creasing the sides of lean
mackerel to improve their appearance.</cd> <au>Knight.</au> --
<col><b>Mackerel shark</b></col> <fld>(Zool.)</fld>, <cd>the
porbeagle.</cd> -- <mcol><col><b>Mackerel sky</b></col>, <it>or</it>
<col><b>Mackerel-back sky</b></col></mcol>, <cd>a sky flecked with small
white clouds; a cirro-cumulus. See <er>Cloud</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mackerel sky</qex> and mare's-tails<br/
Make tall ships carry low sails.</q> <rj><qau>Old Rhyme.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mackerel shad</ent><br/
<ent>mackerel scad</ent><br/
<mhw><hw>mackerel scad</hw>, <hw>mackerel shad</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>A small silvery fish (<spn>Decapterus
macarellus</spn>) found from Nova Scotia to Brazil.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mackerel sky</ent><br/
<hw>mackerel sky</hw> <pos>n.</pos> <def>A sky filled with rows of
cirrocumulus or small altocumulus clouds.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mackinaw</ent><br/
<ent>Mackinaw blanket</ent><br/
<mhw>{ <hw>Mack"i*naw blan"ket</hw> <pr>(?)</pr>, <hw>Mack"i*naw</hw>.
}</mhw><ety>[From <ets>Mackinac</ets>, the State of Michigan, where
blankets and other stores were distributed to the Indians.]</ety>
<sn>1.</sn> <def>A thick blanket formerly in common use in the western
part of the United States.</def> <wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a heavy woolen cloth heavily napped and felted,
often with a plaid design.</def> <wns>[wns=4]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mackinaw boat</ent><br/
<ent>Mackinaw</ent><br/
<mhw><hw>Mack"i*naw</hw>, <hw>Mack"i*naw boat</hw></mhw>. <def>A
flat-bottomed boat with a pointed prow and square stern, using oars or
sails or both, used esp. on the upper Great Lakes and their
tributaries.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mackinaw coat</ent><br/
<ent>Mackinaw</ent><br/
<mhw><hw>Mack"i*naw</hw>, <hw>Mack"i*naw coat</hw></mhw>. <def>A short,
heavy, double-breasted plaid coat, the design of which is large and
striking.</def> <mark>[Local, U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mackinaw trout</ent><br/
<hw>Mackinaw trout</hw>. <def>The namaycush.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mackintosh</ent><br/
<hw>Mack"in*tosh</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A waterproof
outer garment; -- so called from the name of the inventor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mackle</ent><br/
<hw>Mac"kle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Macle</er>.]</ety> <def>Same as <er>Macule</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mackle</ent><br/
<hw>Mac"kle</hw>, <pos>v. t. & i.</pos> <def>To blur, or be blurred, in
printing, as if there were a double impression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macle</ent><br/
<hw>Ma"cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>macula</ets> a
spot: cf. F. <ets>macle</ets>. Cf. <er>Mackle</er>,
<er>Mascle</er>.]</ety> <fld>(Min.)</fld> <sd>(a)</sd> <def>Chiastolite;
-- so called from the tessellated appearance of a cross section. See
<er>Chiastolite</er>.</def> <sd>(b)</sd> <def>A crystal having a similar
tessellated appearance.</def> <sd>(c)</sd> <def>A twin
crystal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macleaya</ent><br/
<hw>Macleaya</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Bot.)</fld>
<def>A genus of East Asian perennial herbs including the plume
poppy.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macled</ent><br/
<hw>Ma"cled</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Min.)</fld> <sd>(a)</sd> <def>Marked like macle
(chiastolite).</def> <sd>(b)</sd> <def>Having a twin structure. See
<er>Twin</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <er>Mascled</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maclura</ent><br/
<hw>Maclura</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Bot.)</fld>
<def>A genus of plants including the yellowwood trees and
shrubs.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maclurea</ent><br/
\'d8<hw>Ma*clu"re*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. Named
from <person>William <etsep>Maclure</etsep></person>, the
geologist.]</ety> <fld>(Paleon.)</fld> <def>A genus of spiral gastropod
shells, often of large size, characteristic of the lower Silurian
rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maclurin</ent><br/
<hw>Ma*clu"rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Morintannic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maconnais</ent><br/
<ent>macon</ent><br/
<mhw><hw>macon</hw>, <hw>maconnais</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>A fine Burgundy wine usually white and dry, produced
in the area around Macon, a city in France.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macoun</ent><br/
<hw>Ma*coun"</hw> <pr>(m<adot/*k<oomac/n")</pr>, <pos>prop. n.</pos>
<def>A juicy, late-ripening apple similar to a McIntosh.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macowanites</ent><br/
<hw>Macowanites</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A
stout-stemmed genus of fungi belonging to the family
<fam>Secotiaceae</fam> having fruiting bodies that never expand
completely.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macowanites americanus</ent><br/
<hw>Macowanites americanus</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A
small fungus with a fragile cap that cracks to expose the white context
and a white stalk that is practically enclosed by the cap.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macrame</ent><br/
<hw>Mac"ra*me</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>the art
of tying knots in patterns.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a coarse lace, made by weaving and knotting cords;
<er>macrame lace</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macrame lace</ent><br/
<hw>Mac"ra*me lace"</hw> <pr>(?)</pr>. <def>A coarse lace made of twine,
used especially in decorating furniture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrencephalous</ent><br/
<ent>Macrencephalic</ent><br/
<mhw>{ <hw>Mac`ren*ce*phal"ic</hw> <pr>(?)</pr>,
<hw>Mac`ren*ceph"a*lous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Macro</ets> + <ets>encephalic</ets>,
<ets>encephalous</ets>.]</ety> <def>Of or pertaining to macrencephaly;
having a large brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macrencephaly</ent><br/
<hw>macrencephaly</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
having an abnormally large braincase.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>macro</ent><br/
<hw>macro</hw> <pos>n.</pos> <ety>[shortened form of
<ets>macroinstruction</ets>]</ety> <sn>1.</sn> <def>a single computer
instruction which symbolizes, and is converted at the time of program
execution or by a compiler into, a series of instructions in the same
computer language.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A keystroke (or combination of keystrokes) which
symbolizes and is replaced by a series of keystrokes; -- a convenient
feature of some advanced programs, such as word processors or database
programs, which allows a user to rapidly execute any series of
operations which may be performed multiple times. Such macros may
typically be defined by the program user, without rewriting or
recompiling the program.</def><br/
[<source>PJC</source>]</p>

<p><ent>macro</ent><br/
<hw>macro</hw> <pos>a.</pos> <def>very large in scale or scope or
capability; <as>as, <ex>macro</ex>economics</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macro-</ent><br/
<hw>Mac"ro-</hw> <pr>(?)</pr> <pos>pref.</pos> <ety>[Gr.
<grk>makro`s</grk>, adj.]</ety> <def>A combining form signifying
<sig>long</sig>, <sig>large</sig>, <sig>great</sig>; <as>as
<ex>macro</ex>diagonal, <ex>macro</ex>spore, <ex>macro</ex>molecule,
<ex>macro</ex>cosm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrobiotic</ent><br/
<hw>Mac`ro*bi*ot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
long-lived; <grk>makro`s</grk> long + <grk>bi`os</grk> life: cf. F.
<ets>macrobiotique</ets>.]</ety> <sn>1.</sn> <def>Long-lived.</def>
<rj><au> Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to macrobiotics.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to macrobiotic food; serving
macrobiotic food.</def><br/
[<source>PJC</source>]</p>

<p><ent>macrobiotic diet</ent><br/
<hw>macrobiotic diet</hw> <pos>n.</pos> <def>A diet consisting chiefly
of beans and whole grains.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macrobiotics</ent><br/
<hw>Mac`ro*bi*ot"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Physiol.)</fld> <def>The art of prolonging life.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>A philosophy or
attitude that health and long life are promoted by adhering to a diet
consisting mostly of whole grains, with some vegetables, beans, fruit,
and moderate amounts of seafood. However, the absence of essential
nutrients such as fat makes such a diet of questionable value if
strictly adhered to.</def><br/
[<source>PJC</source>]</p>

<p><ent>macrocephalous</ent><br/
<ent>macrocephalic</ent><br/
<mhw><hw>mac`ro*ce*phal"ic</hw> <pr>(?)</pr>,
<hw>mac`ro*ceph"a*lous</hw></mhw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Macro</ets> + Gr. <grk>kefalh`</grk> the head.]</ety>
<sn>1.</sn> <def>Of or pertaining to macrocephaly; having an unusually
large head.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having the cotyledons of a
dicotyledonous embryo confluent, and forming a large mass compared with
the rest of the body.</def> <rj><au>Henslow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>macrocephaly</ent><br/
<hw>macrocephaly</hw> <pos>n.</pos> <def>THe condition of having an
unusually large head; it differs from <contr>hydrocephalus</contr>
because there is no increase intracranial pressure and the overgrowth is
symmetrical.</def><br/
<syn><b>Syn. --</b> megacephaly, megalocephaly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macrocheira</ent><br/
<hw>Macrocheira</hw> <pos>peop. n.</pos> <def>A genus of giant crabs of
Japan.</def><br/
<syn><b>Syn. --</b> genus <gen>Macrocheira</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macro-chemistry</ent><br/
<hw>Mac`ro-chem"is*try</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>chemistry</ets>.]</ety>
<fld>(Chem.)</fld> <def>The science which treats of the chemical
properties, actions or relations of substances in quantity; --
distinguished from <contr>micro-chemistry</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrochires</ent><br/
\'d8<hw>Mac`ro*chi"res</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>makro`s</grk> long + <?/ hand.]</ety> <fld>(Zool.)</fld>
<def>A division of birds including the swifts and humming birds. So
called from the length of the distal part of the wing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macroclemys</ent><br/
<hw>Macroclemys</hw> <pos>n.</pos> <def>A genus of alligator snapping
turtles.</def><br/
<syn><b>Syn. --</b> genus <gen>Macroclemys</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macrocosm</ent><br/
<hw>Mac"ro*cosm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Macro-</ets>
+ Gr. <?/ the world: cf. F. <ets>macrocosme</ets>.]</ety> <def>The great
world; that part of the universe which is exterior to man; -- contrasted
with <xex>microcosm</xex>, or man. See <er>Microcosm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrocosmic</ent><br/
<hw>Mac`ro*cos"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the macrocosm.</def> <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrocystis</ent><br/
\'d8<hw>Mac`ro*cys"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Macro-</er>, and <er>Cyst</er>.]</ety> <fld>(Bot.)</fld> <def>An
immensely long blackish seaweed of the Pacific (<spn>Macrocystis
pyrifera</spn>), having numerous almond-shaped air vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macro lens</ent><br/
<hw>macro lens</hw> <pos>n.</pos> <def>a camera lens designed to focus
at short distances so as to achieve photographic magnifications of
objects larger than with standard lenses.</def><br/
[<source>PJC</source>]</p>

<p><ent>macrocyte</ent><br/
<hw>macrocyte</hw> <pos>n.</pos> <def>An abnormally large red blood
cell, associated with pernicious anemia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>macrocytosis</ent><br/
<hw>macrocytosis</hw> <pos>n.</pos> <def>An abnormal physiological
condition characterized by the presence of macrocytes in the
blood.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 880 --></p>

<p><ent>Macrodactyl</ent><br/
<hw>Mac`ro*dac"tyl</hw> <pr>(m<acr/k`r<osl/*d<acr/k"t<icr/l)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>makroda`ktylos</grk> long-fingered;
<grk>makro`s</grk> long + <grk>da`ktylos</grk> finger: cf. F.
<ets>macrodactyle</ets>.]</ety> <fld>(Zool.)</fld> <def>One of a group
of wading birds (<it>Macrodactyli</it>) having very long toes.</def>
<altsp>[Written also <asp>macrodactyle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrodactylous</ent><br/
<ent>Macrodactylic</ent><br/
<mhw>{ <hw>Mac`ro*dac*tyl"ic</hw> <pr>(?)</pr>,
<hw>Mac`ro*dac"tyl*ous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having long toes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrodiagonal</ent><br/
<hw>Mac`ro*di*ag"o*nal</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>diagonal</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>The longer of two diagonals, as of a
rhombic prism. See <er>Crystallization</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrodome</ent><br/
<hw>Mac"ro*dome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Macro-</ets>
+ <ets>dome</ets>.]</ety> <fld>(Crystallog.)</fld> <def>A dome parallel
to the longer lateral axis of an orthorhombic crystal. See
<er>Dome</er>, <pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrodont</ent><br/
<hw>Mac"ro*dont</hw>, <pos>a.</pos> <ety>[<ets>Macro-</ets> + Gr.
<grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, a tooth.]</ety>
<fld>(Zool.)</fld> <def>Having large teeth.</def> -- <def2><pos>n.</pos>
<def>A macrodont animal.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrofarad</ent><br/
<hw>Mac"ro*far`ad</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>farad</ets>.]</ety> <fld>(Elec.)</fld>
<def>See <er>Megafarad</er>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>macroglia</ent><br/
<hw>macroglia</hw> <pos>n.</pos> <def>Tissue consisting of large
stellate neuroglial cells.</def><br/
<syn><b>Syn. --</b> astroglia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macroglossia</ent><br/
\'d8<hw>Mac`ro*glos"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Macro-</er>, and <er>Glossa</er>.]</ety> <fld>(Med.)</fld>
<def>Enlargement or hypertrophy of the tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrognathic</ent><br/
<hw>Mac`rog*nath"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Macro-</ets> + <ets>gnathic</ets>.]</ety>
<fld>(Anthropol.)</fld> <def>Long-jawed.</def>
<rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrograph</ent><br/
<hw>Mac"ro*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>-graph</ets>.]</ety> <def>A picture of an
object as seen by the naked eye (that is, unmagnified); <as>as, a
<ex>macrograph</ex> of a metallic fracture</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Macrography</ent><br/
<hw>Ma*crog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Examination or
study with the naked eye, as distinguished from
<contr>micrography</contr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Macrology</ent><br/
<hw>Ma*crol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>macrologia</ets>, Gr. <?/; <?/ long + <grk>lo`gos</grk> discourse:
cf. F. <ets>macrologie</ets>.]</ety> <def>Long and tedious talk without
much substance; superfluity of words.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrometer</ent><br/
<hw>Ma*crom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>-meter</ets>.]</ety> <def>An instrument
for determining the size or distance of inaccessible objects by means of
two reflectors on a common sextant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macromolecule</ent><br/
<hw>mac`ro*mol"e*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.,
Biochem.)</fld> <def>A very large molecule, especially a polymer having
from hundreds to many thousands of atoms, such as <stype>DNA</stype>,
<stype>RNA</stype>, <stype>protein</stype>,
<stype>polysaccharide</stype>, <stype>polyethylene</stype>,
<stype>polycarbonate</stype>, etc.</def><br/
[<source>PJC</source>]</p>

<p><ent>macromolecular</ent><br/
<hw>mac`ro*mo*lec"u*lar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Of,
pertaining to, or consisting of macromolecules.</def><br/
[<source>PJC</source>]</p>

<p><ent>Macron</ent><br/
<hw>Ma"cron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
long.]</ety> <fld>(Pron.)</fld> <def>A short, straight, horizontal mark
[-], placed over vowels to denote that they are to be pronounced with a
long sound; as, <examp><amac/</examp>, in <examp>d<amac/me</examp>;
<examp><emac/</examp>, in <examp>s<emac/am</examp>, etc.</def><br/
<syn><b>Syn. --</b> macrotone.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropetalous</ent><br/
<hw>Mac`ro*pet"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Macro-</ets> + <ets>petal</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having long or large petals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macrophage</ent><br/
<hw>mac"ro*phage</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A large
phagocyte.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macrophyllous</ent><br/
<hw>Ma*croph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Macro-</ets> + Gr. <?/ a leaf.]</ety> <fld>(Bot.)</fld>
<def>Having long or large leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropinacoid</ent><br/
<hw>Mac`ro*pin"a*coid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>pinacoid</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>One of the two planes of an orthorhombic
crystal which are parallel to the vertical and longer lateral
(macrodiagonal) axes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropod</ent><br/
<hw>Mac"ro*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Macro-</ets>
+ <ets>-pod</ets>.]</ety> <fld>(Zool.)</fld> <def>Any one of a group of
maioid crabs remarkable for the length of their legs; -- called also
<altname>spider crab</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropodal</ent><br/
<hw>Ma*crop"o*dal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having long or
large feet, or a long stem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropodian</ent><br/
<hw>Mac`ro*po"di*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
macropod.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropodous</ent><br/
<hw>Ma*crop"o*dous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having long legs or feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macroprism</ent><br/
<hw>Mac"ro*prism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>prism</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>A prism of an orthorhombic crystal between
the macropinacoid and the unit prism; the corresponding pyramids are
called <xex>macropyramids</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropteres</ent><br/
\'d8<hw>Ma*crop"te*res</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ long + <grk>ptero`n</grk> feather, wing.]</ety>
<fld>(Zool.)</fld> <def>A division of birds; the Longipennes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropterous</ent><br/
<hw>Ma*crop"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Macropteres</er>.]</ety> <fld>(Zool.)</fld> <def>Having long wings
or fins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropus</ent><br/
\'d8<hw>Mac"ro*pus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Macropod</er>.]</ety> <fld>(Zool.)</fld> <def>A genus of marsupials
including the common kangaroo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macropyramid</ent><br/
<hw>Mac`ro*pyr"a*mid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>pyramid</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>See <er>Macroprism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macroscopical</ent><br/
<ent>Macroscopic</ent><br/
<mhw>{ <hw>Mac`ro*scop"ic</hw> <pr>(?)</pr>, <hw>Mac`ro*scop"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Macro-</ets> + Gr. <?/ to
view.]</ety> <def>Visible to the unassisted eye; -- as opposed to
<ant>microscopic</ant>.</def> --
<wordforms><wf>Mac`ro*scop"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrosporangium</ent><br/
\'d8<hw>Mac`ro*spo*ran"gi*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
See <er>Macro-</er>, and <er>Sporangium</er>.]</ety> <fld>(Bot.)</fld>
<def>A sporangium or conceptacle containing only large spores; --
opposed to <contr>microsporangium</contr>. Both are found in the genera
<gen>Selaginella</gen>, <gen>Isoctes</gen>, and <gen>Marsilia</gen>,
plants remotely allied to ferns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrospore</ent><br/
<hw>Mac"ro*spore</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>spore</ets>.]</ety> <fld>(Bot.)</fld>
<def>One of the specially large spores of certain flowerless plants, as
<gen>Selaginella</gen>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrosporic</ent><br/
<hw>Mac`ro*spor"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Of or pertaining to macrospores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrotone</ent><br/
<hw>Mac"ro*tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ stretched
out. See <er>Macro-</er>, and <er>Tone</er>.]</ety> <fld>(Pron.)</fld>
<def>Same as <er>Macron</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrotous</ent><br/
<hw>Ma*cro"tous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Macro-</ets>
+ Gr. <grk>o"y^s</grk>, gen. <grk>'wto`s</grk>, the ear.]</ety>
<fld>(Zool.)</fld> <def>Large-eared.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macrotus</ent><br/
<hw>ma*cro"tus</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A large-eared
grayish bat (<spn>Macrotus californicus</spn>) of southern California
and northwestern Mexico.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Macroural</ent><br/
<ent>Macroura</ent><br/
<mhw>\'d8<hw>Ma*crou"ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos>,
<hw>Ma*crou"ral</hw> <pr>(<?/)</pr>, <pos>a.</pos>, etc.</mhw>
<fld>(Zool.)</fld> <def>Same as <er>Macrura</er>, <er>Macrural</er>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrouridae</ent><br/
<hw>Macrouridae</hw> <pr>(?)</pr>, <pos>prop. n.</pos>,
<fld>(Zool.)</fld> <def>A natural family of fish including the
grenadiers.</def><br/
<syn><b>Syn. --</b> Macruridae.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Macrozoospore</ent><br/
<hw>Mac`ro*zo"o*spore</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Macro-</ets> + <ets>zoospore</ets>.]</ety> <fld>(Bot.)</fld>
<def>A large motile spore having four vibratile cilia; -- found in
certain green algae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrura</ent><br/
\'d8<hw>Ma*cru"ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ long + <?/ tail.]</ety> <fld>(Zool.)</fld> <def>A subdivision of
decapod Crustacea, having the abdomen largely developed. It includes the
lobster, prawn, shrimp, and many similar forms. Cf.
<er>Decapoda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrural</ent><br/
<hw>Ma*cru"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Macrurous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macruran</ent><br/
<hw>Ma*cru"ran</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Macrura.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macruridae</ent><br/
<hw>Macruridae</hw> <pr>(?)</pr>, <pos>prop. n.</pos>,
<fld>(Zool.)</fld> <def>Same as <er>Macrouridae</er>.</def><br/
<syn><b>Syn. --</b> Macrouridae.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Macruroid</ent><br/
<hw>Ma*cru"roid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Macrura</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Like or pertaining to the Macrura.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macrurous</ent><br/
<hw>Ma*cru"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Macrura; having a long tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mactation</ent><br/
<hw>Mac*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mactatio</ets>, fr. <ets>macture</ets> to slay, sacrifice.]</ety>
<def>The act of killing a victim for sacrifice.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mactra</ent><br/
\'d8<hw>Mac"tra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
kneading trough, fr. <?/ to knead.]</ety> <fld>(Zool.)</fld> <def>Any
marine bivalve shell of the genus <gen>Mactra</gen>, and allied genera.
Many species are known. Some of them are used as food, as <spn>Mactra
stultorum</spn>, of Europe. See <cref>Surf clam</cref>, under
<er>Surf</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macula</ent><br/
\'d8<hw>Mac"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Maculae</plw> <pr>(#)</pr>.</plu> <ety>[L., spot, stain, blot. See
<er>Mail</er> armor, and cf. <er>Mackle</er>, <er>Macule</er>.]</ety>
<sn>1.</sn> <def>A spot, as on the skin, or on the surface of the sun or
of some other luminous orb; called also
<altname>macule</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A rather large spot or blotch of
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macular area</ent><br/
<ent>macula lutea</ent><br/
<mhw><hw>macula lutea</hw>, <hw>macular area</hw></mhw> <pos>n.</pos>
<def>A yellowish central area of the retina that is rich in
cones.</def><br/
<syn><b>Syn. --</b> macula, yellow spot.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maculate</ent><br/
<hw>Mac"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>maculatus</ets>, p. p. of <ets>maculare</ets> to spot. See
<er>Macula</er>, and cf. <er>Macule</er>, <pos>v.</pos>]</ety> <def>To
spot; to stain; to blur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Maculate</qex> the honor of their people.</q> <rj><qau>Sir T.
Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maculate</ent><br/
<hw>Mac"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>maculatus</ets>, p. p.]</ety> <def>Marked with spots or maculae;
blotched; hence, defiled; impure; <as>as, most <ex>maculate</ex>
thoughts</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maculated</ent><br/
<hw>Mac"u*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having spots or
blotches; maculate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maculation</ent><br/
<hw>Mac"u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maculatio</ets>.]</ety> <def>The act of spotting; a spot; a
blemish; a macula.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maculatory</ent><br/
<hw>Mac"u*la*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing a spot
or stain.</def> <rj><au>T. Adams.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maculature</ent><br/
<hw>Mac"u*la*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Blotting
paper.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macule</ent><br/
<hw>Mac"ule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>macule</ets>.
See <er>Macula</er>.]</ety> <sn>1.</sn> <def>A spot.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A blur, or an appearance of a
double impression, as when the paper slips a little; a mackle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Macule</ent><br/
<hw>Mac"ule</hw>, <pos>v. t.</pos> <ety>[Cf. F. <ets>maculer</ets>. See
<er>Maculate</er>, <pos>v.</pos>]</ety> <def>To blur; especially
<fld>(Print.)</fld>, to blur or double an impression from type. See
<er>Mackle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maculose</ent><br/
<hw>Mac"u*lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>maculosus</ets>.]</ety> <def>Of or pertaining to spots upon a
surface; spotted; maculate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>macumba</ent><br/
<hw>macumba</hw> <pr>(?)</pr>, <pos>n.</pos>, <sn>1.</sn> <def>A popular
dance music of Brazil, derived from the practices of the macumba
religious cult.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>2.</sn> <def>a Brazilian religious cult of African origin;
combines voodoo elements with singing a chanting and dancing.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>macumba</ent><br/
<hw>macumba</hw> <pr>(?)</pr>, <pos>n.</pos>, <def>darling; -- an Irish
term of address expressing affection.</def> <mark>[Irish]</mark> <br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Mad</ent><br/
<hw>Mad</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of
<er>Made</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mad</ent><br/
<hw>Mad</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Madder</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Maddest</adjf> <pr>(?)</pr>.]</amorph> <ety>[AS.
<ets>gem<?/d</ets>, <ets>gem<amac/d</ets>, mad; akin to OS.
<ets>gem<?/d</ets> foolish, OHG. <ets>gameit</ets>, Icel.
<ets>mei<?/a</ets> to hurt, Goth. <ets>gam<aacute/ids</ets> weak,
broken. <?/.]</ety> <sn>1.</sn> <def>Disordered in intellect; crazy;
insane.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have heard my grandsire say full oft,<br/
Extremity of griefs would make men <qex>mad</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excited beyond self-control or the restraint of
reason; inflamed by violent or uncontrollable desire, passion, or
appetite; <as>as, to be <ex>mad</ex> with terror, lust, or hatred;
<ex>mad</ex> against political reform.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the land of graven images, and they are <qex>mad</qex> upon
their idols.</q> <rj><qau>Jer. 1. 88.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And being exceedingly <qex>mad</qex> against them, I persecuted
them even unto strange cities.</q> <rj><qau>Acts xxvi.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Proceeding from, or indicating, madness; expressing
distraction; prompted by infatuation, fury, or extreme rashness.</def>
<ldquo/<xex>Mad</xex> demeanor.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mad</qex> wars destroy in one year the works of many years of
peace.</q> <rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mad</qex> promise of Cleon was fulfilled.</q>
<rj><qau>Jowett (Thucyd.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Extravagant; immoderate.</def> <ldquo/Be
<xex>mad</xex> and merry.<rdquo/ <au>Shak.</au> <ldquo/Fetching
<xex>mad</xex> bounds.<rdquo/ <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Furious with rage, terror, or disease; -- said of
the lower animals; <as>as, a <ex>mad</ex> bull</as>; esp., having
hydrophobia; rabid; <as>as, a <ex>mad</ex> dog</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Angry; out of patience; vexed; <as>as, to get
<ex>mad</ex> at a person</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Having impaired polarity; -- applied to a compass
needle.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Like mad</b></col>, <cd>like a mad person; in a furious
manner; <as>as, to run <ex>like mad</ex>. <au>L'Estrange</au></as>.</cd>
-- <col><b>To run mad</b></col>. <sd>(a)</sd> <cd>To become wild with
excitement</cd>. <sd>(b)</sd> <cd>To run wildly about under the
influence of hydrophobia; to become affected with hydrophobia.</cd> --
<col><b>To run mad after</b></col>, <cd>to pursue under the influence of
infatuation or immoderate desire.</cd> <ldquo/The world is <xex>running
mad after</xex> farce.<rdquo/ <au>Dryden.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mad</ent><br/
<hw>Mad</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Madded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Madding</conjf>.]</vmorph> <def>To make mad or furious; to
madden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had I but seen thy picture in this plight,<br/
It would have <qex>madded</qex> me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mad</ent><br/
<hw>Mad</hw>, <pos>v. i.</pos> <def>To be mad; to go mad; to rave. See
<er>Madding</er>.</def> <mark>[Archaic]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Festus said with great voice, Paul thou <qex>maddest</qex>.</q>
<rj><qau>Wyclif (Acts).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mad</ent><br/
<hw>Mad</hw>, <pos>n.</pos> <ety>[AS. <ets>ma<?/a</ets>; akin to D. & G.
<ets>made</ets>, Goth. <ets>mapa</ets>, and prob. to E.
<ets>moth</ets>.]</ety> <fld>(Zool.)</fld> <def>An earthworm.</def>
<altsp>[Written also <asp>made</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madagascan</ent><br/
<hw>Madagascan</hw> <pos>prop. a.</pos> <sn>1.</sn> <def>Of or
pertaining to Madagascar; <as>as, <ex>Madagascan</ex>
pepper</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the inhabitants of Madagascar;
<as>as, <ex>Madagascan</ex> soldiers</as>.</def><br/
<syn><b>Syn. --</b> Malagasy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madagascan</ent><br/
<hw>Madagascan</hw> <pos>prop. n.</pos> <def>A native or inhabitant of
Madagascar.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madagascar</ent><br/
<hw>Mad`a*gas"car</hw> <pr>(m<acr/d`<adot/*g<acr/s"k<etil/r)</pr>
<pos>prop. n.</pos> <def>An island in the Indian Ocean, about 240 miles
off the southeast coast of Africa, governed as a single country, the
<country>Republic of Madagascar</country>. It is the world's
fourth-largest island, with a total area of 587,040 sq km, with 4,828 km
of coastline. Once a French colony, it gained independence from France
in 1960. The name of the government after independence was the
<country>Malagasy Republic</country>.</def><br/
[<source>PJC</source>]</p>

<p><q> Formerly an independent kingdom, <country>Madagascar</country>
became a French colony in 1886, but regained its independence in 1960.
During 1992-93, free presidential and National Assembly elections were
held, ending 17 years of single-party rule. In 1997 in the second
presidential race, Didier RATSIRAKA, the leader during the 1970s and
1980s, was returned to the presidency. The Population: is 15,982,563
(July 2001 est.) The highest point is Maromokotro, at 2,876 m. Natural
resources are: graphite, chromite, coal, bauxite, salt, quartz, tar
sands, semiprecious stones, mica, fish, and hydropower.</q> <qau>CIA
World Factbook</qau><br/
[<source>PJC</source>]</p>

<p><ent>madagascar cat</ent><br/
<hw>madagascar cat</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A small
lemur having its tail barred with black.</def><br/
<syn><b>Syn. --</b> ring-tailed lemur, <spn>Lemur catta</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>madagascar jasmine</ent><br/
<hw>madagascar jasmine</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
twining woody vine (<spn>Stephanotis floribunda</spn>) of Madagascar
having thick dark waxy evergreen leaves and clusters of large fragrant
waxy white flowers along the stems; widely cultivated in warm
regions.</def><br/
<syn><b>Syn. --</b> waxflower, <spn>Stephanotis
floribunda</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>madagascar pepper</ent><br/
<hw>madagascar pepper</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
climber (<spn>Piper nigrum</spn>) having dark red berries (peppercorns)
when fully ripe; found in South India and <country>Sri Lanka</country>;
naturalized in North Burma and Assam.</def><br/
<syn><b>Syn. --</b> pepper, common pepper, black pepper, white pepper,
Madagascar pepper, <spn>Piper nigrum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>madagascar periwinkle</ent><br/
<hw>madagascar periwinkle</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
commonly cultivated Old World woody herb (<spn>Vinca rosea</spn>) having
large pinkish to red flowers.</def><br/
<syn><b>Syn. --</b> periwinkle, rose periwinkle, Madagascar periwinkle,
old maid, Cape periwinkle, red periwinkle, cayenne jasmine,
<spn>Catharanthus roseus</spn>, <spn>Vinca rosea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>madagascar plum</ent><br/
<hw>madagascar plum</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A small
shrubby tree (<spn>Flacourtia indica</spn>) of Madagascar cultivated in
tropical regions as a hedge plant and for its deep red acid fruits
resembling small plums.</def><br/
<syn><b>Syn. --</b> governor's plum, governor plum, Madagascar plum,
ramontchi, batoko palm, <spn>Flacourtia indica</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>madake</ent><br/
<hw>madake</hw> <pos>n.</pos> <def>large bamboo having thick-walled
culms; native of China and perhaps Japan; widely brown
elsewhere.</def><br/
<syn><b>Syn. --</b> giant timber bamboo, ku-chiku, Phyllostachys
bambusoides.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madam</ent><br/
<hw>Mad"am</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Madams</plw>, or <plw>Mesdames</plw> <pr>(#)</pr>.</plu> <ety>[See
<er>Madame</er>.]</ety> <sn>1.</sn> <def>A gentlewoman; -- an
appellation or courteous form of address given to a lady, especially an
elderly or a married lady; -- much used in the address, at the beginning
of a letter, to a woman. The corresponding word in addressing a man is
<contr>Sir</contr>; often abbreviated <abbr>ma'am</abbr> when used as a
term of address.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The woman who is in charge of a household.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The woman who is in charge of a brothel.</def><br/
[<source>PJC</source>]</p>

<p><ent>Madame</ent><br/
\'d8<hw>Ma`dame"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mesdames</plw> <pr>(#)</pr>.</plu> <ety>[F., fr. <ets>ma</ets> my
(L. <ets>mea</ets>) + <ets>dame</ets> dame. See <er>Dame</er>, and cf.
<er>Madonna</er>.]</ety> <def>My lady; -- a French title formerly given
to ladies of quality; now, in France, given to all married women.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mad apple</ent><br/
<ent>Mad-apple</ent><br/
<mhw><hw>Mad"-ap`ple</hw>, <hw>Mad" ap`ple</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <sn>1.</sn> <fld>(Bot.)</fld> <def>The eggplant bush
(<spn>Solanum melongena</spn>). See <er>Eggplant</er>.</def><br/
<syn><b>Syn. --</b> eggplant, aubergine, brinjal, eggplant bush, garden
egg, <spn>Solanum melongena</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The fruit of the eggplant bush, a large egg-shaped
vegetable having a shiny skin typically dark purple but occasionally
white or yellow.</def><br/
<syn><b>Syn. --</b> eggplant, aubergine.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madbrain</ent><br/
<hw>Mad"brain`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hot-headed;
rash.</def> <au>Shak.</au> -- <def2><pos>n.</pos> <def>A rash or
hot-headed person.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madbrained</ent><br/
<hw>Mad"brained`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disordered in
mind; hot-headed.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madcap</ent><br/
<hw>Mad"cap`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Inclined
to wild sports; delighting in rash, absurd, or dangerous
amusements.</def> <ldquo/The merry <xex>madcap</xex> lord.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wild; reckless.</def> <ldquo/<xex>Madcap</xex>
follies<rdquo/ <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madcap</ent><br/
<hw>Mad"cap`</hw>, <pos>n.</pos> <def>A person of wild behavior; an
excitable, rash, violent person.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madden</ent><br/
<hw>Mad"den</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Maddened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Maddening</conjf>.]</vmorph> <sn>1.</sn> <def>To make
mad; to drive to madness; to drive to insanity; to craze.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make very angry; to enrage; to excite violently
with passion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madden</ent><br/
<hw>Mad"den</hw>, <pos>v. i.</pos> <def>To become mad; to act as if
mad.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They rave, recite, and <qex>madden</qex> round the land.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maddened</ent><br/
<hw>maddened</hw> <pos>adj.</pos> <def>filled with or indicating extreme
anger.</def><br/
<syn><b>Syn. --</b> angered, enraged, furious, infuriated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maddening</ent><br/
<hw>maddening</hw> <pos>adj.</pos> <def>extremely annoying or
displeasing.</def><br/
<syn><b>Syn. --</b> annoying, exasperating, infuriating,
vexing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madder</ent><br/
<hw>Mad"der</hw> <pr>(m<acr/d"d<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mader</ets>, AS. <ets>maedere</ets>; akin to Icel.
<ets>ma<edh/ra</ets>.]</ety> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Rubia</gen> (<spn>Rubia tinctorum</spn>). The root is much used in
dyeing red, and formerly was used in medicine. It is cultivated in
France and Holland. See <er>Rubiaceous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Madder is sometimes used in forming pigments, as lakes,
etc., which receive their names from their colors, such as <prod>madder
yellow</prod>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Field madder</b></col>, <cd>an annual European weed
(<spn>Sherardia arvensis</spn>) resembling madder.</cd> --
<col><b>Indian madder</b></col> , <cd>the East Indian <spn>Rubia
cordifolia</spn>, used in the East for dyeing; -- called also
<altname>munjeet</altname>.</cd> -- <col><b>Wild madder</b></col>,
<cd><spn>Rubia peregrina</spn> of Europe; also the <spn>Galium
Mollugo</spn>, a kind of bedstraw.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>madder family</ent><br/
<hw>madder family</hw> <pos>n.</pos> <def>A widely distributed natural
family of mostly tropical trees and shrubs and herbs including coffee;
chinchona; gardenia; madder; bedstraws; nd partridgeberry.</def><br/
<syn> Rubiaceae, family Rubiaceae, madder family --</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madderwort</ent><br/
<hw>Mad"der*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A name proposed for any plant of the same natural order
(<ord>Rubiaceae</ord>) as the madder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madding</ent><br/
<hw>Mad"ding</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Affected with
madness; raging; furious.</def> -- <wordforms><wf>Mad"ding*ly</wf>,
<pos>adv.</pos> <mark>[Archaic]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Far from the <qex>madding</qex> crowd's ignoble strife.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>madding</qex> wheels<br/
Of brazen chariots raged.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maddish</ent><br/
<hw>Mad"dish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat mad.</def>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mad-dog weed</ent><br/
<ent>mad-dog skullcap</ent><br/
<mhw><hw>mad-dog skullcap</hw>, <hw>mad-dog weed</hw></mhw>
<pos>n.</pos> <fld>(Bot.)</fld> <def>An American mint (<spn>Scutellaria
lateriflora</spn>) that yields a resinous exudate used esp. formerly as
an antispasmodic.</def><br/
<syn><b>Syn. --</b> blue pimpernel, blue skullcap, <spn>Scutellaria
lateriflora</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Made</ent><br/
<hw>Made</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Mad</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Made</ent><br/
<hw>Made</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Make</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Made</ent><br/
<hw>Made</hw>, <pos>a.</pos> <def>Artificially produced; pieced
together; formed by filling in; <as>as, <ex>made</ex> ground; a
<ex>made</ex> mast, in distinction from one consisting of a single
spar.</as></def> <wns>[wns=1]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>having the sheets and blankets set in order; -- of a
bed; <as>as, is the bed <ex>made</ex>?</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>successful or assured of success; <as>as, a
self-<ex>made</ex> man</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><q>Now I am a made man forever.</q> <rj><qau>Christopher
Marlowe</qau></rj><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Made up</b></col>. <sd>(a)</sd> <cd>Complete;
perfect</cd>. <ldquo/A <xex>made up</xex> villain.<rdquo/ <au>Shak.</au>
<sd>(b)</sd> <cd>Falsely devised; fabricated; <as>as, a <ex>made up</ex>
story</as>.</cd> <sd>(c)</sd> <cd>Artificial; <as>as, a <ex>made up</ex>
figure or complexion</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madecassee</ent><br/
<ent>Madecass</ent><br/
<mhw>{ <hw>Mad"e*cass</hw> <pr>(?)</pr>, <hw>Mad`e*cas"see</hw>
<pr>(?)</pr>, }</mhw> <pos>prop. n.</pos> <sn>1.</sn> <def>A native or
inhabitant of Madagascar, or Madecassee. See <er>Malagasy</er></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language of the natives of Madagascar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madecassee</ent><br/
<hw>Mad`e*cas"see</hw>, <pos>prop. a.</pos> <def>Of or pertaining to
Madagascar or its inhabitants; now replaced by
<altname>Madagascan</altname>.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Madefication</ent><br/
<ent>Madefaction</ent><br/
<mhw>{ <hw>Mad`e*fac"tion</hw> <pr>(?)</pr>, <hw>Mad`e*fi*ca"tion</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>madefacere</ets> to
make wet; <ets>madere</ets> to be wet + <ets>facere</ets> to make: cf.
F. <ets>mad<eacute/faction</ets>.]</ety> <def>The act of madefying, or
making wet; the state of that which is made wet.</def> <mark>[R.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madefy</ent><br/
<hw>Mad"e*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Madefied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Madefying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>mad<eacute/fier</ets>, L. <ets>madefacere</ets>. See
<er>Madefaction</er>.]</ety> <def>To make wet or moist.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madegassy</ent><br/
<hw>Mad`e*gas"sy</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>See
<er>Madecassee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madeira</ent><br/
<hw>Ma*dei"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg., the Island
Madeira, properly, wood, fr. L. <ets>materia</ets> stuff, wood. The
island was so called because well wooded. See <er>Matter</er>.]</ety>
<def>A rich wine made on the Island of Madeira.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A cup of <qex>Madeira</qex>, and a cold capon's leg.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Madeira nut</b></col> <fld>(Bot.)</fld>, <cd>the European
walnut; the nut of the <spn>Juglans regia</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madeira vine</ent><br/
<hw>Ma*dei"ra vine</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>A
herbaceous climbing vine (<spn>Boussingaultia baselloides</spn>) very
popular in cultivation, having shining entire leaves and racemes of
small fragrant white flowers.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>madeira winter cherry</ent><br/
<hw>madeira winter cherry</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
small South American shrub (<spn>Solanum pseudocapsicum</spn>)
cultivated as a houseplant for its abundant ornamental but poisonous red
or yellow cherrylike fruit.</def><br/
<syn><b>Syn. --</b> Jerusalem cherry, winter cherry, Madeira winter
cherry, <spn>Solanum pseudocapsicum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madeira wood</ent><br/
<hw>Madeira wood</hw>. <fld>(Bot.)</fld> <sd>(a)</sd> <def>The mahogany
tree (<spn>Swietenia Mahogoni</spn>).</def> <sd>(b)</sd> <def>A West
Indian leguminous tree (<spn>Lysiloma Latisiliqua</spn>) the wood of
which is used for boat trimming.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mademoiselle</ent><br/
\'d8<hw>Ma`de*moi`selle"</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mesdemoiselles</plw> <pr>(#)</pr>.</plu>
<ety>[F., fr. <ets>ma</ets> my, f. of <ets>mon</ets> +
<ets>demoiselle</ets> young lady. See <er>Damsel</er>.]</ety>
<sn>1.</sn> <def>A French title of courtesy given to a girl or an
unmarried lady, equivalent to the English <sig>Miss</sig>.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A marine food fish (<spn>Sciaena
chrysura</spn>), of the Southern United States; -- called also
<altname>yellowtail</altname>, and <altname>silver
perch</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>made-to-order</ent><br/
<hw>made-to-order</hw> <pos>adj.</pos> <sn>1.</sn> <def>made specially
for a specific purpose; -- of articles of manufacture. Contrasted with
<er>mass-produced</er>, <er>standard</er>.</def><br/
<syn><b>Syn. --</b> custom-made.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>made or tailored to fit a specific person; -- of
clothing. Contrasted with <er>off-the-rack</er>,
<er>ready-to-wear</er>.</def><br/
<syn><b>Syn. --</b> custom-made, custom-tailored.</syn><br/
[<source>PJC</source>]</p>

<p><ent>made-up</ent><br/
<hw>made-up</hw> <pos>adj.</pos> <sn>1.</sn> <def>formed or conceived by
the imagination; not true; <as>as, a <ex>made-up</ex>
story</as>.</def><br/
<syn><b>Syn. --</b> fabricated, fancied, fictional, fictitious,
invented.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having been paved.</def> <mark>[British]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>marked by the use of cosmetic makeup; <as>as,
heavily <ex>made-up</ex> eyes</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>formed by fitting or joining components
together.</def><br/
<syn><b>Syn. --</b> assembled, built(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madge</ent><br/
<hw>Madge</hw>, <pos>n.</pos> <ety>[Cf. OF. & Prov. F.
<ets>machette</ets>.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The
barn owl.</def> <sd>(b)</sd> <def>The magpie.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mad-headed</ent><br/
<hw>Mad"-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wild;
crack-brained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madhouse</ent><br/
<hw>Mad"house`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
house or institution where insane persons are confined; an insane
asylum; a bedlam; -- usually used in a deprecatory sense.</def><br/
<syn><b>Syn. --</b> Bedlam, booby hatch, crazy house, cuckoo's nest,
funny farm, funny house, insane asylum, loony bin, nuthouse,
sanatorium.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>(fig.)</mark> <def>A
chaotic, raucus or highly disordered situation.</def><br/
[<source>PJC</source>]</p>

<p><ent>Madia</ent><br/
\'d8<hw>Ma"di*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Sp.
<ets>madi</ets>, fr. Chilian <ets>madi</ets>, the native name.]</ety>
<fld>(Bot.)</fld> <def>A genus of composite plants, of which one species
(<spn>Madia sativa</spn>) is cultivated for the oil yielded from its
seeds by pressure. This oil is sometimes used instead of olive oil for
the table.</def><br/
<syn><b>Syn. --</b> melosa, Chile tarweed, madia oil plant, <spn>Madia
sativa</spn>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>madia oil</ent><br/
<hw>madia oil</hw> <pos>n.</pos> <def>The vegetable oil obtained from
the <spn>Madia sativa</spn>. See <er>Madia</er> and <er>madia oil
plant</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>madia oil plant</ent><br/
<hw>madia oil plant</hw> <pos>n.</pos> <def>The <spn>Madia sativa</spn>,
a South American herb with sticky glandular foliage, the source of madia
oil. See <er>Madia</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madid</ent><br/
<hw>Mad"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>madidus</ets>,
fr. <ets>madere</ets> to be wet.]</ety> <def>Wet; moist; <as>as, a
<ex>madid</ex> eye</as>.</def> <mark>[R.]</mark>
<au>Beaconsfield.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madisterium</ent><br/
\'d8<hw>Mad`is*te"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/.]</ety> <fld>(Surg.)</fld> <def>An instrument to extract
hairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madjoun</ent><br/
\'d8<hw>Mad"joun</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind., fr. Ar.
<ets>ma'j<umac/n</ets>.]</ety> <def>An intoxicating confection from the
hemp plant; -- used by the Turks and Hindus.</def> <altsp>[Written also
<asp>majoun</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madly</ent><br/
<hw>Mad"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From <er>Mad</er>,
<pos>a.</pos>]</ety> <def>In a mad manner; without reason or
understanding; wildly.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> insanely, crazily, dementedly.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a desperate manner; <as>as, she fought back
<ex>madly</ex></as>.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>3.</sn> <def>intensely; <as>as, she was <ex>madly</ex> in
love</as>.</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> insanely, deadly, deucedly, devilishly.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Madman</ent><br/
<hw>Mad"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Madmen</plw> <pr>(<?/)</pr>.</plu> <def>A man who is mad; lunatic;
a crazy person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a man mistakes his thoughts for person and things, he is mad.
A <qex>madman</qex> is properly so defined.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madnep</ent><br/
<hw>Mad"nep</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>The masterwort (<spn>Peucedanum
Ostruthium</spn>), a tall and coarse European umbelliferous
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A biennial weed in Europe and
America having large pinnate leaves and yellow flowers and a bitter and
somewhat poisonous root; the ancestor of cultivated parsnip; called also
<altname>wild parsnip</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madness</ent><br/
<hw>Mad"ness</hw>, <pos>n.</pos> <ety>[From <er>Mad</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>The condition of being mad;
insanity; lunacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Frenzy; ungovernable rage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Extreme folly.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Insanity; distraction; derangement; craziness;
lunacy; mania; frenzy; franticness; rage; aberration; alienation;
monomania. See <er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madonna</ent><br/
<hw>Ma*don"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>madonna</ets> my lady. See <er>Dame</er>, <er>Donna</er>, and cf.
<er>Madame</er>, <er>Monkey</er>.]</ety> <sn>1.</sn> <def>My lady; -- a
term of address in Italian formerly used as the equivalent of
<xex>Madame</xex>, but for which <xex>Signora</xex> is now substituted.
Sometimes introduced into English.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <plu>[<it>pl.</it> <er>Madonnas</er>
<pr>(n<adot/z)</pr>.]</plu> <def>A picture of the Virgin Mary (usually
with the babe).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Italian painters are noted for drawing the <qex>Madonnas</qex>
by their own wives or mistresses.</q> <rj><qau>Rymer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>madonna lily</ent><br/
<hw>madonna lily</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A lily
(<spn>Lilium candidum</spn>) of the Eastern Mediterranean and Balkans
with broad funnel-shaped white flowers.</def><br/
<syn><b>Syn. --</b> white lily, Annunciation lily, Lent lily,
<spn>Lilium candidum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madoqua</ent><br/
\'d8<hw>Ma"do*qua</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small Abyssinian antelope (<spn>Neotragus Saltiana</spn>), about
the size of a hare.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrague</ent><br/
\'d8<hw>Ma`drague"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[R.]</ety>
<def>A large fish pound used for the capture of the tunny in the
Mediterranean; also applied to the seines used for the same
purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>madras</ent><br/
<hw>ma*dras"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So named after
<etsep>Madras</etsep>, a city and presidency of India.]</ety>
<sn>1.</sn> <def>A large silk-and-cotton kerchief, usually of bright
colors, such as those often used by negroes for turbans.</def></p>

<p><q>A black woman in blue cotton gown, red-and-yellow
<qex>madras</qex> turban . . . crouched against the wall.</q>
<rj><qau>G. W. Cable.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A light patterned cotton fabric.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madreperl</ent><br/
<hw>Ma"dre*perl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>madreperla</ets>.]</ety> <def>Mother-of-pearl.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 881 --></p>

<p><ent>Madrepora</ent><br/
\'d8<hw>Mad`re*po"ra</hw> <pr>(m<acr/d`r<esl/*p<omac/"r<adot/)</pr>,
<pos>n.</pos> <ety>[NL. See <er>Madrepore</er>.]</ety>
<fld>(Zool.)</fld> <def>A genus of reef corals abundant in tropical
seas. It includes than one hundred and fifty species, most of which are
elegantly branched.</def> -- <wordforms><wf>Mad`re*po"ral</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madreporaria</ent><br/
\'d8<hw>Mad`re*po*ra"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Madrepore</er>.]</ety> <fld>(Zool.)</fld> <def>An extensive
division of Anthozoa, including most of the species that produce stony
corals. See <xex>Illust.</xex> of <er>Anthozoa</er>.</def> --
<wordforms><wf>Mad`re*po*ra"ri*an</wf> <pr>(#)</pr>, <pos>a. &
n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrepore</ent><br/
<hw>Mad"re*pore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>madrepore</ets>, perh. fr. <ets>madr<eacute/</ets> spotted, fr. OF.
<ets>madre</ets>, <ets>mazre</ets>, a kind of knotty wood with brown
spots, fr. OHG. <ets>masar</ets> a knot, grain, or vein in wood, a
speck, G. <ets>maser + pore</ets> (see <er>Pore</er>); or perh. F.
<ets>madr<eacute/pore</ets> is rather from It. <ets>madrepora</ets>, and
this perh. fr. It. <ets>madre</ets> mother (see <er>Mother</er>) + Gr.
<?/ a soft stone.]</ety> <fld>(Zool.)</fld> <def>Any coral of the genus
<gen>Madrepora</gen>, a group of corals having calcareous skeletons
aggregations of which form reefs and islands; formerly, often applied to
any stony coral.</def><br/
<syn><b>Syn. --</b> stony coral, madriporian coral.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>madriporian coral</ent><br/
<hw>madriporian coral</hw> <pos>n.</pos> <def>A madrepore .</def><br/
[<source>PJC</source>]</p>

<p><ent>Madreporic</ent><br/
<ent>Madreporian</ent><br/
<mhw>{ <hw>Mad`re*po"ri*an</hw> <pr>(?)</pr>, <hw>Mad`re*po"ric</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Resembling,
or pertaining to, the genus <gen>Madrepora</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Madreporic plate</b></col> <fld>(Zool.)</fld>, <cd>a
perforated plate in echinoderms, through which water is admitted to the
ambulacral tubes; -- called also <altname>madreporic
tubercule</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madreporiform</ent><br/
<hw>Mad`re*po"ri*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Madrepore</ets> + <ets>-form</ets>.]</ety> <fld>(Zool.)</fld>
<def>Resembling a madreporian coral in form or structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madreporite</ent><br/
<hw>Mad"re*po*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>madr<eacute/porite</ets>]</ety> <sn>1.</sn> <fld>(Paleon.)</fld>
<def>A fossil coral.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The madreporic plate of
echinoderms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrier</ent><br/
<hw>Ma*drier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from Sp.
<ets>madero</ets>, or Pg. <ets>madeiro</ets>, fr. Sp. <ets>madera</ets>
wood for building, timber, Pg. <ets>madeira</ets>, L. <ets>materia</ets>
stuff, materials, lumber. See <er>Matter</er>.]</ety> <def>A thick
plank, used for several mechanical purposes</def>;
<specif>especially:</specif> <sd>(a)</sd> <def>A plank to receive the
mouth of a petard, with which it is applied to anything intended to be
broken down.</def> <sd>(b)</sd> <def>A plank or beam used for supporting
the earth in mines or fortifications.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrigal</ent><br/
<hw>Mad"ri*gal</hw> <pr>(m<acr/d"r<icr/*g<ait/l)</pr>, <pos>n.</pos>
<ety>[It. <ets>madrigale</ets>, OIt. <ets>madriale</ets>,
<ets>mandriale</ets> (cf. LL. <ets>matriale</ets>); of uncertain origin,
possibly fr. It <ets>mandra</ets> flock, L. <ets>mandra</ets> stall,
herd of cattle, Gr. <grk>ma`ndra</grk> fold, stable; hence,
<ets>madrigal</ets>, originally, a pastoral song.]</ety> <sn>1.</sn>
<def>A little amorous poem, sometimes called a <altname>pastoral
poem</altname>, containing some tender and delicate, though simple,
thought.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose artful strains have oft delayed<br/
The huddling brook to hear his <qex>madrigal</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>An unaccompanied polyphonic song,
in four, five, or more parts, set to secular words, but full of
counterpoint and imitation, and adhering to the old church modes. Unlike
the freer glee, it is best sung with several voices on a part. See
<er>Glee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrigaler</ent><br/
<hw>Mad"ri*gal*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
madrigalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrigalist</ent><br/
<hw>Mad"ri*gal*ist</hw>, <pos>n.</pos> <def>A composer of
madrigals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrilenian</ent><br/
<hw>Mad`ri*le"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Sp.
<ets>Madrile<ntil/o</ets>.]</ety> <def>Of or pertaining to Madrid in
Spain, or to its inhabitants.</def> -- <def2><pos>n.</pos> <def>A native
or inhabitant of Madrid.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Madrina</ent><br/
\'d8<hw>Ma*dri"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., prop., a
godmother.]</ety> <def>An animal (usually an old mare), wearing a bell
and acting as the leader of a troop of pack mules.</def> <mark>[S.
America]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>madrono</ent><br/
<ent>madrona</ent><br/
<mhw><hw>ma*dro"na</hw>, <hw>ma*dro"<ntil/a</hw>,
<hw>ma*dro"no</hw></mhw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>madro<ntil/o</ets>.]</ety> <fld>(Bot.)</fld> <def>A small evergreen
tree or shrub (<spn>Arbutus Menziesii</spn>), of Pacific North America,
having a smooth bark, thick glossy leathery leaves, and edible
orange-red berries, which are often called <prod>madro<ntil/a
apples</prod>; the wood is used for furniture and the bark for
tanning.</def> <altsp>[Written also
<asp>madro<ntil/o</asp>.]</altsp><br/
<syn><b>Syn. --</b> madrona, manzanita, <spn>Arbutus
menziesii</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>madrilene</ent><br/
<hw>madrilene</hw> <pos>n.</pos> <def>a tomato-flavored consomme, often
served chilled.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>madwoman</ent><br/
<hw>madwoman</hw> <pos>n.</pos> <def>a woman lunatic.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Madwort</ent><br/
<hw>Mad"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus of cruciferous plants (<gen>Alyssum</gen>) with white or yellow
flowers and rounded pods. <spn>Alyssum maritimum</spn> is the commonly
cultivated sweet alyssum, a fragrant white-flowered annual.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maeandra</ent><br/
<hw>Maeandra</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A genus of brain
corals.</def><br/
<syn><b>Syn. --</b> genus <gen>Maeandra</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mae West</ent><br/
<hw>Mae West</hw> <pos>prop. n.</pos> <ety>[after <etsep>Mae
West</etsep> (1892-1980) an actress with a well-developed bosom.]</ety>
<def>An inflatable life jacket, originally used as a personal flotation
device by aviators downed at sea.</def><br/
<syn><b>Syn. --</b> air jacket.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Magbote</ent><br/
<ent>Maegbote</ent><br/
<mhw>{ <hw>Maeg"bote`</hw>, <hw>Mag"bote`</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[AS. <ets>m<aemac/g</ets> kinsman +
<ets>b<omac/t</ets> compensation.]</ety> <fld>(Anglo-Saxon Law)</fld>
<def>Compensation for the injury done by slaying a kinsman.</def>
<rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maelstrom</ent><br/
<hw>Mael"strom</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Norw., a
whirlpool.]</ety> <sn>1.</sn> <def>A celebrated whirlpool on the coast
of Norway.</def> <specif>Hence:</specif> <def>any large or powerful
whirlpool.</def><br/
<syn><b>Syn. --</b> whirlpool, vortex.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Also</specif> <mark>(Fig.)</mark> <def>An
uncontrollable agitated or confusedly disordered state or situation;
<as>as, a <ex>maelstrom</ex> of vice</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Maenad</ent><br/
\'d8<hw>Mae"nad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Maenas</ets>, <ets>-adis</ets>, Gr. <?/, <?/, fr. <?/ to
rave.]</ety> <sn>1.</sn> <def>A Bacchante; a priestess or votary of
Bacchus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A frantic or frenzied woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maestoso</ent><br/
\'d8<hw>Ma`es*to"so</hw> <pr>(?)</pr>, <pos>a. & adv.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>Majestic or majestically; -- a
direction to perform a passage or piece of music in a dignified
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maestricht monitor</ent><br/
<hw>Maes"tricht mon"i*tor</hw> <pr>(?)</pr>. <ety>[So called from
<ets>Maestricht</ets>, a town in Holland.]</ety> <fld>(Paleon.)</fld>
<def>The <spn>Mosasaurus Hofmanni</spn>. See
<er>Mosasaurus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maestro</ent><br/
\'d8<hw>Ma*es"tro</hw> <pr>(m<imac/s"tr<osl/; <it>It</it>.
m<aum/*<asl/s"tr<osl/)</pr>, <pos>n.</pos> <ety>[It., fr. L.
<ets>magister</ets>. See <er>Master</er>.]</ety> <def>A master in any
art, especially in music; a composer or orchestra conductor.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mafa</ent><br/
<hw>Mafa</hw> <pr>(?)</pr> <pos>prop. n.</pos>. <fld>(Linguistics)</fld>
<def>A Chadic language spoken south of Lake Chad; called also
<altname>Matakam</altname>.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Mafia</ent><br/
<ent>Maffia</ent><br/
<mhw>{ \'d8<hw>Maf"fi*a</hw> <pr>(?)</pr>, \'d8<hw>Ma"fi*a</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[It. <ets>maffia</ets>.]</ety>
<sn>1.</sn> <def>A secret society which organized in Sicily as a
political organization, but is now widespread among Italians, and is
used to further or protect private interests, reputedly by illegal
methods; called also the <altname>Sicilian Mafia</altname>.</def>
<wns>[wns=2]</wns><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A group of loosely associated of criminal
organizations in the United States, some having ties to the Sicilian
Mafia, and organized in <ldquo/families<rdquo/; the term is applied to
the entire group of organizations, or to any one local group. Also,
loosely, organized groups of criminals anywhere, as the Russian
<ex>mafia</ex>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> syndicate, mob, Cosa Nostra, La Cosa Nostra,
organized crime.</syn><br/
[<source>WordNet 1.6</source> + <source>PJC</source>]</p>

<p><sn>3.</sn> <def>Any tightly knit group of trusted associates having
strong control or influence in some area; <as>as, Kennedy and his Irish
<ex>Mafia</ex></as>.</def> <mark>[informal]</mark>
<wns>[wns=3]</wns><br/
[<source>PJC</source>]</p>

<p><ent>maffick</ent><br/
<hw>maffick</hw> <pos>v. i.</pos> <def>to celebrate publicly with
boisterous rejoicing and hilarious and extravagant behavior.</def>
<mark>[Chiefly Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mafioso</ent><br/
<ent>Maffioso</ent><br/
<mhw>{ \'d8<hw>Maf`fi*o"so</hw> <pr>(?)</pr>, \'d8<hw>Ma`fi*o"so</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos>; <plu>pl. <plw>-si</plw>
<pr>(#)</pr></plu>. <ety>[It. <ets>maffioso</ets>.]</ety> <def>A member
of the mafia.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maffle</ent><br/
<hw>Maf"fle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Akin to OD.
<ets>maffelen</ets> to stammer. Cf. <er>Muffle</er> to mumble.]</ety>
<def>To stammer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maffler</ent><br/
<hw>Maf"fler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stammerer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mafioso</ent><br/
<ent>Mafia</ent><br/
<mhw>{ \'d8<hw>Maf"i*a</hw> <pr>(?)</pr>, \'d8<hw>Ma`fi*o"so</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>see <er>maffia</er>,
<er>maffioso</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mag</ent><br/
<hw>mag</hw> <pos>n.</pos> <def>Shortened form of
<altname>magazine</altname>, the periodic paperback publication.</def>
<mark>[slang]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magadhan</ent><br/
<hw>Magadhan</hw> <pos>prop. n.</pos> <fld>(Linguistics)</fld> <def>A
subfamily of Indic languages.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Magazine</ent><br/
<hw>Mag`a*zine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>magasin</ets>, It. <ets>magazzino</ets>, or Sp. <ets>magacen</ets>,
<ets>almagacen</ets>; all fr. Ar. <ets>makhzan</ets>,
<ets>almakhzan</ets>, a storehouse, granary, or cellar.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A receptacle in which anything is stored, especially
military stores, as ammunition, arms, provisions, etc.</def>
<ldquo/Armories and <xex>magazines</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The building or room in which the supply of powder
is kept in a fortification or a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A chamber in a gun for holding a number of
cartridges to be fed automatically to the piece.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A pamphlet published periodically containing
miscellaneous papers or compositions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A country or district especially rich in natural
products.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>6.</sn> <def>A city viewed as a marketing center.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>A reservoir or supply chamber for a stove, battery,
camera, typesetting machine, or other apparatus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>8.</sn> <def>A store, or shop, where goods are kept for
sale.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Magazine dress</b></col>, <cd>clothing made chiefly of
woolen, without anything metallic about it, to be worn in a powder
magazine.</cd> -- <col><b>Magazine gun</b></col>, <cd>a portable
firearm, as a rifle, with a chamber carrying cartridges which are
brought automatically into position for firing.</cd> -- <col><b>Magazine
stove</b></col>, <cd>a stove having a chamber for holding fuel which is
supplied to the fire by some self-feeding process, as in the common
base-burner.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magazine</ent><br/
<hw>Mag`a*zine"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Magazined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Magazining</conjf>.]</vmorph> <def>To store in, or as
in, a magazine; to store up for use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magazine camera</ent><br/
<hw>Magazine camera</hw>. <fld>(Photog.)</fld> <def>A camera in which a
number of plates can be exposed without reloading.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Magaziner</ent><br/
<hw>Mag`a*zin"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who edits or
writes for a magazine.</def> <mark>[R.]</mark>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magazine rack</ent><br/
<hw>Mag`a*zine" rack`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rack or
stand for displaying magazines{4}.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Magazining</ent><br/
<hw>Mag`a*zin"ing</hw>, <pos>n.</pos> <def>The act of editing, or
writing for, a magazine.</def> <mark>[Colloq.]</mark>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magazinist</ent><br/
<hw>Mag`a*zin"ist</hw>, <pos>n.</pos> <def>One who edits or writes for a
magazine.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magbote</ent><br/
<hw>Mag"bote`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Maegbote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magdala</ent><br/
<hw>Mag"da*la</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Designating an
orange-red dyestuff obtained from naphthylamine, and called <xex>magdala
red</xex>, <xex>naphthalene red</xex>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magdalen</ent><br/
<hw>Mag"da*len</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Mary
<ets>Magdalene</ets>, traditionally reported to have been the repentant
sinner forgiven by Christ. See <ets>Luke</ets> vii. 36.]</ety> <def>A
reformed prostitute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magdaleon</ent><br/
<hw>Mag*da"le*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
crumb of bread, fr. <?/ to knead.]</ety> <fld>(Med.)</fld> <def>A
medicine in the form of a roll, a esp. a roll of plaster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magdeburg</ent><br/
<hw>Mag"de*burg</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A city of
Saxony.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Magdeburg centuries</b></col>, <col><b>Magdeburg
hemispheres</b></col></mcol>. <cd>See under <er>Century</er>, and
<er>Hemisphere</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mage</ent><br/
<hw>Mage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>mage</ets>. See
<er>Magi</er>.]</ety> <def>A magician.</def> <mark>[Archaic]</mark>
<rj><au>Spenser. Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magellanic</ent><br/
<hw>Mag`el*lan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to, or named from, <person>Ferdinand <etsep>Magellan</etsep></person>
(1480-1521), the navigator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magellanic cloud</ent><br/
<hw>Mag`el*lan"ic cloud</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Astron.)</fld> <def>Either of two conspicuous celestial nebulae
near the south celestial pole, resembling thin white clouds, each of
which is a <isa>galaxy</isa>{2} smaller than but separate from the Milky
Way galaxy, and together they are the galactic formations nearest to our
galaxy. They are not visible from the northern hemisphere, and are named
after <person>Ferdinand <etsep>Magellan</etsep></person>, who saw them
in his expedition, which passed through the Strait of Magellan in South
America, and one ship of which completed the first circumnavigation of
the globe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magen David</ent><br/
<hw>Magen David</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hebrew, shield of
David.]</ety> <def>A hexagram{1a}, when used as the symbol of Judaism;
called also <altname>Mogen David</altname> and <altname>Star of
David</altname>. It is included on the flag of Israel</def><br/
<syn><b>Syn. --</b> Star of David, Mogen David.</syn><br/
[<source>PJC</source>]</p>

<p><ent>magenta</ent><br/
<hw>ma*gen"ta</hw> <pr>(m<adot/*j<ecr/n"t<adot/)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>An aniline dye obtained as an amorphous
substance having a green bronze surface color, which dissolves to a
shade of red; also, the color; -- so called from <etsep>Magenta</etsep>,
in Italy, in allusion to the battle fought there about the time the dye
was discovered. Called also <altname>fuchsin</altname>,
<altname>fuchsine</altname>, <altname>roseine</altname>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The purplish-red color of magenta.</def><br/
[<source>PJC</source>]</p>

<p><ent>Magged</ent><br/
<hw>Magged</hw> <pr>(m<acr/gd)</pr>, <pos>a.</pos> <fld>(Naut.)</fld>
<def>Worn; fretted; <as>as, a <ex>magged</ex> brace</as>.</def>
<rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maggiore</ent><br/
\'d8<hw>Mag`gio"re</hw> <pr>(m<aum/d`j<omac/"r<asl/)</pr>, <pos>a.</pos>
<ety>[It., from L. <ets>major</ets>, compar. of <ets>magnus</ets> great.
See <er>Major</er>.]</ety> <fld>(Mus.)</fld> <def>Greater, in respect to
scales, intervals, etc., when used in opposition to
<contr>minor</contr>; major.</def> <rj><au>Moore (Encyc. of
Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maggot</ent><br/
<hw>Mag"got</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W. <ets>macai</ets>,
pl. <ets>maceiod</ets>, <ets>magiod</ets>, a worn or grub; cf.
<ets>magu</ets> to bread.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>The
footless larva of any fly. See <er>Larval</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A whim; an odd fancy.</def> <rj><au>Hudibras.
Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maggotiness</ent><br/
<hw>Mag"got*i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
maggoty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maggotish</ent><br/
<hw>Mag"got*ish</hw>, <pos>a.</pos> <def>Full of whims or fancies;
maggoty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maggot-pie</ent><br/
<hw>Mag"got-pie`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A magpie.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maggoty</ent><br/
<hw>Mag"got*y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Infested
with maggots.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Full of whims; capricious.</def>
<rj><au>Norris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magh</ent><br/
<hw>Magh</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The eleventh month of the
Hindu calendar.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maghet</ent><br/
<hw>Ma"ghet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Fl.
<ets>maghet</ets> maid.]</ety> <fld>(Bot.)</fld> <def>A name for daisies
and camomiles of several kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magi</ent><br/
\'d8<hw>Ma"gi</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., pl. of
<ets>Magus</ets>, Gr. <?/; of Per. origin. Cf. <er>Mage</er>,
<er>Magic</er>.]</ety> <def>A caste of priests, philosophers, and
magicians, among the ancient Persians; hence, any holy men or sages of
the East.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The inspired <qex>Magi</qex> from the Orient came.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magian</ent><br/
<hw>Ma"gi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the Magi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magian</ent><br/
<hw>Ma"gi*an</hw>, <pos>n.</pos> <def>One of the Magi, or priests of the
Zoroastrian religion in Persia; an adherent of the Zoroastrian
religion.</def> -- <wordforms><wf>Ma"gi*an*ism</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magic</ent><br/
<hw>Mag"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>magique</ets>, L. <ets>magice</ets>, Gr. <?/ (sc. <?/), fr. <?/.
See <er>Magic</er>, <pos>a.</pos>, and <er>Magi</er>.]</ety> <sn>1.</sn>
<def>A comprehensive name for all of the pretended arts which claim to
produce effects by the assistance of supernatural beings, or departed
spirits, or by a mastery of secret forces in nature attained by a study
of occult science, including enchantment, conjuration, witchcraft,
sorcery, necromancy, incantation, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An appearance made by some <qex>magic</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The art of creating illusions which appear to the
observer to be inexplicable except by some supernatural influence; it
includes simple sleight of hand (legerdemain) as well as more elaborate
stage magic, using special devices constructed to produce mystifying
effects; <as>as, the <ex>magic</ex> of <person>David
Copperfield</person></as>. It is practised as an entertainment, by
magicians who do not pretend to have supernatural powers.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Celestial magic</b></col>, <cd>a supposed supernatural
power which gave to spirits a kind of dominion over the planets, and to
the planets an influence over men.</cd> -- <col><b>Natural
magic</b></col>, <cd>the art of employing the powers of nature to
produce effects apparently supernatural.</cd> --
<mcol><col><b>Superstitious magic</b></col>, <it>or</it> <col><b>Geotic
magic</b></col></mcol>, <cd>the invocation of devils or demons,
involving the supposition of some tacit or express agreement between
them and human beings.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Sorcery; witchcraft; necromancy; conjuration;
enchantment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magical</ent><br/
<ent>Magic</ent><br/
<mhw>{ <hw>Mag"ic</hw> <pr>(?)</pr>, <hw>Mag"ic*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>magicus</ets>, Gr. <?/, fr. <?/: cf.
F. <ets>magique</ets>. See <er>Magi</er>.]</ety> <sn>1.</sn>
<def>Pertaining to the hidden wisdom supposed to be possessed by the
Magi; relating to the occult powers of nature, and the producing of
effects by their agency.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Performed by, or proceeding from, occult and
superhuman agencies; done by, or seemingly done by, enchantment or
sorcery; <as>as, a <ex>magical</ex> spell</as>.</def>
<specif>Hence:</specif> <def>Seemingly requiring more than human power;
imposing or startling in performance; producing effects which seem
supernatural or very extraordinary; having extraordinary properties;
<as>as, a <ex>magic</ex> lantern; a <ex>magic</ex> square or
circle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The painter's <qex>magic</qex> skill.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Although with certain words <xex>magic</xex> is used
more than <xex>magical</xex>, -- as, <xex>magic</xex> circle,
<xex>magic</xex> square, <xex>magic</xex> wand, -- we may in general say
<xex>magic</xex> or <xex>magical</xex>; as, a <xex>magic</xex> or
<xex>magical</xex> effect; a <xex>magic</xex> or <xex>magical</xex>
influence, etc. But when the adjective is predicative,
<xex>magical</xex>, and not <xex>magic</xex>, is used; as, the effect
was <xex>magical</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magic circle</b></col>, <cd>a series of concentric
circles containing the numbers 12 to 75 in eight radii, and having
somewhat similar properties to the magic square.</cd> -- <col><b>Magic
humming bird</b></col> <fld>(Zool.)</fld>, <cd>a Mexican humming bird
(<spn>Iache magica</spn>) , having white downy thing tufts.</cd> --
<col><b>Magic lantern</b></col>. <cd>See <er>Lantern</er>.</cd> --
<col><b>Magic square</b></col>, <cd>numbers so disposed in parallel and
equal rows in the form of a square, that each row, taken vertically,
horizontally, or diagonally, shall give the same sum, the same product,
or an harmonical series, according as the numbers taken are in
arithmetical, geometrical, or harmonical progression.</cd> --
<col><b>Magic wand</b></col>, <cd>a wand used by a magician in
performing feats of magic.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magically</ent><br/
<hw>Mag"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a magical
manner; by magic, or as if by magic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magic bullet</ent><br/
<hw>magic bullet</hw> <pos>n.</pos> <ety>[From the notion of a
<ets>bullet</ets> that will kill only the bacterium or disease it is
intended for.]</ety> <def>A drug or therapy or preventive that cures or
prevents a disease, with only minimal side effects; <as>as, there is no
<ex>magic bullet</ex> against cancer</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magician</ent><br/
<hw>Ma*gi"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>magicien</ets>. See <er>Magic</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>One skilled in magic; one who practices the black art;
an enchanter; a necromancer; a sorcerer or sorceress; a
conjurer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An entertainer who produces seemingly magical
effects by clever illusions; most magicians admit that the craft is mere
illusion, rather than a true supernatural art.</def><br/
[<source>PJC</source>]</p>

<p><ent>magic lantern</ent><br/
<hw>magic lantern</hw> <pos>n.</pos> <def>An early form of <isa>slide
projector</isa>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magic spell</ent><br/
<hw>magic spell</hw> <pos>n.</pos> <def>A verbal formula considered to
have magical force.</def><br/
<syn><b>Syn. --</b> spell, incantation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magic trick</ent><br/
<hw>magic trick</hw> <pos>n.</pos> <def>An feat of illusion performed by
an illusionist, which appears magical to naive observers.</def><br/
<syn><b>Syn. --</b> conjuring trick, trick, magic, legerdemain,
illusion, deception.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magilph</ent><br/
<ent>Magilp</ent><br/
<mhw>{ <hw>Ma*gilp"</hw> <pr>(?)</pr>, <hw>Ma*gilph"</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <fld>(Paint.)</fld> <def>See
<er>Megilp</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maginot line</ent><br/
<hw>Maginot line</hw> <pos>prop. n.</pos> <def>A line of fortifications
built before World War II to protect France's eastern border.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magister</ent><br/
\'d8<hw>Ma*gis"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Master</er>.]</ety> <def>Master; sir; -- a title of the Middle Ages,
given to a person in authority, or to one having a license from a
university to teach philosophy and the liberal arts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magisterial</ent><br/
<hw>Mag`is*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>magisterius</ets> magisterial. See <er>Master</er>.]</ety>
<sn>1.</sn> <def>Of or pertaining to a master or magistrate, or one in
authority; having the manner of a magister; official; commanding;
authoritative. Hence: Overbearing; dictatorial; dogmatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When <qex>magisterial</qex> duties from his home<br/
Her father called.</q> <rj><qau>Glover.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We are not <qex>magisterial</qex> in opinions, nor, dictator-like,
obtrude our notions on any man.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pretenses go a great way with men that take fair words and
<qex>magisterial</qex> looks for current payment.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Alchem. & Old Chem.)</fld> <def>Pertaining to,
produced by, or of the nature of, magistery. See <er>Magistery</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Authoritative; stately; august; pompous;
dignified; lofty; commanding; imperious; lordly; proud; haughty;
domineering; despotic; dogmatical; arrogant.</syn> <usage> --
<er>Magisterial</er>, <er>Dogmatical</er>, <er>Arrogant</er>. One who is
<xex>magisterial</xex> assumes the air of a master toward his pupils;
one who is <xex>dogmatical</xex> lays down his positions in a tone of
authority or dictation; one who is <xex>arrogant</xex> insults others by
an undue assumption of superiority. Those who have long been teachers
sometimes acquire, unconsciously, a manner which borders too much on the
<xex>magisterial</xex>, and may be unjustly construed as
<xex>dogmatical</xex>, or even <xex>arrogant</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magisteriality</ent><br/
<hw>Mag`is*te`ri*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Magisterialness; authoritativeness.</def> <mark>[R.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magisterially</ent><br/
<hw>Mag`is*te"ri*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
magisterial manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magisterialness</ent><br/
<hw>Mag`is*te"ri*al*ness</hw>, <pos>n.</pos> <def>The quality or state
of being magisterial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistery</ent><br/
<hw>Mag"is*ter*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>magisterium</ets> the office of a chief, president, director,
tutor. See <er>Magistrate</er>.]</ety> <sn>1.</sn> <def>Mastery;
powerful medical influence; renowned efficacy; a sovereign remedy.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A magisterial injunction.</def> <mark>[R.]</mark>
<rj><au>Brougham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>A precipitate; a fine substance
deposited by precipitation; -- applied in old chemistry to certain white
precipitates from metallic solutions; <as>as, <ex>magistery</ex> of
bismuth</as>.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistracy</ent><br/
<hw>Mag"is*tra*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Magistracies</plw> <pr>(#)</pr>.</plu> <ety>[From
<er>Magistrate</er>.]</ety> <sn>1.</sn> <def>The office or dignity of a
magistrate.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The collective body of magistrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistral</ent><br/
<hw>Mag"is*tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>magistralis</ets>: cf. F. <ets>magistral</ets>. See
<er>Magistrate</er>.]</ety> <sn>1.</sn> <def>Pertaining to a master;
magisterial; authoritative; dogmatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Commanded or prescribed by a magister, esp. by a
doctor; hence, effectual; sovereign; <as>as, a <ex>magistral</ex>
sirup</as>.</def> <ldquo/Some <xex>magistral</xex> opiate.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Pharmacy)</fld> <def>Formulated extemporaneously,
or for a special case; -- opposed to <ant>officinal</ant>, and said of
prescriptions and medicines.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magistral line</b></col> <fld>(Fort.)</fld>, <cd>the
guiding line, or outline, by which the form of the work is determined.
It is usually the crest line of the parapet in fieldworks, or the top
line of the escarp in permanent fortifications.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistral</ent><br/
<hw>Mag"is*tral</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Med.)</fld> <def>A
sovereign medicine or remedy.</def> <mark>[Obs.]</mark>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fort.)</fld> <def>A magistral line.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Metal.)</fld> <def>Powdered copper pyrites used in
the amalgamation of ores of silver, as at the Spanish mines of Mexico
and South America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistrality</ent><br/
<hw>Mag`is*tral"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ties</plw> <pr>(<?/)</pr>.</plu> <def>Magisterialness; arbitrary
dogmatism.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistrally</ent><br/
<hw>Mag"is*tral*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
magistral manner.</def> <rj><au>Abp. Bramhall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistrate</ent><br/
<hw>Mag"is*trate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>magistratus</ets>, fr. <ets>magister</ets> master: cf. F.
<ets>magistrat</ets>. See <er>Master</er>.]</ety> <def>A person clothed
with power as a public civil officer; a public civil officer invested
with the executive government, or some branch of it.</def> <ldquo/All
Christian rulers and <xex>magistrates</xex>.<rdquo/ <rj><au>Book of Com.
Prayer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of <qex>magistrates</qex> some also are supreme, in whom the
sovereign power of the state resides; others are subordinate.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistratical</ent><br/
<ent>Magistratic</ent><br/
<mhw>{ <hw>Mag`is*trat"ic</hw> <pr>(?)</pr>, <hw>Mag`is*trat"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of, pertaining to, or
proceeding from, a magistrate; having the authority of a
magistrate.</def> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magistrature</ent><br/
<hw>Mag"is*tra`ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>magistrature</ets>.]</ety> <def>Magistracy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magma</ent><br/
\'d8<hw>Mag"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/,
fr. <?/ to squeeze, knead.]</ety> <sn>1.</sn> <def>Any crude mixture of
mineral or organic matters in the state of a thin paste.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <sd>(a)</sd> <def>A thick residuum
obtained from certain substances after the fluid parts are expressed
from them; the grounds which remain after treating a substance with any
menstruum, as water or alcohol.</def> <sd>(b)</sd> <def>A salve or
confection of thick consistency.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 882 --></p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <sd>(a)</sd> <def>The molten matter
within the earth, the source of the material of lava flows, dikes of
eruptive rocks, etc.</def> <sd>(b)</sd> <def>The glassy base of an
eruptive rock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <def>The amorphous or homogenous
matrix or ground mass, as distinguished from well-defined crystals;
<as>as, the <ex>magma</ex> of porphyry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magna Charta</ent><br/
<ent>Magna Carta</ent><br/
<mhw><hw>Mag"na Car"ta</hw>, <hw>Mag"na Char"ta</hw></mhw> <pr>(?)</pr>.
<ety>[L., great charter.]</ety> <sn>1.</sn> <def>The great Charter, so
called, obtained by the English barons from King John, <sc>A. D.</sc>
1215. This name is also given to the charter granted to the people of
England in the ninth year of <person>Henry III.</person>, and confirmed
by <person>Edward I.</person></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, a fundamental constitution which guaranties
rights and privileges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnality</ent><br/
<hw>Mag*nal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>magnalis</ets> mighty, fr. <ets>magnus</ets> great.]</ety> <def>A
great act or event; a great attainment.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magna Mater</ent><br/
<hw>Magna Mater</hw> <pos>prop. n.</pos> <def>A great nature goddess of
ancient Phrygia in Asia Minor; the counterpart of the Greek
<altname>Rhea</altname> and the Roman <altname>Ops</altname>.</def><br/
<syn><b>Syn. --</b> Cybele, Dindymene, Great Mother, Mater
Turrita.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnanimity</ent><br/
<hw>Mag`na*nim"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>magnanimit<eacute/</ets>, L. <ets>magnanimitas</ets>.]</ety>
<def>The quality of being magnanimous; greatness of mind; elevation or
dignity of soul; that quality or combination of qualities, in character,
which enables one to encounter danger and trouble with tranquility and
firmness, to disdain injustice, meanness and revenge, and to act and
sacrifice for noble objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnanimous</ent><br/
<hw>Mag*nan"i*mous</hw> <pr>(?)</pr>, <pos>a.</pos><ety>[L.
<ets>magnanimus</ets>; <ets>magnus</ets> great + <ets>animus</ets> mind.
See <er>Magnate</er>, and <er>Animus</er>.]</ety> <sn>1.</sn> <def>Great
of mind; elevated in soul or in sentiment; raised above what is low,
mean, or ungenerous; of lofty and courageous spirit; <as>as, a
<ex>magnanimous</ex> character; a <ex>magnanimous</ex>
conqueror.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be <qex>magnanimous</qex> in the enterprise.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To give a kingdom hath been thought<br/
Greater and nobler done, and to lay down<br/
Far more <qex>magnanimous</qex> than to assume.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dictated by or exhibiting nobleness of soul;
honorable; noble; not selfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both strived for death; <qex>magnanimous</qex> debate.</q>
<rj><qau>Stirling.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is an indissoluble union between a <qex>magnanimous</qex>
policy and the solid rewards of public prosperity and felicity.</q>
<rj><qau>Washington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnanimously</ent><br/
<hw>Mag*nan"i*mous*ly</hw>, <pos>adv.</pos> <def>In a magnanimous
manner; with greatness of mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnase black</ent><br/
<hw>Mag"nase black`</hw> <pr>(?)</pr>. <fld>(Paint.)</fld> <def>A black
pigment which dries rapidly when mixed with oil, and is of intense
body.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnate</ent><br/
<hw>Mag"nate</hw> <pr>(?)</pr>, <ety>[F. <ets>magnat</ets>, L. (pl.)
<ets>magnates</ets>, <ets>magnati</ets>, fr. <ets>magnus</ets> great.
See <er>Master</er>.]</ety> <sn>1.</sn> <def>A person of rank; a noble
or grandee; a person of influence or distinction in any sphere; -- used
mostly of prominent business executives; <as>as, an industrial
<ex>magnate</ex></as>.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>One of the nobility, or certain high officers of
state belonging to the noble estate in the national representation of
Hungary, and formerly of Poland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnes</ent><br/
<hw>Mag"nes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Magnet.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnesia</ent><br/
<hw>Mag*ne"si*a</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>Magnesia</ets>, fem. of <ets>Magnesius</ets> of the country
Magnesia, Gr. <grk>h` Magnhsi`a li`qos</grk> a magnet. Cf.
<er>Magnet</er>.]</ety> <fld>(Chem.)</fld> <def>A light earthy white
substance, consisting of magnesium oxide (<chform>MgO</chform>), and
obtained by heating magnesium hydrate or carbonate, or by burning
magnesium. It has a slightly alkaline reaction, and is used in medicine
as a mild antacid laxative. See <er>Magnesium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magnesia alba</b></col> <ety>[L.]</ety> <fld>(Med.
Chem.)</fld>, <cd>a bulky white amorphous substance, consisting of a
hydrous basic carbonate of magnesium, and used as a mild
cathartic.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnesian</ent><br/
<hw>Mag*ne"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
characterized by, or containing, magnesia or magnesium.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magnesian limestone</b></col>. <fld>(Min.)</fld> <cd>See
<er>Dolomite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnesic</ent><br/
<hw>Mag*ne"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or containing, magnesium; <as>as, <ex>magnesic</ex>
oxide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnesite</ent><br/
<hw>Mag"ne*site</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>magn<eacute/site</ets>.]</ety> <fld>(Min.)</fld> <def>Native
magnesium carbonate occurring in white compact or granular masses, and
also in rhombohedral crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnesium</ent><br/
<hw>Mag*ne"si*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. & F. See
<er>Magnesia</er>.]</ety> <fld>(Chem.)</fld> <def>A light silver-white
metallic element of atomic number 12, malleable and ductile, quite
permanent in dry air but tarnishing in moist air. It burns, forming (the
oxide) magnesia, with the production of a blinding light (the so-called
<xex>magnesium light</xex>) which is used in signaling, in pyrotechny,
or in photography where a strong actinic illuminant is required. Its
compounds occur abundantly, as in dolomite, talc, meerschaum, etc.
Symbol Mg. Atomic weight, 24.305. Specific gravity, 1.75.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magnesium sulphate</b></col>. <fld>(Chem.)</fld> <cd>Same
as <er>Epsom salts</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnesium hydroxide</ent><br/
<hw>magnesium hydroxide</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>A
slightly alkaline chemical substance, <chform>Mg(OH)2</chform>, the
active principle in the antacid <partof>milk of magnesia</partof>, also
used as a laxative.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnesium oxide</ent><br/
<hw>magnesium oxide</hw> <pos>n.</pos> <fld>(Chem.)</fld>
<def>Magnesia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnet</ent><br/
<hw>Mag"net</hw> <pr>(m<acr/g"n<ecr/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>magnete</ets>, OF. <ets>magnete</ets>, L. <ets>magnes</ets>,
<ets>-etis</ets>, Gr. <grk>Magnh^tis li`qos</grk> a magnet, metal that
looked like silver, prop., Magnesian stone, fr. Gr.
<grk>Magnhsi`a</grk>, a country in Thessaly. Cf. <er>Magnesia</er>,
<er>Manganese</er>.]</ety> <sn>1.</sn> <def>The loadstone; a species of
iron ore (the ferrosoferric or magnetic ore, <chform>Fe3O4</chform>)
which has the property of attracting iron and some of its ores, and,
when freely suspended, of pointing to the poles; -- called also
<altname>natural magnet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dinocrates began to make the arched roof of the temple of
Arsino<eum/ all of <qex>magnet</qex>, or this loadstone.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two <qex>magnets</qex>, heaven and earth, allure to bliss,<br/
The larger loadstone that, the nearer this.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>A bar or mass of steel or iron
to which the peculiar properties of the loadstone have been imparted; --
called, in distinction from the loadstone, an <altname>artificial
magnet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ An artificial magnet, produced by the action of an
electrical current, is called an
<stype>electro-magnet</stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Field magnet</b></col> <fld>(Physics & Elec.)</fld>,
<cd>a magnet used for producing and maintaining a magnetic field; --
used especially of the stationary or exciting magnet of a dynamo or
electromotor in distinction from that of the moving portion or
armature.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetical</ent><br/
<ent>Magnetic</ent><br/
<mhw>{ <hw>Mag*net"ic</hw> <pr>(?)</pr>, <hw>Mag*net"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>magneticus</ets>: cf.
F. <ets>magn<eacute/tique</ets>.]</ety> <sn>1.</sn> <def>Pertaining to
the magnet; possessing the properties of the magnet, or corresponding
properties; <as>as, a <ex>magnetic</ex> bar of iron; a <ex>magnetic</ex>
needle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to, or characterized by, the
earth's magnetism; <as>as, the <ex>magnetic</ex> north; the
<ex>magnetic</ex> meridian.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Capable of becoming a magnet; susceptible to
magnetism; <as>as, the <ex>magnetic</ex> metals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Endowed with extraordinary personal power to excite
the feelings and to win the affections; attractive; inducing
attachment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She that had all <qex>magnetic</qex> force alone.</q>
<rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having, susceptible to, or induced by, animal
magnetism, so called; hypnotic; <as>as, a <ex>magnetic</ex> sleep</as>.
See <er>Magnetism</er>.</def> <mark>[Archaic]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><mcol><col><b>Magnetic amplitude</b></col>,
<col><b>attraction</b></col>, <col><b>dip</b></col>,
<col><b>induction</b></col></mcol>, <cd>etc. See under
<er>Amplitude</er>, <er>Attraction</er>, etc.</cd> -- <col><b>Magnetic
battery</b></col>, <cd>a combination of bar or horseshoe magnets with
the like poles adjacent, so as to act together with great power.</cd> --
<col><b>Magnetic compensator</b></col>, <cd>a contrivance connected with
a ship's compass for compensating or neutralizing the effect of the iron
of the ship upon the needle.</cd> -- <col><b>Magnetic curves</b></col>,
<cd>curves indicating lines of magnetic force, as in the arrangement of
iron filings between the poles of a powerful magnet.</cd> --
<col><b>Magnetic elements</b></col>. <sd>(a)</sd> <fld>(Chem.
Physics)</fld> <cd>Those elements, as iron, nickel, cobalt, chromium,
manganese, etc., which are capable or becoming magnetic.</cd>
<sd>(b)</sd> <fld>(Physics)</fld> <cd>In respect to terrestrial
magnetism, the declination, inclination, and intensity</cd>.
<sd>(c)</sd> <cd>See under <er>Element</er>.</cd> -- <col><b>Magnetic
fluid</b></col>, <cd>the hypothetical fluid whose existence was formerly
assumed in the explanations of the phenomena of magnetism; -- no longer
considered a meaningful concept.</cd> -- <mcol><col><b>Magnetic
iron</b></col>, <it>or</it> <col><b>Magnetic iron ore</b></col></mcol>.
<fld>(Min.)</fld> <cd>Same as <er>Magnetite</er>.</cd> --
<col><b>Magnetic needle</b></col>, <cd>a slender bar of steel,
magnetized and suspended at its center on a sharp-pointed pivot, or by a
delicate fiber, so that it may take freely the direction of the magnetic
meridian. It constitutes the essential part of a compass, such as the
mariner's and the surveyor's.</cd> -- <col><b>Magnetic poles</b></col>,
<cd>the two points in the opposite polar regions of the earth at which
the direction of the dipping needle is vertical.</cd> --
<col><b>Magnetic pyrites</b></col>. <cd>See <er>Pyrrhotite</er>.</cd> --
<col><b>Magnetic storm</b></col> <fld>(Terrestrial Physics)</fld>, <cd>a
disturbance of the earth's magnetic force characterized by great and
sudden changes.</cd> -- <col><b>magnetic tape</b></col>
<fld>(Electronics)</fld>, <cd>a ribbon of plastic material to which is
affixed a thin layer of powder of a material which can be magnetized,
such as ferrite. Such tapes are used in various electronic devices to
record fluctuating voltages, which can be used to represent sounds,
images, or binary data. Devices such as audio casette recorders,
videocasette recorders, and computer data storage devices use
<ex>magnetic tape</ex> as an inexpensive medium to store data. Different
magnetically susceptible materials are used in such tapes.</cd> --
<col><b>Magnetic telegraph</b></col>, <cd>a telegraph acting by means of
a magnet. See <er>Telegraph</er>.</cd></cs><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Magnetic</ent><br/
<hw>Mag*net"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
magnet.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As the <qex>magnetic</qex> hardest iron draws.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any metal, as iron, nickel, cobalt, etc., which may
receive, by any means, the properties of the loadstone, and which then,
when suspended, fixes itself in the direction of a magnetic
meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetically</ent><br/
<hw>Mag*net"ic*al*ly</hw>, <pos>adv.</pos> <def>By or as by,
magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magneticalness</ent><br/
<hw>Mag*net"ic*al*ness</hw>, <pos>n.</pos> <def>Quality of being
magnetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnetic bottle</ent><br/
<hw>magnetic bottle</hw> <pos>n.</pos> <fld>(Physics)</fld> <def>Any
configuration of magnetic fields used to contain a plasma during
controlled thermonuclear reactions.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic compass</ent><br/
<hw>magnetic compass</hw> <pos>n.</pos> <def>An device using a magnet
(such as a magnetic needle) to indicate the direction of magnetic
north.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic declination</ent><br/
<hw>magnetic declination</hw> <pos>n.</pos> <def>The angle (at a
particular location) between magnetic north and true north; called also
<altname>magnetic variation</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic dip</ent><br/
<hw>magnetic dip</hw> <pos>n.</pos> <def>The angle that a magnetic
needle makes with the plane of the horizon.</def><br/
<syn><b>Syn. --</b> dip, angle of dip, magnetic inclination,
inclination.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic dipole</ent><br/
<hw>magnetic dipole</hw> <pos>n.</pos> <def>A dipole with opposing
magnetic poles.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic dipole moment</ent><br/
<hw>magnetic dipole moment</hw> <pos>n.</pos> <def>A physical quantity
associated with the magnetic field of a dundamental particle; <as>as, An
orbiting electron in an atom will have a <ex>magnetic dipole
moment</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic disk</ent><br/
<ent>magnetic disc</ent><br/
<mhw><hw>magnetic disc</hw>, <hw>magnetic disk</hw></mhw> <pos>n.</pos>
<def>A ditical memory device consisting of a flat disk covered with a
magnetic coating on which information is stored; a <stype>hard
disk</stype>, <stype>floppy disk</stype>, and <stype>diskette</stype>
are typically magnetic disks.</def><br/
<syn><b>Syn. --</b> disk, disc.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic equator</ent><br/
<hw>magnetic equator</hw> <pos>n.</pos> <def>An imaginary line
paralleling the equator where a magnetic needle has no dip, the dipping
needle being horizontal; called also <altname>aclinic
line</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic field</ent><br/
<hw>magnetic field</hw> <pos>n.</pos> <fld>(Physics)</fld> <def>The
space around a magnet through which it exerts magnetic force; a field of
force surrounding a permanent magnet, electrical current, or a moving
charged particle; called also <altname>magnetic flux</altname> and
<altname>field of magnetic force</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic field strength</ent><br/
<hw>magnetic field strength</hw> <pos>n.</pos> <def>The amount of
magnetic flux in a unit area perpendicular to the direction of magnetic
flow.</def><br/
<syn><b>Syn. --</b> magnetic intensity, magnetic induction, magnetic
flux density.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic flux</ent><br/
<hw>magnetic flux</hw> <pos>n.</pos> <sn>1.</sn> <def>A measure of the
strength of a magnetic field over a given area.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Same as <er>magnetic field</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic flux density</ent><br/
<hw>magnetic flux density</hw> <pos>n.</pos> <def>The amount of magnetic
flux in a unit area perpendicular to the direction of magnetic
flow.</def><br/
<syn><b>Syn. --</b> magnetic field strength, magnetic intensity,
magnetic induction.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic force</ent><br/
<hw>magnetic force</hw> <pos>n.</pos> <def>The force caused by a
magnetic field, a force which affects objects having a magnetic field
and objects in which a magnetic field can be induced, such as
ferromagnetic substances; a magnetic force manifests itself as an
attraction for iron. It is associated with electric currents and moving
charged paticles as well as permanent magnets.</def><br/
<syn><b>Syn. --</b> magnetism, magnetic attraction.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>magnetic head</ent><br/
<hw>magnetic head</hw> <pos>n.</pos> <fld>(Electronics)</fld> <def>An
electromagnet (as on a tape recorder) that converts electrical
variations into magnetic variations that can be stored on a magnetizable
surface and later retrieved.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnetician</ent><br/
<hw>Mag`ne*ti"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
the science of magnetism; a magnetist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnetic inclination</ent><br/
<hw>magnetic inclination</hw> <pos>n.</pos> <def>Same as <er>magnetic
dip</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic induction</ent><br/
<hw>magnetic induction</hw> <pos>n.</pos> <sn>1.</sn> <def>The process
that makes a substance magnetic (temporarily or permanently).</def><br/
<syn><b>Syn. --</b> magnetization, magnetisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Same as <er>magnetic field strength</er>.</def><br/
<syn><b>Syn. --</b> magnetic intensity, magnetic flux density.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic intensity</ent><br/
<hw>magnetic intensity</hw> <fld>(Physics)</fld>, <pos>n.</pos>
<def>Same as <er>magnetic field strength</er>.</def><br/
<syn><b>Syn. --</b> magnetic flux density.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic iron-ore</ent><br/
<hw>magnetic iron-ore</hw> <pos>n.</pos> <def>Magnetite.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic levitation</ent><br/
<hw>magnetic levitation</hw> <pos>n.</pos> <def>The process of
supporting an object, such as a vehicle, with a magnetic field so that
it does not contact the object supporting it; it is a method used for
eliminating friction in moving vehicles, and is used, e.g. in high-speed
rail technology where a train is suspended on a magnetic cushion above a
magnetized track and so travels free of friction.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic line of force</ent><br/
<hw>magnetic line of force</hw> <fld>(Physics)</fld>, <pos>n.</pos>
<def>A line of force in a magnetic field.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic meridian</ent><br/
<hw>magnetic meridian</hw> <fld>(Physics)</fld>, <pos>n.</pos> <def>An
imaginary line passing through both magnetic poles of the
earth.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic mine</ent><br/
<hw>magnetic mine</hw> <pos>n.</pos> <fld>(Mil.)</fld> <def>A marine
mine that is detonated by a mechanism that detects the nearness of
magnetic material (as the steel hull of a ship). A <stype>magnetic
counter mine</stype> may allow the passagw of several ships before
detonating.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic moment</ent><br/
<hw>magnetic moment</hw> <pos>n.</pos> <def>The torque exerted on a
magnet or dipole when it is placed in a magnetic field.</def><br/
<syn><b>Syn. --</b> moment of a magnet.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic monopole</ent><br/
<hw>magnetic monopole</hw> <fld>(Physics)</fld>, <def>a hypothetical
subatomic particle having only one type of magnetic charge, the magnetic
analogue of an electrically charged particle; it has only one magnetic
pole instead of the two observed in all common magnetic object; -- it
was still not observed as of 1998.</def><br/
[<source>PJC</source>]</p>

<p><ent>magnetic needle</ent><br/
<hw>magnetic needle</hw> <pos>n.</pos> <def>A slender magnet suspended
in a magnetic compass on a low-friction mounting; used to indicate the
direction of the earth's magnetic pole.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic north</ent><br/
<hw>magnetic north</hw> <pos>n.</pos> <def>The direction in which the
north-pointing end of a compass needle points; at low latitudes it is
close to geographic (true) north, but deviates substantially from true
north as one nears the north pole.</def><br/
<syn><b>Syn. --</b> north, compass north.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magneticness</ent><br/
<hw>Mag*net"ic*ness</hw>, <pos>n.</pos> <def>Magneticalness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnetic pole</ent><br/
<hw>magnetic pole</hw> <pos>n.</pos> <sn>1.</sn> <def>Either of two
points where the lines of force of the earth's magnetic field are
vertical.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>One of the two ends of a magnet where the magnetic
field is strongest.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic recorder</ent><br/
<hw>magnetic recorder</hw> <pos>n.</pos> <def>A device for making
records (of sound, data, etc.) on magnetic media such as magnetic tape
or wire.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic resonance</ent><br/
<hw>magnetic resonance</hw> <pos>n.</pos> <fld>(Physics)</fld> <def>A
phenomenon resulting from quantization in the magnetic field of
electrons or atoms or molecules or nuclei exposed to an external
magnetic field, by which a narrow frequency band of radio waves may be
absorbed and re-emitted by the object.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>magnetic resonance imaging</ent><br/
<hw>mag*net"ic res"on*ance im"ag*ing</hw> <pos>n.</pos>
<fld>(Medicine)</fld> <def>a medical diagnostic procedure utilizing the
phenomenon of <er>nuclear magnetic resonance</er> to generate images of
internal parts of the body. It depends on the differential absorption of
electromagnetic radiation by different types of living tissue in a
magnetic field. It is complementary to X-ray imaging in that the softer
tissue show more prominently in magnetic resonance images, rather than
bone, as with X-rays. It is a non-invasive procedure, allowing such
images to be obtained without penetration of the tissue by objects. It
is abbreviated <altname>MRI</altname>. As with <er>computerized
tomography</er>, the results are usually presented as images of
sequential planar sections of that part of the body of concern to the
physician.</def><br/
[<source>PJC</source>]</p>

<p><ent>Magnetics</ent><br/
<hw>Mag*net"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The science of
magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnetic storm</ent><br/
<hw>magnetic storm</hw> <pos>n.</pos> <def>A sudden disturbance of the
earth's magnetic field; caused by emission of particles from the
sun.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic tape</ent><br/
<hw>magnetic tape</hw> <pos>n.</pos> <def>A long thin plastic ribbon
coated with iron oxide or other ferromagnetic material, used to record
audio or video signals digital data in the form of small magnetized
regions on the tape; it is a common <isa>digital data storage
medium</isa> for computer information.</def><br/
<syn><b>Syn. --</b> mag tape, tape.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetic variation</ent><br/
<hw>magnetic variation</hw> <pos>n.</pos> <def>Same as <er>magnetic
declination</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnetiferous</ent><br/
<hw>Mag`net*if"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>magnes</ets>, <ets>-etis</ets> + <ets>-ferous</ets>.]</ety>
<def>Producing or conducting magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetism</ent><br/
<hw>Mag"net*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>magn<eacute/tisme</ets>.]</ety> <def>The property, quality, or
state, of being magnetic; the manifestation of the force in nature which
is seen in a magnet. At one time it was believed to be separate from the
electrical force, but it is now known to be intimately associated with
electricity, as part of the phenomenon of
<er>electromagnetism</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The science which treats of magnetic
phenomena.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Power of attraction; power to excite the feelings
and to gain the affections.</def> <ldquo/By the <xex>magnetism</xex> of
interest our affections are irresistibly attracted.<rdquo/
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Animal magnetism</b></col>, <cd>Same as
<er>hypnotism</er>, at one time believe to be due to a force more or
less analogous to magnetism, which, it was alleged, is produced in
animal tissues, and passes from one body to another with or without
actual contact. The existence of such a force, and its potentiality for
the cure of disease, were asserted by <persfn>Mesmer</persfn> in 1775.
His theories and methods were afterwards called <xex>mesmerism</xex>, a
name which has been popularly applied to theories and claims not put
forward by Mesmer himself. See <er>Mesmerism</er>, <er>Biology</er>,
<er>Od</er>, <er>Hypnotism</er>.</cd> -- <col><b>Terrestrial
magnetism</b></col>, <cd>the magnetic force exerted by the earth, and
recognized by its effect upon magnetized needles and bars.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetist</ent><br/
<hw>Mag"net*ist</hw>, <pos>n.</pos> <def>One versed in
magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetite</ent><br/
<hw>Mag"net*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>An oxide of iron (<chform>Fe3O4</chform>) occurring in isometric
crystals, also massive, of a black color and metallic luster. It is
readily attracted by a magnet and sometimes possesses polarity, being
then called <stype>loadstone</stype>. It is an important iron ore.
Called also <altname>magnetic iron</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetizable</ent><br/
<hw>Mag"net*i`za*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being magnetized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetization</ent><br/
<hw>Mag`net*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
magnetizing, or the state of being magnetized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetize</ent><br/
<hw>Mag"net*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Magnetized</conjf> <pr>(?)</pr>; <pos>prep. &
adv.</pos> <conjf>Magnetizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf.
F. <ets>magn<eacute/tiser</ets>.]</ety> <sn>1.</sn> <def>To communicate
magnetic properties to; to make magnetic; <as>as, to <ex>magnetize</ex>
a needle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To attract as a magnet attracts, or like a magnet;
to move; to influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fascinated, <qex>magnetized</qex>, as it were, by his
character.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bring under the influence of animal
magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetizee</ent><br/
<hw>Mag`net*i*zee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person
subjected to the influence of animal magnetism.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetizer</ent><br/
<hw>Mag"net*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, imparts magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magneto</ent><br/
<hw>mag*ne"to</hw> <pr>(m<acr/g*n<emac/"t<osl/)</pr>, <pos>n.</pos>
<def>A small electric generator with an armature rotating in a magnetic
field, having a secondary winding that generates a high voltage, such as
one used to generate a voltage sufficient to cause a spark to jump
between the poles of a spark plug in an internal-combustion
engine.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magneto-</ent><br/
<hw>Mag"net*o-</hw> <pr>(?)</pr>, <pos>pref.</pos> <ety>[See
<er>Magnet</er>.]</ety> <def>A prefix meaning <xex>pertaining to</xex>,
<xex>produced by</xex>, or in some way <xex>connected with</xex>,
magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magneto-electrical</ent><br/
<ent>Magneto-electric</ent><br/
<mhw>{ <hw>Mag`net*o-e*lec"tric</hw> <pr>(?)</pr>,
<hw>Mag`net*o-e*lec"tric*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Physics)</fld> <def>Pertaining to, or characterized by,
electricity by the action of magnets; <as>as, <ex>magneto-electric</ex>
induction</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magneto-electric machine</b></col>, <cd>a form of
dynamo-electric machine in which the field is maintained by permanent
steel magnets instead of electro-magnets.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magneto-electricity</ent><br/
<hw>Mag`net*o-e`lec*tric"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Electricity evolved by the action of magnets.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>That branch of science which
treats of the development of electricity by the action of magnets; --
the counterpart of <xex>electro-magnetism</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetograph</ent><br/
<hw>Mag*net"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Magneto-</ets> + <ets>-graph</ets>.]</ety>
<fld>(Physics)</fld> <def>An automatic instrument for registering, by
photography or otherwise, the states and variations of any of the
terrestrial magnetic elements.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnetohydrodynamics</ent><br/
<hw>mag*net"o*hy`dro*dy*nam"ics</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>The study of the interaction of magnetic fields with electrically
conductive fluids, such as a plasma or a molten metal.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnetometer</ent><br/
<hw>Mag`net*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Magneto-</ets> + <ets>-meter</ets>: cf. F.
<ets>magn<eacute/tom<egrave/tre</ets>.]</ety> <fld>(Physics)</fld>
<def>An instrument for measuring the intensity of magnetic forces; also,
less frequently, an instrument for determining any of the terrestrial
magnetic elements, as the dip and declination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetometric</ent><br/
<hw>Mag`net*o*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or employed in, the measurement of magnetic forces; obtained by
means of a magnetometer; <as>as, <ex>magnetometric</ex> instruments;
<ex>magnetometric</ex> measurements.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnetomotive</ent><br/
<hw>Mag`net*o*mo"tive</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Magneto-</ets> + <ets>motive</ets>, a.]</ety>
<fld>(Elec.)</fld> <def>Pertaining to, or designating, a force producing
magnetic flux, analogous to electromotive force, and equal to the
magnetic flux multiplied by the magnetic reluctance.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>magnetomotive force</ent><br/
<hw>magnetomotive force</hw> <pos>n.</pos> <def>The force that produces
magnetic flux.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnetomotor</ent><br/
<hw>Mag`net*o*mo"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A voltaic
series of two or more large plates, producing a great quantity of
electricity of low tension, and hence adapted to the exhibition of
electro-magnetic phenomena.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>magneton</ent><br/
<hw>mag"net*on</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A unit of magnetic
moment for a subatomic particle, atom, or molecule.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnetosphere</ent><br/
<hw>mag*net"o*sphere</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the magnetic
field of a planet; the volume around the planet in which charged
particles are subject more to the planet's magnetic field than to the
solar magnetic field.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Magnetotherapy</ent><br/
<hw>Mag`net*o*ther"a*py</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>The treatment of disease by the application of
magnets to the surface of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnetron</ent><br/
<hw>mag"ne*tron</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a diode vacuum
tube in which the flow of electrons from a central cathode to a
cylindrical anode is controlled by crossed magnetic and electric fields;
used mainly in microwave oscillators.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnifiable</ent><br/
<hw>Mag"ni*fi`a*ble</hw>, <pos>a.</pos> <ety>[From
<er>Magnify</er>.]</ety> <def>Such as can be magnified, or
extolled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnifical</ent><br/
<ent>Magnific</ent><br/
<mhw>{ <hw>Mag*nif"ic</hw> <pr>(?)</pr>, <hw>Mag*nif"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>magnificus</ets>;
<ets>magnus</ets> great + <ets>facere</ets> to make: cf. F.
<ets>magnifique</ets>. See <er>Magnitude</er>, <er>Fact</er>. and cf.
<er>Magnificent</er>.]</ety> <def>Grand; splendid; illustrious;
magnificent.</def> <mark>[Obs.]</mark> <au>1 Chron. xxii. 5.</au>
<ldquo/Thy <xex>magnific</xex> deeds.<rdquo/ <au>Milton.</au> --
<wordforms><wf>Mag*nif"ic*al*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnificat</ent><br/
\'d8<hw>Mag*nif"i*cat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., it
magnifies.]</ety> <def>The song of the Virgin Mary, <au>Luke i. 46</au>;
-- so called because it commences with this word in the
Vulgate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnificate</ent><br/
<hw>Mag*nif"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>magnificatus</ets>, p. p. of <ets>magnificare</ets>.]</ety> <def>To
magnify or extol.</def> <mark>[Obs.]</mark>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnification</ent><br/
<hw>Mag`ni*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
magnifying; enlargement; exaggeration.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnificence</ent><br/
<hw>Mag*nif"i*cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>magnificence</ets>, L. <ets>magnificentia</ets>. See
<er>Magnific</er>.]</ety> <def>The act of doing what is magnificent; the
state or quality of being magnificent.</def> <au>Acts xix. 27.</au>
<ldquo/Then cometh <xex>magnificence</xex>.<rdquo/ <au>Chaucer.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>And, for the heaven's wide circuit, let it speak<br/
The Maker's high <qex>magnificence</qex>, who built<br/
so spacious.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The noblest monuments of Roman <qex>magnificence.</qex></q>
<rj><qau>Eustace.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnificent</ent><br/
<hw>Mag*nif"i*cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Magnificence</er>.]</ety> <sn>1.</sn> <def>Doing grand things;
admirable in action; displaying great power or opulence, especially in
building, way of living, and munificence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A prince is never so <qex>magnificent</qex><br/
As when he's sparing to enrich a few<br/
With the injuries of many.</q> <rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Grand in appearance; exhibiting grandeur or
splendor; splendid; pompous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When Rome's exalted beauties I descry<br/
<qex>Magnificent</qex> in piles of ruin lie.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Glorious; majestic; sublime. See
<er>Grand</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnificently</ent><br/
<hw>Mag*nif"i*cent*ly</hw>, <pos>adv.</pos> <def>In a Magnificent
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnifico</ent><br/
<hw>Mag*nif"i*co</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Magnificoes</plw> <pr>(#)</pr>.</plu> <ety>[It. See
<er>Magnific</er>.]</ety> <sn>1.</sn> <def>A grandee or nobleman of
Venice; -- so called in courtesy.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rector of a German university.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnified</ent><br/
<hw>magnified</hw> <pos>adj.</pos> <def>enlarged to an abnormal
degree.</def><br/
<syn><b>Syn. --</b> exaggerated, enlarged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnifier</ent><br/
<hw>Mag"ni*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, magnifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnify</ent><br/
<hw>Mag"ni*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Magnified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Magnifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>magnifien</ets>, F. <ets>magnifier</ets>, L.
<ets>magnificare</ets>. See <er>Magnific</er>.]</ety> <sn>1.</sn>
<def>To make great, or greater; to increase the dimensions of; to
amplify; to enlarge, either in fact or in appearance; <as>as, the
microscope <ex>magnifies</ex> the object by a thousand
diameters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The least error in a small quantity . . . will in a great one . .
. be proportionately <qex>magnified</qex>.</q>
<rj><qau>Grew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To increase the importance of; to augment the esteem
or respect in which one is held.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On that day the Lord <qex>magnified</qex> Joshua in the sight of
all Israel.</q> <rj><qau>Joshua iv. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To praise highly; to laud; to extol.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>O, <qex>magnify</qex> the Lord with me, and let us exalt his name
together.</q> <rj><qau>Ps. xxxiv. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To exaggerate; <as>as, to <ex>magnify</ex> a loss or
a difficulty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To magnify one's self</b></col> <fld>(Script.)</fld>,
<cd>to exhibit pride and haughtiness; to boast.</cd> -- <col><b>To
magnify one's self against</b></col> <fld>(Script.)</fld>, <cd>to oppose
with pride.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnify</ent><br/
<hw>Mag"ni*fy</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To have the power
of causing objects to appear larger than they really are; to increase
the apparent dimensions of objects; <as>as, some lenses <ex>magnify</ex>
but little</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have effect; to be of importance or
significance.</def> <mark>[Cant & Obs.]</mark>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>magnifying glass</ent><br/
<hw>magnifying glass</hw> <pos>n.</pos> <def>A single convex lens which
magnifies the apparent dimensions of objects seen through it, and is
used to produce an enlarged image.</def><br/
<syn><b>Syn. --</b> hand glass.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magniloquence</ent><br/
<hw>Mag*nil"o*quence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>magniloquentia</ets>.]</ety> <def>The quality of being
magniloquent; pompous discourse; grandiloquence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magniloquent</ent><br/
<hw>Mag*nil"o*quent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>magnus</ets> great + <ets>loquens</ets>, <ets>-entis</ets>, p. pr.
of <ets>loqui</ets> to speak. See <er>Magnitude</er>,
<er>Loquacious</er>.]</ety> <def>Speaking pompously; using swelling
discourse; bombastic; tumid in style; grandiloquent.</def> --
<wordforms><wf>Mag*nil"o*quent*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magniloquous</ent><br/
<hw>Mag*nil"o*quous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>magniloquus</ets>.]</ety> <def>Magniloquent.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnitude</ent><br/
<hw>Mag"ni*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>magnitudo</ets>, from <ets>magnus</ets> great. See <er>Master</er>,
and cf. <er>Maxim</er>.]</ety> <sn>1.</sn> <def>Extent of dimensions;
size; -- applied to things that have length, breadth, and
thickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Conceive those particles of bodies to be so disposed amongst
themselves, that the intervals of empty spaces between them may be equal
in <qex>magnitude</qex> to them all.</q> <rj><qau>Sir I.
Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>That which has one or more of the
three dimensions, length, breadth, and thickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything of which greater or less can be predicated,
as time, weight, force, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 883 --></p>

<p><sn>4.</sn> <def>Greatness; grandeur.</def> <ldquo/With plain, heroic
<xex>magnitude</xex> of mind.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Greatness, in reference to influence or effect;
importance; <as>as, an affair of <ex>magnitude</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>magnitude</qex> of his designs.</q> <rj><qau>Bp.
Horsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Astron.)</fld> <def>See <cref>magnitude of a
star</cref>, below.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Apparent magnitude</b></col> <sn>1.</sn>
<fld>(Opt.)</fld>, <cd>the angular breadth of an object viewed as
measured by the angle which it subtends at the eye of the observer; --
called also <altname>apparent diameter</altname>.</cd> <sn>2.</sn>
<fld>(Astron.)</fld> <cd>Same as <cref>magnitude of a star</cref>,
below.</cd> -- <col><b>Magnitude of a star</b></col>
<fld>(Astron.)</fld>, <cd>the rank of a star with respect to brightness.
About twenty very bright stars are said to be of first magnitude, the
stars of the sixth magnitude being just visible to the naked eye; called
also <altname>visual magnitude</altname>, <altname>apparent
magnitude</altname>, and simply <altname>magnitude</altname>. Stars
observable only in the telescope are classified down to below the
twelfth magnitude. The difference in actual brightness between
magnitudes is now specified as a factor of 2.512, i.e. the difference in
brightness is 100 for stars differing by five magnitudes.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Magnolia</ent><br/
<hw>Mag*no"li*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. Named after
Pierre <etsep>Magnol</etsep>, professor of botany at Montpellier,
France, in the 17th century.]</ety> <fld>(Bot.)</fld> <def>A genus of
American and Asiatic trees, with aromatic bark and large sweet-scented
whitish or reddish flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Magnolia grandiflora</spn> has coriaceous shining
leaves and very fragrant blossoms. It is common from North Carolina to
Florida and Texas, and is one of the most magnificent trees of the
American forest. The sweet bay (<spn>Magnolia glauca</spn>)is a small
tree found sparingly as far north as Cape Ann. Other American species
are <spn>Magnolia Umbrella</spn>, <spn>Magnolia macrophylla</spn>,
<spn>Magnolia Fraseri</spn>, <spn>Magnolia acuminata</spn>, and
<spn>Magnolia cordata</spn>. <spn>Magnolia conspicua</spn> and
<spn>Magnolia purpurea</spn> are cultivated shrubs or trees from Eastern
Asia. <spn>Magnolia Campbellii</spn>, of India, has rose-colored or
crimson flowers.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magnolia warbler</b></col> <fld>(Zool.)</fld>, <cd>a
beautiful North American wood warbler (<spn>Dendroica maculosa</spn>).
The rump and under parts are bright yellow; the breast and belly are
spotted with black; the under tail coverts are white; the crown is
ash.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnoliaceae</ent><br/
<hw>Magnoliaceae</hw> <pos>n.</pos> <def>A natural family of plants, a
subclass of the Magnoliidae; it includes the genera
<gen>Liriodendron</gen>; <gen>Magnolia</gen>; <gen>Manglietia</gen>; and
<gen>Michelia</gen>.</def><br/
<syn><b>Syn. --</b> family <fam>Magnoliaceae</fam>, magnolia
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnoliaceous</ent><br/
<hw>Mag*no`li*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Pertaining to a natural order (<ord>Magnoliaceae</ord>) of trees of
which the magnolia, the tulip tree, and the star anise are
examples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magnolia State</ent><br/
<hw>Magnolia State</hw> <pos>prop. n.</pos> <def>The state of
Mississippi; -- a nickname.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnoliidae</ent><br/
<hw>Magnoliidae</hw> <pos>n.</pos> <def>a group of families of trees and
shrubs and herbs having well-developed perianths and apocarpous ovaries
and generally regarded as the most primitive extant flowering plants;
contains 36 families including <fam>Magnoliaceae</fam> and
<fam>Ranunculaceae</fam>; sometimes classified as a
superorder.</def><br/
<syn><b>Syn. --</b> subclass Magnoliidae, ranalian complex.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnoliophyta</ent><br/
<hw>Magnoliophyta</hw> <pos>n.</pos> <def>A class of flowering plants
that produce seeds enclosed in an ovary; in some systems considered a
class (<class>Angiospermae</class>) and in others a division
(Magnoliophyta or Anthophyta).</def><br/
<syn><b>Syn. --</b> Angiospermae, class <class>Angiospermae</class>,
division Magnoliophyta, Anthophyta, division Anthophyta.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magnoliopsid</ent><br/
<hw>magnoliopsid</hw> <pos>n.</pos> <def>A flowering plant.</def><br/
<syn><b>Syn. --</b> dicot, dicotyledon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnoliopsida</ent><br/
<hw>Magnoliopsida</hw> <pos>n.</pos> <def>A class of seed plants that
produce an embryo with two cotyledons and net-veined leaves; divided
into six (not always well distinguished) subclasses (or superorders):
Magnoliidae and Hamamelidae (considered primitive); Caryophyllidae (an
early and distinctive offshoot); and three more or less advanced groups:
Dilleniidae; Rosidae; Asteridae.</def><br/
<syn><b>Syn. --</b> Dicotyledones, class Dicotyledones, Dicotyledonae,
class Dicotyledonae, class Magnoliopsida.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magnum</ent><br/
<hw>Mag"num</hw> <pr>(m<acr/g"n<ucr/m)</pr>, <pos>n.</pos> <ety>[Neut.
sing. of L. <ets>magnus</ets> great.]</ety> <sn>1.</sn> <def>A large
wine bottle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They passed the <qex>magnum</qex> to one another freely.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A bone of the carpus at the base
of the third metacarpal bone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A magnum pistol, or the cartridge such a pistol
uses; <as>as, he always carried a .44 <ex>magnum</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>magnum</ent><br/
<hw>mag"num</hw> <pr>(m<acr/g"n<ucr/m)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Firearms)</fld> <def>Having a larger charge than usual for a
cartridge of the same caliber; -- of cartridges for handgun; <as>as, a
.44 <ex>magnum</ex> cartridge</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Firearms)</fld> <def>Designed to use a cartridge
with a larger charge than usual for handguns of the same caliber; -- of
handguns; <as>as, a .44 <ex>magnum</ex> pistol</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>magnum opus</ent><br/
<hw>mag"num o"pus</hw> <pr>(m<acr/g"n<ucr/m <omac/"p<ucr/s)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>A great work of art or
literature.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The greatest work or achievement of a particular
artist, writer, or other individual.</def><br/
[<source>PJC</source>]</p>

<p><q>Inspired by this milieu, [Max Stirner] wrote his <qex>magnum
opus</qex> <it>The Ego and Its Own</it>, which was published in November
1844.</q> <rj><qau>Svein Nyberg (The Small Max Stirner Web Page, 1988
[https://web.archive.org/web/19981207014247/http://www.math.uio.no/~solan/stirner/stirner.html])</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>magnus hitch</ent><br/
<hw>magnus hitch</hw> <pos>n.</pos> <def>A rolling hitch similar to a
clove hitch.</def><br/
<source>WordNet 1.5</source></p>

<p><ent>mag tape</ent><br/
<hw>mag tape</hw> <pos>n.</pos> <def>Same as <er>magnetic
tape</er>.</def><br/
<syn><b>Syn. --</b> magnetic tape, tape.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Magot</ent><br/
<hw>Mag"ot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>The Barbary ape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magot-pie</ent><br/
<hw>Mag"ot-pie`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A magpie.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magpie</ent><br/
<hw>Mag"pie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. & Prov. E.
<ets>magot pie</ets>, <ets>maggoty pie</ets>, fr. <ets>Mag</ets>,
<ets>Maggot</ets>, equiv. to <ets>Margaret</ets>, and fr. F.
<ets>Marquerite</ets>, and common name of the magpie.
<ets>Marguerite</ets> is fr. L. <ets>margarita</ets> pearl, Gr. <?/,
prob. of Eastern origin. See <er>Pie</er> magpie, and cf. the analogous
names <er>Tomtit</er>, and <er>Jackdaw</er>.]</ety> <fld>(Zool.)</fld>
<def>Any one of numerous species of the genus <gen>Pica</gen> and
related genera, allied to the jays, but having a long graduated
tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any one of several black-and-white birds, such as
<spn>Gymnorhina tibicen</spn>, not belonging to the genus
<gen>Pica</gen>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ The common European magpie (<spn>Pica pica</spn>, or
<spn>Pica caudata</spn>) is a black and white noisy and mischievous
bird. It can be taught to speak. The American magpie (<spn>Pica
Hudsonica</spn>) is very similar. The yellow-belled magpie (<spn>Pica
Nuttalli</spn>) inhabits California. The blue magpie (<spn>Cyanopolius
Cooki</spn>) inhabits Spain. Other allied species are found in Asia. The
Tasmanian and Australian magpies are crow shrikes, as the white magpie
(<spn>Gymnorhina organicum</spn>), the black magpie (<spn>Strepera
fuliginosa</spn>), and the Australian magpie (<spn>Cracticus
picatus</spn>).</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A talkative person; a chatterbox.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Magpie lark</b></col> <fld>(Zool.)</fld>, <cd>a common
Australian bird (<spn>Grallina picata</spn>), conspicuously marked with
black and white; -- called also <altname>little magpie</altname>.</cd>
-- <col><b>Magpie moth</b></col> <fld>(Zool.)</fld>, <cd>a black and
white European geometrid moth (<spn>Abraxas grossulariata</spn>); the
harlequin moth. Its larva feeds on currant and gooseberry
bushes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maguari</ent><br/
\'d8<hw>Ma`gua*ri"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From native
name: cf. Pg. <ets>magoari</ets>.]</ety> <fld>(Zool.)</fld> <def>A South
American stork (<spn>Euxenara maguari</spn>), having a forked
tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maguey</ent><br/
<hw>Mag"uey</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>maguey</ets>, Mexican <ets>maguei</ets> and <ets>metl</ets>.]</ety>
<fld>(Bot.)</fld> <def>Any of several species of <gen>Agave</gen>, such
as the <stype>century plant</stype> (<spn>Agave Americana</spn>), a
plant requiring many years to come to maturity and blossoming only once
before dying; and the <spn>Agave atrovirens</spn>, a Mexican plant used
especially for making <prod>pulque</prod>, the source of the colorless
Mexican liquor <prod>mescal</prod>; and the <stype>cantala</stype>
(<spn>Agave cantala</spn>), a Philippine plant yielding a hard fibre
used in making coarse twine. See <er>Agave</er>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A hard fibre used in making coarse twine, derived
from the Philippine Agave <prodby>cantala</prodby> (<spn>Agave
cantala</spn>); also called <altname>cantala</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>magus</ent><br/
<hw>magus</hw> <pos>n.</pos> <sn>1.</sn> <def>a magician or sorcerer of
ancient times.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a member of the Zoroastrian priesthood of the
ancient Persians.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Magyar</ent><br/
<hw>Mag"yar</hw> <pr>(m<acr/g"y<aum/r; <it>Hung</it>.
m<ocr/d"y<ocr/r)</pr>, <pos>prop. n.</pos> <ety>[Hung.]</ety>
<sn>1.</sn> <fld>(Ethnol.)</fld> <def>One of the dominant people of
Hungary, allied to the Finns; a Hungarian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language of the Magyars.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Magyar</ent><br/
<hw>Mag"yar</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or pertaining
to the Magyars or their language; Hungarian.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maha</ent><br/
\'d8<hw>Ma"ha</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
kind of baboon; the wanderoo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maha</ent><br/
<hw>Ma"ha</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Ethnol.)</fld>
<def>A member of the Siouan people formerly living in the Missouri river
valley in Northeastern Nebraska; called also
<altname>Omaha</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mahabharatam</ent><br/
<ent>Mahabarata</ent><br/
<mhw>{ \'d8<hw>Ma*ha*ba"ra*ta</hw> <pr>(?)</pr>,
\'d8<hw>Ma*ha*bha"ra*tam</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[Skr. <ets>mah<amac/bh<amac/rata</ets>.]</ety>
<fld>(Hinduism)</fld> <def>A celebrated sacred epic poem of the Hindus,
written in Sanskrit. It is of great length, and is chiefly devoted to a
history, in many episodes, of a civil war between two dynasties of
ancient India.</def><br/
<syn><b>Syn. --</b> Mahabharatam, Mahabharatum.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahaled</ent><br/
\'d8<hw>Ma*ha"led</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[Ar.
<ets>mahled</ets>.]</ety> <fld>(Bot.)</fld> <def>A cherry tree
(<spn>Prunus Mahaleb</spn>) of Southern Europe. The wood is prized by
cabinetmakers, the twigs are used for pipe stems, the flowers and leaves
yield a perfume, and from the fruit a violet dye and a fermented liquor
(like kirschwasser) are prepared.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maharajah</ent><br/
<ent>maharaja</ent><br/
<mhw><hw>maharaja</hw>, <hw>ma*ha*ra"jah</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Skr. <ets>mah<amac/r<amac/ja</ets>; <ets>mahat</ets>
great + <ets>r<amac/ja</ets> king.]</ety> <def>A sovereign prince in
India; a Hindu prince or king in India ranking above a raja; -- a title
given also to other persons of high rank.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>maharani</ent><br/
<hw>maharani</hw> <pos>n.</pos> <def>A great rani; a princess in India
or the wife of a maharaja.</def> <altsp>[Also spelled
<asp>maharanee</asp>.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maharif</ent><br/
\'d8<hw>Ma`ha*rif"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An African antelope (<spn>Hippotragus Bakeri</spn>). Its face is
striped with black and white.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maharmah</ent><br/
\'d8<hw>Ma*har"mah</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A muslin
wrapper for the head and the lower part of the face, worn by Turkish and
Armenian women when they go abroad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahatma</ent><br/
<hw>Ma*hat"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.
<ets>mah<amac/tman</ets>, lit., great-souled, wise.]</ety>
<fld>(Theosophy)</fld> <def>One of a class of sages, or
<ldquo/adepts,<rdquo/ reputed to have knowledge and powers of a higher
order than those of ordinary men.</def>

<note>The title was popularly applied to <person>Mohandas Karamchand
Gandhi</person> in tribute to his wisdom, though not implying any
supernatural powers; he is thus often referred to as <person>Mahatma
Ghandi</person> or <person>The Mahatma</person>. He was most noted for
his advocacy of non-violence in resisting oppression, and played an
important role in convincing Great Britain to grant independence to
India and Pakistan.</note> -- <wordforms><wf>Ma*hat"ma*ism</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Mahatma Ghandi</ent><br/
<hw>Ma*hat"ma Ghandi</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>See the
note under <er>mahatma</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mahayana</ent><br/
<hw>Mahayana</hw> <pos>n.</pos> <sn>1.</sn> <def>a major school of
Buddhism teaching social concern and universal salvation, found in
China; Japan; Tibet; Nepal; Korea; and Mongolia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>one of two great schools of Buddhist doctrine
emphasizing a common search for universal salvation esp through faith
alone; chiefly in China; Tibet; Japan.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mahayanist</ent><br/
<hw>Mahayanist</hw> <pos>n.</pos> <def>an adherent of Mahayana
Buddhism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mahdi</ent><br/
<hw>Mah"di</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar., guide,
leader.]</ety> <def>Among Muslims, the last <xex>imam</xex> or leader of
the faithful. The Sunni, the largest sect of the Muslims, believe that
he is yet to appear.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The title has been taken by several persons in countries
where Islam prevails, -- notably by <person>Mohammad Ahmed</person>, who
overran the Egyptian Sudan, and in 1885 captured Khartum, his soldiers
killing <person>General Gordon</person>, an Englishman, who was then the
Egyptian governor of the region.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahdiism</ent><br/
<hw>Mah"di*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mahdism</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mahdism</ent><br/
<hw>Mah"dism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Belief in the coming
of the Mahdi; fanatical devotion to the cause of the Mahdi or a
pretender to that title.</def> -- <wordforms><wf>Mah"dist</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms></p>

<p><q><qex>Mahdism</qex> has proved the most shameful and terrible
instrument of bloodshed and oppression which the modern world has ever
witnessed.</q> <rj><qau>E. N. Bennett.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mahican</ent><br/
<hw>Mahican</hw> <pos>prop. n.</pos> <def>Variant of
<er>Mohican</er>.</def> <altsp>[Also spelled
<asp>Mohican</asp>.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mahimahi</ent><br/
<hw>mahimahi</hw> <pos>n.</pos> <sn>1.</sn> <def>either of two large
slender food and game fish (<spn>Coryphaena equisetis</spn> or
<spn>Coryphaena hippurus</spn>) of warm waters. They are highly esteemed
as food fish, especially in Hawaii. See also
<er>dolphin{2}</er>.</def><br/
<syn><b>Syn. --</b> dolphin, dolphinfish.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>lean-fleshed fish of warm waters, esp.
Hawaii.</def><br/
<syn><b>Syn. --</b> dolphinfish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mah-Jongg</ent><br/
<ent>mahjong</ent><br/
<mhw><hw>mahjong</hw>, <hw>Mah-Jongg</hw></mhw> <pos>n.</pos> <def>A
Chinese game played by 4 people with 144 tiles.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mahl-stick</ent><br/
<ent>mahlstick</ent><br/
<mhw><hw>mahl"stick`</hw>, <hw>mahl"-stick`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[G. <ets>malerstock</ets>; <ets>maler</ets> a painter
+ <ets>stock</ets> stick.]</ety> <def>A long stick that a painter uses
to support the hand holding the brush while painting. Same as
<er>Maul-stick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahoe</ent><br/
<hw>Ma"hoe</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
name given to several malvaceous trees (species of <gen>Hibiscus</gen>,
<gen>Ochroma</gen>, etc.), and to their strong fibrous inner bark, which
is used for strings and cordage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahogany tree</ent><br/
<ent>Mahogany</ent><br/
<mhw><hw>Ma*hog"a*ny</hw>, <hw>Ma*hog"a*ny tree`</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[From the South American name.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A large tree of the genus
<gen>Swietenia</gen> (<spn>Swietenia Mahogoni</spn>), found in tropical
America.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Several other trees, with wood more or less like
mahogany, are called by this name; as, African mahogany (<spn>Khaya
Senegalensis</spn>), Australian mahogany (<spn>Eucalyptus
marginatus</spn>), Bastard mahogany (<spn>Batonia apetala</spn> of the
West Indies), Indian mahogany (<spn>Cedrela Toona</spn> of Bengal, and
trees of the genera <gen>Soymida</gen> and <gen>Chukrassia</gen>),
Madeira mahogany (<spn>Persea Indica</spn>), Mountain mahogany, the
black or cherry birch (<spn>Betula lenta</spn>), also the several
species of <gen>Cercocarpus</gen> of California and the Rocky
Mountains.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The wood of the <spn>Swietenia Mahogoni</spn>. It is
of a reddish brown color, beautifully veined, very hard, and susceptible
of a fine polish. It is used in the manufacture of furniture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A table made of mahogany wood.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be under the mahogany</b></col>, <cd>to be so drunk as
to have fallen under the table.</cd> <mark>[Eng.]</mark> -- <col><b>To
put one's legs under some one's mahogany</b></col>, <cd>to dine with
him.</cd> <mark>[Slang]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maholi</ent><br/
\'d8<hw>Ma*ho"li</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A South African lemur (<spn>Galago maholi</spn>), having very large
ears.</def> <altsp>[Written also <asp>moholi</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahometan</ent><br/
<ent>Mahomedan</ent><br/
<mhw>{ <hw>Ma*hom"ed*an</hw> <pr>(?)</pr>, <hw>Ma*hom"et*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>See
<er>Mohammedan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahomet</ent><br/
<hw>Ma*hom"et</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>Same as
<er>Mohammed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahometanism</ent><br/
<hw>Ma*hom"et*an*ism</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>See
<er>Mohammedanism</er> and <er>Islam</er>.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahometanize</ent><br/
<hw>Ma*hom"et*an*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Mahometanized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Mahometanizing</conjf>
<pr>(?)</pr>.]</vmorph> <def>To convert to Islam, the religion of
Mohammed; to Mohammedanize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahometism</ent><br/
<hw>Ma*hom"et*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mohammedanism</er> and <er>Islam</er>.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahometist</ent><br/
<hw>Ma*hom"et*ist</hw>, <pos>n.</pos> <def>A Muslim.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahometry</ent><br/
<hw>Ma*hom"et*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Islam.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahone</ent><br/
<hw>Ma*hone"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A large Turkish
ship.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mahonia</ent><br/
<hw>ma*ho"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after
<person>Bernard Mc<etsep>Mahon</etsep></person>.]</ety>
<fld>(Bot.)</fld> <def>The Oregon grape, a species of barberry
(<spn>Berberis Aquifolium</spn>), often cultivated for its hollylike
foliage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahonia</ent><br/
<hw>Mahonia</hw> <pos>prop. n.</pos> <def>A genus of evergreen shrubs
and small trees of North and Central America and Asia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mahon stock</ent><br/
<hw>ma*hon" stock`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>An annual
cruciferous plant with reddish purple or white flowers (<spn>Malcolmia
maritima</spn>). It is called in England <altname>Virginia
stock</altname>, but the plant comes from the Mediterranean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahoohoo</ent><br/
\'d8<hw>Ma*hoo"hoo</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The African white two-horned rhinoceros (<spn>Atelodus
simus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahori</ent><br/
<hw>Ma"ho*ri</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name. Cf.
<er>Maori</er>.]</ety> <fld>(Ethnol.)</fld> <def>One of the dark race
inhabiting principally the islands of Eastern Polynesia. Also used
adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahound</ent><br/
<hw>Ma`hound</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A contemptuous name
for Mohammed; hence, an evil spirit; a devil.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who's this, my <qex>mahound</qex> cousin ?</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahout</ent><br/
\'d8<hw>Ma*hout"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>mah<amac/wat</ets>, Skr. <ets>mah<amac/m<amac/tra</ets>;
<ets>mahat</ets> great + <ets>m<amac/tr<amac/</ets> measure.]</ety>
<def>The keeper and driver of an elephant.</def> <mark>[East
Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahovo</ent><br/
<hw>Ma*ho"vo</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mach.)</fld> <def>A
device for saving power in stopping and starting a railroad car, by
means of a heavy fly wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahrati</ent><br/
<hw>Mah*rat"i</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The language of the
Mahrattas; the language spoken in the Deccan and Concan.</def>
<altsp>[Written also <asp>Marathi</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahratta</ent><br/
<hw>Mah*rat"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>Marhat<amac/</ets>, <ets>Marh<amac/tt<amac/</ets>, the name of a
famous Hindoo race, from the old Skr. name
<ets>Mah<amac/-r<amac/shtra</ets>.]</ety> <def>One of a numerous people
inhabiting the southwestern part of India. Also, the language of the
Mahrattas; Mahrati. It is closely allied to Sanskrit.</def> --
<def2><pos>a.</pos> <def>Of or pertaining to the Mahrattas.</def></def2>
<altsp>[Written also <asp>Maratha</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahumetanism</ent><br/
<ent>Mahumetan</ent><br/
<mhw>{ <hw>Ma*hu"met*an</hw> <pr>(?)</pr>, <hw>Ma*hu"met*an*ism</hw>
<pr>(?)</pr>, <pos>n.</pos> }</mhw> <def>See <er>Mohammedan</er>,
<er>Muslim</er>, <er>Mohammedanism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahwa tree</ent><br/
<hw>Mah"wa tree`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>An East
Indian sapotaceous tree (<spn>Bassia latifolia</spn>, and also
<spn>Bassia butyracea</spn>), whose timber is used for wagon wheels, and
the flowers for food and in preparing an intoxicating drink. It is one
of the butter trees. The oil, known as <xex>mahwa</xex> and
<xex>yallah</xex>, is obtained from the kernels of the fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maia</ent><br/
\'d8<hw>Ma"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>Maia</ets>, a goddess.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>A genus of spider crabs, including the common European species
(<spn>Maia squinado</spn>).</def> <sd>(b)</sd> <def>A beautiful American
bombycid moth (<spn>Eucronia maia</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maian</ent><br/
<hw>Ma"ian</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any
spider crab of the genus Maia, or family <fam>Maiadae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maid</ent><br/
<hw>Maid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Shortened from
<ets>maiden</ets>. <ets><?/</ets>. See <er>Maiden</er>.]</ety>
<sn>1.</sn> <def>An unmarried woman; usually, a young unmarried woman;
esp., a girl; a virgin; a maiden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Would I had died a <qex>maid</qex>,<br/
And never seen thee, never borne thee son.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Can a <qex>maid</qex> forget her ornaments, or a bride her attire?
Yet my people have forgotten me.</q> <rj><qau>Jer. ii.
32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man who has not had sexual intercourse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Christ was a <qex>maid</qex> and shapen as a man.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A female servant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Spinning amongst her <qex>maids</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Maid</xex> is used either adjectively or in
composition, signifying <xex>female</xex>, as in <xex>maid</xex> child,
<xex>maid</xex>servant.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>The female of a ray or skate,
esp. of the gray skate (<spn>Raia batis</spn>), and of the thornback
(<spn>Raia clavata</spn>).</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fair maid</b></col>. <fld>(Zool.)</fld> <cd>See under
<er>Fair</er>, <pos>a.</pos></cd> -- <col><b>Maid of honor</b></col>,
<cd>a female attendant of a queen or royal princess; -- usually of noble
family, and having to perform only nominal or honorary duties.</cd> --
<col><b>Old maid</b></col>. <cd>See under <er>Old</er>.</cd></cs> <--
maid of honor. principal female attendant (if unmarried) of a bride at
wedding. (If married, matron of honor.) --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidan</ent><br/
\'d8<hw>Mai*dan"</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>midan</asp>, <asp>meidan</asp>, <asp>mydan</asp>, etc.]</altsp>
<ety>[Hind. & Per. <ets>maid<amac/n</ets>, fr. Ar.
<ets>maid<amac/n</ets>.]</ety> <def>In various parts of Asia, an open
space, as for military exercises, or for a market place; an open grassy
tract; an esplanade.</def></p>

<p><q>A gallop on the green <qex>maidan</qex>.</q> <rj><qau>M.
Crawford.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maiden</ent><br/
<hw>Maid"en</hw> <pr>(m<amac/d"'n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>maiden</ets>, <ets>meiden</ets>, AS. <ets>maegden</ets>, dim. of
AS. <ets>maeg<edh/</ets>, fr. <ets>mago</ets> son, servant; akin to G.
<ets>magd</ets>, <ets>m<aum/dchen</ets>, maid, OHG. <ets>magad</ets>,
Icel. <ets>m<oum/gr</ets> son, Goth. <ets>magus</ets> boy, child,
<ets>magaps</ets> virgin, and perh. to Zend. <ets>magu</ets> youth. Cf.
<er>Maid</er> a virgin.]</ety> <sn>1.</sn> <def>An unmarried woman; a
girl or woman who has not experienced sexual intercourse; a virgin; a
maid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She employed the residue of her life to repairing of highways,
building of bridges, and endowing of <qex>maidens</qex>.</q>
<rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>maiden</qex> of our century, yet most meek.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A female servant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An instrument resembling the guillotine, formerly
used in Scotland for beheading criminals.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A machine for washing linen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maiden</ent><br/
<hw>Maid"en</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to a
maiden, or to maidens; suitable to, or characteristic of, a virgin;
<as>as, <ex>maiden</ex> innocence</as>.</def> <ldquo/Amid the
<xex>maiden</xex> throng.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Have you no modesty, no <qex>maiden</qex> shame ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Never having been married; not having had sexual
intercourse; virgin; -- said usually of the woman, but sometimes of the
man; <as>as, a <ex>maiden</ex> aunt</as>.</def> <ldquo/A surprising old
<xex>maiden</xex> lady.<rdquo/ <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fresh; innocent; unpolluted; pure; hitherto
unused.</def> <ldquo/<xex>Maiden</xex> flowers.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Full bravely hast thou fleshed<br/
Thy <qex>maiden</qex> sword.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Used of a fortress, signifying that it has never
been captured, or violated.</def> <rj><au> T. Warton.
Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maiden assize</b></col> <fld>(Eng. Law)</fld>, <cd>an
assize which there is no criminal prosecution; an assize which is
unpolluted with blood. It was usual, at such an assize, for the sheriff
to present the judge with a pair of white gloves.</cd> <au>Smart.</au>
-- <col><b>Maiden name</b></col>, <cd>the surname of a woman before her
marriage.</cd> -- <col><b>Maiden pink</b></col>. <fld>(Bot.)</fld>
<cd>See under <er>Pink</er>.</cd> -- <col><b>Maiden plum</b></col>
<fld>(Bot.)</fld>, <cd>a West Indian tree (<spn>Comocladia
integrifolia</spn>) with purplish drupes. The sap of the tree is
glutinous, and gives a persistent black stain.</cd> -- <col><b>Maiden
speech</b></col>, <cd>the first speech made by a person, esp. by a new
member in a public body.</cd> -- <col><b>Maiden tower</b></col>, <cd>the
tower most capable of resisting an enemy.</cd> -- <col><b>maiden
voyage</b></col> <cd>the first regular service voyage of a
ship.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maiden</ent><br/
<hw>Maid"en</hw>, <pos>v. t.</pos> <def>To act coyly like a maiden; --
with <xex>it</xex> as an indefinite object.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For had I <qex>maiden'd</qex> it, as many use.<br/
Loath for to grant, but loather to refuse.</q> <rj><qau>Bp.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maiden grass</b></col>, <cd>the smaller quaking
grass.</cd> -- <col><b>Maiden tree</b></col>. <cd>See
<er>Ginkgo</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>maiden aunt</ent><br/
<hw>maiden aunt</hw> <pos>n.</pos> <def>Literally, an aunt who has never
been married. Figuratively, it is a term used as the prototype of a
person who is broadly naive and not wise in worldly ways; <as>as, he
knows as much about programming as my <ex>maiden
aunt</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>maiden blue-eyed mary</ent><br/
<hw>maiden blue-eyed mary</hw> <pos>n.</pos> <def>A small widely
branching Western wildflower (<spn>Collinsia parviflora</spn>) with tiny
blue-and-white flowers; found from British Columbia to Ontaria and south
to California and Colorado.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maidenhair fern</ent><br/
<ent>maidenhair</ent><br/
<mhw><hw>maid"en*hair`</hw>, <hw>maidenhair fern</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Any of various small
to large terrestrial ferns of the genus <gen>Adiantum</gen> having very
slender graceful stalks and delicate palmately branched fronds,
especially (<spn>Adiantum pedatum</spn>). It is common in the United
States, and is sometimes used in medicine. The name is also applied to
other species of the same genus, as to the Venus-hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maidenhair berry</ent><br/
<hw>maidenhair berry</hw> <pos>n.</pos> <def>A slow-growing procumbent
evergreen shrublet (<spn>Gaultheria hispidula</spn>) of Northern North
America and Japan having white flowers and numerous white fleshy
rough-hairy seeds.</def><br/
<syn><b>Syn. --</b> creeping snowberry, moxie plum, <spn>Gaultheria
hispidula</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maidenhair fern</ent><br/
<hw>maidenhair fern</hw> <pos>n.</pos> <def>See
<er>maidenhair</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>maidenhair spleenwort</ent><br/
<hw>maidenhair spleenwort</hw> <pos>n.</pos> <def>A small
rock-inhabiting fern (<spn>Asplenium trichomanes</spn>) of the North
temperate zone and Hawaii, having pinnate fronds.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maidenhair tree</ent><br/
<hw>maidenhair tree</hw> <pos>n.</pos> <def>A deciduous dioecious
gymnospermous Chinese tree (<spn>Ginkgo biloba</spn>) having fan-shaped
leaves and fleshy yellow seeds, also called the
<altname>ginkgo</altname>; it exists almost exclusively in cultivation
esp. as an ornamental street tree.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maidenhead</ent><br/
<hw>Maid"en*head</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Maidenhood</er>.]</ety> <sn>1.</sn> <def>The state of being a
maiden; maidenhood; virginity.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being unused or uncontaminated;
freshness; purity.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>maidenhead</qex> of their credit.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The hymen, or virginal membrane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidenhood</ent><br/
<hw>Maid"en*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>maegdenh<amac/d</ets>. See <er>Maid</er>, and
<er>-hood</er>.]</ety> <sn>1.</sn> <def>The state of being a maid or a
virgin; virginity.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Newness; freshness; uncontaminated state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>maidenhood</qex><br/
Of thy fight.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidenlike</ent><br/
<hw>Maid"en*like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a maiden;
modest; coy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidenliness</ent><br/
<hw>Maid"en*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being maidenly; the behavior that becomes a maid; modesty;
gentleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidenly</ent><br/
<hw>Maid"en*ly</hw>, <pos>a.</pos> <def>Like a maid; suiting a maid;
maiden-like; gentle, modest, reserved.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Must you be blushing ? . . . <br/
What a <qex>maidenly</qex> man-at-arms are you become !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidenly</ent><br/
<hw>Maid"en*ly</hw>, <pos>adv.</pos> <def>In a maidenlike manner.</def>
<ldquo/<xex>Maidenly</xex> demure.<rdquo/ <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maiden over</ent><br/
<hw>maiden over</hw> <pos>n.</pos> <fld>(cricket)</fld> <def>An over in
which no runs are scored.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maiden pink</ent><br/
<hw>maiden pink</hw> <pos>n.</pos> <def>A low-growing loosely
mat-forming Eurasian pink (<spn>Dianthus deltoides</spn>) with single
crimson-eyed pale pink flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maidenship</ent><br/
<hw>Maid"en*ship</hw>, <pos>n.</pos> <def>Maidenhood.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidhood</ent><br/
<hw>Maid"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>maeg<edh/h<amac/d</ets>. See <er>Maid</er>, and
<er>-hood</er>.]</ety> <def>Maidenhood.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidmarian</ent><br/
<hw>Maid`ma"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Maid</ets>
+ <ets>Marian</ets>, relating to <ets>Mary</ets>, or the Virgin
<ets>Mary</ets>.]</ety> <sn>1.</sn> <def>The lady of the May games; one
of the characters in a morris dance; a May queen. Afterward, a grotesque
character personated in sports and buffoonery by a man in woman's
clothes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of dance.</def> <rj><au>Sir W.
Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidpale</ent><br/
<hw>Maid"pale`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pale, like a sick
girl.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maidservant</ent><br/
<hw>Maid"serv`ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
servant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maid's hair</ent><br/
<hw>Maid's" hair`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>The yellow
bedstraw (<spn>Galium verum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maieutical</ent><br/
<ent>Maieutic</ent><br/
<mhw>{ <hw>Ma*ieu"tic</hw> <pr>(m<asl/*<umac/"t<icr/k)</pr>,
<hw>Ma*ieu"tic*al</hw> <pr>(m<asl/*<umac/"t<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[Gr. <grk>maieytiko`s</grk>, fr. <grk>mai^a</grk>
midwife.]</ety> <sn>1.</sn> <def>Serving to assist childbirth.</def>
<rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>[Fig.]</mark> <def>Aiding, or tending to, the
definition and interpretation of thoughts or language.</def>
<rj><au>Payne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maieutic method</ent><br/
<hw>maieutic method</hw> <pos>n.</pos> <def>A method of teaching by
question and answer; it was used by <persfn>Socrates</persfn> to elicit
truths from his students; -- called also the <altname>Socratic
method</altname></def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maieutics</ent><br/
<hw>Ma*ieu"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of giving
birth (<it>i. e.</it>, clearness and conviction) to ideas, which are
conceived as struggling for birth.</def> <rj><au>Payne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maiger</ent><br/
<hw>Mai"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
meagre.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maigre</ent><br/
<hw>Mai"gre</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. See
<er>Meager</er>.]</ety> <def>Belonging to a fast day or fast; <as>as, a
<ex>maigre</ex> day</as>.</def> <rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maigre food</b></col> <fld>(R. C. Ch.)</fld>, <cd>food
allowed to be eaten on fast days.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 884 --></p>

<p><ent>Maihem</ent><br/
<hw>Mai"hem</hw> <pr>(m<amac/"h<ecr/m)</pr>, <pos>n.</pos> <def>See
<er>Maim</er>, and <er>Mayhem</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maikel</ent><br/
\'d8<hw>Mai*kel"</hw> <pr>(m<aum/<icr/*k<asl/l")</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A South American carnivore of the genus
<gen>Conepatus</gen>, allied to the skunk, but larger, and having a
longer snout. The tail is not bushy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maikong</ent><br/
\'d8<hw>Mai*kong"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A South American wild dog (<spn>Canis cancrivorus</spn>); the
crab-eating dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mail</ent><br/
<hw>Mail</hw> <pr>(m<amac/l)</pr>, <pos>n.</pos> <def>A spot.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mail</ent><br/
<hw>Mail</hw>, <pos>n.</pos> <ety>[F. <ets>maille</ets>, OF. also
<ets>maaille</ets>, LL. <ets>medalia</ets>. See <er>Medal</er>.]</ety>
<sn>1.</sn> <def>A small piece of money; especially, an English silver
half-penny of the time of <person>Henry V.</person></def>
<mark>[Obs.]</mark> <altsp>[Written also <asp>maile</asp>, and
<asp>maille</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rent; tribute.</def> <mark>[Obs., except in certain
compounds and phrases, as blackmail, mails and duties, etc.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mail and duties</b></col> <fld>(Scots Law)</fld>, <cd>the
rents of an estate, in whatever form paid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mail</ent><br/
<hw>Mail</hw> <pr>(m<amac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>maile</ets>, <ets>maille</ets>, F. <ets>maille</ets> a ring of
mail, mesh, network, a coat of mail, fr. L. <ets>macula</ets> spot, a
mesh of a net. Cf. <er>Macle</er>, <er>Macula</er>,
<er>Mascle</er>.]</ety> <sn>1.</sn> <def>A flexible fabric made of metal
rings interlinked. It was used especially for defensive armor.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Chain mail</b></col>, <col><b>Coat of
mail</b></col></mcol>. <cd>See under <er>Chain</er>, and
<er>Coat</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence generally, armor, or any defensive
covering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A contrivance of interlinked
rings, for rubbing off the loose hemp on lines and white
cordage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>Any hard protective covering of
an animal, as the scales and plates of reptiles, shell of a lobster,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We . . . strip the lobster of his scarlet <qex>mail</qex>.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mail</ent><br/
<hw>Mail</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To arm with
mail.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pinion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mail</ent><br/
<hw>Mail</hw> <pr>(m<amac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>male</ets> bag, OF. <ets>male</ets>, F. <ets>malle</ets> bag,
trunk, mail, OHG. <ets>malaha</ets>, <ets>malha</ets>, wallet; akin to
D. <ets>maal</ets>, <ets>male</ets>; cf. Gael. & Ir. <ets>mala</ets>,
Gr. <grk>molgo`s</grk> hide, skin.]</ety> <sn>1.</sn> <def>A bag; a
wallet.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The bag or bags with the letters, papers, or other
matter contained therein, conveyed under public authority from one post
office to another; the whole system of appliances used by government in
the conveyance and delivery of mail matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a <qex>mail</qex> come in to-day, with letters dated
Hague.</q> <rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which comes in the mail; letters, etc.,
received through the post office.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A trunk, box, or bag, in which clothing, etc., may
be carried.</def> <mark>[Obs.]</mark> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mail catcher</b></col>, <cd>an iron rod, or other
contrivance, attached to a railroad car for catching a mail bag while
the train is in motion.</cd> -- <col><b>Mail guard</b></col>, <cd>an
officer whose duty it is to guard the public mails.</cd>
<mark>[Eng.]</mark> -- <col><b>Mail train</b></col>, <cd>a railroad
train carrying the mail.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mail</ent><br/
<hw>Mail</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mailed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mailing</conjf>.]</vmorph> <def>To deliver into the custody of
the postoffice officials, or place in a government letter box, for
transmission by mail; to post; <as>as, to <ex>mail</ex> a
letter</as>.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the United States <xex>to mail</xex> and <xex>to
post</xex> are both in common use; as, to <xex>mail</xex> or
<xex>post</xex> a letter. In England <xex>post</xex> is the commoner
usage.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mailable</ent><br/
<hw>Mail"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Admissible lawfully
into the mail. Opposed to <ant>non-mailable</ant>. Dangerous items such
as explosives, weapons, or corrosive chemicals are often classified by
the postal authorities as non-mailable.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>mail bag</ent><br/
<ent>mailbag</ent><br/
<mhw><hw>mail"bag`</hw>, <hw>mail bag</hw></mhw> <pos>n.</pos> <def>A
bag in which mailed matter is conveyed or shipped under public
authority.</def><br/
<syn><b>Syn. --</b> mail pouch.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A letter carrier's shoulder bag; <as>as, in England
they call a <ex>mailbag</ex> a postbag</as>.</def><br/
<syn><b>Syn. --</b> postbag.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mail boat</ent><br/
<ent>mailboat</ent><br/
<mhw><hw>mail"boat`</hw>, <hw>mail" boat`</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>a boat that carries the mail.</def><br/
<syn><b>Syn. --</b> mail boat, packet, packet boat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mailbox</ent><br/
<hw>mail"box`</hw> <pos>n.</pos> <sn>1.</sn> <def>A public box for
deposit of mail, where it is later picked up by the postal authority for
delivery.</def><br/
<syn><b>Syn. --</b> postbox, letter box.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A private box to recieve delivery of mail. The term
is used both for boxes receiving mail delivered by the public postal
authority, or by a private services, such as for mail to employees in
large corporations.</def><br/
<syn><b>Syn. --</b> letter box.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>A location within a computer
storage device where electronic mail is held until it is retrieved by
the addressee. Creation and use of an electronic <ex>mailbox</ex>
requires special software as well as a data storage device.</def><br/
[<source>PJC</source>]</p>

<p><ent>mail call</ent><br/
<hw>mail call</hw> <pos>n.</pos> <def>A call of the names of those
persons receiving mail for the purpose of transmitting mail to them; --
a technique used in the military services to deliver mail to enlisted
personnel.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mail car</ent><br/
<hw>mail car</hw> <pos>n.</pos> <def>A railway car of special design
used for the transportation and sorting of mail en route to its
destination, and having employees of the post office inside to perform
those functions.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mail carrier</ent><br/
<hw>mail carrier</hw> <pos>n.</pos> <def>A person who delivers the mail;
-- also called a <altname>letter carrier</altname>. A male mail carrier
is also called a <altname>mailman</altname>.</def><br/
<syn><b>Syn. --</b> postman, letter carrier, carrier, mailman.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Mailclad</ent><br/
<hw>Mail"clad`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Protected by a coat
of mail; clad in armor.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mail clerk</ent><br/
<hw>mail clerk</hw> <pos>n.</pos> <def>A clerk in a post
office.</def><br/
<syn><b>Syn. --</b> postal clerk.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mailed</ent><br/
<hw>Mailed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Protected by an external coat, or covering, of scales or
plates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mailed</ent><br/
<hw>Mailed</hw>, <pos>a.</pos> <ety>[See 1st <er>Mail</er>.]</ety>
<def>Spotted; speckled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mail fraud</ent><br/
<hw>mail fraud</hw> <pos>n.</pos> <def>The use of the mails to defraud
someone.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mailing</ent><br/
<hw>Mail"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot., fr.
<ets>mail</ets> tribute, rent. See 2d <er>Mail</er>.]</ety> <def>A
farm.</def> <mark>[Scot.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mailing</ent><br/
<hw>mail"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or process of sending materials through the mail.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A quantity of mail, such as letters, magazines,
advertising brochures, etc., sent at one time by one person or
organization; <as>as, the ads with coupons will go out in our next
<ex>mailing</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>mailing address</ent><br/
<hw>mailing address</hw> <pos>n.</pos> <def>The postal address where a
maile can be addressed to a person or organization.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mailing list</ent><br/
<hw>mailing list</hw> <pos>n.</pos> <def>A list of names and addresses
to which advertising, solicitations of money, or other materials
material sent in large quantities is mailed; -- it is usually used by
comercial or charitable organizations. Mailing lists are often sold by
organizations to other organizations, and are frequently used for
<ecol><b>targeted mailing</b></ecol>, i. e., mailing to groups of people
who are more likely htan the general population to respond as desired to
the message in the mail.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>maillot</ent><br/
<hw>maillot</hw> <pos>n.</pos> <def>A woman's one-piece bathing
suit.</def><br/
<syn><b>Syn. --</b> tank suit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>for dancers or gymnasts.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mailman</ent><br/
<hw>mail"man`</hw> <pos>n.</pos> <def>A man who delivers the mail. A
male <er>mail carrier</er>.</def><br/
<syn><b>Syn. --</b> postman, mail carrier, letter carrier,
carrier.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mail-order</ent><br/
<ent>mail-order buying</ent><br/
<mhw><hw>mail-order buying</hw>, <hw>mail-order</hw></mhw> <pos>n.</pos>
<def>The buying and selling of goods to be shipped from the vendor
through the mail to the purchaser. Information about to be purchased may
be found in catalogs, advertisements, on the web, etc., and purchase
orders transmitted to the vendor by mail, telephone, or internet
connection.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mail pouch</ent><br/
<hw>mail pouch</hw> <pos>n.</pos> <def>Same as
<er>mailbag</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mail-shell</ent><br/
<hw>Mail"-shell`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A chiton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mail slot</ent><br/
<hw>mail slot</hw> <pos>n.</pos> <def>A usually horizontal slot in a
door through which mail can be delivered. It often has a hinged cover to
keep the opening cloised when not in use.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mailsorter</ent><br/
<hw>mailsorter</hw> <pos>n.</pos> <def>A machine that sorts mail,
according to the address.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mail train</ent><br/
<hw>mail train</hw> <pos>n.</pos> <def>A railroad train that carries
mail.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maim</ent><br/
<hw>Maim</hw> <pr>(m<amac/m)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Maimed</conjf> <pr>(m<amac/md)</pr>;<pos>p. pr. & vb.
n.</pos> <conjf>Maiming</conjf>.]</vmorph> <ety>[OE. <ets>maimen</ets>,
OF. <ets>mahaignier</ets>, <ets>mehaignier</ets>,
<ets>meshaignier</ets>, cf. It. <ets>magagnare</ets>, LL.
<ets>mahemiare</ets>, <ets>mahennare</ets>; perh. of Celtic origin; cf.
Armor. <ets>mac'ha<ntil/a</ets> to mutilate, <ets>m<amac/c'ha</ets> to
crowd, press; or cf. OHG. <ets>mang<omac/n</ets> to lack, perh. akin to
E. <ets>mangle</ets> to lacerate. Cf. <er>Mayhem</er>.]</ety>
<sn>1.</sn> <def>To deprive of the use of a limb, so as to render a
person in fighting less able either to defend himself or to annoy his
adversary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By the ancient law of England he that <qex>maimed</qex> any man
whereby he lost any part of his body, was sentenced to lose the like
part.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mutilate; to cripple; to injure; to disable; to
impair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My late <qex>maimed</qex> limbs lack wonted might.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>maimed</qex> the jurisdiction of all bishops.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To mutilate; mangle; cripple.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maim</ent><br/
<hw>Maim</hw>, <pos>n.</pos> <altsp>[Written in law language
<asp>maihem</asp>, and <asp>mayhem</asp>.]</altsp> <ety>[OF.
<ets>mehaing</ets>. See <er>Maim</er>, <pos>v.</pos>]</ety> <sn>1.</sn>
<def>The privation of the use of a limb or member of the body, by which
one is rendered less able to defend himself or to annoy his
adversary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The privation of any necessary part; a crippling;
mutilation; injury; deprivation of something essential. See
<er>Mayhem</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Surely there is more cause to fear lest the want there of be a
<qex>maim</qex> than the use of it a blemish.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A noble author esteems it to be a <qex>maim</qex> in history that
the acts of Parliament should not be recited.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maimedly</ent><br/
<hw>Maim"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a maimed
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maimedness</ent><br/
<hw>maim"ed*ness</hw>, <pos>n.</pos> <def>State of being maimed.</def>
<rj><au>Bolton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>main</ent><br/
<hw>main</hw> <pr>(m<amac/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>main</ets> hand, L. <ets>manus</ets>. See <er>Manual</er>.]</ety>
<sn>1.</sn> <def>A hand or match at dice.</def> <rj><au>Prior.</au>
<au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stake played for at dice.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The largest throw in a match at dice; a throw at
dice within given limits, as in the game of hazard.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A match at cockfighting.</def> <ldquo/My lord would
ride twenty miles . . . to see a <xex>main</xex> fought.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A main-hamper.</def> <mark>[Obs.]</mark>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Main</ent><br/
<hw>Main</hw>, <pos>n.</pos> <ety>[AS. <ets>m<ae/gen</ets> strength,
power, force; akin to OHG. <ets>magan</ets>, Icel. <ets>megin</ets>, and
to E. <ets>may</ets>, v. <root/103. See <er>May</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>Strength; force; might; violent
effort.</def> <mark>[Obs., except in certain phrases.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There were in this battle of most might and <qex>main</qex>.</q>
<rj><qau>R. of Gl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He 'gan advance,<br/
With huge force, and with importable <qex>main</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The chief or principal part; the main or most
important thing.</def> <mark>[Obs., except in special uses.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Resolved to rest upon the title of Lancaster as the
<qex>main</qex>, and to use the other two . . . but as supporters.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> Specifically: <sd>(a)</sd> <def>The great sea, as
distinguished from an arm, bay, etc. ; the high sea; the ocean.</def>
<ldquo/Struggling in the <xex>main</xex>.<rdquo/ <au>Dryden.</au>
<sd>(b)</sd> <def>The continent, as distinguished from an island; the
mainland.</def> <ldquo/Invaded the <xex>main</xex> of Spain.<rdquo/
<au>Bacon.</au> <sd>(c)</sd> <def>principal duct or pipe, as
distinguished from lesser ones; esp. <fld>(Engin.)</fld>, a principal
pipe leading to or from a reservoir; <as>as, a fire
<ex>main</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forcing main</b></col>, <cd>the delivery pipe of a
pump.</cd> -- <mcol><col><b>For the main</b></col>, <it>or</it>
<col><b>In the main</b></col></mcol>, <cd>for the most part; in the
greatest part.</cd> -- <mcol><col><b>With might and main</b></col>,
<it>or</it> <col><b>With all one's might and main</b></col></mcol>,
<cd>with all one's strength; with violent effort.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>With might and main</qex> they chased the murderous fox.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Main</ent><br/
<hw>Main</hw> <pr>(m<amac/n)</pr>, <pos>a.</pos> <ety>[From
<er>Main</er> strength, possibly influenced by OF. <ets>maine</ets>,
<ets>magne</ets>, great, L. <ets>magnus</ets>. Cf.
<er>Magnate</er>.]</ety> <sn>1.</sn> <def>Very or extremely
strong.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That current with <qex>main</qex> fury ran.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vast; huge.</def> <mark>[Obs.]</mark> <ldquo/The
<xex>main</xex> abyss.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Unqualified; absolute; entire; sheer.</def>
<mark>[Obs.]</mark> <ldquo/It's a <xex>man</xex> untruth.<rdquo/ <au>Sir
W. Scott.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Principal; chief; first in size, rank, importance,
etc.; <as>as, the <ex>main</ex> reason to go; the <ex>main</ex>
proponent</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Our <qex>main</qex> interest is to be happy as we can.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Important; necessary.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That which thou aright<br/
Believest so <qex>main</qex> to our success, I bring.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>By main force</b></col>, <cd>by mere force or sheer
force; by violent effort; <as>as, to subdue insurrection <ex>by main
force</ex></as>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>That Maine which <qex>by main force</qex> Warwick did win.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>By main strength</b></col>, <cd>by sheer strength; <as>as,
to lift a heavy weight <ex>by main strength</ex></as>.</cd> --
<col><b>Main beam</b></col> <fld>(Steam Engine)</fld>, <cd>working
beam.</cd> -- <col><b>Main boom</b></col> <fld>(Naut.)</fld>, <cd>the
boom which extends the foot of the mainsail in a fore and aft
vessel.</cd> -- <col><b>Main brace</b></col>. <sd>(a)</sd>
<fld>(Mech.)</fld> <cd>The brace which resists the chief strain. Cf.
<er>Counter brace</er>.</cd> <sd>(b)</sd> <fld>(Naut.)</fld> <cd>The
brace attached to the main yard.</cd> -- <col><b>Main center</b></col>
<fld>(Steam Engine)</fld>, <cd>a shaft upon which a working beam or side
lever swings.</cd> -- <col><b>Main chance</b></col>. <cd>See under
<er>Chance</er>.</cd> -- <col><b>Main couple</b></col>
<fld>(Arch.)</fld>, <cd>the principal truss in a roof.</cd> --
<col><b>Main deck</b></col> <fld>(Naut.)</fld>, <cd>the deck next below
the spar deck; the principal deck.</cd> -- <col><b>Main keel</b></col>
<fld>(Naut.)</fld>, <cd>the principal or true keel of a vessel, as
distinguished from the false keel.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- Principal; chief; leading; cardinal;
capital.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Main</ent><br/
<hw>Main</hw>, <pos>adv.</pos> <ety>[See <er>Main</er>,
<pos>a.</pos>]</ety> <def>Very; extremely; <as>as, <ex>main</ex>
heavy</as>.</def> <ldquo/I'm <xex>main</xex> dry.<rdquo/ <au>Foote.</au>
<mark>[Obs. or Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>main course</ent><br/
<hw>main course</hw> <pos>n.</pos> <sn>1.</sn> <def>The principal part
of a meal.</def><br/
<syn><b>Syn. --</b> entree.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Nautical)</fld> <def>A square mainsail.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>main deck</ent><br/
<hw>main deck</hw> <pos>n.</pos> <def>The uppermost sheltered deck that
runs the entire length of a large vessel.</def><br/
<syn><b>Syn. --</b> second deck.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maine</ent><br/
<hw>Maine</hw> <pr>(m<amac/n)</pr>, <pos>prop. n.</pos> <def>One of the
New England States.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maine law</b></col>, <cd>any law prohibiting the
manufacture and sale of intoxicating beverages, esp. one resembling that
enacted in the State of Maine. At present, the state of Maine sells such
beverages in its own stores.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>maine lobster</ent><br/
<hw>maine lobster</hw> <pos>n.</pos> <sn>1.</sn> <def>Any of several
cold-water lobsters with large tender claws, caught from Maine to the
Carolinas.</def><br/
<syn><b>Syn. --</b> American lobster, Northern lobster.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A lobster (<spn>Homarus americanus</spn>) found off
the Atlantic coast of North America.</def><br/
<syn><b>Syn. --</b> American lobster, Northern lobster, <spn>Homarus
americanus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>main entry word</ent><br/
<hw>main entry word</hw> <pos>n.</pos> <def>The form of a word that
heads a lexical entry and is alphabetized in a dictionary; also called
<altname>entry word</altname>, <altname>headword</altname>, and
<altname>lemma</altname>.</def><br/
<syn><b>Syn. --</b> citation form, entry word, headword,
lemma.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><note><hand/ In different languages, different wordforms, such as
cases for verbs, may be taken as the main entry word. In English
dictionaries, it is the infinitive form, but in latin dictionaries it is
usually the first person singular present.</note><br/
[<source>PJC</source>]</p>

<p><ent>main file</ent><br/
<hw>main file</hw> <pos>n.</pos> <fld>(computers)</fld> <def>A file that
is used as the authority in a given job and that is relatively
permanent.</def><br/
<syn><b>Syn. --</b> master file.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mainframe</ent><br/
<hw>main"frame`</hw> <pos>n.</pos> <fld>(Computers)</fld> <sn>1.</sn>
<def>A large digital computer serving 100-400 users and occupying a
special air-conditioned room. At any given point in development of
computer technology, the <ex>mainframe</ex> will be faster, have large
main memeory, and be more capable than a <contr>minicomputer</contr>,
which will in turn be faster and more capable than a <contr>personal
computer</contr>. The typical personal computer in 1999 is faster than a
<ex>mainframe</ex> was in 1970.</def><br/
<syn><b>Syn. --</b> mainframe computer.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The board holding the CPU and the memory forming the
central part of a computer to which the peripherals are
attached.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Main-gauche</ent><br/
<hw>Main`-gauche"</hw> <pr>(m<acr/N`g<omac/sh")</pr>, <pos>n.</pos>
<ety>[F., the left hand.]</ety> <fld>(Ancient Armor)</fld> <def>The
dagger held in the left hand, while the rapier is held in the right; --
used to parry thrusts of the adversary's rapier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Main-hamper</ent><br/
<hw>Main"-ham`per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>main</ets> hand (see <er>Main</er> a hand at dice) + E.
<ets>hamper</ets>.]</ety> <def>A hamper to be carried in the hand; a
hand basket used in carrying grapes to the press.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainland</ent><br/
<hw>Main"land`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The continent; the
principal land; -- opposed to <contr>island</contr>, or
<contr>peninsula</contr>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After the two wayfarers had crossed from the peninsula to the
<qex>mainland</qex>.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mainland China</ent><br/
<hw>mainland China</hw> <pos>n.</pos> <def>The People's Republic of
China, also called <altname>Communist China</altname>, in distinction
from <contr>Nationalist China</contr>, the government located on the
island of Taiwan. Both governments claim to represent the entire people
of China, but the People's republic is recognized as China by the United
Nationss and most of its member states.</def><br/
<syn><b>Syn. --</b> Red China, PRC, Beijing.</syn><br/
[<source>PJC</source>]</p>

<p><ent>main line</ent><br/
<hw>main line</hw> <pos>n.</pos> <def>Ahe principal route of a
transportation system, such as a railroad or bus line.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mainline</ent><br/
<hw>main"line`</hw> <pr>(m<amac/n"l<imac/n`)</pr> <pos>v. t.</pos>
<sn>1.</sn> <def>to inject (illegal drugs) into the vein; <as>as, he
preferred to <ex>mainline</ex> heroin rather than sniff
coke</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mainly</ent><br/
<hw>Main"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<ets>main</ets> strong. See <er>Main</er> strength.]</ety> <def>Very
strongly; mightily; to a great degree.</def> <mark>[Obs.]</mark>
<rj><au>Bacon. Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainly</ent><br/
<hw>Main"ly</hw>, <pos>adv.</pos> <ety>[From <ets>main</ets> principal,
chief.]</ety> <def>Principally; chiefly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainmast</ent><br/
<hw>Main"mast`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The principal mast in a ship or other vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>main office</ent><br/
<hw>main office</hw> <pos>n.</pos> <def>The office that serves as the
administrative center of an enterprise,</def><br/
<syn><b>Syn. --</b> headquarters, central office, home office.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>main memory</ent><br/
<hw>main memory</hw> <pos>n.</pos> <fld>(Computers)</fld> <def>The
memory in a computer that holds programs and data for rapid access
during execution of a program; it usually hold the largest quantity of
rapid-access storage in a computer; -- also called
<altname>RAM</altname> (<altname>random access memory</altname>. It is
contrasted to <contr>ROM</contr>, <contr>disk data storage</contr>,
<contr>cache</contr>, <contr>registers</contr> and other forms of data
storage.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mainor</ent><br/
<hw>Main"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Anglo-Norm.
<ets>meinoure</ets>, OF. <ets>manuevre</ets>. See
<er>Maneuver</er>.]</ety> <fld>(O. Eng. Law)</fld> <def>A thing stolen
found on the person of the thief.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A thief was said to be <ldquo/taken with the
<xex>mainor</xex>,<rdquo/ when he was taken with the thing stolen upon
him, that is, <xex>in his hands</xex>.</note> <rj><au>Wharton.</au>
<au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainpernable</ent><br/
<hw>Main"per*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>main</ets> hand + <ets>pernable</ets>, for <ets>prenable</ets>,
that may be taken, pregnable. See <er>Mainpernor</er>.]</ety>
<fld>(Law)</fld> <def>Capable of being admitted to give surety by
mainpernors; able to be mainprised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainpernor</ent><br/
<hw>Main"per*nor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>main</ets> hand + <ets>pernor</ets>, for <ets>preneor</ets>, a
taker, F. <ets>preneur</ets>, fr. <ets>prendre</ets> to take.]</ety>
<fld>(Law)</fld> <def>A surety, under the old writ of mainprise, for a
prisoner's appearance in court at a day.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mainpernors</xex> differ from <xex>bail</xex> in
that a man's <xex>bail</xex> may imprison or surrender him before the
stipulated day of appearance; <xex>mainpernors</xex> can do neither;
they are bound to produce him to answer all charges whatsoever.</note>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainpin</ent><br/
<hw>Main"pin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Vehicles)</fld>
<def>A kingbolt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainprise</ent><br/
<hw>Main"prise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>main</ets>
hand + <ets>prise</ets> a taking, fr. <ets>prendre</ets>, p. p.
<ets>pris</ets> to take, fr. L. <ets>prehendere</ets>,
<ets>prehensum</ets>.]</ety> <fld>(Law)</fld> <sd>(a)</sd> <def>A writ
directed to the sheriff, commanding him to take sureties, called
<xex>mainpernors</xex>, for the prisoner's appearance, and to let him go
at large. This writ is now obsolete.</def> <au>Wharton.</au>
<sd>(b)</sd> <def>Deliverance of a prisoner on security for his
appearance at a day.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainprise</ent><br/
<hw>Main"prise</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mainprised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mainprising</conjf>.]</vmorph> <fld>(Law)</fld> <def>To suffer to
go at large, on his finding sureties, or mainpernors, for his appearance
at a day; -- said of a prisoner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>main road</ent><br/
<hw>main road</hw> <pos>n.</pos> <def>A major road for any form of motor
transport.</def><br/
<syn><b>Syn. --</b> highway.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>main rotor</ent><br/
<hw>main rotor</hw> <pos>n.</pos> <fld>(Aviation)</fld> <def>The
assembly of large rotating airfoils (blades) on a helicopter that
produce the lift to support the helicopter in the air.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mains</ent><br/
<hw>mains</hw> <pr>(m<amac/nz)</pr>, <pos>n.</pos> <ety>[Scot. See
<er>Manse</er>.]</ety> <def>The farm attached to a mansion house; a
manse.</def> <mark>[Scot. or Brit. dial.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mains</ent><br/
<hw>mains</hw> <pr>(m<amac/nz)</pr>, <pos>n.</pos>
<fld>(Electricity)</fld> <def>The source of electrical power in a
building; the wiring system of a building.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mainsail</ent><br/
<hw>Main"sail`</hw> <pr>(m<amac/n"s<amac/l`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>The principal sail in a ship or other
vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[They] hoised up the <qex>mainsail</qex> to the wind.</q>
<rj><qau> Acts xxvii. 40.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>mainsail</xex> of a ship is extended upon a
yard attached to the mainmast, and that of a sloop or schooner upon the
boom.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>main sequence</ent><br/
<hw>main" se`quence</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Astronomy)</fld> <def>That region on a two-dimensional graph of
luminosity versus temperature for stars (the <ecol><b>Herzsprung-Russel
diagram</b></ecol>), which runs from high temperature and high
luminosity to low temperature and low luminosity, in which most of the
stars (plotted as points on the diagram) are found. A normal star such
as the earth's sun will spend most of its time over billions of years
within this region of temperature and luminosity, as it progressively
converts more of its original hydrogen into heavier elements. After the
hydrogen is consumed, a star may become a <er>red giant</er> or evolve
into other types of star not within the <ex>main sequence</ex>
region.</def><br/
[<source>PJC</source>]</p>

<p><ent>mainsheet</ent><br/
<hw>main"sheet`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>One of the ropes by which the mainsail is hauled aft and
trimmed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mainspring</ent><br/
<hw>main"spring`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principal or
most important spring in a piece of mechanism, especially the moving
spring of a watch or clock or the spring in a gunlock which impels the
hammer.</def> <specif>Hence:</specif> <mark>(Fig.)</mark> <def>The chief
or most powerful motive; the efficient cause of action; <as>as, the
<ex>mainspring</ex> of action</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mainstay</ent><br/
<hw>Main"stay`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>The stay extending from the foot of the foremast
to the maintop.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Main support; principal dependence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The great <qex>mainstay</qex> of the Church.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mainstream</ent><br/
<hw>main"stream`</hw> <pos>n.</pos> <def>The prevailing opinion or
practise; <as>as, the doctor avoided using therapies outside the
<ex>mainstream</ex> of modern medical practice</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>mainstream</ent><br/
<hw>main"stream`</hw> <pos>v. t.</pos> <fld>(Education)</fld> <def>TO
place (a student) in regular school classes; -- used especially of
mentally or physically handicapped children.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mainstreamed</ent><br/
<hw>main"streamed`</hw> <pos>adj.</pos> <fld>(Education)</fld>
<def>Placed in regular school classes; -- of the handicapped.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>main street</ent><br/
<hw>main street</hw> <pos>n.</pos> <sn>1.</sn> <def>A main thoroughfare,
usually one in a small town having the largest concentration of retail
businesses.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>(Fig.)</mark> <def>The
attitudes, environment, or life style of a small town; -- usually
capitalized, and often used attributively; <as>as, <ex>Main Street</ex>
attitudes toward Washington</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mainswear</ent><br/
<hw>Main"swear`</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>m<amac/nswerian</ets> to forswear; <ets>m<amac/n</ets> sin, crime +
<ets>swerian</ets> to swear.]</ety> <def>To swear falsely.</def>
<mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maintain</ent><br/
<hw>Main*tain</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Maintained</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Maintaining</conjf>.]</vmorph> <ety>[OE.
<ets>maintenen</ets>, F. <ets>maintenir</ets>, properly, to hold by the
hand; <ets>main</ets> hand (L. <ets>manus</ets>) + F. <ets>tenir</ets>
to hold (L. <ets>tenere</ets>). See <er>Manual</er>, and Tenable.]</ety>
<sn>1.</sn> <def>To hold or keep in any particular state or condition;
to support; to sustain; to uphold; to keep up; not to suffer to fail or
decline; <as>as, to <ex>maintain</ex> a certain degree of heat in a
furnace; to <ex>maintain</ex> a fence or a railroad; to
<ex>maintain</ex> the digestive process or powers of the stomach; to
<ex>maintain</ex> the fertility of soil; to <ex>maintain</ex> present
reputation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To keep possession of; to hold and defend; not to
surrender or relinquish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God values . . . every one as he <qex>maintains</qex> his
post.</q> <rj><qau>Grew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To continue; not to suffer to cease or
fail.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Maintain</qex> talk with the duke.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To bear the expense of; to support; to keep up; to
supply with what is needed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Glad, by his labor, to <qex>maintain</qex> his life.</q>
<rj><qau>Stirling.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>maintains</qex> one vice would bring up two
children.</q> <rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To affirm; to support or defend by
argument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is hard to <qex>maintain</qex> the truth, but much harder to be
maintained by it.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To assert; vindicate; allege. See
<er>Assert</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maintainable</ent><br/
<hw>Main*tain"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
maintained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maintainer</ent><br/
<hw>Main*tain"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
maintains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maintainor</ent><br/
<hw>Main*tain"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mainteneor</ets>, F. <ets>mainteneur</ets>.]</ety> <fld>(Crim.
Law)</fld> <def>One who, not being interested, maintains a cause
depending between others, by furnishing money, etc., to either
party.</def> <rj><au>Bouvier.</au> <au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maintenance</ent><br/
<hw>Main"te*nance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>maintenance</ets>. See <er>Maintain</er>.]</ety> <sn>1.</sn>
<def>The act of maintaining; sustenance; support; defense;
vindication.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whatsoever is granted to the church for God's honor and the
<qex>maintenance</qex> of his service, is granted to God.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which maintains or supports; means of
sustenance; supply of necessaries and conveniences.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those of better fortune not making learning their
<qex>maintenance</qex>.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Crim. Law)</fld> <def>An officious or unlawful
intermeddling in a cause depending between others, by assisting either
party with money or means to carry it on. See <er>Champerty</er>.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Those actions required for the care of machinery, a
building, etc., to keep it clean and in proper functioning condition,
and to prevent or forestall damage due to normal use.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>Payments, such as child support or alimony, to a
dependent child not living with one or to a divorced wife.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Cap of maintenance</b></col>. <cd>See under
<er>Cap</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>maintenance man</ent><br/
<hw>maintenance man</hw> <pos>n.</pos> <def>A worker, usually in an
enterprise or apartment building, whose job is to repair damaged parts
of a building or its fixtures, and sometimes to make improvements or
other changes to the building.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maintenance staff</ent><br/
<hw>maintenance staff</hw> <pos>n.</pos> <def>Those persons in a
business responsible for maintaining the physical plant in good
condition.</def><br/
<syn><b>Syn. --</b> service staff, maintenance crew.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maintop</ent><br/
<hw>main"top`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The platform about the head of the mainmast in square-rigged
vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>main-topmast</ent><br/
<hw>main-topmast</hw> <pos>n.</pos> <def>the mast next above the
mainmast.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>main-topsail</ent><br/
<hw>main-topsail</hw> <pos>n.</pos> <def>a topsail set on the
mainmast.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Main yard</ent><br/
<hw>Main" yard`</hw> <pr>(?)</pr>. <fld>(Naut.)</fld> <def>The yard on
which the mainsail is extended, supported by the mainmast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maioid</ent><br/
<hw>Mai"oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Maia</ets> +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Of or pertaining to the
genus <gen>Maia</gen>, or family <fam>Maiadeae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maister</ent><br/
<hw>Mais"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Master.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer. Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maister</ent><br/
<hw>Mais"ter</hw>, <pos>a.</pos> <def>Principal; chief.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maistry</ent><br/
<ent>Maistrie</ent><br/
<ent>Maistre</ent><br/
<mhw>{ <hw>Mais"tre</hw> <pr>(?)</pr>, <hw>Mais"trie</hw>,
<hw>Mais"try</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>Mastery;
superiority; art. See <er>Mastery</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maistress</ent><br/
<hw>Mais"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mistress.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maithes</ent><br/
<hw>Mai"thes</hw> <pr>(m<amac/"th<ecr/s)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>Same as <er>Maghet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maitre d'hotel</ent><br/
<mhw><hw>mai`tre d'ho*tel"</hw>, <hw>ma<icir/`tre
d'h<ocir/*tel`</hw></mhw> <pr>(m<amac/"t<etil/r d<omac/*t<ecr/l" or
m<amac/"tr<ucr/ d<omac/*t<ecr/l")</pr>; <plu><it>pl.</it> <plw>maitres
d'hotel</plw></plu>. <pos>n.</pos> <sn>1.</sn> <def>A
headwaiter.</def><br/
<syn><b>Syn. --</b> captain, head waiter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The manager or owner of a hotel.</def><br/
[<source>PJC</source>]</p>

<p><ent>maize</ent><br/
<hw>maize</hw> <pr>(m<amac/z)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>maiz</ets>. fr. <ets>mahiz</ets> or <ets>mahis</ets>, is the
language of the Island of Haiti.]</ety> <fld>(Bot.)</fld> <def>A large
species of American grass of the genus <gen>Zea</gen> (<spn>Zea
Mays</spn>), widely cultivated as a forage and food plant; Indian corn,
commonly called <altname>corn</altname>. Also, its seed, growing on
cobs, and used as food for men and animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maize eater</b></col> <fld>(Zool.)</fld>, <cd>a South
American bird of the genus <gen>Pseudoleistes</gen>, allied to the
troupials.</cd> -- <col><b>Maize yellow</b></col>, <cd>a delicate pale
yellow.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>majagua</ent><br/
<hw>majagua</hw> <pos>n.</pos> <sn>1.</sn> <def>A shrubby tree
(<spn>Hibiscus tiliaceus</spn>) widely distributed along tropical
shores, which yields a light tough wood used for canoe outriggers and a
fiber used for cordage and caulk; it is often cultivated for
ornament.</def><br/
<syn><b>Syn. --</b> mahoe, mahagua, balibago, purau, <spn>Hibiscus
tiliaceus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An erect forest tree (<spn>Hibiscus elatus</spn>) of
Cuba and Jamaica having variably hairy leaves and orange-yellow or
orange-red flowers; it yields a moderately dense timber for cabinetwork
and gunstocks.</def><br/
<syn><b>Syn. --</b> Cuban bast, blue mahoe, mahoe, mahagua,
<spn>Hibiscus elatus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maja squinado</ent><br/
<hw>maja squinado</hw> <pos>n.</pos> <ety>[species name.]</ety> <def>A
large European spider crab.</def><br/
<syn><b>Syn. --</b> European spider crab, king crab, <spn>Maja
squinado</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Majestatal</ent><br/
<ent>Majestatic</ent><br/
<mhw>{ <hw>Maj`es*tat"ic</hw> <pr>(?)</pr>, <hw>Maj`es*tat"*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Majestic.</def>
<mark>[Obs.]</mark> <rj><au>E. Pocock.</au> <au>Dr. J.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majestic</ent><br/
<hw>Ma*jes"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Majesty</er>.]</ety> <def>Possessing or exhibiting majesty; of
august dignity, stateliness, or imposing grandeur; lofty; noble;
grand.</def> <ldquo/The <xex>majestic</xex> world.<rdquo/ <au>Shak.</au>
<ldquo/Tethys' grave <xex>majestic</xex> pace.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The least portions must be of the epic kind; all must be grave,
<qex>majestic</qex>, and sublime.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- August; splendid; grand; sublime; magnificent;
imperial; regal; pompous; stately; lofty; dignified; elevated.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 885 --></p>

<p><ent>Majestical</ent><br/
<hw>Ma*jes"tic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Majestic.</def>
<rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An older architecture, greater, cunninger, more
<qex>majestical</qex>.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ma*jes"tic*al*ly</wf>, <pos>adv.</pos> --
<wf>Ma*jes"tic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majesticness</ent><br/
<hw>Ma*jes"tic*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being majestic.</def> <rj><au>Oldenburg.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majesty</ent><br/
<hw>Maj"es*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Majesties</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>magestee</ets>,
F. <ets>majest<eacute/</ets>, L. <ets>majestas</ets>, fr. an old compar.
of <ets>magnus</ets> great. See <er>Major</er>, <er>Master</er>.]</ety>
<def>The dignity and authority of sovereign power; quality or state
which inspires awe or reverence; grandeur; exalted dignity, whether
proceeding from rank, character, or bearing; imposing loftiness;
stateliness; -- usually applied to the rank and dignity of
sovereigns.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord reigneth; he is clothed with <qex>majesty</qex>.</q>
<rj><qau>Ps. xciii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No sovereign has ever represented the <qex>majesty</qex> of a
great state with more dignity and grace.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, used with the possessive pronoun, the title
of an emperor, king or queen; -- in this sense taking a plural; <as>as,
their <ex>majesties</ex> attended the concert</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In all the public writs which he [Emperor Charles V.] now issued
as King of Spain, he assumed the title of <qex>Majesty</qex>, and
required it from his subjects as a mark of respect. Before that time all
the monarchs of Europe were satisfied with the appellation of
<qex>Highness</qex> or <qex>Grace</qex>.</q>
<rj><qau>Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Dignity; elevation of manner or style.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majidae</ent><br/
<hw>Majidae</hw> <pos>prop. n.</pos> <def>A natural family comprising
the spider crabs.</def><br/
<syn><b>Syn. --</b> family <fam>Majidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Majolica</ent><br/
<hw>Ma*jol"i*ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety> <def>A
kind of pottery, with opaque glazing and showy decoration, which reached
its greatest perfection in Italy in the 16th century.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is said to be derived from Majorca, which was
an early seat of this manufacture.</note> <rj><au>Heyse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Major</ent><br/
<hw>Ma"jor</hw> <pr>(?)</pr>, <ety>[L. <ets>major</ets>, compar. of
magnus great: cf. F. <ets>majeur</ets>. Cf. <er>Master</er>,
<er>Mayor</er>, <er>Magnitude</er>, <er>More</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>Greater in number, quantity, or extent; <as>as, the
<ex>major</ex> part of the assembly; the <ex>major</ex> part of the
revenue; the <ex>major</ex> part of the territory.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of greater dignity; more important.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of full legal age; adult.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>Greater by a semitone, either in
interval or in difference of pitch from another tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Major key</b></col> <fld>(Mus.)</fld>, <cd>a key in which
one and two, two and three, four and five, five and six and seven, make
major seconds, and three and four, and seven and eight, make minor
seconds.</cd> -- <col><b>Major offense</b></col> <fld>(Law)</fld>,
<cd>an offense of a greater degree which contains a lesser offense, as
murder and robbery include assault.</cd> -- <col><b>Major
scale</b></col> <fld>(Mus.)</fld>, <cd>the natural diatonic scale, which
has semitones between the third and fourth, and seventh and fourth, and
seventh and eighth degrees; the scale of the major mode, of which the
third is major. See <er>Scale</er>, and <er>Diatonic</er>.</cd> --
<col><b>Major second</b></col> <fld>(Mus.)</fld>, <cd>a second between
whose tones is a difference in pitch of a step.</cd> -- <col><b>Major
sixth</b></col> <fld>(Mus.)</fld>, <cd>a sixth of four steps and a half
step. In major keys the third and sixth from the key tone are major.
Major keys and intervals, as distinguished from minors, are more
cheerful.</cd> -- <col><b>Major third</b></col> <fld>(Mus.)</fld>, <cd>a
third of two steps.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Major</ent><br/
<hw>Ma"jor</hw>, <pos>n.</pos> <ety>[F. <ets>major</ets>. See
<er>Major</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <fld>(Mil.)</fld>
<def>An officer next in rank above a captain and next below a lieutenant
colonel; the lowest field officer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A person of full age.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Logic)</fld> <def>That premise which contains the
major term. It its the first proposition of a regular syllogism; as: No
unholy person is qualified for happiness in heaven [the major]. Every
man in his natural state is unholy [minor]. Therefore, no man in his
natural state is qualified for happiness in heaven [conclusion or
inference].</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In hypothetical syllogisms, the hypothetical premise is
called the <xex>major</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[LL. See <er>Major</er>.]</ety> <def>A mayor.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majorana</ent><br/
<hw>Majorana</hw> <pos>prop. n.</pos> <def>A small genus of herbs
usually included in the genus <gen>Origanum</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Majorana</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Majorat</ent><br/
\'d8<hw>Ma`jo`rat"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>majorat</ets>, LL. <ets>majoratus</ets>. See <er>Major</er>,
<pos>a.</pos>, and cf. <er>Majorate</er>.]</ety> <sn>1.</sn> <def>The
right of succession to property according to age; -- so termed in some
of the countries of continental Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(French Law)</fld> <def>Property, landed or funded,
so attached to a title of honor as to descend with it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majorate</ent><br/
<hw>Ma"jor*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office or rank
of a major.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majorate</ent><br/
<hw>Ma"jor*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>majorare</ets> to augment. See <er>Major</er>, <pos>a.</pos>]</ety>
<def>To augment; to increase.</def> <mark>[Obs.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majoration</ent><br/
<hw>Ma`jor*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Increase;
enlargement.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>major axis</ent><br/
<hw>major axis</hw> <pos>n.</pos> <fld>(Geom.)</fld>, <def>The greater
axis of a geometrical figure.</def> <specif>Especially</specif>:
<def>the longest axis of an ellipse or ellipsoid, which passes through
the two foci. See <er>Focus</er>, <pos>n.</pos>, 2.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Majorcan</ent><br/
<hw>Ma*jor"can</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to Majorca.</def> -- <def2><pos>n.</pos> <def>A native or
inhabitant of Majorca.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>major diatonic scale</ent><br/
<hw>major diatonic scale</hw> <pos>n.</pos> <fld>(Mus.)</fld>, <def>The
natural diatonic scale, which has semitones between the third and
fourth, and seventh and eighth notes, and whole tones between the other
notes; the scale of the major mode, of which the third is major; also
called <altname>major scale</altname>. See <er>Scale</er>, and
<er>Diatonic</er>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Major-domo</ent><br/
<hw>Ma`jor-do"mo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>mayordomo</ets>, or It. <ets>maggiordomo</ets>; both fr. LL.
<ets>majordomus</ets>; L. <ets>major</ets> greater + <ets>domus</ets>
house.]</ety> <def>A man who has authority to act, within certain
limits, as master of the house; a steward; also, a chief minister or
officer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>major form class</ent><br/
<hw>major form class</hw> <pos>n.</pos> <fld>(Grammar)</fld> <def>Any of
the <er>parts of speech</er> of traditional grammar.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Major general</ent><br/
<hw>Ma"jor gen"er*al</hw> <pr>(?)</pr>. <def>An officer of the army
holding a rank next above that of brigadier general and next below that
of lieutenant general, and who usually commands a division or a
corps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majority</ent><br/
<hw>Ma*jor"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Majorities</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>majorit<eacute/</ets>. See <er>Major</er>.]</ety> <sn>1.</sn>
<def>The quality or condition of being major or greater;
superiority.</def> Specifically: <sd>(a)</sd> <def>The military rank of
a major.</def> <sd>(b)</sd> <def>The condition of being of full age, or
authorized by law to manage one's own affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The greater number; more than half; <as>as, a
<ex>majority</ex> of mankind; a <ex>majority</ex> of the votes
cast.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. L. <ets>majores</ets>.]</ety> <def>Ancestors;
ancestry.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The amount or number by which one aggregate exceeds
all other aggregates with which it is contrasted; especially, the number
by which the votes for a successful candidate exceed those for all other
candidates; <as>as, he is elected by a <ex>majority</ex> of five hundred
votes</as>. See <er>Plurality</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To go over to the majority</b></col> <it>or</it>
<col><b>To join the majority</b></col></mcol>, <cd>to die.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>majority leader</ent><br/
<hw>majority leader</hw> <pos>n.</pos> <fld>(Politics)</fld> <def>The
leader of the majority party in a legislature. Compare <contr>minority
leader</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>majority rule</ent><br/
<hw>majority rule</hw> <pos>n.</pos> <def>The rule or doctrine that the
numerical majority{2} of an organized group can make decisions binding
on the whole group; <as>as, our club makes decisions by <ex>majority
rule</ex>.</as>. Contrasted with <contr>unanimous consent</contr>, or
decision by a <contr>decree</contr> of a single person or small
committee forming part of an organization.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>major league</ent><br/
<hw>major league</hw> <pos>n.</pos> <fld>(Sports)</fld> <def>The most
important league{2} in any sport (especially baseball); contrasted with
<contr>minor league</contr>. Its teams are more competent, its members
are paid more, and its games attract more interest and publicity, than
those of a minor league.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>major league</ent><br/
<ent>major-league</ent><br/
<mhw><hw>major-league</hw>, <hw>major league</hw></mhw> <pos>a.</pos>
<sn>1.</sn> <def>Of or pertaining to a <er>major league</er>; <as>as,
<ex>major-league</ex> football rules</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Among the best or most important of its class;
<as>as, a <ex>major-league</ex> computer manufacturer</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>major-league team</ent><br/
<ent>major-league club</ent><br/
<mhw><hw>major-league club</hw>, <hw>major-league team</hw></mhw>
<pos>n.</pos> <def>A sports team that plays in a major league.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>major leaguer</ent><br/
<hw>major leaguer</hw> <pos>n.</pos> <def>A member of a major-league
baseball team.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>major power</ent><br/
<hw>major power</hw> <pos>n.</pos> <def>A nation powerful enough to
influence events throughout the world.</def><br/
<syn><b>Syn. --</b> world power, great power, power.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>major premise</ent><br/
<hw>major premise</hw> <pos>n.</pos> <fld>(Logic)</fld>, <def>That
premise of a syllogism that contains the major term (which is the
predicate of the conclusion). Contrasted to <contr>minor
premise</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Majorship</ent><br/
<hw>Ma"jor*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office of
major.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>majors</ent><br/
<hw>majors</hw> <pos>n. pl.</pos> <def>The teams in the major
leagues.</def><br/
<syn><b>Syn. --</b> major leagues, big leagues.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>major suit</ent><br/
<hw>major suit</hw> <pos>n.</pos> <fld>(Bridge)</fld> <def>A suit of
playing cards which has higher scoring value; specifically, either
spades or hearts. Contrasted with a <contr>minor suit</contr>, being
either diamonds or clubs.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>major term</ent><br/
<hw>major term</hw> <pos>n.</pos> <fld>(Logic)</fld>, <def>That term of
a syllogism which forms the predicate of the conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majoun</ent><br/
<hw>Maj"oun</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Madjoun</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majusculae</ent><br/
\'d8<hw>Ma*jus"cu*lae</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.,
fem. pl. fr. <ets>majusculus</ets> somewhat greater or great, dim. of
<ets>major</ets>, <ets>majus</ets>. See <er>Major</er>.]</ety>
<fld>(Palaeography)</fld> <def>Capital letters, as found in manuscripts
of the sixth century and earlier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Majuscule</ent><br/
<hw>Ma*jus"cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>majuscule</ets>. See <er>Majusculae</er>.]</ety> <def>A capital
letter; especially, one used in ancient manuscripts. See
<er>Majusculae</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Majuscule writing</b></col>, <cd>writing composed wholly
of capital letters, especially the style which prevailed in Europe from
the third to the sixth century.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>makable</ent><br/
<hw>mak"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Makalu</ent><br/
<hw>Makalu</hw> <pos>prop. n.</pos> <def>A mountain in Nepal and Tibet,
27,824 feet high.</def> <comm>According to WordNet, it is 27,790 feet
high.</comm><br/
<syn><b>Syn. --</b> Makalu I.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>makaron</ent><br/
<hw>mak"a*ron</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Macaroon</er>, 2.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>make</ent><br/
<hw>make</hw> <pr>(m<amac/k)</pr>, <pos>n.</pos> <ety>[AS.
<ets>maca</ets>, <ets>gemaca</ets>. See <er>Match</er>.]</ety> <def>A
companion; a mate; often, a husband or a wife.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For in this world no woman is<br/
Worthy to be my <qex>make</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>make</ent><br/
<hw>make</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>made</conjf> <pr>(m<amac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>making</conjf>.]</vmorph> <ety>[OE. <ets>maken</ets>,
<ets>makien</ets>, AS. <ets>macian</ets>; akin to OS.
<ets>mak<?/n</ets>, OFries. <ets>makia</ets>, D. <ets>maken</ets>, G.
<ets>machen</ets>, OHG. <ets>mahh<?/n</ets> to join, fit, prepare, make,
Dan. <ets>mage</ets>. Cf. <er>Match</er> an equal.]</ety> <sn>1.</sn>
<def>To cause to exist; to bring into being; to form; to produce; to
frame; to fashion; to create.</def> Hence, in various specific uses or
applications: <sd>(a)</sd> <def>To form of materials; to cause to exist
in a certain form; to construct; to fabricate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . fashioned it with a graving tool, after he had
<qex>made</qex> it a molten calf.</q> <rj><qau>Ex. xxxii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To produce, as something artificial, unnatural, or
false; -- often with <xex>up</xex>; <as>as, to <ex>make</ex> up a
story</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And Art, with her contending, doth aspire<br/
To excel the natural with <qex>made</qex> delights.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To bring about; to bring forward; to be the cause
or agent of; to effect, do, perform, or execute; -- often used with a
noun to form a phrase equivalent to the simple verb that corresponds to
such noun; as, to <xex>make</xex> complaint, for to complain; to
<xex>make</xex> record of, for to record; to <xex>make</xex> abode, for
to abide, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Call for Samson, that he may <qex>make</qex> us sport.</q>
<rj><qau>Judg. xvi. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wealth <qex>maketh</qex> many friends.</q> <rj><qau>Prov. xix.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will neither plead my age nor sickness in excuse of the faults
which I have <qex>made</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To execute with the requisite formalities; as, to
<xex>make</xex> a bill, note, will, deed, etc.</def> <sd>(e)</sd>
<def>To gain, as the result of one's efforts; to get, as profit; to make
acquisition of; to have accrue or happen to one; <as>as, to
<ex>make</ex> a large profit; to <ex>make</ex> an error; to
<ex>make</ex> a loss; to <ex>make</ex> money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He accuseth Neptune unjustly who <qex>makes</qex> shipwreck a
second time.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>To find, as the result of calculation or
computation; to ascertain by enumeration; to find the number or amount
of, by reckoning, weighing, measurement, and the like; as, he
<xex>made</xex> the distance of; to travel over; <as>as, the ship
<ex>makes</ex> ten knots an hour; he <ex>made</ex> the distance in one
day</as>.</def> <sd>(h)</sd> <def>To put in a desired or desirable
condition; to cause to thrive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who <qex>makes</qex> or ruins with a smile or frown.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to be or become; to put into a given state
verb, or adjective; to constitute; <as>as, to <ex>make</ex> known; to
<ex>make</ex> public; to <ex>make</ex> fast.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who <qex>made</qex> thee a prince and a judge over us?</q>
<rj><qau>Ex. ii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>See, I have <qex>made</qex> thee a god to Pharaoh.</q>
<rj><qau>Ex. vii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When used reflexively with an adjective, the reflexive
pronoun is often omitted; as, to <xex>make</xex> merry; to
<xex>make</xex> bold; to <xex>make</xex> free, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to appear to be; to constitute
subjectively; to esteem, suppose, or represent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is not that goose and ass that Valla would <qex>make</qex>
him.</q> <rj><qau>Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To require; to constrain; to compel; to force; to
cause; to occasion; -- followed by a noun or pronoun and
infinitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the active voice the <xex>to</xex> of the infinitive
is usually omitted.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>make</qex> them hear my words.</q> <rj><qau>Deut. iv.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They should be <qex>made</qex> to rise at their early hour.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To become; to be, or to be capable of being, changed
or fashioned into; to do the part or office of; to furnish the material
for; <as>as, he will <ex>make</ex> a good musician; sweet cider
<ex>makes</ex> sour vinegar; wool <ex>makes</ex> warm
clothing.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>And old cloak <qex>makes</qex> a new jerkin.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To compose, as parts, ingredients, or materials; to
constitute; to form; to amount to; <as>as, a pound of ham <ex>makes</ex>
a hearty meal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The heaven, the air, the earth, and boundless sea,<br/
<qex>Make</qex> but one temple for the Deity.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To be engaged or concerned in.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Gomez, what <qex>makest</qex> thou here, with a whole brotherhood
of city bailiffs?</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To reach; to attain; to arrive at or in sight
of.</def> <ldquo/And <xex>make</xex> the Libyan shores.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They that sail in the middle can <qex>make</qex> no land of either
side.</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To make a bed</b></col>, <cd>to prepare a bed for being
slept on, or to put it in order.</cd> -- <col><b>To make a
card</b></col> <fld>(Card Playing)</fld>, <cd>to take a trick with
it.</cd> -- <col><b>To make account</b></col>. <cd>See under
<er>Account</er>, <pos>n.</pos></cd> -- <col><b>To make account
of</b></col>, <cd>to esteem; to regard.</cd> -- <col><b>To make
away</b></col>. <sd>(a)</sd> <cd>To put out of the way; to kill; to
destroy.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If a child were crooked or deformed in body or mind, they
<qex>made</qex> him <qex>away</qex>.</q> <rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <cd>To alienate; to transfer; to make over.</cd>
<mark>[Obs.]</mark> <au>Waller.</au> -- <col><b>To make
believe</b></col>, <cd>to pretend; to feign; to simulate.</cd> --
<col><b>To make bold</b></col>, <cd>to take the liberty; to
venture.</cd> -- <col><b>To make the cards</b></col> <fld>(Card
Playing)</fld>, <cd>to shuffle the pack.</cd> -- <col><b>To make choice
of</b></col>, <cd>to take by way of preference; to choose.</cd> --
<col><b>To make danger</b></col>, <cd>to make experiment.</cd>
<mark>[Obs.]</mark> <au>Beau. & Fl.</au> -- <col><b>To make
default</b></col> <fld>(Law)</fld>, <cd>to fail to appear or
answer.</cd> -- <col><b>To make the doors</b></col>, <cd>to shut the
door.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Make the doors</qex> upon a woman's wit, and it will out at
the casement.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>- <col><b>To make free with</b></col>. <cd>See under <er>Free</er>,
<pos>a.</pos></cd> -- <col><b>To make good</b></col>. <cd>See under
<er>Good</er>.</cd> -- <col><b>To make head</b></col>, <cd>to make
headway.</cd> -- <col><b>To make light of</b></col>. <cd>See under
<er>Light</er>, <pos>a.</pos></cd> -- <col><b>To make little
of</b></col>. <sd>(a)</sd> <cd>To belittle.</cd> <sd>(b)</sd> <cd>To
accomplish easily.</cd> -- <col><b>To make love to</b></col>. <cd>See
under <er>Love</er>, <pos>n.</pos></cd> -- <col><b>To make
meat</b></col>, <cd>to cure meat in the open air.</cd> <mark>[Colloq.
Western U. S.]</mark> -- <col><b>To make merry</b></col>, <cd>to feast;
to be joyful or jovial.</cd> -- <col><b>To make much of</b></col>,
<cd>to treat with much consideration,, attention, or fondness; to value
highly.</cd> -- <col><b>To make no bones</b></col>. <cd>See under
<er>Bone</er>, <pos>n.</pos></cd> -- <col><b>To make no
difference</b></col>, <cd>to have no weight or influence; to be a matter
of indifference.</cd> -- <col><b>To make no doubt</b></col>, <cd>to have
no doubt.</cd> -- <col><b>To make no matter</b></col>, <cd>to have no
weight or importance; to make no difference.</cd> -- <col><b>To make
oath</b></col> <fld>(Law)</fld>, <cd>to swear, as to the truth of
something, in a prescribed form of law.</cd> -- <col><b>To make
of</b></col>. <sd>(a)</sd> <cd>To understand or think concerning;
<as>as, not to know what <ex>to make of</ex> the news</as>.</cd>
<sd>(b)</sd> <cd>To pay attention to; to cherish; to esteem; to
account.</cd> <ldquo/<xex>Makes</xex> she no more <xex>of</xex> me than
<xex>of</xex> a slave.<rdquo/ <au>Dryden.</au> -- <col><b>To make one's
law</b></col> <fld>(Old Law)</fld>, <cd>to adduce proof to clear one's
self of a charge.</cd> -- <col><b>To make out</b></col>. <sd>(a)</sd>
<cd>To find out; to discover; to decipher; <as>as, <ex>to make out</ex>
the meaning of a letter</as>.</cd> <sd>(b)</sd> <cd>to gain sight of; to
recognize; to discern; to descry; <as>as, as they approached the city,
he could <ex>make out</ex> the tower of the Chrysler Building</as>.</cd>
<sd>(c)</sd> <cd>To prove; to establish; <as>as, the plaintiff was
unable <ex>to make</ex> out his case</as></cd>. <sd>(d)</sd> <cd>To make
complete or exact; <as>as, he was not able <ex>to make out</ex> the
money</as>.</cd> <sd>(d)</sd> <cd>to write out; to write down; -- used
especially of a bank check or bill; <as>as, he <ex>made out</ex> a check
for the cost of the dinner; the workman <ex>made out</ex> a bill and
handed it to him</as>.</cd> -- <col><b>To make over</b></col>, <cd>to
transfer the title of; to convey; to alienate; <as>as, he <ex>made
over</ex> his estate in trust or in fee</as>.</cd> -- <col><b>To make
sail</b></col>. <fld>(Naut.)</fld> <sd>(a)</sd> <cd>To increase the
quantity of sail already extended</cd>. <sd>(b)</sd> <cd>To set
sail.</cd> -- <col><b>To make shift</b></col>, <cd>to manage by
expedients; <as>as, they <ex>made shift</ex> to do without it</as>.</cd>
<mark>[Colloq.]</mark>. -- <col><b>To make sternway</b></col>, <cd>to
move with the stern foremost; to go or drift backward.</cd> --
<col><b>To make strange</b></col>, <cd>to act in an unfriendly manner or
as if surprised; to treat as strange; <as>as, <ex>to make strange</ex>
of a request or suggestion</as>.</cd> -- <col><b>To make suit
to</b></col>, <cd>to endeavor to gain the favor of; to court.</cd> --
<col><b>To make sure</b></col>. <cd>See under <er>Sure</er>.</cd> --
<col><b>To make up</b></col>. <sd>(a)</sd> <cd>To collect into a sum or
mass; <as>as, <ex>to make up</ex> the amount of rent; <ex>to make
up</ex> a bundle or package</as>.</cd> <sd>(b)</sd> <cd>To reconcile; to
compose; <as>as, <ex>to make up</ex> a difference or quarrel</as>.</cd>
<sd>(c)</sd> <cd>To supply what is wanting in; to complete; <as>as, a
dollar is wanted <ex>to make up</ex> the stipulated sum</as></cd>.
<sd>(d)</sd> <cd>To compose, as from ingredients or parts; to shape,
prepare, or fabricate; <as>as, <ex>to make up</ex> a mass into pills;
<ex>to make up</ex> a story</as>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>He was all <qex>made up</qex> of love and charms!</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <cd>To compensate; to make good; <as>as, <ex>to make
up</ex> a loss</as>.</cd> <sd>(f)</sd> <cd>To adjust, or to arrange for
settlement; <as>as, <ex>to make up</ex> accounts</as></cd>. <sd>(g)</sd>
<cd>To dress and paint for a part, as an actor; <as>as, he was well
<ex>made up</ex></as>.</cd> -- <col><b>To make up a face</b></col>,
<cd>to distort the face as an expression of pain or derision.</cd> --
<col><b>To make up one's mind</b></col>, <cd>to reach a mental
determination; to resolve.</cd> -- <mcol><col><b>To make way</b></col>,
<it>or</it> <col><b>To make one's way</b></col></mcol>. <sd>(a)</sd>
<cd>To make progress; to advance.</cd> <sd>(b)</sd> <cd>To open a
passage; to clear the way</cd>. -- <col><b>To make words</b></col>,
<cd>to multiply words.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Make</ent><br/
<hw>Make</hw> <pr>(m<amac/k)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
act in a certain manner; to have to do; to manage; to interfere; to be
active; -- often in the phrase <xex>to meddle or make</xex>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A scurvy, jack-a-nape priest to meddle or <qex>make</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To proceed; to tend; to move; to go; <as>as, he
<ex>made toward home</ex>; <ex>the tiger made</ex> at the
sportsmen.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly, authors used <xex>to make on</xex>, <xex>to
make forth</xex>, <xex>to make about</xex>; but these phrases are
obsolete. We now say, <xex>to make at</xex>, <xex>to make away</xex>,
<xex>to make for</xex>, <xex>to make off</xex>, <xex>to make
toward</xex>, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tend; to contribute; to have effect; -- with
<xex>for</xex> or <xex>against</xex>; <as>as, it <ex>makes</ex> for his
advantage</as>.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Follow after the things which <qex>make</qex> for peace.</q>
<rj><qau>Rom. xiv. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Considerations infinite<br/
Do <qex>make</qex> against it.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To increase; to augment; to accrue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To compose verses; to write poetry; to
versify.</def> <mark>[Archaic]</mark> <rj><au>Chaucer.
Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To solace him some time, as I do when I <qex>make</qex>.</q>
<rj><qau>P. Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>To make as if</b></col>, <it>or</it> <col><b>To
make as though</b></col></mcol>, <cd>to pretend that; to make show that;
to make believe (see under <er>Make</er>, <pos>v. t.</pos>).</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Joshua and all Israel <qex>made as if</qex> they were beaten
before them, and fled.</q> <rj><qau>Josh. viii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My lord of London <qex>maketh as though</qex> he were greatly
displeased with me.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To make at</b></col>, <cd>to go toward hastily, or in a
hostile manner; to attack.</cd> -- <col><b>To make away with</b></col>.
<sd>(a)</sd> <cd>To carry off.</cd> <sd>(b)</sd> <cd>To transfer or
alienate; hence, to spend; to dissipate</cd>. <sd>(c)</sd> <cd>To kill;
to destroy.</cd> -- <col><b>To make off</b></col>, <cd>to go away
suddenly.</cd> -- <col><b>To make out</b></col>, <cd>to succeed; to
manage oneself; to be able at last; to make shift; <as>as, he <ex>made
out</ex> to reconcile the contending parties; after the earthquake they
<ex>made out</ex> all right</as>.</cd> <sd>(b)</sd> <cd>to engage in
fond caresses; to hug and kiss; to neck; -- of courting couples or
individuals (for individuals, used with <ptcl>with</ptcl>); <as>as, they
<ex>made out</ex> on a bench in the park; he was <ex>making out</ex>
with the waitress in the kitchen</as></cd> <mark>[informal]</mark> --
<col><b>To make up</b></col>, <cd>to become reconciled or friendly.</cd>
-- <col><b>To make up for</b></col>, <cd>to compensate for; to supply an
equivalent for.</cd> -- <col><b>To make up to</b></col>. <sd>(a)</sd>
<cd>To approach; <as>as, a suspicious boat <ex>made up to</ex>
us</as>.</cd> <sd>(b)</sd> <cd>To pay addresses to; to make love
to.</cd> -- <col><b>To make up with</b></col>, <cd>to become reconciled
to.</cd> <mark>[Colloq.]</mark> -- <col><b>To make with</b></col>,
<cd>to concur or agree with.</cd> <au>Hooker.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Make</ent><br/
<hw>Make</hw>, <pos>n.</pos> <def>Structure, texture, constitution of
parts; construction; shape; form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It our perfection of so frail a <qex>make</qex><br/
As every plot can undermine and shake?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>On the make</b></col>, <sd>(a)</sd> <cd>bent upon making
great profits; greedy of gain.</cd> <mark>[Low, U. S.]</mark></cs>
<sd>(b)</sd> <cd>seeking higher social status or a higher employment
position.</cd> <sd>(c)</sd> <cd>seeking a sexual partner; looking for
sexual adventure.</cd> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Make and break</ent><br/
<hw>Make and break</hw>. <fld>(Elec.)</fld> <def>Any apparatus for
making and breaking an electric circuit; a circuit breaker.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Makebate</ent><br/
<hw>Make"bate`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Make</ets>,
v. + <ets>bate</ets> a quarrel.]</ety> <def>One who excites contentions
and quarrels.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>make-belief</ent><br/
<hw>make"-be*lief`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A feigning to
believe; make believe.</def> <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>make believe</ent><br/
<hw>make" be*lieve`</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To pretend;
-- often used with <ptcl>that</ptcl>, but often having the that omitted;
<as>as, he <ex>made believe</ex> he didn't hear her; or he <ex>made
believe</ex> that he didn't hear her</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>make-believe</ent><br/
<hw>make"-be*lieve`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A feigning to
believe, as in the play of children; a mere pretense; a fiction; an
invention.</def> <ldquo/Childlike <xex>make-believe</xex>.<rdquo/
<rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To forswear self-delusion and <qex>make-believe</qex>.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Make-believe</ent><br/
<hw>Make"-be*lieve`</hw>, <pos>a.</pos> <sn>1.</sn> <def>Feigned;
insincere.</def> <ldquo/<xex>Make-believe</xex> reverence.<rdquo/
<rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Imaginary; <as>as, the child had a
<ex>make-believe</ex> friend to whom he often talked</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maked</ent><br/
<hw>Mak"ed</hw> <pr>(?)</pr>, <mark>obs.</mark> <mord><pos>p. p.</pos>
of <er>Make</er></mord>. <def>Made.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Make-game</ent><br/
<hw>Make"-game`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An object of
ridicule; a butt.</def> <rj><au>Godwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>make known</ent><br/
<hw>make known</hw> <pos>v. t.</pos> <def>To reveal; to disclose;
<as>as, the congressman <ex>made known</ex> his interest in the company
only after he voted on the bill</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Makeless</ent><br/
<hw>Make"less</hw>, <pos>a.</pos> <ety>[See 1st <er>Make</er>, and cf.
<er>Matchless</er>, <er>Mateless</er>.]</ety> <sn>1.</sn>
<def>Matchless.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without a mate.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Make-peace</ent><br/
<hw>Make"-peace`</hw> <pr>(-p<emac/s`)</pr>, <pos>n.</pos> <def>A
peacemaker.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maker</ent><br/
<hw>Mak"er</hw> <pr>(m<amac/k"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who makes, forms, or molds; a manufacturer; specifically, the
Creator.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The universal <qex>Maker</qex> we may praise.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The person who makes a promissory
note.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who writes verses; a poet.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/The Greeks named the poet <grk>poihth`s</grk>,
which name, as the most excellent, hath gone through other languages. It
cometh of this word <grk>poiei^n</grk>, <xex>make</xex>; wherein, I know
not whether by luck or wisdom, we Englishmen have met well the Greeks in
calling him a <xex>maker</xex>.<rdquo/</note> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To meet one's maker</b></col>, <cd>to die.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>makeready</ent><br/
<hw>makeready</hw> <pos>n.</pos> <def>The final preparation and
adjustments.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 886 --></p>

<p><ent>makeshift</ent><br/
<hw>make"shift`</hw> <pr>(m<amac/k"sh<icr/ft`)</pr>, <pos>n.</pos>
<def>That with which one makes shift; a temporary expedient, with
implication of inferiority to the more usual object or means.</def>
<rj><au>James Mill.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>I am not a model clergyman, only a decent
<qex>makeshift</qex>.</q> <rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>make-up</ent><br/
<ent>makeup</ent><br/
<mhw><hw>make"up`</hw>, <hw>make"-up`</hw></mhw>
<pr>(m<amac/k"<ucr/p`)</pr>, <pos>n.</pos> <sn>1.</sn> <sn>1.</sn>
<def>The way in which the parts of anything are put together.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The unthinking masses are necessarily teleological in their mental
<qex>make-up</qex>.</q> <rj><qau>L. F. Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The constituent parts of anything; <as>as, the
<ex>makeup</ex> of the new congress was predominantly
conservative</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Cosmetics applied to the face, such as
<stype>lipstick</stype>, <stype>facial power</stype>, or <stype>eye
shadow</stype>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>The aggregate of cosmetics and costume worn by an
actor.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>The effect or appearance of the wearing of makeup
(in senses 3 or 4); often, the way in which an actor is dressed,
painted, etc., in personating a character; <as>as, her <ex>makeup</ex>
was very realistic</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>An action that is taken to fulfill a requirement not
accomplished at the expected time, such as a make-up examination;
<as>as, the student took his <ex>make-up</ex> on
Saturday</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <fld>(Printing)</fld> <def>The appearance of a page of a
publication, specifically the type style of the text and the spatial
arrangement of the text, illustrations, advertising material etc., on
the page.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <fld>(Printing)</fld> <def>The art or process of
arranging the portions of a printed publication on the pages for
esthetic reasons or for optimal effect on the reader.</def><br/
[<source>PJC</source>]</p>

<p><ent>make water</ent><br/
<hw>make water</hw> <pr>(<?/)</pr>, <pos>v. i.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>To leak.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To urinate; -- a euphemism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Makeweight</ent><br/
<hw>Make"weight`</hw> <pr>(<?/)</pr>, <pos>n.</pos> <def>That which is
thrown into a scale to make weight; something of little account added to
supply a deficiency or fill a gap.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>make-work</ent><br/
<hw>make-work</hw> <pos>n.</pos> <def>Active work of litle value, such
as assignments given by teachers to students to keep them busy while the
teacher performs other tasks, or chores performed to while away time;
also called <altname>busywork</altname>.</def><br/
<syn><b>Syn. --</b> busywork.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Maki</ent><br/
\'d8<hw>Ma"ki</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from native
name.]</ety> <fld>(Zool.)</fld> <def>A lemur. See
<er>Lemur</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Making</ent><br/
<hw>Mak"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of
one who makes; workmanship; fabrication; construction; <as>as, this is
cloth of your own <ex>making</ex>; the <ex>making</ex> of peace or war
was in his power.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Composition, or structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>a poem.</def> <mark>[Obs.]</mark> <rj><au>Sir J.
Davies.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which establishes or places in a desirable
state or condition; the material of which something may be made; <as>as,
early misfortune was the <ex>making</ex> of him</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>External appearance; from.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Making-iron</ent><br/
<hw>Mak"ing-i`ron</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tool somewhat
like a chisel with a groove in it, used by calkers of ships to finish
the seams after the oakum has been driven in.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Making-up</ent><br/
<hw>Mak"ing-up`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of bringing spirits to a certain degree of strength, called
<xex>proof</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of becoming reconciled or
friendly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mako</ent><br/
<hw>mako</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as <er>mako
shark</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>makomako</ent><br/
<hw>makomako</hw> <pos>n.</pos> <def>A graceful deciduous shrub or small
tree (<spn>Aristotelia serrata</spn>) having attractive foliage and
small red berries that turn black at maturity and are used for making
wine.</def><br/
<syn><b>Syn. --</b> New Zealand wine berry, wineberry, <spn>Aristotelia
serrata</spn>, <spn>Aristotelia racemosa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mako shark</ent><br/
<hw>mako shark</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A powerful and
fierce mackerel shark of the Atlantic and Pacific, of the family
<fam>Lamidae</fam>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maksutov telescope</ent><br/
<hw>Maksutov telescope</hw> <pos>n.</pos> <def>A type of reflecting
telescope in which the aberration of the concave mirror is reduced by a
meniscus lens.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mal-</ent><br/
<hw>Mal-</hw> <pr>(m<acr/l-)</pr>. <def>A prefix in composition denoting
<sig>ill</sig>, or <sig>evil</sig>, F. <ets>male</ets>, adv., fr.
<ets>malus</ets>, bad, ill. In some words it has the form
<altname>male-</altname>, as in <ex>male</ex>diction,
<ex>male</ex>volent. See <er>Malice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The form <xex>male-</xex> is chiefly used in cases where
the <eit/, either alone or with other letters, is pronounced as a
separate syllable, as in <xex>male</xex>diction, <xex>male</xex>factor,
<xex>male</xex>ficent, etc. Where this is not the case, as in
<xex>mal</xex>feasance or <xex>male</xex>-feasance,
<xex>mal</xex>formation or <xex>male</xex>-formation, etc., as also
where the word to which it is prefixed commences with a vowel, as in
<xex>mal</xex>administration, etc., the form <ex>mal</ex> is to be
preferred, and is the one commonly employed.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mala</ent><br/
\'d8<hw>Ma"la</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>pl. of
<singw>Malum</singw>.</sing> <ety>[L.]</ety> <def>Evils; wrongs;
offenses against right and law.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mala in se</b></col> <ety>[L.]</ety> <fld>(Law)</fld>,
<cd>offenses which are such from their own nature, at common law,
irrespective of statute.</cd> -- <col><b>Mala prohibita</b></col>
<ety>[L.]</ety> <fld>(Law)</fld>, <cd>offenses prohibited by statute, as
distinguished from <contr>mala in se</contr>, which are offenses at
common law.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malabar</ent><br/
<hw>Mal"a*bar`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A region in the
western part of the Peninsula of India, between the mountains and the
sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malabar nut</b></col> <fld>(Bot.)</fld>, <cd>the seed of
an East Indian acanthaceous shrub, the <spn>Adhatoda Vasica</spn>,
sometimes used medicinally.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>malabar kino</ent><br/
<hw>malabar kino</hw> <pos>n.</pos> <def>The reddish or black juice or
resin from certain trees of the genus <gen>Pterocarpus</gen>, used in
medicine and tanning etc.</def><br/
<syn><b>Syn. --</b> East India kino, kino gum.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malacanthidae</ent><br/
<hw>Malacanthidae</hw> <pos>prop. n.</pos> <def>A natural family of
short-headed marine fishes which are often brightly colored.</def><br/
<syn><b>Syn. --</b> family <fam>Malacanthidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malacatune</ent><br/
<hw>Mal`a*ca*tune"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Melocoton</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacca</ent><br/
<hw>Ma*lac"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A town and district
upon the seacoast of the Malay Peninsula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malacca cane</ent><br/
<hw>malacca cane</hw> <pos>n.</pos> <fld>(Bot.)</fld>, <def>A walking
cane made from the stem of a species of palm of the genus
<gen>Calamus</gen> (<spn>Calamus Scipionum</spn>), and of a brown color,
often mottled. The plant is a native of Cochin China, Sumatra, and
Malays.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malachite</ent><br/
<hw>Mal"a*chite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Fr. Gr.
<grk>mala`chh</grk> a mallow, from its resembling the green color of the
leaf of mallows: cf. F. <ets>malachite</ets>. Cf.
<er>Mallow</er>.]</ety> <fld>(Min.)</fld> <def>Native hydrous carbonate
of copper, usually occurring in green mammillary masses with concentric
fibrous structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Green malachite</xex>, or malachite proper, admits
of a high polish, and is sometimes used for ornamental work. <xex>Blue
malachite</xex>, or azurite, is a related species of a deep blue
color.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malachite green</b></col>. <cd>See <cref>Emerald
green</cref>, under <er>Green</er>, <pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacissant</ent><br/
<hw>Mal`a*cis"sant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Malacissation</er>.]</ety> <def>Softening; relaxing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacissation</ent><br/
<hw>Mal`a*cis*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>malacissare</ets> to make soft, Gr. <grk>malaki`zein</grk>.]</ety>
<def>The act of making soft or supple.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacobdella</ent><br/
\'d8<hw>Mal`a*cob*del"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>malako`s</grk> soft + <?/ a leech.]</ety> <fld>(Zool.)</fld>
<def>A genus of nemertean worms, parasitic in the gill cavity of clams
and other bivalves. They have a large posterior sucker, like that of a
leech. See <xex>Illust.</xex> of <er>Bdellomorpha</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacoderm</ent><br/
<hw>Mal"a*co*derm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>malako`s</grk> soft + <?/ skin.]</ety> <fld>(Zool.)</fld> <def>One
of a tribe of beetles (<spn>Malacodermata</spn>), with a soft and
flexible body, as the fireflies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacolite</ent><br/
<hw>Mal"a*co*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>malako`s</grk> soft + <ets>-lite</ets>.]</ety> <fld>(Min.)</fld>
<def>A variety of pyroxene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacologist</ent><br/
<hw>Mal`a*col"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
the science of malacology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacology</ent><br/
<hw>Mal`a*col"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>malako`s</grk> soft + <ets>-logy</ets>: cf. F.
<ets>malacologie</ets>.]</ety> <def>The science which relates to the
structure and habits of mollusks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacopoda</ent><br/
\'d8<hw>Mal`a*cop"o*da</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. Gr. <grk>malako`s</grk> soft + <ets>-poda</ets>.]</ety>
<fld>(Zool.)</fld> <def>A class of air-breathing
<phylum>Arthropoda</phylum>; -- called also
<altname><class>Protracheata</class></altname>, and
<altname><class>Onychophora</class></altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They somewhat resemble myriapods, and have from
seventeen to thirty-three pairs of short, imperfectly jointed legs, two
pairs of simple jaws, and a pair of antennae. The trancheae are
connected with numerous spiracles scattered over the surface of the
body. <gen>Peripatus</gen> is the only known genus. See
<er>Peripatus</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacopterygian</ent><br/
<hw>Mal`a*cop`ter*yg"i*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>malacopt<eacute/rygien</ets>.]</ety> <fld>(Zool.)</fld> <def>One of
the <ord>Malacopterygii</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacopterygii</ent><br/
\'d8<hw>Mal`a*cop`te*ryg"i*i</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. Gr. <grk>malako`s</grk> soft + <grk>pte`ryx</grk> wing,
fin, fr. <grk>ptero`n</grk> feather.]</ety> <fld>(Zool.)</fld> <def>An
order of fishes in which the fin rays, except the anterior ray of the
pectoral and dorsal fins, are closely jointed, and not spiny. It
includes the carp, pike, salmon, shad, etc. Called also
<ord>Malacopteri</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacopterygious</ent><br/
<hw>Mal`a*cop`ter*yg"i*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Belonging to the
<ord>Malacopterygii</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacosteon</ent><br/
<hw>Mal`a*cos"te*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., Gr. fr.
<grk>malako`s</grk> soft + <grk>'oste`on</grk> bone.]</ety>
<fld>(Med.)</fld> <def>A peculiar disease of the bones, in consequence
of which they become softened and capable of being bent without
breaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacostomous</ent><br/
<hw>Mal`a*cos"to*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>malako`s</grk> soft + <?/ mouth.]</ety> <fld>(Zool.)</fld>
<def>Having soft jaws without teeth, as certain fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacostraca</ent><br/
\'d8<hw>Mal`a*cos"tra*ca</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., from Gr. <grk>malako`s</grk> soft + <?/ shell of a
testacean.]</ety> <fld>(Zool.)</fld> <def>A subclass of Crustacea,
including Arthrostraca and Thoracostraca, or all those higher than the
Entomostraca.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacostracan</ent><br/
<hw>Mal`a*cos"tra*can</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>One of the
<subclass>Malacostraca</subclass>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacostracology</ent><br/
<hw>Mal`a*cos`tra*col"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Malacostrac</ets>an + <ets>-logy</ets>.]</ety> <def>That
branch of Zoological science which relates to the crustaceans; -- called
also <altname>carcinology</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacostracous</ent><br/
<hw>Mal`a*cos"tra*cous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Belonging to the Malacostraca.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacotoon</ent><br/
<hw>Mal`a*co*toon"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Melocoton</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacozoa</ent><br/
\'d8<hw>Mal`a*co*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>malako`s</grk> soft + <grk>zw^,on</grk> an animal.]</ety>
<fld>(Zool.)</fld> <def>An extensive group of Invertebrata, including
the <phylum>Mollusca</phylum>, Brachiopoda, and Bryozoa. Called also
<altname>Malacozoaria</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malacozoic</ent><br/
<hw>Mal`a*co*zo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Malacozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maladdress</ent><br/
<hw>Mal`ad*dress"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mal-</ets>
+ <ets>address</ets>.]</ety> <def>Bad address; an awkward, tactless, or
offensive way of accosting one or talking with one.</def> <rj><au>W. D.
Howells.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maladjustment</ent><br/
<hw>Mal`ad*just"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>adjustment</ets>.]</ety> <def>A bad
adjustment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maladministration</ent><br/
<hw>Mal`ad*min`is*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>administration</ets>.]</ety> <def>Bad
administration; bad management of any business, especially of public
affairs.</def> <altsp>[Written also
<asp>maleadministration</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maladroit</ent><br/
<hw>Mal`a*droit"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. See
<er>Malice</er>, and <er>Adroit</er>.]</ety> <def>Of a quality opposed
to adroitness; clumsy; awkward; unskillful.</def> --
<wordforms><wf>Mal"a*droit`ly</wf>, <pos>adv.</pos> --
<wf>Mal`a*droit"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>malady</ent><br/
<hw>mal"a*dy</hw> <pr>(m<acr/l"<adot/*d<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Maladies</plw>
<pr>(m<acr/l"<adot/*d<icr/z)</pr>.</plu> <ety>[F. <ets>maladie</ets>,
fr. <ets>malade</ets> ill, sick, OF. also, <ets>malabde</ets>, fr. L.
<ets>male habitus</ets>, i. e., ill-kept, not in good condition. See
<er>Malice</er>, and <er>Habit</er>.]</ety> <sn>1.</sn> <def>Any disease
of the human body; a distemper, disorder, or indisposition, proceeding
from impaired, defective, or morbid organic functions; especially, a
lingering or deep-seated disorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>maladies</qex> of the body may prove medicines to the
mind.</q> <rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A moral or mental defect or disorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Love's a <qex>malady</qex> without a cure.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Disorder; distemper; sickness; ailment; disease;
illness. See <er>Disease</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malaga</ent><br/
<hw>Mal"a*ga</hw> <pr>(m<acr/l"<adot/*g<adot/ Sp.
m<aum/"l<adot/*g<adot/)</pr>, <pos>n.</pos> <def>A city and a province
of <city>Spain</city>, on the Mediterranean. Hence, <ex>Malaga</ex>
grapes, <ex>Malaga</ex> raisins, <ex>Malaga</ex> wines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malagash</ent><br/
\'d8<hw>Mal`a*gash"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Malagasy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malagasy</ent><br/
<hw>Mal`a*gas"y</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos> <def>A
native or natives of Madagascar; also (<singf>sing</singf>.), the
language.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malagasy Republic</ent><br/
<hw>Malagasy Republic</hw> <pos>prop. n.</pos> <def>Former name of the
Republic of Madagascar, a nation in Africa occupying the island of
Madagascar in the Indian Ocean east of Mozambique.</def><br/
[<source>PJC</source>]</p>

<p><ent>Malaise</ent><br/
\'d8<hw>Ma`laise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>mal</ets> ill + <ets>aise</ets> ease.]</ety> <fld>(Med.)</fld>
<def>An indefinite feeling of uneasiness, or of being sick or ill at
ease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malamate</ent><br/
<hw>Ma*lam"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of malamic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malambo</ent><br/
\'d8<hw>Ma*lam"bo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.]</ety>
<def>A yellowish aromatic bark, used in medicine and perfumery, said to
be from the South American shrub <spn>Croton Malambo</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malamethane</ent><br/
<hw>Mal`am*eth"ane</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Malamic</ets> + <ets>ethane</ets>.]</ety> <fld>(Chem.)</fld>
<def>A white crystalline substance forming the ethyl salt of malamic
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malamic</ent><br/
<hw>Ma*lam"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mal</ets>ic +
<ets>amic</ets>.]</ety> <fld>(Chem.)</fld> <def>Of or designating an
acid intermediate between malic acid and malamide, and known only by its
salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malamide</ent><br/
<hw>Ma*lam"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Malic</ets> +
<ets>amide</ets>.]</ety> <fld>(Chem.)</fld> <def>The acid amide derived
from malic acid, as a white crystalline substance metameric with
asparagine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malanders</ent><br/
<hw>mal"an*ders</hw> <pr>(m<acr/l"<ait/n*d<etil/rz)</pr>, <pos>n.
pl.</pos> <ety>[F. <ets>malandres</ets>, fr. L. <ets>malandria</ets>
blisters or pustules on the neck, especially in horses.]</ety>
<fld>(Far.)</fld> <def>A scurfy eruption in the bend of the knee of the
fore leg of a horse. See <er>Sallenders</er>.</def> <altsp>[Written also
<asp>mallenders</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>malapert</ent><br/
<hw>mal"a*pert</hw> <pr>(m<acr/l"<adot/*p<etil/rt)</pr>, <pos>a.</pos>
<ety>[OF. <ets>malapert</ets> unskillful, ill-taught, ill-bred;
<ets>mal</ets> ill + <ets>apert</ets> open, adroit, intelligent, L.
<ets>apertus</ets>, p. p. of <ets>aperire</ets> to open. See
<er>Malice</er>, and <er>Aperient</er>.]</ety> <def>Bold; forward;
impudent; saucy; pert.</def> <au>Shak.</au> -- <def2><pos>n.</pos>
<def>A malapert person.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>Are you growing <qex>malapert</qex>! <qex>Will you force me to
make use of my authority</qex> ?</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mal"a*pert`ly</wf>, <pos>adv.</pos> --
<wf>mal"a*pert`ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>malapropism</ent><br/
<hw>mal"a*prop*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<person>Mrs. <etsep>Malaprop</etsep></person>, a character in
<persfn>Sheridan's</persfn> drama, <ldquo/ The Rivals,<rdquo/ who makes
amusing blunders in her use of words. See <er>Malapropos</er>.]</ety>
<def>A grotesque misuse of a word; a word so used.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malapropos</ent><br/
<hw>mal*ap"ro*pos`</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[F.
<ets>mal <agrave/ propos</ets>; <ets>mal</ets> evil + <ets><agrave/
propos</ets> to the purpose.]</ety> <def>Unseasonable or unseasonably;
unsuitable or unsuitably.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malapterurus</ent><br/
\'d8<hw>Mal*ap`te*ru"rus</hw>
<pr>(m<acr/l*<acr/p`t<esl/*r<udd/"r<ucr/s)</pr>, <pos>prop. n.</pos>
<ety>[NL., from Gr. <grk>malako`s</grk> soft + <grk>ptero`n</grk> wing +
<grk>o'yra`</grk> tail.]</ety> <fld>(Zool.)</fld> <def>A genus of
African siluroid fishes, including the electric catfishes. See
<cref>Electric cat</cref>, under <er>Electric</er>.</def>
<altsp>[Sometimes spelled <asp>Malopterurus</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malapterurus electricus</ent><br/
<hw>Malapterurus electricus</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld>
<def>The species name of the <altname>electric catfish</altname>, a
freshwater catfish of the Nile and tropical central Africa having an
electric organ.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malar</ent><br/
<hw>Ma"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>mala</ets> the
cheek: cf. F. <ets>malaire</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or
pertaining to the region of the cheek bone, or to the malar bone;
jugal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malar</ent><br/
<hw>ma"lar</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld> <def>The
cheek bone, which forms a part of the lower edge of the orbit; that arch
of bone beneath the eye that forms the prominence of the cheek; also
called the <altname>malar bone</altname>.</def><br/
<syn><b>Syn. --</b> cheekbone, zygomatic bone, malar bone, jugal bone,
os zygomaticum.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>malar bone</ent><br/
<hw>malar bone</hw> <pos>n.</pos> <def>Same as <er>malar</er>,
<pos>n.</pos></def><br/
[<source>PJC</source>]</p>

<p><ent>malaria</ent><br/
<hw>ma*la"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It., contr. fr.
<ets>malaaria</ets> bad air. See <er>Malice</er>, and Air.]</ety>
<sn>1.</sn> <def>Air infected with some noxious substance capable of
engendering disease; esp., an unhealthy exhalation from certain soils,
as marshy or wet lands, producing fevers; miasma.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The morbific agent in malaria is supposed by some to be
a vegetable microbe or its spores, and by others to be a very minute
animal blood parasite (an <xex>infusorian</xex>).</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A human disease caused by
infection of red blood cells by a protozoan of the genus
<gen>Plasmodium</gen>, giving rise to fever and chills and many other
symptoms, characterized by their tendency to recur at definite and
usually uniform intervals. The protozoal infection is usually
transmitted from another infected individual by the bite of an
<gen>Anopheles</gen> mosquito.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Malarious</ent><br/
<ent>Malarian</ent><br/
<ent>Malarial</ent><br/
<mhw>{ <hw>Ma*la"ri*al</hw> <pr>(?)</pr>, <hw>Ma*la"ri*an</hw>
<pr>(?)</pr>, <hw>Ma*la"ri*ous</hw> <pr>(?)</pr> }</mhw>, <pos>a.</pos>
<def>Of or pertaining, to or infected by, malaria.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malarial fever</b></col> <fld>(Med.)</fld>, <cd>a fever
produced by malaria, and characterized by the occurrence of chills,
fever, and sweating in distinct paroxysms, At intervals of definite and
often uniform duration, in which these symptoms are wholly absent
(<xex>intermittent fever</xex>), or only partially so (<xex>remittent
fever</xex>); fever and ague; chills and fever.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>malarial mosquito</ent><br/
<ent>malaria mosquito</ent><br/
<mhw><hw>malaria mosquito</hw>, <hw>malarial mosquito</hw></mhw>
<pos>n.</pos> <def>A mosquito that transmits the malaria parasite; it is
most commonly the <gen>Anopheles</gen> mosquito.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malaria parasite</ent><br/
<hw>Malaria parasite</hw>. <def>Any of several minute protozoans of the
genus <gen>Plasmodium</gen> (syn. <gen>Haematozoon</gen>) which in their
adult condition live in the tissues of mosquitoes of the genus
<gen>Anopheles</gen> (which see) and when transferred to the blood of
man, by the bite of the mosquito, produce malaria.</def> <note>The young
parasites, or <b>sporozoites</b>, enter the red blood corpuscles,
growing at their expense, undergoing sporulation, and finally destroying
the corpuscles, thus liberating in the blood plasma an immense number of
small spores called <b>merozoites</b>. An indefinite but not ultimated
number of such generations may follow, but if meanwhile the host is
bitten by a mosquito, the parasites develop into gametes in the stomach
of the insect. These conjugate, the zygote thus produced divides,
forming spores, and eventually sporozoites, which, penetrating to the
salivary glands of the mosquito, may be introduced into a new host. The
attacks of the disease coincide with the dissolution of the corpuscles
and liberation of the spores and products of growth of the parasites
into the blood plasma. Several species of the parasite are
distinguished, as <spn>Plasmodium vivax</spn>, producing tertian
malaria; <spn>Plasmodium malariae</spn>, quartan malaria; and
<spn>Plasmodium (<plain>subgenus</plain> Laverania) falciferum</spn>,
the malarial fever of summer and autumn common in the
tropics.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Malashaganay</ent><br/
<hw>Ma`la*sha"ga*nay</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Indian
name.]</ety> <fld>(Zool.)</fld> <def>The fresh-water drumfish
(<spn>Haploidonotus grunniens</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malassimilation</ent><br/
<hw>Mal`as*sim`i*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>assimilation</ets>.]</ety>
<fld>(Physiol.)</fld> <sd>(a)</sd> <def>Imperfect digestion of the
several leading constituents of the food.</def> <sd>(b)</sd> <def>An
imperfect elaboration by the tissues of the materials brought to them by
the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malate</ent><br/
<hw>Ma"late</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>malum</ets>
apple: cf. F. <ets>malate</ets>. See <er>Malic</er>.]</ety>
<fld>(Chem.)</fld> <def>A salt of malic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malawi kwacha</ent><br/
<hw>malawi kwacha</hw> <pos>n.</pos> <def>The kwacha, the monetary unit
of Malawi.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malaxate</ent><br/
<ent>Malax</ent><br/
<mhw>{ <hw>Ma"lax</hw> <pr>(?)</pr>, <hw>Ma*lax"ate</hw> <pr>(?)</pr>,
}</mhw> <pos>v. t.</pos> <ety>[L. <ets>malaxare</ets>,
<ets>malaxatum</ets>, cf. Gr. <?/, fr. <grk>malako`s</grk> soft: cf. F.
<ets>malaxer</ets>.]</ety> <def>To soften by kneading or stirring with
some thinner substance.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malaxation</ent><br/
<hw>Mal`ax*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>malaxatio</ets>: cf. F. <ets>malaxation</ets>.]</ety> <def>The act
of softening by mixing with a thinner substance; the formation of
ingredients into a mass for pills or plasters.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>malaxator</ent><br/
<hw>mal"ax*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, malaxates; esp., a machine for grinding, kneading, or stirring
into a pasty or doughy mass.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malaxis</ent><br/
<hw>Malaxis</hw> <pos>prop. n.</pos> <def>A large genus of largely
terrestrial orchids with one or a few plicate leaves and slender spikes
or tiny mostly green flowers; it is cosmopolitan.</def><br/
<syn><b>Syn. --</b> genus <gen>Malaxis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malaxis-unifolia</ent><br/
<hw>Malaxis-unifolia</hw> <pos>n.</pos> <def>A North American orchid
having a solitary leaf and flowers with threadlike petals.</def><br/
<syn><b>Syn. --</b> green adder's mouth, <spn>Malaxis
ophioglossoides</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malay</ent><br/
<hw>Ma*lay"</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>One of a race of
a brown or copper complexion in the Malay Peninsula and the western
islands of the Indian Archipelago.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malayan</ent><br/
<ent>Malay</ent><br/
<mhw>{ <hw>Ma*lay"</hw> <pr>(?)</pr>, <hw>Ma*lay"an</hw> <pr>(?)</pr>,
}</mhw> <pos>prop. a.</pos> <def>Of or pertaining to the Malays or their
country.</def> -- <def2><pos>n.</pos> <def>The Malay
language.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malay apple</b></col> <fld>(Bot.)</fld>, <cd>a myrtaceous
tree (<spn>Eugenia Malaccensis</spn>) common in India; also, its
applelike fruit.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malaya</ent><br/
<hw>Malaya</hw> <pos>prop. n.</pos> <def>Formerly, an Asian country on
Borneo and the Malay Peninsula, now part of
<partof>Malaysia</partof>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malayalam</ent><br/
<hw>Ma"la*ya"lam</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>The name
given to one the cultivated Dravidian languages, closely related to the
Tamil.</def> <rj><au>Yule.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malayan tapir</ent><br/
<hw>Malayan tapir</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A large
inoffensive chiefly nocturnal ungulate (<spn>Tapirus indicus</spn>) of
tropical America and Southeast Asia having a heavy body and fleshy
snout.</def><br/
<syn><b>Syn. --</b> Indian tapir, <spn>Tapirus indicus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malay Archipelago</ent><br/
<hw>Malay Archipelago</hw> <pos>prop. n.</pos> <def>A group of islands
in the Indian and Pacific Oceans between Asia and Australia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malayo-Polynesian</ent><br/
<hw>Malayo-Polynesian</hw> <pos>adj.</pos> <def>of or pertaining to
Malayo-Polynesia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malay Peninsula</ent><br/
<hw>Malay Peninsula</hw> <pos>prop. n.</pos> <def>a peninsula in
Southeastern Asia occupied by parts of Malaysia and Thailand and
Burma.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malaysia</ent><br/
<hw>Malaysia</hw> <pos>prop. n.</pos> <def>A country in Southeast Asia
including the former nation of <part>Malaya</part> on the Malay
Peninsula, and part of Borneo; sometimes still referred to as
<altname>Malaya</altname>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Malaysian</ent><br/
<hw>Malaysian</hw> <pos>adj.</pos> <def>Of or pertaining to or
characteristic of Malaysia or its people or their culture; <as>as,
<ex>Malaysian</ex> police cracked down hard on drug smugglers;
<ex>Malaysian</ex> poetry</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malbrouck</ent><br/
\'d8<hw>Mal"brouck</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>A West African arboreal monkey
(<spn>Cercopithecus cynosurus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malcolmia</ent><br/
<hw>Malcolmia</hw> <pos>prop. n.</pos> <def>A genus of plants usually
found in coastal habitats; native from the Mediterranean to
Afghanistan.</def><br/
<syn><b>Syn. --</b> genus <gen>Malcolmia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malcolm Little</ent><br/
<hw>Malcolm Little</hw> <pos>prop. n.</pos> <def>A militant American
black nationalist leader, also called <altname>Malcolm X</altname>;
(1925-1965).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malcolm stock</ent><br/
<hw>Malcolm stock</hw> <pos>n.</pos> <def>Any of various ornamental
flowering plants of the genus <gen>Malcolmia</gen>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malcolm X</ent><br/
<hw>Malcolm X</hw> <pos>prop. n.</pos> <def>See <er>Malcolm
Little</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malconformation</ent><br/
<hw>mal*con`for*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>conformation</ets>.]</ety> <def>Imperfect,
disproportionate, or abnormal formation; ill form; disproportion of
parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malcontent</ent><br/
<hw>mal"con*tent`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr.
<ets>mal</ets> ill + <ets>content</ets>. See <er>Malice</er>,
<er>Content</er>.]</ety> <def>discontented; uneasy; dissatisfied;
especially, dissatisfied with the government.</def> <altsp>[Written also
<asp>malecontent</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>The famous <qex>malcontent</qex> earl of Leicester.</q>
<rj><qau>Milner.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malcontent</ent><br/
<hw>Mal"con*tent`</hw>, <pos>n.</pos> <ety>[F.
<ets>malcontent</ets>.]</ety> <def>One who discontented; especially, a
discontented subject of a government; one who expresses his discontent
by words or overt acts.</def> <rj><au>Spenser.</au>
<au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>malcontented</ent><br/
<hw>mal`con*tent"ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Malcontent.</def> -- <wordforms><wf>Mal`con*tent"ed*ly</wf>,
<pos>adv.</pos> -- <wf>Mal`con*tent"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>maldanian</ent><br/
<hw>mal*da"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any species of marine annelids of the genus <gen>Maldane</gen>, or
family <fam>Maldanidae</fam>. They have a slender, round body, and make
tubes in the sand or mud.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mal de mer</ent><br/
<hw>mal de mer</hw> <pos>n.</pos> <def>Motion sickness experienced while
traveling on water; seasickness.</def><br/
<syn><b>Syn. --</b> seasickness, naupathia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maldive Islands</ent><br/
<hw>Maldive Islands</hw> <pos>prop. n.</pos> <def>A group of about 2000
islands in the Indian ocean; also known as the
<altname>Maldives</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maldivian</ent><br/
<hw>Maldivian</hw> <pos>n.</pos> <def>A native or inhabitant of
Maldives.</def><br/
<syn><b>Syn. --</b> Maldivan.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maldon</ent><br/
<hw>Maldon</hw> <pos>prop. n.</pos> <def>A battle in which the Danes
defeated the East Saxons in 991; it is celebrated in an old English
poem.</def><br/
<syn><b>Syn. --</b> battle of Maldon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Male-</ent><br/
<hw>Male-</hw> <pr>(m<acr/l- <it>or</it> m<acr/l<esl/-)</pr>. <def>See
<er>Mal-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Male</ent><br/
<hw>Male</hw> <pr>(m<amac/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>malus</ets>. See <er>Malice</er>.]</ety> <def>Evil; wicked;
bad.</def> <mark>[Obs.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Male</ent><br/
<hw>Male</hw>, <pos>n.</pos> <def>Same as <er>Mail</er>, a bag.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Male</ent><br/
<hw>Male</hw>, <pos>a.</pos> <ety>[F. <ets>m<acir/le</ets>, OF.
<ets>masle</ets>, <ets>mascle</ets>, fr. L. <ets>masculus</ets> male,
masculine, dim. of <ets>mas</ets> a male; possibly akin to E.
<ets>man</ets>. Cf. <er>Masculine</er>, <er>Marry</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Of or pertaining to the sex that begets
or procreates young, or (in a wider sense) to the sex that produces
spermatozoa, by which the ova are fertilized; not female; <as>as,
<ex>male</ex> organs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Capable of producing
fertilization, but not of bearing fruit; -- said of stamens and
antheridia, and of the plants, or parts of plants, which bear
them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Suitable to the male sex; characteristic or
suggestive of a male; masculine; <as>as, <ex>male</ex>
courage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Consisting of males; <as>as, a <ex>male</ex>
choir</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mech.)</fld> <def>Adapted for entering another
corresponding piece (the <xex>female</xex> piece) which is hollow and
which it fits; <as>as, a <ex>male</ex> gauge, for gauging the size or
shape of a hole; a <ex>male</ex> screw, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Male fern</b></col> <fld>(Bot.)</fld>, <cd>a fern of the
genus <gen>Aspidium</gen> (<spn>Aspidium Filixmas</spn>), used in
medicine as an anthelmintic, esp. against the tapeworm. <spn>Aspidium
marginale</spn> in America, and <spn>Aspidium athamanticum</spn> in
South Africa, are used as good substitutes for the male fern in medical
practice. See <cref>Female fern</cref>, under <er>Female</er>.</cd> --
<col><b>Male rhyme</b></col>, <cd>a rhyme in which only the last
syllables agree, as <xex>laid</xex>, <xex>afraid</xex>,
<xex>dismayed</xex>. See <cref>Female rhyme</cref>, under
<er>Female</er>.</cd> -- <col><b>Male screw</b></col>
<fld>(Mech.)</fld>, <cd>a screw having threads upon its exterior which
enter the grooves upon the inside of a corresponding nut or female
screw.</cd> -- <col><b>Male thread</b></col>, <cd>the thread of a male
screw.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Male</ent><br/
<hw>Male</hw>, <pos>n.</pos> <sn>1.</sn> <def>An animal of the male
sex.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A plant bearing only staminate
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleadministration</ent><br/
<hw>Male`ad*min`is*tra"tion</hw>
<pr>(m<acr/l`<acr/d*m<icr/n`<icr/s*tr<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>Maladministration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleate</ent><br/
<hw>Ma*le"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A salt of maleic
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>male berry</ent><br/
<ent>maleberry</ent><br/
<mhw><hw>male"ber`ry</hw>, <hw>male" ber`ry</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A deciduous much-branched shrub
(<spn>Lyonia ligustrina</spn>) with dense downy panicles of small
bell-shaped white flowers; also called <altname>swamp
andromeda</altname>.</def><br/
<syn><b>Syn. --</b> privet andromeda, he-huckleberry, <spn>Lyonia
ligustrina</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A kind of coffee. See <er>Pea
berry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>male body</ent><br/
<hw>male body</hw> <pos>n.</pos> <def>The body of an adult human male;
-- a term used especially in art; <as>as, <person>Da Vinci</person> was
unexcelled in painting the <ex>male body</ex></as>.</def><br/
<syn><b>Syn. --</b> adult male body, man's body.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Malebranchism</ent><br/
<hw>Male*branch"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
philosophical system of <persfn><etsep>Malebranche</etsep></persfn>, an
eminent French metaphysician. The fundamental doctrine of his system is
that the mind can not have knowledge of anything external to itself
except in its relation to God.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>male chauvinism</ent><br/
<hw>male chauvinism</hw> <pos>n.</pos> <def>Disparaging, patronizing,
discriminatory or abusive speech or behavior by males toward females
stemming from a belief that males are superior to females and females
therefore worthy of less respect and inferior treatment. A form of
<isa>sexism</isa>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>male chauvinist</ent><br/
<hw>male chauvinist</hw> <pos>n.</pos> <def>A man with a belief in the
inferiority of women; one who believes in or practises male
chavinism.</def><br/
<syn><b>Syn. --</b> sexist.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><-- p. 887 --></p>

<p><ent>Maleconformation</ent><br/
<hw>Male*con`for*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Malconformation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malecontent</ent><br/
<hw>Male"con*tent`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Malcontent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maledicency</ent><br/
<hw>Mal`e*di"cen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maledicentia</ets>. See <er>Maledicent</er>.]</ety> <def>Evil
speaking.</def> <mark>[Obs.]</mark> <rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maledicent</ent><br/
<hw>Mal`e*di"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>maledicens</ets>, p. pr. of <ets>maledicere</ets> to speak ill;
<ets>male</ets> ill + <ets>dicere</ets> to say, speak. See
<er>Malice</er>, and <er>Diction</er>.]</ety> <def>Speaking
reproachfully; slanderous.</def> <mark>[Obs.]</mark> <rj><au>Sir E.
Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maledict</ent><br/
<hw>Mal"e*dict</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>maledictus</ets>, p. p. of <ets>maledicere</ets>.]</ety>
<def>Accursed; abominable.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malediction</ent><br/
<hw>Mal`e*dic"tion</hw>, <pos>n.</pos> <ety>[L. <ets>maledictio</ets>:
cf. F. <ets>mal<eacute/diction</ets>. See <er>Maledicent</er>.]</ety>
<def>A proclaiming of evil against some one; a cursing; imprecation; a
curse or execration; -- opposed to <ant>benediction</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>malediction</qex> falls from his tongue.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Cursing; curse; execration; imprecation;
denunciation; anathema.</syn> <usage> -- <er>Malediction</er>,
<er>Curse</er>, <er>Imprecation</er>, <er>Execration</er>.
<xex>Malediction</xex> is the most general term, denoting bitter
reproach, or wishes and predictions of evil. <xex>Curse</xex> implies
the desire or threat of evil, declared upon oath or in the most solemn
manner. <xex>Imprecation</xex> is literally the praying down of evil
upon a person. <xex>Execration</xex> is literally a putting under the
ban of excommunication, a curse which excludes from the kingdom of God.
In ordinary usage, the last three words describe profane swearing,
<xex>execration</xex> being the strongest.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malefaction</ent><br/
<hw>Mal`e*fac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Malefactor</er>.]</ety> <def>A crime; an offense; an evil
deed.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malefactor</ent><br/
<hw>Mal`e*fac"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>malefacere</ets> to do evil; <ets>male</ets> ill, evil +
<ets>facere</ets> to do. See <er>Malice</er>, and <er>Fact</er>.]</ety>
<sn>1.</sn> <def>An evil doer; one who commits a crime; one subject to
public prosecution and punishment; a criminal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who does wrong by injuring another, although not
a criminal. Opposite of <ant>benefactor</ant>.</def> <rj><au>H.
Brooke.</au> <au>Fuller.</au></rj><br/
<ldquo/Malefactors of great wealth.<rdquo/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><syn><b>Syn.</b> -- Evil doer; criminal; culprit; felon;
convict.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malefactress</ent><br/
<hw>Mal`e*fac"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
malefactor.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malefeasance</ent><br/
<hw>Male*fea"sance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Malfeasance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>male fern</ent><br/
<hw>male fern</hw> <pos>n.</pos> <def>A fern of North America and Europe
(<spn>Dryopteris filix-mas</spn>) whose rhizomes and stalks yield an
oleoresin used to expel tapeworms. It is a member of the
<isa>woodfern</isa> genus.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malefic</ent><br/
<hw>Ma*lef"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>maleficus</ets>: cf. F. <ets>mal<eacute/fique</ets>. See
<er>Malefaction</er>.]</ety> <def>Doing mischief; causing harm or evil;
nefarious; hurtful.</def> <mark>[R.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malefice</ent><br/
<hw>Mal"e*fice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maleficium</ets>: cf. F. <ets>mal<eacute/fice</ets>. See
<er>Malefactor</er>.]</ety> <def>An evil deed; artifice;
enchantment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficence</ent><br/
<hw>Ma*lef"i*cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maleficentia</ets>. Cf. <er>Malfeasance</er>.]</ety> <def>Evil
doing, esp. to others.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficent</ent><br/
<hw>Ma*lef"i*cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Malefic</er>.]</ety> <def>Doing evil to others; harmful;
mischievous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficial</ent><br/
<hw>Mal`e*fi"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Injurious.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficiate</ent><br/
<hw>Mal`e*fi"ci*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>maleficiatus</ets>, p. p. of <ets>maleficiare</ets> to bewitch, fr.
L. <ets>maleficium</ets>. See <er>Malefice</er>.]</ety> <def>To bewitch;
to harm.</def> <mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficiation</ent><br/
<hw>Mal`e*fi`ci*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
bewitching.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficience</ent><br/
<hw>Mal`e*fi"cience</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Maleficence</er>.]</ety> <def>The doing of evil, harm, or
mischief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleficient</ent><br/
<hw>Mal`e*fi"cient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Maleficent</er>.]</ety> <def>Doing evil, harm, or
mischief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleformation</ent><br/
<hw>Male`for*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Malformation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleic</ent><br/
<hw>Ma*le"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mal<eacute/ique</ets>. See <er>Malic</er>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an acid of the
ethylene series (maleic acid), metameric with fumaric acid and obtained
by heating malic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maleic acid</ent><br/
<hw>maleic acid</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>An
unsaturated dicarboxylic acid (<chform>HO.CO.CH=CH.CO.OH</chform>) of
<it>cis</it> conformation, having various uses in the manufacture of
artificial resins, the dyeing and finishing of wool, silk, and cotton,
and also combined with certain drugs to make salts more soluble than the
basic forms. The corresponding isomer having <it>trans</it>
conformation, is identical in chemical formula, is called <contr>fumaric
acid</contr>.</def> <au>MI11</au><br/
[<source>PJC</source>]</p>

<p><ent>Malengine</ent><br/
<hw>Ma*len"gine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>malengin</ets>; L. <ets>malus</ets> bad, evil + <ets>ingenium</ets>
natural capacity. See <er>Engine</er>.]</ety> <def>Evil machination;
guile; deceit.</def> <mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleo</ent><br/
<hw>Ma"le*o</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From its native
name.]</ety> <fld>(Zool.)</fld> <def>A bird of Celebes
(<spn>megacephalon maleo</spn>), allied to the brush turkey. It makes
mounds in which to lay its eggs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Male-odor</ent><br/
<hw>Male-o"dor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Malodor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>male orchis</ent><br/
<hw>male orchis</hw> <pos>n.</pos> <def>A Eurasian orchid (<spn>Orchis
mascula</spn>) with showy pink or purple flowers in a loose
spike.</def><br/
<syn><b>Syn. --</b> early purple orchid, <spn>Orchis
mascula</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>male orgasm</ent><br/
<hw>male orgasm</hw> <pos>n.</pos> <def>An orgasm in a male animal
accompanied by the ejaculation of semen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>male plug</ent><br/
<hw>male plug</hw> <pos>n.</pos> <fld>(Electricity)</fld> <def>The
connecting end of the cord on an electrical device, having two or three
pins, that is inserted into a matching socket to make an electrical
connection.</def><br/
<syn><b>Syn. --</b> plug.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malepractice</ent><br/
<hw>Male*prac"tice</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Malpractice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Male-spirited</ent><br/
<hw>Male"-spir`it*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
spirit of a male; vigorous; courageous.</def> <mark>[R.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malet</ent><br/
<hw>Mal"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mallette</ets>, dim. of <ets>malle</ets>. See <er>Mail</er> a
bag.]</ety> <def>A little bag or budget.</def> <mark>[Obs.]</mark>
<rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maletreat</ent><br/
<hw>Male*treat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Maltreat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malevolence</ent><br/
<hw>Ma*lev"o*lence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>malevolentia</ets>. See <er>Malevolent</er>.]</ety> <def>The
quality or state of being malevolent; evil disposition toward another;
inclination to injure others; ill will. See Synonym of
<er>Malice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malevolent</ent><br/
<hw>Ma*lev"o*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>malevolens</ets>, <ets>-entis</ets>; <ets>male</ets> ill +
<ets>volens</ets>, p. pr. of <ets>velle</ets> to be willing or disposed,
to wish. See <er>Malice</er>, and <er>Voluntary</er>.]</ety>
<def>Wishing evil; disposed to injure others; rejoicing in another's
misfortune.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Ill-disposed; envious; mischievous; evil-minded;
spiteful; malicious; malignant; rancorous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malevolently</ent><br/
<hw>Ma*lev"o*lent*ly</hw>, <pos>adv.</pos> <def>In a malevolent
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malevolous</ent><br/
<hw>Ma*lev"o*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>malevolus</ets>; fr. <ets>male</ets> ill + <ets>velle</ets> to be
disposed.]</ety> <def>Malevolent.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malexecution</ent><br/
<hw>Mal*ex`e*cu"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>execution</ets>.]</ety> <def>Bad
execution.</def> <rj><au>D. Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maleyl</ent><br/
<hw>Ma*le"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Maleic</ets> +
<ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A hypothetical radical
derived from maleic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malfeasance</ent><br/
<hw>Mal*fea"sance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>malfaisance</ets>, fr. <ets>malfaisant</ets> injurious, doing ill;
<ets>mal</ets> ill, evil + <ets>faisant</ets> doing, p. pr. of
<ets>faire</ets> to do. See <er>Malice</er>, <er>Feasible</er>, and cf.
<er>Maleficence</er>.]</ety> <fld>(Law)</fld> <def>The doing of an act
which a person ought not to do; evil conduct; an illegal deed.</def>
<altsp>[Written also <asp>malefeasance</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>malfeasant</ent><br/
<hw>malfeasant</hw> <pos>n.</pos> <def>One guilty of
malfeasance.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malformation</ent><br/
<hw>Mal`for*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>formation</ets>.]</ety> <def>Ill formation;
irregular or anomalous formation; abnormal or wrong conformation or
structure; -- often used of body parts such as limbs which do not
develop properly during fetal maturation.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Malgracious</ent><br/
<hw>Mal*gra"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>malgracieux</ets>.]</ety> <def>Not graceful; displeasing.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malgre</ent><br/
<hw>Mal"gre</hw> <pr>(?)</pr>, <pos>prep.</pos> <def>See
<er>Mauger</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malheur wire lettuce</ent><br/
<hw>malheur wire lettuce</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
small mustardlike plant (<spn>Stephanomeria malheurensis</spn>) of
Oregon, belonging to the family <fam>Cruciferae</fam>; it is a
threatened species.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malian</ent><br/
<hw>Malian</hw> <pos>prop. a.</pos> <sn>1.</sn> <def>Of or pertaining to
Mali; <as>as, <ex>Malian</ex> deserts</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to the inhabitants of Mali; <as>as,
<ex>Malian</ex> nomads</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malian</ent><br/
<hw>Malian</hw> <pos>prop. n.</pos> <def>A native or inhabitant of
Mali.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mali franc</ent><br/
<hw>Mali franc</hw> <pos>prop. n.</pos> <def>The standard monetary unit
in Mali and some other countries.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malic</ent><br/
<hw>Ma"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>malum</ets> an
apple: cf. F. <ets>malique</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or obtained from, apples; <as>as, <ex>malic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malic acid</b></col>, <fld>(Chem.)</fld> <cd>a hydroxy
acid (<chform>HO.CO.CH2.CH(OH).CO.OH</chform>) obtained from unripe
fruit (such as <prodby>green apples</prodby>, <prodby>currants</prodby>,
<prodby>tomatoes</prodby> or <prodby>cherries</prodby>) as a substance
which is sirupy or crystallized with difficulty, and has a strong but
pleasant sour taste. It is levorotatory or dextrorotatory according to
the temperature and concentration; the natural form is of L-
conformation. A synthetic variety is a derivative of succinic acid, but
as with most simple synthetic compounds, is a racemic mixture of isomers
and thus has no rotatory action on polarized light.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>malice</ent><br/
<hw>mal"ice</hw> <pr>(m<acr/l"<icr/s)</pr>, <pos>n.</pos> <ety>[F.
<ets>malice</ets>, fr. L. <ets>malitia</ets>, from <ets>malus</ets> bad,
ill, evil, prob. orig., dirty, black; cf. Gr. <grk>me`las</grk> black,
Skr. <ets>mala</ets> dirt. Cf. <er>Mauger</er>.]</ety> <sn>1.</sn>
<def>Enmity of heart; malevolence; ill will; a spirit delighting in harm
or misfortune to another; a disposition to injure another; a malignant
design of evil.</def> <ldquo/Nor set down aught in
<xex>malice</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Envy, hatred, and <qex>malice</qex> are three distinct passions of
the mind.</q> <rj><qau>Ld. Holt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Any wicked or mischievous intention
of the mind; a depraved inclination to mischief; an intention to vex,
annoy, or injure another person, or to do a wrongful act without just
cause or cause or excuse; a wanton disregard of the rights or safety of
others; willfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Malice aforethought</b></col> <it>or</it>
<col><b>Malice prepense</b></col></mcol>, <cd>malice previously and
deliberately entertained.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Spite; ill will; malevolence; grudge; pique;
bitterness; animosity; malignity; maliciousness; rancor;
virulence.</syn> <usage> See <er>Spite</er>. -- <er>Malevolence</er>,
<er>Malignity</er>, <er>Malignancy</er>. <xex>Malice</xex> is a stronger
word than <xex>malevolence</xex>, which may imply only a desire that
evil may befall another, while <xex>malice</xex> desires, and perhaps
intends, to bring it about. <xex>Malignity</xex> is intense and
deepseated <xex>malice</xex>. It implies a natural delight in hating and
wronging others. One who is <xex>malignant</xex> must be both
<xex>malevolent</xex> and <xex>malicious</xex>; but a man may be
<xex>malicious</xex> without being <xex>malignant</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Proud tyrants who <qex>maliciously</qex> destroy<br/
And ride o'er ruins with <qex>malignant</qex> joy.</q>
<rj><qau>Somerville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>in some connections, <qex>malignity</qex> seems rather more
pertinently applied to a radical depravity of nature, and
<qex>malignancy</qex> to indications of this depravity, in temper and
conduct in particular instances.</q> <rj><qau>Cogan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malice</ent><br/
<hw>Mal"ice</hw>, <pos>v. t.</pos> <def>To regard with extreme ill
will.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malicho</ent><br/
<hw>Mal"i*cho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>malhecho</ets>; <ets>mal</ets> bad + <ets>hecho</ets> deed, L.
<ets>factum</ets>. See <er>Fact</er>.]</ety> <def>Mischief.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malicious</ent><br/
<hw>Ma*li"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Of.
<ets>malicius</ets>, F. <ets>malicieux</ets>, fr. L.
<ets>malitiosus</ets>. See <er>Malice</er>.]</ety> <sn>1.</sn>
<def>Indulging or exercising malice; harboring ill will or
enmity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I grant him bloody, . . . <br/
Sudden, <qex>malicious</qex>, smacking of every sin<br/
That has a name.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proceeding from hatred or ill will; dictated by
malice; <as>as, a <ex>malicious</ex> report; <ex>malicious</ex>
mischief.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>With wicked or mischievous
intentions or motives; wrongful and done intentionally without just
cause or excuse; <as>as, a <ex>malicious</ex> act</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malicious abandonment</b></col>, <cd>the desertion of a
wife or husband without just cause.</cd> <au>Burrill.</au> --
<mcol><col><b>Malicious prosecution</b></col> <it>or</it>
<col><b>Malicious arrest</b></col></mcol> <fld>(Law)</fld>, <cd>a wanton
prosecution or arrest, by regular process in a civil or criminal
proceeding, without probable cause.</cd> <au>Bouvier.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Ill-disposed; evil-minded; mischievous; envious;
malevolent; invidious; spiteful; bitter; malignant; rancorous;
malign.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ma*li"cious*ly</wf>, <pos>adv.</pos> --
<wf>Ma*li"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>malicious mischief</ent><br/
<hw>malicious mischief</hw> <pos>n.</pos> <fld>(Law)</fld>,
<def>Malicious and willful destructionof or injury to the property of
others; -- it is an offense at common law.</def> <au>Wharton.</au><br/
<syn><b>Syn. --</b> vandalism, hooliganism.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>malign</ent><br/
<hw>ma*lign"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>malignus</ets>, for <ets>maligenus</ets>, i. e., of a bad kind or
nature; <ets>malus</ets> bad + the root of <ets>genus</ets> birth, race,
kind: cf. F. <ets>malin</ets>, masc., <ets>maligne</ets>, fem. See
<er>Malice</er>, <er>Gender</er>, and cf. <er>Benign</er>,
<er>Malignant</er>.]</ety> <sn>1.</sn> <def>Having an evil disposition
toward others; harboring violent enmity; malevolent; malicious;
spiteful; -- opposed to <ant>benign</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Witchcraft may be by operation of <qex>malign</qex> spirits.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unfavorable; unpropitious; pernicious; tending to
injure; <as>as, a <ex>malign</ex> aspect of planets</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Malignant; <as>as, a <ex>malign</ex>
ulcer</as>.</def> <mark>[R.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malign</ent><br/
<hw>Ma*lign"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Maligned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Maligning</conjf>.]</vmorph> <ety>[Cf. L. <ets>malignare</ets>.
See <er>Malign</er>, <pos>a.</pos>]</ety> <def>To treat with malice; to
show hatred toward; to abuse; to wrong; to injure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The people practice what mischiefs and villainies they will
against private men, whom they <qex>malign</qex> by stealing their
goods, or murdering them.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To speak great evil of; to traduce; to defame; to
slander; to vilify; to asperse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To be envied and shot at; to be <qex>maligned</qex> standing, and
to be despised falling.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malign</ent><br/
<hw>Ma*lign"</hw>, <pos>v. i.</pos> <def>To entertain malice.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malignancy</ent><br/
<ent>Malignance</ent><br/
<mhw>{ <hw>Ma*lig"nance</hw> <pr>(?)</pr>, <hw>Ma*lig"nan*cy</hw> ,
}</mhw> <pos>n.</pos> <ety>[See <er>Malignant</er>.]</ety> <sn>1.</sn>
<def>The state or quality of being malignant; extreme malevolence;
bitter enmity; malice; disposition toward evil; intense ill will;
<as>as, <ex>malignancy</ex> of heart</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unfavorableness; evil nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>malignancy</qex> of my fate might perhaps distemner
yours.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>Virulence; tendency to a fatal
issue; <as>as, the <ex>malignancy</ex> of an ulcer or of a
fever</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <fld>(Med.)</fld> <def>A
cancerous tumor that is spreading beyond the point of origin.</def><br/
<syn><b>Syn. --</b> malignant tumor, malignant neoplasm, metastatic
tumor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>5.</sn> <def>The state of being a malignant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malignant</ent><br/
<hw>ma*lig"nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>malignans</ets>, <ets>-antis</ets>, p. pr. of <ets>malignare</ets>,
<ets>malignari</ets>, to do or make maliciously. See <er>Malign</er>,
and cf. <er>Benignant</er>.]</ety> <sn>1.</sn> <def>Disposed to do harm,
inflict suffering, or cause distress; actuated by extreme malevolence or
enmity; virulently inimical; bent on evil; malicious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>malignant</qex> and a turbaned Turk.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized or caused by evil intentions;
pernicious.</def> <ldquo/<xex>Malignant</xex> care.<rdquo/
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>malignant</qex> power upon my life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Something deleterious and <qex>malignant</qex> as his touch.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>Tending to produce death;
threatening a fatal issue; virulent; <as>as, <ex>malignant</ex>
diphtheria</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malignant pustule</b></col> <fld>(Med.)</fld>, <cd>a very
contagious disease produced by infection of subcutaneous tissues with
the bacterium <spn>Bacillus anthracis</spn>. It is transmitted to man
from animals and is characterized by the formation, at the point of
reception of the infection, of a vesicle or pustule which first enlarges
and then breaks down into an unhealthy ulcer. It is marked by profound
exhaustion and often fatal. The disease in animals is called
<altname>charbon</altname>; in man it is called <altname>cutaneous
anthrax</altname>, and formerly was sometimes called simply
<altname>anthrax</altname>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Malignant</ent><br/
<hw>Ma*lig"nant</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A man
of extreme enmity or evil intentions.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Hist.)</fld> <def>One of the adherents of
<person>Charles I.</person> or <person>Charles II.</person>; -- so
called by the opposite party.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malignant anemia</ent><br/
<hw>malignant anemia</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>A chronic
progressive anemia of older adults, thought to result from a lack of
intrinsic factor (a substance secreted by the stomach that is
responsible for the absorption of vitamin B-12); also called
<altname>pernicious anemia</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malignant melanoma</ent><br/
<hw>malignant melanoma</hw> <pos>n.</pos> <fld>(Med.)</fld>, <def>Any of
several malignant neoplasms (usually of the skin) consisting of
melanocytes; called also <altname>melanoma</altname>. It is classed as a
type of <isa>skin cancer</isa>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malignant neoplasm</ent><br/
<hw>malignant neoplasm</hw> <pos>n.</pos> <fld>(Med.)</fld>, <def>Same
as malignancy{4}.</def><br/
<syn><b>Syn. --</b> malignancy, malignance, malignant tumor, metastatic
tumor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malignant tumor</ent><br/
<hw>malignant tumor</hw> <pos>n.</pos> <fld>(Med.)</fld>, <def>Same as
malignancy{4}.</def><br/
<syn><b>Syn. --</b> malignancy, malignance, malignant tumor, metastatic
tumor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malignantly</ent><br/
<hw>ma*lig"nant*ly</hw>, <pos>adv.</pos> <def>In a malignant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maligned</ent><br/
<hw>maligned</hw> <pos>adj.</pos> <def>Assailed with contemptuous
language.</def><br/
<syn><b>Syn. --</b> reviled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maligner</ent><br/
<hw>ma*lign"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
maligns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malignify</ent><br/
<hw>ma*lig"ni*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Malignified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Malignifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>malignus</ets> malign + <ets>-fy</ets>.]</ety> <def>To make malign
or malignant.</def> <mark>[R.]</mark> <ldquo/A strong faith
<xex>malignified</xex>.<rdquo/ <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malignity</ent><br/
<hw>Ma*lig"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>malignit<eacute/</ets>, L. <ets>malignitas</ets>.]</ety>
<sn>1.</sn> <def>The state or quality of being malignant; disposition to
do evil; virulent enmity; malignancy; malice; spite.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Virulence; deadly quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His physicians discerned an invincible <qex>malignity</qex> in his
disease.</q> <rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Extreme evilness of nature or influence;
perniciousness; heinousness; <as>as, the <ex>malignity</ex> of
fraud</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Malice</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malignly</ent><br/
<hw>Ma*lign"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a malign
manner; with malignity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malinger</ent><br/
<hw>Ma*lin"ger</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>MAlingered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Malingering</conjf>.]</vmorph> <def>To act the part of a
malingerer; to feign illness or inability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malingerer</ent><br/
<hw>Ma*lin"ger*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>malingre</ets> sickly, weakly, prob. from <ets>mal</ets> ill + OF.
<ets>heingre</ets>, <ets>haingre</ets>, thin, lean, infirm, fr. L.
<ets>aeger</ets>.]</ety> <def>In the army, a soldier who feigns himself
sick, or who induces or protracts an illness, in order to avoid doing
his duty; hence, in general, one who shirks his duty by pretending
illness or inability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malingery</ent><br/
<hw>Ma*lin"ger*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The spirit or
practices of a malingerer; malingering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malison</ent><br/
<hw>Mal"i*son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>maleicon</ets>, L. <ets>maledictio</ets>. See <er>Malediction</er>,
and cf. <er>Benison</er>.]</ety> <def>Malediction; curse;
execration.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God's <qex>malison</qex> on his head who this gainsays.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malkin</ent><br/
<hw>Mal"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>Maud</ets>, the proper name. Cf. <er>Grimalkin</er>.]</ety>
<altsp>[Written also <asp>maukin</asp>.]</altsp> <sn>1.</sn>
<def>Originally, a kitchenmaid; a slattern.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mop made of clouts, used by the kitchen
servant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A scarecrow.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>A mop or sponge attached to a
jointed staff for swabbing out a cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mall</ent><br/
<hw>Mall</hw> <pr>(m<add/l; 277)</pr>, <pos>n.</pos> <altsp>[Written
also <asp>maul</asp>.]</altsp> <ety>[OE. <ets>malle</ets>, F.
<ets>mail</ets>, L. <ets>malleus</ets>. Cf. <er>Malleus</er>.]</ety>
<sn>1.</sn> <def>A large heavy wooden beetle; a mallet for driving
anything with force; a maul.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A heavy blow.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An old game played with <xex>malls</xex> or mallets
and balls. See <er>Pall-mall</er>.</def> <rj><au>Cotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A place where the game of <xex>mall</xex> was
played. Hence: A public walk; a level shaded walk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Part of the area was laid out in gravel walks, and planted with
elms; and these convenient and frequented walks obtained the name of the
City <qex>Mall</qex>.</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mall</ent><br/
<hw>Mall</hw> <pr>(m<add/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Malled</conjf> <pr>(m<add/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Malling</conjf>.]</vmorph> <ety>[Cf. OF.
<ets>mailler</ets>. See <er>Mall</er> beetle, and cf.
<er>Malleate</er>.]</ety> <def>To beat with a mall; to beat with
something heavy; to bruise; to maul.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mall</ent><br/
<hw>Mall</hw> <pr>(m<acr/l)</pr>, <pos>n.</pos> <ety>[LL.
<ets>mallum</ets> a public assembly; cf. OHG. <ets>mahal</ets> assembly,
transaction; akin to AS. <ets>m<ae/<edh/el</ets>, <ets>me<edh/el</ets>,
assembly, <ets>m<aemac/lan</ets> to speak, Goth. <ets>ma<thorn/l</ets>
market place.]</ety> <def>Formerly, among Teutonic nations, a meeting of
the notables of a state for the transaction of public business, such
meeting being a modification of the ancient popular assembly.</def>
Hence: <sd>(a)</sd> <def>A court of justice.</def> <sd>(b)</sd> <def>A
place where justice is administered.</def> <sd>(c)</sd> <def>A place
where public meetings are held.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Councils, which had been as frequent as diets or <qex>malls</qex>,
ceased.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mall</ent><br/
<hw>Mall</hw> <pr>(m<add/l)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
public access area containing a promenade for pedestrians; <as>as, to
gather near the Washington monument on the <ex>mall</ex> in
Washington</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The paved or grassy strip between two
roadways.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A shopping area with multiple shops and a concourse
for predominantly or exclusively pedestrian use; in cities the concourse
is usually a city street which may be temporarily or permamently closed
to motor vehicles; in suburban areas, a mall is often located on a
convenient highway, may be large, contained in one building or in
multiple buildings connected by (usually covered) walkways. Also called
<altname>shopping mall</altname></def><br/
[<source>PJC</source>]</p>

<p><ent>Mallard</ent><br/
<hw>Mal"lard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>malari</ets>,fr. <ets>m<acir/le</ets> male + <ets>-art</ets> =
<ets>-ard</ets>. See <er>Male</er>, <pos>a.</pos>, and
<er>-ard</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A drake; the
male of <spn>Anas boschas</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A large wild duck (<spn>Anas
boschas</spn>) inhabiting both America and Europe. The domestic duck has
descended from this species. Called also
<altname>greenhead</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleability</ent><br/
<hw>Mal"le*a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. F.
<ets>mall<eacute/abilit<eacute/</ets>.]</ety> <def>The quality or state
of being malleable; -- opposed to <contr>friability</contr> and
<contr>brittleness</contr>.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleable</ent><br/
<hw>Mal"le*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>mall<eacute/able</ets>, fr. LL. <ets>malleare</ets> to hammer. See
<er>Malleate</er>.]</ety> <sn>1.</sn> <def>Capable of being extended or
shaped by beating with a hammer, or by the pressure of rollers; --
applied to metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being influenced to behave as desired;
tractable; -- used mostly of children.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Malleable iron</b></col>, <cd>iron that is capable of
extension or of being shaped under the hammer; decarbonized cast iron.
See under <er>Iron</er>.</cd> -- <col><b>Malleable iron
castings</b></col>, <cd>articles cast from pig iron and made malleable
by heating then for several days in the presence of some substance, as
hematite, which deprives the cast iron of some of its
carbon.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleableize</ent><br/
<hw>Mal"le*a*ble*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
malleable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleableness</ent><br/
<hw>Mal"le*a*ble*ness</hw>, <pos>n.</pos> <def>Quality of being
malleable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleal</ent><br/
<hw>Mal"le*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to the malleus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleate</ent><br/
<hw>Mal"le*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Malleated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Malleating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>malleatus</ets> hammered, fr. <ets>malleus</ets> a hammer. See
<er>Mall</er>, <pos>v. t.</pos>]</ety> <def>To hammer; to beat into a
plate or leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleation</ent><br/
<hw>Mal`le*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>malleatio</ets>: cf. OF. <ets>mall<eacute/ation</ets>.]</ety>
<def>The act or process of beating into a plate, sheet, or leaf, as a
metal; extension by beating.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 888 --></p>

<p><ent>mallecho</ent><br/
<hw>mal"le*cho</hw> <pr>(m<acr/l"l<esl/*ch<omac/)</pr>, <pos>n.</pos>
<def>Same as <er>Malicho</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mallee</ent><br/
<hw>mal"lee</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A dwarf Australian eucalypt with a
number of thin stems springing from a thickened stock. The most common
species are <spn>Eucalyptus dumosa</spn> and <spn>Eucalyptus
Gracilis</spn>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Scrub or thicket formed by the mallee.</def>
<mark>[Australia]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mallee bird</ent><br/
<hw>mal*lee" bird`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <ety>[From
native name.]</ety> <def>The leipoa, or Australian moundbird; it
incubates eggs naturally in sandy mounds. See <er>Leipoa</er>.</def><br/
<syn><b>Syn. --</b> mallee fowl, mallee-fowl, leipoa, lowan, <spn>Leipoa
ocellata</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>mallee fowl</ent><br/
<hw>mallee fowl</hw> <pos>n.</pos> <fld>(Zool.)</fld>, <def>Same as
<er>mallee bird</er> (<spn>Leipoa ocellata</spn>). See also
<er>Leipoa</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mallee hen</ent><br/
<hw>mallee hen</hw> <pos>n.</pos> <fld>(Zool.)</fld>, <def>The adult
female of the mallee fowl (<spn>Leipoa ocellata</spn>). See
<er>Leipoa</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mallemoke</ent><br/
<ent>Mallemock</ent><br/
<mhw>{ <hw>Mal"le*mock</hw> <pr>(?)</pr>, <hw>Mal"le*moke</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Mollemoke</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mallenders</ent><br/
<hw>Mal"len*ders</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <fld>(Far.)</fld>
<def>Same as <er>Malanders</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleolar</ent><br/
<hw>Mal*le"o*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Malleolus</er>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to
the malleolus; in the region of the malleoli of the ankle
joint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleolus</ent><br/
\'d8<hw>Mal*le"*o*lus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Malleoli</plw> <pr>(#)</pr>.</plu> <ety>[L., dim.
of <ets>malleus</ets> hammer.]</ety> <sn>1.</sn> <fld>(Anat.)</fld>
<def>A projection at the distal end of each bone of the leg at the ankle
joint. The malleolus of the tibia is the internal projection, that of
the fibula the external.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def><ldquo/ A layer, <rdquo/ a shoot partly buried in
the ground, and there cut halfway through.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mallet</ent><br/
<hw>Mal"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>maillet</ets>, dim. of <ets>mail</ets>. See <er>Mall</er> a
beetle.]</ety> <def>A small maul with a short handle, -- used esp. for
driving a tool, as a chisel or the like; also, a light beetle with a
long handle, -- used in playing croquet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malleus</ent><br/
\'d8<hw>Mal"le*us</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mallei</plw> <pr>(#)</pr>.</plu> <ety>[L., hammer. See
<er>Mall</er> a beetle.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>The
outermost of the three small auditory bones, ossicles; the hammer. It is
attached to the tympanic membrane by a long process, the handle or
manubrium. See <xex>Illust.</xex> of <er>Far</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the hard lateral pieces of
the mastax of Rotifera. See <er>Mastax</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A genus of bivalve shells; the
hammer shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mallophaga</ent><br/
\'d8<hw>Mal*loph"a*ga</hw> <pr>(m<acr/l*l<ocr/f"<adot/*g<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>mallo`s</grk> a lock of wool +
<grk>fagei^n</grk> to eat.]</ety> <fld>(Zool.)</fld> <def>An extensive
group of insects which are parasitic on birds and mammals, and feed on
the feathers and hair; -- called also <altname>bird lice</altname>. See
<cref>Bird louse</cref>, under <er>Bird</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mallotus</ent><br/
\'d8<hw>Mal*lo"tus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr Gr.
<?/ fleecy.]</ety> <fld>(Zool.)</fld> <def>A genus of small Arctic
fishes. One American species, the capelin (<spn>Mallotus
villosus</spn>), is extensively used as bait for cod.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mallows</ent><br/
<ent>Mallow</ent><br/
<mhw>{ <hw>Mal"low</hw> <pr>(?)</pr>, <hw>Mal"lows</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[OE. <ets>malwe</ets>, AS. <ets>mealwe</ets>,
fr. L. <ets>malva</ets>, akin to Gr. <grk>mala`chh</grk>; cf.
<grk>mala`ssein</grk> to soften, <grk>malako`s</grk> soft. Named either
from its softening or relaxing properties, or from its soft downy
leaves. Cf. <er>Mauve</er>, <er>Malachite</er>.]</ety> <fld>(Bot.)</fld>
<def>A genus of plants (<gen>Malva</gen>) having mucilaginous qualities.
See <er>Malvaceous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The flowers of the common mallow (<spn>Malva
sylvestris</spn>) are used in medicine. The dwarf mallow (<spn>Malva
rotundifolia</spn>) is a common weed, and its flattened, dick-shaped
fruits are called <xex>cheeses</xex> by children. Tree mallow
(<spn>Malva Mauritiana</spn> and <spn>Lavatera arborea</spn>), musk
mallow (<spn>Malva moschata</spn>), rose mallow or hollyhock, and curled
mallow (<spn>Malva crispa</spn>), are less commonly seen.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Indian mallow</b></col>. <cd>See <er>Abutilon</er>.</cd>
-- <col><b>Jew's mallow</b></col>, <cd>a plant (<spn>Corchorus
olitorius</spn>) used as a pot herb by the Jews of Egypt and Syria.</cd>
-- <col><b>Marsh mallow</b></col>. <cd>See under
<er>Marsh</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mallow family</ent><br/
<hw>mallow family</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>The natural
family <fam>Malvaceae</fam>, a <isa>dilleniid dicot family</isa>
consisting of herbs and shrubs and some trees, and including the
mallows, cotton, and okra.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mallowwort</ent><br/
<hw>mal"low*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Any plant of the order <ord>Malvaceae</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malmbrick</ent><br/
<ent>Malm</ent><br/
<mhw>{ <hw>Malm</hw> <pr>(?)</pr>, <hw>Malm"brick`</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Cf. AS. <ets>mealm</ets> sand.]</ety> <def>A
kind of brick of a light brown or yellowish color, made of sand, clay,
and chalk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malma</ent><br/
<hw>mal"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
spotted trout (<spn>Salvelinus malma</spn>), inhabiting Northern
America, west of the Rocky Mountains; -- called also <altname>Dolly
Varden trout</altname>, <altname>bull trout</altname>,
<altname>red-spotted trout</altname>, and
<altname>golet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- Insert: Illustr. of Malma (Salvelinus malma) --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malmag</ent><br/
\'d8<hw>Mal"mag</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from native
name in Madagascar.]</ety> <fld>(Zool.)</fld> <def>The tarsius, or
spectral lemur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malmsey</ent><br/
<hw>Malm"sey</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>malvesie</ets>, F. <ets>malvoisie</ets>, It. <ets>malvasia</ets>,
<ets>malavagia</ets>, fr. <ets>Malvasia</ets>, or Napoli di
<ets>Malvasia</ets>, in the Morea.]</ety> <def>A kind of sweet wine from
Crete, the Canary Islands, etc.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>malnourished</ent><br/
<hw>malnourished</hw> <pos>adj.</pos> <def>Not getting adequate food;
suffering from malnutrition; underfed.</def> [Narrower terms:
<stype>starved, starving</stype>; <stype>unfed</stype>;
<stype>foodless</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malnutrition</ent><br/
<hw>mal`nu*tri"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>nutrition</ets>.]</ety>
<fld>(Physiol.)</fld> <def>Faulty or imperfect nutrition; inadequate or
unbalanced food intake.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malobservation</ent><br/
<hw>Mal*ob`ser*va"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>observation</ets>.]</ety> <def>Erroneous
observation.</def> <rj><au>J. S Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>malodor</ent><br/
<hw>mal*o"dor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An offensive
odor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malodorous</ent><br/
<hw>mal*o"dor*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Offensive to the
sense of smell; ill-smelling.</def> --
<wordforms><wf>mal*o"dor*ous*ness</wf>. <pos>n.</pos></wordforms>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>malodorousness</ent><br/
<hw>mal*o"dor*ous*ness</hw> <pos>n.</pos> <def>The attribute of having a
strong offensive smell.</def><br/
<syn><b>Syn. --</b> stinkiness, foulness, rankness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malonate</ent><br/
<hw>mal"o*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>A salt of malonic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malonic</ent><br/
<hw>Ma*lon"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a dicarboxylic acid produced
artifically as a white crystalline substance,
<chform>CH2.(CO2H)2</chform>, and so called because obtained by the
oxidation of <xex>malic</xex> acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malonyl</ent><br/
<hw>Mal"o*nyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Malonic</ets>
+ <ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A divalent diacyl
radical, <chform>CH2.(CO)2</chform>, from malonic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malonylurea</ent><br/
<hw>malonylurea</hw> <pos>n.</pos> <def>A white crystalline acid derived
from pyrimidine; it is used in preparing barbiturate drugs.</def><br/
<syn><b>Syn. --</b> barbituric acid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malope</ent><br/
<hw>malope</hw> <pos>n.</pos> <def>A Western Mediterranean annual
(<spn>Malope trifida</spn>) having deep purple-red flowers subtended by
three large cordate bracts.</def><br/
<syn><b>Syn. --</b> <spn>Malope trifida</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malopterurus</ent><br/
<hw>Malopterurus</hw> <pos>prop. n.</pos> <ety>[NL., from Gr.
<grk>malako`s</grk> soft + <grk>ptero`n</grk> wing + <grk>o'yra`</grk>
tail.]</ety> <fld>(Zool.)</fld> <def>A variant spelling of
<er>Malapterurus</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Malopterurus electricus</ent><br/
<hw>Malopterurus electricus</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld>
<def>See <er>Malopterurus electricus</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malosma</ent><br/
<hw>Malosma</hw> <pos>prop. n.</pos> <def>A genus having only one
species; often included in the genus <gen>Rhus</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Malosma</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malpais</ent><br/
<hw>Mal"pais`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>mal</ets>, <ets>malo</ets>, bad, and <ets>pa<iacute/s</ets>
country.]</ety> <fld>(Geol.)</fld> <def>The rough surface of a congealed
lava stream.</def> <mark>[Southwestern U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Malpighia</ent><br/
\'d8<hw>Mal*pi"ghi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Malpighian</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of tropical
American shrubs with opposite leaves and small white or reddish flowers.
The drupes of <spn>Malpighia glabra</spn> (formerly <spn>Malpighia
urens</spn>) are eaten under the name of <prod>Barbadoes
cherries</prod>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malpighiaceous</ent><br/
<hw>Mal*pi`ghi*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Of, pertaining to, or resembling, a natural order
of tropical trees and shrubs (<ord>Malpighiaceae</ord>), some of them
climbing plants, and their stems forming many of the curious lianes of
South American forests.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malpighia glabra</ent><br/
<hw>Malpighia glabra</hw> <pos>prop. n.</pos> <fld>(Bot.)</fld> <def>THe
species name of the acerola, also called <altname>barbados
cherry</altname>, a tropical American shrub bearing edible cherrylike
acid red fruit.</def><br/
<syn><b>Syn. --</b> barbados cherry, acerola, Surinam cherry, West
Indian cherry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malpighian</ent><br/
<hw>Mal*pi"ghi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of, pertaining to, or discovered by, <person>Marcello
<etsep>Malpighi</etsep></person>, an Italian anatomist of the 17th
century.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Malpighian capsules</b></col> <it>or</it>
<col><b>Malpighian corpuscles</b></col></mcol> <fld>(Anatomy)</fld>,
<cd>the globular dilatations, containing the glomeruli or Malpighian
tufts, at the extremities of the urinary tubules of the kidney.</cd> --
<col><b>Malpighian corpuscles of the spleen</b></col>, <cd>masses of
adenoid tissue connected with branches of the splenic
artery.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>malpighian body</ent><br/
<hw>malpighian body</hw> <pos>n.</pos> <fld>(Anatomy)</fld>, <def>The
capsule that contains a glomerulus at the expanded end of a nephron;
also called <altname>malpighian corpuscle</altname> and
<altname>Malpighian capsule</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malpighian corpuscle</ent><br/
<hw>malpighian corpuscle</hw> <pos>n.</pos> <fld>(Anatomy)</fld>,
<def>See malpighian body.</def><br/
<syn><b>Syn. --</b> malpighian body, Malpighian capsule.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malpighian layer</ent><br/
<hw>malpighian layer</hw> <pos>n.</pos> <fld>(Anatomy)</fld>, <def>The
innermost layer of the epidermis.</def><br/
<syn><b>Syn. --</b> stratum germinativum, rete Malpighii.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malposed tooth</ent><br/
<hw>malposed tooth</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>A tooth
that has grown in a faulty position.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malposition</ent><br/
<hw>Mal`po*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mal-</ets> + <ets>position</ets>.]</ety> <def>A wrong
position.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malpractice</ent><br/
<hw>Mal*prac"tice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mal-</ets>
+ <ets>practice</ets>.]</ety> <def>Evil practice; illegal or immoral
conduct; practice contrary to established rules; specifically, the
treatment of a case by a surgeon or physician in a manner which is
contrary to accepted rules and productive of unfavorable results.</def>
<altsp>[Written also <asp>malepractice</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malt</ent><br/
<hw>Malt</hw> <pr>(m<add/lt)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mealt</ets>; akin to D. <ets>mout</ets>, G. <ets>malz</ets>, Icel.,
Sw., & Dan. <ets>malt</ets>, and E. <ets>melt</ets>. <root/108. See
<er>Melt</er>.]</ety> <def>Barley or other grain, steeped in water and
dried in a kiln, thus forcing germination until the saccharine principle
has been evolved. It is used in brewing and in the distillation of
whisky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malt</ent><br/
<hw>Malt</hw>, <pos>a.</pos> <def>Relating to, containing, or made with,
malt.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malt liquor</b></col>, <cd>an alcoholic liquor, as beer,
ale, porter, etc., prepared by fermenting an infusion of malt.</cd> --
<col><b>Malt dust</b></col>, <cd>fine particles of malt, or of the grain
used in making malt; -- used as a fertilizer.</cd> <ldquo/ <xex>Malt
dust</xex> consists chiefly of the infant radicle separated from the
grain.<rdquo/ <au>Sir H. Davy.</au> -- <col><b>Malt floor</b></col>,
<cd>a floor for drying malt.</cd> -- <mcol><col><b>Malt house</b></col>,
<it>or</it> <col><b>Malthouse</b></col></mcol>, <cd>a house in which
malt is made.</cd> -- <col><b>Malt kiln</b></col>, <cd>a heated chamber
for drying malt.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malt</ent><br/
<hw>Malt</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Malted</conjf>: <pos>p. pr. & vb. n.</pos>
<conjf>Malting</conjf>.]</vmorph> <def>To make into malt; <as>as, to
<ex>malt</ex> barley</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malt</ent><br/
<hw>Malt</hw>, <pos>v. i.</pos> <def>To become malt; also, to make grain
into malt.</def> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malta</ent><br/
<hw>Malta</hw> <pos>n.</pos> <sn>1.</sn> <def>A country on the island of
Malta.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An island south of Sicily in the Mediterranean
Sea.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malta fever</ent><br/
<hw>malta fever</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>An infectious
disease contracted from meat or milk products from infected domestic
animals; called also <altname>brucellosis</altname> and
<altname>undulant fever</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maltalent</ent><br/
<hw>Mal"ta*lent</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Malice</er>, and <er>Talent</er>.]</ety> <def>Ill will;
malice.</def> <mark>[Obs.]</mark> <rj><au>Rom. of R.</au>
<au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maltase</ent><br/
<hw>malt"ase</hw> <pr>(m<add/lt"<amac/s)</pr>, <pos>n.</pos>
<fld>(Biochem.)</fld> <def>An enzyme, <alpha/-D-glucosidase, which
hydrolyzes maltose with production of glucose, and also hydrolyzes
certain other <alpha/-D-glucosides.</def><br/
[<source>PJC</source>]</p>

<p><ent>malted</ent><br/
<hw>malt"ed</hw> <pr>(m<add/lt"<ecr/d)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Same as <er>malted milk</er>{1}.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malted milk</ent><br/
<hw>malted milk</hw> <pos>n.</pos> <sn>1.</sn> <def>A milkshake made
with malt powder; also called simply a
<altname>malted</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A powder made of dried milk and malted
cereals.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maltese</ent><br/
<hw>Mal*tese"</hw> <pr>(m<add/l*t<emac/s" or m<add/l*t<emac/z")</pr>,
<pos>prop. a.</pos> <def>Of or pertaining to <etsep>Malta</etsep> or to
its inhabitants.</def> -- <def2><pos>n. sing. & pl.</pos> <def>A native
or inhabitant of Malta; the people of Malta.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maltese cross</b></col>. <cd>See <xex>Illust.</xex> 5, of
<er>Cross</er>.</cd> -- <col><b>Maltese dog</b></col>
<fld>(Zool.)</fld>, <cd>a breed of small terriers, having long silky
white hair. The breed originated in Malta.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>maltese cat</ent><br/
<hw>maltese cat</hw> <pos>n.</pos> <fld>(Zool.)</fld>, <def>A
short-haired bluish-gray breed of the domestic cat.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maltese cross</ent><br/
<hw>maltese cross</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A Eurasian
garden perennial (<spn>Lychins chalcedonica</spn>) having scarlet
flowers in dense terminal heads.</def><br/
<syn><b>Syn. --</b> scarlet lychnis, <spn>Lychins
chalcedonica</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A cross with triangular or arrow-shaped arms and the
points toward the center. See illustration under
<er>cross</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maltese dog</ent><br/
<hw>Maltese dog</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A breed of
<isa>toy dog</isa> having a long straight silky white coat; also called
a <altname>Maltese</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maltese pound</ent><br/
<hw>maltese pound</hw> <pos>n.</pos> <def>The monetary unit of
Malta.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maltha</ent><br/
\'d8<hw>Mal"tha</hw> <pr>(m<acr/l"th<adot/)</pr>, <pos>n.</pos>
<ety>[L., fr. Gr. <grk>ma`lqa</grk>.]</ety> <sn>1.</sn> <def>A variety
of bitumen, viscid and tenacious, like pitch, unctuous to the touch, and
exhaling a bituminous odor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mortar.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malthus</ent><br/
<hw>Malthus</hw> <pos>prop. n.</pos> <def>Thomas Robert Malthus, an
English economist who argued that increases in population would outgrow
increases in the means of subsistence (1766-1834).</def><br/
<syn><b>Syn. --</b> Thomas Malthus, Thomas Robert Malthus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malthusian</ent><br/
<hw>Mal*thu"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to the political economist, the <person>Rev. T. R.
<etsep>Malthus</etsep></person>, or conforming to his views; <as>as,
<ex>Malthusian</ex> theories</as>. See <er>Malthus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Malthus held that population tends to increase faster
than its means of subsistence can be made to do, and hence that the
lower classes must necessarily suffer more or less from lack of food,
unless an increase of population be checked by prudential restraint or
otherwise. The steadily increasing capacity of world economic systems
and food production has proven this theory to be at least premature,
since economic production has increased notably faster than population
since the time of Malthus. The general notion that there is an ultimate
limit on the ability of mankind to continue increasing food and goods in
proportion to population is still held by many people, especially
environmentalists, some of whom who feel that the chief limiting factor
will be the inability to dispose of the waste products of industry,
leading to a steady degradation of the environment in the absence of
population limitation. However, even those that believe this differ
widely in their estimates of when this limit will be reached.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Malthusian</ent><br/
<hw>Mal*thu"sian</hw>, <pos>n.</pos> <def>A follower of
Malthus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malthusianism</ent><br/
<hw>Mal*thu"sian*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The system of
Malthusian doctrines relating to population. See
<er>Malthusian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malthusian theory</ent><br/
<hw>malthusian theory</hw> <pos>n.</pos> <def>Malthus' theory that
population increase would outpace increases in the means of subsistence;
Malthusianism. See <er>Malthusian</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maltine</ent><br/
<ent>Maltin</ent><br/
<mhw>{ <hw>Malt"in</hw> <pr>(?)</pr>, <hw>Malt"ine</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <fld>(Physiol. Chem.)</fld> <def>The fermentative
principle of malt; malt diastase; also, a name given to various
medicinal preparations made from or containing malt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malting</ent><br/
<hw>Malt"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The process of
making, or of becoming malt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>malt liquor</ent><br/
<hw>malt liquor</hw> <pos>n.</pos> <def>An alcoholic drink made with
malt.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maltman</ent><br/
<hw>Malt"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Maltmen</plw> <pr>(<?/)</pr>.</plu> <def>A man whose occupation is
to make malt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maltobiose</ent><br/
<hw>mal"to*bi"ose</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Maltose; <altname>malt sugar</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maltonic</ent><br/
<hw>Mal*ton"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, pertaining to, or derived from, maltose; specif., designating
an acid called also <altname>gluconic</altname> or
<altname>dextronic</altname> acid. See <er>Gluconic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maltose</ent><br/
<hw>Malt"ose`</hw> <pr>(m<add/lt"<omac/s`)</pr>, <pos>n.</pos>
<ety>[From <er>Malt</er>.]</ety> <fld>(Biochem.)</fld> <def>A
crystalline disaccharide (<chform>C12H22O11</chform>) formed from starch
by the action of diastase of malt, and the amylolytic ferment of saliva
and pancreatic juice; called also <altname>maltobiose</altname> and
<altname>malt sugar</altname>. Chemically it is
<chname>4-O-<alpha/-D-glucopyranosyl-D-glucose</chname>. It rotates the
plane of polarized light further to the right than does dextrose and
possesses a lower cupric oxide reducing power.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>maltreat</ent><br/
<hw>mal*treat"</hw> <pr>(m<acr/l*tr<emac/t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Maltreated</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Maltreating</conjf>.]</vmorph>
<ety>[<ets>Mal-</ets> + <ets>treat</ets>: cf. F.
<ets>maltraiter</ets>.]</ety> <def>To treat ill; to abuse; to treat
roughly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maltreatment</ent><br/
<hw>mal*treat"ment</hw> <pr>(?)</pr>, <pos>n.</pos>; <ety>[Cf. F.
<ets>maltraitement</ets>.]</ety> <def>Cruel or inhumane treatment; ill
usage; abuse.</def><br/
<syn><b>Syn. --</b> ill-treatment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maltster</ent><br/
<hw>Malt"ster</hw> <pr>(m<add/lt"st<etil/r)</pr>, <pos>n.</pos> <def>A
maltman.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>malt sugar</ent><br/
<hw>malt sugar</hw> <pos>n.</pos> <def>Same as
<er>maltose</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>malt whisky</ent><br/
<ent>malt whiskey</ent><br/
<mhw><hw>malt whiskey</hw>, <hw>malt whisky</hw></mhw> <pos>n.</pos>
<def>A whiskey distilled in Scotland (esp. whiskey made from malted
barley in a pot still); Scotch whisky.</def><br/
<syn><b>Syn. --</b> Scotch, Scotch-whiskey, Scotch whisky.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maltworm</ent><br/
<hw>malt"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tippler.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>malty</ent><br/
<hw>malt"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing, or like,
malt.</def> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malum</ent><br/
\'d8<hw>Ma"lum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mala</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>An evil. See
<er>Mala</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malva</ent><br/
<hw>Malva</hw> <pos>prop. n.</pos> <def>A genus of herbs and subshrubs
including the mallows.</def><br/
<syn><b>Syn. --</b> genus <gen>Malva</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malvaceae</ent><br/
<hw>Malvaceae</hw> <pos>prop. n.</pos> <def>A natural family of herbs
and shrubs and some trees, including the mallows, cotton, and okra; the
<altname>mallow family</altname>.</def><br/
<syn><b>Syn. --</b> family <fam>Malvaceae</fam>, mallow
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malvaceous</ent><br/
<hw>Mal*va"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>malvaceus</ets>, from <ets>malva</ets> mallows. See
<er>Mallow</er>.]</ety> <fld>(Bot.)</fld> <def>Pertaining to, or
resembling, a natural family of plants (<fam>Malvaceae</fam>), of which
the mallow is the type. The cotton plant, hollyhock, and abutilon are of
this family. It was formerly classified as an order, and included the
baobab and the silk-cotton trees. The baobab and silk-cotton trees are
now placed in the family <fam>Bombacaceae</fam>, which is included with
the <fam>Malvaceae</fam> in the order <ord>Malvales</ord>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Malvales</ent><br/
<hw>Malvales</hw> <pos>n.</pos> <def>A natural order of plants including
the families <fam>Malvaceae</fam>, <fam>Bombacaceae</fam>,
<fam>Elaeocarpaceae</fam>, <fam>Sterculiaceae</fam>, and
<fam>Tiliaceae</fam>.</def><br/
<syn><b>Syn. --</b> order <ord>Malvales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malva neglecta</ent><br/
<hw>Malva neglecta</hw> <pos>prop. n.</pos> <fld>(Bot.)</fld> <def>The
species name of the common mallow, an annual Old World plant with
clusters of pink or white flowers; naturalized in U.S..</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>malvasia</ent><br/
<hw>malvasia</hw> <pos>n.</pos> <def>A sweet grape used to make malmsey
wine.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malvastrum</ent><br/
<hw>Malvastrum</hw> <pos>n.</pos> <def>A genus of mallows characterized
by red and yellow flowers often placed in other genera.</def><br/
<syn><b>Syn. --</b> genus <gen>Malvastrum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malva sylvestris</ent><br/
<hw>Malva sylvestris</hw><pos>prop. n.</pos> <fld>(Bot.)</fld> <def>The
species name of the tall mallow, an erect or decumbent Old World
perennial with axillary clusters of rosy-purple flowers; introduced into
the U. S.</def><br/
<syn><b>Syn. --</b> tall mallow, high mallow, cheese,
cheeseflower.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malvaviscus</ent><br/
<hw>Malvaviscus</hw> <pos>n.</pos> <def>A small genus of shrubs of
Central and South America: wax mallows.</def><br/
<syn><b>Syn. --</b> genus <gen>Malvaviscus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Malversation</ent><br/
<hw>Mal`ver*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>malverser</ets> to be corrupt in office, fr. L. <ets>male</ets> ill
+ <ets>versari</ets> to move about, to occupy one's self,
<ets>vertere</ets> to turn. See <er>Malice</er>, and
<er>Verse</er>.]</ety> <def>Evil conduct; fraudulent practices;
misbehavior, corruption, or extortion in office.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Malvesie</ent><br/
<hw>Mal"ve*sie</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Malmsey wine. See
<er>Malmsey</er>.</def> <ldquo/ A jub of <xex>malvesye</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mam</ent><br/
<hw>Mam</hw> <pr>(m<acr/m)</pr>, <pos>n.</pos> <ety>[Abbrev. fr.
<ets>mamma</ets>.]</ety> <def>Mamma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mama</ent><br/
<hw>Ma*ma"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mamma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mamaluke</ent><br/
<hw>Mam"a*luke</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mameluke</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mama's boy</ent><br/
<hw>mama's boy</hw> <pos>n.</pos> <def>Same as <er>mamma's
boy</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mamelon</ent><br/
\'d8<hw>Mam"e*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A rounded hillock; a rounded elevation or protuberance.</def>
<rj><au>Westmin. Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mameluco</ent><br/
\'d8<hw>Mam`e*lu"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.]</ety>
<def>A child born of a white father and Indian mother.</def> <mark>[S.
Amer.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mameluke</ent><br/
<hw>Mam"e*luke</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mamelouk</ets>, cf. Sp. <ets>mameluco</ets>, It.
<ets>mammalucco</ets>; all fr. Ar. <ets>maml<umac/k</ets> a purchased
slave or captive; lit., possessed or in one's power, p. p. of
<ets>malaka</ets> to possesses.]</ety> <def>One of a body of mounted
soldiers recruited from slaves converted to Muslimism, who, during
several centuries, had more or less control of the government of Egypt,
until exterminated or dispersed by <person>Mehemet Ali</person> in
1811.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mamillated</ent><br/
<hw>Mam"il*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Mammillated</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mamma</ent><br/
<hw>Mam*ma"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Reduplicated from the
infantine word <ets>ma</ets>, influenced in spelling by L.
<ets>mamma</ets>.]</ety> <def>Mother; -- word of tenderness and
familiarity.</def> <altsp>[Written also <asp>mama</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Tell tales papa and <qex>mamma</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mamma</ent><br/
<hw>Mam"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mammae</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>mamma</ets>
breast.]</ety> <fld>(Anat.)</fld> <def>A glandular organ for secreting
milk, characteristic of all mammals, but usually rudimentary in the
male; a mammary gland; a breast; udder; bag.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammal</ent><br/
<hw>Mam"mal</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mammals</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>mammalis</ets>
belonging to the breast, fr. <ets>mamma</ets> the breast or pap: cf. F.
<ets>mammal</ets>.]</ety> <fld>(Zool.)</fld> <def>One of the
Mammalia.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Age of mammals</b></col>. <cd>See under <er>Age</er>,
<pos>n.</pos>, 8.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammalia</ent><br/
\'d8<hw>Mam*ma"li*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., from
L. <ets>mammalis</ets>. See <er>Mammal</er>.]</ety> <fld>(Zool.)</fld>
<def>The highest class of Vertebrata. The young are nourished for a time
by milk, or an analogous fluid, secreted by the mammary glands of the
mother.</def><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ Mammalia are divided into three subclasses; --<br/
[<source>1913 Webster</source>]</p>

<p>I. <stype>Placentalia</stype>. This subclass embraces all the higher
orders, including man. In these the fetus is attached to the uterus by a
placenta.<br/
[<source>1913 Webster</source>]</p>

<p>II. <stype>Marsupialia</stype>. In these no placenta is formed, and
the young, which are born at an early state of development, are carried
for a time attached to the teats, and usually protected by a marsupial
pouch. The opossum, kangaroo, wombat, and koala are examples.<br/
[<source>1913 Webster</source>]</p>

<p>III. <stype>Monotremata</stype>. In this group, which includes the
genera <gen>Echidna</gen> and <gen>Ornithorhynchus</gen>, the female
lays large eggs resembling those of a bird or lizard, and the young,
which are hatched like those of birds, are nourished by a watery
secretion from the imperfectly developed mammae.<br/
[<source>1913 Webster</source>]</p></note>

<p><ent>Mammalian</ent><br/
<hw>Mam*ma"li*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to the Mammalia or mammals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammaliferous</ent><br/
<hw>Mam`ma*lif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mammal</ets> + <ets>-ferous</ets>.]</ety> <fld>(Geol.)</fld>
<def>Containing mammalian remains; -- said of certain strata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammalogical</ent><br/
<hw>Mam`ma*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to mammalogy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammalogist</ent><br/
<hw>Mam*mal"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mammalogiste</ets>.]</ety> <def>One versed in mammalogy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammalogy</ent><br/
<hw>Mam*mal"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mamma</ets>
breast + <ets>-logy</ets>: cf. f. <ets>mammalogie</ets>.]</ety> <def>The
science which relates to mammals or the <class>Mammalia</class>. See
<er>Mammalia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammary</ent><br/
<hw>Mam"ma*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mammaire</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to
the mammae or breasts; <as>as, the <ex>mammary</ex> arteries and
veins</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mammary gland</ent><br/
<hw>mammary gland</hw> <pos>n.</pos> <def>The milk-secreting organ of
female mammals.</def><br/
<syn><b>Syn. --</b> mamma.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mama's boy</ent><br/
<hw>mama's boy</hw> <pos>n.</pos> <def>A boy excessively attached to his
mother; a boy lacking the usual masculine interests; also spelled
<asp>mamma's boy</asp>.</def><br/
<syn><b>Syn. --</b> mother's boy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mammea</ent><br/
<hw>Mammea</hw> <pos>n.</pos> <def>A genus of American and Asiatic trees
having edible one-seeded fruit.</def><br/
<syn><b>Syn. --</b> genus <gen>Mammea</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mammea americana</ent><br/
<hw>Mammea americana</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>The
speciaes name for the mammee tree.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mammee tree</ent><br/
<ent>Mammee</ent><br/
<mhw><hw>Mam*mee"</hw>, <hw>Mam*mee" tree`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Haitian <ets>mamey</ets>.]</ety> <fld>(Bot.)</fld>
<def>A fruit tree of tropical America, belonging to the genus
<gen>Mammea</gen> (<spn>Mammea Americana</spn>); also, its fruit, called
the <prod>mammee apple</prod>. The latter is large, covered with a
thick, tough ring, and contains a bright yellow pulp of a pleasant taste
and fragrant scent. It is often called <altname>mammee
apple</altname>.</def><br/
<syn><b>Syn. --</b> mammee apple, mammee, mamey, <spn>Mammea
americana</spn>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>mammee apple</ent><br/
<hw>mammee apple</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A tropical
American tree (<spn>Mammea americana</spn>) having edible fruit (the
<prod>mammee apple</prod>) with a leathery rind.</def><br/
<syn><b>Syn. --</b> mammee, mamey, mammee tree, <spn>Mammea
americana</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The globular or ovoid tropical fruit of the mammee
tree (<spn>Mammea americana</spn>), having a thick russet leathery rind
and juicy yellow or reddish flesh.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mammer</ent><br/
<hw>Mam"mer</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. G.
<ets>memme</ets> coward, poltroon.]</ety> <def>To hesitate; to mutter
doubtfully.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammet</ent><br/
<hw>Mam"met</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mawmet</er>.]</ety> <def>An idol; a puppet; a doll.</def>
<mark>[Obs.]</mark> <rj><au>Selden.</au> <au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammetry</ent><br/
<hw>Mam"met*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mawmetry</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammifer</ent><br/
<hw>Mam"mi*fer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Mammiferous</er>.]</ety> <fld>(Zool.)</fld> <def>A mammal. See
<er>Mammalia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammiferous</ent><br/
<hw>Mam*mif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mamma</ets> breast + <ets>-ferous</ets>: cf. F.
<ets>mammif<egrave/re</ets>.]</ety> <def>Having breasts; of, pertaining
to, or derived from, the Mammalia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammiform</ent><br/
<hw>Mam"mi*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mamma</ets>
breast + <ets>-form</ets>: cf. F. <ets>mammiforme</ets>.]</ety>
<def>Having the form of a mamma (breast) or mammae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammilla</ent><br/
\'d8<hw>Mam*mil"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mammilae</plw> <pr>(#)</pr>.</plu> <ety>[L., dim. of
<ets>mamma</ets> a breast.]</ety> <fld>(Anat.)</fld> <def>The
nipple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammillary</ent><br/
<hw>Mam"mil*la*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mammilaire</ets>. See <er>Mammilla</er>.]</ety> <sn>1.</sn> <def>Of
or pertaining to the mammilla, or nipple, or to the breast; resembling a
mammilla; mammilloid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>Composed of convex convex
concretions, somewhat resembling the breasts in form; studded with small
mammiform protuberances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammillated</ent><br/
<ent>Mammillate</ent><br/
<mhw>{ <hw>Mam"mil*late</hw> <pr>(?)</pr>, <hw>Mam"mil*la`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Mammilla</er>.]</ety>
<sn>1.</sn> <def>Having small nipples, or small protuberances like
nipples or mammae.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Bounded like a nipple; -- said of
the apex of some shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammilliform</ent><br/
<hw>Mam*mil"li*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mammilla</ets> + <ets>-form</ets>.]</ety> <def>Having the
form of a mammilla.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammilloid</ent><br/
<hw>Mam"mil*loid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mammilla</ets> + <ets>-oid</ets>.]</ety> <def>Like a mammilla
or nipple; mammilliform.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammock</ent><br/
<hw>Mam"mock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ir. & Gael.
<ets>mam</ets> a round hill + <ets>-ock</ets>.]</ety> <def>A shapeless
piece; a fragment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammock</ent><br/
<hw>Mam"mock</hw>, <pos>v. t.</pos> <def>To tear to pieces.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammodis</ent><br/
<hw>Mam"mo*dis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mamoudis</ets>, fr. Hind. <ets>mahm<umac/d<imac/</ets> a
muslin.]</ety> <def>Coarse plain India muslins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammology</ent><br/
<hw>Mam*mol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mamma</ets>
+ <ets>-logy</ets>.]</ety> <def>Mastology. See
<er>Mammalogy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammon</ent><br/
<hw>Mam"mon</hw> <pr>(m<acr/m"m<ucr/n)</pr>, <pos>n.</pos> <ety>[L.
<ets>mammona</ets>, Gr. <grk>mammwna^s</grk> riches, Syr.
<ets>mam<omac/n<amac/</ets>; cf. Heb. <ets>matm<omac/n</ets> a hiding
place, subterranean storehouse, treasury, fr. <ets>t<amac/man</ets> to
hide.]</ety> <def>Riches; wealth; the god of riches; riches,
personified.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye can not serve God and <qex>Mammon</qex>.</q> <rj><qau>Matt. vi.
24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammonish</ent><br/
<hw>Mam"mon*ish</hw>, <pos>a.</pos> <def>Actuated or prompted by a
devotion to money getting or the service of Mammon.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammonism</ent><br/
<hw>Mam"mon*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Devotion to the
pursuit of wealth; worldliness.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammonist</ent><br/
<hw>Mam"mon*ist</hw>, <pos>n.</pos> <def>A mammonite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammonite</ent><br/
<hw>Mam"mon*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One devoted to the
acquisition of wealth or the service of Mammon.</def> <rj><au>C.
Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammonization</ent><br/
<hw>Mam`mon*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The process
of making mammonish; the state of being under the influence of
mammonism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammonize</ent><br/
<hw>Mam"mon*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
mammonish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammose</ent><br/
<hw>Mam*mose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mammosus</ets> having large breasts, <ets>mamma</ets>
breast.]</ety> <fld>(Bot.)</fld> <def>Having the form of the breast;
breast-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 889 --></p>

<p><ent>Mammoth</ent><br/
<hw>Mam"moth</hw> <pr>(m<acr/m"m<ocr/th)</pr>, <pos>n.</pos> <ety>[Russ.
<ets>m<acir/mont</ets>, <ets>m<aacute/mant</ets>, fr. Tartar
<ets>mamma</ets> the earth. Certain Tartar races, the Tungooses and
Yakoots, believed that the mammoth worked its way in the earth like a
mole.]</ety> <fld>(Zool.)</fld> <def>An extinct, hairy, maned elephant
(<spn>Mammuthus primigenius</spn> formerly <spn>Elephas
primigenius</spn>), of enormous size, remains of which are found in the
northern parts of both continents. The last of the race, in Europe, were
coeval with prehistoric man.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Several specimens have been found in Siberia preserved
entire, with the flesh and hair remaining. They were imbedded in the ice
cliffs at a remote period, and became exposed by the melting of the
ice.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammoth</ent><br/
<hw>Mam"moth</hw> <pr>(m<acr/m"m<ocr/th)</pr>, <pos>a.</pos>
<def>Resembling the mammoth in size; very large; gigantic; <as>as, a
<ex>mammoth</ex> ox</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mammothrept</ent><br/
<hw>mam"mo*thrept</hw> <pr>(m<acr/m"m<osl/*thr<ecr/pt)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>mammo`qreptos</grk>; <grk>ma`mma</grk>
grandmother + <grk>tre`pein</grk> to nourish.]</ety> <def>A child
brought up by its grandmother; a spoiled child.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>O, you are a more <qex>mammothrept</qex> in judgment.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mammuthus</ent><br/
<hw>Mammuthus</hw> <pos>prop. n.</pos> <def>An extinct genus comprising
the mammoths.</def><br/
<syn><b>Syn. --</b> genus <gen>Mammuthus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mammuthus primigenius</ent><br/
<hw>Mammuthus primigenius</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld>
<def>The species name for the woolly mammoth, a very hairy mammoth
common in colder portions of the Northern hemisphere.</def><br/
<syn><b>Syn. --</b> woolly mammoth, northern mammoth.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mammutidae</ent><br/
<hw>Mammutidae</hw> <pos>prop. n.</pos> <def>An extinct natural family
of mammals, comprising the mastodons.</def><br/
<syn><b>Syn. --</b> family <fam>Mammutidae</fam>, family
<fam>Mastodontidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mammy</ent><br/
<hw>mam"my</hw> <pr>(m<acr/m"m<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>mammies</plw> <pr>(m<acr/m"m<icr/z)</pr>.</plu>
<def>A child's name for <sig>mamma</sig>, mother.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mamoncillo</ent><br/
<hw>mamoncillo</hw> <pos>n.</pos> <def>A tropical American tree
(<spn>Melicocca bijuga</spn>, or <spn>Melicocca bijugatus</spn>) bearing
a small edible fruit with green leathery skin and sweet juicy
translucent pulp.</def><br/
<syn><b>Syn. --</b> Spanish lime, Spanish lime tree, honey berry, genip,
ginep, <spn>Melicocca bijuga</spn>, <spn>Melicocca
bijugatus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mamzer</ent><br/
\'d8<hw>Mam"zer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>m<aacute/mz<emac/r</ets>.]</ety> <def>A person born of relations
between whom marriage was forbidden by the Mosaic law; a bastard.</def>
<au>Deut. xxiii. 2 (Douay version).</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Man</ent><br/
<hw>Man</hw> <pr>(m<acr/n)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Men</plw> <pr>(m<ecr/n)</pr>.</plu> <ety>[AS. <ets>mann</ets>,
<ets>man</ets>, <ets>monn</ets>, <ets>mon</ets>; akin to OS., D., & OHG.
<ets>man</ets>, G. <ets>mann</ets>, Icel. <ets>ma<edh/r</ets>, for
<ets>mannr</ets>, Dan. <ets>Mand</ets>, Sw. <ets>man</ets>, Goth.
<ets>manna</ets>, Skr. <ets>manu</ets>, <ets>manus</ets>, and perh. to
Skr. <ets>man</ets> to think, and E. <ets>mind</ets>. <root/104. Cf.
<er>Minx</er> a pert girl.]</ety> <sn>1.</sn> <def>A human being; --
opposed to <contr>beast</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These <qex>men</qex> went about wide, and <qex>man</qex> found
they none,<br/
But fair country, and wild beast many [a] one.</q> <rj><qau>R. of
Glouc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The king is but a <qex>man</qex>, as I am; the violet smells to
him as it doth to me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'Tain't a fit night out for <qex>man</qex> nor beast!</q>
<rj><qau>W. C. Fields</qau></rj><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Especially:</specif> <def>An adult male person; a
grown-up male person, as distinguished from a woman or a
child.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When I became a <qex>man</qex>, I put away childish things.</q>
<rj><qau>I Cor. xiii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ceneus, a woman once, and once a <qex>man</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The human race; mankind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And God said, Let us make <qex>man</qex> in our image, after our
likeness, and let them have dominion.</q> <rj><qau>Gen. i.
26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The proper study of mankind is <qex>man</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The male portion of the human race.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Woman has, in general, much stronger propensity than
<qex>man</qex> to the discharge of parental duties.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One possessing in a high degree the distinctive
qualities of manhood; one having manly excellence of any kind.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This was the noblest Roman of them all . . . the elements<br/
So mixed in him that Nature might stand up<br/
And say to all the world <ldquo/This was a <qex>man</qex>!<rdquo/</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An adult male servant; also, a vassal; a
subject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like master, like <qex>man</qex>.</q> <rj><qau>Old
Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The vassal, or tenant, kneeling, ungirt, uncovered, and holding up
his hands between those of his lord, professed that he did become his
<qex>man</qex> from that day forth, of life, limb, and earthly
honor.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A term of familiar address at one time implying on
the part of the speaker some degree of authority, impatience, or haste;
<as>as, Come, <ex>man</ex>, we 've no time to lose!</as> In the latter
half of the 20th century it became used in a broader sense as simply a
familiar and informal form of address, but is not used in business or
formal situations; <as>as, hey, <ex>man</ex>! You want to go to a movie
tonight?</as>.</def> <mark>[Informal]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>8.</sn> <def>A married man; a husband; -- correlative to
<inv>wife</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I pronounce that they are <qex>man</qex> and wife.</q>
<rj><qau>Book of Com. Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>every wife ought to answer for her <qex>man</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>One, or any one, indefinitely; -- a modified
survival of the Saxon use of <xex>man</xex>, or <xex>mon</xex>, as an
indefinite pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>man</qex> can not make him laugh.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>man</qex> would expect to find some antiquities; but all
they have to show of this nature is an old rostrum of a Roman ship.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>One of the piece with which certain games, as chess
or draughts, are played.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Man</ex> is often used as a prefix in composition,
or as a separate adjective, its sense being usually self-explaining; as,
<ex>man</ex> child, <ex>man</ex> eater or <ex>man</ex>eater,
<ex>man-</ex>eating, <ex>man</ex> hater or <ex>man</ex>hater,
<ex>man-</ex>hating, <ex>man</ex>hunter, <ex>man-</ex>hunting,
<ex>man</ex>killer, <ex>man-</ex>killing, <ex>man</ex> midwife,
<ex>man</ex> pleaser, <ex>man</ex> servant, <ex>man-</ex>shaped,
<ex>man</ex>slayer, <ex>man</ex>stealer, <ex>man-stealing</ex>,
<ex>man</ex>thief, <ex>man</ex> worship, etc.<br/
<br/
<ex>Man</ex> is also used as a suffix to denote a person of the male sex
having a business which pertains to the thing spoken of in the
qualifying part of the compound; ash<ex>man</ex>, butter<ex>man</ex>,
laundry<ex>man</ex>, lumber<ex>man</ex>, milk<ex>man</ex>,
fire<ex>man</ex>, repair<ex>man</ex>, show<ex>man</ex>,
water<ex>man</ex>, wood<ex>man</ex>. Where the combination is not
familiar, or where some specific meaning of the compound is to be
avoided, <ex>man</ex> is used as a separate substantive in the foregoing
sense; as, apple <ex>man</ex>, cloth <ex>man</ex>, coal <ex>man</ex>,
hardware <ex>man</ex>, wood <ex>man</ex> (as distinguished from
wood<ex>man</ex>).</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Man ape</b></col> <fld>(Zool.)</fld>, <cd>a anthropoid
ape, as the gorilla.</cd> -- <col><b>Man at arms</b></col>, <cd>a
designation of the fourteenth and fifteenth centuries for a soldier
fully armed.</cd> -- <col><b>Man engine</b></col>, <cd>a mechanical lift
for raising or lowering people through considerable distances;</cd>
<specif>specifically</specif> <fld>(Mining)</fld>, <cd>a contrivance by
which miners ascend or descend in a shaft. It consists of a series of
landings in the shaft and an equal number of shelves on a vertical rod
which has an up and down motion equal to the distance between the
successive landings. A man steps from a landing to a shelf and is lifted
or lowered to the next landing, upon which he them steps, and so on,
traveling by successive stages.</cd> -- <col><b>Man Friday</b></col>,
<cd>a person wholly subservient to the will of another, like Robinson
Crusoe's servant Friday.</cd> -- <col><b>Man of straw</b></col>, <cd>a
puppet; one who is controlled by others; also, one who is not
responsible pecuniarily.</cd> -- <col><b>Man-of-the earth</b></col>
<fld>(Bot.)</fld>, <cd>a twining plant (<spn>Ipomoea pandurata</spn>)
with leaves and flowers much like those of the morning-glory, but having
an immense tuberous farinaceous root.</cd> -- <col><b>Man of
sin</b></col> <fld>(Script.)</fld>, <cd>one who is the embodiment of
evil, whose coming is represented (<au>2 Thess. ii. 3</au>) as preceding
the second coming of Christ.</cd> <mark>[A Hebraistic expression]</mark>
-- <col><b>Man of war</b></col>. <sd>(a)</sd> <cd>A warrior; a
soldier</cd>. <au>Shak.</au> <sd>(b)</sd> <fld>(Naut.)</fld> <cd>See in
the Vocabulary.</cd> <sd>(c)</sd> <cd>See <cref>Portuguese
man-of-war</cref> under <er>man-of-war</er> and also see
<er>Physalia</er>.</cd> -- <col><b>Man-stopping bullet</b></col>
<fld>(Mil.)</fld>, <cd>a bullet which will produce a sufficient shock to
stop a soldier advancing in a charge; specif., a small-caliber bullet so
modified as to expand when striking the human body, producing a severe
wound which is also difficult to treat medically. Types of bullets
called <stype>hollow-nosed bullets</stype>, <stype>soft-nosed
bullets</stype> and <stype>hollow-point bullets</stype> are classed as
man-stopping. The <stype>dumdum bullet</stype> or <stype>dumdum</stype>
is another well-known variety. Such bullets were originally designed for
wars with savage tribes.</cd> -- <col><b>great man</b></col>, <cd>a
man{2} who has become prominent due to substantial and widely admired
contributions to social or intellectual endeavors; <as>as, Einstein was
one of the <ex>great men</ex> of the twentieth century</as>.</cd> --
<col><b>To be one's own man</b></col>, <cd>to have command of one's
self; not to be subject to another.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Man</ent><br/
<hw>Man</hw> <pr>(m<acr/n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Manned</conjf> <pr>(m<acr/nd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Manning</conjf>.]</vmorph> <sn>1.</sn> <def>To supply
with men; to furnish with a sufficient force or complement of men, as
for management, service, defense, or the like; to guard; <as>as, to
<ex>man</ex> a ship, boat, or fort</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>See how the surly Warwick <qex>mans</qex> the wall !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>man</qex> their boats, and all their young men arm.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with strength for action; to prepare for
efficiency; to fortify.</def> <ldquo/Theodosius having <xex>manned</xex>
his soul with proper reflections.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tame, as a hawk.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To furnish with a servant or servants.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To wait on as a manservant.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In <ldquo/Othello,<rdquo/ V. ii. 270, the meaning is
uncertain, being, perhaps: To point, to aim, or to manage.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To man a yard</b></col> <fld>(Naut.)</fld>, <cd>to send
men upon a yard, as for furling or reefing a sail.</cd> -- <col><b>To
man the yards</b></col> <fld>(Naut.)</fld>, <cd>to station men on the
yards as a salute or mark of respect.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manable</ent><br/
<hw>Man"a*ble</hw> <pr>(m<acr/n"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Marriageable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manace</ent><br/
<hw>Man"ace</hw> <pr>(m<acr/n"<asl/s)</pr>, <pos>n. & v.</pos> <def>Same
as <er>Menace</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manacle</ent><br/
<hw>Man"a*cle</hw> <pr>(m<acr/n"<adot/*k'l)</pr>, <pos>n.</pos>
<ety>[OE. <ets>manicle</ets>, OF. <ets>manicle</ets>, F.
<ets>manicle</ets> sort glove, manacle, L. <ets>manicula</ets> a little
hand, dim. of <ets>manus</ets> hand; cf. L. <ets>manica</ets> sleeve,
manacle, fr. <ets>manus</ets>. See <er>Manual</er>.]</ety> <def>A
handcuff; a shackle for the hand or wrist; -- usually in the
plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Doctrine unto fools is as fetters on the feet, and like
<qex>manacles</qex> on the right hand.</q> <rj><qau>Ecclus. xxi.
19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manacle</ent><br/
<hw>Man"a*cle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Manacled</conjf> <pr>(m<acr/n"<adot/*k'ld)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Manacling</conjf> <pr>(?)</pr>.]</vmorph> <def>To
put handcuffs or other fastening upon, for confining the hands; to
shackle; to confine; to restrain from the use of the limbs or natural
powers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is it thus you use this monarch, to <qex>manacle</qex> and shackle
him hand and foot ?</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manage</ent><br/
<hw>Man"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>man<egrave/ge</ets>, It. <ets>maneggio</ets>, fr.
<ets>maneggiare</ets> to manage, fr. L. <ets>manus</ets>hand. Perhaps
somewhat influenced by F. <ets>m<eacute/nage</ets> housekeeping, OF.
<ets>mesnage</ets>, akin to E. <ets>mansion</ets>. See <er>Manual</er>,
and cf. <er>Manege</er>.]</ety> <def>The handling or government of
anything, but esp. of a horse; management; administration. See
<er>Manege</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Young men, in the conduct and <qex>manage</qex> of actions,
embrace more than they can hold.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Down, down I come; like glistering Phaethon<br/
Wanting the <qex>manage</qex> of unruly jades.</q>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The unlucky <qex>manage</qex> of this fatal brawl.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word, in its limited sense of management of a
horse, has been displaced by <xex>manege</xex>; in its more general
meaning, by <xex>management</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manage</ent><br/
<hw>Man"age</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Managed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Managing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From
<er>Manage</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To have under
control and direction; to conduct; to guide; to administer; to treat; to
handle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Long tubes are cumbersome, and scarce to be easily
<qex>managed</qex>.</q> <rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What wars I<qex>manage</qex>, and what wreaths I gain.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence, Esp.:</specif> <def>to guide by careful or
delicate treatment; to wield with address; to make subservient by artful
conduct; to bring around cunningly to one's plans.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was so much his interest to <qex>manage</qex> his Protestant
subjects.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was not her humor to <qex>manage</qex> those over whom she had
gained an ascendant.</q> <rj><qau>Bp. Hurd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To train in the manege, as a horse; to exercise in
graceful or artful action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To treat with care; to husband.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To bring about; to contrive.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To direct; govern; control; wield; order;
contrive; concert; conduct; transact.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manage</ent><br/
<hw>Man"age</hw>, <pos>v. i.</pos> <def>To direct affairs; to carry on
business or affairs; to administer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leave them to <qex>manage</qex> for thee.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manageability</ent><br/
<hw>Man`age*a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state
or quality of being manageable; manageableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manageable</ent><br/
<hw>Man"age*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
managed or used; suffering control; governable; tractable; subservient;
<as>as, a <ex>manageable</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Governable; tractable; controllable;
docile.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Man"age*a*ble*ness</wf>, <pos>n.</pos> --
<wf>Man"age*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>managed economy</ent><br/
<hw>managed economy</hw> <pos>n.</pos> <def>A non-market economy in
which government intervention is important in allocating goods and
resources and determining prices.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manageless</ent><br/
<hw>Man"age*less</hw>, <pos>a.</pos> <def>Unmanageable.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Management</ent><br/
<hw>Man"age*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Manage</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>The act or art of
managing; the manner of treating, directing, carrying on, or using, for
a purpose; conduct; administration; guidance; control; <as>as, the
<ex>management</ex> of a family or of a farm; the <ex>management</ex> of
a business enterprise; the <ex>management</ex> of state
affairs.</as></def> <ldquo/The <xex>management</xex> of the
voice.<rdquo/ <rj><au>E. Porter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Business dealing; negotiation;
arrangement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had great <qex>managements</qex> with ecclesiastics.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Judicious use of means to accomplish an end; conduct
directed by art or address; skillful treatment; cunning practice; --
often in a bad sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mark with what <qex>management</qex> their tribes divide<br/
Some stick to you, and some to t'other side.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The collective body of those who manage or direct
any enterprise or interest; the board of managers.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Conduct; administration; government; direction;
guidance; care; charge; contrivance; intrigue.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>management consultant</ent><br/
<hw>management consultant</hw> <pos>n.</pos> <def>An adviser to business
about efficient management practices.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>management personnel</ent><br/
<hw>management personnel</hw> <pos>n. pl.</pos> <def>Personnel having
ovrall planning and direction responsibilities.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manager</ent><br/
<hw>Man"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
manages; a conductor or director; <as>as, the <ex>manager</ex> of a
theater</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A skillful <qex>manager</qex> of the rabble.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who conducts business or household affairs
with economy and frugality; a good economist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A prince of great aspiring thoughts; in the main, a
<qex>manager</qex> of his treasure.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A contriver; an intriguer.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>manageress</ent><br/
<hw>manageress</hw> <pos>n.</pos> <def>A woman manager.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Managerial</ent><br/
<hw>Man`a*ge"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to management or a manager; <as>as, <ex>managerial</ex>
qualities</as>.</def> <ldquo/<xex>Managerial</xex>
responsibility.<rdquo/ <rj><au>C. Bront<eacute/.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Managership</ent><br/
<hw>Man"a*ger*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office or
position of a manager.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Managery</ent><br/
<hw>Man"age*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>menagerie</ets>, <ets>mesnagerie</ets>. See <er>Manage</er>,
<pos>n.</pos>, and cf. <er>Menagerie</er>.]</ety> <sn>1.</sn>
<def>Management; manner of using; conduct; direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Husbandry; economy; frugality.</def> <rj><au>Bp.
Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>managing director</ent><br/
<hw>managing director</hw> <pos>n.</pos> <def>A person who manages a
busness though not the owner or chief executive.</def><br/
<syn><b>Syn. --</b> director, manager.</syn><br/
[<source>PJC</source> + <source>WordNet 1.5</source>]</p>

<p><ent>managing editor</ent><br/
<hw>managing editor</hw> <pos>n.</pos> <def>The editor in charge of all
editorial activities of a newspaper or magazine.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manakin</ent><br/
<hw>Man"a*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. & G.
<ets>manakin</ets>; prob. the native name.]</ety> <fld>(Zool.)</fld>
<def>Any one of numerous small birds belonging to <gen>Pipra</gen>,
<gen>Manacus</gen>, and other genera of the family <fam>Pipridae</fam>.
They are mostly natives of Central and South America. Some are
bright-colored, and others have the wings and tail curiously ornamented.
The name is sometimes applied to related birds of other
families.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manakin</ent><br/
<hw>Man"a*kin</hw>, <pos>n.</pos> <def>A dwarf. See
<er>Manikin</er>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manannan</ent><br/
<hw>Manannan</hw> <pos>prop. n.</pos> <fld>(Irish mythology)</fld>
<def>The Irish god of the sea; son of <persfn>Ler</persfn>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man and wife</ent><br/
<hw>man and wife</hw> <pos>n.</pos> <def>A man and woman who are married
to each other; a married couple.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man-at-arms</ent><br/
<hw>man-at-arms</hw> <pos>n.</pos>; <plu><it>pl.</it>
<plw>men-at-arms</plw> <pr>(?)</pr></plu>. <def>A heavily armed and
sometimes mounted soldier in medieval times.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manatee</ent><br/
<hw>man`a*tee"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>manat<iacute/</ets>, from the native name in Haiti. Cf.
<er>Lamantin</er>.]</ety> <fld>(Zool.)</fld> <def>Any species of
<gen>Trichechus</gen>, a genus of sirenians; -- called also <altname>sea
cow</altname>.</def> <altsp>[Written also <asp>manaty</asp>,
<asp>manati</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ One species (<spn>Trichechus Senegalensis</spn>)
inhabits the west coast of Africa; another (<spn>Trichechus
Americanus</spn>) inhabits the east coast of South America, and the
West-Indies. The Florida manatee (<spn>Trichechus latirostris</spn>) is
by some considered a distinct species, by others it is thought to be a
variety of <spn>Trichechus Americanus</spn>. It sometimes becomes
fifteen feet or more in length, and lives both in fresh and salt water.
It was hunted for its oil and flesh, and every species is now an
<isa>endangered species</isa>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manation</ent><br/
<hw>Ma*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[L.
<ets>manatio</ets>, fr. <ets>manare</ets> to flow.]</ety> <def>The act
of issuing or flowing out.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manbird</ent><br/
<hw>Man"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An aviator.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manbote</ent><br/
<hw>Man"bote`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>man</ets>
man, vassal + <ets>b<omac/t</ets> recompense.]</ety> <fld>(Anglo-Saxon
Law)</fld> <def>A sum paid to a lord as a pecuniary compensation for
killing his man (that is, his vassal, servant, or tenant).</def>
<rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manca</ent><br/
<hw>Man"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.]</ety> <def>See
<er>Mancus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manche</ent><br/
<hw>Manche</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Also
<asp>maunch</asp>.]</altsp> <ety>[F. <ets>manche</ets>, fr. L.
<ets>manica</ets>. See <er>Manacle</er>.]</ety> <def>A sleeve.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manchester terrier</ent><br/
<hw>Manchester terrier</hw> <pos>prop. n.</pos> <def>A breed of
short-haired black-and-tan terrier developed in Manchester
England.</def><br/
<syn><b>Syn. --</b> black-and-tan terrier.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manchet</ent><br/
<hw>Man"chet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fine white bread; a
loaf of fine bread.</def> <mark>[Archaic]</mark> <rj><au>Bacon.
Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manchineel</ent><br/
<hw>Man`chi*neel"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>manzanillo</ets>, fr. <ets>manzana</ets> an apple, fr. L.
<ets>malum Matianum</ets> a kind of apple. So called from its apple-like
fruit.]</ety> <fld>(Bot.)</fld> <def>A euphorbiaceous tree
(<spn>Hippomane Mancinella</spn>) of tropical America, having a
poisonous and blistering milky juice, and poisonous acrid fruit somewhat
resembling an apple.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bastard manchineel</b></col>, <cd>a tree (<spn>Cameraria
latifolia</spn>) of the East Indies, having similar poisonous
properties.</cd> <au>Lindley.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manchu</ent><br/
<hw>Man*chu"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Written also
<ets>Manchoo</ets>, <ets>Mantchoo</ets>, etc.]</ety> <def>Of or
pertaining to Manchuria or its inhabitants.</def> -- <def2><pos>n.</pos>
<def>A native or inhabitant of Manchuria; also, the language spoken by
the Manchus.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mancipate</ent><br/
<hw>Man"ci*pate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>mancipatus</ets>, p. p. of <ets>mancipare</ets> to sell. Cf.
<er>Emancipate</er>.]</ety> <def>To enslave; to bind; to restrict.</def>
<mark>[Obs.]</mark> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mancipation</ent><br/
<hw>Man`ci*pa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mancipatio</ets> a transfer.]</ety> <def>Slavery; involuntary
servitude.</def> <mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manciple</ent><br/
<hw>Man"ci*ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From OF.
<ets>mancipe</ets> slave, servant (with <ets>l</ets> inserted, as in
<ets>participle</ets>), fr. L. <ets>mancipium</ets>. See
<er>Mancipate</er>.]</ety> <def>A steward; a purveyor, particularly of a
college or Inn of Court.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mancona bark</ent><br/
<hw>Man*co"na bark`</hw> <pr>(?)</pr>. <def>See <er>Sassy
bark</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mancus</ent><br/
<hw>Man"cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.]</ety> <def>An
old Anglo Saxon coin both of gold and silver, and of variously estimated
values. The silver <ex>mancus</ex> was equal to about one shilling of
modern English money.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-mancy</ent><br/
<hw>-man`cy</hw> <pr>(?)</pr>. <ety>[Gr. <?/ divination: cf. F.
<ets>-mancie</ets>.]</ety> <def>A combining form denoting
<xex>divination</xex>; <as>as, aleuro<ex>mancy</ex>,
chiro<ex>mancy</ex>, necro<ex>mancy</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mand</ent><br/
<hw>Mand</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A demand.</def>
<mark>[Obs.]</mark> <see>See <er>Demand</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandamus</ent><br/
\'d8<hw>Man*da"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., we
command, fr. <ets>mandare</ets> to command.]</ety> <fld>(Law)</fld>
<def>A writ issued by a superior court and directed to some inferior
tribunal, or to some corporation or person exercising authority,
commanding the performance of some specified duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandarin</ent><br/
<hw>Man`da*rin"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.
<ets>mandarim</ets>, from Malay <ets>mantr<imac/</ets> minister of
state, prop. a Hind. word, fr. Skr. <ets>mantrin</ets> a counselor,
<ets>manira</ets> a counsel, <ets>man</ets> to think.]</ety> <sn>1.</sn>
<def>A Chinese public officer or nobleman; a civil or military official
in China and Annam.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A powerful government
official or bureaucrat, especially one who is pedantic and has a strong
sense of his own importance and privelege.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>A member of an influential,
powerful or elite group, espcially within artistic or intellectual
circles; -- used especially of elder members who are traditionalist or
conservative about their specialties.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>The form of the Chinese language spoken by members
of the Chinese Imperial Court an officials of the empire.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>Any of several closely related dialects of the
Chinese language spoken by a mojority of the population of China, the
standard variety of which is spoken in the region around
Beijing.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <fld>(Bot.)</fld> <def>A small flattish reddish-orange
loose-skinned orange, with an easily separable rind. It is thought to be
of Chinese origin, and is counted a distinct species (<spn>Citrus
reticulata</spn> formerly <spn>Citrus nobilis</spn>); called also
<altname>mandarin orange</altname> and
<altname>tangerine</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mandarin language</b></col>, <cd>the spoken or colloquial
language of educated people in China.</cd> -- <col><b>Mandarin
yellow</b></col> <fld>(Chem.)</fld>, <cd>an artificial aniline dyestuff
used for coloring silk and wool, and regarded as a complex derivative of
quinoline.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandarinate</ent><br/
<hw>Man`da*rin"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The collective
body of officials or persons of rank in China.</def> <rj><au>S. W.
Williams.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandarin duck</ent><br/
<hw>mandarin duck</hw> <pos>n.</pos> <def>A showy crested Asiatic duck
(<spn>Aix galericulata</spn>, formerly <spn>Dendronessa
galericulata</spn>), often domesticated, and regarded by the Chinese as
an emblem of conjugal affection.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><-- p. 890 --></p>

<p><ent>Mandarinic</ent><br/
<hw>Man`da*rin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Appropriate or
peculiar to a mandarin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandarining</ent><br/
<hw>Man`da*rin"ing</hw>, <pos>n.</pos> <fld>(Dyeing)</fld> <def>The
process of giving an orange color to goods formed of animal tissue, as
silk or wool, not by coloring matter, but by producing a certain change
in the fiber by the action of dilute nitric acid.</def>
<rj><au>Tomlinson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandarinism</ent><br/
<hw>Man`da*rin"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A government by
mandarins (senses 1 or 2); character or spirit of the
mandarins{2}.</def> <rj><au>F. Lieder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandarin orange</ent><br/
<hw>man`da*rin" or"ange</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A shrub or small tree (<spn>Citrus reticulata</spn>) having
flattened globose fruit with very sweet aromatic pulp and thin
yellow-orange to flame-orange rind that is loose and easily removed;
native to Southeast Asia.</def><br/
<syn><b>Syn. --</b> mandarin orange tree.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Same as <er>mandarin</er>{7}.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandatary</ent><br/
<hw>Man"da*ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. mandatarius,
fr. <ets>mandatum</ets> a charge, commission, order: cf. F.
<ets>mandataire</ets>. See <er>Mandate</er>.]</ety> <sn>1.</sn> <def>One
to whom a command or charge is given; hence, specifically, a person to
whom the pope has, by his prerogative, given a mandate or order for his
benefice.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>One who undertakes to discharge a
specific business commission; a mandatory.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandate</ent><br/
<hw>Man"date</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mandatum</ets>, fr. <ets>mandare</ets> to commit to one's charge,
order, orig., to put into one's hand; <ets>manus</ets> hand +
<ets>dare</ets> to give: cf. F. <ets>mandat</ets>. See <er>Manual</er>,
<er>Date</er> a time, and cf. <er>Commend</er>, <er>Maundy
Thursday</er>.]</ety> <sn>1.</sn> <def>An official or authoritative
command, order, or authorization from a superior official to a
subordinate; an order or injunction; a commission; a judicial
precept.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This dream all-powerful Juno; I bear<br/
Her mighty <qex>mandates</qex>, and her words you hear.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <fld>(Politics)</fld> <def>An
authorization to carry out a specific public policy, given by the
electorate to their representatives; -- it is considered to be implied
by the election of a candidate by a significant margin after that
candidate has campaigned with that policy as a prominent element of the
campaign platform.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>Authorization by a
multinational body to a nation to administer the government and affairs
of a territory, usually a former colony; <as>as, termination of the
British <ex>mandate</ex> in Palestine</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Canon Law)</fld> <def>A rescript of the pope,
commanding an ordinary collator to put the person therein named in
possession of the first vacant benefice in his collation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Scots Law)</fld> <def>A contract by which one
employs another to manage any business for him. By the Roman law, it
must have been gratuitous.</def> <rj><au>Erskine.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandator</ent><br/
\'d8<hw>Man*da"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>A director; one who gives a mandate or order.</def>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rom. Law)</fld> <def>The person who employs another
to perform a mandate.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandatory</ent><br/
<hw>Man"da*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mandatorius</ets>.]</ety> <sn>1.</sn> <def>Containing a command;
preceptive; directory.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Obligatory; compulsory; required by
authority.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>Not optional; not able to be
modified or disregarded; <as>as, seven <ex>mandatory</ex> clauses in the
contract</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mandatory</ent><br/
<hw>Man"da*to*ry</hw>, <pos>n.</pos> <def>Same as
<er>Mandatary</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandelate</ent><br/
<hw>Man"del*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of mandelic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandelic</ent><br/
<hw>Man*del"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[G.
<ets>mandel</ets> almond.]</ety> <fld>(Chem.)</fld> <def>Pertaining to
an acid first obtained from benzoic aldehyde (oil of better almonds), as
a white crystalline substance; -- called also <xex>phenyl glycolic
acid</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mander</ent><br/
<hw>Man"der</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Maunder</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manderil</ent><br/
<hw>Man"der*il</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
mandrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandible</ent><br/
<hw>Man"di*ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mandibula</ets>, <ets>mandibulum</ets>, fr. <ets>mandere</ets> to
chew. Cf. <er>Manger</er>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld>
<def>The bone, or principal bone, of the lower jaw; the inferior
maxilla; -- also applied to either the upper or the lower jaw in the
beak of birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The anterior pair of mouth organs
of insects, crustaceaus, and related animals, whether adapted for biting
or not. See <xex>Illust.</xex> of <er>Diptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandibular</ent><br/
<hw>Man*dib"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mandibulaire</ets>.]</ety> <def>Of or pertaining to a mandible;
like a mandible.</def> -- <def2><pos>n.</pos> <def>The principal
mandibular bone; the mandible.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mandibular arch</b></col> <fld>(Anat.)</fld>, <cd>the
most anterior visceral arch, -- that in which the mandible is
developed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandibular joint</ent><br/
<hw>mandibular joint</hw> <pos>n.</pos> <fld>(anatomy)</fld> <def>The
joint between the head of the lower jawbone and the temporal
bone.</def><br/
<syn><b>Syn. --</b> temporomandibular joint, articulatio
temporomandibularis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mandibulated</ent><br/
<ent>Mandibulate</ent><br/
<mhw>{ <hw>Man*dib"u*late</hw> <pr>(?)</pr>, <hw>Man*dib"u*la`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Provided
with mandibles adapted for biting, as many insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandibulate</ent><br/
<hw>Man*dib"u*late</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An insect having mandibles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandibuliform</ent><br/
<hw>Man`di*bu"li*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having the form of a mandible; -- said
especially of the maxillae of an insect when hard and adapted for
biting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandibulohyoid</ent><br/
<hw>Man*dib`u*lo*hy"oid</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Pertaining both to the mandibular and the hyoid
arch, or situated between them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandil</ent><br/
<hw>man"dil</hw> <pr>(m<acr/n"d<icr/l)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mandil</ets>; cf. Sp. & Pg. <ets>mandil</ets> a coarse apron, a
haircloth; all from Ar. <ets>mandil</ets> tablecloth, handkerchief,
mantle, fr. LGr. <grk>mandh`lion</grk>, fr. L. <ets>mantile</ets>,
<ets>mantele</ets>. See <er>Mantle</er>.]</ety> <def>A loose outer
garment worn the 16th and 17th centuries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandilion</ent><br/
<hw>Man*dil"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mandil</er>.</def> <au>Chapman.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandingos</ent><br/
<hw>Man*din"gos</hw> <pr>(?)</pr>, <pos>n. pl.</pos>;
<sing><it>sing.</it> <singw>Mandingo</singw></sing>.
<fld>(Ethnol.)</fld> <def>An extensive and powerful tribe of West
African negroes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandioca</ent><br/
<ent>Mandioc</ent><br/
<mhw>{ <hw>Man"di*oc</hw> <pr>(?)</pr>, \'d8<hw>Man`di*o"ca</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<er>Manioc</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandlestone</ent><br/
<hw>Man"dle*stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>mandelstein</ets> almond stone.]</ety> <fld>(Min.)</fld>
<def>Amygdaloid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandment</ent><br/
<hw>Mand"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Commandment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandola</ent><br/
<hw>Man*do"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Mandolin</er>.]</ety> <fld>(Mus.)</fld> <def>An instrument closely
resembling the mandolin, but of larger size and tuned lower.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mandoline</ent><br/
<ent>Mandolin</ent><br/
<mhw>{ <hw>Man"do*lin</hw>, <hw>Man"do*line</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>mandoline</ets>, It. <ets>mandolino</ets>,
dim. of <ets>mandola</ets>, fr. L. <ets>pandura</ets>. See
<er>Bandore</er>.]</ety> <fld>(Mus.)</fld> <def>A small and beautifully
shaped instrument resembling the lute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandore</ent><br/
<hw>Man"dore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mandolin</er>, and <er>Bandore</er>.]</ety> <fld>(Mus.)</fld> <def>A
kind of four-stringed lute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandragora</ent><br/
<hw>Man*drag"o*ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
<ets>mandragoras</ets> the mandrake.]</ety> <fld>(Bot.)</fld> <def>A
genus of plants; the mandrake. See <er>Mandrake</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mandragorite</ent><br/
<hw>Man*drag"o*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
habitually intoxicates himself with a narcotic obtained from
mandrake.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandrake</ent><br/
<hw>man"drake</hw> <pr>(m<acr/n"dr<amac/k)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mandragora</ets>, L. <ets>mandragoras</ets>, fr. Gr.
<grk>mandrago`ras</grk>: cf. F. <ets>mandragore</ets>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A low plant (<spn>Mandragora
officinarum</spn>) of the Nightshade family, having a fleshy root, often
forked, and supposed to resemble a man. It was therefore supposed to
have animal life, and to cry out when pulled up. All parts of the plant
are strongly narcotic. It is found in the Mediterranean
region.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And shrieks like <qex>mandrakes</qex>, torn out of the earth,<br/
That living mortals, hearing them, run mad.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The mandrake of Scripture was perhaps the same plant,
but proof is wanting.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The May apple (<spn>Podophyllum
peltatum</spn>). See <cref>May apple</cref> under <er>May</er>, and
<er>Podophyllum</er>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandrake root</ent><br/
<hw>mandrake root</hw> <pos>n.</pos> <def>The root of the mandrake
plant; used medicinally or as a narcotic; as a substance it is also
called <altname>mandrake</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mandrel</ent><br/
<hw>Man"drel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mandrin</ets>, prob. through (assumed) LL. <ets>mamphurinum</ets>,
fr. L. <ets>mamphur</ets> a bow drill.]</ety> <fld>(Mach.)</fld>
<sd>(a)</sd> <def>A bar of metal inserted in the work to shape it, or to
hold it, as in a lathe, during the process of manufacture; an
arbor.</def> <sd>(b)</sd> <def>The live spindle of a turning lathe; the
revolving arbor of a circular saw. It is usually driven by a
pulley.</def> <altsp>[Written also <asp>manderil</asp> and
<asp>mandril</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mandrel lathe</b></col>, <cd>a lathe with a stout
spindle, adapted esp. for chucking, as for forming hollow articles by
turning or spinning.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mandril</ent><br/
<hw>mandril</hw> <pos>n.</pos> <def>any of various shafts that rotate or
serve as axes for larger rotating parts.</def> <altsp>[Written also
<asp>manderil</asp> and <asp>mandrel</asp>.]</altsp><br/
<syn><b>Syn. --</b> spindle, mandrel, arbor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mandrill</ent><br/
<hw>man"drill</hw> <pr>(m<acr/n"dr<icr/l)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>mandrille</ets>, Sp. <ets>mandril</ets>, It.
<ets>mandrillo</ets>; prob. the native name in Africa. Cf.
<er>Drill</er> an ape.]</ety> <fld>(Zool.)</fld> <def>A large West
African baboon (<spn>Papio sphinx</spn> syn. <spn>Mandrillus
sphinx</spn>, formerly <spn>Cynocephalus mormon</spn> syn. <spn>Papio
mormon</spn>). The adult male has, on the sides of the nose, large,
naked, grooved swellings, conspicuously striped with blue and red. It is
an <isa>endangered species</isa>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Manduca</ent><br/
<hw>Manduca</hw> <pos>prop. n.</pos> <def>A genus of moths whose larvae
are hornworms.</def><br/
<syn><b>Syn. --</b> genus <gen>Manduca</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manducable</ent><br/
<hw>Man"du*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>manducable</ets>. See <er>Manducate</er>.]</ety> <def>Such as can
be chewed; fit to be eaten.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Any <qex>manducable</qex> creature.</q> <rj><qau>Sir T.
Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manducate</ent><br/
<hw>Man"du*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Manducated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Manducating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>manducatus</ets>, p. p. of <ets>manducare</ets> to chew. See
<er>Manger</er>.]</ety> <def>To masticate; to chew; to eat.</def>
<mark>[R.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manducation</ent><br/
<hw>Man`du*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manducatio</ets>: cf. F. <ets>manducation</ets>.]</ety> <def>The
act of chewing.</def> <mark>[R.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manducatory</ent><br/
<hw>Man"du*ca*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or employed in, chewing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manducus</ent><br/
\'d8<hw>Man*du"cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>manducare</ets> to chew.]</ety> <fld>(Gr. & Rom. Antiq.)</fld>
<def>A grotesque mask, representing a person chewing or grimacing, worn
in processions and by comic actors on the stage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mane</ent><br/
<hw>Mane</hw> <pr>(m<amac/n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>manu</ets>; akin to OD. <ets>mane</ets>, D. <ets>maan</ets>, G.
<ets>m<aum/hne</ets>, OHG. <ets>mana</ets>, Icel. <ets>m<oum/n</ets>,
Dan. & Sw. <ets>man</ets>, AS. <ets>mene</ets> necklace, Icel.
<ets>men</ets>, L. <ets>monile</ets>, Gr. <?/, <?/, Skr.
<ets>many<amac/</ets> neck muscles. <root/275.]</ety> <def>The long and
heavy hair growing on the upper side of, or about, the neck of some
quadrupedal animals, as the horse, the lion, etc. See <xex>Illust.</xex>
of <er>Horse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maned sheep</ent><br/
<hw>maned sheep</hw> <pos>n.</pos> <def>A type of wild sheep
(<spn>Ammotragus lervia</spn>) of northern Africa; called also
<altname>Barbary sheep</altname> and
<altname>aoudad</altname>.</def><br/
<syn><b>Syn. --</b> aoudad, arui, audad, Barbary sheep, <spn>Ammotragus
lervia</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maned wolf</ent><br/
<hw>maned wolf</hw> <pos>n.</pos> <def>A reddish-gray wolf (<spn>Canis
rufus</spn> or <spn>Canis niger</spn>) of Southwestern North
America.</def><br/
<syn><b>Syn. --</b> red wolf, <spn>Canis rufus</spn>, <spn>Canis
niger</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Man-eater</ent><br/
<hw>Man"-eat`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One who, or that which, has an appetite for human flesh;
specifically, one of certain large sharks (esp. <spn>Carcharodon
carcharias</spn> syn. <spn>Carcharodon Rondeleti</spn>); also, a lion or
a tiger which has acquired the habit of feeding upon human
flesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>man-eating shark</ent><br/
<hw>man-eating shark</hw> <pos>n.</pos> <def>A term applied to sharks
that attack humans, especially the great white shark (<spn>Carcharodon
carcharias</spn>), a large aggressive shark widespread in warm
seas.</def><br/
<syn><b>Syn. --</b> great white shark, white shark, man-eater,
<spn>Carcharodon carcharias</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maned</ent><br/
<hw>Maned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a mane.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maned seal</b></col> <fld>(Zool.)</fld>, <cd>the sea
lion.</cd> -- <col><b>Maned sheep</b></col> <fld>(Zool.)</fld>, <cd>the
aoudad.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manege</ent><br/
<hw>Ma*nege"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>man<egrave/ge</ets>. See <er>Manage</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>The art of horsemanship, or of training
horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A school for teaching horsemanship, and for training
horses.</def> <rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maneh</ent><br/
\'d8<hw>Ma"neh</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>m<amac/neh</ets>.]</ety> <def>A Hebrew weight for gold or silver,
being one hundred shekels of gold and sixty shekels of silver.</def>
<rj><au>Ezek. xlv. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maneless</ent><br/
<hw>Mane"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having no
mane.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maneless lion</b></col> <fld>(Zool.)</fld>, <cd>a variety
of the lion having a short, inconspicuous mane. It inhabits Arabia and
adjacent countries.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manequin</ent><br/
<hw>Man"e*quin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Manikin</er>.]</ety> <def>An artist's model of wood or other
material.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manerial</ent><br/
<hw>Ma*ne"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Manorial</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manes</ent><br/
\'d8<hw>Ma"nes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.]</ety>
<fld>(Rom. Antiq.)</fld> <def>The benevolent spirits of the dead,
especially of dead ancestors, regarded as family deities and
protectors.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hail, O ye holy <qex>manes</qex>!</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manesheet</ent><br/
<hw>Mane"sheet`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A covering placed
over the upper part of a horse's head.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manoeuvre</ent><br/
<ent>Maneuver</ent><br/
<mhw>{ <hw>Ma*neu"ver</hw>, <hw>Ma*noeu"vre</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>manoeuvre</ets>, OF. <ets>manuevre</ets>,
LL. <ets>manopera</ets>, lit., hand work, manual labor; L.
<ets>manus</ets> hand + <ets>opera</ets>, fr. <ets>opus</ets> work. See
<er>Manual</er>, <er>Operate</er>, and cf. <er>Mainor</er>,
<er>Manure</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Management; dexterous movement; specif., a military
or naval evolution, movement, or change of position.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Management with address or artful design; adroit
proceeding; stratagem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manoeuvre</ent><br/
<ent>Maneuver</ent><br/
<mhw>{ <hw>Ma*neu"ver</hw>, <hw>Ma*noeu"vre</hw>, }</mhw> <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Maneuvered</conjf>
<pr>(#)</pr> or <conjf>Manoeuvred</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Maneuvering</conjf> <pr>(<?/)</pr>, or <conjf>Manoeuvring</conjf>
<pr>(<?/)</pr>.]</vmorph> <ety>[Cf. F. <ets>manoeuvrer</ets>. See
<er>Maneuver</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To perform a
movement or movements in military or naval tactics; to make changes in
position with the intention of getting an advantage in attack or
defense.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>To make changes in one's
approach to solving a problem, so as to achieve maximum advantage in a
changing situation; -- used especially in competitive situations, as in
politics, diplomacy, or sports.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To manage with address or art; to scheme.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manoeuvre</ent><br/
<ent>Maneuver</ent><br/
<mhw>{ <hw>Ma*neu"ver</hw>, <hw>Ma*noeu"vre</hw>, }</mhw> <pos>v.
t.</pos> <sn>1.</sn> <def>To change the positions of, as of troops of
ships.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manoeuvrer</ent><br/
<ent>Maneuverer</ent><br/
<mhw>{ <hw>Ma*neu"ver*er</hw> <pr>(?)</pr>, <hw>Ma*noeu"vrer</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>One who maneuvers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This charming widow Beaumont is a <qex>nanoeuvrer</qex>. We can't
well make an English word of it.</q> <rj><qau>Miss
Edgeworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>man Friday</ent><br/
<hw>man Friday</hw> <pos>prop. n.</pos> <ety>[From
<etsep>Friday</etsep>, the name of a character in the novel
<booki>Robinson Crusoe</booki> (1719) by DeFoe.]</ety> <def>A person who
contributes to the fulfillment of a need or furtherance of an effort or
purpose; a devoted assistant.</def><br/
<syn><b>Syn. --</b> right-hand man, chief assistant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manful</ent><br/
<hw>Man"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Showing manliness, or
manly spirit; hence, brave, courageous, resolute, noble.</def> <ldquo/
<xex>Manful</xex> hardiness.<rdquo/ <au>Chaucer.</au> --
<wordforms><wf>Man"ful*ly</wf>, <pos>adv.</pos> --
<wf>Man"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangabey</ent><br/
<hw>Man"ga*bey</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called by
<person>Buffon</person> from <etsep>Mangaby</etsep>, in Madagascar,
where he erroneously supposed them be native.]</ety> <fld>(Zool.)</fld>
<def>Any one of several African monkeys of the genus
<gen>Cercocebus</gen>, as the sooty mangabey (<spn>Cercocebus
fuliginosus</spn>), which is sooty black.</def> <altsp>[Also written
<asp>mangaby</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangan</ent><br/
<hw>Man"gan</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mangonel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganate</ent><br/
<hw>Man"ga*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>manganate</ets>.]</ety> <fld>(Chem.)</fld> <def>A salt of manganic
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The manganates are usually green, and are well-known
compounds, though derived from a hypothetical acid.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganesate</ent><br/
<hw>Man`ga*ne"sate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A manganate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganese</ent><br/
<hw>Man`ga*nese"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mangan<egrave/se</ets>, It. <ets>manganese</ets>, sasso
<ets>magnesio</ets>; prob. corrupted from L. <ets>magnes</ets>, because
of its resemblance to the magnet. See <er>Magnet</er>, and cf.
<er>Magnesia</er>.]</ety> <fld>(Chem.)</fld> <def>An element obtained by
reduction of its oxide, as a hard, grayish white metal, fusible with
difficulty (melting point 1244<deg/ C), but easily oxidized. Its ores
occur abundantly in nature as the minerals pyrolusite, manganite, etc.
Symbol <it>Mn.</it> Atomic number 25; Atomic weight 54.938
[C=12.011].</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ An alloy of manganese with iron (called
<xex>ferromanganese</xex>) is used to increase the density and hardness
of steel.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Black oxide of manganese</b></col>,
<col><b>Manganese dioxide</b></col> <it>or</it> <col><b>Manganese
peroxide</b></col>, <it>or</it> <col><b>Black manganese</b></col></mcol>
<fld>(Chem.)</fld>, <cd>a heavy black powder <chform>MnO2</chform>,
occurring native as the mineral pyrolusite, and valuable as a strong
oxidizer; -- called also familiarly <altname>manganese</altname>. It
colors glass violet, and is used as a decolorizer to remove the green
tint of impure glass.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>manganese bronze</ent><br/
<hw>manganese bronze</hw> <pos>n.</pos> <def>A brass alloy having from 1
to 4 percent of manganese added to harden it; made by adding manganese
to the copper and zinc used in brass.</def><br/
<syn><b>Syn. --</b> high-strength brass.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manganese steel</ent><br/
<hw>Man`ga*nese" steel</hw>. <def>Cast steel containing a considerable
percentage (10-14) of manganese, which makes it very hard and tough and
highly resistant to wear. See <er>Alloy steel</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manganesian</ent><br/
<hw>Man`ga*ne"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mangan<eacute/sien</ets>.]</ety> <fld>(Chem.)</fld>
<def>Manganic.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganesic</ent><br/
<hw>Man`ga*ne"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mangan<eacute/sique</ets>.]</ety> <fld>(Chem.)</fld>
<def>Manganic.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganesious</ent><br/
<hw>Man`ga*ne"sious</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Manganous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganesium</ent><br/
<hw>Man`ga*ne"si*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>Manganese.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganesous</ent><br/
<hw>Man`ga*ne"sous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Manganous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganic</ent><br/
<hw>Man`gan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>manganique</ets>.]</ety> <fld>(Chem.)</fld> <def>Of, pertaining to
resembling, or containing, manganese; specif., designating compounds in
which manganese has a higher valence as contrasted with
<contr>manganous</contr> compounds. Cf. <er>Manganous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manganic acid</ent><br/
<hw>manganic acid</hw> <pos>n.</pos> <def>A dibasic acid
<chform>H2MnO4</chform>, formed from manganese, analogous to sulphuric
acid; it is found only in solution and in manganate salts.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Manganiferous</ent><br/
<hw>Man`ga*nif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Manganese</ets> + <ets>-ferous</ets>.]</ety> <def>Containing
manganese.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganite</ent><br/
<hw>Man"ga*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Min.)</fld> <def>One of the oxides of manganese; -- called also
<altname>gray manganese ore</altname>. It occurs in brilliant steel-gray
or iron-black crystals, also massive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A compound of manganese dioxide
with a metallic oxide; so called as though derived from the hypothetical
<xex>manganous</xex> acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganium</ent><br/
<hw>Man*ga"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>Manganese.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manganous</ent><br/
<hw>Man"ga*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, pertaining to, designating, those compounds of manganese in
which the element has a lower valence as contrasted with
<contr>manganic</contr> compounds; <as>as, <ex>manganous</ex>
oxide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Manganous acid</b></col>, <cd>a hypothetical compound
analogous to sulphurous acid, and forming the so-called
<xex>manganites</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangcorn</ent><br/
<hw>Mang"corn`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mengen</ets> to mix. See <er>Mingle</er>, and <er>Corn</er>.]</ety>
<def>A mixture of wheat and rye, or other species of grain.</def>
<mark>[Prov Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mange</ent><br/
<hw>Mange</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mangy</er>.]</ety> <fld>(Vet.)</fld> <def>The scab or itch in
cattle, dogs, and other beasts.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mange insect</b></col> <fld>(Zool.)</fld>, <cd>any one of
several species of small parasitic mites, which burrow in the skin of
cattle. horses, dogs, and other animals, causing the mange. The mange
insect of the horse (<spn>Psoroptes equi</spn> or <spn>Dermatodectes
equi</spn>), and that of cattle (<spn>Symbiotes bovis</spn> or
<spn>Dermatophagys bovis</spn>) are the most important species. See
<er>Acarina</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangel-wurzel</ent><br/
<hw>Man"gel-wur`zel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., corrupted
fr. <ets>mangoldwurzel</ets>; <ets>mangold</ets> beet +
<ets>wurzel</ets> root.]</ety> <fld>(Bot.)</fld> <def>A kind of large
field beet (<spn>Beta macrorhiza</spn>), used as food for cattle, -- by
some considered a mere variety of the ordinary beet. See
<er>Beet</er>.</def> <altsp>[Written also
<asp>mangold-wurzel</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><-- Insert: Illustr. of Mangel-Wurzel --><br/
[<source>1913 Webster</source>]</p>

<p><ent>manger</ent><br/
<hw>man"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mangeoire</ets>, fr. <ets>manger</ets> to eat, fr. L.
<ets>manducare</ets>, fr. <ets>mandere</ets> to chew. Cf.
<er>Mandible</er>, <er>Manducate</er>.]</ety> <sn>1.</sn> <def>A trough
or open box in which fodder is placed for horses or cattle to
eat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And she brought forth her firstborn son, and wrapped him in
swaddling clothes, and laid him in a <qex>manger</qex>; because there
was no room for them in the inn.</q> <rj><qau>Luke 2: 7</qau></rj><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>The fore part of the deck, having
a bulkhead athwart ships high enough to prevent water which enters the
hawse holes from running over it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mangey</ent><br/
<hw>mangey</hw> <pos>adj.</pos> <def>Same as <er>mangy</er>.</def><br/
<syn><b>Syn. --</b> mangy, threadbare; worn-out, seedy,
squalid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mangifera</ent><br/
<hw>Mangifera</hw> <pos>prop. n.</pos> <def> genus of tropical trees
native to Asia bearing fleshy fruit.</def><br/
<syn><b>Syn. --</b> genus <gen>Mangifera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mangily</ent><br/
<hw>man"gi*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mangy manner;
scabbily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manginess</ent><br/
<hw>man"gi*ness</hw>, <pos>n.</pos> <ety>[From <er>Mangy</er>.]</ety>
<def>The condition or quality of being mangy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangle</ent><br/
<hw>Man"gle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mangled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mangling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[A frequentative
fr. OE. <ets>manken</ets> to main, AS. <ets>mancian</ets>, in
<ets>bemancian</ets> to mutilate, fr. L. <ets>mancus</ets> maimed; perh.
akin to G. <ets>mangeln</ets> to be wanting.]</ety> <sn>1.</sn> <def>To
cut or bruise with repeated blows or strokes, making a ragged or torn
wound, or covering with wounds; to tear in cutting; to cut in a bungling
manner; to lacerate; to mutilate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mangled</qex> with ghastly wounds through plate and mail.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mutilate or injure, in making, doing, or
performing; <as>as, to <ex>mangle</ex> a piece of music or a
recitation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>mangle</qex> a play or a novel.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mangle</ent><br/
<hw>man"gle</hw>, <pos>n.</pos> <ety>[D. <ets>mangel</ets>, fr. OE.
<ets>mangonel</ets> a machine for throwing stones, LL.
<ets>manganum</ets>, Gr. <?/ a machine for defending fortifications,
axis of a pulley. Cf. <er>Mangonel</er>.]</ety> <def>A machine for
smoothing linen or cotton cloth, as sheets, tablecloths, napkins, and
clothing, by roller pressure, often with heated rollers.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mangle rack</b></col> <fld>(Mach.)</fld>, <cd>a
contrivance for converting continuous circular motion into reciprocating
rectilinear motion, by means of a rack and pinion, as in the mangle. The
pinion is held to the rack by a groove in such a manner that it passes
alternately from one side of the rack to the other, and thus gives
motion to it in opposite directions, according to the side in which its
teeth are engaged.</cd> -- <col><b>Mangle wheel</b></col>, <cd>a wheel
in which the teeth, or pins, on its face, are interrupted on one side,
and the pinion, working in them, passes from inside to outside of the
teeth alternately, thus converting the continuous circular motion of the
pinion into a reciprocating circular motion of the wheel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 891 --></p>

<p><ent>Mangle</ent><br/
<hw>Man"gle</hw> <pr>(m<acr/<nsm/"g'l)</pr>, <pos>v. t.</pos> <ety>[Cf.
D. <ets>mangelen</ets>. See <er>Mangle</er>, <pos>n.</pos>]</ety>
<def>To smooth with a mangle, as damp linen or cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangler</ent><br/
<hw>Man"gler</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Mangle</er>.]</ety> <def>One who mangles or tears in cutting; one
who mutilates any work in doing it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangler</ent><br/
<hw>Man"gler</hw>, <pos>n.</pos> <ety>[See 3d <er>Mangle</er>.]</ety>
<def>One who smooths with a mangle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mango</ent><br/
<hw>Man"go</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mangoes</plw> <pr>(#)</pr>.</plu> <ety>[Pg. <ets>manga</ets>, fr.
Tamil <ets>m<amac/nk<amac/y</ets>.]</ety> <sn>1.</sn> <def>The fruit of
the mango tree. It is rather larger than an apple, and of an ovoid
shape. Some varieties are fleshy and luscious, and others tough and
tasting of turpentine. The green fruit is pickled for market.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A green muskmelon stuffed and pickled.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mango bird</b></col> <fld>(Zool.)</fld>, <cd>an oriole
(<spn>Oriolus kundoo</spn>), native of India.</cd> -- <col><b>Mango
fish</b></col> <fld>(Zool.)</fld>, <cd>a fish of the Ganges
(<spn>Polynemus risua</spn>), highly esteemed for food. It has several
long, slender filaments below the pectoral fins. It appears about the
same time with the mango fruit, in April and May, whence the name.</cd>
-- <col><b>Mango tree</b></col> <fld>(Bot.)</fld>, <cd>an
.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mango tree</ent><br/
<hw>mango tree</hw> <pos>n.</pos> <def>An East Indian tree of the genus
<gen>Mangifera</gen> (<spn>Mangifera Indica</spn>), related to the
cashew and the sumac. It grows to a large size, and produces a large
oval smooth-skinned fruit which is the <prod>mango</prod> of commerce.
It is now cultivated in tropical America.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Mangoldwurzel</ent><br/
<hw>Man"gold*wur`zel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.]</ety>
<fld>(Bot.)</fld> <def>See <er>Mangel-wurzel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangonel</ent><br/
<hw>Man"go*nel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mangonel</ets>, LL. <ets>manganellus</ets>, <ets>manganum</ets>,
fr. Gr. <?/ See <er>Mangle</er>, <pos>n.</pos>]</ety> <def>A military
engine formerly used for throwing stones and javelins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangonism</ent><br/
<hw>Man"go*nism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
mangonizing, or setting off to advantage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangonist</ent><br/
<hw>Man"go*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who mangonizes.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slave dealer; also, a strumpet.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangonize</ent><br/
<hw>Man"go*nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>mangonizare</ets>, fr. <ets>mango</ets> a dealer in slaves or
wares, to which he tries to give an appearance of greater value by
decking them out or furbishing them up.]</ety> <def>To furbish up for
sale; to set off to advantage.</def> <mark>[Obs. or R.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mangosteen tree</ent><br/
<ent>Mangostan</ent><br/
<ent>Mangosteen</ent><br/
<mhw>{ <hw>Man"go*steen</hw> <pr>(?)</pr>, <hw>Man"go*stan</hw>
<pr>(?)</pr>, <hw>mangosteen tree</hw> }</mhw> <pos>n.</pos> <ety>[Malay
<ets>mangusta</ets>, <ets>mangis</ets>.]</ety> <fld>(Bot.)</fld> <def>A
tree of the East Indies of the genus <gen>Garcinia</gen> (<spn>Garcinia
Mangostana</spn>) with thick leathery leaves. The tree grows to the
height of eighteen feet, and bears fruit also called
<prod>mangosteen</prod>, of the size of a small apple, the pulp of which
is very delicious food.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mangrove</ent><br/
<hw>Man"grove</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Malay
<ets>manggi-manggi</ets>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>The
name of one or two trees of the genus <gen>Rhizophora</gen>
(<spn>Rhizophora Mangle</spn>, and <spn>Rhizophora mucronata</spn>, the
last doubtfully distinct) inhabiting muddy shores of tropical regions,
where they spread by emitting aerial roots, which fasten in the saline
mire and eventually become new stems. The seeds also send down a strong
root while yet attached to the parent plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The fruit has a ruddy brown shell, and a delicate white
pulp which is sweet and eatable. The bark is astringent, and is used for
tanning leather. The black and the white mangrove (<spn>Avicennia
nitida</spn> and <spn>Avicennia tomentosa</spn>) have much the same
habit.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The mango fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mangrove family</ent><br/
<hw>mangrove family</hw> <pos>n.</pos> <def>A natural family
(<fam>Rhizophoraceae</fam>) of trees and shrubs that usually form dense
jungles along tropical seacoasts. It includes the mangrove
<member><spn>Rhizophora Mangle</spn></member>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mangrove snapper</ent><br/
<hw>mangrove snapper</hw> <pos>n.</pos> <def>A fish (<spn>Lutjanus
griseus</spn>) found in shallow waters off the coast of Florida; called
also <altname>gray snapper</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mangue</ent><br/
\'d8<hw>Mangue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>The kusimanse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mangy</ent><br/
<hw>man"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>mangier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>mangiest</adjf>.]</amorph> <ety>[F. <ets>mang<eacute/</ets>, p. p.
of <ets>manger</ets> to eat. See <er>Manger</er>.]</ety> <sn>1.</sn>
<def>Infected with the mange; scabby.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Shabby; worn-out; seedy; run-down; squalid; <as>as,
a <ex>mangy</ex> old coat; a <ex>mangy</ex> tavern</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Manhaden</ent><br/
<hw>Man*ha"den</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Menhaden</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manhandle</ent><br/
<hw>Man*han"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>-handled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>-handling</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To move, or manage, by human force without mechanical aid; <as>as,
to <ex>manhandle</ex> a cannon</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To handle roughly; <as>as, the captive was
<ex>manhandled</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manhattan Project</ent><br/
<hw>Manhattan Project</hw> <pos>prop. n.</pos> <fld>(U. S.
History)</fld> <def>A former US agency that was responsible for
developing atomic bombs during World War II.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manhead</ent><br/
<hw>Man"head</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Manhood.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manhes process</ent><br/
<hw>Man`h<egrave/s" proc"ess</hw> <pr>(?)</pr>. <fld>(Copper
Metal.)</fld> <def>A process by which copper matte is treated by passing
through it a blast of air, to oxidize and remove sulphur. It is
analogous in apparatus to the Bessemer process for decarbonizing cast
iron. So called from <person>Pierre
<etsep>Manh<egrave/s</etsep></person>, a French metallurgist, who
invented it.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manhole</ent><br/
<hw>Man"hole`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hole through which
a man may descend or creep into a drain, sewer, steam boiler, parts of
machinery, etc., for cleaning or repairing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manhood</ent><br/
<hw>Man"hood</hw>, <pos>n.</pos> <ety>[<ets>Man-</ets> +
<ets>-hood</ets>.]</ety> <sn>1.</sn> <def>The state of being man as a
human being, or man as distinguished from a child or a woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Manly quality; virility; courage; bravery;
resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am ashamed<br/
That thou hast power to shake my <qex>manhood</qex> thus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The genitalia of a male human.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>The condition of being a human being.</def><br/
[<source>PJC</source>]</p>

<p><ent>man-hour</ent><br/
<ent>man hour</ent><br/
<mhw><hw>man hour</hw>, <hw>man-hour</hw></mhw> <pos>n.</pos> <def>The
quantity of work which one person can perform in one hour; -- often an
estimate made for the purpose of deciding whether to undertake a
project, and sometimes used in accounting; <as>as, it will take a
hundred <ex>man-hours</ex> to write the program</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>manhunt</ent><br/
<hw>man"hunt`</hw> <pos>n.</pos> <pr>(m<acr/n"h<ucr/nt)</pr> <def>An
organized search (by police) for a person (charged with a
crime).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mania</ent><br/
<hw>Ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>mania</ets>,
Gr. <?/, fr. <?/ to rage; cf. OE. <ets>manie</ets>, F. <ets>manie</ets>.
Cf. <er>Mind</er>, <pos>n.</pos>, <ets>Necromancy</ets>.]</ety>
<sn>1.</sn> <def>Violent derangement of mind; madness; insanity. Cf.
<er>Delirium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excessive or unreasonable desire; insane passion
affecting one or many people; <as>as, the tulip
<ex>mania</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mania a potu</b></col> <ety>[L.]</ety>, <cd>madness from
drinking; delirium tremens.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Insanity; derangement; madness; lunacy;
alienation; aberration; delirium; frenzy. See
<er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maniable</ent><br/
<hw>Man"i*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr.
<ets>manier</ets> to manage, fr. L. <ets>manus</ets> hand.]</ety>
<def>Manageable.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maniac</ent><br/
<hw>Ma"ni*ac</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>maniaque</ets>. See <er>Mania</er>.]</ety> <def>Raving with
madness; raging with disordered intellect; affected with mania;
mad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maniac</ent><br/
<hw>ma"ni*ac</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A raving lunatic; a
madman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maniacal</ent><br/
<hw>Ma*ni"a*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Affected with, or
characterized by, madness; maniac.</def> --
<wordforms><wf>Ma*ni"a*cal*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manic</ent><br/
<hw>Man"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>maniko`s</grk> mad, frenzied.]</ety> <fld>(Med.)</fld> <def>Of or
pert. to, or characterized by, mania, or excitement; frenzied; <as>as,
with <ex>manic</ex> energy</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manicate</ent><br/
<hw>Man"i*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>manicatus</ets> sleeved, fr. <ets>manica</ets> a sleeve.]</ety>
<fld>(Bot.)</fld> <def>Covered with hairs or pubescence so platted
together and interwoven as to form a mass easily removed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manic-depressive</ent><br/
<hw>manic-depressive</hw> <pos>n.</pos> <fld>(Med.)</fld>, <def>A person
suffering from <er>manic-depressive psychosis</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>manic-depressive psychosis</ent><br/
<hw>manic-depressive psychosis</hw> <pos>n.</pos> <fld>(Med.)</fld>,
<def>A mental disorder characterized by alternating episodes of mania
and depression.</def><br/
<syn><b>Syn. --</b> bipolar disorder, manic depression, manic depressive
illness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manic disorder</ent><br/
<hw>manic disorder</hw> <pos>n.</pos> <fld>(Med.)</fld>, <def>An
affective disorder in which the victim tends to respond excessively and
sometimes violently.</def><br/
<syn><b>Syn. --</b> mania.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manichee</ent><br/
<ent>Manichean</ent><br/
<ent>Manichaean</ent><br/
<mhw>{ <hw>Man`i*chae"an</hw> <pr>(?)</pr>, <hw>Man`i*che"an</hw>,
<hw>Man"i*chee</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[LL.
<ets>Manichaeus</ets>: cf. F. <ets>manich<eacute/en</ets>.]</ety> <def>A
believer in the doctrines of <persfn>Manes</persfn>, a Persian of the
third century A. D., who taught a dualism in which Light is regarded as
the source of Good, and Darkness as the source of Evil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Manichaeans</qex> stand as representatives of dualism
pushed to its utmost development.</q> <rj><qau>Tylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manichean</ent><br/
<ent>Manichaean</ent><br/
<mhw>{ <hw>Man`i*chae"an</hw>, <hw>Man`i*che"an</hw> <pr>(?)</pr>
}</mhw>, <pos>a.</pos> <def>Of or pertaining to the
Manichaeans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manicheism</ent><br/
<ent>Manichaeism</ent><br/
<mhw>{ <hw>Man"i*chae*ism</hw>, <hw>Man"i*che*ism</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[Cf. F.
<ets>manich<eacute/isme</ets>.]</ety> <def>The doctrines taught, or
system of principles maintained, by the Manichaeans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manicheist</ent><br/
<hw>Man"i*che*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>manich<eacute/iste</ets>.]</ety> <def>Manichaean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manichordon</ent><br/
<ent>Manichord</ent><br/
<mhw>{ <hw>Man"i*chord</hw> <pr>(?)</pr>, <hw>Man`i*chor"don</hw>
<pr>(?)</pr>, }</mhw> <ety>[L. <ets>monochordon</ets>, Gr. <?/; -- so
called because it orig. had only one string. See
<er>Monochord</er>.]</ety> <fld>(Mus.)</fld> <def>The clavichord or
clarichord; -- called also <altname>dumb spinet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maniclike</ent><br/
<hw>maniclike</hw> <pos>adj.</pos> <def>Resembling the mania of
manic-depressive illness.</def><br/
<syn><b>Syn. --</b> manic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manicotti</ent><br/
<hw>manicotti</hw> <pos>n.</pos> <def>Tubular large noodles that are
usually stuffed with mild cheese and baked in tomato sauce; -- a type of
Italian <isa>pasta</isa>; also a dish of such noodles thus
prepared.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Manicure</ent><br/
<hw>Man"i*cure</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Manicured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Manicuring</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To care for (the hands and nails); to care for the hands and nails
of; to do manicure work.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>to trim carefully and meticulously; <as>as, to
<ex>manicure</ex> a lawn</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>manicure</ent><br/
<hw>man"i*cure</hw>, <pos>n.</pos> <def>The care of the hands and nails,
especially a thorough cosmetic treatment of the hands, especially the
trimming and polishing of the fingernails, and removing of cuticles,
performed by a manicurist.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>manicure</ent><br/
<hw>man"i*cure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>manus</ets> hand + <ets>curare</ets> to cure.]</ety> <def>A person
who makes a business of taking care of people's hands, especially their
nails; -- an older term for a <altname>manicurist</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Men] who had taken good care of their hands by wearing gloves and
availing themselves of the services of a <qex>manicure</qex>.</q>
<rj><qau>Pop. Sci. Monthly.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>manicurist</ent><br/
<hw>man"i*cur`ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>manus</ets> hand + <ets>curare</ets> to cure.]</ety> <def>A person
who makes a business of taking care of people's hands, especially their
fingernails; -- formerly called a <altname>manicure</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>manid</ent><br/
<hw>ma"nid</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any
species of the genus <gen>Manis</gen>, or family
<fam>Manidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manie</ent><br/
<hw>ma`nie"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Mania</er>.]</ety> <def>Mania; insanity.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifest</ent><br/
<hw>Man"i*fest</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>manifeste</ets>, L. <ets>manifestus</ets>, lit., struck by the
hand, hence, palpable; <ets>manus</ets> hand + <ets>fendere</ets> (in
comp.) to strike. See <er>Manual</er>, and <er>Defend</er>.]</ety>
<sn>1.</sn> <def>Evident to the senses, esp. to the sight; apparent;
distinctly perceived; hence, obvious to the understanding; apparent to
the mind; easily apprehensible; plain; not obscure or hidden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither is there any creature that is not <qex>manifest</qex> in
his sight.</q> <rj><qau> Heb. iv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That which may be known of God is <qex>manifest</qex> in them.</q>
<rj><qau>Rom. i. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus <qex>manifest</qex> to sight the god appeared.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Detected; convicted; -- with <ptcl>of</ptcl>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Calistho there stood <qex>manifest</qex> of shame.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Open; clear; apparent; evident; visible;
conspicuous; plain; obvious.</syn> <usage> -- <er>Manifest</er>,
<er>Clear</er>, <er>Plain</er>, <er>Obvious</er>, <er>Evident</er>. What
is <xex>clear</xex> can be seen readily; what is <xex>obvious</xex> lies
directly in our way, and necessarily arrests our attention; what is
<xex>evident</xex> is seen so clearly as to remove doubt; what is
<ex>manifest</ex> is very distinctly evident.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>clear</qex>, so shining, and so <qex>evident</qex>,<br/
That it will glimmer through a blind man's eye.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Entertained with solitude,<br/
Where <qex>obvious</qex> duty erewhile appeared unsought.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw, I saw him <qex>manifest</qex> in view,<br/
His voice, his figure, and his gesture knew.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifest</ent><br/
<hw>Man"i*fest</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Manifests</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>manifeste</ets>. See <er>Manifest</er>, <pos>a.</pos>, and cf.
<er>Manifesto</er>.]</ety> <sn>1.</sn> <def>A public declaration; an
open statement; a manifesto. See <er>Manifesto</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A list or invoice of a ship's cargo, containing a
description by marks, numbers, etc., of each package of goods, to be
exhibited at the customhouse; <as>as, to inspect the ship's
<ex>manifest</ex></as>.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifest</ent><br/
<hw>Man"i*fest</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Manifested</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Manifesting</conjf>.]</vmorph> <sn>1.</sn> <def>To show plainly;
to make to appear distinctly, -- usually to the mind; to put beyond
question or doubt; to display; to exhibit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is nothing hid which shall not be <qex>manifested</qex>.</q>
<rj><qau>Mark iv. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy life did <qex>manifest</qex> thou lovedst me not.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To exhibit the manifests or prepared invoices of; to
declare at the customhouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reveal; declare; evince; make known; disclose;
discover; display.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifestable</ent><br/
<hw>Man"i*fest`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can
be manifested.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifestation</ent><br/
<hw>Man`i*fes*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manifestatio</ets>: cf. F. <ets>manifestation</ets>.]</ety>
<sn>1.</sn> <def>The act of manifesting or disclosing, or the state of
being manifested; discovery to the eye or to the
understanding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which manifests; a phenomenon which gives
evidence of something hidden; exhibition; display; revelation; <as>as,
the <ex>manifestation</ex> of God's power in creation</as>; the delayed
<ex>manifestation</ex> of a disease.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The secret manner in which acts of mercy ought to be performed,
requires this public <qex>manifestation</qex> of them at the great
day.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The materialization or apparition of a spirit; -- a
phenomenon claimed to be seen by spiritualists.</def><br/
[<source>PJC</source>]</p>

<p><ent>manifest destiny</ent><br/
<hw>manifest destiny</hw> <pos>n.</pos> <def>A policy of imperialism
rationalized as inevitable (as if granted by God).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manifestible</ent><br/
<hw>Man"i*fest`i*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Manifestable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifestly</ent><br/
<hw>Man"i*fest*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a manifest
manner; obviously; evidently; clearly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifestness</ent><br/
<hw>Man"i*fest*ness</hw>, <pos>n.</pos> <def>The quality or state of
being manifest; obviousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifesto</ent><br/
<hw>Man`i*fes"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Manifestoes</plw> <pr>(#)</pr>.</plu> <ety>[It.
<ets>manifesto</ets>. See <er>Manifest</er>, <pos>n. & a.</pos>]</ety>
<def>A public declaration, usually of a prince, sovereign, or other
person claiming large powers, showing his intentions, or proclaiming his
opinions and motives in reference to some act done or contemplated by
him; <as>as, a <ex>manifesto</ex> declaring the purpose of a prince to
begin war, and explaining his motives</as>.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>it was proposed to draw up a <qex>manifesto</qex>, setting forth
the grounds and motives of our taking arms.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Frederick, in a public <qex>manifesto</qex>, appealed to the
Empire against the insolent pretensions of the pope.</q>
<rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifold</ent><br/
<hw>Man"i*fold</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>manigfeald</ets>. See <er>Many</er>, and <er>Fold</er>.]</ety>
<sn>1.</sn> <def>Various in kind or quality; many in number; numerous;
multiplied; complicated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O Lord, how <qex>manifold</qex> are thy works!</q> <rj><qau>Ps.
civ. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I know your <qex>manifold</qex> transgressions.</q> <rj><qau>Amos
v. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exhibited at divers times or in various ways; --
used to qualify nouns in the singular number.</def> <ldquo/The
<xex>manifold</xex> wisdom of God.<rdquo/ <au>Eph. iii. 10.</au>
<ldquo/The <xex>manifold</xex> grace of God.<rdquo/ <au>1 Pet. iv.
10.</au><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Manifold writing</b></col>, <cd>a process or method by
which several copies, as of a letter, are simultaneously made, sheets of
coloring paper being infolded with thin sheets of plain paper upon which
the marks made by a stylus or a type-writer are transferred; writing
several copies of a document at once by use of carbon paper or the
like.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifold</ent><br/
<hw>Man"i*fold</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A copy
of a writing made by the manifold process.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A cylindrical pipe fitting,
having a number of lateral outlets, for connecting one pipe with several
others; <as>as, the exhaust <ex>manifold</ex> of an automobile
engine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The third stomach of a ruminant
animal.</def> <mark>[Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifold</ent><br/
<hw>Man"i*fold</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Manifolded</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Manifolding</conjf>.]</vmorph> <def>To take copies of by the
process of manifold writing; <as>as, to <ex>manifold</ex> a
letter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifolded</ent><br/
<hw>Man"i*fold`ed</hw>, <pos>a.</pos> <def>Having many folds, layers, or
plates; <as>as, a <ex>manifolded</ex> shield</as>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifoldly</ent><br/
<hw>Man"i*fold`ly</hw>, <pos>adv.</pos> <def>In a manifold
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manifoldness</ent><br/
<hw>Man"i*fold`ness</hw>, <pos>n.</pos> <sn>1.</sn>
<def>Multiplicity.</def> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>A generalized concept of
magnitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maniform</ent><br/
<hw>Man"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>manus</ets> hand + <ets>-form</ets>.]</ety> <def>Shaped like the
hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maniglion</ent><br/
<hw>ma*ni"glion</hw> <pr>(m<adot/*n<icr/l"y<ucr/n)</pr>, <pos>n.</pos>
<ety>[It. <ets>maniglio</ets>, <ets>maniglia</ets>, bracelet, handle.
Cf. <er>Manilio</er>.]</ety> <fld>(Gun.)</fld> <def>Either one of two
handles on the back of a piece of ordnance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manihot</ent><br/
<ent>Manihoc</ent><br/
<mhw>{ <hw>Man"i*hoc</hw> <pr>(?)</pr>, <hw>Man"i*hot</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <def>See <er>Manioc</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manikin</ent><br/
<hw>Man"i*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Also spelled
<asp>mannikin</asp>.]</altsp> <ety>[OD. <ets>manneken</ets>, dim. of
<ets>man</ets> man. See <er>Man</er>, and <er>-kin</er>.]</ety>
<sn>1.</sn> <def>A little man; a dwarf; a pygmy; a manakin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A model of the human body, made of papier-mache or
other material, commonly in detachable pieces, for exhibiting the
different parts and organs, their relative position, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mannequin.</def><br/
[<source>PJC</source>]</p>

<p><ent>Manilla</ent><br/
<ent>Manila</ent><br/
<mhw>{ <hw>Ma*nil"a</hw> <pr>(?)</pr>, <hw>Ma*nil"la</hw> }</mhw>,
<pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to Manila or Manilla,
the capital of the Philippine Islands; made in, or exported from, that
city.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def><cref>Manila paper</cref> or the color of
<cref>manila paper</cref>.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Manila cheroot</b></col> <it>or</it> <col><b>Manila
cigar</b></col></mcol>, <cd>a cheroot or cigar made of tobacco grown in
the Philippine Islands.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>manila bay</ent><br/
<hw>manila bay</hw> <pos>n.</pos> <def>The name of a naval battle in the
Spanish-American War (1898), in which the American fleet under
<person>Admiral Dewey</person> defeated the Spanish fleet off the shore
of Manila in the Philippines.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manila bean</ent><br/
<hw>manila bean</hw> <pos>n.</pos> <def>A tuberous-rooted twining annual
vine (<spn>Psophocarpus tetragonolobus</spn>) bearing clusters of
purplish flowers and pods with four jagged wings; Old World
tropics.</def><br/
<syn><b>Syn. --</b> winged bean, winged pea, goa bean, goa bean vine,
<spn>Psophocarpus tetragonolobus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manila grass</ent><br/
<hw>manila grass</hw> <pos>n.</pos> <def>A lawn grass (<spn>Zoysia
matrella</spn>) common in the Philippines; grown also in US.</def><br/
<syn><b>Syn. --</b> Japanese carpet grass.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manila hemp</ent><br/
<hw>Manila hemp</hw> <pos>n.</pos> <sn>1.</sn> <def>A fibrous material
obtained from the abaca plant (<spn>Musa textilis</spn>), a plant allied
to the banana, growing in the Philippine and other East India islands;
-- called also by the native name <altname>abaca</altname>. From it
matting, canvas, ropes, and cables are made.</def><br/
<syn><b>Syn. --</b> Manilla hemp, abaca.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A Philippine plant (<spn>Musa textilis</spn>) having
leafstalks that yield Manila hemp used for rope and paper etc.; called
also the <altname>abaca</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manila maguey</ent><br/
<hw>manila maguey</hw> <pos>n.</pos> <def>A hard fiber used in making
coarse twine; from Philippine agave plants.</def><br/
<syn><b>Syn. --</b> cantala, Cebu maguey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manila paper</ent><br/
<hw>manila paper</hw> <pos>n.</pos> <def>A durable brown or buff paper
or thin cardboard with a smooth light brown finish, made of Manila hemp,
and used as a wrapping paper, or as a cheap printing and writing paper.
The name is also given to inferior papers, made of other
fiber.</def><br/
<syn><b>Syn. --</b> manila, manila paper, manilla, manilla
paper.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>manila tamarind</ent><br/
<hw>manila tamarind</hw> <pos>n.</pos> <def>A common thorny tropical
American tree (<spn>Pithecellobium dulce</spn>) having terminal racemes
of yellow flowers followed by sickle-shaped or circinate edible pods and
yielding good timber and a yellow dye and mucilaginous gum.</def><br/
<syn><b>Syn. --</b> camachile, huamachil, wild tamarind,
<spn>Pithecellobium dulce</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manilio</ent><br/
<hw>Ma*nil"io</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Manilla</er>, 1.</def> <rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>manilla paper</ent><br/
<ent>manilla hemp</ent><br/
<ent>manilla</ent><br/
<mhw><hw>manilla</hw>, <hw>manilla hemp</hw>, <hw>manilla
paper</hw></mhw> <pos>n.</pos> <def>See <er>manila</er>, <er>manila
hemp</er>, <er>manila paper</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Manilkara</ent><br/
<hw>Manilkara</hw> <pos>prop. n.</pos> <def>A genus of large evergreen
trees with milky latex; pantropical.</def><br/
<syn><b>Syn. --</b> genus <gen>Manilkara</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manilla</ent><br/
<hw>Ma*nil"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>manilla</ets>; cf. It. <ets>maniglio</ets>, <ets>maniglia</ets>; F.
<ets>manille</ets>; Pg. <ets>manilha</ets>; all fr. L. <ets>manus</ets>
hand, and formed after the analogy of L. <ets>monile</ets>, pl.
<ets>monilia</ets>, necklace: cf. F. <ets>manille</ets>.]</ety>
<sn>1.</sn> <def>A ring worn upon the arm or leg as an ornament,
especially among the tribes of Africa.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of copper of the shape of a horseshoe, used
as money by certain tribes of the west coast of Africa.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manilla</ent><br/
<hw>Ma*nil"la</hw>, <pos>a.</pos> <def>Same as
<er>Manila</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manille</ent><br/
\'d8<hw>Ma*nille"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>See 1st <er>Manilla</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>man in the street</ent><br/
<hw>man in the street</hw> <pos>n.</pos> <def>An average person; <as>as,
the views of the <ex>man in the street</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manioc</ent><br/
<hw>Ma"ni*oc</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.
<ets>mandioca</ets>, fr. Braz.]</ety> <fld>(Bot.)</fld> <def>The
tropical plants (<spn>Manihot utilissima</spn>, and <spn>Manihot
Aipi</spn>), from which cassava and tapioca are prepared; also,
cassava.</def> <altsp>[Written also <asp>mandioc</asp>,
<asp>manihoc</asp>, <asp>manihot</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maniple</ent><br/
<hw>Man"i*ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manipulus</ets>, <ets>maniplus</ets>, a handful, a certain number
of soldiers; <ets>manus</ets> hand + root of <ets>plere</ets> to fill,
<ets>plenus</ets> full: cf. F. <ets>maniple</ets>. See <er>Manual</er>,
and <er>Full</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>A
handful.</def> <mark>[R.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A division of the Roman army numbering sixty men
exclusive of officers; any small body of soldiers; a company.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Originally, a napkin; later, an ornamental band or
scarf worn upon the left arm as a part of the vestments of a priest in
the Roman Catholic Church. It is sometimes worn in the English Church
service.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manipular</ent><br/
<hw>Ma*nip"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>manipularis</ets>: cf. F. <ets>manipulaire</ets>.]</ety>
<sn>1.</sn> <def>Of or pertaining to the maniple, or company.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Manipulatory; <as>as, <ex>manipular</ex>
operations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manipulate</ent><br/
<hw>Ma*nip"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Manipulated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Manipulating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[LL.
<ets>manipulatus</ets>, p. p. of <ets>manipulare</ets> to lead by the
hand, fr. L. <ets>manipulus</ets>. See <er>Maniple</er>.]</ety>
<sn>1.</sn> <def>To treat, work, or operate with the hands, especially
when knowledge and dexterity are required; to manage in hand work; to
handle; <as>as, to <ex>manipulate</ex> scientific
apparatus</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To control the action of, by management; <as>as, to
<ex>manipulate</ex> a convention of delegates;</as> also, to manage
artfully or fraudulently; <as>as, to <ex>manipulate</ex> accounts, or
election returns; to <ex>manipulate</ex> the stock
market</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manipulate</ent><br/
<hw>Ma*nip"u*late</hw>, <pos>v. i.</pos> <def>To use the hands in
dexterous operations; to do hand work;</def>
<specif>specifically,</specif> <def>to manage the apparatus or
instruments used in scientific work, or in artistic or mechanical
processes; also, specifically, to use the hand in mesmeric
operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manipulation</ent><br/
<hw>Ma*nip`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>manipulation</ets>.]</ety> <sn>1.</sn> <def>The act or process of
manipulating, or the state of being manipulated; the act of handling
work by hand; use of the hands, in an artistic or skillful manner, in
science or art.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Manipulation</qex> is to the chemist like the external senses
to the mind.</q> <rj><au>Whewell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The use of the hands in mesmeric
operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Artful management; <as>as, the <ex>manipulation</ex>
of political bodies</as>; sometimes, a management or treatment for
purposes of deception or fraud.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manipulative</ent><br/
<hw>ma*nip"u*la*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Of or pertaining to manipulation; performed by
manipulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Prone to attempt to influence others by devious or
subtle psychological means, in order to induce them to do what one
wants.</def><br/
[<source>PJC</source>]</p>

<p><ent>manipulative</ent><br/
<hw>ma*nip"u*la*tive</hw>
<pr>(m<adot/*n<icr/p"<usl/*l<adot/*t<icr/v)</pr>, <pos>n.</pos>
<fld>(Education)</fld> <def>Any object given to children to encourage
them to learn by manipulating physical objects; applied especially to
solid objects of varying geometrical shape that can be fit together to
form larger aggregates.</def><br/
[<source>PJC</source>]</p>

<p><ent>Manipulator</ent><br/
<hw>Ma*nip"u*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
manipulates, sometimes in an underhanded or fraudulent manner; <as>as, a
stock market <ex>manipulator</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><-- p. 892 --></p>

<p><ent>Manipulatory</ent><br/
<hw>Ma*nip"u*la*to*ry</hw>
<pr>(m<adot/*n<icr/p"<usl/*l<adot/*t<osl/*r<ycr/)</pr>, <pos>a.</pos>
<def>Of or pertaining to manipulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manis</ent><br/
\'d8<hw>Ma"nis</hw> <pr>(m<amac/"n<icr/s)</pr>, <pos>n.</pos> <ety>[NL.,
fr. L. <ets>manes</ets> the ghosts or shades of the dead. So called from
its dismal appearance, and because it seeks for its food by
night.]</ety> <fld>(Zool.)</fld> <def>A genus of edentates, covered with
large, hard, triangular scales, with sharp edges that overlap each other
like tiles on a roof. They inhabit the warmest parts of Asia and Africa,
and feed on ants. Called also <altname>Scaly anteater</altname>. See
<er>Pangolin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manitu</ent><br/
<ent>Manitou</ent><br/
<ent>Manito</ent><br/
<mhw>{ <hw>Man"i*to</hw> <pr>(?)</pr>, <hw>Man"i*tou</hw> <pr>(?)</pr>,
<hw>Man"i*tu</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>A name given
by tribes of American Indians to a great spirit, whether good or evil,
or to any object of worship.</def> <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gitche <qex>Manito</qex> the mighty,<br/
The Great Spirit, the creator,<br/
Smiled upon his helpless children!</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mitche <qex>Manito</qex> the mighty,<br/
He the dreadful Spirit of Evil,<br/
As a serpent was depicted.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manitrunk</ent><br/
<hw>Man"i*trunk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manus</ets> hand + E. <ets>trunk</ets>.]</ety> <fld>(Zool.)</fld>
<def>The anterior segment of the thorax in insects. See
<er>Insect</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>man jack</ent><br/
<hw>man jack</hw> <pos>n.</pos> <def>A single individual person; <as>as,
every <ex>man jack</ex> of them</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mankind</ent><br/
<hw>man`kind"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mancynn</ets>. See <er>Kin</er> kindred, <er>Kind</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>The human race; man, taken
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The proper study of <qex>mankind</qex> is man.</q>
<rj><qau>Pore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Men, as distinguished from women; the male portion
of human race.</def> <rj><au>Lev. xviii. 22.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Human feelings; humanity.</def> <mark>[Obs]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mankind</ent><br/
<hw>Man"kind`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Manlike; not
womanly; masculine; bold; cruel.</def> <mark>[Obs]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Are women grown so <qex>mankind</qex>? Must they be wooing?</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not too <qex>mankind</qex> against your wife.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manks</ent><br/
<hw>Manks</hw> <pr>(m<acr/<nsm/ks)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to the language or people of the Isle of Man.</def> --
<def2><pos>n.</pos> <def>The language spoken in the Isle of Man. See
<er>Manx</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manless</ent><br/
<hw>Man"less</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Destitute
of men.</def> <rj><au>Bakon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unmanly; inhuman.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manlessly</ent><br/
<hw>Man"less*ly</hw>, <pos>adv.</pos> <def>Inhumanly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manlike</ent><br/
<hw>Man"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Man</ets> +
<ets>like.</ets> Cf. <er>Manly</er>.]</ety> <def>Like man, or like a
man, in form or nature; having the qualities of a man, esp. the nobler
qualities; manly.</def> <ldquo/ Gentle, <xex>manlike</xex>
speech.<rdquo/ <au>Testament of Love.</au> <ldquo/ A right
<xex>manlike</xex> man.<rdquo/ <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In glaring Chloe's <qex>manlike</qex> taste and mien.</q>
<rj><qau>Shenstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manliness</ent><br/
<hw>Man"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being manly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manling</ent><br/
<hw>Man"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little man.</def>
<mark>[Obs.]</mark> <rj><au> B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manly</ent><br/
<hw>Man"ly</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Manlier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Manliest</adjf>.]</amorph> <ety>[<ets>Man</ets> + <ets>-ly</ets>.
Cf. <er>Manlike</er>.]</ety> <def>Having qualities becoming to a man;
not childish or womanish; manlike, esp. brave, courageous, resolute,
noble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let's briefly put on <qex>manly</qex> readiness.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Serene and <qex>manly</qex>, hardened to sustain<br/
The load of life.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Bold; daring; brave; courageous; firm; undaunted;
hardy; dignified; stately.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manly</ent><br/
<hw>Man"ly</hw>, <pos>adv.</pos> <def>In a manly manner; with the
courage and fortitude of a manly man; <as>as, to act
<ex>manly</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>man-made</ent><br/
<hw>man-made</hw> <pos>adj.</pos> <def>Not of natural origin; prepared
or made by humans; artificial; of substances, made by chemical reaction
rather than extracted from a natural source; <as>as, <ex>man-made</ex>
fibers; <ex>man-made</ex> gems</as>. Opposed to
<ant>natural</ant>.</def><br/
<syn><b>Syn. --</b> semisynthetic, synthetic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man-made fiber</ent><br/
<hw>man-made fiber</hw> <pos>n.</pos> <def>A fiber created from natural
materials or by chemical processes.</def><br/
<syn><b>Syn. --</b> synthetic fiber.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manna</ent><br/
<hw>Man"na</hw> <pr>(m<acr/n"n<adot/)</pr>, <pos>n.</pos> <ety>[L., fr.
Gr. <grk>ma`nna</grk>, Heb. <ets>m<amac/n</ets>; cf. Ar.
<ets>mann</ets>, properly, gift (of heaven).]</ety> <sn>1.</sn>
<fld>(Script.)</fld> <def>The food supplied to the Israelites in their
journey through the wilderness of Arabia; hence, divinely supplied
food.</def> <rj><au>Ex. xvi. 15.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A name given to lichens of the
genus <gen>Lecanora</gen>, sometimes blown into heaps in the deserts of
Arabia and Africa, and gathered and used as food; called also
<altname>manna lichen</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot. & Med.)</fld> <def>A sweetish exudation in the
form of pale yellow friable flakes, coming from several trees and shrubs
and used in medicine as a gentle laxative, as the secretion of
<spn>Fraxinus Ornus</spn>, and <spn>Fraxinus rotundifolia</spn>, the
manna ashes of Southern Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <stype>Persian manna</stype> is the secretion of the
camel's thorn (see <cref>Camel's thorn</cref>, under <er>Camel</er>);
<stype>Tamarisk manna</stype>, that of the <spn>Tamarisk
mannifera</spn>, a shrub of Western Asia; <stype>Australian,
manna</stype>, that of certain species of eucalyptus;
<stype>Brian<cced/on manna</stype>, that of the European
larch.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Manna insect</b></col> <fld>(Zool)</fld>, <cd>a scale
insect (<spn>Gossyparia mannipara</spn>), which causes the exudation of
manna from the Tamarix tree in Arabia.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>manna ash</ent><br/
<hw>manna ash</hw> <pos>n.</pos> <fld>(Bot.)</fld>, <def>A South
Mediterranean ash (<spn>Fraxinus ornus</spn>) having fragrant white
flowers in dense panicles and yielding manna.</def><br/
<syn><b>Syn. --</b> flowering ash, <spn>Fraxinus ornus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manna croup</ent><br/
<hw>Man"na croup`</hw> <pr>(m<acr/n"n<adot/ kr<oomac/p`)</pr>.
<ety>[<ets>Manna</ets> + Russ. & Pol. <ets>krupa</ets> groats,
grits.]</ety> <sn>1.</sn> <def>The portions of hard wheat kernels not
ground into flour by the millstones: a kind of semolina prepared in
Russia and used for puddings, soups, etc. -- called also <altname>manna
groats</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The husked grains of manna grass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manna grass</ent><br/
<hw>manna grass</hw> <pos>n.</pos> <fld>(Bot.)</fld>, <def>Any of
several tall slender grasses of the genus <gen>Glyceria</gen>. They have
long loose panicles, have a sweet flavor or odor, and grow in moist
places. <stype>Nerved manna grass</stype> is <spn>Glyceria
nervata</spn>, and <stype>Floating manna grass</stype> is <spn>Glyceria
fluitans</spn>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>manna gum</ent><br/
<hw>manna gum</hw> <pos>n.</pos> <fld>(Bot.)</fld>, <def>A tall tree
(<spn>Eucalyptus viminalis</spn>) yielding a false manna.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manna lichen</ent><br/
<hw>manna lichen</hw> <pos>n.</pos> <def>Any of several Old World
semicrustaceous or shrubby lecanoras that roll up and are blown about
over African and Arabian deserts and used as food by people and animals;
same as <er>manna</er>{2}.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manned</ent><br/
<hw>manned</hw> <pos>adj.</pos> <sn>1.</sn> <def>Having a crew; -- of
vehicles; <as>as, a <ex>manned</ex> earth satellite was considered a
necessary research step; to minimize casualties, the military used
cruise missiles rather than <ex>manned</ex> aircraft for the
bombardment</as>. Opposite of <ant>unmanned</ant>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mannequin</ent><br/
<hw>mannequin</hw> <pos>n.</pos> <sn>1.</sn> <def>a woman who wears
clothes to display fashions; a fashion model.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> fashion model, model.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A three-dimensional model of a person, used to
display clothes, especially in retail stores and in window displays; a
dummy.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> manikin, mannikin, manakin.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>A model of a human form used by tailors to help make
clothing of the proper shape.</def><br/
[<source>PJC</source>]</p>

<p><ent>Manner</ent><br/
<hw>Man"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>manere</ets>, F. <ets>mani<egrave/re</ets>, from OF.
<ets>manier</ets>, adj., manual, skillful, handy, fr. (assumed) LL.
<ets>manarius</ets>, for L. <ets>manuarius</ets> belonging to the hand,
fr. <ets>manus</ets> the hand. See <er>Manual</er>.]</ety> <sn>1.</sn>
<def>Mode of action; way of performing or effecting anything; method;
style; form; fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The nations which thou hast removed, and placed in the cities of
Samaria, know not the <qex>manner</qex> of the God of the land.</q>
<rj><qau>2 Kings xvii. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The temptations of prosperity insinuate themselves after a gentle,
but very powerful, <qex>manner</qex>.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characteristic mode of acting, conducting, carrying
one's self, or the like; bearing; habitual style.</def><br/
[<source>1913 Webster</source>]</p>

<p>Specifically: <sd>(a)</sd> <def>Customary method of acting;
habit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Paul, as his <qex>manner</qex> was, went in unto them.</q>
<rj><qau>Acts xvii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Air and <qex>manner</qex> are more expressive than words.</q>
<rj><qau>Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <pluf>pl.</pluf> <def>Carriage; behavior; deportment;
also, becoming behavior; well-bred carriage and address; <as>as, mind
your <ex>manners</ex>!</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Good <qex>manners</qex> are made up of petty sacrifices.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>The style of writing or thought of an author;
characteristic peculiarity of an artist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Certain degree or measure; <as>as, it is in a
<ex>manner</ex> done already</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bread is in <qex>a manner</qex> common.</q> <rj><qau>1 Sam.
xxi.5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Sort; kind; style; -- in this application sometimes
having the sense of a plural, sorts or kinds; <as>as, all
<ex>manners</ex> of people came to the rally</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>And they being afraid wondered, saying to one another, What
<qex>manner</qex> of man is this! for he commandeth even the winds and
the water, and they obey him.</q> <rj><qau>Luke 8: 25.</qau></rj></p>

<p><q>Ye tithe mint, and rue, and all <qex>manner</qex> of herbs.</q>
<rj><qau>Luke xi. 42.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I bid thee say,<br/
What <qex>manner</qex> of man art thou?</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In old usage, <ptcl>of</ptcl> was often omitted after
<xex>manner</xex>, when employed in this sense. <ldquo/A
<xex>manner</xex> Latin corrupt was her speech.<rdquo/</note>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>By any manner of means</b></col>, <cd>in any way
possible; by any sort of means.</cd> -- <mcol><col><b>To be taken in the
manner</b></col> <it>or</it> <col><b>To be taken with the
manner</b></col></mcol>. <ety>[A corruption of <ets>to be taken in the
mainor</ets>. See <er>Mainor</er>.]</ety> <cd>To be taken in the very
act.</cd> <mark>[Obs.]</mark> <see>See <er>Mainor</er>.</see> --
<col><b>To make one's manners</b></col>, <cd>to make a bow or courtesy;
to offer salutation.</cd> -- <col><b>Manners bit</b></col>, <cd>a
portion left in a dish for the sake of good manners.</cd>
<au>Hallwell.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Method; mode; custom; habit; fashion; air; look;
mien; aspect; appearance. See <er>Method</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maennerchor</ent><br/
<ent>Mannerchor</ent><br/
\'d8<hw>M<aum/n"ner*chor`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>G.
pl.</it> <plw>M<aum/nnerch<oum/re</plw> <pr>(#)</pr></plu>. <ety>[G.;
<ets>m<aum/nner</ets>, pl. of <ets>mann</ets> man + <ets>chor</ets>
chorus.]</ety> <def>A German men's chorus or singing club.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mannered</ent><br/
<hw>Man"nered</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having a
certain way, esp. a polite way, of carrying and conducting one's self;
<as>as, a well-<ex>mannered</ex> child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give her princely training, that she may be<br/
<qex>Mannered</qex> as she is born.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affected with mannerism; marked by excess of some
characteristic peculiarity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His style is in some degree <qex>mannered</qex> and confined.</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannerism</ent><br/
<hw>Man"ner*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mani<eacute/risme</ets>.]</ety> <sn>1.</sn> <def>Adherence to a
peculiar style or manner; a characteristic mode of action, bearing,
behavior, or treatment of others.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Adherence to a peculiar style or manner carried to
excess, especially in literature or art.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mannerism</qex> is pardonable,and is sometimes even
agreeable, when the manner, though vicious, is natural . . . . But a
<qex>mannerism</qex> which does not sit easy on the mannerist, which has
been adopted on principle, and which can be sustained only by constant
effort, is always offensive.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannerist</ent><br/
<hw>Man"ner*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>mani<eacute/riste</ets>.]</ety> <def>One addicted to mannerism; a
person who, in action, bearing, or treatment, carries characteristic
peculiarities to excess. See citation under
<er>Mannerism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannerliness</ent><br/
<hw>Man"ner*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being mannerly; civility; complaisance.</def> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannerly</ent><br/
<hw>Man"ner*ly</hw>, <pos>a.</pos> <def>Showing good manners; civil;
respectful; complaisant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What thou thinkest meet, and is most <qex>mannerly</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannerly</ent><br/
<hw>Man"ner*ly</hw>, <pos>adv.</pos> <def>With good manners.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>manner name</ent><br/
<hw>manner name</hw> <pos>n.</pos> <fld>(linguistics)</fld> <def>A word
that denotes a manner of doing something; a troponym; as, "march" is a
<ex>manner name</ex> for "walk".</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manner of speaking</ent><br/
<hw>manner of speaking</hw> <pos>n.</pos> <def>The characteristic style
or manner that a person uses to express himself orally.</def><br/
<syn><b>Syn. --</b> delivery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mannheim gold</ent><br/
<hw>Mann"heim gold"</hw> <pr>(?)</pr>. <ety>[From <ets>Mannheim</ets> in
Germany, where much of it was made.]</ety> <def>A kind of brass made in
imitation of gold. It contains eighty per cent of copper and twenty of
zinc.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannide</ent><br/
<hw>Man"nide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mann</ets>ite +
anhydr<ets>ide</ets>.]</ety> <fld>(Chem.)</fld> <def>A white amorphous
or crystalline substance, obtained by dehydration of mannite, and
distinct from, but convertible into, mannitan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannish</ent><br/
<hw>Man"nish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Man</ets> +
<ets>-ish</ets>: cf. AS. <ets>mennisc</ets>, <ets>menisc</ets>.]</ety>
<sn>1.</sn> <def>Resembling a human being in form or nature;
human.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But yet it was a figure<br/
Most like to <qex>mannish</qex> creature.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling, suitable to, or characteristic of, a
man, manlike, masculine.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A woman impudent and <qex>mannish</qex> grown.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fond of men; -- said of a woman.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Man"nish*ly</wf> <pr>(#)</pr>,<pos>adv.</pos> --
<wf>Man"nish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannitan</ent><br/
<hw>Man"ni*tan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mannite</ets>
+ <ets>an</ets>hydrite.]</ety> <fld>(Chem.)</fld> <def>A white amorphous
or crystalline substance obtained by the partial dehydration of
mannite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannitate</ent><br/
<hw>Man"ni*tate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of mannitic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannite</ent><br/
<hw>Man"nite</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Same as
<er>mannitol</er>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A sweet white efflorescence from
dried fronds of kelp, especially from those of the <spn>Laminaria
saccharina</spn>, or devil's apron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mannitic</ent><br/
<hw>Man*nit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, pertaining to, resembling, or derived from, mannitol.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mannitic acid</b></col> <fld>(Chem.)</fld>, <cd>a white
amorphous substance, intermediate between saccharic acid and mannitol,
and obtained by the partial oxidation of the latter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mannitol</ent><br/
<hw>man"ni*tol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mannite</ets>
+ <ets>-ol</ets>.]</ety> <sn>1.</sn> <fld>(Chem.)</fld> <def>A white
crystalline hexose (<chform>HO.CH2.(CHOH)4.CH2.OH</chform>) of a sweet
taste obtained from a so-called <xex>manna</xex>, the dried sap of the
flowering ash (<prodby><spn>Fraxinus ornus</spn></prodby>); -- called
also <altname>mannite</altname>, and <altname>hydroxy hexane</altname>.
Cf. <er>Dulcite</er>. It is used in pharmacy as excipient and diluent
for solids and liquids. It is also used as a food additive for
anti-caking properties, or as a sweetener, and, illegally, to "cut"
(dilute) illegal drugs such as cocaine or heroin.</def> <syn><b>Syn.
--</b> D-mannitol; manna sugar; cordycepic acid; Diosmol; Mannicol;
Mannidex; Osmiktrol; Osmosal.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mannitose</ent><br/
<hw>Man"ni*tose`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A variety of sugar obtained by the partial oxidation of mannite,
and closely resembling levulose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mano</ent><br/
\'d8<hw>Ma"no</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., lit.,
hand.]</ety> <def>The muller, or crushing and grinding stone, used in
grinding corn on a metate.</def> <mark>[Mexico & Local U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manoeuvre</ent><br/
<hw>Ma*noeu"vre</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Maneuver</er>.</def> <mark>[Chiefly Brit.]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>man of action</ent><br/
<hw>man of action</hw> <pos>n.</pos> <def>A person who prefers to act
rather than contemplate and gets things accomplished quickly an
efficiently.</def><br/
<syn><b>Syn. --</b> man of deeds.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>man of affairs</ent><br/
<hw>man of affairs</hw> <pos>n.</pos> <def>A person engaged in
commercial or industrial business (especially an owner or
executive).</def><br/
<syn><b>Syn. --</b> businessman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man of deeds</ent><br/
<hw>man of deeds</hw> <pos>n.</pos> <def>Same as <er>man of
action</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man of letters</ent><br/
<hw>man of letters</hw> <pos>n.</pos> <sn>1.</sn> <def>A writer,
especially one who writes for a living.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A learned person; a scholar.</def><br/
[<source>PJC</source>]</p>

<p><ent>man of means</ent><br/
<hw>man of means</hw> <pos>n.</pos> <def>A wealthy person.</def><br/
<syn><b>Syn. --</b> rich man, wealthy man.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man of science</ent><br/
<hw>man of science</hw> <pos>n.</pos> <def>A scientist.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man-of-the-earth</ent><br/
<hw>man-of-the-earth</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Bot.)</fld>
<def>A long-rooted morning glory (<spn>Ipomoea leptophylla</spn>) of
Western U. S.</def><br/
<syn><b>Syn. --</b> man of the earth, <spn>Ipomoea
leptophylla</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A tropical American prostrate or climbing herbaceous
perennial (<spn>Ipomoea panurata</spn> or <spn>Ipomoea fastigiata</spn>)
having an enormous starchy root; sometimes held to be source of the
sweet potato.</def><br/
<syn><b>Syn. --</b> wild potato vine, wild sweet potato vine, man of the
earth, manroot, scammonyroot, <spn>Ipomoea panurata</spn>, <spn>Ipomoea
fastigiata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>man of the world</ent><br/
<hw>man of the world</hw> <pos>n.</pos> <def>A worldly-wise person; a
sophisticate.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Man-of-war</ent><br/
<hw>Man`-of-war"</hw> <pr>(?)</pr>, <pos>n</pos>; <plu><it>pl.</it>
<plw>Men-of-war</plw>.</plu> <sn>1.</sn> <def>A government vessel
employed for the purposes of war, esp. one of large size; a ship of
war.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> ship of the line.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The <cref>Portuguese man-of-war</cref>.</def><br/
<syn><b>Syn. --</b> , jellyfish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Man-of-war hawk</b></col> <fld>(Zool.)</fld>, <cd>the
frigate bird.</cd> -- <col><b>Man-of-war's man</b></col>, <cd>a sailor
serving in a ship of war.</cd> -- <col><b>Portuguese
man-of-war</b></col> <fld>(Zool.)</fld>, <cd>any species of the genus
<gen>Physalia</gen>; it is a hydrozoan having both medusa and polyp
stages present in a single colony. It floats on the surface of the sea
by a buoyant bladderlike structure, from which dangle multiple long
tentacles with stinging cells. Its can cause severe rashes when it comes
in contact with humans swimming in the area. See
<er>Physalia</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>man-of-war bird</ent><br/
<hw>man-of-war bird</hw> <pos>n.</pos> <fld>(Zool.)</fld>, <def>The
frigate bird, a long-billed warm-water seabird with wide wingspan and
forked tail; also applied to the skua gulls, and to the wandering
albatross.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manograph</ent><br/
<hw>Man"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ thin,
rare + <ets>-graph</ets>: cf. F. <ets>manographe</ets>.]</ety>
<fld>(Engin.)</fld> <def>An optical device for making an indicator
diagram for high-speed engines. It consists of a light-tight box or
camera having at one end a small convex mirror which reflects a beam of
light on to the ground glass or photographic plate at the other end. The
mirror is pivoted so that it can be moved in one direction by a small
plunger operated by an elastic metal diaphragm which closes a tube
connected with the engine cylinder. It is also moved at right angles to
this direction by a reducing motion, called a <xex>reproducer</xex>, so
as to copy accurately on a smaller scale the motion of the engine
piston. The resultant of these two movements imparts to the reflected
beam of light a motion similar to that of the pencil of the ordinary
indicator, and this can be traced on the sheet of ground glass, or
photographed.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Manometer</ent><br/
<hw>Ma*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ thin,
rare + <ets>-meter</ets>: cf. F. <ets>manom<egrave/tre</ets>.]</ety>
<def>An instrument for measuring the tension or elastic force of gases,
steam, etc., constructed usually on the principle of allowing the gas to
exert its elastic force in raising a column of mercury in an open tube,
or in compressing a portion of air or other gas in a closed tube with
mercury or other liquid intervening, or in bending a metallic or other
spring so as to set in motion an index; a pressure gauge. See
<er>Pressure</er>, and <xex>Illust.</xex> of <er>Air
pump</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manometrical</ent><br/
<ent>Manometric</ent><br/
<mhw>{ <hw>Man`o*met"ric</hw> <pr>(?)</pr>, <hw>Man`o*met"ric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>manom<eacute/trique</ets>.]</ety> <def>Of or pertaining to the
manometer; made by the manometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manor</ent><br/
<hw>Man"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>maner</ets>,
OF. <ets>maneir</ets> habitation, village, F. <ets>manoir</ets> manor,
prop. the OF. inf. <ets>maneir</ets> to stay, remain, dwell, L.
<ets>manere</ets>, and so called because it was the permanent residence
of the lord and of his tenants. See <er>Mansion</er>, and cf.
<er>Remain</er>.]</ety> <sn>1.</sn> <fld>(Eng. Law)</fld> <def>The land
belonging to a lord or nobleman, or so much land as a lord or great
personage kept in his own hands, for the use and subsistence of his
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>manors</qex>, rents, revenues, l forego.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In these days, a <xex>manor</xex> rather signifies the
jurisdiction and royalty incorporeal, than the land or site, for a man
may have a manor in gross, as the law terms it, that is, the right and
interest of a court-baron, with the perquisites thereto
belonging.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(American Law)</fld> <def>A tract of land occupied
by tenants who pay a free-farm rent to the proprietor, sometimes in
kind, and sometimes by performing certain stipulated services.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Manor house</b></col>, or <col><b>Manor
seat</b></col></mcol>, <cd>the house belonging to a manor; the house of
the lord of the manor; a manse.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>manor hall</ent><br/
<hw>manor hall</hw> <pos>n.</pos> <def>The large room of a manor or
castle.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manorial</ent><br/
<hw>Ma*no"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a manor.</def> <ldquo/ <xex>Manorial</xex> claims.<rdquo/
<rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manoscope</ent><br/
<hw>Man"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ thin,
rare + <ets>-scope</ets>.]</ety> <def>Same as
<er>Manometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manoscopy</ent><br/
<hw>Ma*nos"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The science of
the determination of the density of vapors and gases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manovery</ent><br/
<hw>Ma*no"ver*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Maneuver</er>.]</ety> <fld>(Eng. Law)</fld> <def>A contrivance or
maneuvering to catch game illegally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manqueller</ent><br/
<hw>Man"quell`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A killer of men;
a manslayer.</def> <mark>[Obs.]</mark> <rj><au>Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manrent</ent><br/
<ent>Manred</ent><br/
<mhw>{ <hw>Man"red</hw> <pr>(?)</pr>, <hw>Man"rent`</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <def>Homage or service rendered to a superior, as
to a lord; vassalage.</def> <mark>[Obs. or Scots Law]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manrope</ent><br/
<hw>Man"rope`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>One of the side ropes to the gangway of a ship.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mansard roof</ent><br/
<hw>Man"sard roof"</hw> <pr>(?)</pr>. <ety>[So called from its inventor,
<person>Fran<cced/ois <ets>Mansard</ets></person>, or
<ets>Mansart</ets>, a distinguished French architect, who died in
1666.]</ety> <fld>(Arch.)</fld> <def>A hipped curb roof; that is, a roof
having on all sides two slopes, the lower one being steeper than the
upper one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manse</ent><br/
<hw>Manse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL. <ets>mansa</ets>,
<ets>mansus</ets>, <ets>mansum</ets>, a farm, fr. L. <ets>manere</ets>,
<ets>mansum</ets>, to stay, dwell. See <er>Mansion</er>,
<er>Manor</er>.]</ety> <sn>1.</sn> <def>A dwelling house, generally with
land attached.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The parsonage; a clergyman's house.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Capital manse</b></col>, <cd>the manor house, or lord's
court.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manservant</ent><br/
<hw>Man"serv`ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A male
servant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mansion</ent><br/
<hw>Man"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mansion</ets>, F. <ets>maison</ets>, fr. L. <ets>mansio</ets> a
staying, remaining, a dwelling, habitation, fr. <ets>manere</ets>,
<ets>mansum</ets>, to stay, dwell; akin to Gr. <?/. Cf. <er>Manse</er>,
<er>Manor</er>, <er>Menagerie</er>, <er>Menial</er>,
<er>Permanent</er>.]</ety> <sn>1.</sn> <def>A dwelling place, -- whether
a part or whole of a house or other shelter.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In my Father's house are many <qex>mansions</qex>.</q>
<rj><qau>John xiv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These poets near our princes sleep,<br/
And in one grave their <qex>mansions</qex> keep.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The house of the lord of a manor; a manor house;
hence: Any house of considerable size or pretension.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astrol.)</fld> <def>A twelfth part of the heavens;
a house. See 1st <er>House</er>, 8.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The place in the heavens occupied each day by the
moon in its monthly revolution.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The eight and twenty <qex>mansions</qex><br/
<qex>That longen to the moon</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mansion house</b></col>, <cd>the house in which one
resides; specifically, in London and some other cities, the official
residence of the Lord Mayor.</cd> <rj><au>Blackstone.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mansion</ent><br/
<hw>Man"sion</hw>, <pos>v. i.</pos> <def>To dwell; to reside.</def>
<mark>[Obs.]</mark> <rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mansionary</ent><br/
<hw>Man"sion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resident;
residentiary; <as>as, <ex>mansionary</ex> canons</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mansion house</ent><br/
<hw>mansion house</hw> <pos>n.</pos> <def>A large and imposing
house.</def><br/
<syn><b>Syn. --</b> mansion, manse, hall, residence.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mansionry</ent><br/
<hw>Man"sion*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
dwelling or residing; occupancy as a dwelling place.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>man-sized</ent><br/
<hw>man-sized</hw> <pos>adj.</pos> <sn>1.</sn> <def>Calling for manly
attributes; <as>as, a <ex>man-sized</ex> job</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Large enough to satisfy a man; <as>as, a
<ex>man-sized</ex> piece of cake</as>.</def> <mark>[informal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manslaughter</ent><br/
<hw>Man"slaugh`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
slaying of a human being; destruction of men.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The unlawful killing of a man,
either in negligence or incidentally to the commission of some unlawful
act, but without specific malice, or upon a sudden excitement of
anger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manslayer</ent><br/
<hw>Man"slay`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who kills a
human being; one who commits manslaughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manstealer</ent><br/
<hw>Man"steal`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person who
steals or kidnaps a human being or beings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manstealing</ent><br/
<hw>Man"steal`ing</hw>, <pos>n.</pos> <def>The act or business of
stealing or kidnapping human beings, especially with a view to enslave
them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mansuete</ent><br/
<hw>Man"suete</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mansuetus</ets>, p. p. of <ets>mansuescere</ets> to tame;
<ets>manus</ets> hand + <ets>suescere</ets> to accustom: cf. F.
<ets>mansuet</ets>.]</ety> <def>Tame; gentle; kind.</def>
<mark>[Obs.]</mark> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mansuetude</ent><br/
<hw>Man"sue*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mansuetudo</ets>: cf. F. <ets>mansu<eacute/tude</ets>.]</ety>
<def>Tameness; gentleness; mildness.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manswear</ent><br/
<hw>Man"swear`</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To swear
falsely. Same as <er>Mainswear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manta</ent><br/
\'d8<hw>Man"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the native
name.]</ety> <fld>(Zool.)</fld> <def>The <er>manta ray</er>. See also
<er>Cephaloptera</er> and <er>Sea devil</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manta ray</ent><br/
<hw>manta ray</hw> <pos>n.</pos> <def>An extremely large pelagic
tropical ray of the family <fam>Mobulidae</fam>, that feeds on plankton
and small fishes. It is usually harmless but its size (up to 20 feet
across and up to a ton in weight) make it dangerous if harpooned. Called
also <altname>manta</altname>, <altname>sea devil</altname> and
<altname>devilfish</altname>. See also <er>Cephaloptera</er> and <er>Sea
devil</er>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Mantchoo</ent><br/
<hw>Mant*choo"</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>Same as
<er>Manchu</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manteau</ent><br/
\'d8<hw>Man`teau"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> F.
<plw>Manteaux</plw> <pr>(#)</pr>, E. <plw>Manteaus</plw>
<pr>(#)</pr>.</plu> <ety>[F. See <er>Mantle</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>A woman's cloak or mantle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A gown worn by women.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manteidae</ent><br/
<hw>Manteidae</hw> <pos>prop. n.</pos> <def>A natural family of insects
including the mantises. Also spelled
<altname><fam>Mantidae</fam></altname>.</def><br/
<syn><b>Syn. --</b> <fam>Mantidae</fam>, family <fam>Mantidae</fam>,
family Manteidae.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mantel</ent><br/
<hw>Man"tel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[The same word as
<ets>mantle</ets> a garment; cf. F. <ets>manteau de
chemin<eacute/e</ets>. See <er>Mantle</er>.]</ety> <fld>(Arch.)</fld>
<def>The finish around a fireplace, covering the chimney-breast in front
and sometimes on both sides; especially, a shelf above the fireplace,
and its supports. The shelf is called also a
<altname>mantelpiece</altname> or <altname>mantlepiece</altname>.</def>
<altsp>[Written also <asp>mantle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantelet</ent><br/
<hw>Man"tel*et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., dim. of
<ets>manteau</ets>, OF. <ets>mantel</ets>. See <er>Mantle</er>.]</ety>
<sn>1.</sn> <sd>(a)</sd> <def>A short cloak formerly worn by
knights.</def> <sd>(b)</sd> <def>A short cloak or mantle worn by
women.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>mantelet</qex> upon his shoulders hanging.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fort.)</fld> <def>A musket-proof shield of rope,
wood, or metal, which is sometimes used for the protection of sappers or
riflemen while attacking a fortress, or of gunners at embrasures; -- now
commonly written <asp>mantlet</asp>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 893 --></p>

<p><ent>Mantelletta</ent><br/
<hw>Man`tel*let"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>mantelletta</ets>. See <er>Mantelet</er>.]</ety> <fld>(R. C.
Ch.)</fld> <def>A silk or woolen vestment without sleeves worn by
cardinals, bishops, abbots, and the prelates of the Roman court. It has
a low collar, is fastened in front, and reaches almost to the
knees.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mantelpiece</ent><br/
<hw>Man"tel*piece`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mantel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantelshelf</ent><br/
<hw>Man"tel*shelf`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The shelf of a
mantel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manteltree</ent><br/
<hw>Man"tel*tree`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>The lintel of a fireplace when of wood, as frequently in early
houses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantic</ent><br/
<hw>Man"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
prophetic.]</ety> <def>Of or pertaining to divination, or to the
condition of one inspired, or supposed to be inspired, by a deity;
prophetic.</def> <mark>[R.]</mark> <ldquo/<xex>Mantic</xex> fury.<rdquo/
<rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>manticore</ent><br/
<ent>manticora</ent><br/
<ent>mantichora</ent><br/
<mhw><hw>mantichora</hw>, <hw>manticora</hw>, <hw>manticore</hw></mhw>
<pos>n.</pos> <def>A mythical monster having the head of man (with
horns) and the body of a lion and the tail of a scorpion.</def><br/
<syn><b>Syn. --</b> manticore, mantichora, mantiger.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantid</ent><br/
<hw>mantid</hw> <pos>n.</pos> <def>A <er>mantis</er>.</def><br/
<syn><b>Syn. --</b> mantis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mantidae</ent><br/
<hw>Mantidae</hw> <pos>prop. n.</pos> <def>The natural family comprising
the mantises. Same as <fam>Manteidae</fam>.</def><br/
<syn><b>Syn. --</b> family Mantidae, <fam>Manteidae</fam>, family
Manteidae.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantiger</ent><br/
<hw>mantiger</hw> <pos>n.</pos> <def>The <er>manticore</er>.</def><br/
<syn><b>Syn. --</b> manticore, mantichora, manticora.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mantilla</ent><br/
<hw>Man*til"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. See
<er>Mantle</er>.]</ety> <sn>1.</sn> <def>A lady's light cloak of cape of
silk, velvet, lace, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of veil, covering the head and falling down
upon the shoulders; -- worn in Spain, Mexico, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantineia</ent><br/
<ent>Mantinea</ent><br/
<mhw><hw>Mantinea</hw>, <hw>Mantineia</hw></mhw> <pos>prop. n.</pos>
<def>The site of three famous battles among Greek city-states: in 418 BC
and 362 BC and 207 BC.</def><br/
<syn><b>Syn. --</b> Mantineia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mantis</ent><br/
\'d8<hw>Man"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
a prophet.]</ety> <fld>(Zool.)</fld> <def>Any one of numerous species of
voracious orthopterous insects of the genus <gen>Mantis</gen>, and
allied genera. They are predacious long-bodied large-eyed insects of
warm regions, are remarkable for their slender grotesque forms, and for
holding their stout anterior legs in a manner suggesting hands folded in
prayer. The common American species is <spn>Mantis
Carolina</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mantis shrimp</b></col>. <fld>(Zool.)</fld> <cd>The
<er>Squilla</er>, a tropical marine burrowing crustacean with large
grasping appendages. Also called <altname>mantis crab</altname> and
<altname>mantis prawn</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mantis crab</ent><br/
<hw>mantis crab</hw> <pos>n.</pos> <def>Same as
<er>Squilla</er>.</def><br/
<syn><b>Syn. --</b> Mantis shrimp.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantis prawn</ent><br/
<hw>mantis prawn</hw> <pos>n.</pos> <def>Same as
<er>Squilla</er>.</def><br/
<syn><b>Syn. --</b> Mantis shrimp.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantispid</ent><br/
<hw>man*tis"pid</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any neuropterous insect of the genus <gen>Mantispa</gen>, and
allied genera. The larvae feed on plant lice. Also used adjectively. See
<xex>Illust.</xex> under <er>Neuroptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantispidae</ent><br/
<hw>Mantispidae</hw> <pos>prop. n.</pos> <def>The natural family
comprising the mantispids.</def><br/
<syn><b>Syn. --</b> family <fam>Mantispidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantissa</ent><br/
<hw>man*tis*sa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., an addition,
makeweight; of Tuscan origin.]</ety> <fld>(Math.)</fld> <def>The decimal
part of a <partof>logarithm</partof>, as distinguished from the integral
part, or <contr>characteristic</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mantle</ent><br/
<hw>man"tle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mantel</ets>, OF. <ets>mantel</ets>, F. <ets>manteau</ets>, fr. L.
<ets>mantellum</ets>, <ets>mantelum</ets>, a cloth, napkin, cloak,
mantle (cf. <ets>mantele</ets>, <ets>mantile</ets>, towel, napkin);
prob. from <ets>manus</ets> hand + the root of <ets>tela</ets> cloth.
See <er>Manual</er>, <er>Textile</er>, and cf. <er>Mandil</er>,
<er>Mantel</er>, <er>Mantilla</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A loose garment to be worn over other garments; an
enveloping robe; a cloak.</def> <specif>Hence,</specif> figuratively,
<def>a covering or concealing envelope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The] children are clothed with <qex>mantles</qex> of satin.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The green <qex>mantle</qex> of the standing pool.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now Nature hangs her <qex>mantle</qex> green<br/
On every blooming tree.</q> <rj><qau>Burns.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Same as
<er>Mantling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The external fold,
or folds, of the soft, exterior membrane of the body of a mollusk. It
usually forms a cavity inclosing the gills. See <xex>Illusts.</xex> of
<er>Buccinum</er>, and <er>Byssus</er>.</def> <sd>(b)</sd> <def>Any
free, outer membrane.</def> <sd>(c)</sd> <def>The back of a bird
together with the folded wings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>A mantel. See
<er>Mantel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The outer wall and casing of a blast furnace, above
the hearth.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Hydraulic Engin.)</fld> <def>A penstock for a water
wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Geol.)</fld> <def>The highly viscous shell of hot
semisolid rock, about 1800 miles thick, lying under the crust of the
Earth and above the core. Also, by analogy, a similar shell on any other
planet.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mantle</ent><br/
<hw>Man"tle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mantled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mantling</conjf> <pr>(?)</pr>.]</vmorph> <def>To cover or
envelop, as with a mantle; to cloak; to hide; to disguise.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantle</ent><br/
<hw>Man"tle</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To unfold and spread
out the wings, like a mantle; -- said of hawks. Also used
figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ne is there hawk which <qex>mantleth</qex> on her perch.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Or tend his sparhawk <qex>mantling</qex> in her mew.</q>
<rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My frail fancy fed with full delight.<br/
Doth bathe in bliss, and <qex>mantleth</qex> most at ease.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spread out; -- said of wings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The swan, with arched neck<br/
Between her white wings <qex>mantling</qex> proudly, rows.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To spread over the surface as a covering; to
overspread; <as>as, the scum <ex>mantled</ex> on the
pool</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though <qex>mantled</qex> in her cheek the blood.</q> <rj><qau>Sir
W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To gather, assume, or take on, a covering, as froth,
scum, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a sort of men whose visages<br/
Do cream and <qex>mantle</qex> like a standing pond.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor bowl of wassail <qex>mantle</qex> warm.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mantled</ent><br/
<hw>man"tled</hw> <pos>adj.</pos> <def>Covered with or as if with
clothes or a wrap or cloak.</def><br/
<syn><b>Syn. --</b> cloaked, clothed, draped, wrapped.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantled ground squirrel</ent><br/
<hw>mantled ground squirrel</hw> <pos>n.</pos> <def>A common
black-striped reddish-brown ground squirrel (<spn>Citellus
lateralis</spn>) of western North America, resembling a large
chipmunk.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mantlepiece</ent><br/
<hw>man"tle*piece</hw> <pos>n.</pos> <def>A shelf that projects from the
wall above a fireplace; a mantel; <as>as, in England they call a
<ex>mantelpiece</ex> a chimneypiece</as>.</def><br/
<syn><b>Syn. --</b> mantel, mantelpiece, mantle, chimneypiece.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mantlet</ent><br/
<hw>Man"tlet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mantelet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantling</ent><br/
<hw>Man"tling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Her.)</fld>
<def>The representation of a mantle, or the drapery behind and around a
coat of arms: -- called also <altname>lambrequin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manto</ent><br/
<hw>Man"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. or Sp.
<ets>manto</ets>, abbrev., from L. <ets>mantelum</ets>. See
<er>Mantle</er>.]</ety> <def>See <er>Manteau</er>.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantologist</ent><br/
<hw>Man*tol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
skilled in mantology; a diviner.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantology</ent><br/
<hw>Man*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ prophet
+ <ets>-logy</ets>.]</ety> <def>The act or art of divination.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantoux test</ent><br/
<hw>Mantoux test</hw> <pos>prop. n.</pos> <fld>(Med.)</fld> <def>A skin
test for hypersensitivity to tuberculin. It determines whether there is
or has been any infection with tubercle bacilli.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mantra</ent><br/
\'d8<hw>Man"tra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.]</ety>
<def>A prayer; an invocation; a religious formula; a charm.</def>
<mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Among the Hindoos each caste and tribe has a
<xex>mantra</xex> peculiar to itself; as, the <xex>mantra</xex> of the
Brahmans.</note> <rj><au>Balfour (Cyc. of India).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantrap</ent><br/
<hw>Man"trap`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A trap
for catching trespassers.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dangerous place, as an open hatch, into which one
may fall.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantua</ent><br/
<hw>Man"tu*a</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
superior kind of rich silk formerly exported from Mantua in Italy.</def>
<mark>[Obs.]</mark> <rj><au>Beck (Draper's Dict.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman's cloak or mantle; also, a woman's
gown.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantuamaker</ent><br/
<hw>Man"tu*a*mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes
dresses, cloaks, etc., for women; a dressmaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mantuan</ent><br/
<hw>Man"tu*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Mantua.</def> -- <def2><pos>n.</pos> <def>A native or inhabitant of
Mantua.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manu</ent><br/
\'d8<hw>Ma"nu</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.]</ety>
<fld>(Hind. Myth.)</fld> <def>One of a series of progenitors of human
beings, and authors of human wisdom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manual</ent><br/
<hw>Man"u*al</hw> <pr>(m<acr/n"<usl/*<ait/l)</pr>, <pos>a.</pos>
<ety>[OE. <ets>manuel</ets>, F. <ets>manuel</ets>, L.
<ets>manualis</ets>, fr. <ets>manus</ets> hand; prob. akin to AS.
<ets>mund</ets> hand, protection, OHG. <ets>munt</ets>, G.
<ets>m<uum/nd</ets>el a ward, vor<ets>mund</ets> guardian, Icel.
<ets>mund</ets> hand. Cf. <er>Emancipate</er>, <er>Legerdemain</er>,
<er>Maintain</er>, <er>Manage</er>, <er>Manner</er>, <er>Manure</er>,
<er>Mound</er> a hill.]</ety> <sn>1.</sn> <def>Of or pertaining to the
hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Performed by a person using physical as contrasted
with <contr>mental</contr> effort; <as>as, <ex>manual</ex>
labor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Done or made by the hand. In some contexts,
contrasted with <contr>automatic</contr> or
<contr>mechanical</contr>.</def> <ldquo/<xex>Manual</xex> and ocular
examination.<rdquo/ <rj><au>Tatham.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Manual exercise</b></col> <fld>(Mil.)</fld> <cd>the
exercise by which soldiers are taught the use of their muskets and other
arms.</cd> -- <col><b>Seal manual</b></col>, <cd>the impression of a
seal worn on the hand as a ring.</cd> -- <col><b>Sign manual</b></col>.
<cd>See under <er>Sign</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manual</ent><br/
<hw>Man"u*al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>manuel</ets>, LL. <ets>manuale</ets>. See <er>Manual</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>A small book, such as may be
carried in the hand, or conveniently handled; a handbook; specifically,
the service book of the Roman Catholic Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>manual</qex> of laws, styled the Confessor's Laws.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A keyboard of an organ or
harmonium for the fingers, as distinguished from the pedals; a clavier,
or set of keys.</def> <rj><au>Moore (Encyc. of Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>A prescribed exercise in the
systematic handing of a weapon; <as>as, the <ex>manual</ex> of arms; the
<ex>manual</ex> of the sword; the <ex>manual</ex> of the piece (cannon,
mortar, etc.).</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manual alphabet</ent><br/
<hw>manual alphabet</hw> <pos>n.</pos> <def>An alphabet of signs made by
movement of the hands, used by the deaf; in it letters are represented
by finger positions. See <er>Dactylology</er>.</def><br/
<syn><b>Syn. --</b> finger alphabet.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manual dexterity</ent><br/
<hw>manual dexterity</hw> <pos>n.</pos> <def>Adroitness in using the
hands.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manualist</ent><br/
<hw>Man"u*al*ist</hw>, <pos>n.</pos> <def>One who works with the hands;
an artificer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manual labour</ent><br/
<ent>manual labor</ent><br/
<mhw><hw>manual labor</hw>, <hw>manual labour</hw></mhw> <pos>n.</pos>
<def>Labor done with the hands.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manual laborer</ent><br/
<hw>manual laborer</hw> <pos>n.</pos> <def>A person who works with the
hands, rather than with the mind.</def><br/
<syn><b>Syn. --</b> laborer, labourer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manually</ent><br/
<hw>man"u*al*ly</hw>, <pos>adv.</pos> <def>By hand. In some contexts,
contrasted with <contr>automatically</contr>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Manuary</ent><br/
<hw>Man"u*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>manuarius</ets>, fr. <ets>manus</ets> hand.]</ety>
<def>Manual.</def> -- <def2><pos>n.</pos> <def>An
artificer.</def></def2> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manubial</ent><br/
<hw>Ma*nu"bi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>manubialis</ets>, fr. <ets>manubiae</ets> money obtained from the
sale of booty, booty.]</ety> <def>Belonging to spoils; taken in
war.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manubrial</ent><br/
<hw>Ma*nu"bri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to a manubrium; shaped like a manubrium;
handlelike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manubrium</ent><br/
\'d8<hw>Ma*nu"bri*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
L. <plw>Manubria</plw> <pr>(#)</pr>, E. <plw>Manubriums</plw>
<pr>(#)</pr>.</plu> <ety>[L., handle, fr. <ets>manus</ets>
hand.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>A handlelike process or part;
esp., the anterior segment of the sternum, or presternum, and the
handlelike process of the malleus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The proboscis of a jellyfish; --
called also <altname>hypostoma</altname>. See <xex>Illust.</xex> of
<er>Hydromedusa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manucode</ent><br/
<hw>Man"u*code</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Javanese
<ets>manukdewata</ets> the bird of the gods: cf. F.
<ets>manucode</ets>.]</ety> <fld>(Zool.)</fld> <def>Any bird of the
genus <gen>Manucodia</gen>, of Australia and New Guinea. They are
related to the bird of paradise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuducent</ent><br/
<hw>Man`u*du"cent</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who leads by
the hand; a manuductor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuduction</ent><br/
<hw>Man`u*duc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manus</ets> hand + <ets>ductio</ets> a leading, <ets>ducere</ets>
to lead: cf. F. <ets>manuduction</ets>.]</ety> <def>Guidance by the
hand.</def> <mark>[Obs.]</mark> <rj><au>Glanvill.</au>
<au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuductor</ent><br/
<hw>Man`u*duc"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manus</ets> the hand + <ets>ductor</ets> a leader,
<ets>ducere</ets> to lead: cf. F. <ets>manuducteur</ets>.]</ety>
<fld>(Mus.)</fld> <def>A conductor; an officer in the ancient church who
gave the signal for the choir to sing, and who beat time with the hand,
and regulated the music.</def> <rj><au>Moore (Encyc. of
Music.)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufactory</ent><br/
<hw>Man`u*fac"to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. L. <ets>factorium</ets>
an oil press, properly, place where something is made. See
<er>Manufacture</er>.]</ety> <sn>1.</sn> <def>Manufacture.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A building or place where anything is manufactured;
a factory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufactory</ent><br/
<hw>Man`u*fac"to*ry</hw>, <pos>a.</pos> <def>Pertaining to
manufacturing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufactural</ent><br/
<hw>Man`u*fac"tur*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to manufactures.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufacture</ent><br/
<hw>Man`u*fac"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manus</ets> the hand + <ets>factura</ets> a making, fr.
<ets>facere</ets> to make: cf. F. <ets>manufacture</ets>. See
<er>Manual</er>, and <er>Fact</er>.]</ety> <sn>1.</sn> <def>The
operation of making wares or any products by hand, by machinery, or by
other agency.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything made from raw materials by the hand, by
machinery, or by art, as cloths, iron utensils, shoes, machinery,
saddlery, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufacture</ent><br/
<hw>Man`u*fac"ture</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Manufactured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Manufacturing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>manufacturer</ets>.]</ety> <sn>1.</sn> <def>To make (wares or other
products) by hand, by machinery, or by other agency; <as>as, to
<ex>manufacture</ex> cloth, nails, glass, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To work, as raw or partly wrought materials, into
suitable forms for use; <as>as, to <ex>manufacture</ex> wool, cotton,
silk, or iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufacture</ent><br/
<hw>Man`u*fac"ture</hw>, <pos>v. i.</pos> <def>To be employed in
manufacturing something.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manufactured</ent><br/
<hw>manufactured</hw> <pos>adj.</pos> <def>Produced in a large-scale
industrial operation. Contrasted with
<contr>hand-made</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manufacturer</ent><br/
<hw>Man`u*fac"tur*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
manufactures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manufacturing</ent><br/
<hw>Man`u*fac"tur*ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Employed, or
chiefly employed, in manufacture; <as>as, a <ex>manufacturing</ex>
community; a <ex>manufacturing</ex> town.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to manufacture; <as>as,
<ex>manufacturing</ex> projects</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manufacturing business</ent><br/
<hw>manufacturing business</hw> <pos>n.</pos> <def>A business engaged in
manufacturing some product.</def><br/
<syn><b>Syn. --</b> manufacturer, maker.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manufacturing plant</ent><br/
<hw>manufacturing plant</hw> <pos>n.</pos> <def>A factory.</def><br/
<syn><b>Syn. --</b> mill, manufacturing plant, manufactory.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manul</ent><br/
\'d8<hw>ma"nul</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A wild cat (<spn>Felis manul</spn>), having long, soft,
light-colored fur. It is found in the mountains of Central Asia, and
dwells among rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manumise</ent><br/
<hw>Man"u*mise`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Manumit</er>.]</ety> <def>To manumit.</def> <mark>[Obs.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manumission</ent><br/
<hw>Man`u*mis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manumissio</ets>: cf. F. <ets>manumission</ets>. See
<er>Manumit</er>.]</ety> <def>The act of manumitting, or of liberating a
slave from bondage.</def> <ldquo/Given to slaves at their
<xex>manumission</xex>.<rdquo/ <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manumit</ent><br/
<hw>Man`u*mit"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Manumitted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Manumitting</conjf>.]</vmorph> <ety>[L. <ets>manumittere</ets>,
<ets>manumissum</ets>; <ets>manus</ets> the hand + <ets>mittere</ets> to
send, to send off. See <er>Manual</er>, and <er>Missile</er>.]</ety>
<def>To release from slavery; to liberate from personal bondage or
servitude; to free, as a slave.</def> <ldquo/<xex>Manumitted</xex>
slaves.<rdquo/ <rj><au>Hume.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manumotive</ent><br/
<hw>Man"u*mo`tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>manus</ets> the hand + E. <ets>motive</ets>.]</ety> <def>Movable by
hand.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manumotor</ent><br/
<hw>Man"u*mo`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manus</ets> the hand + E. <ets>motor</ets>.]</ety> <def>A small
wheel carriage, so constructed that a person sitting in it may move
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manurable</ent><br/
<hw>Ma*nur"a*ble</hw> <pr>(<?/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of cultivation.</def> <mark>[Obs.]</mark> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of receiving a fertilizing
substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manurage</ent><br/
<hw>Ma*nur"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Cultivation.</def>
<mark>[Obs.]</mark> <rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manurance</ent><br/
<hw>Ma*nur"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Cultivation.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manure</ent><br/
<hw>Ma*nure"</hw> <pr>(m<adot/*n<umac/r")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Manured</conjf>
<pr>(m<adot/*n<umac/rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Manuring</conjf>.]</vmorph> <ety>[Contr, from OF.
<ets>manuvrer</ets>, <ets>manovrer</ets>, to work with the hand, to
cultivate by manual labor, F. <ets>man<oe/uvrer</ets>. See
<er>Manual</er>, <er>Ure</er>, <er>Opera</er>, and cf.
<er>Inure</er>.]</ety> <sn>1.</sn> <def>To cultivate by manual labor; to
till; hence, to develop by culture.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To whom we gave the strand for to <qex>manure</qex>.</q>
<rj><qau>Surrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Manure</qex> thyself then; to thyself be improved;<br/
And with vain, outward things be no more moved.</q>
<rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To apply manure to; to enrich, as land, by the
application of a fertilizing substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The blood of English shall <qex>manure</qex> the ground.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>manure</ent><br/
<hw>ma*nure"</hw> <pr>(m<adot/*n<umac/r")</pr>, <pos>n.</pos> <def>Any
matter which makes land productive; a fertilizing substance.</def>
<specif>Especially,</specif>, <def>dung, the contents of stables and
barnyards, decaying animal or vegetable substances, etc.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manurement</ent><br/
<hw>Ma*nure"ment</hw>, <pos>n.</pos> <ety>[Cf. OF.
<ets>manouvrement</ets>.]</ety> <def>Cultivation.</def>
<mark>[Obs.]</mark> <rj><au>W. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manurer</ent><br/
<hw>Ma*nur"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who manures
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manurial</ent><br/
<hw>Ma*nu"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
manures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuring</ent><br/
<hw>Ma*nur"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of process
of applying manure; also, the manure applied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manus</ent><br/
\'d8<hw>Ma"nus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Manus</plw>.</plu> <ety>[L., the hand.]</ety> <fld>(Anat.)</fld>
<def>The distal segment of the fore limb, including the carpus and fore
foot or hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuscript</ent><br/
<hw>Man"u*script</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>manu
scriptus</ets>. See <er>Manual</er>, and <er>Scribe</er>.]</ety>
<def>Written with or by the hand; not printed; <as>as, a
<ex>manuscript</ex> volume</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuscript</ent><br/
<hw>Man"u*script</hw>, <pos>n.</pos> <ety>[LL. <ets>manuscriptum</ets>,
lit., something written with the hand. See <er>Manuscript</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>An original literary or musical
composition written by the author, formerly with the hand, now usually
by typewriter or word processor. It is contrasted with a printed
copy.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Writing, as opposed to print; <as>as, the book
exists only in <ex>manuscript</ex></as>.</def>
<rj><au>Craik.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is often abbreviated to <abbr>MS.</abbr>,
plural <abbr>MSS.</abbr></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manuscriptal</ent><br/
<hw>Man"u*script`al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Manuscript.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manutenency</ent><br/
<hw>Man`u*ten"en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>manus</ets> hand + <ets>tenere</ets> to hold.]</ety>
<def>Maintenance.</def> <mark>[Obs.]</mark> <rj><au>Abp.
Sancroft.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manway</ent><br/
<hw>Man"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small passageway,
as in a mine, that a man may pass through.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manx</ent><br/
<hw>Manx</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to the
Isle of Man, or its inhabitants; <as>as, the <ex>Manx</ex>
language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Manx shearwater</b></col> <cd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manx cat</ent><br/
<hw>Manx cat</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld>, <def>A breed
of domestic cats having a rudimentary tail, containing only about three
vertebrae. It is believed to have originated on the Isle of
Man.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Manx shearwater</ent><br/
<hw>Manx shearwater</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld>, <def>A
small black-and-white oceanic bird (<spn>Puffinus puffinus</spn>, or
<spn>Puffinus anglorum</spn>), common in the Eastern North Atlantic.
Called also <altname>Manx petrel</altname>, <altname>Manx
puffin</altname>. It is a variety of <er>shearwater</er>. It was
formerly abundant in the Isle of Man.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manx</ent><br/
<hw>Manx</hw>, <pos>prop. n.</pos> <def>The language of the inhabitants
of the Isle of Man, a dialect of the Celtic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Many</ent><br/
<hw>Ma"ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Meine</er>,
<er>Mansion</er>.]</ety> <def>A retinue of servants; a household.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Many</ent><br/
<hw>Ma"ny</hw>, <pos>a. & pron.</pos> <note>[It has no variation to
express degrees of comparison; <xex>more</xex> and <xex>most</xex>,
which are used for the comparative and superlative degrees, are from a
different root.]</note> <ety>[OE. <ets>mani</ets>, <ets>moni</ets>, AS.
<ets>manig</ets>, <ets>m<ae/nig</ets>, <ets>monig</ets>; akin to D.
<ets>menig</ets>, OS. & OHG. <ets>manag</ets>, G. <ets>manch</ets>, Dan.
<ets>mange</ets>, Sw. <ets>m<aring/nge</ets>, Goth. <ets>manags</ets>,
OSlav. <ets>mnog'</ets>, Russ. <ets>mnogii</ets>; cf. Icel.
<ets>margr</ets>, Prov. E. <ets>mort</ets>. <root/103.]</ety>
<def>Consisting of a great number; numerous; not few.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt be a father of <qex>many</qex> nations.</q>
<rj><qau>Gen. xvii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>many</qex> wise men after the flesh, not <qex>many</qex>
mighty, not <qex>many</qex> noble, are called.</q> <rj><qau>1 Cor. i.
26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Many</xex> is freely prefixed to participles,
forming compounds which need no special explanation; as,
<xex>many-</xex>angled, <xex>many-</xex>celled, <xex>many-</xex>eyed,
<xex>many-</xex>footed, <xex>many-</xex>handed, <xex>many-</xex>leaved,
<xex>many-</xex>lettered, <xex>many-</xex>named,
<xex>many-</xex>peopled, <xex>many-</xex>petaled,
<xex>many-</xex>seeded, <xex>many-</xex>syllabled (polysyllabic),
<xex>many-</xex>tongued, <xex>many-</xex>voiced, <xex>many-</xex>wived,
and the like. In such usage it is equivalent to
<altname>multi</altname>. Comparison is often expressed by
<xex>many</xex> with <xex>as</xex> or <xex>so</xex>. <ldquo/As
<xex>many</xex> as were willing hearted . . . brought bracelets.<rdquo/
<au>Exod. xxxv. 22.</au> <ldquo/So <xex>many</xex> laws argue so
<xex>many</xex> sins.<rdquo/ <au>Milton.</au> <xex>Many</xex> stands
with a singular substantive with <xex>a</xex> or
<xex>an</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Many a</b></col>, <cd>a large number taken
distributively; each one of many.</cd> <ldquo/For thy sake have I shed
<xex>many a</xex> tear.<rdquo/ <au>Shak.</au> <ldquo/Full <xex>many
a</xex> gem of purest ray serene.<rdquo/ <au>Gray.</au> -- <col><b>Many
one</b></col>, <cd>many a one; many persons.</cd> <au>Bk. of Com.
Prayer.</au> -- <col><b>The many</b></col>, <cd>the majority; -- opposed
to <contr>the few</contr>. See <er>Many</er>, <pos>n.</pos></cd> --
<col><b>Too many</b></col>, <cd>too numerous; hence, too powerful;
<as>as, they are <ex>too many</ex> for us</as>.</cd>
<rj><au>L'Estrange.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Numerous; multiplied; frequent; manifold;
various; divers; sundry.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Many</ent><br/
<hw>Ma"ny</hw>, <pos>n.</pos> <ety>[AS. <ets>menigeo</ets>,
<ets>menigo</ets>, <ets>menio</ets>, multitude; akin to G.
<ets>menge</ets>, OHG. <ets>manag<imac/</ets>, <ets>menig<imac/</ets>,
Goth. <ets>managei</ets>. See <er>Many</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>The populace; the common people; the majority of
people, or of a community.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After him the rascal <qex>many</qex> ran.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A large or considerable number.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>many</qex> of our bodies shall no doubt<br/
Find native graves.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Seeing a great <qex>many</qex> in rich gowns.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It will be concluded by <qex>many</qex> that he lived like an
honest man.</q> <rj><qau>Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this sense, <xex>many</xex> is connected immediately
with another substantive (without <xex>of</xex>) to show of what the
<xex>many</xex> consists; as, a good <xex>many</xex> [of] people think
so.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>He is liable to a great <qex>many</qex> inconveniences.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Many-minded</ent><br/
<hw>Ma"ny-mind`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having many
faculties; versatile; many-sided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Manyplies</ent><br/
<hw>Ma"ny*plies</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Many</ets>,
adj. + <ets>plies</ets>, pl. of <ets>ply</ets> a fold.]</ety>
<fld>(Anat.)</fld> <def>The third division, or that between the
reticulum, or honeycomb stomach, and the abomasum, or rennet stomach, in
the stomach of ruminants; the omasum; the psalterium. So called from the
numerous folds in its mucous membrane. See <xex>Illust</xex> of
<er>Ruminant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Many-sided</ent><br/
<hw>Ma"ny-sid`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having many sides; -- said of figures. Hence, presenting many
questions or subjects for consideration; <as>as, a <ex>many-sided</ex>
topic</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Interested in, and having an aptitude for, many
unlike pursuits or objects of attention; versatile.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ma"ny-sid`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 894 --></p>

<p><ent>manywise</ent><br/
<ent>manyways</ent><br/
<mhw>{ <hw>ma"ny*ways`</hw> <pr>(m<ecr/n"<ycr/*w<amac/z`)</pr>,
<hw>ma"ny*wise`</hw> <pr>(m<ecr/n"<ycr/*w<imac/z`)</pr>, }</mhw>
<pos>adv.</pos> <def>In many different ways; variously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>manzanilla</ent><br/
<hw>man`za*nil"la</hw> <pr>(m<acr/n`z<adot/*n<icr/l"l<adot/;
<it>Sp.</it> m<aum/n`th<aum/*n<emac/l"y<aum/)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Olive Trade)</fld> <def>A kind of small roundish olive
with a small freestone pit, a fine skin, and a peculiar bitterish
flavor. Manzanillas are commonly pitted and stuffed with Spanish
pimientos.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A very dry pale sherry from Spain.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>manzanita</ent><br/
<hw>man`za*ni"ta</hw> <pr>(m<acr/n`z<adot/*n<emac/"t<adot/)</pr>,
<pos>n.</pos> <ety>[Sp., dim. of <ets>manzana</ets> an apple.]</ety>
<fld>(Bot.)</fld> <def>A name given to several species of
<spn>Arctostaphylos</spn>, but mostly to <spn>Arctostaphylos
glauca</spn> and <spn>Arctostaphylos pungens</spn>, shrubs of
California, Oregon, etc., with reddish smooth bark, ovate or oval
coriaceous evergreen leaves, and bearing clusters of red berries, which
are said to be a favorite food of the grizzly bear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mao</ent><br/
<hw>Mao</hw> <pos>prop. n.</pos> <def>See <er>Mao
Tsetung</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maoism</ent><br/
<hw>Maoism</hw> <pos>prop. n.</pos> <def>A form of communism developed
in China by Mao Zedong.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maoist</ent><br/
<hw>Maoist</hw> <pos>prop. n.</pos> <def>An advocate of
Maoism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maori</ent><br/
<hw>Ma"o*ri</hw> <pr>(?)</pr>, <pos>prop. n.</pos>; <plu><it>pl.</it>
<plw>Maoris</plw> <pr>(<?/)</pr>.</plu> <fld>(Ethnol.)</fld> <def>One of
the aboriginal inhabitants of New Zealand; also, the original language
of New Zealand.</def> -- <def2><pos>a.</pos> <def>Of or pertaining to
the Maoris or to their language.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>maori hen</ent><br/
<hw>maori hen</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A flightless
New Zealand rail of thievish disposition having short wings each with a
spur used in fighting.</def><br/
<syn><b>Syn. --</b> weka, wood hen.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mao Zedong</ent><br/
<ent>Mao Tsetung</ent><br/
<mhw><hw>Mao Tsetung</hw>, <hw>Mao Zedong</hw></mhw> <pos>prop. n.</pos>
<def>The leader of the Chinese communist party and later of the People's
Republic of China; b. 1893, d. 1976. Also referred to a simply
<altname>Mao</altname>.</def> <altsp>[Also spelled <asp>Mao
Tse-Tung</asp>.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Map</ent><br/
<hw>Map</hw> <pr>(m<acr/p)</pr>, <pos>n.</pos> <ety>[From F.
<ets>mappe</ets>, in <ets>mappemonde</ets> map of the world, fr. L.
<ets>mappa</ets> napkin, signal cloth; -- a Punic word. Cf.
<er>Apron</er>, <er>Napkin</er>, <er>Nappe</er>.]</ety> <sn>1.</sn>
<def>A representation of the surface of the earth, or of some portion of
it, showing the relative position of the parts represented; -- usually
on a flat surface. Also, such a representation of the celestial sphere,
or of some part of it.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are five principal kinds of projection used in
making maps: the <xex>orthographic</xex>, the <xex>stereographic</xex>,
the <xex>globuar</xex>, the <xex>conical</xex>, and the
<xex>cylindrical</xex>, or <xex>Mercator's projection</xex>. See
<er>Projection</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A graphical representation of anything showing the
relative arrangement of its parts in a maplike form.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Anything which represents graphically a succession
of events, states, or acts; <as>as, an historical
<ex>map</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus is his cheek the <qex>map</qex> of days outworn.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mathematics)</fld> <def>A relation between two sets
in which an element of one set is associated with each element of the
other set. Also called a <asp>mapping</asp>, <asp>transformation</asp>,
or <asp>correspondence</asp>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Map lichen</b></col> <fld>(Bot.)</fld>, <cd>a lichen
(<spn>Lecidea geographica</spn>.) growing on stones in curious maplike
figures.</cd> <rj><au>Dr. Prior.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Map</ent><br/
<hw>Map</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mapped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mapping</conjf> <pr>(?)</pr>.]</vmorph> <def>To represent by a
map; -- often with <xex>out</xex>; <as>as, to survey and <ex>map</ex>,
or <ex>map out</ex>, a <ex>county</ex></as>. Hence, figuratively: To
represent or indicate systematically and clearly; to sketch; to plan;
<as>as, to <ex>map</ex>, or <ex>map out</ex>, a journey; to <ex>map
out</ex> business.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am near to the place where they should meet, if Pisanio have
<qex>mapped</qex> it truly.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mathematics)</fld> <def>To create a mapping between
two sets; see <er>map</er>{4}, <pos>n.</pos>. Also, to create any list
of corresponding elements of two sets of things; <as>as, to <ex>map</ex>
the symbols of an ancient language into a modern phonetic
alphabet</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mapach</ent><br/
\'d8<hw>Ma*pach"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Mexican.]</ety>
<def>The raccoon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mapinguari</ent><br/
<hw>mapinguari</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A supposed
human-sized slothlike creature reported sighted by Indians in the Amazon
rain forest.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maple</ent><br/
<hw>Ma"ple</hw> <pr>(m<amac/"p'l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mapolder</ets>, <ets>mapulder</ets>, <ets>mapol</ets>; akin to
Icel. <ets>m<oum/purr</ets>; cf. OHG. <ets>mazzaltra</ets>,
<ets>mazzoltra</ets>, G. <ets>massholder</ets>.]</ety> <fld>(Bot.)</fld>
<def>A tree of the genus <gen>Acer</gen>, including about fifty species.
<spn>Acer saccharinum</spn> is the <stype>rock maple</stype>, or
<stype>sugar maple</stype>, from the sap of which sugar is made, in the
United States, in great quantities, by evaporation; the <stype>red
maple</stype> or <stype>swamp maple</stype> is <spn>Acer rubrum</spn>;
the <stype>silver maple</stype>, <spn>Acer dasycarpum</spn>, having
fruit wooly when young; the <stype>striped maple</stype>, <spn>Acer
Pennsylvanium</spn>, called also <stype>moosewood</stype>. The common
maple of Europe is <spn>Acer campestre</spn>, the <stype>sycamore
maple</stype> is <spn>Acer Pseudo-platanus</spn>, and the <stype>Norway
maple</stype> is <spn>Acer platanoides</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Maple</xex> is much used adjectively, or as the
first part of a compound; as, <xex>maple</xex> tree, <xex>maple</xex>
leaf, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bird's-eye maple</b></col>, <col><b>Curled
maple</b></col></mcol>, <cd>varieties of the wood of the rock maple, in
which a beautiful lustrous grain is produced by the sinuous course of
the fibers.</cd> -- <mcol><col><b>Maple honey</b></col>, <col><b>Maple
molasses</b></col>, <col><b>Maple syrup</b></col>, <it>or</it>
<col><b>Maple sirup</b></col></mcol>, <cd>maple sap boiled to the
consistency of molasses.</cd> -- <col><b>Maple sugar</b></col>,
<cd>sugar obtained from the sap of the sugar maple by
evaporation.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>maple-leaf begonia</ent><br/
<hw>maple-leaf begonia</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
tuberous or semi-tuberous South African begonia (<spn>Begonia
dregei</spn>) having shallowly lobed ovate leaves and small white
flowers.</def><br/
<syn><b>Syn. --</b> grape-leaf begonia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maple-leaved bayur</ent><br/
<hw>maple-leaved bayur</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>An
Indian tree (<spn>Pterospermum acerifolium</spn>) having fragrant
nocturnal white flowers and yielding a reddish wood used for planking;
often grown as an ornamental or shade tree. Called also
<altname>mayeng</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maple family</ent><br/
<hw>maple family</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>The natural
family of trees <fam>Aceraceae</fam>, including the maples.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maplike</ent><br/
<hw>Map"like`</hw> <pr>(m<acr/p"l<imac/k`)</pr>, <pos>a.</pos>
<def>Having or consisting of lines resembling a map; <as>as, the
<ex>maplike</ex> figures in which certain lichens grow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mapmaker</ent><br/
<ent>map maker</ent><br/
<mhw><hw>map" mak*er</hw>, <hw>map"mak*er</hw></mhw> <pos>n.</pos>
<def>A person who makes maps; a cartographer.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mapmaking</ent><br/
<hw>map"mak*ing</hw> <pos>n.</pos> <def>The making of maps and charts;
cartography.</def><br/
<syn><b>Syn. --</b> cartography.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mappery</ent><br/
<hw>map"per*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Map.]</ety>
<def>The making, or study, of maps.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mapping</ent><br/
<hw>map"ping</hw> <pos>n.</pos> <fld>(Math.)</fld> <def>A function such
that for every element of one set there is a unique element of another
set. Same as <er>map</er>{4}.</def><br/
<syn><b>Syn. --</b> map, correspondence.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maqui</ent><br/
<hw>Ma"qui</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
Chilian shrub (<spn>Aristotelia Maqui</spn>). Its bark furnishes strings
for musical instruments, and a medicinal wine is made from its
berries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maquis</ent><br/
<hw>Maquis</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A guerrilla fighter
in the French underground in World War II.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The French underground that fought against the
German occupation in World War II.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mar</ent><br/
<hw>Mar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small lake. See
<er>Mere</er>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mar</ent><br/
<hw>Mar</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marred</conjf> <pr>(m<aum/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Marring</conjf>.]</vmorph> <ety>[OE. <ets>marren</ets>,
<ets>merren</ets>, AS. <ets>merran</ets>, <ets>myrran</ets> (in comp.),
to obstruct, impede, dissipate; akin to OS. <ets>merrian</ets>, OHG.
<ets>marrjan</ets>, <ets>merran</ets>; cf. D. <ets>marren</ets>,
<ets>meeren</ets>, to moor a ship, Icel. <ets>merja</ets> to bruise,
crush, and Goth. <ets>marzjan</ets> to offend. Cf. <er>Moor</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>To make defective; to do injury
to, esp. by cutting off or defacing a part; to impair; to disfigure; to
deface.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I pray you <qex>mar</qex> no more trees with wiring love songs in
their barks.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But mirth is <qex>marred</qex>, and the good cheer is lost.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ire, envy, and despair<br/
Which <qex>marred</qex> all his borrowed visage.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spoil; to ruin.</def> <ldquo/It makes us, or it
<xex>mars</xex> us.<rdquo/ <ldquo/Striving to mend, to <xex>mar</xex>
the subject.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mar</ent><br/
<hw>Mar</hw>, <pos>n.</pos> <def>A mark or blemish made by bruising,
scratching, or the like; a disfigurement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mara</ent><br/
\'d8<hw>Ma"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.
<ets>m<amac/ra</ets>.]</ety> <fld>(Hind. Myth.)</fld> <def>The principal
or ruling evil spirit.</def> <rj><au>E. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mara</ent><br/
\'d8<hw>Ma"ra</hw>, <pos>n.</pos> <ety>[Icel. <ets>mara</ets> nightmare,
an ogress. See <er>Nightmare</er>.]</ety> <fld>(Norse Myth.)</fld>
<def>A female demon who torments people in sleep by crouching on their
chests or stomachs, or by causing terrifying visions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mara</ent><br/
\'d8<hw>Ma"ra</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The Patagonian
cavy, a hare-like rodent (<spn>Dolichotis patagonum</spn> or
<spn>Dolichotis Patagonicus</spn>) of the pampas of Argentina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marabou</ent><br/
<hw>Mar`a*bou"</hw> <pr>(m<acr/r"<adot/b<oomac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A large
black-and-white carrion-eating stork of the genus <gen>Leptoptilos</gen>
(formerly <spn>Ciconia</spn>), esp. the African species
(<spn>Leptoptilus crumeniferus</spn> syn. <spn>Leptoptilos
crumenifer</spn>), whose downy under-wing feathers are used to trim
garments; called also <altname>marabout</altname>. The Asiatic species
(<spn>Leptoptilos dubius</spn>, or <spn>Leptoptilos argala</spn>) is the
adjutant. See <er>Adjutant</er>.</def> <altsp>[Written also
<asp>marabu</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One having five eighths negro blood; the offspring
of a mulatto and a griffe.</def> <mark>[Louisiana]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of thrown raw silk, nearly white naturally,
but capable of being dyed without scouring; also, a thin fabric made
from it, as for scarfs, which resembles the feathers of the marabou in
delicacy, -- whence the name.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Marabout</ent><br/
<hw>Marabout"</hw> <pr>(m<acr/r"<adot/b<oomac/t")</pr>, <pos>n.</pos>
<ety>[F., from Pg. <ets>marabuto</ets>, Ar. <ets>mor<amac/bit</ets>. Cf.
<er>Maravedi</er>.]</ety> <sn>1.</sn> <def>A Muslim saint; especially,
one who claims to work cures supernaturally.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The
<er>marabou</er>{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maracan</ent><br/
<hw>Mar"a*can</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Braz.
<ets>maracan<aacute/</ets>.]</ety> <fld>(Zool.)</fld> <def>A
macaw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marai</ent><br/
\'d8<hw>Ma*rai"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sacred inclosure
or temple; -- so called by the islanders of the Pacific Ocean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maranatha</ent><br/
<hw>Mar`a*nath"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Aramaic
<ets>m<amac/ran ath<amac/</ets>.]</ety> <def><ldquo/Our Lord
cometh;<rdquo/ -- an expression used by St. Paul at the conclusion of
his first Epistle to the Corinthians (xvi. 22). This word has been used
in anathematizing persons for great crimes; as much as to say,
<ldquo/May the Lord come quickly to take vengeance of thy crimes.<rdquo/
See <cref>Anathema maranatha</cref>, under <er>Anathema</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marang tree</ent><br/
<hw>marang tree</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A Philippine
tree (<spn>Artocarpus odoratissima</spn>) similar to the breadfruit tree
bearing edible fruit. Called also <altname>marang</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maranta</ent><br/
<hw>Ma*ran"ta</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.]</ety>
<fld>(Bot.)</fld> <def>A genus of endogenous plants found in tropical
America, and some species also in India. They have tuberous roots
containing a large amount of starch, and from one species (<spn>Maranta
arundinacea</spn>, the <member>American arrowroot</member> or
<member>obedience plant</member>) <prod>arrowroot</prod>
(<prod>arrowroot starch</prod>) is obtained. Many kinds are cultivated
for ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marantaceae</ent><br/
<hw>Marantaceae</hw> <pos>prop. n.</pos> <def>A natural family of
tropical perennial herbs with usually starchy rhizomes, including the
arrowroot; the arrowroot family.</def><br/
<syn><b>Syn. --</b> family <fam>Marantaceae</fam>, arrowroot
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>marasca</ent><br/
<hw>marasca</hw> <pos>n.</pos> <def>The small bitter fruit of the
<prodby>marasca cherry</prodby> tree from whose juice maraschino liqueur
is made.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The <er>marasca cherry</er>.</def><br/
<syn><b>Syn. --</b> marasca cherry, maraschino cherry, Prunus cerasus
marasca.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>marasca cherry</ent><br/
<hw>marasca cherry</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A Dalmation
bitter wild cherry tree (<spn>Prunus cerasus</spn> <varn>marasca</varn>)
bearing fruit whose juice is made into maraschino liqueur.</def><br/
<syn><b>Syn. --</b> marasca, maraschino cherry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maraschino</ent><br/
\'d8<hw>Ma`ra*schi"no</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It., fr.
<ets>marasca</ets>, <ets>amarasca</ets>, a sour cherry, L.
<ets>amarus</ets> bitter.]</ety> <def>A liqueur distilled from fermented
cherry juice, and flavored with the pit of a variety of cherry which
grows in Dalmatia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maraschino cherry</ent><br/
<hw>ma`ra*schi"no cher"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A cherry which is colored a deep red and sweetened by cooking in
colored syrup, and flavored with maraschino. It is used as a garnish in
deserts and cocktails.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The <er>marasca cherry</er> tree.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marasmius</ent><br/
<hw>Marasmius</hw> <pos>prop. n.</pos> <def>A genus of chiefly small
white-spored mushrooms, including the <styp><spn>Marasmius
oreades</spn></styp>, the mushroom that grow in a <er>fairy
ring</er>.</def><br/
<syn><b>Syn. --</b> genus <gen>Marasmius</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>marasmus</ent><br/
<hw>ma*ras"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/ ,
fr. <?/, to quench, as fire; pass., to die away.]</ety>
<fld>(Med.)</fld> <def>A wasting of flesh without fever or apparent
disease; a kind of consumption; atrophy; phthisis.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pining atrophy,<br/
<qex>Marasmus</qex>, and wide-wasting pestilence.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marasmus senilis</b></col> <ety>[L.]</ety>,
<cd>progressive atrophy of the aged.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mahratta</ent><br/
<ent>Marathi</ent><br/
<mhw>{ <hw>Ma*ra"thi</hw> <pr>(?)</pr>, <hw>Mah*rat"ta</hw> <pr>(?)</pr>
}</mhw>, <pos>prop. n.</pos> <def>A Sanskritic language of western
India, prob. descended from the Maharastri Prakrit, spoken by the
Marathas and neighboring peoples. It has an abundant literature dating
from the 13th century. It has a book alphabet nearly the same as
Devanagari and a cursive script translation between the Devanagari and
the Gujarati.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>marathon</ent><br/
<hw>marathon</hw> <pos>n.</pos> <sn>1.</sn> <def>A footrace of 26 miles
385 yards.</def> <wns>[wns=2]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any long and arduous
undertaking, straining the endurance of the participants.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> endurance contest.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <mark>(Capitalized)</mark><def>a battle in 490 BC in
which the Athenians and their allies defeated the Persians.</def>
<wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> battle of Marathon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marattia</ent><br/
<hw>Marattia</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Marattiaceae</fam>, consisting of ferns having the sporangia fused
together in two rows.</def><br/
<syn><b>Syn. --</b> genus <gen>Marattia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marattiaceae</ent><br/
<hw>Marattiaceae</hw> <pos>prop. n.</pos> <def>The natural family of
ferns coextensive with the order <ord>Marattiales</ord>, consisting of
chiefly tropical eusporantiate ferns with gigantic fronds.</def><br/
<syn><b>Syn. --</b> family <fam>Marattiaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marattiales</ent><br/
<hw>Marattiales</hw> <pos>prop. n.</pos> <def>An order of lower ferns
coextensive with the family <fam>Marattiaceae</fam>.</def><br/
<syn><b>Syn. --</b> order <ord>Marattiales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>maraud</ent><br/
<hw>ma*raud"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Marauded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Marauding</conjf>.]</vmorph> <ety>[F. <ets>marauder</ets>, fr.
<ets>maraud</ets> vagabond, OF. <ets>marault</ets>; of uncertain origin,
perh. for <ets>malault</ets>, fr. (assumed) LL. <ets>malaldus</ets>; fr.
L. <ets>malus</ets> bad, ill + a suffix of German origin (cf.
<er>Herald</er>). Cf. <er>Malice</er>.]</ety> <def>To rove in quest of
plunder; to make an excursion for booty; to plunder.</def>
<ldquo/<xex>Marauding</xex> hosts.<rdquo/ <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maraud</ent><br/
<hw>Ma*raud"</hw>, <pos>n.</pos> <def>An excursion for
plundering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marauder</ent><br/
<hw>Ma*raud`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Maraud</er>, <pos>v.</pos>: cf. F. <ets>maraudeur</ets>.]</ety>
<def>A rover in quest of booty or plunder; a plunderer; one who
pillages.</def> <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maravedi</ent><br/
<hw>Mar`a*ve"di</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>maraved<iacute/</ets>; -- so called from the
<ets>Mor<amac/bit<imac/n</ets> (lit., the steadfast), an Arabian dynasty
which reigned in Africa and Spain. Cf. <er>Marabout</er>.]</ety>
<fld>(Numis.)</fld> <def>A small copper coin of Spain, equal to three
mils American money, less than a farthing sterling. Also, an ancient
Spanish gold coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maravilla</ent><br/
<hw>maravilla</hw> <pos>n.</pos> <sn>1.</sn> <def>A wildflower
(<spn>Mirabilis multiflora</spn>) having vibrant deep pink tubular
evening-blooming flowers; found in sandy and desert areas from Southern
California to Southern Colorado and into Mexico.</def><br/
<syn><b>Syn. --</b> desert four o'clock, Colorado four o'clock,
<spn>Mirabilis multiflora</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A leafy wildflower (<spn>Mirabilis longiflora</spn>)
having fragrant slender white or pale pink trumpet-shaped flowers; found
in the Southwestern US and Northern Mexico.</def><br/
<syn><b>Syn. --</b> sweet four o'clock, <spn>Mirabilis
longiflora</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marble</ent><br/
<hw>Mar"ble</hw> <pr>(m<aum/r"b'l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>marbel</ets>, <ets>marbre</ets>, F. <ets>marbre</ets>, L.
<ets>marmor</ets>, fr. Gr. <grk>ma`rmaros</grk>, fr.
<grk>marmai`rein</grk> to sparkle, flash. Cf. <er>Marmoreal</er>.]</ety>
<sn>1.</sn> <def>A massive, compact limestone; a variety of calcite,
capable of being polished and used for architectural and ornamental
purposes. The color varies from white to black, being sometimes yellow,
red, and green, and frequently beautifully veined or clouded. The name
is also given to other rocks of like use and appearance, as serpentine
or verd antique marble, and less properly to polished porphyry, granite,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <col><b>Breccia marble</b></col> consists of limestone
fragments cemented together. -- <col><b>Ruin marble</b></col>, when
polished, shows forms resembling ruins, due to disseminated iron oxide.
-- <col><b>Shell marble</b></col> contains fossil shells. --
<col><b>Statuary marble</b></col> is a pure, white, fine-grained kind,
including <xex>Parian</xex> (from Paros) and <xex>Carrara</xex> marble.
If coarsely granular it is called <xex>saccharoidal</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A thing made of, or resembling, marble, as a work of
art, or record, in marble; or, in the plural, a collection of such
works; <as>as, the Arundel or Arundelian <ex>marbles</ex>; the Elgin
<ex>marbles</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A little ball of glass, marble, porcelain, or of
some other hard substance, used as a plaything by children; or, in the
plural, a child's game played with marbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Marble</xex> is also much used in self-explaining
compounds; when used figuratively in compounds it commonly means, hard,
cold, destitute of compassion or feeling; as,
<xex>marble-</xex>breasted, <xex>marble-</xex>faced,
<xex>marble-</xex>hearted.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marble</ent><br/
<hw>Mar"ble</hw>, <pos>a.</pos> <sn>1.</sn> <def>Made of, or resembling,
marble; <as>as, a <ex>marble</ex> mantel; <ex>marble</ex>
paper.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cold; hard; unfeeling; <as>as, a <ex>marble</ex>
breast or heart</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marble</ent><br/
<hw>Mar"ble</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Marbling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>marbrer</ets>. See <er>Marble</er>, <pos>n.</pos>]</ety> <def>To
stain or vein like marble; to variegate in color; <as>as, to
<ex>marble</ex> the edges of a book, or the surface of
paper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marbled</ent><br/
<hw>Mar"bled</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Made of,
or faced with, marble.</def> <mark>[Obs.]</mark> <ldquo/The
<er>marbled</er> mansion.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made to resemble marble; veined or spotted like
marble.</def> <ldquo/<xex>Marbled</xex> paper.<rdquo/
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Varied with irregular markings,
or witch a confused blending of irregular spots and streaks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Having small flecks of fat interspersed with the
muscle; -- of cuts of meat, especially beef; <as>as, a
well-<ex>marbled</ex> steak</as>. Such marbling improves the flavor of
beef for most people.</def><br/
[<source>PJC</source>]</p>

<p><ent>marble cake</ent><br/
<hw>marble cake</hw> <pos>n.</pos> <def>A made of light and dark batter
very lightly blended, so as to produce a variegated appearance
resembling that of marble.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marble-edged</ent><br/
<hw>Mar"ble-edged`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the edge
veined or spotted with different colors like marble, as a
book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marbleize</ent><br/
<hw>Mar"ble*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Marbleized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Marbleizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
stain or grain in imitation of marble; to cover with a surface
resembling marble; <as>as, to <ex>marbleize</ex> slate, wood, or
iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marbleizing</ent><br/
<hw>marbleizing</hw> <pos>n.</pos> <def>A texture like that of
marble.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marbler</ent><br/
<hw>Mar"bler</hw> <pr>(<?/)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
works upon marble or other stone.</def> <mark>[R.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who colors or stains in imitation of
marble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marbles</ent><br/
<hw>marbles</hw> <pos>n.</pos> <def>A children's game played with
marbles{3}, little balls made of a hard substance (as glass).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>marblewood</ent><br/
<hw>marblewood</hw> <pos>n.</pos> <sn>1.</sn> <def>A hard marbled
wood.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A large Asiatic tree (<spn>Diospyros kurzii</spn>)
having hard marbled zebrawood.</def><br/
<syn><b>Syn. --</b> Andaman marble, Andaman marble, <spn>Diospyros
kurzii</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marbling</ent><br/
<hw>Mar"bling</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The art
or practice of variegating in color, in imitation of marble.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An intermixture of fat and lean in meat, giving it a
marbled appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <fld>(Zool.)</fld> <def>Distinct
markings resembling the variegations of marble, as on birds and
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marbly</ent><br/
<hw>Mar"bly</hw>, <pos>a.</pos> <def>Containing, or resembling,
marble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marbrinus</ent><br/
\'d8<hw>Mar*bri"nus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL., fr. OF.
& F. <ets>marble</ets> marble. See <er>Marble</er>.]</ety> <def>A cloth
woven so as to imitate the appearance of marble; -- much used in the
15th and 16th centuries.</def> <rj><au>Beck (Draper's
Dict.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marc</ent><br/
<hw>Marc</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>The
refuse matter which remains after the pressure of fruit, particularly of
grapes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marc</ent><br/
<hw>Marc</hw>, <pos>n.</pos> <ety>[AS. <ets>marc</ets>; akin to G.
<ets>mark</ets>, Icel. <ets>m<oum/rk</ets>, perh. akin to E.
<ets>mark</ets> a sign. <root/106, 273.]</ety> <altsp>[Written also
<asp>mark</asp>.]</altsp> <sn>1.</sn> <def>A weight of various
commodities, esp. of gold and silver, used in different European
countries. In France and Holland it was equal to eight ounces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coin formerly current in England and Scotland,
equal to thirteen shillings and four pence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A German coin and money of account. See
<er>Mark</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcantant</ent><br/
<hw>Mar"can*tant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>mercatante</ets>. See <er>Merchant</er>.]</ety> <def>A
merchant.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcasite</ent><br/
<hw>Mar"ca*site</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>marcassite</ets>; cf. It. <ets>marcassita</ets>, Sp.
<ets>marquesita</ets>, Pg. <ets>marquezita</ets>; all fr. Ar.
<ets>marqash<imac/tha</ets>.]</ety> <fld>(Min.)</fld> <def>A sulphide of
iron resembling pyrite or common iron pyrites in composition, but
differing in form; white iron pyrites.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Golden marcasite</b></col>, <cd>tin.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcasitical</ent><br/
<ent>Marcasitic</ent><br/
<mhw>{ <hw>Mar`ca*sit"ic</hw> <pr>(?)</pr>, <hw>Mar`ca*sit"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Containing, or having the
nature of, marcasite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcassin</ent><br/
<hw>Mar*cas"sin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Her.)</fld> <def>A young wild boar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcato</ent><br/
\'d8<hw>Mar*ca"to</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>In a marked emphatic manner; -- used adverbially
as a direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marceline</ent><br/
<hw>Mar"cel*ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>marcidus</ets> withered, fr. <ets>marcere</ets> to wither,
shrivel.]</ety> <def>A thin silk fabric used for linings, etc., in
ladies' dresses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcel Proust</ent><br/
<hw>Marcel Proust</hw> <pos>n.</pos> <def>A French novelist
(1871-1922).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marcescent</ent><br/
<hw>Mar*ces"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>marcescens</ets>, p. pr. of <ets>marcescere</ets> to wither, decay,
fr. <ets>marcere</ets> to wither, droop: cf. F.
<ets>marcescent</ets>.]</ety> <fld>(Bot.)</fld> <def>Withering without
falling off; fading; decaying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcescible</ent><br/
<hw>Mar*ces"ci*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>marcescible</ets>.]</ety> <def>Liable to wither or decay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>March</ent><br/
<hw>March</hw> <pr>(m<aum/rch)</pr>, <pos>n.</pos> <ety>[L. <ets>Martius
mensis</ets> Mars'month fr. <ets>Martius</ets> belonging to
<ets>Mars</ets>, the god of war: cf. F. <ets>mars</ets>. Cf.
<er>Martial</er>.]</ety> <def>The third month of the year, containing
thirty-one days.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The stormy <qex>March</qex> is come at last,<br/
With wind, and cloud, and changing skies.</q>
<rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>As mad as a March Hare</b></col>, <cd>an old English
Saying derived from the fact that March is the rutting time of hares,
when they are excitable and violent.</cd>
<rj><au>Wright.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>March</ent><br/
<hw>March</hw>, <pos>n.</pos> <ety>[OE. <ets>marche</ets>, F.
<ets>marche</ets>; of German origin; cf. OHG. <ets>marcha</ets>, G.
<ets>mark</ets>, akin to OS. <ets>marka</ets>, AS. <ets>mearc</ets>,
Goth. <ets>marka</ets>, L. <ets>margo</ets> edge, border, margin, and
possibly to E. <ets>mark</ets> a sign. <root/106. Cf. <er>Margin</er>,
<er>Margrave</er>, <er>Marque</er>, <er>Marquis</er>.]</ety> <def>A
territorial border or frontier; a region adjacent to a boundary line; a
confine; -- used chiefly in the plural, and in English history applied
especially to the border land on the frontiers between England and
Scotland, and England and Wales.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Geneva is situated in the <qex>marches</qex> of several dominions
-- France, Savoy, and Switzerland.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lords of waste <qex>marches</qex>, kings of desolate isles.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>March</ent><br/
<hw>March</hw>, <pos>v. i.</pos> <ety>[Cf. OF. <ets>marchir</ets>. See
2d <er>March</er>.]</ety> <def>To border; to be contiguous; to lie side
by side.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That was in a strange land<br/
Which <qex>marcheth</qex> upon Chimerie.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To march with</b></col>, <cd>to have the same boundary
for a greater or less distance; -- said of an estate.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>March</ent><br/
<hw>March</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Marching</conjf>.]</vmorph> <ety>[F. <ets>marcher</ets>, in OF.
also, to tread, prob. fr. L. <ets>marcus</ets> hammer. Cf.
<er>Mortar</er>.]</ety> <sn>1.</sn> <def>To move with regular steps, as
a soldier; to walk in a grave, deliberate, or stately manner; to advance
steadily.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To proceed by walking in a body or in military
order; <as>as, the German army <er>marched</er> into
France</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>March</ent><br/
<hw>March</hw>, <pos>v. t.</pos> <def>To cause to move with regular
steps in the manner of a soldier; to cause to move in military array, or
in a body, as troops; to cause to advance in a steady, regular, or
stately manner; to cause to go by peremptory command, or by
force.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>March</qex> them again in fair array.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>March</ent><br/
<hw>March</hw>, <pos>n.</pos> <ety>[F. <ets>marche</ets>.]</ety>
<sn>1.</sn> <def>The act of marching; a movement of soldiers from one
stopping place to another; military progress; advance of
troops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These troops came to the army harassed with a long and wearisome
<qex>march</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Measured and regular advance or movement,
like that of soldiers moving in order; stately or deliberate walk;
steady onward movement; <as>as, the <ex>march</ex> of
time</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With solemn <qex>march</qex><br/
Goes slow and stately by them.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This happens merely because men will not bide their time, but will
insist on precipitating the <qex>march</qex> of affairs.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The distance passed over in marching; <as>as, an
hour's <ex>march</ex>; a <ex>march</ex> of twenty miles.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A piece of music designed or fitted to accompany and
guide the movement of troops; a piece of music in the march
form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The drums presently striking up a <qex>march</qex>.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To make a march</b></col>, <fld>(Card Playing)</fld>,
<cd>to take all the tricks of a hand, in the game of
euchre.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>marchand de vin</ent><br/
<hw>marchand de vin</hw> <pos>n.</pos> <fld>(Cookery)</fld> <def>A sauce
consisting of brown sauce with mushrooms and red wine or
madeira.</def><br/
<syn><b>Syn. --</b> mushroom wine sauce.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marchantia</ent><br/
<hw>Marchantia</hw> <pos>prop. n.</pos> <def>The type genus of
<fam>Marchantiaceae</fam>; liverworts that reproduce asexually by gemmae
and have stalked antheridiophores.</def><br/
<syn><b>Syn. --</b> genus <gen>Marchantia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marchantiaceae</ent><br/
<hw>Marchantiaceae</hw> <pos>prop. n.</pos> <def>A natural family of
liverworts with prostrate and usually dichotomously branched
thalli.</def><br/
<syn><b>Syn. --</b> family <fam>Marchantiaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marchantiales</ent><br/
<hw>Marchantiales</hw> <pos>prop. n.</pos> <def>An order of liverworts
with gametophyte differentiated internally.</def><br/
<syn><b>Syn. --</b> order <ord>Marchantiales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>march equinox</ent><br/
<hw>march equinox</hw> <pos>n.</pos> <def>The <er>vernal
equinox</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marcher</ent><br/
<hw>March"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
marches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcher</ent><br/
<hw>March"er</hw>, <pos>n.</pos> <ety>[See 2d <er>March</er>.]</ety>
<def>The lord or officer who defended the marches or borders of a
territory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchet</ent><br/
<ent>Marchet</ent><br/
<mhw>{ <hw>Mar"chet</hw> <pr>(?)</pr>, <hw>Mer"chet</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[LL. <ets>marcheta</ets>; of uncertain
origin.]</ety> <def>In old English and in Scots law, a fine paid to the
lord of the soil by a tenant upon the marriage of one the tenant's
daughters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marching</ent><br/
<hw>March"ing</hw> <pr>(?)</pr>, <def><pos>a. & n.</pos>, fr.
<er>March</er>, <pos>v.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marching money</b></col> <fld>(Mil.)</fld>, <cd>the
additional pay of officer or soldier when his regiment is marching.</cd>
-- <col><b>In marching order</b></col> <fld>(Mil.)</fld>, <cd>equipped
for a march.</cd> -- <col><b>Marching regiment</b></col>.
<fld>(Mil.)</fld> <sd>(a)</sd> <cd>A regiment in active service</cd>.
<sd>(b)</sd> <cd>In England, a regiment liable to be ordered into other
quarters, at home or abroad; a regiment of the line.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marchioness</ent><br/
<hw>Mar"chion*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>marchionissa</ets>, fr. <ets>marchio</ets> a marquis. See
<ets>Marquis</ets>.]</ety> <def>The wife or the widow of a marquis; a
woman who has the rank and dignity of a marquis.</def>
<rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>March-mad</ent><br/
<hw>March"-mad`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Extremely rash;
foolhardy. See under <er>March</er>, the month.</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marchman</ent><br/
<hw>March"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person living in
the marches between England and Scotland or Wales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marchpane</ent><br/
<hw>March"pane`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>marzapane</ets>,Sp. <ets>pan</ets>,. <ets>massepain</ets>, prob.
fr. L. <ets>maza</ets> frumenty (Gr. <grk>ma^za</grk>) + L.
<ets>panis</ets> bread; but perh. the first part of the word is from the
name of the inventor.]</ety> <def>A kind of sweet bread or biscuit; a
cake of pounded almonds and sugar. Called also
<altname>marzipan</altname>.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>March-ward</ent><br/
<hw>March"-ward`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A warden of the
marches; a marcher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcian</ent><br/
<hw>Mar"cian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Under the influence
of Mars; courageous; bold.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcid</ent><br/
<hw>Mar"cid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>marcidus</ets>, fr. <ets>marcere</ets> to wither, pine.]</ety>
<sn>1.</sn> <def>Pining; lean; withered.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by emaciation, as a fever.</def>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcidity</ent><br/
<hw>Mar*cid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>marciditas</ets>.]</ety> <def>The state or quality of being
withered or lean.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 895 --></p>

<p><ent>Marcionite</ent><br/
<hw>Mar"cion*ite</hw> <pr>(m<aum/r"sh<ucr/n*<imac/t)</pr>, <pos>n.</pos>
<fld>(Eccl. Hist)</fld> <def>A follower of <persfn>Marcion</persfn>, a
Gnostic of the second century, who adopted the Oriental notion of the
two conflicting principles, and imagined that between them there existed
a third power, neither wholly good nor evil, the Creator of the world
and of man, and the God of the Jewish dispensation.</def> <rj><au>Brande
& C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcobrunner</ent><br/
\'d8<hw>Mar`co*brun"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>Marcobrunner</ets>.]</ety> <def>A celebrated Rhine wine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marconi</ent><br/
<hw>Mar*co"ni</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <ety>[After
<person>Guglielmo <ets>Marconi</ets></person> (b. 1874), Italian
inventor.]</ety> <def>Designating, or pert. to, Marconi's system of
wireless telegraphy; <as>as, <ex>Marconi</ex> aerial, coherer, station,
system, etc.</as> <mark>[archaic]</mark> </def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Marconigram</ent><br/
<hw>Mar*co"ni*gram</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<etsep>Marconi</etsep> + <ets>-gram</ets>.]</ety> <def>same as
<er>radiogram</er>; a wireless message.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Marconigraph</ent><br/
<hw>Mar*co"ni*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Marconi</ets> + <ets>-graph</ets>.]</ety> <def>The apparatus
used in Marconi wireless telegraphy.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>marconi rig</ent><br/
<hw>marconi rig</hw> <pos>n.</pos> <fld>(Naut.)</fld> <def>A rig of
triangular sails for a yacht.</def><br/
<syn><b>Syn. --</b> Bermuda rig, Bermudan rig, Bermudian rig.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marconi's law</ent><br/
<hw>Mar*co"ni's law</hw> <pr>(?)</pr> <pos>prop. n.</pos> <fld>(Wireless
Teleg.)</fld> <def>The law that the maximum good signaling distance
varies directly as the square of the height of the transmitting
antenna.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Marconism</ent><br/
<hw>Mar*co"nism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The theory or
practice of Marconi's wireless telegraph system.</def>
<mark>[archaic]</mark> <br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Marconi system</ent><br/
<hw>Mar*co"ni system</hw> <pr>(?)</pr>. <fld>(Elec.)</fld> <def>A system
or wireless telegraphy developed by <person>G.
<etsep>Marconi</etsep></person>, an Italian physicist, in which Hertzian
waves are used in transmission and a coherer is used as the receiving
instrument.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>marco polo's sheep</ent><br/
<ent>marco polo sheep</ent><br/
<mhw><hw>marco polo sheep</hw>, <hw>marco polo's sheep</hw></mhw>
<pos>n.</pos> <def>An Asiatic wild sheep (<spn>Ovis poli</spn>) with
exceptionally large horns; sometimes considered a variety of the argali:
<spn>Ovis ammon</spn> <varn>poli</varn>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marcor</ent><br/
\'d8<hw>Mar"cor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>marcere</ets> to wither.]</ety> <def>A wasting away of flesh;
decay.</def> <mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marcosian</ent><br/
<hw>Mar*co"sian</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>One of a Gnostic sect of the second century, so called
from <xex>Marcus</xex>, an Egyptian, who was reputed to be a
magician.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mardi gras</ent><br/
\'d8<hw>Mar"di` gras"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.,
literally, fat Tuesday.]</ety> <sn>1.</sn> <def>The last day of
Carnival; the Tuesday before Ash Wednesday (the beginning of Lent and
fasting); Shrove Tuesday; -- in some cities a great day of carnival and
merrymaking; in the United States it is especially associated with
<city>New Orleans</city>.</def><br/
<syn><b>Syn. --</b> pancake day.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The series of festival events celebrated on
<er>Mardi Gras</er>{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mare</ent><br/
<hw>Mare</hw> <pr>(m<acir/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mere</ets>, AS. <ets>mere</ets>, <ets>myre</ets>, fem of AS.
<ets>mearh</ets> horse, akin to D. <ets>merrie</ets> mare, G.
<ets>m<aum/hre</ets>, OHG. <ets>marah</ets> horse, <ets>meriha</ets>
mare, Icel. <ets>marr</ets> horse, OCelt. <ets>marka</ets> (Pausan. 19,
19,4), Ir. <ets>marc</ets>, W. <ets>march</ets>. Cf.
<er>Marshal</er>.]</ety> <def>The female of the horse and other equine
quadrupeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mare</ent><br/
<hw>Mare</hw>, <pos>n.</pos> <ety>[AS. <ets>mara</ets> incubus; akin to
OHG. & Icel. <ets>mara</ets>; cf. Pol. <ets>mora</ets>, Bohem.
<ets>m<uring/ra</ets>.]</ety> <fld>(Med.)</fld> <def>Sighing,
suffocative panting, intercepted utterance, with a sense of pressure
across the chest, occurring during sleep; the incubus; -- obsolete,
except in the compound <xex>nightmare</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will ride thee o' nights like the <qex>mare</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marechal Niel</ent><br/
<hw>Mare"chal Niel"</hw> <pr>(?)</pr>. <ety>[F.]</ety> <def>A kind of
large yellow rose.</def> <altsp>[Written also <asp>Marshal
Niel</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mare clausum</ent><br/
\'d8<hw>Ma"re clau"sum</hw> <pr>(?)</pr>. <ety>[L.]</ety>
<fld>(Internat. Law)</fld> <def>Lit., closed sea; hence, a body of water
within the separate jurisdiction of the nation; -- opposed to
<contr>open sea</contr> (<contr>mare liberum</contr>), the water open to
all nations and over which no single nation has special
control.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mareis</ent><br/
<hw>Mar"eis</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Marsh.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mare liberum</ent><br/
<hw>mare liberum</hw> <pos>n.</pos> <ety>[L., free sea.]</ety> <def>A
navigable body of water to which all nations have equal access; the
opposite of <contr>mare clausum</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marena</ent><br/
<hw>Ma*re"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. <ets>Salmo
maraena</ets>, G. <ets>mar<aum/ne</ets>, <ets>mor<aum/ne</ets>; -- so
called from Lake <etsep>Morin</etsep>, in the March of Brandenburg, in
Prussia.]</ety> <fld>(Zool.)</fld> <def>A European whitefish of the
genus <gen>Coregonus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mare nostrum</ent><br/
<hw>mare nostrum</hw> <pos>n.</pos> <ety>[L. our sea.]</ety> <def>The
term used by the ancient Romans to refer to the <sig>Mediterranean
Sea</sig>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mareschal</ent><br/
<hw>Mare"schal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mareschal</ets>, F. <ets>mar<eacute/chal</ets>. See
<er>Marshal</er>.]</ety> <def>A military officer of high rank; a
marshal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mare's-nest</ent><br/
<hw>mare's"-nest`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A supposed
discovery which turns out to be a hoax; something grossly
absurd.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A confused multitude of things.</def><br/
<syn><b>Syn. --</b> clutter, jumble, muddle, welter, smother.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mare's-tail</ent><br/
<hw>Mare's"-tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
long streaky cloud, spreading out like a horse's tail, and believed to
indicate rain; a cirrus cloud. See <er>Cloud</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mackerel sky and <qex>mare's-tails</qex><br/
Make tall ships carry low sails.</q> <rj><qau>Old Rhyme.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>An aquatic plant of the genus
<gen>Hippuris</gen> (<spn>Hippuris vulgaris</spn>), having narrow leaves
in whorls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarate</ent><br/
<hw>Mar"ga*rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>margarate</ets>.]</ety> <fld>(Physiol. Chem.)</fld> <def>A compound
of the so-called margaric acid with a base.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margaric</ent><br/
<hw>Mar*gar"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>margarique</ets>. See <er>Margarite</er>.]</ety> <def>Pertaining
to, or resembling, pearl; pearly.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Margaric acid</b></col>. <sd>(a)</sd> <fld>(Physiol.
Chem.)</fld> <cd>A fatty body, crystallizing in pearly scales, and
obtained by digesting saponified fats (soaps) with an acid. It was
formerly supposed to be an individual fatty acid, but is now known to be
simply an intimate mixture of stearic and palmitic acids.</cd>
<sd>(b)</sd> <fld>(Chem.)</fld> <cd>A white, crystalline substance,
<chform>C17H34O2</chform> of the <isa>fatty acid</isa> series,
intermediate between palmitic and stearic acids, and obtained from the
wax of certain lichens, from cetyl cyanide, and other sources. Called
also <altname>heptadecanoic acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarin</ent><br/
<hw>Mar"ga*rin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>margarine</ets>. See <er>Margarite</er>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A fatty substance, extracted from animal fats and
certain vegetable oils, formerly supposed to be a definite compound of
glycerin and margaric acid, but now known to be simply a mixture or
combination of tristearin and tripalmitin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarine</ent><br/
<hw>Mar"ga*rine</hw> <pr>(m<aum/r"j<ucr/*r<icr/n;
m<aum/r`j<ucr/*r<emac/n")</pr>, <pos>n.</pos> <ety>[F.; see
<er>margarin</er>.]</ety> <sn>1.</sn> <def>A processed food product used
as an inexpensive substitute for butter, made primarily from refined
vegetable oils, sometimes including animal fats, and churned with skim
milk to form a semisolid emulsion; also called
<altname>oleomargarine</altname>; artificial butter.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><q>The word <qex>margarine</qex> shall mean all substances, whether
compounds or otherwise, prepared in imitation of butter, and whether
mixed with butter or not.</q> <rj><qau>Margarine Act, 1887 (50 & 51
Vict. c. 29).</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Margarin.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Margaritaceous</ent><br/
<hw>Mar`ga*ri*ta"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or resembling, pearl; pearly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarite</ent><br/
<hw>Mar"ga*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>margarita</ets>, Gr. <?/ a pearl; cf. F.
<ets>marguerite</ets>.]</ety> <sn>1.</sn> <def>A pearl.</def>
<mark>[Obs.]</mark> <rj><au>Peacham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>A mineral related to the micas,
but low in silica and yielding brittle folia with pearly
luster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margaritic</ent><br/
<hw>Mar`ga*rit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>margaritique</ets>.]</ety> <fld>(Physiol. Chem.)</fld>
<def>Margaric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margaritiferous</ent><br/
<hw>Mar`ga*ri*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>margaritifer</ets>; <ets>margarita</ets> pearl + <ets>ferre</ets>
to bear: cf. F. <ets>margaritif<egrave/re</ets>.]</ety> <def>Producing
pearls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarodite</ent><br/
<hw>Mar*gar"o*dite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
pearl-like.]</ety> <fld>(Min.)</fld> <def>A hidrous potash mica related
to muscovite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarone</ent><br/
<hw>Mar"ga*rone</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Margar</ets>ic + <ets>-one</ets>.]</ety> <fld>(Chem.)</fld>
<def>The ketone of margaric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margarous</ent><br/
<hw>Mar"ga*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Margaric; -- formerly designating a supposed acid.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margary's fluid</ent><br/
<ent>Margaryize</ent><br/
<hw>Mar"ga*ry*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>-ized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>-izing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[(J. J.
Lloyd) <etsep>Margary</etsep>, inventor of the process +
<ets>-ize</ets>.]</ety> <def>To impregnate (wood) with a preservative
solution of copper sulphate (often called <hw>Mar"ga*ry's flu"id</hw>
<pr>(-r<icr/z)</pr>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Margate fish</ent><br/
<hw>Mar"gate fish"</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>A sparoid
fish (<spn>Diabasis aurolineatus</spn>) of the Gulf of Mexico, esteemed
as a food fish; -- called also <altname>red-mouth
grunt</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>margay cat</ent><br/
<ent>Margay</ent><br/
<mhw><hw>Mar"gay</hw>, <hw>margay cat</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>A small American wild cat
(<spn>Felis wiedi</spn> syn. <spn>Felis tigrina</spn>), ranging from
Mexico to Brazil. It is spotted with black. Called also
<altname>long-tailed cat</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marge</ent><br/
<hw>Marge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>marge</ets>.
See <er>Margin</er>.]</ety> <def>Border; margin; edge; verge.</def>
<mark>[Poetic]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Along the river's stony <qex>marge</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margent</ent><br/
<hw>Mar"gent</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. See
<er>Margin</er>.]</ety> <def>A margin; border; brink; edge.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The beached <qex>margent</qex> of the sea.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margent</ent><br/
<hw>Mar"gent</hw>, <pos>v. t.</pos> <def>To enter or note down upon the
margin of a page; to margin.</def> <mark>[Obs.]</mark> <rj><au>Mir. for
Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margin</ent><br/
<hw>Mar"gin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>margine</ets>, <ets>margent</ets>, L. <ets>margo</ets>,
<ets>ginis</ets>. Cf. <er>March</er> a border, <er>Marge</er>.]</ety>
<sn>1.</sn> <def>A border; edge; brink; verge; <as>as, the
<ex>margin</ex> of a river or lake</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically: The part of a page at the edge left
uncovered in writing or printing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>The difference between the cost
and the selling price of an article.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Something allowed, or reserved, for that which can
not be foreseen or known with certainty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Brokerage)</fld> <def>Collateral security deposited
with a broker to secure him from loss on contracts entered into by him
on behalf of his principal, as in the speculative buying and selling of
stocks, wheat, etc. It is usually less than the full value of the
security purchased, in which case it may be qualified by the portion of
the full value required to be deposited; <as>as, to buy stocks on 50%
<ex>margin</ex></as>.</def> <rj><au>N. Biddle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Margin draft</b></col> <fld>(Masonry)</fld>, <cd>a smooth
cut margin on the face of hammer-dressed ashlar, adjacent to the
joints.</cd> -- <col><b>Margin of a course</b></col> <fld>(Arch.)</fld>,
<cd>that part of a course, as of slates or shingles, which is not
covered by the course immediately above it. See 2d
<er>Gauge</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Border; brink; verge; brim; rim.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margin</ent><br/
<hw>Mar"gin</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Margined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Marginging</conjf>.]</vmorph> <sn>1.</sn> <def>To
furnish with a margin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enter in the margin of a page.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>margin account</ent><br/
<hw>margin account</hw> <pos>n.</pos> <fld>(Finance)</fld> <def>An
account with a securities brokerage in which the broker extends
credit.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marginal</ent><br/
<hw>Mar"gin*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>marginal</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to a
margin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Written or printed in the margin; <as>as, a
<ex>marginal</ex> note or gloss</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>At the lower limit; barely sufficient; <as>as, of
<ex>marginal</ex> utility</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>marginal cost of production</ent><br/
<ent>marginal cost</ent><br/
<mhw><hw>marginal cost</hw>, <hw>marginal cost of production</hw></mhw>
<pos>n.</pos> <fld>(Economics)</fld> <def>The increase in total cost of
production as a result of producing one more unit of output; since
certain overhead costs are fixed, the <ex>marginal cost</ex> is almost
always less than the total per-unit cost of production averaged over all
units produced.</def><br/
<syn><b>Syn. --</b> incremental cost, differential cost.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marginalia</ent><br/
\'d8<hw>Mar`gi*na"li*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <def>Marginal notes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marginality</ent><br/
<hw>marginality</hw> <pos>n.</pos> <def>the property of being marginal
or on the fringes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marginally</ent><br/
<hw>Mar"gin*al*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In the margin
of a book.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a <er>marginal</er>{3} manner; barely
sufficiently; almost not; <as>as, <ex>marginally</ex>
useful</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marginate</ent><br/
<hw>Mar"gin*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>marginatus</ets>, p. p. of <ets>marginare</ets> to margin. See
<er>Margin</er>, <pos>n.</pos>]</ety> <def>Having a margin distinct in
appearance or structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marginate</ent><br/
<hw>Mar"gin*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To furnish with
a distinct margin; to margin.</def> <mark>[R.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marginated</ent><br/
<hw>Mar"gin*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Marginate</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margined</ent><br/
<hw>Mar"gined</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having a
margin.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Bordered with a distinct line of
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>margin call</ent><br/
<hw>margin call</hw> <pos>n.</pos> <fld>(Stock market)</fld> <def>A
demand by a broker that a customer deposit enough to bring his margin up
to the minimum requirement; -- caused by the decline in market prices of
a security or commodity purchased on margin{5}.</def><br/
<syn><b>Syn. --</b> call.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marginella</ent><br/
\'d8<hw>Mar`gi*nel"la</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.,
dim. of L. <ets>margo</ets>, <ets>marginis</ets>, a margin.]</ety>
<fld>(Zool.)</fld> <def>A genus of small, polished, marine univalve
shells, native of all warm seas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marginicidal</ent><br/
<hw>Mar"gin*i*ci`dal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>margo</ets>, <ets>-ginis</ets>, margin + <ets>caedere</ets> to
cut.]</ety> <fld>(Bot.)</fld> <def>Dehiscent by the separation of united
carpels; -- said of fruits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margosa</ent><br/
<hw>Mar*go"sa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.
<ets>amargoso</ets> bitter.]</ety> <fld>(Bot.)</fld> <def>A large tree
of the genus <gen>Melia</gen> (<spn>Melia Azadirachta</spn>) found in
India. Its bark is bitter, and used as a tonic. A valuable oil is
expressed from its seeds, and a tenacious gum exudes from its trunk. The
<spn>Melia Azedarach</spn> is a much more showy tree, and is cultivated
in the Southern United States, where it is known as <stype>Pride of
India</stype>, <stype>Pride of China</stype>, or <stype>bead
tree</stype>. Various parts of the tree are considered
anthelmintic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>margosa</qex> oil . . . is a most valuable balsam for
wounds, having a peculiar smell which prevents the attacks of flies.</q>
<rj><qau>Sir S. Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margraviate</ent><br/
<ent>Margravate</ent><br/
<mhw>{ <hw>Mar"gra*vate</hw> <pr>(?)</pr>, <hw>Mar*gra"vi*ate</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf. F.
<ets>margraviat</ets>.]</ety> <def>The territory or jurisdiction of a
margrave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margrave</ent><br/
<hw>Mar"grave</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>markgraf</ets>, prop., lord chief justice of the march;
<ets>mark</ets> bound, border, march + <ets>graf</ets> earl, count, lord
chief justice; cf. Goth. <ets>gagr<eum/fts</ets> decree: cf. D.
<ets>markgraaf</ets>, F. <ets>margrave</ets>. See <er>March</er> border,
and cf. <er>Landgrave</er>, <er>Graff</er>.]</ety> <sn>1.</sn>
<def>Originally, a lord or keeper of the borders or marches in
Germany.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The English equivalent of the German title of
nobility, <xex>markgraf</xex>; a marquis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Margravine</ent><br/
<hw>Mar"gra*vine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>markgr<aum/fin</ets>: cf. F. <ets>margrafine</ets>.]</ety> <def>The
wife of a margrave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marguerite</ent><br/
<hw>Mar"gue*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., a pearl, a
daisy. See <er>Margarite</er>.]</ety> <fld>(Bot.)</fld> <def>The daisy
(<spn>Bellis perennis</spn>). The name is often applied also to the
ox-eye daisy and to the China aster.</def>
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maria</ent><br/
<hw>maria</hw> <pos>n. pl.</pos> <sn>1.</sn> <fld>(Astron.)</fld>
<def>Plural form of <altname>mare</altname>, a dark region of
considerable extent on the surface of the moon.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A valuable timber tree of
Panama.</def><br/
<syn><b>Syn. --</b> Calophyllum longifolium.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marian</ent><br/
<hw>Ma"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to the
<person>Virgin Mary</person>, or sometimes to <person>Mary, Queen of
England</person>, daughter of <person>Henry VIII</person>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of all the <qex>Marian</qex> martyrs, Mr. Philpot was the
best-born gentleman.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maid Marian</b></col>. <sd>(a)</sd> <cd>See
<er>Maidmarian</er> in the Vocabulary.</cd> <sd>(a)</sd> <cd>A prominent
character in the legend of Robin Hood.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marie</ent><br/
<hw>Mar"ie</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>Marry.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mariet</ent><br/
<hw>Mar"i*et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mariette</ets>, prop. dim. of <ets>Marie</ets> Mary.]</ety>
<fld>(Bot.)</fld> <def>A kind of bellflower, <spn>Companula
Trachelium</spn>, once called <spn>Viola Mariana</spn>; but it is not a
violet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marigenous</ent><br/
<hw>Ma*rig"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mare</ets> the sea + <ets>-genous</ets>.]</ety> <def>Produced in or
by the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marigold</ent><br/
<hw>Mar"i*gold</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mary</ets> +
<ets>gold</ets>.]</ety> <fld>(Bot.)</fld> <def>A name for several plants
with golden yellow blossoms, especially the <spn>Calendula
officinalis</spn> (see <er>Calendula</er>), and the cultivated species
of <gen>Tagetes</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are several yellow-flowered plants of different
genera bearing this name; as, the <stype>African marigold</stype>
<it>or</it> <stype>French marigold</stype> of the genus
<gen>Tagetes</gen>, of which several species and many varieties are
found in gardens. They are mostly strong-smelling herbs from South
America and Mexico: <stype>bur marigold</stype>, of the genus
<gen>Bidens</gen>; <stype>corn marigold</stype>, of the genus
<gen>Chrysanthemum</gen> (<spn>Chrysanthemum segetum</spn>, a pest in
the cornfields of Italy); <stype>fig marigold</stype>, of the genus
<gen>Mesembryanthemum</gen>; <stype>marsh marigold</stype>, of the genus
<gen>Caltha</gen> (<spn>Caltha palustris</spn>), commonly known in
America as the <stype>cowslip</stype>. See <er>Marsh
Marigold</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marigold window</b></col>. <fld>(Arch.)</fld> <cd>See
<cref>Rose window</cref>, under <er>Rose</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>marijuana</ent><br/
<hw>marijuana</hw> <pos>n.</pos> <sn>1.</sn> <def>A strong-smelling
Asian plant (<spn>Cannabis sativa</spn>), also called
<altname>hemp</altname>, from which a number of euphorogenic and
hallucinogenic drugs are prepared. The euphoric effect is predominantly
due to <prod>tetrahydrocannabinol</prod> (<prod>THC</prod>).</def>
<altsp>[Also spelled <asp>marihuana</asp>.]</altsp><br/
<syn><b>Syn. --</b> cannabis, ganja, pot, grass, marihuana,
<spn>Cannabis sativa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The dried leaves or the female flowers of the hemp
plant, which is smoked or chewed to obtain a euphoric effect. The
flowers usually have a higher concentration of the active ingredient,
tetrahydrocannabinol.</def><br/
<syn><b>Syn. --</b> cannabis, ganja, pot, grass, marihuana, dope, weed,
gage, sess, sens, smoke, skunk, Mary Jane.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marikina</ent><br/
<hw>Mar`i*ki"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the native
name: cf. Pg. <ets>mariquinha</ets>.]</ety> <fld>(Zool)</fld> <def>A
small marmoset (<spn>Midas rosalia</spn>); the silky tamarin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marimba</ent><br/
\'d8<hw>Ma*rim"ba</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.]</ety>
<def>A musical instrument of percussion, consisting of bars yielding
musical tones when struck.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marimonda</ent><br/
\'d8<hw>Mar`i*mon"da</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<fld>(Zool.)</fld> <def>A spider monkey (<spn>Ateles belzebuth</spn>) of
Central and South America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marinade</ent><br/
<hw>Mar`i*nade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.: cf. It.
<ets>marinato</ets> marinade, F. <ets>mariner</ets> to preserve food for
use at sea. See <er>Marinate</er>.]</ety> <fld>(Cookery)</fld> <def>A
brine or pickle containing wine or vinegar, with oil, herbs, and spices,
for enriching the flavor of meat and fish, which are steeped in it prior
to cooking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marinara</ent><br/
<hw>marinara</hw> <pos>n.</pos> <def>An Italian sauce containing
tomatoes, garlic, herbs, and spices.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>marinara</ent><br/
<hw>marinara</hw> <pos>a.</pos> <def>Served in marinara sauce; -- used
postpositionally, as veal <ex>marinara</ex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marinate</ent><br/
<hw>Mar"i*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Marine</er>, and cf. <er>Marinade</er>.]</ety> <def>To salt or
pickle, as fish, and then preserve in oil or vinegar; to prepare (food)
by the use of marinade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marine</ent><br/
<hw>Ma*rine"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>marinus</ets>, fr. <ets>mare</ets> the sea: cf. F.
<ets>marin</ets>. See <er>Mere</er> a pool.]</ety> <sn>1.</sn> <def>Of
or pertaining to the sea; having to do with the ocean, or with
navigation or naval affairs; nautical; <as>as, <ex>marine</ex>
productions or bodies; <ex>marine</ex> shells; a <ex>marine</ex>
engine.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Formed by the action of the
currents or waves of the sea; <as>as, <ex>marine</ex>
deposits</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marine acid</b></col> <fld>(Chem.)</fld>,
<cd>hydrochloric acid.</cd> <mark>[Obs.]</mark> -- <col><b>Marine
barometer</b></col>. <cd>See under <er>Barometer</er>.</cd> --
<col><b>Marine corps</b></col>, <cd>a corps formed of the officers,
noncommissioned officers, privates, and musicants of marines.</cd><--
officially part of the navy, but now considered one of the four branches
of the armed forces in the US --> -- <col><b>Marine engine</b></col>
<fld>(Mech.)</fld>, <cd>a steam engine for propelling a vessel.</cd> --
<col><b>Marine glue</b></col>. <cd>See under <er>Glue</er>.</cd> --
<col><b>Marine insurance</b></col>, <cd>insurance against the perils of
the sea, including also risks of fire, piracy, and barratry.</cd> --
<col><b>Marine interest</b></col>, <cd>interest at any rate agreed on
for money lent upon respondentia and bottomry bonds.</cd> --
<col><b>Marine law</b></col>. <cd>See under <er>Law</er>.</cd> --
<col><b>Marine league</b></col>, <cd>three geographical miles.</cd> --
<col><b>Marine metal</b></col>, <cd>an alloy of lead, antimony, and
mercury, made for sheathing ships.</cd> <au>Mc Elrath.</au> --
<col><b>Marine soap</b></col>, <cd>cocoanut oil soap; -- so called
because, being quite soluble in salt water, it is much used on
shipboard.</cd> -- <col><b>Marine store</b></col>, <cd>a store where old
canvas, ropes, etc., are bought and sold; a junk shop.</cd>
<mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marine</ent><br/
<hw>Ma*rine"</hw>, <pos>n.</pos> <ety>[F. <ets>marin</ets> a sea
solider, <ets>marine</ets> naval economy, a marine picture, fr. L.
<ets>marinus</ets>. See <er>Marine</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>A solider serving on shipboard; a sea soldier; one of a
body of troops trained to do duty in the navy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>A member of the
United States Marine Corps, or a similar foreign military
force.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The sum of naval affairs; naval economy; the
department of navigation and sea forces; the collective shipping of a
country; <as>as, the mercantile <ex>marine</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A picture representing some marine
subject.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Tell that to the marines</b></col>, <cd>an expression of
<sig>disbelief</sig>, the <xex>marines</xex> being regarded by sailors
as credulous.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marined</ent><br/
<hw>Ma*rined"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>marin<eacute/</ets>.]</ety> <fld>(Her.)</fld> <def>Having the lower
part of the body like a fish.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>marine mine</ent><br/
<hw>ma*rine" mine`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.)</fld>
<def>A military explosive device designed to be placed on or under the
surface of a body of water, and to explode when ships pass nearby or
come in contact with it. Its function is to destroy enemy ships or deny
hostile naval forces access to certain areas of the sea, usually near
the shoreline. Also called <altname>underwater mine</altname> and
<altname>floating mine</altname>, and previously referred to as a
<altname>torpedo</altname> (See <er>torpedo</er>{2}
<sd>(a)</sd>).</def><br/
[<source>PJC</source>]</p>

<p><ent>Mariner</ent><br/
<hw>Mar"i*ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>marinier</ets>, LL. <ets>marinarius</ets>. See
<er>Marine</er>.]</ety> <def>One whose occupation is to assist in
navigating ships; a seaman or sailor.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mariner's compass</b></col>. <cd>See under
<er>Compass</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marinership</ent><br/
<hw>Mar"i*ner*ship</hw>, <pos>n.</pos> <def>Seamanship.</def>
<mark>[Obs.]</mark> <rj><au>Udalt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marinism</ent><br/
<hw>Ma*ri"nism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bombastic
literary style marked by the use of metaphors and antitheses
characteristic of the Italian poet <person>Giambattista Marini</person>
(1569-1625).</def> -- <wordforms><wf>Ma*ri"nist</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Marinorama</ent><br/
<hw>Mar`i*no*ra"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from L.
<ets>marinus</ets> marine + Gr. <?/ view.]</ety> <def>A representation
of a sea view.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mariolater</ent><br/
<hw>Ma`ri*ol"a*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mariolatry</er>.]</ety> <def>One who worships the Virgin
Mary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mariolatry</ent><br/
<hw>Ma`ri*ol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ Mary +
<?/ worship.]</ety> <def>The worship of the Virgin Mary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marionette</ent><br/
<hw>Mar`i*o*nette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>marionette</ets>, prop. a dim. of <ets>Marie</ets> Mary.]</ety>
<sn>1.</sn> <def>A puppet moved by strings, as in a puppet
show.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The buffel duck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mariotte's law</ent><br/
<hw>Ma`ri*otte's law`</hw> <pr>(?)</pr>. <fld>(Physics.)</fld> <def>See
<cref>Boyle's law</cref>, under <er>Law</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mariposa lily</ent><br/
<hw>Ma`ri*po"sa lil`y</hw> <pr>(?)</pr>. <ety>[Sp. <ets>mariposa</ets> a
butterfly + E. <ets>lily</ets>. So called from the gay appearance of the
blossoms.]</ety> <fld>(Bot.)</fld> <def>One of a genus
(<gen>Calochortus</gen>) of tuliplike bulbous herbs with large, and
often gaycolored, blossoms. Called also <altname>butterfly
lily</altname>. Most of them are natives of California.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mariput</ent><br/
<hw>Mar"i*put</hw> <pr>(m<acr/r"<icr/*p<ucr/t)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A species of civet; the zoril.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marish</ent><br/
<hw>Mar"ish</hw> <pr>(m<acr/r"<icr/sh)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>marais</ets>, LL. <ets>marascus</ets>. See <er>Marsh</er>.]</ety>
<def>Low, wet ground; a marsh; a fen; a bog; a moor.</def>
<mark>[Archaic]</mark> <rj><au>Milton.</au> <au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marish</ent><br/
<hw>Mar"ish</hw>, <pos>a.</pos> <sn>1.</sn> <def>Moory; fenny;
boggy.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Growing in marshes.</def> <ldquo/<xex>Marish</xex>
flowers.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marital</ent><br/
<hw>Mar"i*tal</hw> <pr>(m<acr/r"<icr/*t<ait/l)</pr>, <pos>a.</pos>
<ety>[F., fr. L. <ets>maritalis</ets>, fr. <ets>maritus</ets> belonging
to marriage, <pos>n.</pos>, a husband. See <er>Marry</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>Of or pertaining to a husband;
<as>as, <ex>marital</ex> rights, duties, authority</as>.</def>
<mark>[archaic]</mark> <ldquo/<xex>Marital</xex> affection.<rdquo/
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to marriage; matrimonial.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maritated</ent><br/
<hw>Mar"i*ta`ted</hw> <pr>(m<acr/r"<icr/*t<amac/`t<ecr/d)</pr>,
<pos>a.</pos> <ety>[L. <ets>maritatus</ets> married.]</ety> <def>Having
a husband; married.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maritimale</ent><br/
<ent>Maritimal</ent><br/
<mhw>{ <hw>Ma*rit"i*mal</hw>, <hw>Ma*rit"i*male</hw> }</mhw>
<pr>(m<adot/*r<icr/t"<icr/*m<ait/l)</pr>, <pos>a.</pos> <def>See
<er>Maritime</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maritime</ent><br/
<hw>Mar"i*time</hw> <pr>(m<acr/r"<icr/*t<imac/m, <it>formerly</it>
m<acr/r"<icr/*t<icr/m; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>maritimus</ets>, fr. <ets>mare</ets> the sea: cf. F.
<ets>maritime</ets>. See <er>Mere</er> a pool.]</ety> <sn>1.</sn>
<def>Bordering on, or situated near, the ocean; connected with the sea
by site, interest, or power; having shipping and commerce or a navy;
<as>as, <ex>maritime</ex> states</as>.</def> <ldquo/A
<xex>maritime</xex> town.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the ocean; marine; pertaining to
navigation and naval affairs, or to shipping and commerce by sea.</def>
<ldquo/<xex>Maritime</xex> service.<rdquo/ <rj><au>Sir H.
Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maritime law</b></col>. <cd>See <er>Law</er>.</cd> --
<col><b>Maritime loan</b></col>, <cd>a loan secured by bottomry or
respodentia bonds.</cd> -- <col><b>Martime nations</b></col>,
<cd>nations having seaports, and using the sea more or less for war or
commerce.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maritimes</ent><br/
<ent>Maritime provinces</ent><br/
<mhw><hw>Maritime provinces</hw>, <hw>Maritimes</hw></mhw> <pos>prop.
n.</pos> <def>The Canadian provinces of New Brunswick and Nova Scotia
and Prince Edward Island.</def><br/
<syn><b>Syn. --</b> Maritime Provinces.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marjoram</ent><br/
<hw>Mar"jo*ram</hw> <pr>(m<aum/r"j<osl/*r<ait/m)</pr>, <pos>n.</pos>
<ety>[OE. <ets>majoran</ets>, F. <ets>marjolaine</ets>, LL.
<ets>marjoraca</ets>, fr. L. <ets>amaracus</ets>, <ets>amaracum</ets>,
Gr. <grk>'ama`rakos</grk>, <grk>'ama`rakon</grk>.]</ety>
<fld>(Bot.)</fld> <def>A genus of mintlike plants (<gen>Origanum</gen>)
comprising about twenty-five species. The sweet marjoram (<spn>Origanum
Majorana</spn>) is peculiarly aromatic and fragrant, and much used in
cookery. The wild marjoram of Europe and America is <spn>Origanum
vulgare</spn>, far less fragrant than the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mark</ent><br/
<hw>Mark</hw> <pr>(m<aum/rk)</pr>, <pos>n.</pos> <def>A license of
reprisals. See <er>Marque</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mark</ent><br/
<hw>Mark</hw>, <pos>n.</pos> <ety>[See 2d <er>Marc</er>.]</ety>
<sn>1.</sn> <def>An old weight and coin. See <er>Marc</er>.</def>
<ldquo/Lend me a <xex>mark</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The unit of monetary account of the German Empire,
equal to 23.8 cents of United States money (1913); the equivalent of one
hundred pfennigs. Also, a silver coin of this value. The unit was
retained by subsequent German states up to the time of the Federal
Republic of Germany. In 1995, the value was approximately 65 cents
American. In 1999 it began to be superseded by the Euro as a unit of
currency in Germany and throughout much of the European union.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mark</ent><br/
<hw>Mark</hw>, <pos>n.</pos> <ety>[OE. <ets>marke</ets>,
<ets>merke</ets>, AS. <ets>mearc</ets>; akin to D. <ets>merk</ets>, MHG.
<ets>marc</ets>, G. <ets>marke</ets>, Icel. <ets>mark</ets>, Dan.
<ets>m<ae/rke</ets>; cf. Lith. <ets>margas</ets> party-colored.
<root/106, 273. Cf. <er>Remark</er>.]</ety> <sn>1.</sn> <def>A visible
sign or impression made or left upon anything; esp., a line, point,
stamp, figure, or the like, drawn or impressed, so as to attract the
attention and convey some information or intimation; a token; a
trace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord set a <qex>mark</qex> upon Cain, lest any finding him
should kill him.</q> <rj><qau>Gen. iv. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 896 --></p>

<p><sn>2.</sn> Specifically: <sd>(a)</sd> <def>A character or device put
on an article of merchandise by the maker to show by whom it was made; a
trade-mark.</def> <sd>(b)</sd> <def>A character (usually a cross) made
as a substitute for a signature by one who can not write.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mark</qex> of the artisan is found upon the most ancient
fabrics that have come to light.</q> <rj><qau>Knight.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fixed object serving for guidance, as of a ship, a
traveler, a surveyor, etc.; <as>as, a sea<ex>mark</ex>, a
land<ex>mark</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A trace, dot, line, imprint, or discoloration,
although not regarded as a token or sign; a scratch, scar, stain, etc.;
<as>as, this pencil makes a fine <ex>mark</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have some <qex>marks</qex> of yours upon my pate.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An evidence of presence, agency, or influence; a
significative token; a symptom; a trace; specifically, a permanent
impression of one's activity or character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The confusion of tongues was a <qex>mark</qex> of separation.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That toward which a missile is directed; a thing
aimed at; what one seeks to hit or reach.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>France was a fairer <qex>mark</qex> to shoot at than Ireland.</q>
<rj><qau>Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whate'er the motive, pleasure is the <qex>mark</qex>.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Attention, regard, or respect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As much in mock as <qex>mark</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Limit or standard of action or fact; <as>as, to be
within the <ex>mark</ex>; to come up to the
<ex>mark</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Badge or sign of honor, rank, or official
station.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the official <qex>marks</qex> invested, you<br/
Anon do meet the Senate.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Preeminence; high position; <as>as, patricians of
<ex>mark</ex>; a fellow of no <ex>mark</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Logic)</fld> <def>A characteristic or essential
attribute; a differential.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>A number or other character used in registering;
<as>as, examination <ex>marks</ex>; a <ex>mark</ex> for
tardiness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>Image; likeness; hence, those formed in one's
image; children; descendants.</def> <mark>[Obs.]</mark> <ldquo/All the
<xex>mark</xex> of Adam.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Naut.)</fld> <def>One of the bits of leather or
colored bunting which are placed upon a sounding line at intervals of
from two to five fathoms. The unmarked fathoms are called
<ldquo/deeps.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A man of mark</b></col>, <cd>a conspicuous or eminent
man.</cd> -- <col><b>To make one's mark</b></col>. <fld>(a)</fld> <cd>To
sign, as a letter or other writing, by making a cross or other
mark.</cd> <sd>(b)</sd> <cd>To make a distinct or lasting impression on
the public mind, or on affairs; to gain distinction.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Impress; impression; stamp; print; trace;
vestige; track; characteristic; evidence; proof; token; badge;
indication; symptom.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mark</ent><br/
<hw>Mark</hw> <pr>(m<aum/rk)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Marked</conjf> <pr>(m<aum/rkt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Marking</conjf>.]</vmorph> <ety>[OE.
<ets>marken</ets>, <ets>merken</ets>, AS. <ets>mearcian</ets>, from
<ets>mearc</ets>. See <er>Mark</er> the sign.]</ety> <sn>1.</sn> <def>To
put a mark upon; to affix a significant mark to; to make recognizable by
a mark; <as>as, to <ex>mark</ex> a box or bale of merchandise; to
<ex>mark</ex> clothing.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be a mark upon; to designate; to indicate; --
used literally and figuratively; <as>as, this monument <ex>marks</ex>
the spot where Wolfe died; his courage and energy <ex>marked</ex> him
for a leader.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To leave a trace, scratch, scar, or other mark,
upon, or any evidence of action; <as>as, a pencil <ex>marks</ex> paper;
his hobnails <ex>marked</ex> the floor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To keep account of; to enumerate and register;
<as>as, to <ex>mark</ex> the points in a game of billiards or
cards</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To notice or observe; to give attention to; to take
note of; to remark; to heed; to regard; <as>as, <ex>mark</ex> my
words</as>.</def> <ldquo/<xex>Mark</xex> the perfect man.<rdquo/
<rj><au>Ps. xxxvii. 37.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To mark out</b></col>. <sd>(a)</sd> <cd>To designate, as
by a mark; to select; as, the ringleaders were <xex>marked out</xex> for
punishment</cd>. <sd>(b)</sd> <cd>To obliterate or cancel with a mark;
as, to <xex>mark out</xex> an item in an account.</cd> -- <col><b>To
mark time</b></col> <fld>(Mil.)</fld>, <cd>to keep the time of a
marching step by moving the legs alternately without
advancing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To note; remark; notice; observe; regard; heed;
show; evince; indicate; point out; betoken; denote; characterize; stamp;
imprint; impress; brand.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mark</ent><br/
<hw>Mark</hw>, <pos>v. i.</pos> <def>To take particular notice; to
observe critically; to note; to remark.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mark</qex>, I pray you, and see how this man seeketh
mischief.</q> <rj><qau>1 Kings xx. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Markable</ent><br/
<hw>Mark"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Remarkable.</def>
<mark>[Obs.]</mark> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marked</ent><br/
<hw>Marked</hw> <pr>(m<aum/rkt)</pr>, <pos>a.</pos> <def>Designated or
distinguished by, or as by, a mark; hence; noticeable; conspicuous;
<as>as, a <ex>marked</ex> card; a <ex>marked</ex> coin; a
<ex>marked</ex> instance.</as></def> -- <wordforms><wf>Mark"ed*ly</wf>
<pr>(#)</pr>, <pos>adv.</pos> <au>J. S. Mill.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A marked man</b></col>, <cd>a man who is noted by a
community, or by a part of it, as, for excellence or depravity; --
usually with an unfavorable suggestion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Markee</ent><br/
<hw>Mar*kee"</hw> <pr>(m<aum/r*k<emac/")</pr>, <pos>n.</pos> <def>See
<er>Marquee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marker</ent><br/
<hw>Mark"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who or that which
marks.</def> Specifically: <sd>(a)</sd> <def>One who keeps account of a
game played, as of billiards.</def> <sd>(b)</sd> <def>A counter used in
card playing and other games.</def> <sd>(c)</sd> <fld>(Mil.)</fld>
<def>The soldier who forms the pilot of a wheeling column, or marks the
direction of an alignment.</def> <sd>(d)</sd> <def>An attachment to a
sewing machine for marking a line on the fabric by creasing
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Market</ent><br/
<hw>Mar"ket</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Akin to D.
<ets>markt</ets>, OHG. <ets>mark<amac/t</ets>, <ets>merk<amac/t</ets>,
G. <ets>markt</ets>; all fr.L. <ets>mercatus</ets> trade, market place,
fr. <ets>mercari</ets>, p. p. <ets>mercatus</ets>, to trade, traffic,
<ets>merx</ets>, <ets>mercis</ets>, ware, merchandise, prob. akin to
<ets>merere</ets> to deserve, gain, acquire: cf. F.
<ets>march<eacute/</ets>. See <er>Merit</er>, and cf. <er>Merchant</er>,
<er>Mart</er>.]</ety> <sn>1.</sn> <def>A meeting together of people, at
a stated time and place, for the purpose of buying and selling (as
cattle, provisions, wares, etc.) by private purchase and sale, and not
by auction; <as>as, a <ex>market</ex> is held in the town every week; a
farmers' <ex>market</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is wit's peddler; and retails his wares<br/
At wakes, and wassails, meetings, <qex>markets</qex>, fairs.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Three women and a goose make a <qex>market</qex>.</q> <rj><qau>Old
Saying.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A public place (as an open space in a town) or a
large building, where a market is held; a market place or market house;
esp., a place where provisions are sold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is at Jerusalem by the sheep <qex>market</qex> a pool.</q>
<rj><qau>John v. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An opportunity for selling or buying anything;
demand, as shown by price offered or obtainable; <as>as, to find a
<ex>market</ex> for one's wares; there is no <ex>market</ex> for woolen
cloths in that region; India is a <ex>market</ex> for English goods;
there are none for sale on the <ex>market</ex>; the best price on the
<ex>market</ex>.</as></def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>There is a third thing to be considered: how a <qex>market</qex>
can be created for produce, or how production can be limited to the
capacities of the <qex>market</qex>.</q> <rj><qau>J. S.
Mill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Exchange, or purchase and sale; traffic; <as>as, a
dull <ex>market</ex>; a slow <ex>market</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The price for which a thing is sold in a market;
market price. Hence: Value; worth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What is a man<br/
If his chief good and <qex>market</qex> of his time<br/
Be but to sleep and feed?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Eng. Law)</fld> <def>The privilege granted to a
town of having a public market.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A specified group of potential buyers, or a region
in which goods may be sold; a town, region, or country, where the demand
exists; <as>as, the under-30 <ex>market</ex>; the New Jersey
<ex>market</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ <xex>Market</xex> is often used adjectively, or in
forming compounds of obvious meaning; as, <xex>market</xex> basket,
<xex>market</xex> day, <xex>market</xex> folk, <xex>market</xex> house,
<xex>market</xex>man, <xex>market</xex> place, <xex>market</xex> price,
<xex>market</xex> rate, <xex>market</xex> wagon, <xex>market</xex>
woman, and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Market beater</b></col>, <cd>a swaggering bully; a noisy
braggart.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au> -- <col><b>Market
bell</b></col>, <cd>a bell rung to give notice that buying and selling
in a market may begin.</cd> <mark>[Eng.]</mark> <au>Shak.</au> --
<col><b>Market cross</b></col>, <cd>a cross set up where a market is
held.</cd> <au>Shak.</au> -- <col><b>Market garden</b></col>, <cd>a
garden in which vegetables are raised for market.</cd> -- <col><b>Market
gardening</b></col>, <cd>the raising of vegetables for market.</cd> --
<col><b>Market place</b></col>, <cd>an open square or place in a town
where markets or public sales are held.</cd> -- <col><b>Market
town</b></col>, <cd>a town that has the privilege of a stated public
market.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Market</ent><br/
<hw>Mar"ket</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Marketed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Marketing</conjf>.]</vmorph> <def>To deal in a market; to buy or
sell; to make bargains for provisions or goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Market</ent><br/
<hw>Mar"ket</hw>, <pos>v. t.</pos> <def>To expose for sale in a market;
to traffic in; to sell in a market, and in an extended sense, to sell in
any manner; <as>as, most of the farmers have <ex>marketed</ex> their
crops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Industrious merchants meet, and <qex>market</qex> there<br/
The world's collected wealth.</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marketable</ent><br/
<hw>Mar"ket*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Fit
to be offered for sale in a market; such as may be justly and lawfully
sold; <as>as, decayed provisions are not
<ex>marketable</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Current in market; <as>as, <ex>marketable</ex>
value</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wanted by purchasers; salable; <as>as, furs are not
<ex>marketable</ex> in that country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marketableness</ent><br/
<hw>Mar"ket*a*ble*ness</hw>, <pos>n.</pos> <def>Quality of being
marketable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marketer</ent><br/
<hw>Mar"ket*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who attends a
market to buy or sell; one who carries goods to market.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marketplace</ent><br/
<hw>marketplace</hw> <pos>n.</pos> <sn>1.</sn> <def>an area in a town
where a public market is set up; a <cref>market place</cref>; a
<er>market</er>{2}.</def><br/
<syn><b>Syn. --</b> mart.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The commercial activity whereby good and services
are exchanged; <as>as, without competition there would be no
<ex>market</ex></as>.</def><br/
<syn><b>Syn. --</b> market.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>The mechanism by which one finds a person to whom to
sell or from whom to buy goods; the opportunity to buy and sell; a
<er>market</er>{3}; <as>as, to put one's goods on the
<ex>market</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marketing</ent><br/
<hw>Mar"ket*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of selling
or of purchasing in, or as in, a market.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Articles in, or from, a market; supplies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The activities required by a producer to sell his
products, including advertising, storing, taking orders, and
distribution to vendors or individuals.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marketstead</ent><br/
<hw>Mar"ket*stead</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Market</ets> + <ets>stead</ets> a place.]</ety> <def>A market
place.</def> <mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>markhor</ent><br/
<ent>Markhoor</ent><br/
<mhw>\'d8<hw>Mark"hoor`</hw>, <hw>mark"hor`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Per. <ets>m<amac/r-kh<omac/r</ets> snake
eater.]</ety> <fld>(Zool.)</fld> <def>A large wild goat (<spn>Capra
falconeri</spn> syn. <spn>Capra megaceros</spn>), having huge flattened
spiral horns. It inhabits the mountains of Northern India and
Cashmere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marking</ent><br/
<hw>Mark"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of one who,
or that which, marks; the mark or marks made; arrangement or disposition
of marks or coloring; <as>as, the <ex>marking</ex> of a bird's
plumage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marking ink</b></col>, <cd>indelible ink, because used in
marking linen.</cd> -- <col><b>Marking nut</b></col> <fld>(Bot.)</fld>,
<cd>the nut of the <spn>Semecarpus Anacardium</spn>, an East Indian
tree. The shell of the nut yields a blackish resinous juice used for
marking cotton cloth, and an oil prepared from it is used for
rheumatism.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Markis</ent><br/
<hw>Mar"kis</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A marquis.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Markisesse</ent><br/
<hw>Mar"kis*esse</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
marchioness.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Markman</ent><br/
<hw>Mark"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A marksman.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Markov chain</ent><br/
<hw>Mark"ov chain</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[after
<person>A. A. <etsep>Markov</etsep></person>, Russian mathematician, b.
1856, d. 1922.]</ety> <fld>(Statistics)</fld> <def>A random process
(<isa>Markov process</isa>) in which the probabilities of discrete
states in a series depend only on the properties of the immediately
preceding state or the next preceding state, independent of the path by
which the preceding state was reached. It differs from the more general
Markov process in that the states of a <ex>Markov chain</ex> are
discrete rather than continuous. Certain physical processes, such as
diffusion of a molecule in a fluid, are modelled as a <ex>Markov
chain</ex>. See also <styp><er>random walk</er></styp>.</def>
<altsp>[Also spelled <asp>Markoff chain</asp>.]</altsp><br/
[<source>PJC</source>]</p>

<p><ent>Markov process</ent><br/
<hw>Mark"ov pro`cess</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[after
<person>A. A. <etsep>Markov</etsep></person>, Russian mathematician, b.
1856, d. 1922.]</ety> <fld>(Statistics)</fld> <def>a random process in
which the probabilities of states in a series depend only on the
properties of the immediately preceding state or the next preceding
state, independent of the path by which the preceding state was reached.
It is distinguished from a <contr>Markov chain</contr> in that the
states of a <ex>Markov process</ex> may be continuous as well as
discrete.</def> <altsp>[Also spelled <asp>Markoff
process</asp>.]</altsp><br/
[<source>PJC</source>]</p>

<p><ent>Marksman</ent><br/
<hw>Marks"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Marksmen</plw> <pr>(#)</pr>.</plu> <ety>[Earlier
<ets>markman</ets>; <ets>mark</ets> + <ets>man</ets>.]</ety> <sn>1.</sn>
<def>One skillful to hit a mark with a missile; one who shoots well.
especially with a pistol or rifle.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>One who makes his mark, instead of
writing his name, in signing documents.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marksmanship</ent><br/
<hw>Marks"man*ship</hw>, <pos>n.</pos> <def>Skill of a
marksman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>markup</ent><br/
<hw>markup</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Commerce)</fld> <def>The
amount added to the cost to determine the asking price.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(printing)</fld> <def>Instructions for the
typesetter that are written on the copy (e.g. underlining words that are
to be set in italics).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <fld>(Legislation)</fld> <def>Changes in proposed
legislation drafted in conference, as contrasted with changes resulting
from the amendment process.</def><br/
[<source>PJC</source>]</p>

<p><ent>markweed</ent><br/
<hw>markweed</hw> <pos>n.</pos> <def>A climbing plant
(<spn>Toxicodendron radicans</spn>) common in eastern and central U. S.
with ternate leaves and greenish flowers followed by white berries. It
yields an irritating oil that causes a rash on contact; commonly called
<altname>poison ivy</altname>.</def><br/
<syn><b>Syn. --</b> poison ivy, poison mercury, poison oak,
<spn>Toxicodendron radicans</spn>, <spn>Rhus radicans</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marl</ent><br/
<hw>Marl</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Marline</er>.]</ety> <fld>(Naut.)</fld> <def>To cover, as part of a
rope, with marline, marking a peculiar hitch at each turn to prevent
unwinding.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marling spike</b></col>. <fld>(Naut.)</fld> <cd>See under
<er>Marline</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marl</ent><br/
<hw>Marl</hw>, <pos>n.</pos> <ety>[OF. <ets>marle</ets>, F.
<ets>marne</ets>, LL. <ets>margila</ets>, dim. of L. <ets>marga</ets>
marl. Originally a Celtic word, according to Pliny, xvii. 7: <ldquo/Quod
genus terrae Galli et Britanni <ets>margam</ets> vocant.<rdquo/
<root/274.]</ety> <def>A mixed earthy substance, consisting of carbonate
of lime, clay, and sand, in very variable proportions, and accordingly
designated as calcareous, clayey, or sandy. See
<er>Greensand</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marl</ent><br/
<hw>Marl</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Marling</conjf>.]</vmorph> <ety>[Cf. F. <ets>marner</ets>. See
<er>Marl</er>, <pos>n.</pos>]</ety> <def>To overspread or manure with
marl; <as>as, to <ex>marl</ex> a field</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marlaceous</ent><br/
<hw>Mar*la"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling marl;
partaking of the qualities of marl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marlin</ent><br/
<hw>Mar"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
American great marbled godwit (<spn>Limosa fedoa</spn>). Applied also to
the red-breasted godwit (<spn>Limosa haematica</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[from <ets>marlin</ets> spike, the shape of its
bill.]</ety> <def> Any of several marine billfishes of the genera
<gen>Makaira</gen> and <gen>Tetrapturus</gen>, popular as game in sport
fishing.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Hook-billed marlin</b></col>, <cd>a curlew.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marline</ent><br/
<hw>Mar"line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LG.
<ets>marlien</ets>, <ets>marling</ets>, or D. <ets>marling</ets>,
<ets>marlijn</ets>, fr. D. <ets>marren</ets> to tie, prob. akin to E.
<ets>moor</ets>, v., and <ets>lijn</ets> line: cf.F. <ets>merlin</ets>.
See <er>Moor</er>, <pos>v.</pos>, <er>Line</er>.]</ety>
<fld>(Naut.)</fld> <def>A small line composed of two strands a little
twisted, used for winding around ropes and cables, to prevent their
being weakened by fretting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Marline spike</b></col>, <col><b>Marling
spike</b></col></mcol> <fld>(Naut.)</fld>, <cd>an iron tool tapering to
a point, used to separate the strands of a rope in splicing and in
marling. It has an eye in the thick end to which a lanyard is attached.
See <er>Fid</er>.</cd> <altsp>[Written also <asp>marlin
spike</asp>]</altsp> -- <col><b>Marline-spike bird</b></col>. <ety>[The
name alludes to the long middle tail feathers.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>A tropic bird.</cd> <sd>(b)</sd> <cd>A jager, or skua
gull.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marline</ent><br/
<hw>Mar"line</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>merliner</ets>.]</ety> <fld>(Naut.)</fld> <def>To wind marline
around; <as>as, to <ex>marline</ex> a rope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marlite</ent><br/
<hw>Marl"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>marlite</ets>. See <er>Marl</er>, <pos>n.</pos>]</ety>
<fld>(Min.)</fld> <def>A variety of marl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marlitic</ent><br/
<hw>Mar*lit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Partaking of the
qualities of marlite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marlpit</ent><br/
<hw>Marl"pit`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pit where marl is
dug.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marlstone</ent><br/
<hw>Marl"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Geol.)</fld>
<def>A sandy calcareous stratum, containing, or impregnated with, iron,
and lying between the upper and lower Lias of England.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marly</ent><br/
<hw>Marl"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Marlier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Marliest</adjf>.]</amorph> <def>Consisting or partaking of marl;
resembling marl; abounding with marl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmalade</ent><br/
<hw>Mar"ma*lade</hw> <pr>(m<aum/r"m<adot/*l<amac/d)</pr>, <pos>n.</pos>
<ety>[F. <ets>marmelade</ets>, Pg. <ets>marmelada</ets>, fr.
<ets>marm<eacute/lo</ets> a quince, fr. L. <ets>melimelum</ets> honey
apple, Gr. <grk>meli`mhlon</grk> a sweet apple, an apple grafted on a
quince; <grk>me`li</grk> honey + <grk>mh^lon</grk> apple. Cf.
<er>Mellifluous</er>, <er>Melon</er>.]</ety> <def>A preserve or
confection made of the pulp of fruit, as the quince, pear, apple,
orange, etc., boiled with sugar, and brought to a jamlike
consistency.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marmalade tree</b></col> <fld>(Bot.)</fld>, <cd>a
sapotaceous tree (<spn>Lucuma mammosa</spn>) of the West Indies and
Tropical America. It has large obovate leaves and an egg-shaped fruit
from three to five inches long, containing a pleasant-flavored pulp and
a single large seed. The fruit is called <prod>marmalade</prod>, or
<xex>natural marmalade</xex>, from its consistency and flavor.</cd></cs>
[<source>1913 Webster</source>]</p>

<p><ent>Marmalet</ent><br/
<hw>Mar"ma*let`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Marmalade</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmatite</ent><br/
<hw>Mar"ma*tite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>marmatite</ets>.]</ety> <fld>(Min.)</fld> <def>A ferruginous
variety of shalerite or zinc blende, nearly black in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmolite</ent><br/
<hw>Mar"mo*lite</hw> <pr>(m<aum/r"m<osl/*l<imac/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>maramai`rein</grk> to sparkle + <ets>-lite</ets>.]</ety>
<fld>(Min.)</fld> <def>A thin, laminated variety of serpentine, usually
of a pale green color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmoraceous</ent><br/
<hw>Mar`mo*ra"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>marmor</ets> marble. See <er>Marble</er>.]</ety> <def>Pertaining
to, or like, marble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmorated</ent><br/
<ent>Marmorate</ent><br/
<mhw>{ <hw>Mar"mo*rate</hw> <pr>(?)</pr>, <hw>Mar"mo*ra`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>marmoratus</ets>, p.
p. of <ets>marmorate</ets> to overlay with marble, fr. <ets>marmor</ets>
marble.]</ety> <def>Variegated like marble; covered or overlaid with
marble.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmoration</ent><br/
<hw>Mar`mo*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>marmoratio</ets>.]</ety> <def>A covering or incrusting with marble;
a casing of marble; a variegating so as to resemble marble.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmoratum opus</ent><br/
\'d8<hw>Mar`mo*ra`tum o"pus</hw> <pr>(?)</pr>. <ety>[L. See
<er>Marmorate</er>, and <er>Opus</er>.]</ety> <fld>(Arch.)</fld> <def>A
kind of hard finish for plasterwork, made of plaster of Paris and marble
dust, and capable of taking a high polish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmorean</ent><br/
<ent>Marmoreal</ent><br/
<mhw>{ <hw>Mar*mo"re*al</hw> <pr>(m<aum/r*m<omac/"r<esl/*<ait/l)</pr>,
<hw>Mar*mo"re*an</hw> <pr>(m<aum/r*m<omac/"r<esl/*<ait/n)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>marmoreus</ets>, fr. <ets>marmor</ets>
marble: cf. F. <ets>marmor<eacute/en</ets>. See <er>Marble</er>.]</ety>
<def>Pertaining to, or resembling, marble; made of marble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmorosis</ent><br/
\'d8<hw>Mar`mo*ro"sis</hw> <pr>(m<aum/r`m<osl/*r<omac/"s<icr/s)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <fld>(Geol.)</fld> <def>The metamorphism
of limestone, that is, its conversion into marble.</def>
<rj><au>Geikie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmose</ent><br/
<hw>Mar"mose`</hw> <pr>(m<aum/r"m<omac/s`)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <fld>(Zool.)</fld> <def>A species of small opossum
(<spn>Didelphys murina</spn>) ranging from Mexico to Brazil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmoset</ent><br/
<hw>Mar"mo*set`</hw> <pr>(m<aum/r"m<osl/*z<ecr/t`; 277)</pr>,
<pos>n.</pos> <ety>[F. <ets>marmouset</ets> a grotesque figure, an ugly
little boy, prob. fr. LL. <ets>marmoretum</ets>, fr. L.
<ets>marmor</ets> marble. Perhaps confused with <ets>marmot</ets>. See
<er>Marble</er>.]</ety> <fld>(Zool.)</fld> <def>Any one of numerous
species of small South American monkeys of the genera <gen>Hapale</gen>
and <gen>Midas</gen>, family <fam>Hapalidae</fam>. They have long soft
fur, and a hairy, nonprehensile tail. They are often kept as pets.
Called also <altname>squirrel monkey</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marmot</ent><br/
<hw>mar"mot</hw> <pr>(m<aum/r"m<ocr/t; 277)</pr>, <pos>n.</pos>
<ety>[It. <ets>marmotta</ets>, <ets>marmotto</ets>, prob. fr. L.
<ets>mus montanus</ets>, or <ets>mus montis</ets>, lit., mountain mouse
or rat. See <er>Mountain</er>, and <er>Mouse</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Any rodent of the genus <gen>Marmota</gen>
(formerly <gen>Arctomys</gen>) of the subfamily
<subfam>Sciurinae</subfam>. The common European marmot (<spn>Marmota
marmotta</spn>) is about the size of a rabbit, and inhabits the higher
regions of the Alps and Pyrenees. The <stype>bobac</stype> is another
European species. The common American species (<spn>Marmota monax</spn>)
is the <stype>woodchuck</stype> (also called <stype>groundhog</stype>),
but the name <ex>marmot</ex> is usually used only for the western
variety.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Any one of several species of ground squirrels or
gophers of the genus <gen>Spermophilus</gen>; also, the prairie
dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marmot squirrel</b></col> <fld>(Zool.)</fld>, <cd>a
ground squirrel or spermophile.</cd> -- <col><b>Prairie
marmot</b></col>. <cd>See <er>Prairie dog</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmottes oil</ent><br/
<hw>Mar"mottes oil`</hw> <pr>(?)</pr>. <def>A fine oil obtained from the
kernel of <spn>Prunus brigantiaca</spn>. It is used instead of olive or
almond oil.</def> <rj><au>De Colange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marmozet</ent><br/
<hw>Mar"mo*zet`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Marmoset</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maroc</ent><br/
<hw>Maroc</hw> <pos>prop. n.</pos> <def>Morocco, a country in
Northwestern Africa.</def><br/
<syn><b>Syn. --</b> Morocco, Marruecos.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maroc</ent><br/
<hw>Maroc</hw> <pos>prop. a.</pos> <def>Of or pertaining to Morocco;
<as>as, <ex>Maroc</ex> mosques cannot be entered by women without a head
covering</as>.</def><br/
<syn><b>Syn. --</b> Moroccan.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>marocain</ent><br/
<hw>marocain</hw> <pos>n.</pos> <def>A dress crepe; similar to Canton
crepe.</def><br/
<syn><b>Syn. --</b> crepe marocain.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marone</ent><br/
<hw>Ma*rone"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Maroon</er>,
the color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maronite</ent><br/
<hw>Mar"o*nite</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Maronites</plw> <pr>(<?/)</pr>.</plu> <fld>(Eccl. Hist.)</fld>
<def>One of a body of nominal Christians, who speak the Arabic language,
and reside on Mount Lebanon and in different parts of Syria. They take
their name from one <persfn><etsep>Maron</etsep></persfn> of the 6th
century.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maroon</ent><br/
<hw>Ma*roon"</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>marroon</asp>.]</altsp> <ety>[F. <ets>marron</ets>, abbrev. fr. Sp.
<ets>cimarron</ets> wild, unruly, from <ets>cima</ets> the summit of a
mountain; hence, <ets>negro cimarron</ets> a runaway negro that lives in
the mountains.]</ety> <def>In the West Indies and Guiana, a fugitive
slave, or a free negro, living in the mountains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maroon</ent><br/
<hw>Ma*roon"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marooned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Marooning</conjf>.]</vmorph> <ety>[See <er>Maroon</er> a fugitive
slave.]</ety> <def>To put (a person) ashore on a desolate island or
coast and leave him to his fate.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marooning party</b></col>, <cd>a social excursion party
that sojourns several days on the shore or in some retired place; a
prolonged picnic.</cd> <mark>[Southern U. S.]</mark>
<rj><au>Bartlett.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 897 --></p>

<p><ent>Maroon</ent><br/
<hw>Ma*roon"</hw> <pr>(m<adot/*r<oomac/n")</pr>, <pos>a.</pos> <ety>[F.
<ets>marron</ets> chestnut-colored, fr. <ets>marron</ets> a large French
chestnut, It. <ets>marrone</ets>; cf. LGr. <grk>ma`raon</grk>. Cf.
<er>Marron</er>.]</ety> <def>Having the color called maroon. See 4th
<er>Maroon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maroon lake</b></col>, <cd>lake prepared from madder, and
distinguished for its transparency and the depth and durability of its
color.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maroon</ent><br/
<hw>Ma*roon"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A brownish or dull red
of any description, esp. of a scarlet cast rather than approaching
crimson or purple.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An explosive shell. See <er>Marron</er>,
3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marplot</ent><br/
<hw>Mar"plot`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, by his
officious interference, mars or frustrates a design or plot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marque</ent><br/
<hw>Marque</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>marque</ets>,
in <ets>lettre de marque</ets> letter of marque, a commission with which
the commandant of every armed vessel was obliged to be provided, under
penalty of being considered a pirate or corsair; <ets>marque</ets> here
prob. meaning, border, boundary (the letter of marque being a permission
to go beyond the border), and of German origin. See <er>March</er>
border.]</ety> <fld>(Law)</fld> <def>A license to pass the limits of a
jurisdiction, or boundary of a country, for the purpose of making
reprisals.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Letters of marque</b></col>, <col><b>Letters of
marque and reprisal</b></col></mcol>, <cd>a license or extraordinary
commission granted by a government to a private person to fit out a
privateer or armed ship to cruise at sea and make prize of the enemy's
ships and merchandise. The ship so commissioned is sometimes called a
<xex>letter of marque</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquee</ent><br/
<hw>Mar*quee"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>marquise</ets>, misunderstood as a plural; prob. orig., tent of the
marchioness. See <er>Marquis</er>.]</ety> <def>A large field tent; esp.,
one adapted to the use of an officer of high rank.</def> <altsp>[Written
also <asp>markee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquess</ent><br/
<hw>Mar"quess</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>marques</ets>. See <er>Marquis</er>.]</ety> <def>A
marquis.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lady marquess</b></col>, <cd>a marchioness.</cd>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>marquetry</ent><br/
<ent>marqueterie</ent><br/
<mhw><hw>mar"que*te*rie</hw>, <hw>mar"quet*ry</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>marqueterie</ets>, from <ets>marqueter</ets>
to checker, inlay, fr. <ets>marque</ets> mark, sign; of German origin.
See <er>Mark</er> a sign.]</ety> <def>Inlaid work; work inlaid with
pieces of wood, shells, ivory, veneer, and the like, of several colors,
fitted together to form a design or picture that is then used to
ornament furniture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquis</ent><br/
<hw>Mar"quis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>marquis</ets>, OF. <ets>markis</ets>, <ets>marchis</ets>, LL.
<ets>marchensis</ets>; of German origin; cf. G. <ets>mark</ets> bound,
border, march, OHG. <ets>marcha</ets>. See <er>March</er> border, and
cf. <er>Marchioness</er>, <er>Marquee</er>, <er>Marquess</er>.]</ety>
<def>A nobleman in England, France, and Germany, of a rank next below
that of duke. Originally, the marquis was an officer whose duty was to
guard the marches or frontiers of the kingdom. The office has ceased,
and the name is now a mere title conferred by patent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquisate</ent><br/
<hw>Mar"quis*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>marquisat</ets>.]</ety> <def>The seigniory, dignity, or lordship of
a marquis; the territory governed by a marquis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquisdom</ent><br/
<hw>Mar"quis*dom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
marquisate.</def> <mark>[Obs.]</mark> <ldquo/Nobles of the
<xex>marquisdom</xex> of Saluce.<rdquo/ <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquise</ent><br/
\'d8<hw>Mar`quise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Marquis</er>, and cf. <er>Marquee</er>.]</ety> <def>The wife of a
marquis; a marchioness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marquisship</ent><br/
<hw>Mar"quis*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
marquisate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marram</ent><br/
<hw>Mar"ram</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
coarse grass found on sandy beaches (<spn>Ammophila arundinacea</spn>).
See <cref>Beach grass</cref>, under <er>Beach</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrer</ent><br/
<hw>Mar"rer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who mars or
injures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marriable</ent><br/
<hw>Mar"ri*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mariable</ets>.]</ety> <def>Marriageable.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marriage</ent><br/
<hw>Mar"riage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mariage</ets>, F. <ets>mariage</ets>. See <er>Marry</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>The act of marrying, or the state of
being married; legal union of a man and a woman for life, as husband and
wife; wedlock; matrimony.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Marriage</qex> is honorable in all.</q> <rj><qau>Heb. xiii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The marriage vow or contract.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A feast made on the occasion of a
marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The kingdom of heaven is like unto a certain king which made a
<qex>marriage</qex> for his son.</q> <rj><qau>Matt. xxii.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any intimate or close union.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>In pinochle, b<eacute/zique, and similar games at
cards, the combination of a king and queen of the same suit. If of the
trump suit, it is called a <stype>royal marriage</stype>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Marriage brokage</b></col>. <sd>(a)</sd> <cd>The business
of bringing about marriages</cd>. <sd>(b)</sd> <cd>The payment made or
demanded for the procurement of a marriage.</cd> -- <col><b>Marriage
favors</b></col>, <cd>knots of white ribbons, or bunches of white
flowers, worn at weddings.</cd> -- <col><b>Marriage settlement</b></col>
<fld>(Law)</fld>, <cd>a settlement of property in view, and in
consideration, of marriage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Matrimony; wedlock; wedding; nuptials.</syn>
<usage> -- <er>Marriage</er>, <er>Matrimony</er>, <er>Wedlock</er>.
<xex>Marriage</xex> is properly the <xex>act</xex> which unites the two
parties, and <xex>matrimony</xex> the <xex>state</xex> into which they
enter. <xex>Marriage</xex> is, however, often used for the state as well
as the act. <xex>Wedlock</xex> is the old Anglo-Saxon term for
<xex>matrimony</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marriageability</ent><br/
<hw>Mar`riage*a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality or state of being marriageable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marriageable</ent><br/
<hw>Mar"riage*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fit for, or
capable of, marriage; of an age at which marriage is allowable.</def> --
<wordforms><wf>Mar"riage*a*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Married</ent><br/
<hw>Mar"ried</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Being in
the state of matrimony; having a spouse; wedded; <as>as, a
<ex>married</ex> man or woman</as>; -- of one person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to marriage; connubial; <as>as, the
<ex>married</ex> state; one's <ex>married</ex> name</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wedded to each other; <as>as, a <ex>married</ex>
couple; John and Joan are no longer <ex>married</ex></as>; -- of two
people.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <mark>[fig.]</mark> <def>Joined
to form one object; united.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marrier</ent><br/
<hw>Mar"ri*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
marries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marron</ent><br/
<hw>Mar*ron"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Maroon</er>,
<pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A large chestnut.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A chestnut color; maroon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Pyrotechny & Mil.)</fld> <def>A paper or pasteboard
box or shell, wound about with strong twine, filled with an explosive,
and ignited with a fuse, -- used to make a noise like a cannon.</def>
<altsp>[Written also <asp>maroon</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marroon</ent><br/
<hw>Mar*roon"</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>Same as 1st
<er>Maroon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrot</ent><br/
<hw>Mar"rot</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The razor-billed auk. See <er>Auk</er>.</def>
<sd>(b)</sd> <def>The common guillemot.</def> <sd>(c)</sd> <def>The
puffin.</def> <mark>[Prov. Eng.]</mark> <altsp>[Written also
<asp>marrott</asp>, and <asp>morrot</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrow</ent><br/
<hw>Mar"row</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>marou</ets>,
<ets>mary</ets>, <ets>maruh</ets>, AS. <ets>mearg</ets>,
<ets>mearh</ets>; akin to OS. <ets>marg</ets>, D. <ets>merg</ets>, G.
<ets>Mark</ets>, OHG. <ets>marg</ets>, <ets>marag</ets>, Icel.
<ets>mergr</ets>, Sw. <ets>merg</ets>, Dan. <ets>marv</ets>, Skr.
<ets>majjan</ets>; cf. Skr. <ets>majj</ets> to sink, L.
<ets>mergere</ets>. <root/274 Cf. <er>Merge</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>The tissue which fills the
cavities of most bones; the medulla. In the larger cavities it is
commonly very fatty, but in the smaller cavities it is much less fatty,
and red or reddish in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The essence; the best part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It takes from our achievements . . .<br/
The pith and <qex>marrow</qex> of our attribute.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[OE. <ets>maru</ets>, <ets>maro</ets>; -- perh. a
different word; cf. Gael. <ets>maraon</ets> together.]</ety> <def>One of
a pair; a match; a companion; an intimate associate.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Chopping and changing I can not commend,<br/
With thief or his <qex>marrow</qex>, for fear of ill end.</q>
<rj><qau>Tusser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marrow squash</b></col> <fld>(Bot.)</fld>, <cd>a name
given to several varieties of squash, esp. to the <altname>Boston
marrow</altname>, an ovoid fruit, pointed at both ends, and with reddish
yellow flesh, and to the <altname>vegetable marrow</altname>, a variety
of an ovoid form, and having a soft texture and fine grain resembling
marrow.</cd> -- <col><b>Spinal marrow</b></col>. <fld>(Anat.)</fld>
<cd>See <cref>Spinal cord</cref>, under <er>Spinal</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrow</ent><br/
<hw>Mar"row</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Marrowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Marrowing</conjf>.]</vmorph> <def>To fill with, or as
with, marrow or fat; to glut.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrowbone</ent><br/
<hw>Mar"row*bone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bone
containing marrow;</def> <pluf>pl.</pluf> <def>ludicrously, knee bones
or knees; <as>as, to get down on one's <ex>marrowbones</ex>, <it>i.
e.</it>, to kneel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrowfat</ent><br/
<hw>Mar"row*fat</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rich but late
variety of pea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrowish</ent><br/
<hw>Mar"row*ish</hw>, <pos>a.</pos> <def>Of the nature of, or like,
marrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrowless</ent><br/
<hw>Mar"row*less</hw>, <pos>a.</pos> <def>Destitute of marrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrowy</ent><br/
<hw>Mar"row*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of marrow;
pithy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marrubium</ent><br/
\'d8<hw>Mar*ru"bi*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Bot.)</fld> <def>A genus of bitter aromatic plants, sometimes used
in medicine; hoarhound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marruecos</ent><br/
<hw>Marruecos</hw> <pos>prop. n.</pos> <def>Morocco, a country in
Northwestern Africa.</def><br/
<syn><b>Syn. --</b> Morocco, Maroc.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marry</ent><br/
<hw>Mar"ry</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Married</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Marrying</conjf>.]</vmorph> <ety>[OE. <ets>marien</ets>, F.
<ets>marier</ets>, L. <ets>maritare</ets>, fr. <ets>maritus</ets>
husband, fr. <ets>mas</ets>, <ets>maris</ets>, a male. See
<er>Male</er>, and cf. <er>Maritral</er>.]</ety> <sn>1.</sn> <def>To
unite in wedlock or matrimony; to perform the ceremony of joining, as a
man and a woman, for life; to constitute (a man and a woman) husband and
wife according to the laws or customs of the place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tell him that he shall <qex>marry</qex> the couple himself.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To join according to law, (a man) to a woman as his
wife, or (a woman) to a man as her husband. See the Note to def.
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A woman who had been <qex>married</qex> to her twenty-fifth
husband, and being now a widow, was prohibited to marry.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To dispose of in wedlock; to give away as
wife.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Maecenas took the liberty to tell him [Augustus] that he must
either <qex>marry</qex> his daughter [Julia] to Agrippa, or take away
his life.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To take for husband or wife. See the Note
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ We say, a man is <xex>married to</xex> or
<xex>marries</xex> a woman; or, a woman is <xex>married to</xex> or
<xex>marries</xex> a man. Both of these uses are equally well
authorized; but <xex>given in marriage</xex> is said only of the
woman.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>They got him [the Duke of Monmouth] . . . to declare in writing,
that the last king [Charles II.] told him he was never
<qex>married</qex> to his mother.</q> <rj><qau>Bp. Lloyd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Figuratively, to unite in the closest and most
endearing relation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Turn, O backsliding children, saith the Lord; for I am
<qex>married</qex> unto you.</q> <rj><qau>Jer. iii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To marry ropes</b></col>. <fld>(Naut.)</fld> <sd>(a)</sd>
<cd>To place two ropes along side of each other so that they may be
grasped and hauled on at the same time</cd>. <sd>(b)</sd> <cd>To join
two ropes end to end so that both will pass through a block.</cd>
<rj><au>Ham. Nav. Encyc.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marry</ent><br/
<hw>Mar"ry</hw>, <pos>v. i.</pos> <def>To enter into the conjugal or
connubial state; to take a husband or a wife.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will, therefore, that the younger women <qex>marry</qex>.</q>
<rj><qau>1 Tim. v. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marrying man</b></col>, <cd>a man disposed to marry.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marry</ent><br/
<hw>Mar"ry</hw>, <pos>interj.</pos> <def>Indeed! in truth! -- a term of
asseveration said to have been derived from the practice of swearing by
the Virgin Mary.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mars</ent><br/
<hw>Mars</hw> <pr>(m<aum/rz)</pr>, <pos>prop. n.</pos> <ety>[L.
<ets>Mars</ets>, gen. <ets>Martis</ets>, archaic <ets>Mavors</ets>, gen.
<ets>Mavortis</ets>.]</ety> <sn>1.</sn> <fld>(Rom. Myth.)</fld> <def>The
god of war and husbandry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>One of the planets of the solar
system, the fourth in order from the sun, or the next beyond the earth,
having a diameter of about 4,200 miles, a period of 687 days, and a mean
distance of 141,000,000 miles. It is conspicuous for the redness of its
light.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Alchemy)</fld> <def>The metallic element iron, the
symbol of which <Male/ was the same as that of the planet Mars.</def>
<mark>[Archaic]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mars brown</b></col>, <cd>a bright, somewhat yellowish,
brown.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsala</ent><br/
<hw>Mar*sa"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It., fr.
<ets>Marsala</ets>, in Sicyly.]</ety> <def>A kind of wine exported from
Marsala in Sicily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsdenia</ent><br/
\'d8<hw>Mars*de"ni*a</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.
From W. <ets>Marsden</ets>, an English author.]</ety> <fld>(Bot.)</fld>
<def>A genus of plants of the Milkweed family, mostly woody climbers
with fragrant flowers, several species of which furnish valuable fiber,
and one species (<spn>Marsdenia tinctoria</spn>) affords
indigo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marseillaise</ent><br/
<ent>Marseillais</ent><br/
<mhw>{ \'d8<hw>Mar`sei`llais"</hw> <pr>(?)</pr>, <pos>a. m.</pos>
\'d8<hw>Mar`sei`llaise"</hw> <pr>(?)</pr>, <pos>a. f.</pos>
}</mhw><ety>[F.]</ety> <def>Of or pertaining to Marseilles, in France,
or to its inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Marseillaise hymn</b></col>, <it>or</it>
<col><b>The Marseillaise</b></col></mcol>, <cd>the national anthem of
France, popularly so called. It was composed in 1792, by Rouget de
l'Isle, an officer then stationed at Strasburg. In Paris it was sung for
the first time by the band of men who came from Marseilles to aid in the
revolution of August 10, 1792; whence the name.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marseillaise</ent><br/
<ent>Marseillais</ent><br/
<mhw>{ \'d8<hw>Mar`sei`llais"</hw>, <pos>n. m.</pos>
\'d8<hw>Mar`sei`llaise"</hw>, <pos>n. f.</pos> }</mhw><ety>[F.]</ety>
<def>A native or inhabitant of Marseilles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marseilles</ent><br/
<hw>Mar*seilles"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A general term
for certain kinds of fabrics, which are formed of two series of threads
interlacing each other, thus forming double cloth, quilted in the loom;
-- so named because first made in <city>Marseilles</city>,
France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsh</ent><br/
<hw>Marsh</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>mersch</ets>,
AS. <ets>mersc</ets>, fr. <ets>mere</ets> lake. See <er>Mere</er> pool,
and cf. <er>Marish</er>, <er>Morass</er>.]</ety> <def>A tract of soft
wet land, commonly covered partially or wholly with water; a fen; a
swamp; a morass.</def> <altsp>[Written also
<asp>marish</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marsh asphodel</b></col> <fld>(Bot.)</fld>, <cd>a plant
(<spn>Nartheeium ossifragum</spn>) with linear equitant leaves, and a
raceme of small white flowers; -- called also <altname>bog
asphodel</altname>.</cd> -- <col><b>Marsh cinquefoil</b></col>
<fld>(Bot.)</fld>, <cd>a plant (<spn>Potentilla palustris</spn>) having
purple flowers, and found growing in marshy places; marsh
five-finger.</cd> -- <col><b>Marsh elder</b></col>. <fld>(Bot.)</fld>
<sd>(a)</sd> <cd>The guelder-rose or cranberry tree (<spn>Viburnum
Opulus</spn>)</cd>. <sd>(b)</sd> <cd>In the United States, a composite
shrub growing in salt marshes (<spn>Iva frutescens</spn>).</cd> --
<col><b>Marsh five-finger</b></col>. <fld>(Bot.)</fld> <cd>See
<cref>Marsh cinquefoil</cref> (above).</cd> -- <col><b>Marsh
gas</b></col>. <fld>(Chem.)</fld> <cd>See under <er>Gas</er>.</cd> --
<col><b>Marsh grass</b></col> <fld>(Bot.)</fld>, <cd>a genus
(<gen>Spartina</gen>) of coarse grasses growing in marshes; -- called
also <altname>cord grass</altname>. The tall <spn>Spartina
cynosuroides</spn> is not good for hay unless cut very young. The low
<spn>Spartina juncea</spn> is a common component of salt hay.</cd> --
<col><b>Marsh harrier</b></col> <fld>(Zool.)</fld>, <cd>a European hawk
or harrier (<spn>Circus aeruginosus</spn>); -- called also
<altname>marsh hawk</altname>, <altname>moor hawk</altname>,
<altname>moor buzzard</altname>, <altname>puttock</altname>.</cd> --
<col><b>Marsh hawk</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A hawk
or harrier (<spn>Circus cyaneus</spn>), native of both America and
Europe. The adults are bluish slate above, with a white rump. Called
also <altname>hen harrier</altname>, and <altname>mouse
hawk</altname>.</cd> <sd>(b)</sd> <cd>The marsh harrier.</cd> --
<col><b>Marsh hen</b></col> <fld>(Zool.)</fld>, <cd>a rail; esp.,
<spn>Rallus elegans</spn> of fresh-water marshes, and <spn>Rallus
longirostris</spn> of salt-water marshes.</cd> -- <col><b>Marsh
mallow</b></col> <fld>(Bot.)</fld>, <cd>a plant of the genus
<gen>Althaea</gen> ( <spn>Althaea officinalis</spn>) common in marshes
near the seashore, and whose root is much used in medicine as a
demulcent.</cd> -- <col><b>Marsh marigold</b></col>. <fld>(Bot.)</fld>
<cd>See in the Vocabulary.</cd> -- <col><b>Marsh pennywort</b></col>
<fld>(Bot.)</fld>, <cd>any plant of the umbelliferous genus
<gen>Hydrocotyle</gen>; low herbs with roundish leaves, growing in wet
places; -- called also <altname>water pennywort</altname>.</cd> --
<col><b>Marsh quail</b></col> <fld>(Zool.)</fld>, <cd>the meadow
lark.</cd> -- <col><b>Marsh rosemary</b></col> <fld>(Bot.)</fld>, <cd>a
plant of the genus <gen>Statice</gen> (<spn>Statice Limonium</spn>),
common in salt marshes. Its root is powerfully astringent, and is
sometimes used in medicine. Called also <altname>sea
lavender</altname>.</cd> -- <col><b>Marsh samphire</b></col>
<fld>(Bot.)</fld>, <cd>a plant (<spn>Salicornia herbacea</spn>) found
along seacoasts. See <er>Glasswort</er>.</cd> -- <col><b>Marsh St.
John's-wort</b></col> <fld>(Bot.)</fld>, <cd>an American herb
(<spn>Elodes Virginica</spn>) with small opposite leaves and
flesh-colored flowers.</cd> -- <col><b>Marsh tea</b></col>.
<fld>(Bot.)</fld>. <cd>Same as <er>Labrador tea</er>.</cd> --
<col><b>Marsh trefoil</b></col>. <fld>(Bot.)</fld> <cd>Same as
<er>Buckbean</er>.</cd> -- <col><b>Marsh wren</b></col>
<fld>(Zool.)</fld>, <cd>any species of small American wrens of the genus
<gen>Cistothorus</gen>, and allied genera. They chiefly inhabit salt
marshes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marshal</ent><br/
<hw>Mar"shal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mareschal</ets>, OF. <ets>mareschal</ets>, F.
<ets>mar<eacute/chal</ets>, LL. <ets>mariscalcus</ets>, from OHG.
<ets>marah-scalc</ets> (G. <ets>marschall</ets>); <ets>marah</ets> horse
+ <ets>scalc</ets> servant (akin to AS. <ets>scealc</ets>, Goth.
<ets>skalks</ets>). F. <ets>mar<eacute/chal</ets> signifies, a marshal,
and a farrier. See <er>Mare</er> horse, and cf.
<er>Seneschal</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Originally, an officer who had the care of horses; a
groom.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An officer of high rank, charged with the
arrangement of ceremonies, the conduct of operations, or the like</def>;
<specif>as, specifically:</specif> <sd>(a)</sd> <def>One who goes before
a prince to declare his coming and provide entertainment; a harbinger; a
pursuivant.</def> <sd>(b)</sd> <def>One who regulates rank and order at
a feast or any other assembly, directs the order of procession, and the
like.</def> <sd>(c)</sd> <def>The chief officer of arms, whose duty it
was, in ancient times, to regulate combats in the lists.</def>
<au>Johnson.</au> <sd>(d)</sd> <fld>(France)</fld> <def>The highest
military officer.</def> In other countries of Europe a marshal is a
military officer of high rank, and called <altname>field
marshal</altname>. <sd>(e)</sd> <fld>(Am. Law)</fld> <def>A ministerial
officer, appointed for each judicial district of the United States, to
execute the process of the courts of the United States, and perform
various duties, similar to those of a sheriff. The name is also
sometimes applied to certain police officers of a city.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Earl marshal of England</b></col>, <cd>the eighth officer
of state; an honorary title, and personal, until made hereditary in the
family of the Duke of Norfolk. During a vacancy in the office of high
constable, the earl marshal has jurisdiction in the court of
chivalry.</cd> <au>Brande & C.</au> -- <col><b>Earl marshal of
Scotland</b></col>, <cd>an officer who had command of the cavalry under
the constable. This office was held by the family of Keith, but
forfeited by rebellion in 1715.</cd> -- <mcol><col><b>Knight
marshal</b></col>, <it>or</it> <col><b>Marshal of the King's
house</b></col></mcol>, <cd>formerly, in England, the marshal of the
king's house, who was authorized to hear and determine all pleas of the
Crown, to punish faults committed within the verge, etc. His court was
called the Court of Marshalsea.</cd> -- <col><b>Marshal of the Queen's
Bench</b></col>, <cd>formerly the title of the officer who had the
custody of the Queen's bench prison in Southwark.</cd> <au>Mozley &
W.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marshal</ent><br/
<hw>Mar"shal</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marshaled</conjf> <pr>(?)</pr> or <conjf>Marshalled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Marshaling</conjf> or
<conjf>Marshalling</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To dispose in order; to arrange in a suitable
manner; <as>as, to <ex>marshal</ex> troops or an army</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>marshaling</qex> the heroes of his name<br/
As, in their order, next to light they came.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To direct, guide, or lead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou <qex>marshalest</qex> me the way that I was going.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Her.)</fld> <def>To dispose in due order, as the
different quarterings on an escutcheon, or the different crests when
several belong to an achievement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marshaler</ent><br/
<hw>Mar"shal*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>marshaller</ets>.]</ety> <def>One who marshals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marshaling</ent><br/
<hw>Mar"shal*ing</hw>, <pos>n.</pos> <ety>[Written also
<ets>marshalling</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of arranging in due order.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>The arrangement of an escutcheon
to exhibit the alliances of the owner.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marshaling of assets</b></col> <fld>(Law)</fld>, <cd>the
arranging or ranking of assets in due order of
administration.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marshalsea</ent><br/
<hw>Mar"shal*sea</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Marshal</ets> + OE. <ets>se</ets> a seat. See <er>See</er> a
seat.]</ety> <def>The court or seat of a marshal; hence, the prison in
Southwark, belonging to the marshal of the king's household.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Court of Marshalsea</b></col>, <cd>a court formerly held
before the steward and marshal of the king's house to administer justice
between the king's domestic servants.</cd>
<rj><au>Blackstone.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marshalship</ent><br/
<hw>Mar"shal*ship</hw>, <pos>n.</pos> <def>The office of a
marshal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsebanker</ent><br/
<ent>Marshbanker</ent><br/
<mhw>{ <hw>Marsh"bank`er</hw> <pr>(?)</pr>, <hw>Marse"bank`er</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>The
menhaden.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 898 --></p>

<p><ent>marshiness</ent><br/
<hw>marsh"i*ness</hw> <pr>(m<aum/rsh"<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The state or condition of being marshy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsh marigold</ent><br/
<hw>marsh mar"i*gold</hw> <pr>(m<aum/rsh m<acr/r"<icr/*g<osl/ld)</pr>.
<fld>(Bot.)</fld> <def>A perennial plant of the genus <gen>Caltha</gen>
(<spn>Caltha palustris</spn>), growing in wet places and bearing bright
yellow flowers. In the United States it is used as a pot herb under the
name of <altname>cowslip</altname>. See <er>Cowslip</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marshy</ent><br/
<hw>marsh"y</hw> <pr>(m<aum/rsh"<ycr/)</pr>, <pos>a.</pos> <ety>[E.
<er>Marsh</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Resembling a marsh; wet; boggy; fenny.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to, or produced in, marshes; <as>as, a
<ex>marshy</ex> weed</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsileaceae</ent><br/
<hw>Marsileaceae</hw> <pos>prop. n.</pos> <def>A natural family of
clover ferns.</def><br/
<syn><b>Syn. --</b> family <fam>Marsileaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marsipobranch</ent><br/
<hw>Mar"si*po*branch`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>One of the
<class>Marsipobranchia</class>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsipobranchia</ent><br/
\'d8<hw>Mar"si*po*bran"chi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ a pouch + <?/ a gill.]</ety> <fld>(Zool.)</fld>
<def>A class of <subphylum>Vertebrata</subphylum>, lower than fishes,
characterized by their purselike gill cavities, cartilaginous skeletons,
absence of limbs, and a suckerlike mouth destitute of jaws. It includes
the lampreys and hagfishes. See <er>Cyclostoma</er>, and
<er>Lamprey</er>. Called also <altname>Marsipobranchiata</altname>, and
<altname>Marsipobranchii</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsupial</ent><br/
<hw>Mar*su"pi*al</hw> <pr>(m<aum/r*s<umac/"p<icr/*<ait/l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>marsupial</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Zool.)</fld> <def>Having a pouch for carrying the
immature young; of or pertaining to the Marsupialia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat. & Zool.)</fld> <def>Of or pertaining to a
marsupium; <as>as, the <ex>marsupial</ex> bones</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marsupial frog</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Nototrema</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsupial</ent><br/
<hw>mar*su"pi*al</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
<subclass>Marsupialia</subclass>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marsupialia</ent><br/
\'d8<hw>Mar*su`pi*a"li*a</hw>
<pr>(m<aum/r*s<umac/`p<icr/*<amac/"l<icr/*<adot/)</pr>, <pos>prop. n.
pl.</pos> <ety>[NL., fr. L. <ets>marsupium</ets> a pouch, bag, purse,
Gr. <grk>marsy`pion</grk>, dim. of <grk>ma`rsypos</grk>,
<grk>ma`rsipos</grk>.]</ety> <fld>(Zool.)</fld> <def>A subclass of
<class>Mammalia</class>, including nearly all the mammals of Australia
and the adjacent islands, together with the opossums of America. They
differ from ordinary mammals in having the corpus callosum very small,
in being implacental, and in having their young born while very
immature. The female generally carries the young for some time after
birth in an external pouch, or marsupium. Called also
<altname>Marsupiata</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsupian</ent><br/
<ent>marsupialian</ent><br/
<mhw>{ <hw>mar*su`pi*a"li*an</hw> <pr>(?)</pr>, <hw>mar*su"pi*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
<subclass>Marsupialia</subclass>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsupiate</ent><br/
<hw>mar*su"pi*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Related to or resembling the marsupials; furnished with a pouch for
the young, as the marsupials, and also some fishes and
Crustacea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsupion</ent><br/
\'d8<hw>mar*su"pi*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>Same as <er>Marsupium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsupite</ent><br/
<hw>mar"su*pite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>marsupial</er>.]</ety> <fld>(Paleon.)</fld> <def>A fossil crinoid of
the genus <gen>Marsupites</gen>, resembling a purse in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marsupium</ent><br/
\'d8<hw>mar*su"pi*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>marsupia</plw> <pr>(#)</pr>.</plu> <ety>[L., a pouch]</ety>,
<fld>(Anat. & Zool.)</fld> <sd>(a)</sd> <def>The pouch, formed by a fold
of the skin of the abdomen, in which marsupials carry their young; also,
a pouch for similar use in other animals, as certain Crustacea.</def>
<sd>(b)</sd> <def>The pecten in the eye of birds and reptiles. See
<er>Pecten</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mart</ent><br/
<hw>Mart</hw> <pr>(m<aum/rt)</pr>, <pos>n.</pos> <ety>[Contr. fr.
<ets>market</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A market.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where has commerce such a <qex>mart</qex> . . . as London?</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bargain.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mart</ent><br/
<hw>Mart</hw>, <pos>v. t.</pos> <def>To buy or sell in, or as in, a
mart.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To sell and <qex>mart</qex> your officer for gold<br/
To undeservers.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mart</ent><br/
<hw>Mart</hw>, <pos>v. t.</pos> <def>To traffic.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mart</ent><br/
<hw>Mart</hw>, <pos>n.</pos> <ety>[See <er>Mars</er>.]</ety> <sn>1.</sn>
<def>The god Mars.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Battle; contest.</def> <mark>[Obs.]</mark>
<rj><au>Fairfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>martagon</ent><br/
<hw>mar"ta*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. & Sp.
<ets>martagon</ets>, It. <ets>martagone</ets>.]</ety> <fld>(Bot.)</fld>
<def>A lily (<spn>Lilium Martagon</spn>) with purplish red flowers,
found in Europe and Asia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>martel</ent><br/
<hw>mar"tel</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[F.
<ets>marteler</ets>, fr. <ets>martel</ets>, <ets>marteau</ets>, hammer,
a dim. fr. L. <ets>martulus</ets>, <ets>marculus</ets>, dim. of
<ets>marcus</ets> hammer. Cf. <er>March</er> to step.]</ety> <def>To
make a blow with, or as with, a hammer.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>martel de fer</ent><br/
\'d8<hw>mar`tel` de fer"</hw> <pr>(?)</pr>. <ety>[OF., hammer of
iron.]</ety> <def>A weapon resembling a hammer, often having one side of
the head pointed; -- used by horsemen in the Middle Ages to break
armor.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>marteline</ent><br/
<hw>mar"te*line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
small hammer used by marble workers and sculptors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martello tower</ent><br/
<hw>Mar*tel"lo tow`er</hw> <pr>(?)</pr>. <ety>[It. <ets>martello</ets>
hammer. The name was orig. given to towers erected on the coasts of
Sicily and Sardinia for protection against the pirates in the time of
Charles the Fifth, which prob. orig. contained an alarm bell to be
struck with a hammer. See <er>Martel</er>.]</ety> <fld>(Fort.)</fld>
<def>A building of masonry, generally circular, usually erected on the
seacoast, with a gun on the summit mounted on a traversing platform, so
as to be fired in any direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The English borrowed the name of the tower from Corsica
in 1794.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marten</ent><br/
<hw>Mar"ten</hw> <pr>(m<aum/r"t<ecr/n)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A bird. See <er>Martin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marten</ent><br/
<hw>mar"ten</hw>, <pos>n.</pos> <ety>[From older <ets>martern</ets>,
<ets>marter</ets>, <ets>martre</ets>, F. <ets>martre</ets>,
<ets>marte</ets>, LL. <ets>martures</ets> (pl.), fr. L.
<ets>martes</ets>; akin to AS. <ets>mear<edh/</ets>, <ets>meard</ets>,
G. <ets>marder</ets>, OHG. <ets>mardar</ets>, Icel.
<ets>m<oum/r<edh/r</ets>. Cf. <er>Foumart</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Any one of several fur-bearing carnivores of the
genus <gen>Martes</gen> (formerly <gen>Mustela</gen>), closely allied to
the sable. Among the more important species are the European
<stype>beech marten</stype> or <stype>stone marten</stype> (<spn>Martes
foina</spn>); the <stype>pine marten</stype> (<spn>Martes martes</spn>);
and the <stype>American marten</stype>, or <stype>sable</stype>
(<spn>Martes Americana</spn>), which some Zoologists consider only a
variety of the Russian sable.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The fur of the marten, used for hats, muffs,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>martern</ent><br/
<hw>mar"tern</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Marten</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mar-text</ent><br/
<hw>mar"-text`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A blundering
preacher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martes</ent><br/
<hw>Martes</hw> <pos>prop. n.</pos> <def>The genus of mammals including
the martens.</def><br/
<syn><b>Syn. --</b> genus Martes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Martial</ent><br/
<hw>Mar"tial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>martialis</ets> of or belonging to <ets>Mars</ets>, the god of war.
Cf. <er>March</er> the month.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of, pertaining to, or suited for, war; military;
<as>as, <ex>martial</ex> music; a <ex>martial</ex>
appearance.</as></def> <ldquo/<xex>Martial</xex> equipage.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Practiced in, or inclined to, war; warlike;
brave.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But peaceful kings, o'er <qex>martial</qex> people set,<br/
Each other's poise and counterbalance are.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Belonging to war, or to an army and navy; -- opposed
to <contr>civil</contr>; <as>as, <ex>martial</ex> law; a
court<ex>-martial</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Pertaining to, or resembling, the god, or the
planet, Mars.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Old Chem. & Old Med.)</fld> <def>Pertaining to, or
containing, iron; chalybeate; <as>as, <ex>martial</ex>
preparations</as>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Martial flowers</b></col> <fld>(Med.)</fld>, <cd>a
reddish crystalline salt of iron; the ammonio-chloride of iron.</cd>
<mark>[Obs.]</mark> -- <col><b>Martial law</b></col>, <cd>the law
administered by the military power of a government when it has
superseded the civil authority in time of war, or when the civil
authorities are unable to enforce the laws. It is distinguished from
<xex>military law</xex>, the latter being the code of rules for the
regulation of the army and navy alone, either in peace or in
war.</cd></cs><-- ???add air force --><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Martial</er>, <er>Warlike</er>.</syn> <usage>
<xex>Martial</xex> refers more to war in <xex>action</xex>, its array,
its attendants, etc.; as, <xex>martial</xex> music, a <xex>martial</xex>
appearance, a <xex>martial</xex> array, courts<xex>-martial</xex>, etc.
<xex>Warlike</xex> describes the feeling or temper which leads to war,
and the adjuncts of war; as, a <xex>warlike</xex> nation,
<xex>warlike</xex> indication, etc. The two words are often used without
discrimination.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martialism</ent><br/
<hw>Mar"tial*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being warlike; exercises suitable for war.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martialist</ent><br/
<hw>Mar"tial*ist</hw>, <pos>n.</pos> <def>A warrior.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martialize</ent><br/
<hw>Mar"tial*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Martialized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Martializing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
render warlike; <as>as, to <ex>martialize</ex> a people</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martially</ent><br/
<hw>Mar"tial*ly</hw>, <pos>adv.</pos> <def>In a martial
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martialness</ent><br/
<hw>Mar"tial*ness</hw>, <pos>n.</pos> <def>The quality of being
martial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martian</ent><br/
<hw>Mar"tian</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <ety>[L.
<ets>Martius</ets>.]</ety> <def>Of or pertaining to Mars, the Roman god
of war, or to the planet bearing his name; martial.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Martian</ent><br/
<hw>Mar"tian</hw>, <pos>prop. n.</pos> <def>An inhabitant of the planet
Mars; -- fictional or hypothetical.</def> <rj><au>Du
Maurier.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ In science fiction, it has often been postulated that
there are intelligent creatures living on Mars, but no strong evidence
of any form of life on Mars has been observed up to the end of
1998.</note></p>

<p><ent>Martin</ent><br/
<hw>Mar"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Stone Working)</fld>
<ety>[Etymol. uncertain.]</ety> <def>A perforated stone-faced runner for
grinding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martin</ent><br/
<hw>Mar"tin</hw>, <pos>n.</pos> <ety>[F. <ets>martin</ets>, from the
proper name <ets>Martin</ets>. Cf. <er>Martlet</er>.]</ety>
<fld>(Zool.)</fld> <def>One of several species of swallows, usually
having the tail less deeply forked than the tail of the common
swallows.</def> <altsp>[Written also <asp>marten</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The American <stype>purple martin</stype>, or <stype>bee
martin</stype> (<spn>Progne subis</spn> or <spn>Progne purpurea</spn>),
and the European <stype>house martin</stype>, or <stype>window
martin</stype> (<spn>Hirundo urbica</spn> or <spn>Chelidon
urbica</spn>), are the best known species.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bank martin</b></col>. <sd>(a)</sd> <cd>The bank
swallow</cd>. See under <er>Bank</er>. <sd>(b)</sd> <cd>The fairy
martin. See under <er>Fairy</er>.</cd> -- <col><b>Bee martin</b></col>.
<sd>(a)</sd> <cd>The purple martin</cd>. <sd>(b)</sd> <cd>The
kingbird.</cd> -- <col><b>Sand martin</b></col>, <cd>the bank
swallow.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martinet</ent><br/
<hw>Mar"ti*net`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from an
officer of that name in the French army under <person>Louis
XIV.</person> Cf. <er>Martin</er> the bird, <er>Martlet</er>.]</ety>
<def>In military language, a strict disciplinarian; in general, one who
lays stress on a rigid adherence to the details of discipline, or to
forms and fixed methods.</def> <mark>[Hence, the word is commonly
employed in a depreciatory sense.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martinet</ent><br/
<hw>Mar"ti*net`</hw>, <pos>n.</pos> <ety>[F.]</ety> <fld>(Zool.)</fld>
<def>The martin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martineta</ent><br/
<hw>Mar`ti*ne"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>martinete</ets>.]</ety> <fld>(Zool.)</fld> <def>A species of
tinamou (<spn>Calopezus elegans</spn>), having a long slender
crest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martinetism</ent><br/
<hw>Mar"ti*net`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles
or practices of a martinet; rigid adherence to discipline,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martingal</ent><br/
<ent>Martingale</ent><br/
<mhw>{ <hw>Mar"tin*gale</hw> <pr>(?)</pr>, <hw>Mar"tin*gal</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[F. <ets>martingale</ets>; cf.
It. <ets>martingala</ets> a sort of hose, martingale, Sp.
<ets>martingala</ets> a greave, cuish, martingale, Sp.
<ets>alm<aacute/rtaga</ets> a kind of bridle.]</ety> <sn>1.</sn> <def>A
strap fastened to a horse's girth, passing between his fore legs, and
fastened to the bit, or now more commonly ending in two rings, through
which the reins pass. It is intended to hold down the head of the horse,
and prevent him from rearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A lower stay of rope or chain for
the jib boom or flying jib boom, fastened to, or reeved through, the
dolphin striker. Also, the dolphin striker itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gambling)</fld> <def>The act of doubling, at each
stake, that which has been lost on the preceding stake; also, the sum so
risked; -- metaphorically derived from the bifurcation of the
<xex>martingale</xex> of a harness. Called also <altname>Martingale
strategy</altname>. Such a betting strategy does not change the overall
likelihood of winning, but in a short run it increases the probability
of winning a small sum, balancing it against an increased probability of
losing a large sum.</def> <mark>[Cant]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Martinmas</ent><br/
<hw>Mar"tin*mas</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[St. <ets>Martin +
mass</ets> religious service.]</ety> <fld>(Eccl.)</fld> <def>The feast
of <person>St. Martin</person>, the eleventh of November; -- often
called <altname>martlemans</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Martinmas summer</b></col>, <cd>a period of calm, warm
weather often experienced about the time of Martinmas; Indian
summer.</cd> <rj><au>Percy Smith.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martite</ent><br/
<hw>Mar"tite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>Mars</ets>,
<ets>Martis</ets>, the god Mars, the alchemical name of iron.]</ety>
<fld>(Min.)</fld> <def>Iron sesquioxide in isometric form, probably a
pseudomorph after magnetite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martlemas</ent><br/
<hw>Mar"tle*mas</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Martinmas</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martlet</ent><br/
<hw>Mart"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>martinet</ets>. See <er>Martin</er> the bird, and cf.
<er>Martinet</er> a disciplinarian.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Zool.)</fld> <def>The European house
martin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. F. <ets>merlette</ets>.]</ety>
<fld>(Her.)</fld> <def>A bird without beak or feet; -- generally assumed
to represent a <sig>martin</sig>. As a mark of cadency it denotes the
fourth son.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyniaceae</ent><br/
<hw>Martyniaceae</hw> <pos>prop. n.</pos> <def>A natural family in most
classifications not considered a separate family but included in the
<fam>Pedaliaceae</fam>.</def><br/
<syn><b>Syn. --</b> family <fam>Martyniaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Martyr</ent><br/
<hw>Mar"tyr</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS., from L.
<ets>martyr</ets>, Gr. <grk>ma`rtyr</grk>, <grk>ma`rtys</grk>, prop., a
witness; cf. Skr. <ets>sm<rsdot/</ets> to remember, E.
<ets>memory</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One who, by his death, bears witness to the truth of
the gospel; one who is put to death for his religion; <as>as,
<persfn>Stephen</persfn> was the first Christian
<ex>martyr</ex></as>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To be a <qex>martyr</qex>, signifies only to witness the truth of
Christ; but the witnessing of the truth was then so generally attended
with persecution, that martyrdom now signifies not only to witness, but
to witness by death.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, one who sacrifices his life, his station, or
what is of great value to him, for the sake of principle, or to sustain
a cause.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then if thou fall'st, O Cromwell,<br/
Thou fall'st a blessed <qex>martyr</qex> !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyr</ent><br/
<hw>Mar"tyr</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Martyred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Martyring</conjf>.]</vmorph> <sn>1.</sn> <def>To put to
death for adhering to some belief, esp. Christianity; to sacrifice on
account of faith or profession.</def> <rj><au>Bp. Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To persecute; to torment; to torture.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The lovely Amoret, whose gentle heart<br/
Thou <qex>martyrest</qex> with sorrow and with smart.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Racked with sciatics, <qex>martyred</qex> with the stone.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrdom</ent><br/
<hw>Mar"tyr*dom</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Martyr</ets>
+ <ets>-dom</ets>.]</ety> <sn>1.</sn> <def>The condition of a martyr;
the death of a martyr; the suffering of death on account of adherence to
the Christian faith, or to any cause.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I came from <qex>martyrdom</qex> unto this peace.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affliction; torment; torture.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrization</ent><br/
<hw>Mar`tyr*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
martyrizing, or state of being martyrized; torture.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrize</ent><br/
<hw>Mar"tyr*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>martyriser</ets>, LL. <ets>martyrizare</ets>.]</ety> <def>To make a
martyr of.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrly</ent><br/
<hw>Mar"tyr*ly</hw>, <pos>adv.</pos> <def>In the manner of a
martyr.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrologe</ent><br/
<hw>Mar"tyr*o*loge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>martyrologium</ets>: cf. F. <ets>martyrologe</ets>.]</ety> <def>A
martyrology.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrological</ent><br/
<ent>Martyrologic</ent><br/
<mhw>{ <hw>Mar`tyr*o*log"ic</hw> <pr>(?)</pr>,
<hw>Mar`tyr*o*log"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Pertaining to martyrology or martyrs; registering, or registered
in, a catalogue of martyrs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrologist</ent><br/
<hw>Mar`tyr*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>martyrologiste</ets>.]</ety> <def>A writer of martyrology; an
historian of martyrs.</def> <rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrology</ent><br/
<hw>Mar`tyr*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-gies</plw> <pr>(#)</pr>.</plu> <ety>[<ets>Martyr</ets> +
<ets>-logy</ets>.]</ety> <def>A history or account of martyrs; a
register of martyrs.</def> <rj><au>Bp. Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Martyrship</ent><br/
<hw>Mar"tyr*ship</hw>, <pos>n.</pos> <def>Martyrdom.</def>
<mark>[R.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marvel</ent><br/
<hw>Mar"vel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mervaile</ets>, F. <ets>merveille</ets>, fr. L.
<ets>mirabilia</ets> wonderful things, pl., fr. <ets>mirabilis</ets>
wonderful, fr. <ets>mirari</ets> to wonder or marvel at. See
<er>Admire</er>, <er>Smile</er>, and cf. <er>Miracle</er>.]</ety>
<sn>1.</sn> <def>That which causes wonder; a prodigy; a
miracle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will do <qex>marvels</qex> such as have not been done.</q>
<rj><qau>Ex. xxxiv. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nature's sweet <qex>marvel</qex> undefiled.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wonder.</def> <mark>[R.]</mark> <ldquo/Use lessens
<xex>marvel</xex>.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>marvel-of-Peru</ent><br/
<ent>marvel of Peru</ent><br/
<mhw><hw>marvel of Peru</hw>, <hw>marvel-of-Peru</hw></mhw>.
<pos>n.</pos> <fld>(Bot.)</fld> <def>A common garden plant
(<spn>Mirabilis jalapa</spn> or <spn>Mirabilis uniflora</spn>) of North
America having fragrant red or purple or yellow or white flowers that
open in late afternoon; called also <altname>four-o'clock</altname>. See
<er>four-o'clock</er>.</def><br/
<syn><b>Syn. --</b> common four-o'clock, marvel of Peru, <spn>Mirabilis
jalapa</spn>, <spn>Mirabilis uniflora</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marvel</ent><br/
<hw>Mar"vel</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Marveled</conjf> <pr>(?)</pr> or <conjf>Marvelled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Marveling</conjf> or
<conjf>Marvelling</conjf>.]</vmorph> <ety>[OE. <ets>merveilen</ets>, OF.
<ets>merveillier</ets>.]</ety> <def>To be struck with surprise,
astonishment, or wonder; to wonder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Marvel</qex> not, my brethren, if the world hate you.</q>
<rj><qau>1 john iii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marvel</ent><br/
<hw>Mar"vel</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To marvel at.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to marvel, or be surprised; -- used
impersonally.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But much now me <qex>marveleth</qex>.</q> <rj><qau>Rich. the
Redeless.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>marvellous</ent><br/
<hw>marvellous</hw> <pos>adj.</pos> <def>Marvelous.</def><br/
<syn><b>Syn. --</b> improbable, marvelous, tall(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Marvelous</ent><br/
<hw>Mar"vel*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>merveillous</ets>, OF. <ets>merveillos</ets>, F.
<ets>Merveilleux</ets>. See <er>Marvel</er>, <pos>n.</pos>]</ety>
<altsp>[Written also <asp>marvellous</asp>.]</altsp> <sn>1.</sn>
<def>Exciting wonder or surprise; astonishing; wonderful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the Lord's doing; it is <qex>marvelous</qex> in our
eyes.</q> <rj><qau>Ps. cxiii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Partaking of the character of miracle, or
supernatural power; incredible; so improbable as to defy
belief.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The <qex>marvelous</qex> fable includes whatever is supernatural,
and especially the machines of the gods.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The marvelous</b></col>, <cd>that which exceeds natural
power, or is preternatural; that which is wonderful; -- opposed to
<ant>the probable</ant>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Wonderful; astonishing; surprising; strange;
improbable; incredible.</syn> <usage> -- <er>Marvelous</er>,
<er>Wonderful</er>. We speak of a thing as <xex>wonderful</xex> when it
awakens our surprise and admiration; as <xex>marvelous</xex> when it is
so much out of the ordinary course of things as to seem nearly or quite
incredible.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marvelously</ent><br/
<hw>Mar"vel*ous*ly</hw>, <pos>adv.</pos> <def>In a marvelous manner;
wonderfully; strangely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marvelousness</ent><br/
<hw>Mar"vel*ous*ness</hw>, <pos>n.</pos> <def>The quality or state of
being marvelous; wonderfulness; strangeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marver</ent><br/
<hw>Mar"ver</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. corrupt. fr.
OE. or F. <ets>marbre</ets> marble.]</ety> <fld>(Glass Marking)</fld>
<def>A stone, or cast-iron plate, or former, on which hot glass is
rolled to give it shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marxism</ent><br/
<hw>Marx"ism</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A system of
economic and political thought, originated by <person>Karl
Marx</person>, and elaborated by others. It holds that the state has
been the a device for suppression of the masses, allowing exploitation
by a dominant (capitalistic) class; that historical change occurs
through class struggle; and that the capitalist system will inevitably
wither away to be superseded by a classless society.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marxism-Leninism</ent><br/
<hw>Marx"ism-Len"in*ism</hw> <pr>(?)</pr>, <pos>prop. n.</pos>
<def>Marxism, as interpreted by <person>V. I. Lenin</person>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marxist</ent><br/
<hw>Marx"ist</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>One who
believes in the theories of <person>Karl Marx</person>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marxist</ent><br/
<hw>Marx"ist</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to <persfn>Marx</persfn> or Marxism.</def><br/
[<source>PJC</source>]</p>

<p><ent>Marxist-Leninist</ent><br/
<hw>Marxist-Leninist</hw> <pos>adj.</pos> <def>of or pertaining to
Marxism-Leninism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mary</ent><br/
<hw>Mar"y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Marrow.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mary</ent><br/
<hw>Ma"ry</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>See
<er>Marry</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mary-bud</ent><br/
<hw>Ma"ry-bud`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The marigold; a blossom of the marigold.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maryolatry</ent><br/
<hw>Ma`ry*ol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Mariolatry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Marysole</ent><br/
<hw>Ma"ry*sole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mary</ets>,
the proper name + <ets>sole</ets> the fish.]</ety> <fld>(Zool.)</fld>
<def>A large British fluke, or flounder (<spn>Rhombus megastoma</spn>);
-- called also <altname>carter</altname>, and
<altname>whiff</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>marzipan</ent><br/
<hw>mar"zi*pan`</hw> <pr>(m<aum/r"z<icr/*p<acr/n`)</pr>, <pos>n.</pos>
<def>A confection made of almonds and sugar mixed into a paste and
molded into shapes. Same as <er>marchpane.</er></def><br/
[<source>PJC</source>]</p>

<p><ent>Masai</ent><br/
<hw>Masai</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A Nilotic
language.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An African tribe inhabiting parts of Kenya and
Tanzania.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mascagnite</ent><br/
<ent>Mascagnin</ent><br/
<mhw>{ <hw>Mas*ca"gnin</hw> <pr>(?)</pr>, <hw>Mas*ca"gnite</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf. F.
<ets>mascagnin</ets>.]</ety> <fld>(Min.)</fld> <def>Native sulphate of
ammonia, found in volcanic districts; -- so named from
<etsep>Mascagni</etsep>, who discovered it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mascara</ent><br/
<hw>mascara</hw> <pos>n.</pos> <def>A cosmetic used to darken and
thicken the eye lashes, usually applied with a small brush.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mascle</ent><br/
<hw>Mas"cle</hw> <pr>(m<acr/s"k'l)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mascle</ets>, F. <ets>macle</ets>, L. <ets>macula</ets> spot, mesh
of a net, LL. <ets>macula</ets>, <ets>macla</ets>, <ets>mascla</ets> a
scale of a coat of mail. See <er>Mail</er> armor.]</ety>
<fld>(Her.)</fld> <def>A lozenge voided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mascled</ent><br/
<hw>Mas"cled</hw> <pr>(-k'ld)</pr>, <pos>a.</pos> <def>Composed of, or
covered with, lozenge-shaped scales; having lozenge-shaped
divisions.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mascled armor</b></col>, <cd>armor composed of small
lozenge-shaped scales of metal fastened on a foundation of leather or
quilted cloth.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mascotte</ent><br/
<ent>Mascot</ent><br/
<mhw>{ <hw>Mas"cot</hw>, <hw>Mas"cotte</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Through French fr. Pr. <ets>mascot</ets> a little
sorcerer or magician, <ets>mascotto</ets> witchcraft, sorcery.]</ety>
<sn>1.</sn> <def>A person who is supposed to bring good luck to the
household to which he or she belongs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Anything that brings good
luck; especially, an animal kept by a group, as a sports team, to serve
as a symbol and to bring luck.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Masculate</ent><br/
<hw>Mas"cu*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>masculus</ets> male, masculine.]</ety> <def>To make strong.</def>
<mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 899 --></p>

<p><ent>masculine</ent><br/
<hw>mas"cu*line</hw> <pr>(m<acr/s"k<usl/*l<icr/n)</pr>, <pos>a.</pos>
<ety>[L. <ets>masculinus</ets>, fr. <ets>masculus</ets> male, manly,
dim. of <ets>mas</ets> a male: cf. F. <ets>masculin</ets>. See
<er>Male</er> masculine.]</ety> <sn>1.</sn> <def>Of the male sex; not
female.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy <qex>masculine</qex> children, that is to say, thy sons.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the qualities of a man; suitable to, or
characteristic of, a man; virile; not feminine or effeminate; strong;
robust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That lady, after her husband's death, held the reins with a
<qex>masculine</qex> energy.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Belonging to males; appropriated to, or used by,
males.</def> <mark>[R.]</mark> <ldquo/A <xex>masculine</xex>
church.<rdquo/ <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gram.)</fld> <def>Having the inflections of, or
construed with, words pertaining especially to male beings, as
distinguished from <contr>feminine</contr> and <contr>neuter</contr>.
See <er>Gender</er>.</def> -- <wordforms><wf>Mas"cu*line*ly</wf>,
<pos>adv.</pos> -- <wf>Mas"cu*line*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masculinity</ent><br/
<hw>Mas`cu*lin"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being masculine; masculineness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mase</ent><br/
<hw>Mase</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Maze</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maselyn</ent><br/
<hw>Mas"e*lyn</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A drinking cup. See
1st <er>Maslin</er>, 2.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mase</ent><br/
<hw>mase</hw> <pr>(m<amac/z)</pr>, <pos>v. i.</pos> <ety>[by
back-formation from <er>maser</er>{2}.]</ety> <def>To emit coherent
microwave radiation, as in a maser{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>maser</ent><br/
<hw>ma"ser</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Same as
<er>Mazer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <ety>[from <ets>M</ets>icrowave
<ets>A</ets>mplification by <ets>S</ets>timulated <ets>E</ets>mission of
<ets>R</ets>adiation.]</ety> <def>An electronic device producing
coherent monochromatic microwave radiation; it produces less noise than
other forms of <isa>microwave oscillator</isa>.</def>
<mark>[acronym]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>MASH</ent><br/
<ent>MASH</ent><br/
<mhw><hw>MASH</hw>, <hw>M*A*S*H</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Mil.)</fld> <def>An abbreviation for <altname>Mobile Army Surgical
Hospital</altname>, consisting of the equipment and personnel required
to perform emergency operations on injured soldiers, located in tents
near the front lines of combat; <as>as, he worked in the 25th
<ex>MASH</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mash</ent><br/
<hw>Mash</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mesh.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mash</ent><br/
<hw>Mash</hw>, <pos>n.</pos> <ety>[Akin to G. <ets>meisch</ets>,
<ets>maisch</ets>, <ets>meische</ets>, <ets>maische</ets>, mash, wash,
and prob. to AS. <ets>miscian</ets> to mix. See <er>Mix</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A mass of mixed ingredients reduced to a soft pulpy
state by beating or pressure; a mass of anything in a soft pulpy state.
Specifically <fld>(Brewing)</fld>, ground or bruised malt, or meal of
rye, wheat, corn, or other grain (or a mixture of malt and meal) steeped
and stirred in hot water for making the wort.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mixture of meal or bran and water fed to
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mess; trouble.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mash tun</b></col>, <cd>a large tub used in making mash
and wort.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mash</ent><br/
<hw>Mash</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mashed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mashing</conjf>.]</vmorph> <ety>[Akin to G. <ets>meischen</ets>,
<ets>maischen</ets>, to mash, mix, and prob. to <ets>mischen</ets>, E.
<ets>mix</ets>. See 2d <er>Mash</er>.]</ety> <def>To convert into a
mash; to reduce to a soft pulpy state by beating or pressure; to bruise;
to crush; <as>as, to <ex>mash</ex> apples in a mill, or potatoes with a
pestle</as>.</def> <specif>Specifically</specif> <fld>(Brewing)</fld>,
<def>to convert, as malt, or malt and meal, into the mash which makes
wort.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mashing tub</b></col>, <cd>a tub for making the mash in
breweries and distilleries; -- called also <altname>mash tun</altname>,
and <altname>mash vat</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mashed potato</ent><br/
<hw>mashed potato</hw>, <pos>n.</pos> <def>the name of a dance, briefly
popular in the 1960's.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mashed potatoes</ent><br/
<hw>mashed potatoes</hw>, <pos>n. pl.</pos> <def>Potatoes which have
been boiled and mashed to a pulpy consistency, usu. with sparing
addition of milk, salt, butter, or other flavoring. It is a popular
accompaniment to a meat course [U.S., 1900's], providing bulk and
calories to a meal.</def><br/
[<source>PJC</source>]</p>

<p><ent>Masher</ent><br/
<hw>Mash"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, mashes; also <fld>(Brewing)</fld>, a machine for making
mash.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A charmer of women.</def> <mark>[Slang]</mark>
<rj><au>London Punch.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mashy</ent><br/
<ent>Mashie</ent><br/
<mhw>{ <hw>Mash"ie</hw>, <hw>Mash"y</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos>; <plu>pl. <plw>Mashies</plw> <pr>(#)</pr></plu>.
<ety>[Etym. uncert.]</ety> <def>A golf club like the iron, but with a
shorter head, slightly more lofted, used chiefly for short
approaches.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mashlin</ent><br/
<hw>Mash"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Maslin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mashy</ent><br/
<hw>Mash"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Produced by crushing or
bruising; resembling, or consisting of, a mash.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>masjid</ent><br/
<hw>masjid</hw> <pos>n.</pos> <ety>[Arabic.]</ety> <def>A Muslim place
of worship; a mosque.</def> <altsp>[Also spelled
<asp>musjid</asp>.]</altsp><br/
<syn><b>Syn. --</b> mosque.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mask</ent><br/
<hw>Mask</hw> <pr>(m<adot/sk)</pr>, <pos>n.</pos> <ety>[F.
<ets>masque</ets>, LL. <ets>masca</ets>, <ets>mascha</ets>,
<ets>mascus</ets>; cf. Sp. & Pg. <ets>m<aacute/scara</ets>, It.
<ets>maschera</ets>; all fr. Ar. <ets>maskharat</ets> buffoon, fool,
pleasantry, anything ridiculous or mirthful, fr. <ets>sakhira</ets> to
ridicule, to laugh at. Cf. <er>Masque</er>, <er>Masquerade</er>.]</ety>
<sn>1.</sn> <def>A cover, or partial cover, for the face, used for
disguise or protection; <as>as, a dancer's <ex>mask</ex>; a fencer's
<ex>mask</ex>; a ball player's <ex>mask</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which disguises; a pretext or
subterfuge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A festive entertainment of dancing or other
diversions, where all wear masks; a masquerade; hence, a revel; a
frolic; a delusive show.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This thought might lead me through the world's vain
<qex>mask</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A dramatic performance, formerly in vogue, in which
the actors wore masks and represented mythical or allegorical
characters.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Arch.)</fld> <def>A grotesque head or face, used to
adorn keystones and other prominent parts, to spout water in fountains,
and the like; -- called also <altname>mascaron</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Fort.)</fld> <sd>(a)</sd> <def>In a permanent
fortification, a redoubt which protects the caponiere.</def>
<sd>(b)</sd> <def>A screen for a battery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Zool.)</fld> <def>The lower lip of the larva of a
dragon fly, modified so as to form a prehensile organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A person wearing a mask; a masker.</def></p>

<p><q>The <qex>mask</qex> that has the arm of the Indian queen.</q>
<rj><qau>G. W. Cable.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>9.</sn> <fld>(Sporting)</fld> <def>The head or face of a
fox.</def></p>

<p><cs><col><b>Mask house</b></col>, <cd>a house for masquerades.</cd>
<mark>[Obs.]</mark></cs> -- <col><b>Death mask</b></col>, <cd>a cast of
the face of a dead person.</cd><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mask</ent><br/
<hw>Mask</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Masked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Masking</conjf>.]</vmorph> <sn>1.</sn> <def>To cover, as the
face, by way of concealment or defense against injury; to conceal with a
mask or visor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They must all be <qex>masked</qex> and vizarded.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disguise; to cover; to hide.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Masking</qex> the business from the common eye.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>To conceal; also, to
intervene in the line of.</def> <sd>(b)</sd> <def>To cover or keep in
check; <as>as, to <ex>mask</ex> a body of troops or a fortress by a
superior force, while some hostile evolution is being carried
out</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mask</ent><br/
<hw>Mask</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To take part as a
masker in a masquerade.</def> <rj><au>Cavendish.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wear a mask; to be disguised in any way.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masked</ent><br/
<hw>Masked</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Wearing a
mask or masks; characterized by masks; concealed; hidden.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Same as
<er>Personate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Having the anterior part of the
head differing decidedly in color from the rest of the plumage; -- said
of birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Masked ball</b></col>, <cd>a ball in which the dancers
wear masks.</cd> -- <col><b>Masked battery</b></col> <fld>(Mil.)</fld>,
<cd>a battery so placed as not to be seen by an enemy until it opens
fire.</cd> <au>H. L. Scott.</au> -- <col><b>Masked crab</b></col>
<fld>(Zool.)</fld>, <cd>a European crab (<spn>Corystes
cassivelaunus</spn>) with markings on the carapace somewhat resembling a
human face.</cd> -- <col><b>Masked pig</b></col> <fld>(Zool.)</fld>,
<cd>a Japanese domestic hog (<spn>Sus pliciceps</spn>). Its face is
deeply furrowed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masker</ent><br/
<hw>Mask"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who wears a mask;
one who appears in disguise at a masquerade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masker</ent><br/
<hw>Mask"er</hw>, <pos>v. t.</pos> <def>To confuse; to stupefy.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maskery</ent><br/
<hw>Mask"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The dress or
disguise of a masker; masquerade.</def> <mark>[Obs.]</mark>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maskinonge</ent><br/
<hw>Mas"ki*nonge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
muskellunge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mask shell</ent><br/
<hw>Mask" shell`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>Any spiral
marine shell of the genus <gen>Persona</gen>, having a curiously twisted
aperture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maslach</ent><br/
<hw>Mas"lach</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>maslaq</ets>: cf. F. <ets>masloc</ets>.]</ety> <fld>(Med.)</fld>
<def>An excitant containing opium, much used by the Turks.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maslin</ent><br/
<hw>Mas"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>missellane</ets>, <ets>misceline</ets>, <ets>miscelin</ets>,
<ets>meslin</ets>, fr. <ets>miscellane</ets>. See
<er>Miscellane</er>.]</ety> <sn>1.</sn> <def>A mixture composed of
different materials</def>; especially: <sd>(a)</sd> <def>A mixture of
metals resembling brass.</def> <sd>(b)</sd> <def>A mixture of different
sorts of grain, as wheat and rye.</def> <altsp>[Written also
<asp>meslin</asp>, <asp>mislin</asp>, <asp>maselyn</asp>,
<asp>mastlin</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vessel made of maslin, 1 <sd>(a)</sd>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Mead eke in a <qex>maselyn</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maslin</ent><br/
<hw>Mas"lin</hw>, <pos>a.</pos> <def>Composed of different sorts;
<as>as, <ex>maslin</ex> bread, which is made of rye mixed with a little
wheat</as>.</def> <altsp>[Written also <asp>meslin</asp>,
<asp>mislin</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mason</ent><br/
<hw>Ma"son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>ma<cced/on</ets>, LL. <ets>macio</ets>, <ets>machio</ets>,
<ets>mattio</ets>, <ets>mactio</ets>, <ets>marcio</ets>,
<ets>macerio</ets>; of uncertain origin.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One whose occupation is to build with stone or
brick; also, one who prepares stone for building purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A member of the fraternity of Freemasons. See
<er>Freemason</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mason bee</b></col> <fld>(Zool.)</fld>, <cd>any one of
numerous species of solitary bees of the genus <gen>Osmia</gen>. They
construct curious nests of hardened mud and sand.</cd> -- <col><b>Mason
moth</b></col> <fld>(Zool.)</fld>, <cd>any moth whose larva constructs
an earthen cocoon under the soil.</cd> -- <col><b>Mason shell</b></col>
<fld>(Zool.)</fld>, <cd>a marine univalve shell of the genus
<gen>Phorus</gen>; -- so called because it cements other shells and
pebbles upon its own shell; a carrier shell.</cd> -- <col><b>Mason
wasp</b></col> <fld>(Zool.)</fld>, <cd>any wasp that constructs its
nest, or brood cells, of hardened mud. The female fills the cells with
insects or spiders, paralyzed by a sting, and thus provides food for its
larvae</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mason</ent><br/
<hw>Ma"son</hw>, <pos>v. t.</pos> <def>To build stonework or brickwork
about, under, in, over, etc.; to construct by masons; -- with a
prepositional suffix; <as>as, to <ex>mason</ex> up a well or terrace; to
<ex>mason</ex> in a kettle or boiler.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masonic</ent><br/
<hw>Ma*son"ic</hw> <pr>(m<adot/*s<ocr/n"<icr/k)</pr>, <pos>prop.
a.</pos> <def>Of or pertaining to Freemasons or to their craft or
mysteries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masonite</ent><br/
<hw>Masonite</hw> <pos>prop. n.</pos> <ety>[trademark.]</ety> <def>A
type of fiberboard.</def> <mark>[trademark]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Masonry</ent><br/
<hw>Ma"son*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>ma<cced/onnerie</ets>.]</ety> <sn>1.</sn> <def>The art or
occupation of a mason.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The work or performance of a mason; <as>as, good or
bad <ex>masonry</ex>; skillful <ex>masonry</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is built by a mason; anything constructed
of the materials used by masons, such as stone, brick, tiles, or the
like. <stype>Dry masonry</stype> is applied to structures made without
mortar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The craft, institution, or mysteries of Freemasons;
freemasonry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masoola boat</ent><br/
<hw>Ma*soo"la boat`</hw> <pr>(?)</pr>. <def>A kind of boat used on the
coast of Madras, India. The planks are sewed together with strands of
coir which cross over a wadding of the same material, so that the shock
on taking the beach through surf is much reduced.</def> <altsp>[Written
also <asp>masula</asp>, <asp>masulah</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masora</ent><br/
\'d8<hw>Ma*so"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NHeb.
<ets>m<amac/s<omac/r<amac/h</ets> tradition.]</ety> <def>A Jewish
critical work on the text of the Hebrew Scriptures, composed by several
learned rabbis of the school of Tiberias, in the eighth and ninth
centuries.</def> <altsp>[Written also <asp>Masorah</asp>,
<asp>Massora</asp>, and <asp>Massorah</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masoret</ent><br/
<hw>Mas"o*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Masorite.</def>
<altsp>[Written also <asp>Masorete</asp>, and
<asp>Massorete</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masoretical</ent><br/
<ent>Masoretic</ent><br/
<mhw>{ <hw>Mas`o*ret"ic</hw> <pr>(?)</pr>, <hw>Mas`o*ret"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>massor<eacute/tique</ets>.]</ety> <def>Of or relating to the
Masora, or to its authors.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Masoretic points and accents</b></col>, <cd>the vowel
points and accents of the Hebrew text of the Bible, of which the first
mention is in the Masora. See <er>vowel point</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masorite</ent><br/
<hw>Mas"o*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the writers
of the Masora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masque</ent><br/
<hw>Masque</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mask; a
masquerade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masquerade</ent><br/
<hw>Mas`quer*ade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mascarade</ets>, fr. Sp. <ets>mascarada</ets>, or It.
<ets>mascherata</ets>. See <er>Mask</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An assembly of persons wearing masks, and amusing
themselves with dancing, conversation, or other diversions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In courtly balls and midnight <qex>masquerades</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dramatic performance by actors in masks; a mask.
See 1st <er>Mask</er>, 4.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Acting or living under false pretenses; concealment
of something by a false or unreal show; pretentious show;
disguise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>masquerade</qex> of misrepresentation which invariably
accompanied the political eloquence of Rome.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A Spanish diversion on horseback.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masquerade</ent><br/
<hw>Mas`quer*ade"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Masqueraded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Masquerading</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To assemble in masks; to take part in a
masquerade.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To frolic or disport in disguise; to make a
pretentious show of being what one is not.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A freak took an ass in the head, and he goes into the woods,
<qex>masquerading</qex> up and down in a lion's skin.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masquerade</ent><br/
<hw>Mas`quer*ade"</hw>, <pos>v. t.</pos> <def>To conceal with masks; to
disguise.</def> <ldquo/To <xex>masquerade</xex> vice.<rdquo/
<rj><au>Killingbeck.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masquerader</ent><br/
<hw>Mas`quer*ad"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
masquerades; a person wearing a mask; one disguised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mass</ent><br/
<hw>Mass</hw> <pr>(m<adot/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>masse</ets>, <ets>messe</ets>, AS. <ets>maesse</ets>. LL.
<ets>missa</ets>, from L. <ets>mittere</ets>, <ets>missum</ets>, to
send, dismiss: cf. F. <ets>messe</ets>. In the ancient churches, the
public services at which the catechumens were permitted to be present
were called <ets>missa catechumenorum</ets>, ending with the reading of
the Gospel. Then they were <ets>dismissed</ets> with these words :
<ldquo/Ite, missa est<rdquo/ [<it>sc</it>. ecclesia], the congregation
is dismissed. After that the sacrifice proper began. At its close the
same words were said to those who remained. So the word gave the name of
<xex>Mass</xex> to the sacrifice in the Catholic Church. See
<er>Missile</er>, and cf. <er>Christmas</er>, <er>Lammas</er>,
<er>Mess</er> a dish, <er>Missal</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(R. C. Ch.)</fld> <def>The sacrifice in the
sacrament of the Eucharist, or the consecration and oblation of the
host.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The portions of the Mass usually
set to music, considered as a musical composition; -- namely, the
<part>Kyrie</part>, the <part>Gloria</part>, the <part>Credo</part>, the
<part>Sanctus</part>, and the <part>Agnus Dei</part>, besides sometimes
an <part>Offertory</part> and the <part>Benedictus</part>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Canon of the Mass</b></col>. <cd>See <er>Canon</er>.</cd>
-- <col><b>High Mass</b></col>, <cd>Mass with incense, music, the
assistance of a deacon, subdeacon, etc.</cd> -- <col><b>Low
Mass</b></col>, <cd>Mass which is said by the priest throughout, without
music.</cd> -- <col><b>Mass bell</b></col>, <cd>the sanctus bell. See
<er>Sanctus</er>.</cd> -- <col><b>Mass book</b></col>, <cd>the missal or
Roman Catholic service book.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mass</ent><br/
<hw>Mass</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Massed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Massing</conjf>.]</vmorph> <def>To celebrate Mass.</def>
<mark>[Obs.]</mark> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mass</ent><br/
<hw>Mass</hw>, <pos>n.</pos> <ety>[OE. <ets>masse</ets>, F.
<ets>masse</ets>, L. <ets>massa</ets>; akin to Gr. <?/ a barley cake,
fr. <?/ to knead. Cf. <er>Macerate</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A quantity of matter cohering together so as to make
one body, or an aggregation of particles or things which collectively
make one body or quantity, usually of considerable size; <as>as, a
<ex>mass</ex> of ore, metal, sand, or water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If it were not for these principles, the bodies of the earth,
planets, comets, sun, and all things in them, would grow cold and
freeze, and become inactive <qex>masses</qex>.</q> <rj><qau>Sir I.
Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A deep <qex>mass</qex> of continual sea is slower stirred<br/
To rage.</q> <rj><qau>Savile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phar.)</fld> <def>A medicinal substance made into a
cohesive, homogeneous lump, of consistency suitable for making pills;
<as>as, blue <ex>mass</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A large quantity; a sum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>mass</qex> of gold that comes into Spain.</q>
<rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He had spent a huge <qex>mass</qex> of treasure.</q> <rj><qau>Sir
J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Bulk; magnitude; body; size.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This army of such <qex>mass</qex> and charge.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The principal part; the main body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Night closed upon the pursuit, and aided the <qex>mass</qex> of
the fugitives in their escape.</q> <rj><qau>Jowett
(Thucyd.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Physics)</fld> <def>The quantity of matter which a
body contains, irrespective of its bulk or volume.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mass</xex> and <xex>weight</xex> are often used, in
a general way, as interchangeable terms, since the <xex>weight</xex> of
a body is proportional to its <xex>mass</xex> (under the same or equal
gravitative forces), and the <xex>mass</xex> is usually ascertained from
the <xex>weight</xex>. Yet the two ideas, <xex>mass</xex> and
<xex>weight</xex>, are quite distinct. <xex>Mass</xex> is the quantity
of matter in a body; <xex>weight</xex> is the comparative force with
which it tends towards the center of the earth. A <xex>mass</xex> of
sugar and a <xex>mass</xex> of lead are assumed to be equal when they
show an equal <xex>weight</xex> by balancing each other in the
scales.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Blue mass</b></col>. <cd>See under <er>Blue</er>.</cd> --
<col><b>Mass center</b></col> <fld>(Geom.)</fld>, <cd>the center of
gravity of a triangle.</cd> -- <col><b>Mass copper</b></col>, <cd>native
copper in a large mass.</cd> -- <col><b>Mass meeting</b></col>, <cd>a
large or general assembly of people, usually a meeting having some
relation to politics.</cd> -- <col><b>The masses</b></col>, <cd>the
great body of the people, as contrasted with the higher classes; the
populace.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mass</ent><br/
<hw>Mass</hw>, <pos>v. t.</pos> <def>To form or collect into a mass; to
form into a collective body; to bring together into masses; to
assemble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But <qex>mass</qex> them together and they are terrible
indeed.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massacre</ent><br/
<hw>Mas"sa*cre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. LL.
<ets>mazacrium</ets>; cf. Prov. G. <ets>metzgern</ets>,
<ets>metzgen</ets>, to kill cattle, G. <ets>metzger</ets> a butcher, and
LG. <ets>matsken</ets> to cut, hew, OHG. <ets>meizan</ets> to cut, Goth.
<ets>m<aacute/itan</ets>.]</ety> <sn>1.</sn> <def>The killing of a
considerable number of human beings under circumstances of atrocity or
cruelty, or contrary to the usages of civilized people; <as>as, the
<ex>massacre</ex> on St. Bartholomew's Day; the St. Valentine's Day
<ex>massacre</ex>; the Amritsar <ex>massacre</ex>; the Wounded Knee
<ex>massacre</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Murder.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Massacre</er>, <er>Butchery</er>,
<er>Carnage</er>.</syn> <usage> <xex>Massacre</xex> denotes the
promiscuous slaughter of <xex>many</xex> who can not make resistance, or
much resistance. <xex>Butchery</xex> refers to cold-blooded cruelty in
the killing of men as if they were brute beasts. <xex>Carnage</xex>
points to slaughter as producing the heaped-up bodies of the
slain.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll find a day to <qex>massacre</qex> them all,<br/
And raze their faction and their family.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou delight to view thy heinous deeds,<br/
Brhold this pattern of thy <qex>butcheries</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a scent I draw<br/
Of <qex>carnage</qex>, prey innumerable!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massacre</ent><br/
<hw>Mas"sa*cre</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Massacred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Massacring</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>massacrer</ets>. See <er>Massacre</er>, <pos>n.</pos>]</ety>
<def>To kill in considerable numbers where much resistance can not be
made; to kill with indiscriminate violence, without necessity, and
contrary to the usages of nations; to butcher; to slaughter; -- limited
to the killing of human beings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If James should be pleased to <qex>massacre</qex> them all, as
Maximian had <qex>massacred</qex> the Theban legion.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massacrer</ent><br/
<hw>Mas"sa*crer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
massacres.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massage</ent><br/
<hw>Mas"sage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
rubbing or kneading of the body, especially when performed as a hygienic
or remedial measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massage</ent><br/
<hw>Mas"sage</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Med.)</fld>
<def>To treat by means of massage; to rub or knead; <as>as, to
<ex>massage</ex> a patient with ointment</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Massagist</ent><br/
<hw>Mas"sag*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who practices
massage; a masseur or masseuse.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Massasauga</ent><br/
<hw>Mas`sa*sau"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The black rattlesnake (<spn>Crotalus tergemina</spn>, or
<spn>Caudisona tergemina</spn>), found in the Mississippi
Valley.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masse</ent><br/
<ent>Masse shot</ent><br/
<mhw>{ <hw>Mass<eacute/</hw>, <it>or</it> <hw>Mass<eacute/ shot</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <fld>(Billiards)</fld> <def>A stroke
made with the cue held vertically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masser</ent><br/
<hw>Mass"er</hw>, <pos>n.</pos> <def>A priest who celebrates Mass.</def>
<mark>[R.]</mark> <rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masseter</ent><br/
<hw>Mas"se*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/ a
chewer, <?/ a muscle of the lower jaw used in chewing, from <?/ to chew:
cf. F. <ets>mass<eacute/ter</ets>.]</ety> <fld>(Anat.)</fld> <def>The
large muscle which raises the under jaw, and assists in
mastication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masseteric</ent><br/
<hw>Mas`se*ter"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the masseter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masseterine</ent><br/
<hw>Mas"se*ter`ine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Masseteric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masseur</ent><br/
\'d8<hw>Mas`seur"</hw> <pr>(m<adot/*s<ucir/r")</pr>, <pos>n.</pos>;
<plu>pl. <plw>Masseurs</plw> <pr>(m<adot/*s<ucir/rz"; <it>F.</it>
m<adot/*s<ucir/r")</pr></plu>. <ety>[F. See <er>Massage</er>.]</ety>
<sn>1.</sn> <def>A man who practices massage.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>An instrument used in the performance of
massage.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Masseuse</ent><br/
\'d8<hw>Mas`seuse"</hw> <pr>(m<adot/*s<ucir/z")</pr>, <pos>n.</pos>;
<plu>pl. <plw>Masseuses</plw> <pr>(<it>F.</it>
m<adot/*s<ucir/z")</pr></plu>. <ety>[F.]</ety> <def>A woman who
practices massage.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>massicot</ent><br/
<hw>mas"si*cot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>massicot</ets>; E. <ets>masticot</ets> is a corruption.]</ety>
<fld>(Chem.)</fld> <def>Lead monoxide (also called <altname>Lead
protoxide</altname>), <chform>PbO</chform>, obtained as a yellow
amorphous powder, the fused and crystalline form of which is called
<altname>litharge</altname>; lead ocher. It is used as a pigment. It is
also called <altname>lead oxide yellow</altname>, as opposed to
<contr>red lead</contr>, which is lead tetroxide
<chform>Pb3O4</chform>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ <xex>Massicot</xex> is sometimes used by painters, and
also as a drier in the composition of ointments and plasters.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>massif</ent><br/
<hw>massif</hw> <pos>n.</pos> <fld>(Geol.)</fld> <def>A block of the
earth's crust bounded by faults and shifted to form peaks of a mountain
range.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>massiness</ent><br/
<hw>mass"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Massy</er>.]</ety> <def>The state or quality of being massy;
ponderousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 900 --></p>

<p><ent>massive</ent><br/
<hw>mass"ive</hw> <pr>(m<adot/s"<icr/v)</pr>, <pos>a.</pos> <ety>[F.
<ets>massif</ets>.]</ety> <sn>1.</sn> <def>Forming, or consisting of, a
large mass; compacted; weighty; heavy; massy.</def>
<ldquo/<xex>Massive</xex> armor.<rdquo/ <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>In mass; not necessarily without a
crystalline structure, but having no regular form; <as>as, a mineral
occurs <ex>massive</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Massive rock</b></col> <fld>(Geol.)</fld>, <cd>a compact
crystalline rock not distinctly schistose, as granite; also, with some
authors, an eruptive rock.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massively</ent><br/
<hw>Mass"ive*ly</hw>, <pos>adv.</pos> <def>In a heavy mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massiveness</ent><br/
<hw>Mass"ive*ness</hw>, <pos>n.</pos> <def>The state or quality of being
massive; massiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massoola boat</ent><br/
<hw>Mas*soo"la boat`</hw>. <def>See <er>Masoola boat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massora</ent><br/
<hw>Mas*so"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Masora</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Massoret</ent><br/
<hw>Mas"so*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Masorite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mass-produce</ent><br/
<hw>mass-produce</hw> <pos>v. t.</pos> <def>To produce on a large
scale.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mass-produced</ent><br/
<hw>mass-produced</hw> <pos>adj.</pos> <def>Produced in large quantity,
often by automated or assembly-line techniques.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mass spectrometer</ent><br/
<hw>mass spectrometer</hw> <pos>n.</pos> <fld>(Physics, Chemistry)</fld>
<def>An analytical instrument which determines the mass of molecules of
a substance or fragments of its molecules. It functions by injecting
ionized molecules or molecular fragments into a vacuum chamber subjected
to a strong magnetic field, in which charged particles move in a curved
trajectory.</def> <note>The mass is determined by observing the path of
the molecule after being charged and accelerated in a magnetic field.
The path of the ionic fragment depends on the charge, velocity, and
mass. Several techniques of charging and detection are employed. The
mass information is usually used to infer structure or chemical
composition of the substance analyzed. Variants of mass spectrometer
called <stype>high-resolution mass spectrometer</stype> permit
determination of the mass of a molecule or molecular fragment with
sufficient precision to unambiguously determine the atomic
composition.</note><br/
[<source>PJC</source>]</p>

<p><ent>mass-spectrometric</ent><br/
<hw>mass-spectrometric</hw> <pos>adj.</pos> <def>of or pertaining to
<er>mass spectrometry</er>; determined by <er>mass
spectrometry</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mass spectroscopy</ent><br/
<ent>mass spectrometry</ent><br/
<mhw><hw>mass spectrometry</hw> <hw>mass spectroscopy</hw></mhw>
<pos>n.</pos> <sn>1.</sn> <fld>(Physics, Chemistry)</fld> <def>A method
for identifying chemical composition of substances by use of a <er>mass
spectrometer</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Massy</ent><br/
<hw>Mass"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Massier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Massiest</adjf>.]</amorph> <def>Compacted into, or consisting of,
a mass; having bulk and weight or substance; ponderous; bulky and heavy;
weighty; heavy; <as>as, a <ex>massy</ex> shield; a <ex>massy</ex>
rock.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your swords are now too <qex>massy</qex> for your strengths,<br/
And will not be uplifted.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yawning rocks in <qex>massy</qex> fragments fly.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mast</ent><br/
<hw>Mast</hw> <pr>(m<adot/st)</pr>, <pos>n.</pos> <ety>[AS.
<ets>maest</ets>, fem.; akin to G. <ets>mast</ets>, and E.
<ets>meat</ets>. See <er>Meat</er>.]</ety> <def>The fruit of the oak and
beech, or other forest trees; nuts; acorns.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Oak <qex>mast</qex>, and beech, . . . they eat.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Swine under an oak filling themselves with the
<qex>mast</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mast</ent><br/
<hw>Mast</hw>, <pos>n.</pos> <ety>[AS. <ets>maest</ets>, masc.; akin to
D., G., Dan., & Sw. <ets>mast</ets>, Icel. <ets>mastr</ets>, and perh.
to L. <ets>malus</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Naut.)</fld> <def>A pole, or long, strong, round
piece of timber, or spar, set upright in a boat or vessel, to sustain
the sails, yards, rigging, etc. A mast may also consist of several
pieces of timber united by iron bands, or of a hollow pillar of iron or
steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The tallest pine<br/
Hewn on Norwegian hills, to be the <qex>mast</qex><br/
Of some great ammiral.<--sic--></q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The most common general names of <ex>masts</ex> are
<stype>foremast</stype>, <stype>mainmast</stype>, and
<stype>mizzenmast</stype>, each of which may be made of separate
spars.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>The vertical post of a derrick or
crane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Aeronautics)</fld> <def>A spar or strut to which
tie wires or guys are attached for stiffening purposes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Afore the mast</b></col>, <col><b>Before the
mast</b></col></mcol>. <cd>See under <er>Afore</er>, and
<er>Before</er>.</cd> -- <col><b>Mast coat</b></col>. <cd>See under
<er>Coat</er>.</cd> -- <col><b>Mast hoop</b></col>, <cd>one of a number
of hoops attached to the fore edge of a boom sail, which slip on the
mast as the sail is raised or lowered; also, one of the iron hoops used
in making a made mast. See <er>Made</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mast</ent><br/
<hw>Mast</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Masted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Masting</conjf>.]</vmorph> <def>To furnish with a mast or masts;
to put the masts of in position; <as>as, to <ex>mast</ex> a
ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastabah</ent><br/
<ent>Mastaba</ent><br/
<mhw>{ <hw>Mas"ta*ba</hw> <pr>(?)</pr>, <pos>n.</pos> Also
<hw>Mas"ta*bah</hw> }</mhw>. <ety>[Ar. <ets>ma<cced/tabah</ets> a large
stone bench.]</ety> <sn>1.</sn> <def>In Muslim countries, a fixed seat,
common in dwellings and in public places.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Egyptology)</fld> <def>A type of tomb, of the time
of the Memphite dynasties, comprising an oblong structure with sloping
sides (sometimes containing a decorated chamber, sometimes of solid
masonry), and connected with a mummy chamber in the rock
beneath.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mastax</ent><br/
\'d8<hw>Mas"tax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
mouth, jaws.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The pharynx of
a rotifer. It usually contains four horny pieces. The two central ones
form the incus, against which the mallei, or lateral ones, work so as to
crush the food.</def> <sd>(b)</sd> <def>The lore of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masted</ent><br/
<hw>Mast"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with a mast
or masts; -- chiefly in composition; <as>as, a three-<ex>masted</ex>
schooner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Master</ent><br/
<hw>Mast"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
vessel having (so many) masts; -- used only in compounds; <as>as, a
two-<ex>master</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Master</ent><br/
<hw>Mas"ter</hw> <pr>(m<adot/s"t<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>maistre</ets>, <ets>maister</ets>, OF. <ets>maistre</ets>,
<ets>mestre</ets>, F. <ets>ma<icir/tre</ets>, fr. L.
<ets>magister</ets>, orig. a double comparative from the root of
<ets>magnus</ets> great, akin to Gr. <grk>me`gas</grk>. Cf.
<er>Maestro</er>, <er>Magister</er>, <er>Magistrate</er>,
<er>Magnitude</er>, <er>Major</er>, <er>Mister</er>, <er>Mistress</er>,
<er>Mickle</er>.]</ety> <sn>1.</sn> <def>A male person having another
living being so far subject to his will, that he can, in the main,
control his or its actions; -- formerly used with much more extensive
application than now.</def> <sd>(a)</sd> <def>The employer of a
servant.</def> <sd>(b)</sd> <def>The owner of a slave.</def>
<sd>(c)</sd> <def>The person to whom an apprentice is articled.</def>
<sd>(d)</sd> <def>A sovereign, prince, or feudal noble; a chief, or one
exercising similar authority.</def> <sd>(e)</sd> <def>The head of a
household.</def> <sd>(f)</sd> <def>The male head of a school or
college.</def> <sd>(g)</sd> <def>A male teacher.</def> <sd>(h)</sd>
<def>The director of a number of persons performing a ceremony or
sharing a feast.</def> <sd>(i)</sd> <def>The owner of a docile brute, --
especially a dog or horse.</def> <sd>(j)</sd> <def>The controller of a
familiar spirit or other supernatural being.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who uses, or controls at will, anything
inanimate; <as>as, to be <ex>master</ex> of one's time</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Master</qex> of a hundred thousand drachms.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We are <qex>masters</qex> of the sea.</q> <rj><qau>Jowett
(Thucyd.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who has attained great skill in the use or
application of anything; <as>as, a <ex>master</ex> of oratorical
art</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Great <qex>masters</qex> of ridicule.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No care is taken to improve young men in their own language, that
they may thoroughly understand and be <qex>masters</qex> of it.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A title given by courtesy, now commonly pronounced
<pr><it>m<icr/ster</it></pr>, except when given to boys; -- sometimes
written <asp>Mister</asp>, but usually abbreviated to
<abbr>Mr.</abbr></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A young gentleman; a lad, or small boy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where there are little <qex>masters</qex> and misses in a house,
they are impediments to the diversions of the servants.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>The commander of a merchant
vessel; -- usually called <altname>captain</altname>. Also, a
commissioned officer in the navy ranking next above ensign and below
lieutenant; formerly, an officer on a man-of-war who had immediate
charge, under the commander, of sailing the vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A person holding an office of authority among the
Freemasons, esp. the presiding officer; also, a person holding a similar
office in other civic societies.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Little masters</b></col>, <cd>certain German engravers of
the 16th century, so called from the extreme smallness of their
prints.</cd> -- <col><b>Master in chancery</b></col>, <cd>an officer of
courts of equity, who acts as an assistant to the chancellor or judge,
by inquiring into various matters referred to him, and reporting thereon
to the court.</cd> -- <col><b>Master of arts</b></col>, <cd>one who
takes the second degree at a university; also, the degree or title
itself, indicated by the abbreviation M. A., or A. M.</cd> --
<col><b>Master of the horse</b></col>, <cd>the third great officer in
the British court, having the management of the royal stables, etc. In
ceremonial cavalcades he rides next to the sovereign.</cd> --
<col><b>Master of the rolls</b></col>, <cd>in England, an officer who
has charge of the rolls and patents that pass the great seal, and of the
records of the chancery, and acts as assistant judge of the court.</cd>
<au>Bouvier.</au> <au>Wharton.</au> -- <col><b>Past master</b></col>,
<sd>(a)</sd> <cd>one who has held the office of <xex>master</xex> in a
lodge of Freemasons or in a society similarly organized.</cd>
<sd>(b)</sd> <cd>a person who is unusually expert, skilled, or
experienced in some art, technique, or profession; -- usually used with
<ptcl>at</ptcl> or <ptcl>of</ptcl>.</cd> -- <col><b>The old
masters</b></col>, <cd>distinguished painters who preceded modern
painters; especially, the celebrated painters of the 16th and 17th
centuries.</cd> -- <col><b>To be master of one's self</b></col>, <cd>to
have entire self-control; not to be governed by passion.</cd> --
<col><b>To be one's own master</b></col>, <cd>to be at liberty to act as
one chooses without dictation from anybody.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Master</xex>, signifying <xex>chief</xex>,
<xex>principal</xex>, <xex>masterly</xex>, <xex>superior</xex>,
<xex>thoroughly skilled</xex>, etc., is often used adjectively or in
compounds; as, <xex>master</xex> builder or <xex>master</xex>-builder,
<xex>master</xex> chord or <xex>master</xex>-chord, <xex>master</xex>
mason or <xex>master</xex>-mason, <xex>master</xex> workman or
<xex>master</xex>-workman, <xex>master</xex> mechanic, <xex>master</xex>
mind, <xex>master</xex> spirit, <xex>master</xex> passion,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Throughout the city by the <qex>master</qex> gate.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Master joint</b></col> <fld>(Geol.)</fld>, <cd>a
quarryman's term for the more prominent and extended joints traversing a
rock mass.</cd> -- <col><b>Master key</b></col>, <cd>a key adapted to
open several locks differing somewhat from each other; figuratively, a
rule or principle of general application in solving difficulties.</cd>
-- <col><b>Master lode</b></col> <fld>(Mining)</fld>, <cd>the principal
vein of ore.</cd> -- <col><b>Master mariner</b></col>, <cd>an
experienced and skilled seaman who is certified to be competent to
command a merchant vessel.</cd> -- <col><b>Master sinew</b></col>
<fld>(Far.)</fld>, <cd>a large sinew that surrounds the hough of a
horse, and divides it from the bone by a hollow place, where the
windgalls are usually seated.</cd> -- <col><b>Master singer</b></col>.
<cd>See <er>Mastersinger</er>.</cd> -- <col><b>Master stroke</b></col>,
<cd>a capital performance; a masterly achievement; a consummate action;
<as>as, a <ex>master stroke</ex> of policy</as>.</cd> -- <col><b>Master
tap</b></col> <fld>(Mech.)</fld>, <cd>a tap for forming the thread in a
screw cutting die.</cd> -- <col><b>Master touch</b></col>. <sd>(a)</sd>
<cd>The touch or skill of a master</cd>. <au>Pope.</au> <sd>(b)</sd>
<cd>Some part of a performance which exhibits very skillful work or
treatment.</cd> <ldquo/Some <xex>master touches</xex> of this admirable
piece.<rdquo/ <au>Tatler.</au> -- <col><b>Master work</b></col>, <cd>the
most important work accomplished by a skilled person, as in
architecture, literature, etc.; also, a work which shows the skill of a
master; a masterpiece.</cd> -- <col><b>Master workman</b></col>, <cd>a
man specially skilled in any art, handicraft, or trade, or who is an
overseer, foreman, or employer.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Master</ent><br/
<hw>Mas"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mastered</conjf> <pr>(?)</pr>; <pos>p. pr. vb. n.</pos>
<conjf>Mastering</conjf>.]</vmorph> <sn>1.</sn> <def>To become the
master of; to subject to one's will, control, or authority; to conquer;
to overpower; to subdue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Obstinacy and willful neglects must be <qex>mastered</qex>, even
though it cost blows.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To gain the command of, so as to understand or
apply; to become an adept in; <as>as, to <ex>master</ex> a
science</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To own; to posses.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The wealth<br/
That the world <qex>masters</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Master</ent><br/
<hw>Mas"ter</hw>, <pos>v. i.</pos> <def>To be skillful; to excel.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>master-at-arms</ent><br/
<hw>master-at-arms</hw> <pos>n.</pos> <fld>(Naut.)</fld> <def>The senior
petty officer of a ship, responsible for discipline aboard the
ship.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Masterdom</ent><br/
<hw>Mas"ter*dom</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Master</ets>
+ <ets>-dom</ets>.]</ety> <def>Dominion; rule; command.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mastered</ent><br/
<hw>mastered</hw> <pos>adj.</pos> <def>Learned thoroughly.</def><br/
<syn><b>Syn. --</b> down, down pat(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Masterful</ent><br/
<hw>Mas"ter*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Inclined to play the master; domineering; imperious;
arbitrary.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the skill or power of a master; indicating or
expressing power or mastery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>masterful</qex>, pale face.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterfully</ent><br/
<hw>Mas"ter*ful*ly</hw>, <pos>adv.</pos> <def>In a masterful manner;
imperiously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A lawless and rebellious man who held lands <qex>masterfully</qex>
and in high contempt of the royal authority.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterhood</ent><br/
<hw>Mas"ter*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being a master; hence, disposition to command or hector.</def>
<rj><au>C. Bront<eacute/.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterless</ent><br/
<hw>Mas"ter*less</hw>, <pos>a.</pos> <def>Destitute of a master or
owner; ungoverned or ungovernable.</def> --
<wordforms><wf>Mas"ter*less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterliness</ent><br/
<hw>Mas"ter*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being masterly; ability to control wisely or
skillfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterly</ent><br/
<hw>Mas"ter*ly</hw>, <pos>a.</pos> <sn>1.</sn> <def>Suitable to, or
characteristic of, a master; indicating thorough knowledge or superior
skill and power; showing a master's hand; <as>as, a <ex>masterly</ex>
design; a <ex>masterly</ex> performance; a <ex>masterly</ex>
policy.</as></def> <ldquo/A wise and <xex>masterly</xex>
inactivity.<rdquo/ <rj><au>Sir J. Mackintosh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Imperious; domineering; arbitrary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterly</ent><br/
<hw>Mas"ter*ly</hw>, <pos>adv.</pos> <def>With the skill of a
master.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou dost speak <qex>masterly</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterous</ent><br/
<hw>Mas"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Masterly.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masterpiece</ent><br/
<hw>Mas"ter*piece`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Anything done
or made with extraordinary skill; a capital performance; a
chef-d'oeuvre; a supreme achievement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The top and <qex>masterpiece</qex> of art.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Dissimulation was his <qex>masterpiece</qex>.</q>
<rj><qau>Claredon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastership</ent><br/
<hw>Mas"ter*ship</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state or
office of a master.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mastery; dominion; superior skill;
superiority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where noble youths for <qex>mastership</qex> should strive.</q>
<rj><qau>Driden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Chief work; masterpiece.</def> <mark>[Obs.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An ironical title of respect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How now, seignior Launce! what news with your
<qex>mastership</qex>?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastersinger</ent><br/
<hw>Mas"ter*sing`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A translation
of G. <ets>meisters<aum/nger</ets>.]</ety> <def>One of a class of poets
which flourished in Nuremberg and some other cities of Germany in the
15th and 16th centuries. They bound themselves to observe certain
arbitrary laws of rhythm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Master vibrator</ent><br/
<hw>Mas"ter vi"bra*tor</hw>. <def>In an internal-combustion engine with
two or more cylinders, an induction coil and vibrator placed in the
circuit between the battery or magneto and the coils for the different
cylinders, which are used without vibrators of their own.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Masterwort</ent><br/
<hw>Mas"ter*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A tall and coarse European umbelliferous plant
(<spn>Peucedanum Ostruthium</spn>, formerly
<spn>Imperatoria</spn>).</def> <sd>(b)</sd> <def>The <spn>Astrantia
major</spn>, a European umbelliferous plant with a showy colored
involucre.</def> <sd>(c)</sd> <def>Improperly, the <altname>cow
parsnip</altname> (<spn>Heracleum lanatum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastery</ent><br/
<hw>Mas"ter*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Masteries</plw> <pr>(#)</pr>.</plu> <ety>[OF.
<ets>maistrie</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The position or authority of a master; dominion;
command; supremacy; superiority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If divided by mountains, they will fight for the
<qex>mastery</qex> of the passages of the tops.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Superiority in war or competition; victory; triumph;
preeminence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The voice of them that shout for <qex>mastery</qex>.</q>
<rj><qau>Ex. xxxii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every man that striveth for the <qex>mastery</qex> is temperate in
all things.</q> <rj><qau>1 Cor. ix. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, but to have gulled him<br/
Had been a <qex>mastery</qex>.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Contest for superiority.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A masterly operation; a feat.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will do a <qex>maistrie</qex> ere I go.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <specif>Specifically,</specif> <def>the philosopher's
stone.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The act process of mastering; the state of having
mastered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He could attain to a <qex>mastery</qex> in all languages.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The learning and <qex>mastery</qex> of a tongue, being unpleasant
in itself, should not be cumbered with other difficulties.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastful</ent><br/
<hw>Mast"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See 1st
<er>Mast</er>.]</ety> <def>Abounding in mast; producing mast in
abundance; <as>as, the <ex>mastful</ex> forest; a <ex>mastful</ex>
chestnut.</as></def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masthead</ent><br/
<hw>Mast"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The top or head of a mast; the part of a mast above the
hounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masthead</ent><br/
<hw>Mast"head"</hw>, <pos>v. t.</pos> <fld>(Naut.)</fld> <def>To cause
to go to the masthead as a punishment.</def>
<rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masthouse</ent><br/
<hw>Mast"house`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A building in
which vessels' masts are shaped, fitted, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastic</ent><br/
<hw>Mas"tic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>mastiche</ets>, <ets>mastichum</ets>, Gr. <?/, fr. <?/ to chew,
because of its being used in the East for chewing.]</ety>
<altsp>[Written also <asp>mastich</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>A low shrubby tree of the genus
<gen>Pistacia</gen> (<spn>Pistacia Lentiscus</spn>), growing upon the
islands and coasts of the Mediterranean, and producing a valuable resin;
-- called also, <altname>mastic tree</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A resin exuding from the mastic tree, and obtained
by incision. The best is in yellowish white, semitransparent tears, of a
faint smell, and is used as an astringent and an aromatic, also as an
ingredient in varnishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of cement composed of burnt clay, litharge,
and linseed oil, used for plastering walls, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Barbary mastic</b></col> <fld>(Bot.)</fld>, <cd>the
<spn>Pistachia Atlantica</spn>.</cd> -- <col><b>Peruvian mastic
tree</b></col> <fld>(Bot.)</fld>, <cd>a small tree (<spn>Schinus
Molle</spn>) with peppery red berries; -- called also <altname>pepper
tree</altname>.</cd> -- <col><b>West Indian mastic</b></col>
<fld>(Bot.)</fld>, <cd>a lofty tree (<spn>Bursera gummifera</spn>) full
of gum resin in every part.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticable</ent><br/
<hw>Mas"ti*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
masticated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticador</ent><br/
<hw>Mas`ti*ca"dor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>mastigador</ets>. See <er>Masticate</er>.]</ety> <fld>(Man.)</fld>
<def>A part of a bridle, the slavering bit.</def> <altsp>[Written also
<asp>mastigador</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticate</ent><br/
<hw>Mas"ti*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Masticated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Masticating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>masticatus</ets>, p. p. of <ets>masticare</ets> to chew, prob. fr.
<ets>mastiche</ets> mastic. See <er>Mastic</er>.]</ety> <def>To grind or
crush with, or as with, the teeth and prepare for swallowing and
digestion; to chew; <as>as, to <ex>masticate</ex> food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticater</ent><br/
<hw>Mas"ti*ca`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
masticates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastication</ent><br/
<hw>Mas`ti*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>masticatio</ets>: cf. F. <ets>mastication</ets>.]</ety> <def>The
act or operation of masticating; chewing, as of food.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mastication</qex> is a necessary preparation of solid
aliment, without which there can be no good digestion.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticator</ent><br/
<hw>Mas"ti*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who masticates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A machine for cutting meat into fine pieces for
toothless people; also, a machine for cutting leather, India rubber, or
similar tough substances, into fine pieces, in some processes of
manufacture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticatory</ent><br/
<hw>Mas"ti*ca*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>masticatoire</ets>.]</ety> <def>Chewing; adapted to perform the
office of chewing food.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticatory</ent><br/
<hw>Mas"ti*ca*to*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(<?/)</pr>.</plu> <fld>(Med.)</fld> <def>A
substance to be chewed to increase the saliva.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastich</ent><br/
<hw>Mas"tich</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mastic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticin</ent><br/
<hw>Mas"ti*cin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A white, amorphous, tenacious substance resembling caoutchouc, and
obtained as an insoluble residue of mastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masticot</ent><br/
<hw>Mas"ti*cot</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Massicot.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastiff</ent><br/
<hw>Mas"tiff</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mastiffs</plw> <pr>(<?/)</pr>. [<plw>Mastives</plw> is irregular
and unusual.]</plu> <ety>[Prob. fr. Prov. E. <ets>masty</ets>, adj.,
large, n., a great dog, prob. fr. <ets>mast</ets> fruit, and hence,
lit., fattened with mast. There is perh. confusion with OF.
<ets>mestif</ets> mongrel; cf. also F. <ets>m<acir/tin</ets> mastiff,
OF. <ets>mastin</ets>.]</ety> <fld>(Zool.)</fld> <def>A breed of large
dogs noted for strength and courage. There are various strains,
differing in form and color, and characteristic of different
countries.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mastiff bat</b></col> <fld>(Zool.)</fld> <cd>, any bat of
the genus <gen>Molossus</gen>; so called because the face somewhat
resembles that of a mastiff.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastigophora</ent><br/
<hw>Mas"ti*go*phor`a</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.,
fr. Gr. <grk>ma`stix</grk>, <grk>ma`stigos</grk>, a whip +
<grk>fe`rein</grk> to bear.]</ety> <fld>(Zool.)</fld> <def>A phylum of
protozoans the kingdom <kingdom>Protista</kingdom>, consisting mainly of
free-living flagellated unicellular organisms, lacking photosynthetic
capability. Some members are pathogenic in man.</def><br/
[<source>PJC</source>]</p>

<p><ent>mastigopod</ent><br/
<hw>mas"ti*go*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Mastigopoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastigopoda</ent><br/
\'d8<hw>Mas`ti*gop"o*da</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. Gr. <grk>ma`stix</grk>, <grk>ma`stigos</grk>, a whip +
<grk>poy`s</grk>, <grk>podo`s</grk>, foot.]</ety> <fld>(Zool.)</fld>
<def>Formerly considered identical to the Infusoria, now distinguished
from that group, which has been reordered. See
<er>Mastigophora</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mastigure</ent><br/
<hw>Mas"ti*gure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>ma`stix</grk>, <grk>ma`stigos</grk>, a scourge + <?/ tail.]</ety>
<fld>(Zool.)</fld> <def>Any one of several large spiny-tailed lizards of
the genus <gen>Uromastix</gen>. They inhabit Southern Asia and North
Africa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masting</ent><br/
<hw>Mast"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The act or process of putting a mast or masts into a vessel; also,
the scientific principles which determine the position of masts, and the
mechanical methods of placing them.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Masting house</b></col> <fld>(Naut.)</fld>, <cd>a large
building, with suitable mechanism overhanging the water, used for
stepping and unstepping the masts of vessels.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastitis</ent><br/
\'d8<hw>Mas*ti"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>masto`s</grk> breast + <ets>-itis</ets>.]</ety> <fld>(Med.)</fld>
<def>Inflammation of the breast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastless</ent><br/
<hw>Mast"less</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See 1st
<er>Mast</er>.]</ety> <def>Bearing no mast; <as>as, a <ex>mastless</ex>
oak or beech</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastless</ent><br/
<hw>Mast"less</hw>, <pos>a.</pos> <ety>[See 2d <er>Mast</er>.]</ety>
<def>Having no mast; <as>as, a <ex>mastless</ex> vessel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 901 --></p>

<p><ent>Mastlin</ent><br/
<hw>Mast"lin</hw> <pr>(m<acr/st"l<icr/n)</pr>, <pos>n.</pos> <def>See
<er>Maslin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastodon</ent><br/
<hw>Mas"to*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>masto`s</grk> the breast + <grk>'odoy`s</grk>,
<grk>'odo`ntos</grk>, a tooth. So called from the conical projections
upon its molar teeth.]</ety> <fld>(Paleon.)</fld> <def>An extinct genus
of mammals closely allied to the elephant, but having less complex molar
teeth, and often a pair of lower, as well as upper, tusks, which are
incisor teeth. The species were mostly larger than elephants, and their
remains occur in nearly all parts of the world in deposits ranging from
Miocene to late Quaternary time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastodonsaurus</ent><br/
\'d8<hw>Mas`to*don*sau"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. E. <ets>Mastodon</ets> + Gr. <grk>say^ros</grk> a lizard.]</ety>
<fld>(Paleon.)</fld> <def>A large extinct genus of labyrinthodonts,
found in the European Triassic rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastodontic</ent><br/
<hw>Mas`to*don"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or resembling, a mastodon; <as>as, <ex>mastodontic</ex>
dimensions</as>.</def> <rj><au>Everett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastodyny</ent><br/
<ent>Mastodynia</ent><br/
<mhw>\'d8<hw>Mas`to*dyn"i*a</hw> <pr>(?)</pr>, <hw>Mas*tod"y*ny</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[NL. <ets>mastodynia</ets>, fr.
Gr. <grk>masto`s</grk> the breast + <?/ pain.]</ety> <fld>(Med.)</fld>
<def>Pain occurring in the mamma or female breast, -- a form of
neuralgia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastoid</ent><br/
<hw>Mas"toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/;
<grk>masto`s</grk> the breast + <grk>e'i^dos</grk> form: cf. F.
<ets>masto<ium/de</ets>.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd>
<def>Resembling the nipple or the breast; -- applied specifically to a
process of the temporal bone behind the ear.</def> <sd>(b)</sd>
<def>Pertaining to, or in the region of, the mastoid process;
mastoidal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastoidal</ent><br/
<hw>Mas*toid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Mastoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastoiditis</ent><br/
<hw>Mas`toid*i*tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Mastoid</er>, and <er>-itis</er>.]</ety> <fld>(Med.)</fld>
<def>Inflammation in the mastoid process of the temporal bone.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mastology</ent><br/
<hw>Mas*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>masto`s</grk> the breast + <ets>-logy</ets>: cf. F.
<ets>mastologie</ets>.]</ety> <def>The natural history of
Mammalia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mastotermes</ent><br/
<hw>Mastotermes</hw> <pos>prop. n.</pos> <def>A primitive genus of
termites, mostly extinct; sometimes considered the most primitive
isopterans.</def><br/
<syn><b>Syn. --</b> genus <gen>Mastotermes</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mastotermitidae</ent><br/
<hw>Mastotermitidae</hw> <pos>prop. n.</pos> <def>A natural family
comprising primitive termites.</def><br/
<syn><b>Syn. --</b> family <fam>Mastotermitidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mastress</ent><br/
<hw>Mas"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mistress.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>masturbate</ent><br/
<hw>masturbate</hw> <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>masturbated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>masturbating</conjf>.]</vmorph> <def>To achieve sexual
gratification by stimulating one's own sexual organs, without the aid of
a partner; -- typically to the point of orgasm.</def> --
<wordforms><wf>masturbator</wf>, <pos>n.</pos></wordforms><br/
<syn><b>Syn. --</b> wank, she-bop, jack off, jerk off, whack off, beat
the meat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>masturbation</ent><br/
<hw>mas`tur*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>masturbatus</ets>, p. p. of <ets>masturbari</ets> to practice
onanism: cf. F. <ets>masturbation</ets>.]</ety> <def>The act of
masturbating; sexual self-gratification; onanism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masty</ent><br/
<hw>Mast"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See 1st
<er>Mast</er>.]</ety> <def>Full of mast; abounding in acorns,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Masula boat</ent><br/
<hw>Ma*su"la boat`</hw> <pr>(?)</pr>. <def>Same as <er>Masoola
boat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mat</ent><br/
<hw>Mat</hw> <pr>(m<acr/t)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Matte</er>.]</ety> <def>A name given by coppersmiths to an alloy of
copper, tin, iron, etc., usually called <xex>white metal</xex>.</def>
<altsp>[Written also <asp>matt</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mat</ent><br/
<hw>Mat</hw>, <pos>a.</pos> <ety>[OF. See 4th <er>Mate</er>.]</ety>
<def>Cast down; dejected; overthrown; slain.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When he saw them so piteous and so <qex>maat</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mat</ent><br/
<hw>Mat</hw>, <pos>n.</pos> <ety>[AS. <ets>matt</ets>, <ets>meatt</ets>,
fr. L. <ets>matta</ets> a mat made of rushes.]</ety> <sn>1.</sn> <def>A
thick flat fabric of sedge, rushes, flags, husks, straw, hemp, or
similar material, placed on the floor and used for wiping and cleaning
shoes at the door, for covering the floor of a hall or room to protect
its surface, and for other purposes.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Any similar flat object made of fabric or other
material, such as rubber or plastic, placed flat on a surface for
various uses, as for covering plant houses, putting beneath dishes or
lamps on a table, securing rigging from friction, and the
like.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>Anything growing thickly, or closely interwoven, so
as to resemble a mat in form or texture; <as>as, a <ex>mat</ex> of
weeds; a <ex>mat</ex> of hair.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An ornamental border made of paper, pasteboard,
metal, etc., put under the glass which covers a framed picture; <as>as,
the <ex>mat</ex> of a daguerreotype</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mat grass</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd> <cd>A
low, tufted, European grass (<spn>Nardus stricta</spn>)</cd>.
<sd>(b)</sd> <cd>Same as <er>Matweed</er>.</cd> -- <col><b>Mat
rush</b></col> <fld>(Bot.)</fld>, <cd>a kind of rush (<spn>Scirpus
lacustris</spn>) used in England for making mats.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mat</ent><br/
<hw>Mat</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Matted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Matting</conjf>.]</vmorph> <sn>1.</sn> <def>To cover or lay with
mats.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To twist, twine, or felt together; to interweave
into, or like, a mat; to entangle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And o'er his eyebrows hung his <qex>matted</qex> hair.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mat</ent><br/
<hw>Mat</hw>, <pos>v. i.</pos> <def>To grow thick together; to become
interwoven or felted together like a mat, as hair when wetted with a
sticky substance; <as>as, a long-haired cat whose fur is
<ex>matted</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Matabeles</ent><br/
<ent>Matabele</ent><br/
<mhw>{ <hw>Mat`a*be"le</hw> <pr>(?)</pr>, <it>or</it>
<hw>Mat`a*be"les</hw> <pr>(?)</pr> }</mhw>, <pos>prop. n. pl.</pos>,
<sing><it>sing.</it> <singw>Matabele</singw>.</sing> <altsp>[Written
also <asp>Matabili</asp>.]</altsp> <fld>(Ethnol.)</fld> <def>A warlike
South African Kaffir tribe.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Matachin</ent><br/
\'d8<hw>Ma`ta*chin"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>An old dance with swords and bucklers; a sword dance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mataco</ent><br/
<hw>Mat"a*co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The three-banded armadillo (<spn>Tolypeutis tricinctus</spn>). See
<xex>Illust.</xex> under <er>Loricata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matadore</ent><br/
<ent>Matador</ent><br/
<mhw>{ <hw>Mat"a*dor</hw>, <hw>Mat"a*dore</hw>}</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Sp. <ets>matador</ets>, prop., a killer, fr.
<ets>matar</ets> to kill, L. <ets>mactare</ets> to sacrifice,
kill.]</ety> <sn>1.</sn> <def>The killer; the man appointed to kill the
bull in bullfights; a bullfighter; a toreador.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Card Playing)</fld> <def>In the game of quadrille
or omber, the three principal trumps, the ace of spades being the first,
the ace of clubs the third, and the second being the deuce of a black
trump or the seven of a red one.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When Lady Tricksey played a four,<br/
You took it with a <qex>matadore</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>[Skat]</fld> <def>The jack of clubs, or any other
trump held in sequence with it, whether by the player or by his
adversaries.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>A certain game of dominoes in which four dominoes
(the 4-3, 5-2, 6-1, and double blank), called <xex>matadors</xex>, may
be played at any time in any way.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Matagasse</ent><br/
<hw>Mat`a*gasse"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A shrike or butcher bird; -- called also
<altname>mattages</altname>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matajuelo</ent><br/
<hw>Ma`ta*jue"lo</hw> <pr>(m<aum/`t<adot/*hw<amac/"l<omac/; 239)</pr>,
<pos>n.</pos> <ety>[Cf. Sp. <ets>matajud<iacute/o</ets> a kind of
fish.]</ety> <def>A large squirrel fish (<spn>Holocentrus
ascensionis</spn>) of Florida and the West Indies.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Matajuelo blanco</ent><br/
<hw>Ma`ta*jue"lo blan"co</hw> <pr>(m<aum/`t<adot/*hw<amac/"l<omac/
bl<aum/<nsm/"k<omac/)</pr>. <ety>[Sp. <ets>blanco</ets> white.]</ety>
<def>A West Indian food fish (<spn>Malacanthus plumieri</spn>) related
to the tilefish.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Matamata</ent><br/
\'d8<hw>Ma`ta*ma"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.]</ety>
<fld>(Zool.)</fld> <def>The bearded tortoise (<spn>Chelys
fimbriata</spn>) of South American rivers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matanza</ent><br/
<hw>Ma*tan"za</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., slaughter, fr.
<ets>matar</ets> to kill.]</ety> <def>A place where animals are
slaughtered for their hides and tallow.</def> <mark>[Western U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match</ent><br/
<hw>Match</hw> <pr>(m<acr/ch)</pr>, <pos>n.</pos> <ety>[OE.
<ets>macche</ets>, F. <ets>m<egrave/che</ets>, F.
<ets>m<egrave/che</ets>, fr. L. <ets>myxa</ets> a lamp nozzle, Gr.
<grk>my`xa</grk> mucus, nostril, a lamp nozzle. Cf.
<er>Mucus</er>.]</ety> <def>Anything used for catching and retaining or
communicating fire, made of some substance which takes fire readily, or
remains burning some time; esp., a small strip or splint of wood or
cardboard dipped at one end in a substance which can be easily ignited
by friction, as a preparation of phosphorus or chlorate of
potassium.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Match tub</b></col>, <cd>a tub with a perforated cover
for holding slow matches for firing cannon, esp. on board ship. The tub
contains a little water in the bottom, for extinguishing sparks from the
lighted matches.</cd> -- <col><b>Quick match</b></col>, <cd>threads of
cotton or cotton wick soaked in a solution of gunpowder mixed with gum
arabic and boiling water and afterwards strewed over with mealed powder.
It burns at the rate of one yard in thirteen seconds, and is used as
priming for heavy mortars, fireworks, etc.</cd> -- <col><b>Slow
match</b></col>, <cd>slightly twisted hempen rope soaked in a solution
of limewater and saltpeter or washed in a lye of water and wood ashes.
It burns at the rate of four or five inches an hour, and is used for
firing cannon, fireworks, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match</ent><br/
<hw>Match</hw>, <pos>n.</pos> <ety>[OE. <ets>macche</ets>, AS.
<ets>gemaecca</ets>; akin to <ets>gemaca</ets>, and to OS.
<ets>gimako</ets>, OHG. <ets>gimah</ets> fitting, suitable, convenient,
Icel. <ets>mark</ets> suitable, <ets>maki</ets> mate, Sw.
<ets>make</ets>, Dan. <ets>mage</ets>; all from the root of E.
<ets>make</ets>, v. See <er>Make</er> mate, and <er>Make</er>,
<pos>v.</pos>, and cf. <er>Mate</er> an associate.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A person or thing equal or similar to another; one
able to mate or cope with another; an equal; a mate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Government . . . makes an innocent man, though of the lowest rank,
a <qex>match</qex> for the mightiest of his fellow subjects.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bringing together of two parties suited to one
another, as for a union, a trial of skill or force, a contest, or the
like</def>; <specif>specifically:</specif> <sd>(a)</sd> <def>A contest
to try strength or skill, or to determine superiority; a sporting
contest; an emulous struggle.</def> <ldquo/Many a warlike
<xex>match</xex>.<rdquo/ <au>Drayton.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>A solemn <qex>match</qex> was made; he lost the prize.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>A matrimonial union; a marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An agreement, compact, etc.</def> <ldquo/Thy hand
upon that <xex>match</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Love doth seldom suffer itself to be confined by other
<qex>matches</qex> than those of its own making.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A candidate for matrimony; one to be gained in
marriage.</def> <ldquo/She . . . was looked upon as the richest
<xex>match</xex> of the West.<rdquo/ <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Equality of conditions in contest or competition, or
one who provides equal competition to another in a contest; <as>as, he
had no <ex>match</ex> as a swordsman within the city</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It were no <qex>match</qex>, your nail against his horn.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Suitable combination or bringing together; that
which corresponds or harmonizes with something else; <as>as, the carpet
and curtains are a <ex>match</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Founding)</fld> <def>A perforated board, block of
plaster, hardened sand, etc., in which a pattern is partly imbedded when
a mold is made, for giving shape to the surfaces of separation between
the parts of the mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Match boarding</b></col> <fld>(Carp.)</fld>, <cd>boards
fitted together with tongue and groove, or prepared to be so fitted; a
surface composed of match boarding. See <er>matchboard</er>.</cd> --
<col><b>Match game</b></col>, <cd>a game arranged as a test of
superiority.</cd> -- <col><b>Match plane</b></col> <fld>(Carp.)</fld>,
<cd>either of the two planes used to shape the edges of boards which are
joined by grooving and tonguing.</cd> -- <col><b>Match plate</b></col>
<fld>(Founding)</fld>, <cd>a board or plate on the opposite sides of
which the halves of a pattern are fastened, to facilitate molding.</cd>
<au>Knight.</au> -- <col><b>Match wheel</b></col> <fld>(Mach.)</fld>,
<cd>a cogwheel of suitable pitch to work with another wheel;
specifically, one of a pair of cogwheels of equal size.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match</ent><br/
<hw>Match</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Matched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Matching</conjf>.]</vmorph> <sn>1.</sn> <def>To be a mate or
match for; to be able to complete with; to rival successfully; to
equal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No settled senses of the world can <qex>match</qex><br/
The pleasure of that madness.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with its match; to bring a match, or
equal, against; to show an equal competitor to; to set something in
competition with, or in opposition to, as equal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No history or antiquity can <qex>match</qex>is policies and his
conduct.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To oppose as equal; to contend successfully
against.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eternal might<br/
To <qex>match</qex> with their inventions they presumed<br/
So easy, and of his thunder made a scorn.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make or procure the equal of, or that which is
exactly similar to, or corresponds with; <as>as, to <ex>match</ex> a
vase or a horse; to <ex>match</ex> cloth.</as></def>
<ldquo/<xex>Matching</xex> of patterns and colors.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make equal, proportionate, or suitable; to adapt,
fit, or suit (one thing <xex>to</xex> another).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let poets <qex>match</qex> their subject to their strength.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To marry; to give in marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A senator of Rome survived,<br/
Would not have <qex>matched</qex> his daughter with a king.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To fit together, or make suitable for fitting
together; specifically, to furnish with a tongue and a groove, at the
edges; <as>as, to <ex>match</ex> boards</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Matching machine</b></col>, <cd>a planing machine for
forming a tongue or a groove on the edge of a board.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match</ent><br/
<hw>Match</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be united in
marriage; to mate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I hold it a sin to <qex>match</qex> in my kindred.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let tigers <qex>match</qex> with hinds, and wolves with sheep.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be of equal, or similar, size, figure, color, or
quality; to tally; to suit; to correspond; <as>as, these vases
<ex>match</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matchable</ent><br/
<hw>Match"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
matched; comparable on equal conditions; adapted to being joined
together; correspondent.</def> -- <wordforms><wf>Match"a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir Walter Raleigh . . . is <qex>matchable</qex> with the best of
the ancients.</q> <rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>matchboard</ent><br/
<hw>matchboard</hw> <pos>n.</pos> <def>A board that has a groove cut
into one edge and a tongue cut into the other so they fit tightly
together (as in a floor); see <cref>match boarding</cref>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>matchbook</ent><br/
<hw>matchbook</hw> <pos>n.</pos> <def>A small folder of paper safety
matches.</def><br/
<syn><b>Syn. --</b> match book.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>match box</ent><br/
<ent>matchbox</ent><br/
<mhw><hw>match"box`</hw>, <hw>match" box`</hw></mhw> <pos>n.</pos>
<def>a box for holding matches. See first <er>match</er>,
<pos>n.</pos></def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>matchbush</ent><br/
<hw>match"bush`</hw> <pos>n.</pos> <def>any of several plants of the
genus <gen>Gutierrezia</gen> having tiny matchlike
flowerheads.</def><br/
<syn><b>Syn. --</b> matchweed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Match-cloth</ent><br/
<hw>Match"-cloth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coarse
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match-coat</ent><br/
<hw>Match"-coat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coat made of
match-cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matcher</ent><br/
<hw>Match"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, matches; a matching machine. See under 3d
<er>Match</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match game</ent><br/
<hw>Match game</hw>. <def>A game arranged as a test of superiority;
also, one of a series of such games.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>matchet</ent><br/
<hw>matchet</hw> <pos>n.</pos> <def>a large heavy knife used in Central
and South America as a weapon or for cutting vegetation; usually called
<altname>machete</altname>.</def><br/
<syn><b>Syn. --</b> machete, panga.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>matching</ent><br/
<hw>matching</hw> <pos>adj.</pos> <sn>1.</sn> <def>having identical or
closely similar appearance or properties; <as>as, a pair of
<ex>matching</ex> candlesticks</as>.</def><br/
<syn><b>Syn. --</b> duplicate, twin(prenominal), twinned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Harmonious and pleasing in appearance when used
together; <as>as, a <ex>matching</ex> skirt and blouse</as>.</def><br/
<syn><b>Syn. --</b> coordinated; color-coordinated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matchless</ent><br/
<hw>Match"less</hw>, <pos>a.</pos> <ety>[Cf.
<er>Mateless</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Having no equal; unequaled.</def> <ldquo/A
<xex>matchless</xex> queen.<rdquo/ <rj><au>Waller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unlike each other; unequal; unsuited.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Matchless</xex> ears.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Match"less*ly</wf>, <pos>adv.</pos> --
<wf>Match"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matchlock</ent><br/
<hw>Match"lock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An old form of
gunlock containing a match for firing the priming; hence, a musket fired
by means of a match.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matchmaker</ent><br/
<hw>Match"mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who makes matches for burning or kinding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who tries to bring about marriages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matchmaking</ent><br/
<hw>Match"mak`ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or
process of making matches for kindling or burning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or process of trying to bring about a
marriage for others.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matchmaking</ent><br/
<hw>Match"mak`ing</hw>, <pos>a.</pos> <def>Busy in making or contriving
marriages; <as>as, a <ex>matchmaking</ex> woman</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Match play</ent><br/
<hw>Match play</hw>. <fld>(Golf)</fld> <def>Play in which the score is
reckoned by counting the holes won or lost by each side; --
distinguished from <contr>medal play</contr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>matchwood</ent><br/
<hw>matchwood</hw> <pos>n.</pos> <sn>1.</sn> <def>wood in small pieces
or splinters; <as>as, the vessel was beaten to <ex>matchwood</ex> on the
rocks</as>.</def> <wns>[wns=1 & 3]</wns><br/
<syn><b>Syn. --</b> splinters.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Wood suitable for making matchsticks.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mate</ent><br/
\'d8<hw>Ma"te</hw> <pr>(m<aum/"t<asl/)</pr>, <pos>n.</pos>
<ety>[Sp.]</ety> <def>The Paraguay tea, being the dried leaf of the
Brazilian holly (<spn>Ilex Paraguensis</spn>). The infusion has a
pleasant odor, with an agreeable bitter taste, and is much used for tea
in South America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mate</ent><br/
<hw>Mate</hw> <pr>(m<amac/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>mat</ets>, abbrev. fr. <eacute/chec et <ets>mat</ets>. See
<er>Checkmate</er>.]</ety> <fld>(Chess)</fld> <def>Same as
<er>Checkmate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mate</ent><br/
<hw>Mate</hw>, <pos>a.</pos> <def>See 2d <er>Mat</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mate</ent><br/
<hw>Mate</hw>, <pos>v. t.</pos> <ety>[F. <ets>mater</ets> to fatigue,
enfeeble, humiliate, checkmate. See <er>Mate</er> checkmate.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To confuse; to confound.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To checkmate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mate</ent><br/
<hw>Mate</hw>, <pos>n.</pos> <ety>[Perhaps for older <ets>make</ets> a
companion; cf. also OD. <ets>maet</ets> companion, mate, D.
<ets>maat</ets>. Cf. <er>Make</er> a companion, <er>Match</er> a
mate.]</ety> <sn>1.</sn> <def>One who customarily associates with
another; a companion; an associate; any object which is associated or
combined with a similar object.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, specifically, a husband or wife; and among
the lower animals, one of a pair associated for propagation and the care
of their young.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A suitable companion; a match; an equal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye knew me once no <qex>mate</qex><br/
For you; there sitting where you durst not soar.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>An officer in a merchant vessel
ranking next below the captain. If there are more than one bearing the
title, they are called, respectively, <xex>first mate</xex>, <xex>second
mate</xex>, <xex>third mate</xex>, etc. In the navy, a subordinate
officer or assistant; <as>as, master's <ex>mate</ex>; surgeon's
<ex>mate</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mate</ent><br/
<hw>Mate</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mating</conjf>.]</vmorph> <sn>1.</sn> <def>To match; to
marry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If she be <qex>mated</qex> with an equal husband.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To match one's self against; to oppose as equal; to
compete with.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no passion in the mind of man so weak but it
<qex>mates</qex> and masters the fear of death.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I, . . . in the way of loyalty and truth, . . .<br/
Dare <qex>mate</qex> a sounder man than Surrey can be.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To breed; to bring (animals) together for the
purpose of breeding; <as>as, she <ex>mated</ex> a doberman with a German
shepherd</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>To join together; to fit together; to connect; to
link; <as>as, he <ex>mated</ex> a saw blade to a broom handle to cut
inaccessible branches.</as></def><br/
[<source>PJC</source>]</p>

<p><ent>Mate</ent><br/
<hw>Mate</hw>, <pos>v. i.</pos> <def>To be or become a mate or mates,
especially in sexual companionship; <as>as, some birds <ex>mate</ex> for
life; this bird will not <ex>mate</ex> with that one.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mated</ent><br/
<hw>mated</hw> <pos>adj.</pos> <sn>1.</sn> <def>Brought together for
sexual activity; bred; -- of animals.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Sorted into pairs of identical size, color, or other
properties; -- used of gloves, socks, etc.</def><br/
<syn><b>Syn. --</b> paired.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>Same as <er>married</er>. Opposite of
<ant>unmarried</ant>; <as>as, they were a devoted couple, <ex>mated</ex>
for life</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matelasse</ent><br/
\'d8<hw>Mate`las`s<eacute/"</hw> <pr>(m<adot/`l<adot/`s<asl/")</pr>,
<pos>a.</pos> <ety>[F., p.p. of <ets>matelasser</ets> to cushion, to
cover as with a mattress, fr. <ets>matelas</ets> mattress. See
<er>Mattress</er>.]</ety> <def>Ornamented by means of an imitation or
suggestion of quilting, the surface being marked by depressed lines
which form squares or lozenges in relief; <as>as,
<ex>matelass<eacute/</ex> silks</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Matelasse</ent><br/
\'d8<hw>Mate`las`s<eacute/"</hw>, <pos>n.</pos> <def>A quilted
ornamented dress fabric of silk or silk and wool.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mateless</ent><br/
<hw>Mate"less</hw>, <pos>a.</pos> <ety>[Cf. <er>Matchless</er>.]</ety>
<def>Having no mate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matelotte</ent><br/
<ent>Matelote</ent><br/
<mhw>{ <hw>Mat"e*lote</hw> <pr>(m<acr/t"<esl/*l<omac/t)</pr>,
<hw>Mat"e*lotte</hw> <pr>(m<acr/t"<esl/*l<ocr/t)</pr> }</mhw>,
<pos>n.</pos> <ety>[F. <ets>matelote</ets>, fr. <ets>matelot</ets> a
sailor; properly, a dish such as a sailors prepare.]</ety> <sn>1.</sn>
<def>A stew, commonly of fish, flavored with wine, and served with a
wine sauce containing onions, mushrooms, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>An old dance of sailors, in double time, and
somewhat like a hornpipe.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mateology</ent><br/
<hw>Ma`te*ol"o*gy</hw> <pr>(m<amac/`t<esl/*<ocr/l"<osl/*j<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>mataiologi`a</grk>; <grk>ma`taios</grk>
useless, vain + <grk>lo`gos</grk> discourse: cf. F.
<ets>mat<eacute/ologie</ets>.]</ety> <def>A vain, unprofitable discourse
or inquiry.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mateotechny</ent><br/
<hw>Ma`te*o*tech"ny</hw> <pr>(m<amac/`t<esl/*<osl/*t<ecr/k"n<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>mataiotechni`a</grk>; <grk>ma`taios</grk>
vain + <grk>te`chnh</grk> art, science.]</ety> <def>Any unprofitable
science.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mater</ent><br/
\'d8<hw>Ma"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., mother. See
<er>Mother</er>.]</ety> <def>See <er>Alma mater</er>, <er>Dura
mater</er>, and <er>Pia mater</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Material</ent><br/
<hw>Ma*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>materialis</ets>, fr. <ets>materia</ets> stuff, matter: cf. F.
<ets>mat<eacute/riel</ets>. See <er>Matter</er>, and cf.
<er>Mat<eacute/riel</er>.]</ety> <br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Consisting of matter; not spiritual; corporeal;
physical; <as>as, <ex>material</ex> substance or bodies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>material</qex> elements of the universe.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Pertaining to, or affecting,
the physical nature of man, as distinguished from the
<contr>mental</contr> or <contr>moral</contr> nature; relating to the
bodily wants, interests, and comforts; <as>as, <ex>material</ex>
well-being; <ex>material</ex> comforts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of solid or weighty character; not insubstantial; of
consequence; not be dispensed with; important; significant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Discourse, which was always <qex>material</qex>, never
trifling.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall, in the account of simple ideas, set down only such as are
most <qex>material</qex> to our present purpose.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Logic.)</fld> <def>Pertaining to the matter, as
opposed to the form, of a thing. See <er>Matter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Material cause</b></col>. <cd>See under
<er>Cause</er>.</cd> -- <col><b>Material evidence</b></col>
<fld>(Law)</fld>, <cd>evidence which conduces to the proof or disproof
of a relevant hypothesis.</cd> <au>Wharton.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Corporeal; bodily; important; weighty; momentous;
essential.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Material</ent><br/
<hw>Ma*te"ri*al</hw>, <pos>n.</pos> <def>The substance or matter of
which anything is made or may be made.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raw material</b></col>, <cd>any crude, unfinished, or
elementary materials that are adapted to use only by processes of
skilled labor. <as>Cotton, wool, ore, logs, etc., are <ex>raw
material</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Material</ent><br/
<hw>Ma*te"ri*al</hw>, <pos>v. t.</pos> <def>To form from matter; to
materialize.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materialism</ent><br/
<hw>Ma*te"ri*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mat<eacute/rialisme</ets>.]</ety> <sn>1.</sn> <def>The doctrine of
materialists; materialistic views and tenets; called also
<altname>philosophical materialism</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The irregular fears of a future state had been supplanted by the
<qex>materialism</qex> of Epicurus.</q>
<rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The tendency to give undue importance to material
interests as contrasted with spiritual concerns; devotion to the
material nature and its wants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Material substances in the aggregate; matter.</def>
<mark>[R. & Obs.]</mark> <rj><au>A. Chalmers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>philosophical materialism</b></col> <cd>The theory that
matter and energy are the only objects existing within the universe, and
that mental and spiritual phenomena are explainable as functions of the
nervous system of people. Same as <er>materialism</er>{1}.</cd></cs><br/
[<source>PJC</source>]</p>

<p><-- p. 902 --></p>

<p><ent>Materialist</ent><br/
<hw>Ma*te"ri*al*ist</hw>
<pr>(m<adot/*t<emac/"r<icr/*<ait/l*<icr/st)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>mat<eacute/rialiste</ets>.]</ety> <sn>1.</sn> <def>One
who denies the existence of spiritual substances or agents, and
maintains that spiritual phenomena, so called, are the result of some
peculiar organization of matter. A believer in <cref>philosophical
materialism</cref>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>One who holds to the existence of matter, as
distinguished from the idealist, who denies it.</def>
<rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materialistical</ent><br/
<ent>Materialistic</ent><br/
<mhw>{ <hw>Ma*te`ri*al*is"tic</hw> <pr>(?)</pr>,
<hw>Ma*te`ri*al*is"tic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Of or pertaining to materialism or materialists; of the nature of
materialism.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But to me his very spiritualism seemed more
<qex>materialistic</qex> than his physics.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Primarily concerned with material objects and
worldly activities, as contrasted with spiritual, moral or philosophical
concerns; especially, concerned primarily with gaining money and the
things that money can buy.</def><br/
[<source>PJC</source>]</p>

<p><ent>Materiality</ent><br/
<hw>Ma*te`ri*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mat<eacute/rialit<eacute/</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The quality or state of being material; material
existence; corporeity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Importance; <as>as, the <ex>materiality</ex> of
facts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materialization</ent><br/
<hw>Ma*te`ri*al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of materializing, or the state of being materialized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materialize</ent><br/
<hw>Ma*te"ri*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Materialized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Materializing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>mat<eacute/rialiser</ets>.]</ety> <sn>1.</sn> <def>To invest with
material characteristics; to make perceptible to the senses; hence, to
present to the mind through the medium of material objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Having with wonderful art and beauty <qex>materialized</qex>, if I
may so call it, a scheme of abstracted notions, and clothed the most
nice, refined conceptions of philosophy in sensible images.</q>
<rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To regard as matter; to consider or explain by the
laws or principles which are appropriate to matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to assume a character appropriate to
material things; to occupy with material interests; <as>as, to
<ex>materialize</ex> thought</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Spiritualism)</fld> <def>To make visible in, or as
in, a material form; -- said of spirits.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A female spirit form temporarily <qex>materialized</qex>, and not
distinguishable from a human being.</q> <rj><qau>Epes
Sargent.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materialize</ent><br/
<hw>Ma*te"ri*al*ize</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To appear as
a material form; to take substantial shape.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come into existence; <as>as, the promised
donations never <ex>materialized</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Materially</ent><br/
<hw>Ma*te"ri*al*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In the state
of matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do not mean that anything is separable from a body by fire that
was not <qex>materially</qex> preexistent in it.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In its essence; substantially.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An ill intention is certainly sufficient to spoil . . . an act in
itself <qex>materially</qex> good.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In an important manner or degree; essentially;
<as>as, it <ex>materially</ex> concerns us to know the real motives of
our actions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materialness</ent><br/
<hw>Ma*te"ri*al*ness</hw>, <pos>n.</pos> <def>The state of being
material.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materia medica</ent><br/
\'d8<hw>Ma*te"ri*a med"i*ca</hw> <pr>(?)</pr>. <ety>[L. See
<er>Matter</er>, and <er>Medical</er>.]</ety> <sn>1.</sn> <def>Material
or substance used in the composition of remedies; -- a general term for
all substances used as curative agents in medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That branch of medical science which treats of the
sources, nature and properties of all the substances that are employed
for the cure of diseases, primarily with natural preparations, rather
than pure or synthetic medicines; pharmacognosy.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Materiarian</ent><br/
<hw>Ma*te`ri*a"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>materiarius</ets>.]</ety> <def>See <er>Materialist</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materiated</ent><br/
<ent>Materiate</ent><br/
<mhw>{ <hw>Ma*te"ri*ate</hw> <pr>(?)</pr>, <hw>Ma*te"ri*a`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>materiatus</ets>, p.
p. of <ets>materiare</ets> to build of wood.]</ety> <def>Consisting of
matter.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materiation</ent><br/
<hw>Ma*te`ri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>materiatio</ets> woodwork.]</ety> <def>Act of forming matter.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materiel</ent><br/
\'d8<hw>Ma`t<eacute/`ri`el"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
See <er>Material</er>.]</ety> <def>Those objects in a complex system
which constitute the <xex>materials</xex>, or instruments employed, in
distinction from the <xex>personnel</xex>, or men; for example, the
buildings, libraries, and apparatus of a college, in distinction from
its officers; -- used in a collective sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <fld>(Military)</fld>
<def>The arms, munitions, baggage, equipment, provisions, etc., of an
army.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Materious</ent><br/
<hw>Ma*te"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Material</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maternal</ent><br/
<hw>Ma*ter"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>maternel</ets>, L. <ets>maternus</ets>, fr. <ets>mater</ets>
mother. See <er>Mother</er>.]</ety> <def>Of or pertaining to a mother;
becoming to a mother; motherly; <as>as, <ex>maternal</ex> love;
<ex>maternal</ex> tenderness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Motherly</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>maternalistic</ent><br/
<hw>maternalistic</hw> <pos>adj.</pos> <def>showing maternal instincts;
behaving as a mother should; motherly.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maternally</ent><br/
<hw>Ma*ter"nal*ly</hw>, <pos>adv.</pos> <def>In a motherly
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maternity</ent><br/
<hw>Ma*ter"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>maternit<eacute/</ets>, LL. <ets>maternitas</ets>.]</ety>
<sn>1.</sn> <def>The state of being a mother; motherhood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The character of a mother; maternal quality;
motherliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The maternity ward; the maternity department of a
hospital.</def><br/
[<source>PJC</source>]</p>

<p><ent>maternity</ent><br/
<hw>ma*ter"ni*ty</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to childbirth or the period during which a woman is pregnant;
<as>as, <ex>maternity</ex> care; a <ex>maternity</ex>
hospital</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>For use during pregnancy; <as>as, a
<ex>maternity</ex> outfit</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>maternity ward</ent><br/
<hw>ma*ter"ni*ty ward`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The section
of a hospital devoted to assisting women during childbirth and caring
for them and their newborn infants until they are released to go
home.</def><br/
[<source>PJC</source>]</p>

<p><ent>matey</ent><br/
<hw>matey</hw> <pos>adj.</pos> <def>having the relationship of friends
or pals.</def> <mark>[colloquial]</mark><br/
<syn><b>Syn. --</b> chummy, pally, palsy-walsy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matfelon</ent><br/
<hw>Mat"fel*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W.
<ets>madfelen</ets>.]</ety> <fld>(Bot.)</fld> <def>The knapweed
(<spn>Centaurea nigra</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Math</ent><br/
<hw>Math</hw> <pr>(m<acr/th)</pr>, <pos>n.</pos> <ety>[AS.
<ets>m<aemac/<edh/</ets>; akin to <ets>m<amac/wan</ets> to mow, G.
<ets>mahd</ets> math. See <er>Mow</er> to cut (grass).]</ety> <def>A
mowing, or that which is gathered by mowing; -- chiefly used in
composition; <as>as, an after<ex>math</ex></as>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The first mowing thereof, for the king's use, is wont to be sooner
than the common <qex>math</qex>.</q> <rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathematic</ent><br/
<hw>Math`e*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>math<eacute/matique</ets>, L. <ets>mathematicus</ets>, Gr. <?/
disposed to learn, belonging to learning or the sciences, especially to
mathematics, fr. <?/ that which is learned, learning, pl. <?/ things
learned, learning, science, especially mathematical science, fr. <?/,
<?/, to learn; akin to E. <ets>mind</ets>. See <er>Mind</er>.]</ety>
<def>See <er>Mathematical</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathematical</ent><br/
<hw>Math`e*mat"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Mathematic</er>.]</ety> <def>Of or pertaining to mathematics;
according to mathematics; hence, theoretically precise; accurate;
<as>as, <ex>mathematical</ex> geography; <ex>mathematical</ex>
instruments; <ex>mathematical</ex> exactness.</as></def> --
<wordforms><wf>Math`e*mat"ic*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathematician</ent><br/
<hw>Math`e*ma*ti"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>math<eacute/maticien</ets>.]</ety> <def>One versed in
mathematics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathematics</ent><br/
<hw>Math`e*mat"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>math<eacute/matiques</ets>, pl., L. <ets>mathematica</ets>, sing.,
Gr. <?/ (sc. <?/) science. See <er>Mathematic</er>, and
<er>-ics</er>.]</ety> <def>That science, or class of sciences, which
treats of the exact relations existing between quantities or magnitudes,
and of the methods by which, in accordance with these relations,
quantities sought are deducible from other quantities known or supposed;
the science of spatial and quantitative relations.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mathematics</xex> embraces three departments,
namely: <bold>1.</bold> <stype>Arithmetic</stype>. <bold>2.</bold>
<stype>Geometry</stype>, including <stype>Trigonometry</stype> and
<stype>Conic Sections</stype>. <bold>3.</bold> <stype>Analysis</stype>,
in which letters are used, including <stype>Algebra</stype>,
<stype>Analytical Geometry</stype>, and <stype>Calculus</stype>. Each of
these divisions is divided into <xex>pure</xex> or <xex>abstract</xex>,
which considers magnitude or quantity abstractly, without relation to
matter; and <xex>mixed</xex> or <xex>applied</xex>, which treats of
magnitude as subsisting in material bodies, and is consequently
interwoven with physical considerations.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mather</ent><br/
<hw>Math"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Madder</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathes</ent><br/
<hw>Math"es</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. corrupted fr.
L. <ets>anthemis</ets> camomile, Gr. <?/ .]</ety> <fld>(Bot.)</fld>
<def>The mayweed. Cf. <er>Maghet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathesis</ent><br/
\'d8<hw>Ma*the"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, from <?/, <?/, to learn.]</ety> <def>Learning; especially,
mathematics.</def> <mark>[R.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mathurin</ent><br/
<hw>Math"u*rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(R. C. Ch.)</fld>
<def>See <er>Trinitarian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matico</ent><br/
<hw>Ma*ti"co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
Peruvian plant (<spn>Piperelongatum</spn> or <spn>Artanthe
elongatum</spn>), allied to the pepper, the leaves of which are used as
a styptic and astringent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matie</ent><br/
<hw>Mat"ie</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
fat herring with undeveloped roe.</def> <altsp>[Written also
<asp>matty</asp>.]</altsp> <mark>[Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matin</ent><br/
\'d8<hw>M<acir/`tin"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<acir/tin</ets>.]</ety> <fld>(Zool.)</fld> <def>A French
mastiff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matin</ent><br/
<hw>Mat"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. fr. L.
<ets>matutinum</ets> the morning, <ets>matutinus</ets> of the morning,
<ets>Matuta</ets> the goddess of the morning. See
<er>Matutinal</er>.]</ety> <sn>1.</sn> <def>Morning.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <ety>[F. <ets>matines</ets>. See Etymol.
above.]</ety> <def>Morning worship or service; morning prayers or
songs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The winged choristers began<br/
To chirp their <qex>matins</qex>.</q> <rj><qau>Cleveland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Time of morning service; the first canonical hour in
the Roman Catholic Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matin</ent><br/
<hw>mat"in</hw>, <pos>a.</pos> <def>Of or pertaining to the morning, or
to matins; used in the morning; matutinal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matinal</ent><br/
<hw>mat"in*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to the
morning, or to matins; matutinal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matinee</ent><br/
<hw>mat`i*n<eacute/e"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from
<ets>matin</ets>. See <er>Matin</er>.]</ety> <def>A reception, or a
musical or dramatic entertainment, held in the daytime. See
<er>Soir<eacute/e</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matrass</ent><br/
<hw>ma*trass"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>matras</ets>; perh. so called from its long narrow neck; cf. OF.
<ets>matras</ets> large arrow, L. <ets>materis</ets>,
<ets>mataris</ets>, <ets>matara</ets>, a Celtic javelin, pike; of Celtic
origin.]</ety> <fld>(Chem.)</fld> <def>A round-bottomed glass flask
having a long neck; a bolthead.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matress</ent><br/
<hw>Mat"ress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mattress</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matriarch</ent><br/
<hw>ma"tri*arch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mater</ets> mother + <ets>-arch</ets>.]</ety> <sn>1.</sn> <def>The
mother and ruler of a family or of her descendants; a ruler by maternal
right.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman who dominates or is the most important
member of a group or organization; in businesses, often the founder or
owner of the largest interest.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A venerated old woman.</def><br/
[<source>PJC</source>]</p>

<p><ent>matriarchal</ent><br/
<hw>ma`tri*ar"chal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to a matriarch; governed by a matriarch or matriarchs;
<as>as, a <ex>matriarchal</ex> society</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Matriarchate</ent><br/
<hw>Ma"tri*ar"chate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office or
jurisdiction of a matriarch; a matriarchal form of government.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matric</ent><br/
<hw>matric</hw> <pos>n.</pos> <ety>[Shortened from
<ets>matriculation</ets>.]</ety> <def>admission to a group (especially a
college or university).</def> <mark>[slang]</mark> <br/
<syn><b>Syn. --</b> matriculation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matricaria</ent><br/
<hw>Matricaria</hw> <pos>prop. n.</pos> <def>A genus of chiefly Old
World strong-smelling weedy herbs; it comprises plants sometimes
included in other genera, such as <gen>Tanacetum</gen> and
<gen>Tripleurospermum</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Matricaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matrice</ent><br/
<hw>Ma"trice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>matrice</ets>. See <er>Matrix</er>.]</ety> <def>See
<er>Matrix</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matricentric</ent><br/
<hw>matricentric</hw> <pos>adj.</pos> <def>centered upon the
mother.</def> [Narrower terms: <stype>matriarchal (vs.
patriarchal)</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matricidal</ent><br/
<hw>Mat"ri*ci`dal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to matricide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matricide</ent><br/
<hw>Mat"ri*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>matricidium</ets>; <ets>mater</ets> mother + <ets>coedere</ets> to
kill, slay: cf. F. <ets>matricide</ets>. See <er>Mother</er>, and cf.
<er>Homicide</er>.]</ety> <sn>1.</sn> <def>The murder of a mother by her
son or daughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[L. <ets>matricida</ets>: cf. F.
<ets>matricide</ets>.]</ety> <def>One who murders one's own
mother.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matriculate</ent><br/
<hw>Ma*tric"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Matriculated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Matriculating</conjf>.]</vmorph> <ety>[L. <ets>matricula</ets> a
public roll or register, dim. of <ets>matrix</ets> a mother, in respect
to propagation, also, a public register. See <er>Matrix</er>.]</ety>
<def>To enroll; to enter in a register;</def>
<specif>specifically,</specif> <def>to enter or admit to membership in a
body or society, particularly in a college or university, by enrolling
the name in a register.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In discovering and <qex>matriculating</qex> the arms of
commissaries from North America.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matriculate</ent><br/
<hw>Ma*tric"u*late</hw>, <pos>v. i.</pos> <def>To go though the process
of admission to membership, as by examination and enrollment, in a
society or college.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matriculate</ent><br/
<hw>Ma*tric"u*late</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Matriculated.</def> <au>Skelton.</au> -- <def2><pos>n.</pos>
<def>One who is matriculated.</def></def2>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matriculation</ent><br/
<hw>Ma*tric`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of matriculating; the state of being matriculated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matrilineage</ent><br/
<hw>matrilineage</hw> <pos>n.</pos> <def>The line of descent traced
through the maternal side of the family; the mother's line of
descent.</def><br/
<syn><b>Syn. --</b> enation, cognation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>matrilineal</ent><br/
<hw>matrilineal</hw> <pos>adj.</pos> <def>tracing descent through the
female line.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matrimoine</ent><br/
<hw>Mat"ri*moine</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Matrimony.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matrimonial</ent><br/
<hw>Mat`ri*mo"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>matrimonialis</ets>: cf. F. <ets>matrimonial</ets>. See
<er>Matrimony</er>.]</ety> <def>Of or pertaining to marriage; derived
from marriage; connubial; nuptial; hymeneal; <as>as,
<ex>matrimonial</ex> rights or duties</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If he relied upon that title, he could be but a king at courtesy,
and have rather a <qex>matrimonial</qex> than a regal power.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Connubial; conjugal; sponsal; spousal; nuptial;
hymeneal.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matrimonially</ent><br/
<hw>Mat`ri*mo"ni*al*ly</hw>, <pos>adv.</pos> <def>In a matrimonial
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matrimonious</ent><br/
<hw>Mat`ri*mo"ni*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Matrimonial.</def> <mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matrimony</ent><br/
<hw>Mat"ri*mo*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>matrimoine</ets>, through Old French, fr. L.
<ets>matrimonium</ets>, fr. <ets>mater</ets> mother. See
<er>Mother</er>.]</ety> <sn>1.</sn> <def>The union of man and woman as
husband and wife; the nuptial state; marriage; wedlock.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If either of you know any impediment, why ye may not be lawfully
joined together in <qex>matrimony</qex>, ye do now confess it.</q>
<rj><qau>Book of Com. Prayer (Eng. Ed.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of game at cards played by several
persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Matrimony vine</b></col> <fld>(Bot.)</fld>, <cd>a
climbing thorny vine (<spn>Lycium barbarum</spn>) of the Potato
family.</cd> <rj><au>Gray.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Marriage; wedlock. See
<er>Marriage</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>matrisib</ent><br/
<hw>matrisib</hw> <pos>n.</pos> <def>One related on the mother's
side.</def><br/
<syn><b>Syn. --</b> enate, matrikin, matrilineal kin, matrilineal
sib.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>matrix</ent><br/
<hw>ma"trix</hw> <pr>(m<amac/"tr<icr/ks)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Matrices</plw>
<pr>(m<acr/t"r<icr/*s<emac/z)</pr>.</plu> <ety>[L., fr. <ets>mater</ets>
mother. See <er>Mother</er>, and cf. <er>Matrice</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>The womb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All that openeth the <qex>matrix</qex> is mine.</q> <rj><qau>Ex.
xxxiv. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>That which gives form or
origin to anything</def>; as: <sd>(a)</sd> <fld>(Mech.)</fld> <def>The
cavity in which anything is formed, and which gives it shape; a die; a
mold, as for the face of a type.</def> <sd>(b)</sd> <fld>(Min.)</fld>
<def>The earthy or stony substance in which metallic ores or
crystallized minerals are found; the gangue.</def> <sd>(c)</sd>
<pluf>pl.</pluf> <fld>(Dyeing)</fld> <def>The five simple colors, black,
white, blue, red, and yellow, of which all the rest are
composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>The lifeless portion of tissue,
either animal or vegetable, situated between the cells; the
intercellular substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Math.)</fld> <def>A rectangular arrangement of
symbols in rows and columns. The symbols may express quantities or
operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matron</ent><br/
<hw>Ma"tron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>matrone</ets>, L. <ets>matrona</ets>, fr. <ets>mater</ets> mother.
See <er>Mother</er>.]</ety> <sn>1.</sn> <def>A wife or a widow,
especially, one who has borne children; a woman of staid or motherly
manners.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your wives, your daughters,<br/
Your <qex>matrons</qex>, and your maids.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Grave from her cradle, insomuch that she was a <qex>matron</qex>
before she was a mother.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A housekeeper; esp., a woman who manages the
domestic economy of a public institution; a head nurse in a hospital;
<as>as, the <ex>matron</ex> of a school or hospital</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Jury of matrons</b></col> <fld>(Law)</fld>, <cd>a jury of
experienced women called to determine the question of pregnancy when set
up in bar of execution, and for other cognate purposes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronage</ent><br/
<hw>Mat"ron*age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state of a matron.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The collective body of matrons.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Can a politician slight the feelings and convictions of the whole
<qex>matronage</qex> of his country?</q> <rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronal</ent><br/
<hw>Mat"ron*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>matronalis</ets>.]</ety> <def>Of or pertaining to a matron;
suitable to an elderly lady or to a married woman; grave;
motherly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronhood</ent><br/
<hw>Ma"tron*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being a matron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronize</ent><br/
<hw>Mat"ron*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Matronized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Matronizing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To make a matron of; to make matronlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Childbed <qex>matronizes</qex> the giddiest spirits.</q>
<rj><qau>Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act the part of a matron toward; to superintend;
to chaperone; <as>as, to <ex>matronize</ex> an assembly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronlike</ent><br/
<hw>Ma"tron*like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a matron;
sedate; grave; matronly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronly</ent><br/
<hw>Ma"tron*ly</hw>, <pos>a.</pos> <sn>1.</sn> <def>Advanced in years;
elderly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like, or befitting, a matron; grave;
sedate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matronymic</ent><br/
<hw>Mat`ro*nym"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mater</ets> mother + <ets>-nymic</ets>, as in
<ets>patronimic</ets>.]</ety> <def>See <er>Metronymic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matross</ent><br/
<hw>Ma*tross"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>matroos</ets>, fr. F. <ets>matelot</ets>.]</ety> <fld>(Mil.)</fld>
<def>Formerly, in the British service, a gunner or a gunner's mate; one
of the soldiers in a train of artillery, who assisted the gunners in
loading, firing, and sponging the guns.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matt</ent><br/
<hw>Matt</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Matte</er>.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mattages</ent><br/
<hw>Mat`ta*ges"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A shrike or butcher bird; -- written also
<altname>matagasse</altname>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mattamore</ent><br/
<hw>Mat"ta*more`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>matamore</ets>, from Ar. <ets>ma<tsdot/m<omac/ra</ets>.]</ety>
<def>A subterranean repository for wheat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matte</ent><br/
<hw>Matte</hw> <pr>(m<acr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>matte</ets>; cf. F. <ets>mat</ets>, masc., <ets>matte</ets>, fem.,
faint, dull, dim; -- said of metals. See <er>Mate</er> checkmate.]</ety>
<sn>1.</sn> <fld>(Metallurgy)</fld> <def>A partly reduced copper
sulphide, obtained by alternately roasting and melting copper ore in
separating the metal from associated iron ores, and called
<altname>coarse metal</altname>, <altname>fine metal</altname>, etc.,
according to the grade of fineness. On the exterior it is dark brown or
black, but on a fresh surface is yellow or bronzy in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dead or dull finish, as in gilding where the gold
leaf is not burnished, or in painting where the surface is purposely
deprived of gloss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matte</ent><br/
<hw>matte</hw> <pr>(m<acr/t)</pr>, <pos>a.</pos> <def>Having a dull,
lusterless surface finish; opposed to <ant>glossy</ant> or
<ex>polished</ex>; <as>as, a <ex>matte</ex> photograph; a proof coin
with <ex>matte</ex> figures on a polished field</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Matted</ent><br/
<hw>Mat"ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Matte</er>.]</ety> <def>Having a dull surface; lusterless;
unburnished; same as <er>matte</er>; <as>as, <ex>matted</ex> gold leaf
or gilding</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Matted glass</b></col>, <cd>glass ornamented with figures
on a dull ground.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matted</ent><br/
<hw>Mat"ted</hw>, <pos>a.</pos> <ety>[See 3d <er>Mat</er>.]</ety>
<sn>1.</sn> <def>Covered with a mat or mats; <as>as, a <ex>matted</ex>
floor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tangled closely together; having its parts adhering
closely together; <as>as, <ex>matted</ex> hair</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matter</ent><br/
<hw>Mat"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>matere</ets>, F. <ets>mati<egrave/re</ets>, fr. L.
<ets>materia</ets>; perh. akin to L. <ets>mater</ets> mother. Cf.
<er>Mother</er>, <er>Madeira</er>, <er>Material</er>.]</ety> <sn>1.</sn>
<def>That of which anything is composed; constituent substance;
material; the material or substantial part of anything; the constituent
elements of conception; that into which a notion may be analyzed; the
essence; the pith; the embodiment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is the <qex>matter</qex> of virtue.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That of which the sensible universe and all existent
bodies are composed; anything which has extension, occupies space, or is
perceptible by the senses; body; substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Matter</xex> is usually divided by philosophical
writers into three kinds or classes: <xex>solid</xex>,
<xex>liquid</xex>, and <xex>gaseous</xex>. <xex>Solid</xex> substances
are those whose parts firmly cohere and resist impression, as wood or
stone. <xex>Liquids</xex> have free motion among their parts, and easily
yield to impression, as water and wine. <xex>Gaseous</xex> substances
are elastic fluids, called <xex>vapors</xex> and <xex>gases</xex>, as
air and oxygen gas.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That with regard to, or about which, anything takes
place or is done; the thing aimed at, treated of, or treated; subject of
action, discussion, consideration, feeling, complaint, legal action, or
the like; theme.</def> <ldquo/If the <xex>matter</xex> should be tried
by duel.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Son of God, Savior of men! Thy name<br/
Shall be the copious <qex>matter</qex> of my song.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every great <qex>matter</qex> they shall bring unto thee, but
every small <qex>matter</qex> they shall judge.</q> <rj><qau>Ex. xviii.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which one has to treat, or with which one has
to do; concern; affair; business.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To help the <qex>matter</qex>, the alchemists call in many
vanities out of astrology.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some young female seems to have carried <qex>matters</qex> so far,
that she is ripe for asking advice.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Affair worthy of account; thing of consequence;
importance; significance; moment; -- chiefly in the phrases <xex>what
matter</xex>? <xex>no matter</xex>, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A prophet some, and some a poet, cry;<br/
No <qex>matter</qex> which, so neither of them lie.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Inducing cause or occasion, especially of anything
disagreeable or distressing; difficulty; trouble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And this is the <qex>matter</qex> why interpreters upon that
passage in Hosea will not consent it to be a true story, that the
prophet took a harlot to wife.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 903 --></p>

<p><sn>7.</sn> <def>Amount; quantity; portion; space; -- often
indefinite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Away he goes, . . . a <qex>matter</qex> of seven miles.</q>
<rj><qau>L' Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have thoughts to tarry a small <qex>matter</qex>.</q>
<rj><qau>Congreve.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No small <qex>matter</qex> of British forces were commanded over
sea the year before.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Substance excreted from living animal bodies; that
which is thrown out or discharged in a tumor, boil, or abscess; pus;
purulent substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Metaph.)</fld> <def>That which is permanent, or is
supposed to be given, and in or upon which changes are effected by
psychological or physical processes and relations; -- opposed to
<contr>form</contr>.</def> <rj><au>Mansel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Print.)</fld> <def>Written manuscript, or anything
to be set in type; copy; also, type set up and ready to be used, or
which has been used, in printing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dead matter</b></col> <fld>(Print.)</fld>, <cd>type which
has been used, or which is not to be used, in printing, and is ready for
distribution.</cd> -- <col><b>Live matter</b></col> <fld>(Print.)</fld>,
<cd>type set up, but not yet printed from.</cd> -- <mcol><col><b>Matter
in bar</b></col>, <col><b>Matter of fact</b></col></mcol>. <cd>See under
<er>Bar</er>, and <er>Fact</er>.</cd> -- <col><b>Matter of
record</b></col>, <cd>anything recorded.</cd> -- <mcol><col><b>Upon the
matter</b></col>, <it>or</it> <col><b>Upon the whole
matter</b></col></mcol>, <cd>considering the whole; taking all things
into view; all things considered.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Waller, with Sir William Balfour, exceeded in horse, but were,
<qex>upon the whole matter</qex>, equal in foot.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matter</ent><br/
<hw>Mat"ter</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mattered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mattering</conjf>.]</vmorph> <sn>1.</sn> <def>To be of
importance; to import; to signify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>matters</qex> not how they were called.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form pus or matter, as an abscess; to
maturate.</def> <mark>[R.]</mark> <ldquo/Each slight sore
<xex>mattereth</xex>.<rdquo/ <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matter</ent><br/
<hw>Mat"ter</hw>, <pos>v. t.</pos> <def>To regard as important; to take
account of; to care for.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He did not <qex>matter</qex> cold nor hunger.</q> <rj><qau>H.
Brooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matterhorn</ent><br/
<hw>Matterhorn</hw> <pos>prop. n.</pos> <def>A mountain in Italy and
Switzerland, 14,690 feet high.</def> <note>According to WordNet, 14,780
feet high</note><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matterless</ent><br/
<hw>Mat"ter*less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Not being, or
having, matter; <as>as, <ex>matterless</ex> spirits</as>.</def>
<rj><au>Davies (Wit's Pilgr.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unimportant; immaterial.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matter-of-fact</ent><br/
<hw>Mat"ter-of-fact"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Adhering to
facts; not turning aside from absolute realities; not fanciful or
imaginative; commonplace; dry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mattery</ent><br/
<hw>Mat"ter*y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Generating or containing pus; purulent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Full of substance or matter; important.</def>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matteuccia</ent><br/
<hw>Matteuccia</hw> <pos>prop. n.</pos> <def>A small genus sometimes
included in genus <gen>Onoclea</gen>; in some classifications both
genera are placed in <gen>Polypodiaceae</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Matteuccia</gen>, Pteretis, genus
<gen>Pteretis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matthew</ent><br/
<hw>Matthew</hw> <pos>prop. n.</pos> <def><person>Saint
Matthew</person>, a disciple of Jesus; author of the first
Gospel.</def><br/
<syn><b>Syn. --</b> Saint Matthew, St. Matthew, Saint Matthew the
Apostle, Levi.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matthiola</ent><br/
<hw>Matthiola</hw> <pos>prop. n.</pos> <def>A genus of Old World plants
grown as ornamentals.</def><br/
<syn><b>Syn. --</b> genus <gen>Matthiola</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matting</ent><br/
<hw>Mat"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Mat</er>,
<pos>v. t. & i.</pos>]</ety> <sn>1.</sn> <def>The act of interweaving or
tangling together so as to make a mat; the process of becoming
matted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mats, in general, or collectively; mat work; a
matlike fabric, for use in covering floors, packing articles, and the
like; a kind of carpeting made of straw, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Materials for mats.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An ornamental border. See 3d <er>Mat</er>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matting</ent><br/
<hw>Mat"ting</hw>, <pos>n.</pos> <ety>[See <er>Matte</er>.]</ety> <def>A
dull, lusterless surface in certain of the arts, as gilding, metal work,
glassmaking, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mattock</ent><br/
<hw>Mat"tock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mattuc</ets>; cf. W. <ets>matog</ets>.]</ety> <def>An implement for
digging and grubbing. The head has two long steel blades, one like an
adz and the other like a narrow ax or the point of a pickax.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is you must dig with <qex>mattock</qex> and with spade.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mattoid</ent><br/
<hw>Mat"toid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. <ets>matto</ets>
mad (cf. L. <ets>mattus</ets>, <ets>matus</ets>, drunk) +
<ets>-oid</ets>.]</ety> <def>A person of congenitally abnormal mind
bordering on insanity or degeneracy.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mattoir</ent><br/
\'d8<hw>Mat*toir"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>matoir</ets>.]</ety> <fld>(Engraving)</fld> <def>A kind of coarse
punch with a rasplike face, used for making a rough surface on etching
ground, or on the naked copper, the effect after biting being very
similar to stippled lines.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mattowacca</ent><br/
<hw>Mat`to*wac"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Indian
name.]</ety> <fld>(Zool.)</fld> <def>An American clupeoid fish
(<spn>Clupea mediocris</spn>), similar to the shad in habits and
appearance, but smaller and less esteemed for food; -- called also
<altname>hickory shad</altname>, <altname>tailor shad</altname>,
<altname>fall herring</altname>, and <altname>shad
herring</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mattress</ent><br/
<hw>Mat"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>materas</ets>, F. <ets>matelas</ets>, LL. <ets>matratium</ets>; cf.
Sp. & Pg. al<ets>madraque</ets>, Pr. al<ets>matrac</ets>; all from Ar.
<ets>ma<tsdot/rah</ets> a place where anything is thrown, what is thrown
under something, fr. <ets><tsdot/araha</ets> to throw.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A large pad stuffed with hair, moss, or other
suitable soft material, and quilted or otherwise fastened, used as or in
a bed, to support the human body while lying down.</def> <altsp>[Written
also <asp>matress</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hydraulic Engin.)</fld> <def>A mass of interwoven
brush, poles, etc., to protect a bank from being worn away by currents
or waves.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>innerspring mattress</b></col> <cd>A variety of
mattress{1} having springs inside to provide a flexible support; it is
considered more comfortable than a stuffed mattress.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Maturant</ent><br/
<hw>Mat"u*rant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maturans</ets>, p. pr. See <er>Maturate</er>.]</ety>
<fld>(Med.)</fld> <def>A medicine, or application, which promotes
suppuration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturate</ent><br/
<hw>Mat"u*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Maturated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Maturating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>maturatus</ets>, p. p. of <ets>maturare</ets> to make ripe, fr.
<ets>maturus</ets> ripe, mature. See <er>Mature</er>, <pos>v.</pos> &
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To bring to ripeness or maturity;
to ripen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A tree may be <qex>maturated</qex> artificially.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To promote the perfect suppuration of (an
abscess).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturate</ent><br/
<hw>Mat"u*rate</hw>, <pos>v. i.</pos> <def>To ripen; to become mature;
specifically, to suppurate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturation</ent><br/
<hw>Mat`u*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maturatio</ets> a hastening: cf. F. <ets>maturation</ets>.]</ety>
<def>The process of bringing, or of coming, to maturity; hence,
specifically, the process of suppurating perfectly; the formation of pus
or matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturative</ent><br/
<hw>Mat"u*ra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>maturatif</ets>.]</ety> <def>Conducing to ripeness or maturity;
hence, conducing to suppuration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturative</ent><br/
<hw>Mat"u*ra*tive</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A remedy
promoting maturation; a maturant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mature</ent><br/
<hw>Ma*ture"</hw> <pr>(?)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Maturer</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Maturest</adjf>.]</amorph> <ety>[L.
<ets>maturus</ets>; prob. akin to E. <ets>matin</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Brought by natural process to completeness of growth
and development; fitted by growth and development for any function,
action, or state, appropriate to its kind; full-grown; ripe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now is love <qex>mature</qex> in ear.</q>
<rj><qau>Tennison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How shall I meet, or how accost, the sage,<br/
Unskilled in speech, nor yet <qex>mature</qex> of age?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Completely worked out; fully digested or prepared;
ready for action; made ready for destined application or use; perfected;
<as>as, a <ex>mature</ex> plan</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This lies glowing, . . . and is almost <qex>mature</qex> for the
violent breaking out.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to a condition of full development;
<as>as, a man of <ex>mature</ex> years</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Come to, or in a state of, completed
suppuration.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Ripe; perfect; completed; prepared; digested;
ready.</syn> <usage> -- <er>Mature</er>, <er>Ripe</er>. Both words
describe <xex>fullness</xex> of growth. <xex>Mature</xex> brings to view
the progressiveness of the process; <xex>ripe</xex> indicates the
result. We speak of a thing as <xex>mature</xex> when thinking of the
successive <xex>stayes</xex> through which it has passed; as
<xex>ripe</xex>, when our attention is directed merely to its state. A
<xex>mature</xex> judgment; <xex>mature</xex> consideration;
<xex>ripe</xex> fruit; a <xex>ripe</xex> scholar.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mature</ent><br/
<hw>Ma*ture"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Matured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Maturing</conjf>.]</vmorph> <ety>[See <er>Maturate</er>,
<er>Mature</er>.]</ety> <def>To bring or hasten to maturity; to promote
ripeness in; to ripen; to complete; <as>as, to <ex>mature</ex> one's
plans</as>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mature</ent><br/
<hw>Ma*ture"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To advance toward
maturity; to become ripe; <as>as, wine <ex>matures</ex> by age; the
judgment <ex>matures</ex> by age and experience.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to become due, as a note.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>matured</ent><br/
<hw>matured</hw> <pos>adj.</pos> <def>Fully grown.</def><br/
<syn><b>Syn. --</b> full-blown.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maturely</ent><br/
<hw>Ma*ture"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a mature
manner; with ripeness; completely.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With caution; deliberately.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Early; soon.</def> <mark>[A Latinism, little
used]</mark> <rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maturement</ent><br/
<hw>maturement</hw> <pos>n.</pos> <def>The process of maturing; coming
to full development; becoming mature; maturation.</def><br/
<syn><b>Syn. --</b> maturation, maturing, ripening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Matureness</ent><br/
<hw>Ma*ture"ness</hw>, <pos>n.</pos> <def>The state or quality of being
mature; maturity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturer</ent><br/
<hw>Ma*tur"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who brings to
maturity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturescent</ent><br/
<hw>Mat`u*res"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>maturescens</ets>, p. pr. of <ets>maturescere</ets> to become ripe,
v. incho. from <ets>maturus</ets>. See <er>Mature</er>,
<pos>a.</pos>]</ety> <def>Approaching maturity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturing</ent><br/
<hw>Ma*tur"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Approaching
maturity; <as>as, <ex>maturing</ex> fruits; <ex>maturing</ex> notes of
hand.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maturity</ent><br/
<hw>Ma*tu"ri*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>maturitas</ets>: cf. F. <ets>maturit<eacute/</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The state or quality of being mature; ripeness; full
development; <as>as, the <ex>maturity</ex> of corn or of grass;
<ex>maturity</ex> of judgment; the <ex>maturity</ex> of a
plan.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Arrival of the time fixed for payment; a becoming
due; termination of the period a note, etc., has to run.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matutinal</ent><br/
<hw>Mat`u*ti"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>matutinalis</ets>, <ets>matutinus</ets>: cf. F.
<ets>matutinal</ets>. See <er>Matin</er>.]</ety> <def>Of or pertaining
to the morning; early.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matutinary</ent><br/
<hw>Ma*tu"ti*na*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Matutinal.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matutine</ent><br/
<hw>Mat"u*tine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Matutinal.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Matweed</ent><br/
<hw>Mat"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
name of several maritime grasses, as the sea sand-reed (<spn>Ammophila
arundinacea</spn>) which is used in Holland to bind the sand of the
seacoast dikes (see <cref>Beach grass</cref>, under <er>Beach</er>);
also, the <spn>Lygeum Spartum</spn>, a Mediterranean grass of similar
habit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maty</ent><br/
<hw>Mat"y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymology
uncertain.]</ety> <def>A native house servant in India.</def>
<rj><au>Balfour (Cyc. of India).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>matzoh</ent><br/
<ent>matzo</ent><br/
<mhw><hw>matz"o</hw>, <hw>matz"oh</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> E. <plw>matzos</plw> or
<plw>matzohs</plw>; Hebr. <plw>matzoth</plw> <pr>(#)</pr></plu>
<ety>[Heb. <ets>matsts<omac/th</ets>, pl. of <ets>matsts<amac/h</ets>
unleavened.]</ety> <def>A cake of unleavened bread eaten by the Jews at
the feast of the Passover.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maucaco</ent><br/
\'d8<hw>Mau*ca"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the native
name.]</ety> <fld>(Zool.)</fld> <def>A lemur; -- applied to several
species, as the White-fronted, the ruffed, and the ring-tailed
lemurs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maud</ent><br/
<hw>Maud</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A gray plaid; -- used by
shepherds in Scotland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maudle</ent><br/
<hw>Mau"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To throw onto
confusion or disorder; to render maudlin.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maudlin</ent><br/
<hw>Maud"lin</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<ets>Maudlin</ets>, a contr. of <ets>Magdalen</ets>, OE.
<ets>Maudeleyne</ets>, who is drawn by painters with eyes swelled and
red with weeping.]</ety> <sn>1.</sn> <def>Tearful; easily moved to
tears; exciting to tears; excessively sentimental; weak and silly.</def>
<ldquo/<xex>Maudlin</xex> eyes.<rdquo/ <au>Dryden.</au>
<ldquo/<xex>Maudlin</xex> eloquence.<rdquo/ <au>Roscommon.</au> <ldquo/A
<xex>maudlin</xex> poetess.<rdquo/ <au>Pope.</au>
<ldquo/<xex>Maudlin</xex> crowd.<rdquo/ <au>Southey.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Drunk, or somewhat drunk; fuddled; given to
drunkenness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Maudlin</qex> Clarence in his malmsey butt.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maudeline</ent><br/
<ent>Maudlin</ent><br/
<mhw>{ <hw>Maud"lin</hw>, <hw>Maude"line</hw> <pr>(?)</pr>, }</mhw>
<pos>n.</pos> <fld>(Bot.)</fld> <def>An aromatic composite herb, the
costmary; also, the South European <spn>Achillea Ageratum</spn>, a kind
of yarrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maudlinism</ent><br/
<hw>Maud"lin*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A maudlin
state.</def> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maudlinwort</ent><br/
<hw>Maud"lin*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The oxeye daisy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maugre</ent><br/
<ent>Mauger</ent><br/
<mhw>{ <hw>Mau"ger</hw>, <hw>Mau"gre</hw> }</mhw>
<pr>(m<add/"g<etil/r)</pr>, <pos>prep.</pos> <ety>[OF.
<ets>maugr<eacute/</ets>, <ets>malgr<eacute/</ets>, F.
<ets>malgr<eacute/</ets>. See <er>Mal-</er>, <er>Malice</er>, and
<er>Agree</er>.]</ety> <def>In spite of; in opposition to;
notwithstanding.</def> <mark>[Archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><q>A man must needs love <qex>maugre</qex> his heed.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>mauger</qex> all the world will I keep safe.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maugre</ent><br/
<hw>Mau"gre</hw>, <pos>v. t.</pos> <def>To defy.</def>
<mark>[Obs.]</mark> <rj><au>J. Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maukin</ent><br/
<hw>Mau"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>See
<er>Malkin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A hare.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maul</ent><br/
<hw>Maul</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Mall</er> a
hammer.]</ety> <def>A heavy wooden hammer or beetle.</def>
<altsp>[Written also <asp>mall</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maul</ent><br/
<hw>Maul</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mauled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mauling</conjf>.]</vmorph> <sn>1.</sn> <def>To beat and bruise
with a heavy stick or cudgel; to wound in a coarse manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Meek modern faith to murder, hack, and <qex>maul</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To injure greatly; to do much harm to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>mauls</qex> not only the person misrepreseted, but him
also to whom he is misrepresented.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maule</ent><br/
<hw>Maule</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The
common mallow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauling</ent><br/
<hw>Maul"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A severe beating with
a stick, cudgel, or the fist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maul-stick</ent><br/
<ent>maulstick</ent><br/
<mhw><hw>maul"stick`</hw>, <hw>maul"-stick`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[G. <ets>malerstock</ets>; <ets>maler</ets> a painter
+ <ets>stock</ets> stick.]</ety> <def>A stick used by painters as a rest
for the hand while working.</def> <altsp>[Written also
<asp>mahl-stick</asp> and <asp>mahlstick</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maumet</ent><br/
<hw>Mau"met</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mawmet</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maunch</ent><br/
<hw>Maunch</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To munch.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maunch</ent><br/
<hw>Maunch</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Manche</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maund</ent><br/
<hw>Maund</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>mand</ets>,
<ets>mond</ets>.]</ety> <def>A hand basket.</def> <mark>[Obs.]</mark>
<rj><au>Herrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maund</ent><br/
<hw>Maund</hw>, <pos>n.</pos> <ety>[Hind, & Per. <ets>man</ets>.]</ety>
<def>An East Indian weight, varying in different localities from 25 to
about 82 pounds avoirdupois.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maunder</ent><br/
<ent>Maund</ent><br/
<mhw>{ <hw>Maund</hw> <pr>(?)</pr>, <hw>Maund"er</hw> <pr>(?)</pr>,
}</mhw> <pos>v. i.</pos> <ety>[Cf. F. <ets>mendier</ets> to beg, E.
<ets>mendicant</ets>.]</ety> <sn>1.</sn> <def>To beg.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson. Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mutter; to mumble; to grumble; to speak
indistinctly or disconnectedly; to talk incoherently.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was ever <qex>maundering</qex> by the how that he met a party
of scarlet devils.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maunder</ent><br/
<hw>Maund"er</hw>, <pos>v. t.</pos> <def>To utter in a grumbling manner;
to mutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maunder</ent><br/
<hw>Maund"er</hw>, <pos>n.</pos> <def>A beggar.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maunderer</ent><br/
<hw>Maund"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
maunders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maundril</ent><br/
<hw>Maun"dril</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Mandrel</er>.]</ety> <fld>(Coal Mining)</fld> <def>A pick with two
prongs, to pry with.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maundy</ent><br/
<hw>Maun"dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Maundy
Thursday</er>.]</ety> <sn>1.</sn> <def>The sacrament of the Lord's
Supper.</def> <mark>[Obs.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>The ceremony of washing the feet of the poor on
Maundy Thursday.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>The alms distributed in connection with this
ceremony or on Maundy Thursday.</def></p>

<p><note><hand/ In England, the foot washing is obsolete, but the
<ldquo/royal maundy<rdquo/ is distributed annually on behalf of the
sovereign. Since 1890 this distribution has been made from Westminster
Abbey.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maundy money</ent><br/
<ent>Maundy coins</ent><br/
<mhw>{ <hw>Maundy coins</hw> <it>or</it> <hw>Maundy money</hw> }</mhw>.
<def>Silver coins or money of the nominal value of 1<it>d.</it>,
2<it>d.</it>, 3<it>d.</it>, and 4<it>d.</it>, struck annually for the
Maundy alms.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maundy Thursday</ent><br/
<hw>Maun"dy Thurs"day</hw> <pr>(?)</pr>. <ety>[OE. <ets>maunde</ets> a
command, OF. <ets>mand<eacute/</ets>, L. <ets>mandatum</ets>, from
<ets>mandare</ets> to command. See called from the ancient custom of
washing the feet of the poor on this day, which was taken to be the
fulfillment of the <ldquo/new commandment,<rdquo/ <au>John xiii. 5,
34.</au>]</ety> <fld>(Eccl.)</fld> <def>The Thursday in Passion week, or
next before Good Friday.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maungy</ent><br/
<hw>Maun"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mangy.</def>
<mark>[Obs.]</mark> <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauresque</ent><br/
<hw>Mau*resque"</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>See
<er>Moresque</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maurist</ent><br/
<hw>Maur"ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Maurus</ets>, the favorite disciple of <person>St.
Benedict</person>.]</ety> <def>A member of the <org>Congregation of
Saint Maur</org>, an offshoot of the <org>Benedictines</org>,
originating in France in the early part of the seventeenth century. The
<ex>Maurists</ex> have been distinguished for their interest in
literature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauritius</ent><br/
<hw>Mauritius</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A country on the
island of Mauritius.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An island in the Indian Ocean.</def><br/
<syn><b>Syn. --</b> Ile de France.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mausolean</ent><br/
<hw>Mau`so*le"an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Mausoleus</ets>. See <er>Mausoleum</er>.]</ety> <def>Pertaining to
a mausoleum; monumental.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mausoleum</ent><br/
<hw>Mau`so*le"um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Mausoleums</plw> <pr>(#)</pr>, L. <plw>-lea</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>mausoleum</ets>, Gr. <?/, fr. <?/
<persfn>Mausolus</persfn>, king of Caria, to whom
<persfn>Artemisia</persfn>, his widow, erected a stately monument, one
of the wonders of the ancient world.]</ety> <def>A magnificent tomb, or
stately sepulchral monument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauther</ent><br/
<hw>Mau"ther</hw> <pr>(m<add/"<th/<etil/r)</pr>, <pos>n.</pos> <ety>[Cf.
AS. <ets>maeg<thorn/</ets> a maid.]</ety> <altsp>[Also spelled
<asp>mawther</asp>, <asp>mother</asp>.]</altsp> <def>A girl; esp., a
great, awkward girl; a wench.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauvaniline</ent><br/
<hw>Mauv`an"i*line</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <cref>Mauve aniline</cref>, under <er>Mauve</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauve</ent><br/
<hw>Mauve</hw> <pr>(m<omac/v)</pr>, <pos>n.</pos> <ety>[F., mallow, L.
<ets>malva</ets>. So named from the similarity of the color to that of
the petals of common mallow, <spn>Malva sylvestris</spn>. See
<er>Mallow</er>.]</ety> <def>A color of a delicate purple, violet, or
lilac.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mauve aniline</b></col> <fld>(Chem.)</fld>, <cd>a
dyestuff produced artificially by the oxidation of commercial aniline,
and the first discovered of the so-called <xex>coal-tar</xex>, or
<xex>aniline</xex>, <xex>dyes</xex>. It consists of the sulphate of
mauve<ium/ne, and is a dark brown or bronze amorphous powder, which
dissolves to a beatiful purple color. Called also <altname>aniline
purple</altname>, <altname>violine</altname>, <altname>Perkin's
mauve</altname>, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mauveine</ent><br/
<hw>mauve"<ium/ne</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>An artificial organic base, obtained by oxidizing a mixture of
aniline and toluidine, and valuable for the dyestuffs it forms.</def>
<altsp>[Written also <asp>mauvine</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mauvine</ent><br/
<hw>Mauv"ine</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Mauve-colored.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maverick</ent><br/
<hw>Mav"er*ick</hw> <pr>(?)</pr>, <pos>n.</pos> <def>In the southwestern
part of the united States, a bullock or heifer that has not been
branded, and is unclaimed or wild; -- said to be from
<etsep>Maverick</etsep>, the name of a cattle owner in Texas who
neglected to brand his cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maverick</ent><br/
<hw>Mav"er*ick</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To take a
maverick.</def> <mark>[Western U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maverick brand</ent><br/
<hw>Maverick brand</hw>. <def>A brand originated by a dishonest
cattleman, who, without owning any stock, gradually accumulates a herd
by finding mavericks.</def> <mark>[Western U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mavis</ent><br/
<hw>Ma"vis</hw> <pr>(m<amac/"v<icr/s)</pr>, <pos>n.</pos> <ety>[F.
<ets>mauvis</ets>, Arm. <ets>milvid</ets>, <ets>milfid</ets>,
<ets>milc'hhouid</ets>, Corn. <ets>melhuez</ets>.]</ety>
<fld>(Zool.)</fld> <def>The European throstle or song thrush
(<spn>Turdus musicus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mavourneen</ent><br/
<ent>Mavournin</ent><br/
<mhw>{ <hw>Ma*vour"nin</hw>, <hw>Ma*vour"neen</hw> }</mhw>
<pr>(m<adot/*v<oomac/r"n<emac/n)</pr>, <pos>n.</pos> <ety>[Ir. <ets>mo
mhuirnin</ets> my darling; <ets>mo</ets> my + <ets>mhuirnin</ets>
darling.]</ety> <def>My darling; -- an Irish term of endearment for a
girl or woman.</def> <ldquo/Erin <xex>mavournin</xex>.<rdquo/
<rj><au>Campbell.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maw</ent><br/
<hw>Maw</hw> <pr>(m<add/)</pr>, <pos>n.</pos> <ety>[See <er>Mew</er> a
gull.]</ety> <fld>(Zool.)</fld> <def>A gull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maw</ent><br/
<hw>Maw</hw>, <pos>n.</pos> <ety>[OE. <ets>mawe</ets>, AS.
<ets>maga</ets> stomach; akin to D. <ets>maag</ets>, OHG.
<ets>mago</ets>, G. <ets>magen</ets>, Icel. <ets>magi</ets>, Sw.
<ets>mage</ets>, Dan. <ets>mave</ets>. <root/103.]</ety> <sn>1.</sn>
<def>A stomach; the receptacle into which food is taken by swallowing;
in birds, the craw; -- now used only of the lower animals, except
humorously or in contempt.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bellies and <qex>maws</qex> of living creatures.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Appetite; inclination.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Unless you had more <qex>maw</qex> to do me good.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fish maw</b></col>. <fld>(Zool.)</fld> <cd>See under
<er>Fish</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maw</ent><br/
<hw>Maw</hw>, <pos>n.</pos> <def>An old game at cards.</def> <rj><au>Sir
A. Weldon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawk</ent><br/
<hw>Mawk</hw> <pr>(m<add/k)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mauk</ets>, <ets>ma<edh/ek</ets>, Icel. <ets>ma<edh/kr</ets>; akin
to Dan. <ets>maddik</ets>, and E. <ets>mad</ets> an earthworm. See
<er>Mad</er>, <pos>n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A maggot.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slattern; a mawks.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawkin</ent><br/
<hw>Maw"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Malkin</er>,
and <er>Maukin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawkingly</ent><br/
<hw>Mawk"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Slatternly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawkish</ent><br/
<hw>Mawk"ish</hw>, <pos>a.</pos> <ety>[Orig., maggoty. See
<er>Mawk</er>.]</ety> <sn>1.</sn> <def>Apt to cause satiety or loathing;
nauseous; slightly nauseating; disgusting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So sweetly <qex>mawkish'</qex>, and so smoothly dull.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Easily disgusted; squeamish; sentimentally
fastidious.</def> <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Weakly sentimental; maudlin.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mawkishly</ent><br/
<hw>Mawk"ish*ly</hw>, <pos>adv.</pos> <def>In a mawkish way.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawkishness</ent><br/
<hw>Mawk"ish*ness</hw>, <pos>n.</pos> <def>The quality or state of being
mawkish.</def> <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawks</ent><br/
<hw>Mawks</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A slattern; a
mawk.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawky</ent><br/
<hw>Mawk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Maggoty.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawmet</ent><br/
<hw>Maw"met</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Contr. fr.
<ets>Mahomet</ets>.]</ety> <def>A puppet; a doll; originally, an idol,
because in the Middle Ages it was generally but falsely believed that
the Muslims worshiped images representing
<persfn>Mohammed</persfn>.</def> <mark>[Obs.]</mark> <rj><au>Wyclif.
Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawmetry</ent><br/
<hw>Maw"met*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The religion of
<persfn>Mohammed</persfn>; also, idolatry. See <er>Mawmet</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawmish</ent><br/
<hw>Maw"mish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prov. E.
<ets>mau</ets>m soft, mellow, rotten; cf. OD. <ets>molm</ets> rotten
wood, G. <ets>mulm</ets>.]</ety> <def>Nauseous.</def>
<mark>[Obs.]</mark> <rj><au>L' Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawseed</ent><br/
<hw>Maw"seed`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>magsamen</ets>.]</ety> <fld>(Bot.)</fld> <def>The seed of the opium
poppy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mawworm</ent><br/
<hw>Maw"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Maw</ets> the
belly + <ets>worm</ets>.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any
intestinal worm found in the stomach, esp. the common round worm
(<spn>Ascaris lumbricoides</spn>), and allied species.</def>
<sd>(b)</sd> <def>One of the larvae of botflies of horses; a
bot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxilla</ent><br/
\'d8<hw>Max*il"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Maxillae</plw> <pr>(#)</pr>.</plu> <ety>[L., dim. of
<ets>mala</ets> jaw, jawbone.]</ety> <sn>1.</sn> <fld>(Anat.)</fld>
<sd>(a)</sd> <def>The bone of either the upper or the under jaw.</def>
<sd>(b)</sd> <def>The bone, or principal bone, of the upper jaw, the
bone of the lower jaw being the <xex>mandible</xex>.</def> <mark>[Now
commonly used in this restricted sense.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the lower or outer jaws of
arthropods.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are usually two pairs in Crustacea and one pair in
insects. In certain insects they are not used as jaws, but may form
suctorial organs. See <xex>Illust.</xex> under <er>Lepidoptera</er>, and
<er>Diptera</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 904 --></p>

<p><ent>Maxillary</ent><br/
<ent>Maxillar</ent><br/
<mhw>{ <hw>Max"il*lar</hw> <pr>(?)</pr>, <hw>Max"il*la*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>maxillaris</ets>, fr.
<ets>maxilla</ets> jawbone, jaw: cf. F. <ets>maxillaire</ets>.]</ety>
<sn>1.</sn> <fld>(Anat.)</fld> <def>Pertaining to either the upper or
the lower jaw, but now usually applied to the upper jaw only.</def> --
<def2><pos>n.</pos> <def>The principal maxillary bone; the
maxilla.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Of or pertaining to a
maxilla.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxilliform</ent><br/
<hw>Max*il"li*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Maxilla</ets> + <ets>-form</ets>: cf. F.
<ets>maxilliforme</ets>.]</ety> <def>Having the form, or structure, of a
maxilla.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxilliped</ent><br/
<hw>Max*il"li*ped</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Maxilla</ets> + L. <ets>pes</ets>, <ets>pedis</ets>,
foot.]</ety> <fld>(Zool.)</fld> <def>One of the mouth appendages of
Crustacea, situated next behind the maxillae. Crabs have three pairs,
but many of the lower Crustacea have but one pair of them. Called also
<altname>jawfoot</altname>, and <altname>foot jaw</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxillo-mandibular</ent><br/
<hw>Max*il`lo-man*dib"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Maxilla</ets> + <ets>mandibular</ets>.]</ety>
<fld>(Anat.)</fld> <def>Pertaining to the maxilla and mandible; <as>as,
the <ex>maxillo-mandibular</ex> nerve</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxillo-palatine</ent><br/
<hw>Max*il`lo-pal"a*tine</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Maxilla</ets> + <ets>palatine</ets>.]</ety>
<fld>(Anat.)</fld> <def>Pertaining to the maxillary and palatine regions
of the skull; <as>as, the <ex>maxillo-palatine</ex> process of the
maxilla</as>. Also used as <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxilloturbinal</ent><br/
<hw>Max*il`lo*tur`bi*nal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Maxilla</ets> + <ets>turbinal</ets>.]</ety>
<fld>(Anat.)</fld> <def>Pertaining to the maxillary and turbinal regions
of the skull.</def> -- <def2><pos>n.</pos> <def>The maxillo-turbinal, or
inferior turbinate, bone.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxim</ent><br/
<hw>Max"im</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>maxime</ets>,
L. <ets>maxima</ets> (sc. <ets>sententia</ets>), the greatest sentence,
proposition, or axiom, i. e., of the greatest weight or authority, fem.
fr. <ets>maximus</ets> greatest, superl. of <ets>magnus</ets> great. See
<er>Magnitude</er>, and cf. <er>Maximum</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An established principle or proposition; a condensed
proposition of important practical truth; an axiom of practical wisdom;
an adage; a proverb; an aphorism.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is their <qex>maxim</qex>, Love is love's reward.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The longest note formerly used,
equal to two longs, or four breves; a large.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Axiom; aphorism; apothegm; adage; proverb;
saying. See <er>Axiom</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maxim gun</ent><br/
<hw>Max"im gun`</hw> <pr>(?)</pr>. <def>A kind of machine gun; -- named
after its inventor, <person>Hiram S.
<etsep>Maxim</etsep></person>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maximilian</ent><br/
<hw>Max`i*mil"ian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the proper
name.]</ety> <def>A gold coin of Bavaria, of the value of about 13s. 6d.
sterling, or about three dollars and a quarter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maximisation</ent><br/
<hw>maximisation</hw> <pos>n.</pos> <sn>1.</sn> <def>Maximization.</def>
<mark>[Chiefly Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maximization</ent><br/
<hw>Max`i*mi*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of increasing to the highest degree.</def>
<rj><au>Bentham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maximize</ent><br/
<hw>Max"i*mize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>maximus</ets> greatest.]</ety> <def>To increase to the highest
degree.</def> <rj><au>Bentham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>maximizing</ent><br/
<hw>maximizing</hw> <pos>adj.</pos> <def>Making as great as possible;
increasing to the highest degree.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Maximum</ent><br/
<hw>Max"i*mum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Maxima</plw> <pr>(#)</pr>.</plu> <ety>[L., neut. from
<ets>maximus</ets> the greatest. See <er>Maxim</er>.]</ety> <def>The
greatest quantity or value attainable in a given case; or, the greatest
value attained by a quantity which first increases and then begins to
decrease; the highest point or degree; -- opposed to
<ant>minimum</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Good legislation is the art of conducting a nation to the
<qex>maximum</qex> of happiness, and the minimum of misery.</q>
<rj><qau>P. Colquhoun.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Maximum thermometer</b></col>, <cd>a thermometer that
registers the highest degree of temperature attained in a given time, or
since its last adjustment.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maximum</ent><br/
<hw>Max"i*mum</hw>, <pos>a.</pos> <def>Greatest in quantity or highest
in degree attainable or attained; <as>as, a <ex>maximum</ex> consumption
of fuel; <ex>maximum</ex> pressure; <ex>maximum</ex>
heat.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>maxwell</ent><br/
<hw>maxwell</hw> <pos>n.</pos> <def>A CGS unit of magnetic flux,
abbreviated <abbr>Mx</abbr>; it is equal to the magnetic flux passing
through one square centimeter which is normal to a magnetic field of one
gauss.</def><br/
<syn><b>Syn. --</b> Mx.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>May</ent><br/
<hw>May</hw> <pr>(m<amac/)</pr>, <pos>v.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Might</conjf> <pr>(m<imac/t)</pr>]</vmorph> <ety>[AS. pres.
<ets>maeg</ets> I am able, pret. <ets>meahte</ets>, <ets>mihte</ets>;
akin to D. <ets>mogen</ets>, G. <ets>m<oum/gen</ets>, OHG.
<ets>mugan</ets>, <ets>magan</ets>, Icel. <ets>mega</ets>, Goth.
<ets>magan</ets>, Russ. <ets>moche</ets>. <root/103. Cf.
<er>Dismay</er>, <er>Main</er> strength, <er>Might</er>. The old imp.
<ets>mought</ets> is obsolete, except as a provincial word.]</ety>
<def>An auxiliary verb qualifying the meaning of another verb,</def>
<specif>by expressing:</specif> <sd>(a)</sd> <def>Ability, competency,
or possibility; -- now oftener expressed by
<altname>can</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>may</qex> a man, said he, with idle speech,<br/
Be won to spoil the castle of his health!</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For what he [the king] <qex>may</qex> do is of two kinds; what he
<qex>may</qex> do as just, and what he <qex>may</qex> do as
possible.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For of all sad words of tongue or pen<br/
The saddest are these: <ldquo/It <qex>might</qex> have been.<rdquo/</q>
<rj><qau>Whittier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Liberty; permission; allowance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou <qex>mayst</qex> be no longer steward.</q> <rj><qau>Luke xvi.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>Contingency or liability; possibility or
probability.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though what he learns he speaks, and <qex>may</qex> advance<br/
Some general maxims, or be right by chance.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Modesty, courtesy, or concession, or a desire to
soften a question or remark.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How old <qex>may</qex> Phillis be, you ask.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <def>Desire or wish, as in prayer, imprecation,
benediction, and the like.</def> <ldquo/<xex>May</xex> you live
happily.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>May be</b></col>, <and/ <col><b>It may
be</b></col></mcol>, <cd>are used as equivalent to
<altname>possibly</altname>, <altname>perhaps</altname>,
<altname>maybe</altname>, <altname>by chance</altname>,
<altname>peradventure</altname>. See 1st <er>Maybe</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>May</ent><br/
<hw>May</hw>, <pos>n.</pos> <ety>[Cf. Icel. <ets>maer</ets>, Goth.
<ets>mawi</ets>; akin to E. <ets>maiden</ets>. <root/103.]</ety> <def>A
maiden.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>May</ent><br/
<hw>May</hw>, <pos>n.</pos> <ety>[F. <ets>Mai</ets>, L.
<ets>Maius</ets>; so named in honor of the goddess <ets>Maia</ets> (Gr.
<grk>Mai^a</grk>), daughter of Atlas and mother of Mercury by
Jupiter.]</ety> <sn>1.</sn> <def>The fifth month of the year, containing
thirty-one days.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The early part or springtime of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>May</qex> of youth, and bloom of lustihood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>The flowers of the hawthorn; -- so
called from their time of blossoming; also, the hawthorn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The palm and <qex>may</qex> make country houses gay.</q>
<rj><qau>Nash.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Plumes that mocked the <qex>may</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The merrymaking of May Day.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Italian may</b></col> <fld>(Bot.)</fld>, <cd>a shrubby
species of <gen>Spiraea</gen> (<spn>Spiraea hypericifolia</spn>) with
many clusters of small white flowers along the slender branches.</cd> --
<col><b>May apple</b></col> <fld>(Bot.)</fld>, <cd>the fruit of an
American plant (<spn>Podophyllum peltatum</spn>). Also, the plant itself
(popularly called <altname>mandrake</altname>), which has two lobed
leaves, and bears a single egg-shaped fruit at the forking. The root and
leaves, used in medicine, are powerfully drastic.</cd> --
<mcol><col><b>May beetle</b></col>, <col><b>May bug</b></col></mcol>
<fld>(Zool.)</fld>, <cd>any one of numerous species of large lamellicorn
beetles that appear in the winged state in May. They belong to
<gen>Melolontha</gen>, and allied genera. Called also <altname>June
beetle</altname>.</cd> -- <col><b>May Day</b></col>, <cd>the first day
of May; -- celebrated in the rustic parts of England by the crowning of
a May queen with a garland, and by dancing about a May pole.</cd> --
<col><b>May dew</b></col>, <cd>the morning dew of the first day of May,
to which magical properties were attributed.</cd> -- <col><b>May
flower</b></col> <fld>(Bot.)</fld>, <cd>a plant that flowers in May;
also, its blossom. See <er>Mayflower</er>, in the vocabulary.</cd> --
<col><b>May fly</b></col> <fld>(Zool.)</fld>, <cd>any species of
<spn>Ephemera</spn>, and allied genera; -- so called because the mature
flies of many species appear in May. See <cref>Ephemeral fly</cref>,
under <er>Ephemeral</er>.</cd> -- <col><b>May game</b></col>, <cd>any
May-day sport.</cd> -- <col><b>May lady</b></col>, <cd>the queen or lady
of May, in old May games.</cd> -- <col><b>May lily</b></col>
<fld>(Bot.)</fld>, <cd>the lily of the valley (<spn>Convallaria
majalis</spn>).</cd> -- <col><b>May pole</b></col>. <cd>See
<er>Maypole</er> in the Vocabulary.</cd> -- <col><b>May queen</b></col>,
<cd>a girl or young woman crowned queen in the sports of May Day.</cd>
-- <col><b>May thorn</b></col>, <cd>the hawthorn.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maya</ent><br/
\'d8<hw>Ma"ya</hw> <pr>(m<aum/"y<aum/)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Hindu Philos.)</fld> <def>The name (in Vedantic philosophy) for
the doctrine of the unreality of matter, called, in English,
<altname>idealism</altname>; hence, nothingness; vanity;
illusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hindu Philos.)</fld> <def>the Hindu goddess
personifying the power that creates phenomena.</def> <au>[RHUD]</au><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Hindu Philos.)</fld> <def>the power to produce
illusions.</def> <au>[RHUD]</au><br/
[<source>PJC</source>]</p>

<p><ent>Maya</ent><br/
<hw>Ma"ya</hw> <pr>(m<aum/"y<adot/)</pr>, <pos>prop. n.</pos>;
<plu><it>pl.</it> <plw>Maya</plw> or <plw>Mayas</plw>.</plu> <sn>1.</sn>
<def>the Indian people occupying the area of Veracruz, Chiapas, Tabasco,
Campeche, and Yucatan, together with a part of Guatemala and a part of
Salvador. The Maya peoples are dark, short, and brachycephalic, and at
the time of the discovery had attained a higher grade of culture than
any other American people. They cultivated a variety of crops, were
expert in the manufacture and dyeing of cotton fabrics, used cacao as a
medium of exchange, and were workers of gold, silver, and copper. Their
architecture comprised elaborately carved temples and palaces, and they
possessed a superior calendar, and a developed system of hieroglyphic
writing, with records said to go back to about 700 <sc>a.
d</sc>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>the language of the Mayas.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Mayaca</ent><br/
<hw>Mayaca</hw> <pos>prop. n.</pos> <def>A small genus of delicate mossy
bog plants having white or violet flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Mayaca</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mayan</ent><br/
<hw>Ma"yan</hw> <pr>(m<aum/"y<ait/n)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Designating, or pertaining to, an American Indian linguistic stock
occupying the Mexican States of Veracruz, Chiapas, Tabasco, Campeche,
and Yucatan, together with a part of Guatemala and a part of El
Salvador. See 2nd <er>Maya</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the Mayas.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Maya arch</ent><br/
<ent>Mayan arch</ent><br/
<mhw>{ <hw>Mayan arch</hw>, <it></it> <hw>Maya arch</hw> }</mhw>. <def>A
form of corbel arch employing regular small corbels.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>may apple</ent><br/
<ent>mayapple</ent><br/
<mhw><hw>mayapple</hw>, <hw>may apple</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>North American herb (<spn>Podophyllum peltatum</spn>)
with poisonous root stock and an edible though insipid egg-shaped
yellowish fruit; called also <altname>wild mandrake</altname>.</def><br/
<syn><b>Syn. --</b> May apple, wild mandrake, <spn>Podophyllum
peltatum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The fruit of the mayapple{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maybe</ent><br/
<hw>May"be</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[For <ets>it may
be</ets>.]</ety> <def>Perhaps; possibly; peradventure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Maybe</qex> the amorous count solicits her.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In a liberal and, <qex>maybe</qex>, somewhat reckless way.</q>
<rj><qau>Tylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maybe</ent><br/
<hw>May"be</hw>, <pos>a.</pos> <def>Possible; probable, but not
sure.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Then add those <qex>maybe</qex> years thou hast to live.</q>
<rj><qau>Driden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maybe</ent><br/
<hw>May"be</hw>, <pos>n.</pos> <def>Possibility; uncertainty.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What they offer is mere <qex>maybe</qex> and shift.</q>
<rj><qau>Creech.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maybird</ent><br/
<hw>May"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The whimbrel; -- called also <altname>May
fowl</altname>, <altname>May curlew</altname>, and <altname>May
whaap</altname>.</def> <sd>(b)</sd> <def>The knot.</def> <mark>[Southern
U. S.]</mark> <sd>(c)</sd> <def>The bobolink.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maybloom</ent><br/
<hw>May"bloom`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The hawthorn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maybush</ent><br/
<hw>May"bush`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The hawthorn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayduke</ent><br/
<hw>May"duke`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupt. of
<etsep>M<eacute/doc</etsep>, a province in France, where it is supposed
to have originated.]</ety> <def>A large dark-red cherry of excellent
quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayfish</ent><br/
<hw>May"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
common American minnow (<spn>Fundulus majalis</spn>). See
<er>Minnow</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayflower</ent><br/
<hw>May"flow`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>In England, the hawthorn; in New England, the trailing arbutus (see
<er>Arbutus</er>); also, the blossom of these plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayhap</ent><br/
<hw>May"hap</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Perhaps;
peradventure.</def> <mark>[Prov. or Dialectic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mayhaw</ent><br/
<hw>mayhaw</hw> <pos>n.</pos> <def>The hawthorn tree (<spn>Crataegus
aestivalis</spn>) of the Southern U. S. bearing a juicy acid scarlet
fruit often used in jellies or preserves.</def><br/
<syn><b>Syn. --</b> summer haw, <spn>Crataegus
aestivalis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mayhem</ent><br/
<hw>may"hem</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[The same as
<ets>maim</ets>. See <er>Maim</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld>
<def>The maiming of a person by depriving him of the use of any of his
members which are necessary for defense or protection. See
<er>Maim</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Violent disorder, especially such as causes serious
harm to persons or damage to property.</def><br/
[<source>PJC</source>]</p>

<p><ent>Maying</ent><br/
<hw>May"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The celebrating of May
Day.</def> <ldquo/He met her once a-<xex>Maying</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>May laws</ent><br/
<hw>May laws</hw>. <sn>1.</sn> <def>See <er>Kulturkampf</er>,
above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>In Russia, severe oppressive laws against Jews,
which have given occasion for great persecution; -- so called because
they received the assent of the czar in May, 1882, and because likened
to the Prussian May laws (see <er>Kulturkampf</er>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mayonnaise</ent><br/
<hw>ma`yon`naise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A thick white sauce compounded of raw yolks of eggs beaten up with
olive oil to the consistency near to that of a gel, and seasoned with
vinegar, pepper, salt, etc.; -- used in dressing salads, fish, etc.
Also, a dish dressed with this sauce.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mayor</ent><br/
<hw>may"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>maire</ets>,
F. <ets>maire</ets>, fr. L. <ets>major</ets> greater, higher, nobler,
compar. of <ets>magnus</ets> great; cf. Sp. <ets>mayor</ets>. See
<er>Major</er>, and cf. <er>Merino</er>.]</ety> <def>The chief
magistrate of a city or borough; the chief administrative officer of a
municipal corporation. In some American cities there is a city court of
which the major is chief judge. The post is usually elective, its holder
chosen by the electorate of the entire city.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayoral</ent><br/
\'d8<hw>May"or*al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., fr.
<ets>mayor</ets> greater, L. <ets>major</ets>.]</ety> <def>The conductor
of a mule team; also, a head shepherd.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mayoral</ent><br/
<hw>may"or*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
a mayor; <as>as, the <ex>mayoral</ex> limousine</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mayoralty</ent><br/
<hw>May"or*al*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office, or
the term of office, of a mayor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayoress</ent><br/
<hw>May"or*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
wife of a mayor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman who is mayor.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mayorship</ent><br/
<hw>May"or*ship</hw>, <pos>n.</pos> <def>The office of a
mayor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maypole</ent><br/
<hw>May"pole`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tall pole erected
in an open place and wreathed with flowers, about which the rustic
May-day sports were had.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maypop</ent><br/
<hw>May"pop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. corrupt. fr.
<ets>maracock</ets>.]</ety> <fld>(Bot.)</fld> <def>The edible fruit of a
passion flower, especially that of the North American <spn>Passiflora
incarnata</spn>, an oval yellowish berry as large as a small
apple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mayweed</ent><br/
<hw>May"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A composite plant (<spn>Anthemis Cotula</spn>), having
a strong odor; dog's fennel. It is a native of Europe, now common by the
roadsides in the United States.</def> <sd>(b)</sd> <def>The
feverfew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazame</ent><br/
<ent>Mazama</ent><br/
<mhw>{ <hw>Ma*za"ma</hw> <pr>(?)</pr>, <hw>Ma*za"me</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A goatlike antelope
(<spn>Haplocerus montanus</spn>) which inhabits the Rocky Mountains,
frequenting the highest parts; -- called also <altname>mountain
goat</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazard</ent><br/
<hw>Maz"ard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>merise</ets> a wild cherry.]</ety> <fld>(Bot.)</fld> <def>A kind of
small black cherry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazard</ent><br/
<hw>Maz"ard</hw>, <pos>n.</pos> <ety>[Prob. fr. <ets>mazer</ets>, the
head being compared to a large goblet.]</ety> <def>The jaw; the head or
skull.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazard</ent><br/
<hw>Maz"ard</hw>, <pos>v. t.</pos>, <def>To knock on the head.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazarine</ent><br/
<hw>Maz`a*rine"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Cardinal <xex>Mazarin</xex>, prime minister of France,
1643-1661.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mazarine Bible</b></col>, <cd>the first Bible, and
perhaps the first complete book, printed with movable metal types; --
printed by Gutenberg at Mentz, 1450-55; -- so called because a copy was
found in the Mazarine Library, at Paris, about 1760.</cd> --
<col><b>Mazarine blue</b></col>, <cd>a deep blue color, named in honor
of Cardinal Mazarin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazarine</ent><br/
<hw>Maz`a*rine"</hw>, <pos>n.</pos> <def>Mazarine blue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazarine</ent><br/
<hw>Maz`a*rine"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Cookery)</fld>
<def>A forcemeat entr<eacute/e.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mazdean</ent><br/
<hw>Maz"de*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
<persfn>Ahura-<xex>Mazda</xex></persfn>, or <persfn>Ormuzd</persfn>, the
beneficent deity in the Zoroastrian dualistic system; hence,
Zoroastrian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazdeism</ent><br/
<hw>Maz"de*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The Zoroastrian
religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maze</ent><br/
<hw>Maze</hw> <pr>(m<amac/z)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mase</ets>; cf. OE. <ets>masen</ets> to confuse, puzzle, Norweg.
<ets>masast</ets> to fall into a slumber, <ets>masa</ets> to be
continually busy, prate, chatter, Icel. <ets>masa</ets> to chatter,
dial. Sw. <ets>masa</ets> to bask, be slow, work slowly and lazily,
<ets>mas</ets> slow, lazy.]</ety> <sn>1.</sn> <def>A wild fancy; a
confused notion.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confusion of thought; perplexity; uncertainty; state
of bewilderment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A confusing and baffling network, as of paths or
passages; an intricacy; a labyrinth.</def> <ldquo/Quaint
<xex>mazes</xex> on the wanton green.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Or down the tempting <qex>maze</qex> of Shawford brook.</q>
<rj><qau>Wordaworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ways of Heaven are dark and intricate,<br/
Puzzled with <qex>mazes</qex>, and perplexed with error.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A complex and confusing system or set of rules that
causes bewilderment; <as>as, a <ex>maze</ex> of environmental
regulations</as>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Labyrinth; intricacy. See
<er>Labyrinth</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maze</ent><br/
<hw>Maze</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mazed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mazing</conjf>.]</vmorph> <def>To perplex greatly; to bewilder;
to astonish and confuse; to amaze.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maze</ent><br/
<hw>Maze</hw>, <pos>v. i.</pos> <def>To be bewildered.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazedness</ent><br/
<hw>Maz"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
being mazed; confusion; astonishment.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazeful</ent><br/
<hw>Maze"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mazy.</def>
<mark>[Obs.]</mark> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazer</ent><br/
<hw>Maz"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>maser</ets>,
akin to OD. <ets>maser</ets> an excrescence on a maple tree, OHG.
<ets>masar</ets>, G. <ets>maser</ets> spot, Icel. <ets>m<oum/surr</ets>
maple.]</ety> <def>A large drinking bowl; -- originally made of
maple.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Their brimful <qex>mazers</qex> to the feasting bring.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazily</ent><br/
<hw>Ma"zi*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mazy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Maziness</ent><br/
<hw>Ma"zi*ness</hw>, <pos>n.</pos> <def>The state or quality of being
mazy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazological</ent><br/
<hw>Maz`o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to mazology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazologist</ent><br/
<hw>Ma*zol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
mazology or mastology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazology</ent><br/
<hw>Ma*zol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mazo`s</grk> the breast + <ets>-logy</ets>.]</ety> <def>Same as
<er>Mastology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazurka</ent><br/
<ent>Mazourka</ent><br/
<mhw>{ <hw>Ma*zour"ka</hw> <pr>(?)</pr>, <hw>Ma*zur"ka</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>A Polish dance, or the music
which accompanies it, usually in 3-4 or 3-8 measure, with a strong
accent on the second beat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mazy</ent><br/
<hw>Ma"zy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Maze</er>.]</ety> <def>Perplexed with turns and windings; winding;
intricate; confusing; perplexing; embarrassing; <as>as, <ex>mazy</ex>
error</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To range amid the <qex>mazy</qex> thicket.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To run the ring, and trace the <qex>mazy</qex> round.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>McCarthyism</ent><br/
<hw>McCarthyism</hw> <pos>prop. n.</pos> <ety>[from <person>Senator
Joseph <etsep>McCarthy</etsep></person>, who repeatedly asserted without
evidence that numerous communists were present in the United States
government.]</ety> <def>Unscrupulously accusing people of disloyalty (as
by saying they were Communists).</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>McKinley</ent><br/
<hw>McKinley</hw> <pos>prop. n.</pos> <def>Mount McKinley, the highest
peak in North America; 20,300 feet high; also called by the native name
<altname>Denali</altname>.</def><br/
<syn><b>Syn. --</b> Mt. McKinley, Denali.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>MDMA</ent><br/
<hw>MDMA</hw> <pos>n.</pos> <def>Methylenedioxymethamphetamine, a drug
designed to have the effects of amphetamines but originally synthesized
to avoid the drug laws; it is now a controlled substance. It is
informally called <altname>ecstasy</altname>. It is used by some
abusively and illegally without a prescription.</def>
<mark>[acronym]</mark><br/
<syn><b>Syn. --</b> methylenedioxymethamphetamine, Adam,
ecstasy.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Me</ent><br/
<hw>Me</hw> <pr>(m<esl/)</pr>, <pos>pron.</pos> <def>One. See
<er>Men</er>, <pos>pron.</pos></def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Me</ent><br/
<hw>Me</hw> <pr>(m<emac/)</pr>, <pos>pers. pron.</pos> <ety>[AS.
<ets>m<emac/</ets>, dat. & acc., <ets>mec</ets>, acc. only ; akin to D.
<ets>mij</ets>, G. <ets>mich</ets>, Icel. & Goth. <ets>mik</ets>, L.
<ets>me</ets>, Gr. <grk>me`</grk>, <grk>'eme`</grk>, Skr.
<ets>m<amac/</ets>, <ets>m<amac/m</ets>. <root/187. Cf. 2d
<er>Mine</er>.]</ety> <def>The person speaking, regarded as an object;
myself; a pronoun of the first person used as the objective and dative
case of the pronoun I; <as>as, he struck <ex>me</ex>; he gave
<ex>me</ex> the money, or he gave the money to <ex>me</ex>; he got
<ex>me</ex> a hat, or he got a hat for <ex>me</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In <xex>methinks</xex>, <xex>me</xex> is properly in the
dative case, and the verb is impersonal, the construction being, <xex>it
appears to me</xex>. In early use <xex>me</xex> was often placed before
forms of the verb <xex>to be</xex> with an adjective; as, <xex>me</xex>
were lief.</note><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Me</qex> rather had my heart might frrl your love<br/
Than my unpleased eye see your courtesy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meach</ent><br/
<hw>Meach</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To skulk; to cower.
See <er>Mich</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meacock</ent><br/
<hw>Mea"cock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr.
<ets>meek</ets> + <ets>cock</ets>.]</ety> <def>An uxorious, effeminate,
or spiritless man.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mead</ent><br/
<hw>Mead</hw> <pr>(m<emac/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mede</ets>, AS. <ets>meodo</ets>; akin to D. <ets>mede</ets>, G.
<ets>met</ets>, <ets>meth</ets>, OHG. <ets>metu</ets>, <ets>mitu</ets>,
Icel. <ets>mj<oum/<edh/r</ets>, Dan. <ets>mi<oum/d</ets>, Sw.
<ets>mj<oum/d</ets>, Russ. <ets>med'</ets>, Lith. <ets>midus</ets>, W.
<ets>medd</ets>, Gr. <grk>me`qy</grk> wine, Skr. <ets>madhu</ets> honey,
a sweet drink, as adj., sweet. <root/270. Cf. <er>Metheglin</er>.]</ety>
<sn>1.</sn> <def>A fermented drink made of water and honey with malt,
yeast, etc.; metheglin; hydromel.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A drink composed of sirup of sarsaparilla or other
flavoring extract, and water. It is sometimes charged with carbonic acid
gas.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mead</ent><br/
<hw>Mead</hw>, <pos>n.</pos> <ety>[AS. <ets>m<aemac/d</ets>. See
<er>Meadow</er>.]</ety> <def>A meadow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>mede</qex><br/
All full of freshe flowers, white and reede.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To fertile vales and dewy <qex>meads</qex><br/
My weary, wandering steps he leads.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meadow</ent><br/
<hw>Mead"ow</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>meady</ets>;
akin to <ets>m<aemac/d</ets>, and to G. <ets>matte</ets>; prob. also to
E. <ets>mow</ets>. See <er>Mow</er> to cut (grass), and cf. 2d
<er>Mead</er>.]</ety> <sn>1.</sn> <def>A tract of low or level land
producing grass which is mown for hay; any field on which grass is grown
for hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Low land covered with coarse grass or rank herbage
near rives and in marshy places by the sea; <as>as, the salt
<ex>meadows</ex> near Newark Bay</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meadow</ent><br/
<hw>Mead"ow</hw>, <pos>a.</pos> <def>Of or pertaining to a meadow; of
the nature of a meadow; produced, growing, or living in, a meadow.</def>
<ldquo/Fat <xex>meadow</xex> ground.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ For many names of plants compounded with
<xex>meadow</xex>, see the particular word in the Vocabulary.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meadow beauty</b></col>. <fld>(Bot.)</fld> <cd>Same as
<er>Deergrass</er>.</cd> -- <col><b>Meadow foxtail</b></col>
<fld>(Bot.)</fld>, <cd>a valuable pasture grass (<spn>Alopecurus
pratensis</spn>) resembling timothy, but with softer spikes.</cd> --
<col><b>Meadow hay</b></col>, <cd>a coarse grass, or true sedge, growing
in uncultivated swamp or river meadow; -- used as fodder or bedding for
cattle, packing for ice, etc.</cd> <mark>[Local, U. S.]</mark> --
<col><b>Meadow hen</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The
American bittern</cd>. See <er>Stake-driver</er>. <sd>(b)</sd> <cd>The
American coot (<gen>Fulica</gen>).</cd> <sd>(c)</sd> <cd>The clapper
rail.</cd> -- <col><b>Meadow mouse</b></col> <fld>(Zool.)</fld>, <cd>any
mouse of the genus <gen>Arvicola</gen>, as the common American species
<spn>Arvicola riparia</spn>; -- called also <altname>field
mouse</altname>, and <altname>field vole</altname>.</cd> --
<col><b>Meadow mussel</b></col> <fld>(Zool.)</fld>, <cd>an American
ribbed mussel (<spn>Modiola plicatula</spn>), very abundant in salt
marshes.</cd> -- <col><b>Meadow ore</b></col> <fld>(Min.)</fld>,
<cd>bog-iron ore , a kind of limonite.</cd> -- <col><b>Meadow
parsnip</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Parsnip</er>.</cd> -- <col><b>Meadow pink</b></col>.
<fld>(Bot.)</fld> <cd>See under <er>Pink</er>.</cd> -- <col><b>Meadow
pipit</b></col> <fld>(Zool.)</fld>, <cd>a small singing bird of the
genus <gen>Anthus</gen>, as <spn>Anthus pratensis</spn>, of Europe.</cd>
-- <col><b>Meadow rue</b></col> <fld>(Bot.)</fld>, <cd>a delicate early
plant, of the genus <gen>Thalictrum</gen>, having compound leaves and
numerous white flowers. There are many species.</cd> -- <col><b>Meadow
saffron</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Saffron</er>.</cd> -- <col><b>Meadow sage</b></col>.
<fld>(Bot.)</fld> <cd>See under <er>Sage</er>.</cd> -- <col><b>Meadow
saxifrage</b></col> <fld>(Bot.)</fld>, <cd>an umbelliferous plant of
Europe (<spn>Silaus pratensis</spn>), somewhat resembling fennel.</cd>
-- <col><b>Meadow snipe</b></col> <fld>(Zool.)</fld>, <cd>the common or
jack snipe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>meadow grass</ent><br/
<ent>meadowgrass</ent><br/
<mhw><hw>meadowgrass</hw>, <hw>meadow grass</hw></mhw> <pos>n.</pos>
<def>Any of various grasses that thrive in the presence of abundant
moisture, especially those of the genus <gen>Poa</gen>, common in
meadows, and of great value for hay and for pasture. See
<er>Grass</er>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>meadow lark</ent><br/
<ent>meadowlark</ent><br/
<mhw><hw>meadowlark</hw>, <hw>meadow lark</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld>, <def>Any species of <gen>Sturnella</gen>, a genus of
North American songbirds allied to the starlings. The common species
(<spn>Sturnella magna</spn>) has a yellow breast with a black
crescent.</def><br/
<syn><b>Syn. --</b> lark.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><-- p. 905 --></p>

<p><ent>Meadowwort</ent><br/
<ent>Meadowsweet</ent><br/
<mhw>{ <hw>Mead"ow*sweet`</hw> <pr>(?)</pr>, <hw>Mead"ow*wort`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Bot.)</fld> <def>The name of
several plants of the genus <gen>Spiraea</gen>, especially the white- or
pink-flowered <spn>Spiraea salicifolia</spn>, a low European and
American shrub, and the herbaceous <spn>Spiraea Ulmaria</spn>, which has
fragrant white flowers in compound cymes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meadowy</ent><br/
<hw>Mead"ow*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
meadows; resembling, or consisting of, meadow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meagre</ent><br/
<ent>Meager</ent><br/
<mhw>{ <hw>Mea"ger</hw>, <hw>Mea"gre</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <ety>[OE. <ets>merge</ets>, F. <ets>maigre</ets>, L.
<ets>macer</ets>; akin to D. & G. <ets>mager</ets>, Icel.
<ets>magr</ets>, and prob. to Gr. <grk>makro`s</grk> long. Cf.
<er>Emaciate</er>, <er>Maigre</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Destitute of, or having little, flesh;
lean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Meager</qex> were his looks;<br/
Sharp misery had worn him to the bones.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of richness, fertility, strength, or the
like; defective in quantity, or poor in quality; poor; barren; scanty in
ideas; wanting strength of diction or affluence of imagery; <as>as,
<ex>meager</ex> resources; <ex>meager</ex> fare</as>. Opposite of
<ant>ample</ant>.</def> <wns>[wns=1]</wns> [Narrower terms:
<stype>exiguous</stype>] [Narrower terms: <stype>hardscrabble,
marginal</stype>] [Narrower terms: <stype>measly, miserable,
paltry</stype>] <ldquo/<xex>Meager</xex> soil.<rdquo/
<rj><au>Dryden.</au></rj><br/
<syn><b>Syn. --</b> meagre, meagerly, scanty.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>Of secular habits and <qex>meager</qex> religious belief.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His education had been but <qex>meager</qex>.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Min.)</fld> <def>Dry and harsh to the touch, as
chalk.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>less than a desirable amount; -- of items
distributed from a larger supply.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> scrimpy, skimpy, skimping.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><syn><b>Syn.</b> -- Thin; lean; lank; gaunt; starved; hungry; poor;
emaciated; scanty; barren.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meagre</ent><br/
<ent>Meager</ent><br/
<mhw>{ <hw>Mea"ger</hw>, <hw>Mea"gre</hw> }</mhw>, <pos>v. t.</pos>
<def>To make lean.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>meagerly</ent><br/
<hw>meagerly</hw> <pos>adj.</pos> <def>same as <er>meager</er>, 2.
Opposite of <ant>ample</ant>.</def><br/
<syn><b>Syn. --</b> meager, meagre.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meagrely</ent><br/
<ent>Meagerly</ent><br/
<mhw>{ <hw>Mea"ger*ly</hw>, <hw>Mea"gre*ly</hw> }</mhw>, <pos>adv.</pos>
<def>Poorly; thinly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meagreness</ent><br/
<ent>Meagerness</ent><br/
<mhw>{ <hw>Mea"ger*ness</hw>, <hw>Mea"gre*ness</hw> }</mhw>,
<pos>n.</pos> <def>The state or quality of being meager; leanness;
scantiness; barrenness.</def><br/
<syn><b>Syn. --</b> meagreness, poorness, scantiness, scantness,
exiguity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meagre</ent><br/
<hw>Mea"gre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>maigre</ets>.]</ety> <fld>(Zool.)</fld> <def>A large European
sciaenoid fish (<spn>Sciaena umbra</spn> or <spn>Sciaena aquila</spn>),
having white bloodless flesh. It is valued as a food fish.</def>
<altsp>[Written also <asp>maigre</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meak</ent><br/
<hw>Meak</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>m<emac/ce</ets> sword, OS. <ets>m<amac/ki</ets>, Icel.
<ets>maekir</ets>.]</ety> <def>A hook with a long handle.</def>
<mark>[Obs.]</mark> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meaking</ent><br/
<hw>Meak"ing</hw>, <pos>n.</pos> <ety>[See <er>Meak</er>.]</ety>
<fld>(Naut.)</fld> <def>The process of picking out the oakum from the
seams of a vessel which is to be recalked.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meaking iron</b></col> <fld>(Naut.)</fld>, <cd>the tool
with which old oakum is picked out of a vessel's seams.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meal</ent><br/
<hw>Meal</hw> <pr>(m<emac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mele</ets>, AS. <ets>m<aemac/l</ets> part, portion, portion of
time; akin to E. <ets>meal</ets> a repast. Cf.
<er>Piecemeal</er>.]</ety> <def>A part; a fragment; a portion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meal</ent><br/
<hw>Meal</hw>, <pos>n.</pos> <ety>[OE. <ets>mel</ets>; akin to E.
<ets>meal</ets> a part, and to D. <ets>maal</ets> time, meal, G.
<ets>mal</ets> time, <ets>mahl</ets> meal, Icel. <ets>m<amac/l</ets>
measure, time, meal, Goth. <ets>m<emac/l</ets> time, and to E.
<ets>measure</ets>. See <er>Measure</er>.]</ety> <def>The portion of
food taken at a particular time for the satisfaction of appetite; the
quantity usually taken at one time with the purpose of satisfying
hunger; a repast; the act or time of eating a meal; <as>as, the traveler
has not eaten a good <ex>meal</ex> for a week; there was silence during
the <ex>meal</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>What strange fish<br/
Hath made his <qex>meal</qex> on thee?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meal</ent><br/
<hw>Meal</hw>, <pos>n.</pos> <ety>[OE. <ets>mele</ets>, AS.
<ets>melu</ets>, <ets>melo</ets>; akin to D. <ets>meel</ets>, G.
<ets>mehl</ets>, OHG. <ets>melo</ets>, Icel. <ets>mj<oum/l</ets>, SW.
<ets>mj<oum/l</ets>, Dan. <ets>meel</ets>, also to D. <ets>malen</ets>
to grind, G. <ets>mahlen</ets>, OHG., OS., & Goth. <ets>malan</ets>,
Icel. <ets>mala</ets>, W. <ets>malu</ets>, L. <ets>molere</ets>, Gr.
<grk>my`lh</grk> mill, and E. <ets>mill</ets>. <root/108. Cf.
<er>Mill</er>, <er>Mold</er> soil, <er>Mole</er> an animal,
<er>Immolate</er>, <er>Molar</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Grain (esp. maize, rye, or oats) that is coarsely
ground and unbolted; also, a kind of flour made from beans, peas, etc.;
sometimes, any flour, esp. if coarse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any substance that is coarsely pulverized like meal,
but not granulated.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meal beetle</b></col> <fld>(Zool.)</fld>, <cd>the adult
of the meal worm. See <cref>Meal worm</cref>, below.</cd> --
<col><b>Meal moth</b></col> <fld>(Zool.)</fld>, <cd>a lepidopterous
insect (<spn>Asopia farinalis</spn>), the larvae of which feed upon
meal, flour, etc.</cd> -- <col><b>Meal worm</b></col>
<fld>(Zool.)</fld>, <cd>the larva of a beetle (<spn>Tenebrio
molitor</spn>) which infests granaries, bakehouses, etc., and is very
injurious to flour and meal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meal</ent><br/
<hw>Meal</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To sprinkle with, or as
with, meal.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pulverize; <as>as, <ex>mealed</ex>
powder</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mealies</ent><br/
<hw>Meal"ies</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[From
<er>Mealy</er>.]</ety> <fld>(Bot.)</fld> <def>Maize or Indian corn; --
the common name in South Africa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mealiness</ent><br/
<hw>Meal"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being mealy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meal-mouthed</ent><br/
<hw>Meal"-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Mealy-mouthed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>meals-on-wheels</ent><br/
<ent>meals on wheels</ent><br/
<mhw><hw>meals on wheels</hw>, <hw>meals-on-wheels</hw></mhw>
<pos>n.</pos> <def>A program that delivers hot meals to persons, such as
the elderly or disabled, who are confined to their homes and unable to
cook for themselves; also, the meals thus delivered. Such programs are
usually conducted by governmental or charitable organizations.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mealtime</ent><br/
<hw>Meal"time`</hw> <pr>(m<emac/l"t<imac/m`)</pr>, <pos>n.</pos>
<def>The usual time of eating a meal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mealy</ent><br/
<hw>Meal"y</hw> <pr>(m<emac/l"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Mealier</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Mealiest</adjf>.]</amorph> <sn>1.</sn>
<def>Having the qualities of meal; resembling meal; soft, dry, and
friable; easily reduced to a condition resembling meal; <as>as, a
<ex>mealy</ex> potato</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Overspread with something that resembles meal;
<as>as, the <ex>mealy</ex> wings of an insect</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mealy bug</ent><br/
<ent>mealybug</ent><br/
<mhw><hw>meal"y*bug`</hw>, <hw>mealy bug</hw></mhw>
<pr>(m<emac/l"<ycr/*b<ucr/g`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>,
<def>Any of several homopteran scale insects (as, <spn>Coccus
adonidum</spn>, and related species of the families
<fam>Pseudococcidae</fam> and <fam>Eriococcidae</fam>), that cover
themselves with a white powderlike or cottony wax secretion. They are
common plant-eating pests in hothouses and are also destructive of fruit
trees.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Mealy-mouthed</ent><br/
<hw>Meal"y-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Using soft
words; not straightforward; plausible; affectedly or timidly delicate of
speech; speaking deviously; unwilling to tell the truth in plain
language. Opposite of <ant>frank</ant> or <ant>blunt</ant>.</def>
<ldquo/<xex>Mealy-mouthed</xex> philanthropies.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She was a fool to be <qex>mealy-mouthed</qex> where nature speaks
so plain.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Meal"y-mouth`ness</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mean</ent><br/
<hw>Mean</hw> <pr>(m<emac/n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Meant</conjf> <pr>(m<ecr/nt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Meaning</conjf>.]</vmorph> <ety>[OE. <ets>menen</ets>,
AS. <ets>m<aemac/nan</ets> to recite, tell, intend, wish; akin to OS.
<ets>m<emac/nian</ets> to have in mind, mean, D. <ets>meenen</ets>, G.
<ets>meinen</ets>, OHG. <ets>meinan</ets>, Icel. <ets>meina</ets>, Sw.
<ets>mena</ets>, Dan. <ets>mene</ets>, and to E. <ets>mind</ets>.
<root/104. See <er>Mind</er>, and cf. <er>Moan</er>.]</ety> <sn>1.</sn>
<def>To have in the mind, as a purpose, intention, etc.; to intend; to
purpose; to design; <as>as, what do you <ex>mean</ex> to
do?</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>mean</qex> ye by this service ?</q> <rj><qau>Ex. xii.
26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye thought evil against me; but God <qex>meant</qex> it unto
good.</q> <rj><qau>Gen. 1. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am not a Spaniard<br/
To say that it is yours and not to <qex>mean</qex> it.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To signify; to indicate; to import; to
denote.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>mean</qex> these seven ewe lambs ?</q> <rj><qau>Gen.
xxi. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Go ye, and learn what that <qex>meaneth</qex>.</q> <rj><qau>Matt.
ix. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mean</ent><br/
<hw>Mean</hw>, <pos>v. i.</pos> <def>To have a purpose or
intention.</def> <mark>[Rare, except in the phrase to mean well, or
ill.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mean</ent><br/
<hw>Mean</hw> <pr>(m<emac/n)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Meaner</adjf>
<pr>(m<emac/n"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Meanest</adjf>.]</amorph> <ety>[OE. <ets>mene</ets>, AS.
<ets>m<aemac/ne</ets> wicked; akin to <ets>m<amac/n</ets>, a., wicked,
n., wickedness, OS. <ets>m<emac/n</ets> wickedness, OHG.
<ets>mein</ets>, G. <ets>meineid</ets> perjury, Icel. <ets>mein</ets>
harm, hurt, and perh. to AS. <ets>gem<aemac/ne</ets> common, general, D.
<ets>gemeen</ets>, G. <ets>gemein</ets>, Goth.
<ets>gam<aacute/ins</ets>, and L. <ets>communis</ets>. The AS.
<ets>gem<aemac/ne</ets> prob. influenced the meaning.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Destitute of distinction or eminence; common; low;
vulgar; humble.</def> <ldquo/Of <xex>mean</xex> parentage.<rdquo/
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mean</qex> man boweth down, and the great man humbleth
himself.</q> <rj><qau>Is. ii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting dignity of mind; low-minded; base; destitute
of honor; spiritless; <as>as, a <ex>mean</ex> motive</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Can you imagine I so <qex>mean</qex> could prove,<br/
To save my life by changing of my love ?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of little value or account; worthy of little or no
regard; contemptible; despicable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Roman legions and great Caesar found<br/
Our fathers no <qex>mean</qex> foes.</q> <rj><qau>J.
Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of poor quality; <as>as, <ex>mean</ex>
fare</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Penurious; stingy; close-fisted; illiberal; <as>as,
<ex>mean</ex> hospitality</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mean</xex> is sometimes used in the formation of
compounds, the sense of which is obvious without explanation; as,
<xex>mean</xex>born, <xex>mean</xex>-looking, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Base; ignoble; abject; beggarly; wretched;
degraded; degenerate; vulgar; vile; servile; menial; spiritless;
groveling; slavish; dishonorable; disgraceful; shameful; despicable;
contemptible; paltry; sordid. See <er>Base</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mean</ent><br/
<hw>Mean</hw>, <pos>a.</pos> <ety>[OE. <ets>mene</ets>, OF.
<ets>meiien</ets>, F. <ets>moyen</ets>, fr. L. <ets>medianus</ets> that
is in the middle, fr. <ets>medius</ets>; akin to E. <ets>mid</ets>. See
<er>Mid</er>.]</ety> <sn>1.</sn> <def>Occupying a middle position;
middle; being about midway between extremes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Being of middle age and a <qex>mean</qex> stature.</q>
<rj><qau>Sir. P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Intermediate in excellence of any kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>According to the fittest style of lofty, <qex>mean</qex>, or
lowly.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>Average; having an intermediate
value between two extremes, or between the several successive values of
a variable quantity during one cycle of variation; <as>as, <ex>mean</ex>
distance; <ex>mean</ex> motion; <ex>mean</ex> solar day.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mean distance</b></col> (of a planet from the sun)
<fld>(Astron.)</fld>, <cd>the average of the distances throughout one
revolution of the planet, equivalent to the semi-major axis of the
orbit.</cd> -- <col><b>Mean error</b></col> <fld>(Math. Phys.)</fld>,
<cd>the average error of a number of observations found by taking the
mean value of the positive and negative errors without regard to
sign.</cd> -- <mcol><col><b>Mean-square error</b></col>, <it>or</it>
<col><b>Error of the mean square</b></col></mcol> <fld>(Math.
Phys.)</fld>, <cd>the error the square of which is the mean of the
squares of all the errors; -- called also, <altname>mean square
deviation</altname>, <altname>mean error</altname>.</cd> -- <col><b>Mean
line</b></col>. <fld>(Crystallog.)</fld> <cd>Same as
<er>Bisectrix</er>.</cd> -- <col><b>Mean noon</b></col>, <cd>noon as
determined by mean time.</cd> -- <col><b>Mean proportional</b></col>
(between two numbers) <fld>(Math.)</fld>, <cd>the square root of their
product.</cd> -- <col><b>Mean sun</b></col>, <cd>a fictitious sun
supposed to move uniformly in the equator so as to be on the meridian
each day at mean noon.</cd> -- <col><b>Mean time</b></col>, <cd>time as
measured by an equable motion, as of a perfect clock, or as reckoned on
the supposition that all the days of the year are of a mean or uniform
length, in contradistinction from <xex>apparent</xex> time, or that
actually indicated by the sun, and from <xex>sidereal</xex> time, or
that measured by the stars.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mean</ent><br/
<hw>Mean</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is mean, or
intermediate, between two extremes of place, time, or number; the middle
point or place; middle rate or degree; mediocrity; medium; absence of
extremes or excess; moderation; measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But to speak in a <qex>mean</qex>, the virtue of prosperity is
temperance; the virtue of adversity is fortitude.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a <qex>mean</qex> in all things.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The extremes we have mentioned, between which the wellinstracted
Christian holds the <qex>mean</qex>, are correlatives.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>A quantity having an intermediate
value between several others, from which it is derived, and of which it
expresses the resultant value; usually, unless otherwise specified, it
is the simple average, formed by adding the quantities together and
dividing by their number, which is called an <stype>arithmetical
mean</stype>. A <stype>geometrical mean</stype> is the <it>n</it>th root
of the product of the <it>n</it> quantities being averaged.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That through which, or by the help of which, an end
is attained; something tending to an object desired; intermediate agency
or measure; necessary condition or coagent; instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their virtuous conversation was a <qex>mean</qex> to work the
conversion of the heathen to Christ.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You may be able, by this <qex>mean</qex>, to review your own
scientific acquirements.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Philosophical doubt is not an end, but a <qex>mean</qex>.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this sense the word is usually employed in the plural
form <xex>means</xex>, and often with a singular attribute or predicate,
as if a singular noun.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>this means</qex> he had them more at vantage.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What other <qex>means is</qex> left unto us.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <specif>Hence:</specif> <def>Resources;
property, revenue, or the like, considered as the condition of easy
livelihood, or an instrumentality at command for effecting any purpose;
disposable force or substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>means</qex> are very slender, and your waste is
great.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <def>A part, whether alto or tenor,
intermediate between the soprano and base; a middle part.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mean</qex> is drowned with your unruly base.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Meantime; meanwhile.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A mediator; a go-between.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He wooeth her by <qex>means</qex> and by brokage.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>By all means</b></col>, <cd>certainly; without fail;
<as>as, go, <ex>by all means</ex></as>.</cd> -- <col><b>By any
means</b></col>, <cd>in any way; possibly; at all.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>If <qex>by any means</qex> I might attain to the resurrection of
the dead.</q> <rj><qau>Phil. iii. ll.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <mcol><col><b>By no means</b></col>, <it>or</it> <col><b>By no
manner of means</b></col></mcol>, <cd>not at all; certainly not; not in
any degree.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The wine on this side of the lake is <qex>by no means</qex> so
good as that on the other.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Meander</ent><br/
<hw>Me*an"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Maeander</ets>, orig., a river in Phrygia, proverbial for its many
windings, Gr. <?/: cf. F. <ets>m<eacute/andre</ets>.]</ety> <sn>1.</sn>
<def>A winding, crooked, or involved course; <as>as, the
<ex>meanders</ex> of the veins and arteries</as>.</def> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>While lingering rivers in <qex>meanders</qex> glide.</q>
<rj><qau>Sir R. Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tortuous or intricate movement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>Fretwork. See
<er>Fret</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meander</ent><br/
<hw>Me*an"der</hw>, <pos>v. t.</pos> <def>To wind, turn, or twist; to
make flexuous.</def> <rj><qau>Dryton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meander</ent><br/
<hw>Me*an"der</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Meandered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Meandering</conjf>.]</vmorph> <def>To wind or turn in a course or
passage; to be intricate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Five miles <qex>meandering</qex> with a mazy motion<br/
Through wood and dale the sacred river ran.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meandrian</ent><br/
<hw>Me*an"dri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Maeandrius</ets>: cf. F. <ets>m<eacute/andrien</ets>.]</ety>
<def>Winding; having many turns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meandrina</ent><br/
\'d8<hw>Me`an*dri"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf. F.
<ets>m<eacute/andrine</ets>.]</ety> <fld>(Zool.)</fld> <def>A genus of
corals with meandering grooves and ridges, including the brain
corals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meandry</ent><br/
<ent>Meandrous</ent><br/
<mhw>{ <hw>Me*an"drous</hw> <pr>(?)</pr>, <hw>Me*an"dry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Winding; flexuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meaning</ent><br/
<hw>Mean"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That
which is meant or intended; intent; purpose; aim; object; <as>as, a
mischievous <ex>meaning</ex> was apparent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If there be any good <qex>meaning</qex> towards you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is signified, whether by act language;
signification; sense; import; <as>as, the <ex>meaning</ex> of a
hint</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Sense; power of thinking.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mean"ing*less</wf>, <pos>a.</pos> --
<wf>Mean"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>meaningful</ent><br/
<hw>meaningful</hw> <pos>adj.</pos> <def>Having a meaning or purpose;
having significance; <as>as, a <ex>meaningful</ex> explanation; a
<ex>meaningful</ex> discussion; a <ex>meaningful</ex> pause; to live a
<ex>meaningful</ex> life</as>. Opposite of <ant>meaningless</ant>.</def>
[Narrower terms: <stype>comprehensible, understandable</stype>;
<stype>indicative, significative, suggestive </stype>; <stype>meaty,
substantive </stype>; <stype>purposeful</stype>] <see>Also See:
<er>purposeful</er>, <er>significant</er>, <er>important</er>.</see><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>meaningfulness</ent><br/
<hw>meaningfulness</hw> <pos>n.</pos> <def>the quality of having great
meaning or value.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>meaningless</ent><br/
<hw>meaningless</hw> <pos>adj.</pos> <def>having no meaning; of no
value; <as>as, a <ex>meaningless</ex> endeavor; a <ex>meaningless</ex>
life; a <ex>meaningless</ex> explanation</as>. Opposite of
<ant>meaningful</ant>.</def> [Narrower terms: <stype>insignificant
</stype>; <stype>mindless, unmeaning </stype>;
<stype>nonsense(prenominal), nonsensical </stype>; <stype>pointless,
purposeless </stype>] <see>Also See: <er>insignificant</er>,
<er>unimportant</er>, <er>purposeless</er>,
<er>unimportant</er>.</see><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meanly</ent><br/
<hw>Mean"ly</hw>, <pos>adv.</pos> <ety>[<er>Mean</er> middle.]</ety>
<def>Moderately.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A man <qex>meanly</qex> learned himself, but not <qex>meanly</qex>
affectioned to set forward learning in others.</q>
<rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meanly</ent><br/
<hw>Mean"ly</hw>, <pos>adv.</pos> <ety>[From <er>Mean</er> low.]</ety>
<def>In a mean manner; unworthily; basely; poorly;
ungenerously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While the heaven-born child<br/
All <qex>meanly</qex> wrapt in the rude manger lies.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Would you <qex>meanly</qex> thus rely<br/
On power you know I must obey ?</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We can not bear to have others think <qex>meanly</qex> of them
[our kindred].</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meanness</ent><br/
<hw>Mean"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The condition, or
quality, of being mean; want of excellence; poorness; lowness; baseness;
sordidness; stinginess.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This figure is of a later date, by the <qex>meanness</qex> of the
workmanship.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mean act; <as>as, to be guilty of
<ex>meanness</ex></as>.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mean-spirited</ent><br/
<ent>meanspirited</ent><br/
<mhw><hw>mean"spir`it*ed</hw>, <hw>mean"-spir`it*ed</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of a mean spirit; petty;
small-minded; base; groveling; -- of people.</def> --
<wordforms><wf>Mean"-spir`it*ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Done for malevolent reasons; -- of deeds and
actions.</def><br/
<syn><b>Syn. --</b> base, contemptible, currish, mean, meanspirited,
scurvy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meant</ent><br/
<hw>Meant</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Mean</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meanwhile</ent><br/
<ent>Meantime</ent><br/
<mhw>{ <hw>Mean"time`</hw> <pr>(?)</pr>, <hw>Mean"while`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The intervening time; <as>as,
in the <ex>meantime</ex> (or <ex>mean time</ex>)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meanwhile</ent><br/
<ent>Meantime</ent><br/
<mhw>{ <hw>Mean"time`</hw>, <hw>Mean"while`</hw>, }</mhw>
<pos>adv.</pos> <def>In the intervening time; during the
interval.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mear</ent><br/
<hw>Mear</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A boundary. See
<er>Mere</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mease</ent><br/
<hw>Mease</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G. <ets>mass</ets>
measure.]</ety> <def>Five hundred; <as>as, a <ex>mease</ex> of
herrings</as>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measelry</ent><br/
<hw>Mea"sel*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>meselrie</ets>, OF. <ets>mesellerie</ets>. See 1st
<er>Measle</er>.]</ety> <def>Leprosy.</def> <mark>[Obs.]</mark>
<rj><au>R. of Brunne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measle</ent><br/
<hw>Mea"sle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>mesel</ets>,
OF. <ets>mesel</ets>, LL. <ets>misellus</ets>, L. <ets>misellus</ets>
unfortunate, dim. of <ets>miser</ets>. See <er>Miser</er>.]</ety> <def>A
leper.</def> <mark>[Obs.]</mark> <altsp>[Written also <asp>meazel</asp>,
and <asp>mesel</asp>.]</altsp> <rj><au>Wyclif (Matt. x. 8.
).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measle</ent><br/
<hw>Mea"sle</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A tapeworm
larva. See 2d <er>Measles</er>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measled</ent><br/
<hw>Mea"sled</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See 2d
<er>Measles</er>.]</ety> <def>Infected or spotted with measles, as
pork.</def> -- <wordforms><wf>Mea"sled*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measles</ent><br/
<hw>Mea"sles</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From 1st
<er>Measle</er>.]</ety> <def>Leprosy; also, a leper.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measles</ent><br/
<hw>Mea"sles</hw>, <pos>n.</pos>; <plu><it>pl.</it> in form, but used as
<xex>singular</xex> in senses 1, 2, & 3.</plu> <ety>[D.
<ets>mazelen</ets>; akin to G. <ets>masern</ets>, pl., and E.
<ets>mazer</ets>, and orig. meaning, little spots. See
<er>Mazer</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Med.)</fld> <def>A contagious viral febrile
disorder commencing with catarrhal symptoms, and marked by the
appearance on the third day of an eruption of distinct red circular
spots, which coalesce in a crescentic form, are slightly raised above
the surface, and after the fourth day of the eruption gradually decline;
rubeola. It is a common childhood disease.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q><qex>Measles</qex> commences with the ordinary symptoms of
fever.</q> <rj><qau>Am. Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 906 --></p>

<p><sn>2.</sn> <fld>(Veter. Med.)</fld> <def>A disease of cattle and
swine in which the flesh is filled with the embryos of different
varieties of the tapeworm.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A disease of trees.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(Zool.)</fld> <def>The larvae of
any tapeworm (<gen>Taenia</gen>) in the cysticercus stage, when
contained in meat. Called also <altname>bladder
worms</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>German measles</b></col> <cd>A mild contagious viral
disease, which may cause birth defects if contracted by a pregnant woman
during early pregnancy; also called
<altname>rubella</altname>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>measly</ent><br/
<hw>mea"sly</hw> <pr>(m<emac/"zly)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Infected with measles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Containing larval tapeworms; --
said of pork and beef.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Contemptibly small in quantity; meager; absurdly
insufficient or bad; <as>as, a <ex>measly</ex> few dollars for all that
work</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>measurability</ent><br/
<hw>measurability</hw> <pos>n.</pos> <def>the quality of being
measurable.</def><br/
<syn><b>Syn. --</b> quantifiability.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Measurable</ent><br/
<hw>Meas"ur*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>mesurable</ets>, L. <ets>mensurabilis</ets>. See <er>Measure</er>,
and cf. <er>Mensurable</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Capable of being measured; susceptible of
mensuration or computation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moderate; temperate; not excessive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of his diet <qex>measurable</qex> was he.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Meas"ur*a*ble*ness</wf>, <pos>n.</pos> --
<wf>Meas"ur*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet do it <qex>measurably</qex>, as it becometh Christians.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>measure</ent><br/
<hw>meas"ure</hw> <pr>(m<ecr/zh"<usl/r; 135)</pr>, <pos>n.</pos>
<ety>[OE. <ets>mesure</ets>, F. <ets>mesure</ets>, L.
<ets>mensura</ets>, fr. <ets>metiri</ets>, <ets>mensus</ets>, to
measure; akin to <ets>metrum</ets> poetical measure, Gr.
<grk>me`tron</grk>, E. <ets>meter</ets>. Cf. <er>Immense</er>,
<er>Mensuration</er>, <er>Mete</er> to measure.]</ety> <sn>1.</sn>
<def>A standard of dimension; a fixed unit of quantity or extent; an
extent or quantity in the fractions or multiples of which anything is
estimated and stated; hence, a rule by which anything is adjusted or
judged.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instrument by means of which size or quantity is
measured, as a graduated line, rod, vessel, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>False ells and <qex>measures</qex> be brought all clean adown.</q>
<rj><qau>R. of Gloucester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The dimensions or capacity of anything, reckoned
according to some standard; size or extent, determined and stated;
estimated extent; <as>as, to take one's <ex>measure</ex> for a
coat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>measure</qex> thereof is longer than the earth, and
broader than the sea.</q> <rj><qau>Job xi. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The contents of a vessel by which quantity is
measured; a quantity determined by a standard; a stated or limited
quantity or amount.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is like leaven which a woman took and hid in three
<qex>measures</qex> of meal.</q> <rj><qau>Luke xiii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Extent or degree not excessive or beyond bounds;
moderation; due restraint; esp. in the phrases, <xex>in measure</xex>;
<xex>with measure</xex>; <xex>without</xex> or <xex>beyond
measure</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hell hath enlarged herself, and opened her mouth without
<qex>measure</qex>.</q> <rj><qau>Is. v. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Determined extent, not to be exceeded; limit;
allotted share, as of action, influence, ability, or the like; due
proportion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord, make me to know mine end, and the <qex>measure</qex> of my
days.</q> <rj><qau>Ps. xxxix. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The quantity determined by measuring, especially in
buying and selling; <as>as, to give good or full
<ex>measure</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Undefined quantity; extent; degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a great <qex>measure</qex> of discretion to be used in
the performance of confession.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Regulated division of movement</def>: <sd>(a)</sd>
<fld>(Dancing)</fld> <def>A regulated movement corresponding to the time
in which the accompanying music is performed; but, especially, a slow
and stately dance, like the minuet.</def> <sd>(b)</sd> <fld>(Mus.)</fld>
(1) <def>The group or grouping of beats, caused by the regular
recurrence of accented beats.</def> (2) <def>The space between two
bars.</def> See <er>Beat</er>, <er>Triple</er>, <er>Quadruple</er>,
<er>Sextuple</er>, <cref>Compound time</cref>, under <er>Compound</er>,
<pos>a.</pos>, and <er>Figure</er>. <sd>(c)</sd> <fld>(Poetry)</fld>
<def>The manner of ordering and combining the quantities, or long and
short syllables; meter; rhythm; hence, a foot; <as>as, a poem in iambic
<ex>measure</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Arith.)</fld> <def>A number which is contained in
a given number a number of times without a remainder; as in the phrases,
the <xex>common measure</xex>, the <xex>greatest common measure</xex>,
etc., of two or more numbers; a denominator. See <cref>common
denominator</cref> under <er>denominator</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>11.</sn> <def>A step or definite part of a progressive course or
policy; a means to an end; an act designed for the accomplishment of an
object; <as>as, political <ex>measures</ex>; prudent <ex>measures</ex>;
an inefficient <ex>measure</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>His majesty found what wrong <qex>measures</qex> he had taken in
the conferring that trust, and lamented his error.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>The act of measuring; measurement.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <pluf>pl.</pluf> <fld>(Geol.)</fld> <def>Beds or strata;
<as>as, coal <ex>measures</ex>; lead <ex>measures</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>linear measure</b></col>, <col><b>lineal
measure</b></col>, <it>or</it> <col><b>long measure</b></col></mcol>,
<cd>measure of length; the measure of lines or distances.</cd> --
<col><b>Liquid measure</b></col>, <cd>the measure of liquids.</cd> --
<col><b>Square measure</b></col>, <cd>the measure of superficial area of
surfaces in square units, as inches, feet, miles, etc.</cd> --
<col><b>To have hard measure</b></col>, <cd>to have harsh treatment
meted out to one; to be harshly or oppressively dealt with.</cd> --
<col><b>To take measures</b></col>, <cd>to make preparations; to provide
means.</cd> -- <col><b>To take one's measure</b></col>, <cd>to measure
one, as for a garment; hence, to form an opinion of one's disposition,
character, ability, etc.</cd> -- <col><b>To tread a measure</b></col>,
<cd>to dance in the style so called. See 9 <sd>(a)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Say to her, we have measured many miles<br/
<qex>To tread a measure</qex> with her on this grass.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measure</ent><br/
<hw>Meas"ure</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Measured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Measuring</conjf>.]</vmorph> <ety>[F. <ets>mesurer</ets>, L.
<ets>mensurare</ets>. See <er>Measure</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To ascertain by use of a measuring instrument; to
compute or ascertain the extent, quantity, dimensions, or capacity of,
by a certain rule or standard; to take the dimensions of; hence, to
estimate; to judge of; to value; to appraise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Great are thy works, Jehovah, infinite<br/
Thy power! what thought can <qex>measure</qex> thee?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To serve as the measure of; <as>as, the thermometer
<ex>measures</ex> changes of temperature</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pass through or over in journeying, as if laying
off and determining the distance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A true devoted pilgrim is not weary<br/
To <qex>measure</qex> kingdoms with his feeble steps.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To adjust by a rule or standard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To secure a contented spirit, <qex>measure</qex> your desires by
your fortunes, not your fortunes by your desires.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To allot or distribute by measure; to set off or
apart by measure; -- often with <xex>out</xex> or
<xex>off</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With what measure ye mete, it shall be <qex>measured</qex> to you
again.</q> <rj><qau>Matt. vii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That portion of eternity which is called time, <qex>measured</qex>
out by the sun.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To measure swords with one</b></col>, <cd>to try
another's skill in the use of the sword; hence, figuratively, to match
one's abilities against an antagonist's.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measure</ent><br/
<hw>Meas"ure</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
make a measurement or measurements.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To result, or turn out, on measuring; <as>as, the
grain <ex>measures</ex> well; the pieces <ex>measure</ex>
unequally.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be of a certain size or quantity, or to have a
certain length, breadth, or thickness, or a certain capacity according
to a standard measure; <as>as, cloth <ex>measures</ex> three fourths of
a yard; a tree <ex>measures</ex> three feet in diameter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measured</ent><br/
<hw>Meas"ured</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Regulated or
determined by a standard; hence, equal; uniform; graduated; limited;
moderated; <as>as, he walked with <ex>measured</ex> steps; he expressed
himself in no <ex>measured</ex> terms.</as></def> --
<wordforms><wf>Meas"ured*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measureless</ent><br/
<hw>Meas"ure*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without measure;
unlimited; immeasurable.</def> --
<wordforms><wf>Meas"ure*less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Where Alf, the sacred river ran,<br/
Through canyons <qex>measureless</qex> to man,<br/
Down to a hidden sea.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Boundless; limitless; endless; unbounded;
unlimited; vast; immense; infinite; immeasurable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measurement</ent><br/
<hw>Meas"ure*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act or result of measuring; mensuration; <as>as, <ex>measurement</ex> is
required</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The extent, size, capacity, amount. or quantity
ascertained by measuring; <as>as, its <ex>measurement</ex> is five
acres</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measurer</ent><br/
<hw>Meas"ur*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who measures;
one whose occupation or duty is to measure commodities in
market.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Measuring</ent><br/
<hw>Meas"ur*ing</hw>, <pos>a.</pos> <def>Used in, or adapted for,
ascertaining measurements, or dividing by measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Measuring faucet</b></col>, <cd>a faucet which permits
only a given quantity of liquid to pass each time it is opened, or one
by means of which the liquid which passes can be measured.</cd> --
<col><b>Measuring worm</b></col> <fld>(Zool.)</fld>, <cd>the larva of
any geometrid moth. They are so called because they move by a process in
which they first pull the rear legs forward toward their front legs,
forming a loop which resembles the process of measuring with a tape
measure. The motion is completed by subsequently moving the front legs
forward to an advanced position. See <er>Geometrid</er>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Meat</ent><br/
<hw>Meat</hw> <pr>(m<emac/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mete</ets>, AS. <ets>mete</ets>; akin to OS. <ets>mat</ets>,
<ets>meti</ets>, D. <ets>met</ets> hashed meat, G. <ets>mett</ets>wurst
sausage, OHG. <ets>maz</ets> food, Icel. <ets>matr</ets>, Sw.
<ets>mat</ets>, Dan. <ets>mad</ets>, Goth. <ets>mats</ets>. Cf.
<er>Mast</er> fruit, <er>Mush</er>.]</ety> <sn>1.</sn> <def>Food, in
general; anything eaten for nourishment, either by man or beast. Hence,
the edible part of anything; <as>as, the <ex>meat</ex> of a lobster, a
nut, or an egg</as>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And God said, Behold, I have given you every herb bearing seed, .
. . to you it shall be for <qex>meat</qex>.</q> <rj><qau>Gen. i.
29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every moving thing that liveth shall be <qex>meat</qex> for
you.</q> <rj><qau>Gen. ix. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The flesh of animals used as food; esp., animal
muscle; <as>as, a breakfast of bread and fruit without
<ex>meat</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <def>Dinner; the chief
meal.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meat biscuit</b></col>. <cd>See under
<er>Biscuit</er>.</cd> -- <col><b>Meat earth</b></col>
<fld>(Mining)</fld>, <cd>vegetable mold.</cd> <au>Raymond.</au> --
<col><b>Meat fly</b></col>. <fld>(Zool.)</fld> <cd>See <cref>Flesh
fly</cref>, under <er>Flesh</er>.</cd> -- <col><b>Meat
offering</b></col> <fld>(Script.)</fld>, <cd>an offering of food, esp.
of a cake made of flour with salt and oil.</cd> -- <col><b>To go to
meat</b></col>, <cd>to go to a meal.</cd> <mark>[Obs.]</mark> --
<col><b>To sit at meat</b></col>, <cd>to sit at the table in taking
food.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meat</ent><br/
<hw>Meat</hw>, <pos>v. t.</pos> <def>To supply with food.</def>
<mark>[Obs.]</mark> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His shield well lined, his horses <qex>meated</qex> well.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meatal</ent><br/
<hw>Me*a"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to a
meatus; resembling a meatus.</def> <rj><au>Owen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meated</ent><br/
<hw>Meat"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Fed;
fattened.</def> <mark>[Obs.]</mark> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having (such) meat; -- used chiefly in composition;
<as>as, thick-<ex>meated</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meathe</ent><br/
<ent>Meath</ent><br/
<mhw>{ <hw>Meath</hw>, <hw>Meathe</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[See <er>Mead</er>.]</ety> <def>A sweet liquor;
mead.</def> <mark>[Obs.]</mark> <rj><au>Chaucer. Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meatiness</ent><br/
<hw>Meat"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality of being
meaty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meatless</ent><br/
<hw>Meat"less</hw>, <pos>a.</pos> <def>Having no meat; without
food.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Leave these beggars <qex>meatless</qex>.<rdquo/</q>
<rj><qau>Sir T. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meatoscope</ent><br/
<hw>Me*at"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meatus</ets> + <ets>-scope</ets>.]</ety> <fld>(Med.)</fld>
<def>A speculum for examining a natural passage, as the
urethra.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meatotome</ent><br/
<hw>Me*at"o*tome</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meatus</ets> + Gr. <?/ to cut.]</ety> <fld>(Surg.)</fld>
<def>An instrument for cutting into the urethra so as to enlarge its
orifice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meatus</ent><br/
\'d8<hw>Me*a"tus</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos>; <plu>E.
<it>pl.</it> <plw>Meatuses</plw> <pr>(<?/)</pr>.</plu> <ety>[L., a
going, passage, fr. <ets>meare</ets> to go.]</ety> <fld>(Anat.)</fld>
<def>A natural passage or canal; <as>as, the external auditory
<ex>meatus</ex></as>. See <xex>Illust.</xex> of <er>Ear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meaty</ent><br/
<hw>Meat"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding in
meat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meaw</ent><br/
<hw>Meaw</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The sea mew.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meaw</ent><br/
<hw>Meaw</hw>, <pos>v. i.</pos> <def>See <er>Mew</er>, to cry as a
cat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meawl</ent><br/
<hw>Meawl</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See <er>Mewl</er>,
and <er>Miaul</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meazel</ent><br/
<hw>Mea"zel</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See 1st
<er>Measle</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meazling</ent><br/
<hw>Meaz"ling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Falling in small
drops; mistling; mizzing.</def> <mark>[Obs.]</mark>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mebles</ent><br/
<hw>Me"bles</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Moebles</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mecate</ent><br/
\'d8<hw>Me*ca"te</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>A rope of hair or of maguey fiber, for tying horses, etc.</def>
<mark>[Southwestern U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meccawee</ent><br/
<hw>Mec`ca*wee"</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to Mecca, in Arabia.</def> -- <def2><pos>n.</pos> <def>A
native or inhabitant of Mecca.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanic</ent><br/
<hw>Me*chan"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/canique</ets> mechanics. See <er>Mechanic</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>The art of the application of the
laws of motion or force to construction.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mechanician; an artisan; an artificer; one who
practices any mechanic art; one skilled or employed in shaping and
uniting materials, as wood, metal, etc., into any kind of structure,
machine, or other object, requiring the use of tools, or instruments.
Also, a technician who maintains or repairs machinery; <as>as, an auto
<ex>mechanic</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>An art quite lost with our <qex>mechanics</qex>.</q> <rj><qau>Sir
T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanic</ent><br/
<hw>Me*chan"ic</hw> <pr>(m<esl/*k<acr/n"<icr/k)</pr>, <pos>a.</pos>
<ety>[F. <ets>m<eacute/canique</ets>, L. <ets>mechanicus</ets>, Gr.
<grk>mhchaniko`s</grk>, fr. <grk>mhchanh`</grk> a machine. See
<er>Machine</er>.]</ety> <sn>1.</sn> <def>Having to do with the
application of the laws of motion in the art of constructing or making
things; of or pertaining to mechanics; mechanical; <as>as, the
<ex>mechanic</ex> arts</as>.</def> <ldquo/These <xex>mechanic</xex>
philosophers.<rdquo/ <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mechanic</qex> slaves,<br/
With greasy aprons, rules, and hammers.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to a mechanic or artificer, or to
the class of artisans; hence, rude; common; vulgar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To make a god, a hero, or a king<br/
Descend to a <qex>mechanic</qex> dialect.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes he ply'd the strong, <qex>mechanic</qex> tool.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Base.</def> <mark>[Obs.]</mark>
<rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanical</ent><br/
<hw>Me*chan"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Mechanic</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Pertaining to, governed by, or in accordance with,
mechanics, or the laws of motion; pertaining to the quantitative
relations of force and matter on a macroscopic scale, as distinguished
from <contr>mental</contr>, <contr>vital</contr>,
<contr>chemical</contr>, <contr>electrical</contr>,
<contr>electronic</contr>, <contr>atomic</contr> etc.; <as>as,
<ex>mechanical</ex> principles; a <ex>mechanical</ex> theory</as>;</def>
<specif>especially,</specif> <def>using only the interactions of solid
parts against each other; <as>as <ex>mechanical</ex> brakes, in contrast
to <contr>hydraulic</contr> brakes.</as></def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to a machine or to machinery or
tools; made or formed by a machine or with tools; <as>as,
<ex>mechanical</ex> precision; <ex>mechanical</ex>
products.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have also divers <qex>mechanical</qex> arts.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Done as if by a machine; uninfluenced by will or
emotion; proceeding automatically, or by habit, without special
intention or reflection; <as>as, <ex>mechanical</ex> singing;
<ex>mechanical</ex> verses; <ex>mechanical</ex> service.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Made and operated by interaction of forces without a
directing intelligence; <as>as, a <ex>mechanical</ex>
universe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Obtained by trial, by measurements, etc.;
approximate; empirical. See the 2d Note under
<er>Geometric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mechanical effect</b></col>, <cd>effective power; useful
work exerted, as by a machine, in a definite time.</cd> --
<col><b>Mechanical engineering</b></col>. <cd>See the Note under
<er>Engineering</er>.</cd> -- <col><b>Mechanical maneuvers</b></col>
<fld>(Mil.)</fld>, <cd>the application of mechanical appliances to the
mounting, dismounting, and moving of artillery.</cd> <au>Farrow.</au> --
<col><b>Mechanical philosophy</b></col>, <cd>the principles of mechanics
applied to the investigation of physical phenomena.</cd> --
<col><b>Mechanical powers</b></col>, <cd>certain simple instruments,
such as the lever and its modifications (the wheel and axle and the
pulley), the inclined plane with its modifications (the screw and the
wedge), which convert a small force acting through a great space into a
great force acting through a small space, or <it>vice versa</it>, and
are used separately or in combination.</cd> -- <col><b>Mechanical
solution</b></col> <fld>(Math.)</fld>, <cd>a solution of a problem by
any art or contrivance not strictly geometrical, as by means of the
ruler and compasses, or other instruments.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanical</ent><br/
<hw>Me*chan"ic*al</hw>, <pos>n.</pos> <def>A mechanic.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanicalize</ent><br/
<hw>Me*chan"ic*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause
to become mechanical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanically</ent><br/
<hw>Me*chan"ic*al*ly</hw>, <pos>adv.</pos> <def>In a mechanical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanicalness</ent><br/
<hw>Me*chan"ic*al*ness</hw>, <pos>n.</pos> <def>The state or quality of
being mechanical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanician</ent><br/
<hw>Mech`a*ni"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/canicien</ets>. See <er>Mechanic</er>.]</ety> <def>One
skilled in the theory or construction of machines; a machinist.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanico-chemical</ent><br/
<hw>Me*chan`i*co-chem"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Pertaining to, connected with, or dependent upon, both mechanics
and chemistry; -- said especially of those sciences which treat of such
phenomena as seem to depend on the laws both of mechanics and chemistry,
as electricity and magnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanics</ent><br/
<hw>Me*chan"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/canique</ets>.]</ety> <def>That science, or branch of
applied mathematics, which treats of the action of forces on
bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ That part of <xex>mechanics</xex> which considers the
action of forces in producing rest or equilibrium is called
<stype>statics</stype>; that which relates to such action in producing
motion is called <stype>dynamics</stype>. The term <xex>mechanics</xex>
includes the action of forces on all bodies, whether solid, liquid, or
gaseous. It is sometimes, however, and formerly was often, used
distinctively of <xex>solid</xex> bodies only: The mechanics of
<xex>liquid</xex> bodies is called also <stype>hydrostatics</stype>, or
<stype>hydrodynamics</stype>, according as the laws of rest or of motion
are considered. The mechanics of <xex>gaseous bodies</xex> is called
also <stype>pneumatics</stype>. The mechanics of fluids in motion, with
special reference to the methods of obtaining from them useful results,
constitutes <stype>hydraulics</stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Animal mechanics</b></col> <fld>(Physiol.)</fld>,
<cd>that portion of physiology which has for its object the
investigation of the laws of equilibrium and motion in the animal body.
The most important mechanical principle is that of the lever, the bones
forming the arms of the levers, the contractile muscles the power, the
joints the fulcra or points of support, while the weight of the body or
of the individual limbs constitutes the weight or resistance.</cd> --
<col><b>Applied mechanics</b></col>, <cd>the principles of abstract
mechanics applied to human art; also, the practical application of the
laws of matter and motion to the construction of machines and structures
of all kinds.</cd> -- <col><b>orbital mechanics</b></col>, <cd>the
principles governing the motion of bodies in orbit around other bodies
under gravitational influence, such as artificial Earth
satellites.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>mechanisation</ent><br/
<hw>mechanisation</hw> <pos>n.</pos> <def>Mechanization.</def><br/
<syn><b>Syn. --</b> automation, mechanization, high technology,
high-tech.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mechanism</ent><br/
<hw>Mech"an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/canisme</ets>, L. <ets>mechanisma</ets>. See
<er>Mechanic</er>.]</ety> <sn>1.</sn> <def>The arrangement or relation
of the parts of a machine; the parts of a machine, taken collectively;
the arrangement or relation of the parts of anything as adapted to
produce an effect; <as>as, the <ex>mechanism</ex> of a watch; the
<ex>mechanism</ex> of a sewing machine; the <ex>mechanism</ex> of a seed
pod.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The series of causal relations that operate to
produce an effect in any system; <as>as, the <ex>mechanism</ex> of a
chemical reaction</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Mechanical operation or action.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He acknowledges nothing besides matter and motion; so that all
must be performed either by <qex>mechanism</qex> or accident.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Kinematics)</fld> <def>An ideal machine; a
combination of movable bodies constituting a machine, but considered
only with regard to relative movements.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mechanism of action</ent><br/
<hw>mech"an*ism of ac"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Medicine, Biochemistry)</fld> <def>The mechanism{2} by which a
pharmacologically active substance produces an effect on a living
organism or in a biochemical system; <as>as, the <ex>mechanism of
action</ex> of actinomycin involves its binding to DNA</as>. The
mechanism of action is usually considered to include an identification
of the specific molecular targets to which a pharmacologically active
substance binds or whose biochemical action it influences; a general
recognition of the broad biochemical pathways (such as DNA synthesis,
protein synthesis, cholesterol synthesis) which are inhibited or
affected by a substance is termed its <contr>mode of
action</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mechanist</ent><br/
<hw>Mech"an*ist</hw>, <pos>n.</pos> <sn>1.</sn> <def>A maker of
machines; one skilled in mechanics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who regards the phenomena of nature as the
effects of forces merely mechanical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mechanization</ent><br/
<hw>mechanization</hw> <pos>n.</pos> <sn>1.</sn> <def>The act or process
of mechanizing.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Causing to be performed by machines, especially by a
highly technical implementation, usually involving electronic hardware;
<as>as, the <ex>mechanization</ex> of a manufacturing
process</as>.</def><br/
<syn><b>Syn. --</b> automation, mechanisation, high technology,
high-tech.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Mechanize</ent><br/
<hw>Mech"an*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mechanized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mechanizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>m<eacute/chaniser</ets>.]</ety> <sn>1.</sn> <def>To cause to be
mechanical.</def> <rj><au>Shelley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To introduce machinery into (a process) in order to
reduce human effort or improve uniformity or quality of the
result;</def> <specif>especially,</specif> <def>To cause to be
accomplished by a mechanical means which requires little or no human
supervision; to automate.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <fld>(Mil.)</fld> <def>To equip
(an armed force) with tanks or other vehicles.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mechanograph</ent><br/
<hw>Mech"an*o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mhchanh`</grk> machine + <ets>-graph</ets>.]</ety> <def>One of a
number of copies of anything multiplied mechanically.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 907 --></p>

<p><ent>Mechanographic</ent><br/
<hw>Mech`an*o*graph`ic</hw>
<pr>(m<ecr/k`<ait/n*<osl/*gr<acr/f"<icr/k)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Treating of mechanics.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Written, copied, or recorded by machinery; produced
by mechanography; <as>as, a <ex>mechanographic</ex> record of changes of
temperature; <ex>mechanographic</ex> prints.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanographist</ent><br/
<hw>Mech`an*og"ra*phist</hw>
<pr>(m<ecr/k`<ait/n*<ocr/g"r<adot/*f<icr/st)</pr>, <pos>n.</pos> <def>An
artist who, by mechanical means, multiplies copies of works of
art.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanography</ent><br/
<hw>Mech`an*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
mechanically multiplying copies of a writing, or any work of
art.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechanurgy</ent><br/
<hw>Mech"an*ur`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mhchanh`</grk> machine + the root of <?/ work.]</ety> <def>That
branch of science which treats of moving machines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechitarist</ent><br/
<hw>Mech"i*tar*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Mechitar</ets>, an Armenian., who founded the congregation in the
early part of the eighteenth century.]</ety> <fld>(Eccl. Hist.)</fld>
<def>One of a religious congregation of the <org>Roman Catholic
Church</org> devoted to the improvement of Armenians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechlin</ent><br/
<hw>Mech"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of lace made
at, or originating in, <etsep>Mechlin</etsep>, in Belgium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mechoacan</ent><br/
<hw>Me*cho"a*can</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A species of
jalap, of very feeble properties, said to be obtained from the root of a
species of <gen>Convolvulus</gen> (<spn>Convolvulus Mechoacan</spn>); --
so called from <etsep>Michoacan</etsep>, in Mexico, whence it is
obtained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meckelian</ent><br/
<hw>Meck*e"li*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to, or discovered by, J. F. <xex>Meckel</xex>, a German
anatomist.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meckelian cartilage</b></col>, <cd>the cartilaginous rod
which forms the axis of the mandible; -- called also <altname>Meckel's
cartilage</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconate</ent><br/
<hw>Mec"o*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/conate</ets>.]</ety> <fld>(Chem.)</fld> <def>A salt of
meconic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconic</ent><br/
<hw>Me*con"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ belonging
to the poppy, fr. <?/ the poppy: cf. F.
<ets>m<eacute/conique</ets>.]</ety> <def>Pertaining to, or obtained
from, the poppy or opium; specif. <fld>(Chem.)</fld>, designating an
acid related to aconitic acid, found in opium and extracted as a white
crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconidine</ent><br/
<hw>Me*con"i*dine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem)</fld>
<def>An alkaloid found in opium, and extracted as a yellow amorphous
substance which is easily decomposed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconidium</ent><br/
\'d8<hw>Mec`o*nid"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim.
of Gr. <?/ a poppy. So called in allusion to the shape of the seed
capsules of the poppy.]</ety> <fld>(Zool.)</fld> <def>A kind of
gonophore produced by hydroids of the genus <gen>Gonothyraea</gen>. It
has tentacles, and otherwise resembles a free medusa, but remains
attached by a pedicel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconin</ent><br/
<hw>Mec"o*nin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/conine</ets>.]</ety> <fld>(Chem.)</fld> <def>A substance
regarded as an anhydride of meconinic acid, existing in opium and
extracted as a white crystalline substance. Also erroneously called
<altname>meconina</altname>, <altname>meconia</altname>, etc., as though
it were an alkaloid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconinic</ent><br/
<hw>Mec`o*nin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an acid which occurs in opium, and
which may be obtained by oxidizing narcotine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meconium</ent><br/
\'d8<hw>Me*co"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, fr. <?/ poppy.]</ety> <fld>(Med.)</fld> <sd>(a)</sd>
<def>Opium.</def> <mark>[Obs.]</mark> <sd>(b)</sd> <def>The contents of
the fetal intestine; hence, first excrement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medal</ent><br/
<hw>Med"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/daille</ets>, It. <ets>medaglia</ets>, fr. L.
<ets>metallum</ets> metal, through (assumed) LL. <ets>metalleus</ets>
made of metal. See <er>Metal</er>, and cf. <er>Mail</er> a piece of
money.]</ety> <def>A piece of metal in the form of a coin, struck with a
device, and intended to preserve the remembrance of a notable event or
an illustrious person, or to serve as a reward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medal</ent><br/
<hw>Med"al</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Medaled</conjf> <pr>(?)</pr>, or <conjf>Medalled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Medaling</conjf> or
<conjf>Medalling</conjf>.]</vmorph> <def>To honor or reward with a
medal.</def> <ldquo/<xex>Medaled</xex> by the king.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medalet</ent><br/
<hw>Med"al*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small
medal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medalist</ent><br/
<hw>Med"al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/dailliste</ets>, It. <ets>medaglista</ets>.]</ety>
<altsp>[Written also <asp>medallist</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A person that is skilled or curious in medals; a
collector of medals.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A designer of medals.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who has gained a medal as the reward of merit;
<as>as, the gold <ex>medalist</ex> in downhill skiing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medallic</ent><br/
<hw>Me*dal"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
a medal, or to medals.</def> <ldquo/Our <xex>medallic</xex>
history.<rdquo/ <rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medallion</ent><br/
<hw>Me*dal"lion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/daillion</ets>, It. <ets>medaglione</ets>, augm. of
<ets>medaglia</ets>. See <er>Medal</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A large medal or memorial coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A circular or oval (or, sometimes, square) tablet
bearing a figure or figures represented in relief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medal play</ent><br/
<hw>Med"al play`</hw>. <fld>(Golf)</fld> <def>Play in which the score is
reckoned by counting the number of strokes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medalurgy</ent><br/
<hw>Med"al*ur`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Medal</ets>
+ the root of Gr. <?/ work.]</ety> <def>The art of making and striking
medals and coins.</def> <altsp>[Written also
<asp>medallurgy</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meddle</ent><br/
<hw>Med"dle`</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Meddled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Meddling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>medlen</ets> to mix, OF. <ets>medler</ets>, <ets>mesler</ets>, F.
<ets>m<ecir/ler</ets>, LL. <ets>misculare</ets>, a dim. fr. L.
<ets>miscere</ets> to mix. <root/271. See <er>Mix</er>, and cf.
<er>Medley</er>, <er>Mellay</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To mix; to mingle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>More to know<br/
Did never <qex>meddle</qex> with my thoughts.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To interest or engage one's self; to have to do; --
in a good sense.</def> <mark>[Obs.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Study to be quiet, and to <qex>meddle</qex> with your own
business.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To interest or engage one's self unnecessarily or
impertinently, to interfere or busy one's self improperly with another's
affairs; specifically, to handle or disturb another's property without
permission; -- often followed by <ptcl>with</ptcl> or
<ptcl>in</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why shouldst thou <qex>meddle</qex> to thy hurt?</q> <rj><qau>2
Kings xiv. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The civil lawyers . . . have <qex>meddled</qex> in a matter that
belongs not to them.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To meddle and make</b></col>, <cd>to intrude one's self
into another person's concerns.</cd> <mark>[Archaic]</mark>
<rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To interpose; interfere; intermeddle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meddle</ent><br/
<hw>Med"dle</hw>, <pos>v. t.</pos> <def>To mix; to mingle.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Wine <qex>meddled</qex> with gall.<rdquo/</q>
<rj><qau>Wyclif (Matt. xxvii. 34).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meddler</ent><br/
<hw>Med"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who meddles; one
who interferes or busies himself with things in which he has no concern;
an officious person; a busybody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meddlesome</ent><br/
<hw>Med"dle*some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Given to
meddling; apt to interpose in the affairs of others; officiously
intrusive.</def> -- <wordforms><wf>Med"dle*some*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meddling</ent><br/
<hw>Med"dling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Meddlesome.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meddlingly</ent><br/
<hw>Med"dling*ly</hw>, <pos>adv.</pos> <def>In a meddling
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mede</ent><br/
<hw>Mede</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A native or
inhabitant of Media in Asia.</def> <ldquo/according to the law of the
<xex>Medes</xex> and Persians, which altereth not<rdquo/ <au>Daniel 6:
8.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mede</ent><br/
<hw>Mede</hw>, <pos>n.</pos> <def>See 1st & 2d <er>Mead</er>, and
<er>Meed</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>medfly</ent><br/
<hw>med"fly</hw> <pr>(m<ecr/d"fl<imac/)</pr>, <altsp>[Often
cap.]</altsp> <def>Same as <er>Mediterranean fruit fly</er>; -- a
shortened form.</def><br/
[<source>PJC</source>]</p>

<p><ent>media</ent><br/
<hw>me"di*a</hw> <pr>(m<emac/"d<icr/*<adot/)</pr>, <pos>n. sing. &
pl.</pos>, <sn>1.</sn> <def>The latinic plural form of <er>medium</er>,
sometimes used as a singular noun with the same meaning as
<sig>medium</sig>; <as>as, <fld>(Computers)</fld> place your
installation <ex>media</ex> into the device which will read it;
<fld>(Microbiology)</fld> the tuberculosis bacterium will only grow in a
special <ex>media</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The public institutions that report the news, such
as newspapers, magazines, radio, and television, collectively; the news
media; <as>as, the <ex>media</ex> were obsessed with Monica Lewinsky for
months</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Media</ent><br/
\'d8<hw>Me"di*a</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Mediae</plw>
<pr>(-<emac/)</pr>.</plu> <ety>[NL., fr. L. <ets>medius</ets>
middle.]</ety> <sn>1.</sn> <fld>(Phonetics)</fld> <def>One of the sonant
mutes <beta/, <delta/, <gamma/ (<it>b</it>, <it>d</it>, <it>g</it>), in
Greek, or of their equivalents in other languages, so named as
intermediate between the <xex>tenues</xex>, <pi/, <tau/, <kappa/
(<it>p</it>, <it>t</it>, <it>k</it>), and the <it>aspiratae</it>
(aspirates) <phi/, <theta/, <chi/ (<it>ph</it> or <it>f</it>,
<it>th</it>, <it>ch</it>). Also called <altname>middle mute</altname>,
or <altname>medial</altname>, and sometimes <altname>soft
mute</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediacy</ent><br/
<hw>Me"di*a*cy</hw> <pr>(m<emac/"d<icr/*<adot/*s<ycr/)</pr>,
<pos>n.</pos> <def>The state or quality of being mediate.</def>
<rj><au>Sir W. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediaeval</ent><br/
<hw>Me`di*ae"val</hw> <pr>(m<emac/`d<icr/*<emac/"v<ait/l; 277)</pr>,
<pos>a.</pos> <ety>[L. <ets>medius</ets> middle + <ets>aevum</ets> age.
See <er>Middle</er>, and <er>Age</er>.]</ety> <def>Of or relating to the
Middle Ages; <as>as, <ex>mediaeval</ex> architecture</as>.</def>
<altsp>[Written also <asp>medieval</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediaevalism</ent><br/
<hw>Me`di*ae"val*ism</hw>
<pr>(m<emac/`d<icr/*<emac/"v<ait/l*<icr/z'm)</pr>, <pos>n.</pos>
<def>The method or spirit of the Middle Ages; devotion to the
institutions and practices of the Middle Ages; a survival from the
Middle Ages.</def> <altsp>[Written also
<asp>medievalism</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediaevalist</ent><br/
<hw>Me`di*ae"val*ist</hw>
<pr>(m<emac/`d<icr/*<emac/"v<ait/l*<icr/st)</pr>, <pos>n.</pos> <def>One
who has a taste for, or is versed in, the history of the Middle Ages;
one in sympathy with the spirit or forms of the Middle Ages.</def>
<altsp>[Written also <asp>medievalist</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediaevally</ent><br/
<hw>Me`di*ae"val*ly</hw>
<pr>(m<emac/`d<icr/*<emac/"v<ait/l*l<ycr/)</pr>, <pos>adv.</pos> <def>In
the manner of the Middle Ages; in accordance with
mediaevalism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediaevals</ent><br/
<hw>Me`di*ae"vals</hw> <pr>(m<emac/`d<icr/*<emac/"v<ait/lz)</pr>,
<pos>n. pl.</pos> <def>The people who lived in the Middle Ages.</def>
<rj><au>Ruskin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medial</ent><br/
<hw>Me"di*al</hw> <pr>(m<emac/"d<icr/*<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>medialis</ets>, fr. <ets>medius</ets> middle: cf. F.
<ets>m<eacute/dial</ets>. See <er>Middle</er>.]</ety> <def>Of or
pertaining to a mean or average; mean; <as>as, <ex>medial</ex>
allegation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medial</ent><br/
<hw>Me"di*al</hw>, <pos>n.</pos> <fld>(Phonetics)</fld> <def>See 2d
<er>Media</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medialuna</ent><br/
\'d8<hw>Me"di*a*lu"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>media luna</ets> half-moon.]</ety> <fld>(Zool.)</fld> <def>See
<er>Half-moon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Median</ent><br/
<hw>Me"di*an</hw> <pr>(m<emac/"d<icr/*<ait/n)</pr>, <pos>a.</pos>
<ety>[L. <ets>medianus</ets>, fr. <ets>medius</ets> middle. See
<er>Medial</er>.]</ety> <sn>1.</sn> <def>Being in the middle; running
through the middle; <as>as, a <ex>median</ex> groove</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Situated in the middle; lying in
a plane dividing a bilateral animal into right and left halves; -- said
of unpaired organs and parts; <as>as, <ex>median</ex>
coverts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Median line</b></col>. <sd>(a)</sd> <fld>(Anat.)</fld>
<cd>Any line in the mesial plane; specif., either of the lines in which
the mesial plane meets the surface of the body.</cd> <sd>(b)</sd>
<fld>(Geom.)</fld> <cd>The line drawn from an angle of a triangle to the
middle of the opposite side; any line having the nature of a
diameter.</cd> -- <col><b>Median plane</b></col> <fld>(Anat.)</fld>,
<cd>the mesial plane.</cd> -- <col><b>Median point</b></col>
<fld>(Geom.)</fld>, <cd>the point where the three median lines of a
triangle mutually intersect.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Median</ent><br/
<hw>Me"di*an</hw>, <pos>n.</pos> <fld>(Geom.)</fld> <def>A median line
or point.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediant</ent><br/
<hw>Me"di*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>medians</ets>, p. p. of <ets>mediare</ets> to halve: cf. It.
<ets>mediante</ets>, F. <ets>m<eacute/diante</ets>.]</ety>
<fld>(Mus.)</fld> <def>The third above the keynote; -- so called because
it divides the interval between the tonic and dominant into two
thirds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediastinal</ent><br/
<hw>Me`di*as*ti"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to a mediastinum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediastinum</ent><br/
<ent>Mediastine</ent><br/
<mhw>{ <hw>Me`di*as"tine</hw> <pr>(?)</pr>, \'d8<hw>Me`di*as*ti"num</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>mediastinum</ets>,
fr. L. <ets>medius</ets> middle; cf. <ets>mediastinus</ets> helper, a
menial servant, LL. <ets>mediastinus</ets> equiv. to <ets>medius</ets>:
cf F. <ets>m<eacute/diastin</ets>.]</ety> <fld>(Anat.)</fld> <def>A
partition; a septum; specifically, the folds of the pleura (and the
space included between them) which divide the thorax into a right and
left cavity. The space included between these folds of the pleura,
called the <xex>mediastinal space</xex>, contains the heart and gives
passage to the esophagus and great blood vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediate</ent><br/
<hw>Me"di*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mediatus</ets>, p. p. of <ets>mediare</ets>, v. t., to halve, v.
i., to be in the middle. See <er>Mid</er>, and cf.
<er>Moiety</er>.]</ety> <sn>1.</sn> <def>Being between the two extremes;
middle; interposed; intervening; intermediate.</def>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Acting by means, or by an intervening cause or
instrument; not direct or immediate; acting or suffering through an
intervening agent or condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Gained or effected by a medium or condition.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An act of <qex>mediate</qex> knowledge is complex.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediate</ent><br/
<hw>Me"di*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mediated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mediating</conjf>.]</vmorph> <ety>[LL.
<ets>mediatus</ets>, p. p. of <ets>mediare</ets> to mediate. See
<er>Mediate</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To be in the middle, or between two; to
intervene.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To interpose between parties, as the equal friend of
each, esp. for the purpose of effecting a reconciliation or agreement;
<as>as, to <ex>mediate</ex> between nations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediate</ent><br/
<hw>Me"di*ate</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To effect by
mediation or interposition; to bring about as a mediator, instrument, or
means; <as>as, to <ex>mediate</ex> a peace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To divide into two equal parts.</def>
<mark>[R.]</mark> <rj><au>Holder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediately</ent><br/
<hw>Me"di*ate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mediate
manner; by a secondary cause or agent; not directly or primarily; by
means; -- opposed to <ant>immediately</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God worketh all things amongst us <qex>mediately</qex>.</q>
<rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The king grants a manor to A, and A grants a portion of it to B.
In this case. B holds his lands immediately of A, but
<qex>mediately</qex> of the king.</q> <rj><qau>Blakstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediateness</ent><br/
<hw>Me"di*ate*ness</hw>, <pos>n.</pos> <def>The state of being
mediate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediation</ent><br/
<hw>Me`di*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mediacioun</ets>, F. <ets>m<eacute/diation</ets>. See
<er>Mediate</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The act of
mediating; action or relation of anything interposed; action as a
necessary condition, means, or instrument; interposition;
intervention.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soul [acts] by the <qex>mediation</qex> of these passions.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, specifically, agency between parties at
variance, with a view to reconcile them; entreaty for another;
intercession.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediative</ent><br/
<hw>Me"di*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
mediation; used in mediation; <as>as, <ex>mediative</ex>
efforts</as>.</def> <rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediatization</ent><br/
<hw>Me`di*at`i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/diatisation</ets>.]</ety> <def>The act of
mediatizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediatize</ent><br/
<hw>Me"di*a*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Mediatized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mediatizing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>m<eacute/diatiser</ets>.]</ety> <def>To cause to act through an
agent or to hold a subordinate position; to annex; -- specifically
applied to the annexation during the former German empire of a smaller
German state to a larger, while allowing it a nominal sovereignty, and
its prince his rank.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The misfortune of being a <qex>mediatized</qex> prince.</q>
<rj><qau>Beaconsfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediator</ent><br/
<hw>Me"di*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mediator</ets>: cf. E. <ets>m<eacute/diateur</ets>.]</ety> <def>One
who mediates; especially, one who interposes between parties at variance
for the purpose of reconciling them; hence, an intercessor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For there is one God, and one <qex>mediator</qex> between God and
men, the man Christ Jesus.</q> <rj><qau>1 Tim. ii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediatorial</ent><br/
<hw>Me`di*a*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to a mediator, or to mediation; mediatory; <as>as, a
<ex>mediatorial</ex> office</as>.</def> --
<wordforms><wf>Me`di*a*to"ri*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>My measures were . . . healing and <qex>mediatorial</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediatorship</ent><br/
<hw>Me"di*a`tor*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office or
character of a mediator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediatory</ent><br/
<hw>Me"di*a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Mediatorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediatrix</ent><br/
<ent>Mediatress</ent><br/
<mhw>{ <hw>Me`di*a"tress</hw> <pr>(?)</pr>, <hw>Me`di*a*"trix</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>mediatrix</ets>, f. of
<ets>mediator</ets>: cf. F. <ets>m<eacute/diatrice</ets>.]</ety> <def>A
female mediator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medic</ent><br/
<hw>Med"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>medica</ets>,
Gr. <?/ (sc. <?/) a kind of clover introduced from <ets>Media</ets>,
from <?/ Median.]</ety> <fld>(Bot.)</fld> <def>A leguminous plant of the
genus <gen>Medicago</gen>. The black medic is the <spn>Medicago
lupulina</spn>; the purple medic, or lucern, is <spn>Medicago
sativa</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medic</ent><br/
<hw>Med"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person who serves to
provide medical care.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <fld>(Mil.)</fld> <def>A
member of the medical corps in the military.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A medical doctor.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A medical student.</def><br/
[<source>PJC</source>]</p>

<p><ent>Medic</ent><br/
<hw>Med"ic</hw>, <pos>a.</pos> <ety>[L. <ets>medicus</ets>.]</ety>
<def>Medical.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicable</ent><br/
<hw>Med"i*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>medicabilis</ets>, from <ets>medicare</ets>, <ets>medicari</ets>,
to heal, fr. <ets>medicus</ets> physician. See <er>Medical</er>.]</ety>
<def>Capable of being medicated; admitting of being cured or
healed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>medicaid</ent><br/
<hw>medicaid</hw> <pos>n.</pos> <def>A program controlled by the United
States government to provide health care for the needy. It is funded by
contributions from the salaries of workers, and is therefore a form of
health insurance.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Medical</ent><br/
<hw>Med"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>medicalis</ets>, L. <ets>medicus</ets> belonging to healing, fr.
<ets>mederi</ets> to heal; cf. Zend <ets>madha</ets> medical science,
wisdom, Gr. <?/ to learn, E. <ets>mind</ets>: cf. F.
<ets>m<eacute/dical</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of, pertaining to, or having to do with, the art of
healing disease, or the science of medicine; <as>as, the
<ex>medical</ex> profession; <ex>medical</ex> services; a
<ex>medical</ex> dictionary; <ex>medical</ex>
jurisprudence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Containing medicine; used in medicine; medicinal;
<as>as, the <ex>medical</ex> properties of a plant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medically</ent><br/
<hw>Med"ic*al*ly</hw>, <pos>adv.</pos> <def>In a medical manner; with
reference to healing, or to the principles of the healing art.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicament</ent><br/
<hw>Med"i*ca*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>medicamentum</ets>, fr. <ets>medicare</ets>, <ets>medicari</ets>,
to heal: cf. F. <ets>m<eacute/dicament</ets>. See
<er>Medicable</er>.]</ety> <def>Anything used for healing diseases or
wounds, especially a medicine; a medication; a healing
application.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicamental</ent><br/
<hw>Med`ica*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to medicaments or healing applications; having the qualities
of medicaments.</def> -- <wordforms><wf>Med`ica*men"tal*ly</wf>,
adv.</wordforms> <-- pref. = medicinal --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicaster</ent><br/
<hw>Med"i*cas`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/dicastre</ets>. See <er>Medical</er>.]</ety> <def>A
quack.</def> <mark>[R.]</mark> <rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicate</ent><br/
<hw>Med"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Medicated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Medicating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>medicatus</ets>, p. p. of <ets>medicare</ets>, <ets>medicari</ets>.
See <er>Medicable</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To tincture or impregnate with anything medicinal;
to drug.</def> <ldquo/<xex>Medicated</xex> waters.<rdquo/
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To treat with medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medication</ent><br/
<hw>Med`i*ca"tion</hw> <pr>(?)</pr>, <ety>[L. <ets>medicatio</ets>: cf.
F. <ets>m<eacute/dication</ets>.]</ety> <def>The act or process of
medicating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicative</ent><br/
<hw>Med"i*ca*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Medicinal;
acting like a medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicean</ent><br/
<hw>Med`i*ce"an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
relating to the <persfn>Medici</persfn>, a noted Italian family; <as>as,
the <ex>Medicean</ex> Venus</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Medicean planets</b></col> <fld>(Astron.)</fld>, <cd>a
name given by <persfn>Galileo</persfn> to the satellites of
Jupiter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicinable</ent><br/
<hw>Me*dic"i*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Medicinal;
having the power of healing.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicinal</ent><br/
<hw>Me*dic"i*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>medicinalis</ets>: cf. F. <ets>m<eacute/dicinal</ets>. See
<er>Medicine</er>.]</ety> <sn>1.</sn> <def>Having curative or palliative
properties; used for the cure or alleviation of bodily disorders;
<as>as, <ex>medicinal</ex> tinctures, plants, or springs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Drop tears as fast as the Arabian trees<br/
Their <qex>medicinal</qex> gum.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to medicine; medical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicinally</ent><br/
<hw>Me*dic"i*nal*ly</hw>, <pos>adv.</pos> <def>In a medicinal
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicine</ent><br/
<hw>Med"i*cine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>medicina</ets> (sc. <ets>ars</ets>), fr. <ets>medicinus</ets>
medical, fr. <ets>medicus</ets>: cf. F. <ets>m<eacute/decine</ets>. See
<er>Medical</er>.]</ety> <sn>1.</sn> <def>The science which relates to
the prevention, cure, or alleviation of disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any substance administered in the treatment of
disease; a remedial agent; a medication; a drug; a pharmaceutical; a
medicament; a remedy; physic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>medicine</qex>, life may be prolonged.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A philter or love potion.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[F. <ets>m<eacute/decin</ets>.]</ety> <def>A
physician.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <sd>(a)</sd> <def>Among the North American Indians, any
object supposed to give control over natural or magical forces, to act
as a protective charm, or to cause healing; also, magical power itself;
the potency which a charm, token, or rite is supposed to
exert.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The North American Indian boy usually took as his
<qex>medicine</qex> the first animal of which he dreamed during the long
and solitary fast that he observed at puberty.</q> <rj><qau>F. H.
Giddings.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sd>(b)</sd> <def>Hence, a similar object or agency among other
savages.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>6.</sn> <def>Short for <er>Medicine man</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>Intoxicating liquor; drink.</def>
<mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Medicine bag</b></col>, <cd>a charm; -- so called among
the North American Indians, or in works relating to them.</cd> --
<col><b>Medicine man</b></col> (among the North American Indians), <cd>a
person who professes to cure sickness, drive away evil spirits, and
regulate the weather by the arts of magic; a shaman.</cd> --
<col><b>Medicine seal</b></col>, <cd>a small gem or paste engraved with
reversed characters, to serve as a seal. Such seals were used by Roman
physicians to stamp the names of their medicines.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicine</ent><br/
<hw>Med"i*cine</hw>, <pos>v. t.</pos> <def>To give medicine to; to
affect as a medicine does; to remedy; to cure.</def>
<ldquo/<xex>Medicine</xex> thee to that sweet sleep.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>medick</ent><br/
<hw>medick</hw> <pos>n.</pos> <def>Any of several Old World herbs of the
genus <gen>Medicago</gen> having small flowers and trifoliate compound
leaves.</def> <altsp>[Also spelled <asp>medic</asp>.]</altsp><br/
<syn><b>Syn. --</b> trefoil.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>medico</ent><br/
<hw>medico</hw> <pos>n.</pos> <sn>1.</sn> <def>a student in medical
school.</def><br/
<syn><b>Syn. --</b> medical student.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A licensed medical practitioner.</def>
<mark>[slang]</mark> <br/
<syn><b>Syn. --</b> doctor, doc, physician, MD, Dr.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Medico-legal</ent><br/
<hw>Med`i*co-le"gal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to law as affected by medical facts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicommissure</ent><br/
<hw>Med`i*com"mis*sure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>medius</ets> middle + E. <ets>commissure</ets>.]</ety>
<fld>(Anat.)</fld> <def>A large transverse commissure in the third
ventricle of the brain; the middle or soft commissure.</def> <rj><au>B.
G. Wildex.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medicornu</ent><br/
\'d8<hw>Med`i*cor"nu</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Medicornua</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. L.
<ets>medius</ets> middle + <ets>cornu</ets> horn.]</ety>
<fld>(Anat.)</fld> <def>The middle or inferior horn of each lateral
ventricle of the brain.</def> <rj><au>B. G. Wilder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medics</ent><br/
<hw>Med"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Science of
medicine.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediety</ent><br/
<hw>Me*di"e*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>medietas</ets>.]</ety> <def>The middle part; half; moiety.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medievalist</ent><br/
<ent>Medievalism</ent><br/
<ent>Medieval</ent><br/
<mhw>{ <hw>Me`di*e"val</hw>, <hw>Me`di*e"val*ism</hw>,
<hw>Me`di*e"val*ist</hw> }</mhw>. <def>Same as <er>Mediaeval</er>,
<er>Mediaevalism</er>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medina epoch</ent><br/
<hw>Me*di"na ep"och</hw> <pr>(?)</pr>. <ety>[From <etsep>Medina</etsep>
in New York.]</ety> <fld>(Geol.)</fld> <def>A subdivision of the Niagara
period in the American upper Silurian, characterized by the formations
known as the Oneida conglomerate, and the Medina sandstone. See the
<xex>Chart</xex> of <er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medinilla</ent><br/
<hw>Medinilla</hw> <pos>peop. n.</pos> <def>A genus of tropical Old
World ornamental evergreen shrubs having fleshy leaves and large
panicles of white pink flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Medinilla</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 908 --></p>

<p><ent>Medino</ent><br/
<hw>Me*di"no</hw> <pr>(m<esl/*d<emac/"n<osl/)</pr>, <pos>n.</pos>
<def>Same as <er>Para</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediocral</ent><br/
<hw>Me"di*o`cral</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mediocre.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mediocre</ent><br/
<hw>me`di*o"cre</hw> <pr>(m<emac/`d<icr/*<omac/"k<etil/r)</pr>,
<pos>a.</pos> <ety>[F. <ets>m<eacute/diocre</ets>, L.
<ets>mediocris</ets>, fr. <ets>medius</ets> middle. See
<er>Mid</er>.]</ety> <def>Of a middle quality; of but a moderate or low
degree of excellence; indifferent; ordinary.</def> <ldquo/ A very
<xex>mediocre</xex> poet.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediocre</ent><br/
<hw>Me"di*o`cre</hw>, <pos>n.</pos> <sn>1.</sn> <def>A mediocre person;
a mediocrity.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A young monk who was excused from performing a
portion of a monk's duties.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediocrist</ent><br/
<hw>Me"di*o`crist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mediocre
person.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediocrity</ent><br/
<hw>Me`di*oc"ri*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/diocrit<eacute/</ets>, L.
<ets>mediocritas</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The quality of being mediocre; a middle state or
degree; a moderate degree or rate.</def> <ldquo/A <xex>mediocrity</xex>
of success.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moderation; temperance.</def> <mark>[Obs.]</mark>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mediocre person; -- used disparagingly.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mediostapedial</ent><br/
<hw>Me`di*o*sta*pe"di*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>medius</ets> middle + E. <ets>stapedial</ets>.]</ety>
<fld>(Anat.)</fld> <def>Pertaining to that part of the columella of the
ear which, in some animals, connects the stapes with the other parts of
the columella.</def> -- <def2><pos>n.</pos> <def>The mediostapedial part
of the columella.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medioxumous</ent><br/
<hw>Me`di*ox"u*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>medioxumus</ets> middlemost.]</ety> <def>Intermediate.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meditance</ent><br/
<hw>Med"i*tance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Meditation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meditate</ent><br/
<hw>Med"i*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Meditated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Meditating</conjf>.]</vmorph> <ety>[L.
<ets>meditatus</ets>, p. p. of <ets>meditari</ets> to meditate; cf. Gr.
<?/ to learn, E. <ets>mind</ets>.]</ety> <def>To keep the mind in a
state of contemplation; to dwell on anything in thought; to think
seriously; to muse; to cogitate; to reflect.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In his law doth he <qex>meditate</qex> day and night.</q>
<rj><qau>Ps. i. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meditate</ent><br/
<hw>Med"i*tate</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To contemplate;
to keep the mind fixed upon; to study.</def> <ldquo/Blessed is the man
that doth <xex>meditate</xex> good things.<rdquo/ <rj><au>Ecclus. xiv.
20.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To purpose; to intend; to design; to plan by
revolving in the mind; <as>as, to <ex>meditate</ex> a
war</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>meditate</qex> to pass the remainder of life in a state of
undisturbed repose.</q> <rj><qau>Washington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To consider; ponder; weigh; revolve; study.</syn>
<usage> -- To <er>Meditate</er>, <er>Contemplate</er>, <er>Intend</er>.
We <xex>meditate</xex> a design when we are looking out or waiting for
the means of its accomplishment; we <xex>contemplate</xex> it when the
means are at hand, and our decision is nearly or quite made. To
<xex>intend</xex> is stronger, implying that we have decided to act when
an opportunity may offer. A general <xex>meditates</xex> an attack upon
the enemy; he <xex>contemplates</xex> or <xex>intends</xex> undertaking
it at the earliest convenient season.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meditation</ent><br/
<hw>Med`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>meditacioun</ets>, F. <ets>m<eacute/ditation</ets>, fr. L.
<ets>meditatio</ets>.]</ety> <sn>1.</sn> <def>The act of meditating;
close or continued thought; the turning or revolving of a subject in the
mind; serious contemplation; reflection; musing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let the words of my mouth and the <qex>meditation</qex> of my
heart be acceptable in thy sight.</q> <rj><qau>Ps. xix.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Thought; -- without regard to kind.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With wings as swift<br/
As <qex>meditation</qex> or the thoughts of love.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meditatist</ent><br/
<hw>Med"i*ta`tist</hw>, <pos>n.</pos> <def>One who is given to
meditation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meditative</ent><br/
<hw>Med"i*ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>meditativus</ets>: cf. F. <ets>m<eacute/ditatif</ets>.]</ety>
<def>Disposed to meditate, or to meditation; <as>as, a
<ex>meditative</ex> man; a <ex>meditative</ex> mood.</as></def> --
<wordforms><wf>Med"i*ta*tive*ly</wf>, <pos>adv.</pos> --
<wf>Med"i*ta*tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mediterranean</ent><br/
<hw>Med`i*ter*ra"ne*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mediterraneus</ets>; <ets>medius</ets> middle + <ets>terra</ets>
land. See <er>Mid</er>, and <er>Terrace</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Inclosed, or nearly inclosed, with land; <as>as, the
<ex>Mediterranean</ex> Sea, between Europe and Africa</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inland; remote from the ocean.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cities, as well <qex>mediterranean</qex> as maritime.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of, pertaining to, or located in the Mediterranean
Sea or on the adjacent lands; <as>as, <ex>Mediterranean</ex> trade; a
<ex>Mediterranean</ex> voyage; a <ex>Mediterranean</ex>
plant.</as></def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mediterranean fruit fly</ent><br/
<hw>Med`i*ter*ra"ne*an fruit" fly</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>A small two-winged fly (<spn>Ceratitis capitata</spn>), a native of
the Mediterranean countries but now widely distributed in warm regions,
which can cause great damage to citrus and other succulent fruit crops
when present in large numbers. It is black and white and irregularly
banded. It lays eggs in ripening oranges, peaches, and other fruits;
when the eggs hatch into larvae (maggots) inside the fruit, they cause
the fruit to decay and fall, and make the fruit unsaleable. It is also
popularly called the <altname>medfly</altname>.</def> <note>The
possibility of infestation by this and other crop pests has caused some
states such as California, where fruit is a major export, to ban the
importation of fruit from other regions. Outbreaks of infestation with
the medfly have caused California to mobilize major eradication
campaigns and have been the subject of political faultfinding. The
eradication tactic, of releasing sterile males to break the reproductive
cycle, has been used to deal with outbreaks of the medfly.</note><br/
[<source>PJC</source>]</p>

<p><ent>Mediterraneous</ent><br/
<hw>Med`i*ter*ra"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Inland.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medium</ent><br/
<hw>Me"di*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Media</plw> <pr>(#)</pr>, <plw>E</plw>. <plw>Mediums</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>medium</ets> the middle, fr.
<ets>medius</ets> middle. See <er>Mid</er>, and cf.
<er>Medius</er>.]</ety> <sn>1.</sn> <def>That which lies in the middle,
or between other things; intervening body or quantity.</def>
<specif>Hence, specifically:</specif> <sd>(a)</sd> <def>Middle place or
degree; mean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The just <qex>medium</qex> . . . lies between pride and
abjection.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <fld>(Math.)</fld> <def>See <er>Mean</er>.</def>
<sd>(c)</sd> <fld>(Logic)</fld> <def>The mean or middle term of a
syllogism; that by which the extremes are brought into
connection.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A substance through which an effect is transmitted
from one thing to another; <as>as, air is the common <ex>medium</ex> of
sound</as>.</def> <specif>Hence:</specif> <def>The condition upon which
any event or action occurs; necessary means of motion or action; that
through or by which anything is accomplished, conveyed, or carried
on;</def> <specif>specifically,</specif> <def>in animal magnetism,
spiritualism, etc., a person through whom the action of another being is
said to be manifested and transmitted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whether any other liquors, being made <qex>mediums</qex>, cause a
diversity of sound from water, it may be tried.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I must bring together<br/
All these extremes; and must remove all <qex>mediums</qex>.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An average.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>medium</qex> of six years of war, and six years of
peace.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A trade name for printing and writing paper of
certain sizes. See <er>Paper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Paint.)</fld> <def>The liquid vehicle with which
dry colors are ground and prepared for application.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Microbiology)</fld> <def>A source of nutrients in
which a microorganism is placed to permit its growth, cause it to
produce substances, or observe its activity under defined conditions;
also called <altname>culture medium</altname> or <altname>growth
medium</altname>. The <ex>medium</ex> is usually a solution of nutrients
in water, or a similar solution solidified with gelatin or
agar.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>A means of transmission of news, advertising, or
other messages from an information source to the public, also called a
<altname>news medium</altname>, such as a newspaper or radio; used
mostly in the plural form, i. e. <altname>news media</altname> or
<altname>media</altname>. See 1st <er>media</er>{2}.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Circulating medium</b></col>, <cd>a current medium of
exchange, whether coin, bank notes, or government notes.</cd> --
<col><b>Ethereal medium</b></col> <fld>(Physics)</fld>, <cd>the
ether.</cd> -- <col><b>Medium of exchange</b></col>, <cd>that which is
used for effecting an exchange of commodities -- money or current
representatives of money.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medium</ent><br/
<hw>Me"di*um</hw>, <pos>a.</pos> <def>Having a middle position or
degree; mean; intermediate; medial; <as>as, a horse of <ex>medium</ex>
size; a decoction of <ex>medium</ex> strength.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medium-sized</ent><br/
<hw>Me"di*um-sized`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
medium size; <as>as, a <ex>medium-sized</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medius</ent><br/
\'d8<hw>Me"di*us</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Medii</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. L. <ets>medius</ets>
middle. See <er>Medium</er>.]</ety> <fld>(Anat.)</fld> <def>The third or
middle finger; the third digit, or that which corresponds to
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medjidieh</ent><br/
<ent>Medjidie</ent><br/
<mhw>{ <hw>Me*dji"di*e</hw>, <hw>Me*dji"di*eh</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Turk. <ets>maj<imac/dieh</ets> (prop. fem. a., fr.
Ar. <ets>mej<imac/d</ets> glorious); -- so called after the sultan Abdul
<etsep>Mejid</etsep>, lit., <ldquo/servant of the Glorious One,<rdquo/
i.e., of God.]</ety> <sn>1.</sn> <sd>(a)</sd> <def>A silver coin of
Turkey formerly rated at twenty, but since 1880 at nineteen, piasters
(about 83 cents).</def> <sd>(b)</sd> <def>A gold coin of Turkey equal
(in 1913) to one hundred piastres ($4.396 or 18s. <frac34/d.); a lira,
or Turkish pound.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A Turkish honorary order established in 1851 by
<persfn>Abdul-Mejid</persfn>, having as its badge a medallion surrounded
by seven silver rays and crescents. It is often conferred on
foreigners.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Medlar</ent><br/
<hw>Med"lar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>medler</ets>
medlar tree, OF. <ets>meslier</ets>, F. <ets>n<eacute/flier</ets>, L.
<ets>mespilum</ets>, <ets>mespilus</ets>, Gr. <?/, <?/. Cf.
<er>Naseberry</er>.]</ety> <def>A tree of the genus <gen>Mespilus</gen>
(<spn>Mespilus Germanica</spn>); also, the fruit of the tree. The fruit
is something like a small apple, but has a bony endocarp. When first
gathered the flesh is hard and austere, and it is not eaten until it has
begun to decay.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Japan medlar</b></col> <fld>(Bot.)</fld>, <cd>the loquat.
See <er>Loquat</er>.</cd> -- <col><b>Neapolitan medlar</b></col>
<fld>(Bot.)</fld>, <cd>a kind of thorn tree (<spn>Crataegus
Azarolus</spn>); also, its fruit.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medle</ent><br/
<hw>Med"le</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Meddle</er>.]</ety> <def>To mix; to mingle; to meddle.</def>
<altsp>[Written also <asp>medly</asp>.]</altsp> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medley</ent><br/
<hw>Med"ley</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Medleys</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>medlee</ets>, OF.
<ets>mesl<eacute/e</ets>, <ets>medl<eacute/e</ets>,
<ets>mell<eacute/e</ets>, F. <ets>m<ecir/l<eacute/e</ets>. See
<er>Meddle</er>, and cf. <er>Mel<eacute/e</er>, <er>Mellay</er>.]</ety>
<sn>1.</sn> <def>A mixture; a mingled and confused mass of ingredients,
usually inharmonious; a jumble; a hodgepodge; -- often used
contemptuously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>medley</qex> of philosophy and war.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Love is a <qex>medley</qex> of endearments, jars,<br/
Suspicions, reconcilements, wars.</q> <rj><qau>W. Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The confusion of a hand to hand battle; a brisk,
hand to hand engagement; a m<ecir/l<eacute/e.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A composition of passages detached
from several different compositions; a potpourri.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Medley</xex> is usually applied to vocal,
<contr>potpourri</contr> to instrumental, compositions.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A cloth of mixed colors.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medley</ent><br/
<hw>Med"ley</hw>, <pos>a.</pos> <sn>1.</sn> <def>Mixed; of mixed
material or color.</def> <mark>[Obs.]</mark> <ldquo/A <xex>medl<eacute/
coat</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mingled; confused.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medly</ent><br/
<hw>Med"ly</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Medle</er>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medoc</ent><br/
\'d8<hw>M<eacute/`doc"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Mayduke</er>.]</ety> <def>A class of claret wines, including several
varieties, from the district of M<eacute/doc in the department of
Gironde.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medregal</ent><br/
<hw>Med"re*gal</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Bonito</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medrick</ent><br/
<hw>Med"rick</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Zool.)</fld> <def>A species of gull or
tern.</def> <mark>[Prov.]</mark> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medulla</ent><br/
<hw>Me*dul"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>Marrow; pith; hence, essence.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The marrow of bones; the deep or
inner portion of an organ or part; <as>as, the <ex>medulla</ex>, or
medullary substance, of the kidney</as>; specifically, the medula
oblongata.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A soft tissue, occupying the
center of the stem or branch of a plant; pith.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>See <cref>medulla oblongata</cref>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Medulla oblongata</b></col>. <ety>[L., oblong
medulla]</ety> <fld>(Anat.)</fld>, <cd>the posterior part of the brain
connected with the spinal cord. It includes all the hindbrain except the
cerebellum and pons, and from it a large part of the cranial nerves
arise. It controls very largely respiration, circulation, swallowing,
and other functions, and is the most vital part of the brain; -- called
also <altname>bulb of the spinal cord</altname>. See
<er>Brain</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medullar</ent><br/
<hw>Me*dul"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Medullary</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medullary</ent><br/
<hw>Med"ul*la*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>medullaris</ets>, fr. <ets>medulla</ets> marrow: cf. F.
<ets>m<eacute/dullaire</ets>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld>
<sd>(a)</sd> <def>Pertaining to, consisting of, or resembling, marrow or
medulla.</def> <sd>(b)</sd> <def>Pertaining to the medula
oblongata.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Filled with spongy pith;
pithy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Medullary groove</b></col> <fld>(Anat.)</fld>, <cd>a
groove, in the epiblast of the vertebrate blastoderm, the edges of which
unite, making a tube (the medullary canal) from which the brain and
spinal cord are developed.</cd> -- <col><b>Medullary rays</b></col>
<fld>(Bot.)</fld>, <cd>the rays of cellular tissue seen in a transverse
section of exogenous wood, which pass from the pith to the bark.</cd> --
<col><b>Medullary sheath</b></col> <fld>(Anat.)</fld>, <cd>the layer of
white semifluid substance (myelin), between the primitive sheath and
axis cylinder of a medullated nerve fiber.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medullated</ent><br/
<hw>Me*dul"la*ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Furnished with a medulla or marrow, or with a medullary sheath;
<as>as, a <ex>medullated</ex> nerve fiber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medullin</ent><br/
<hw>Me*dul"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/dulline</ets>.]</ety> <fld>(Bot. Chem.)</fld> <def>A
variety of lignin or cellulose found in the medulla, or pith, of certain
plants. Cf. <er>Lignin</er>, and <er>Cellulose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medusa</ent><br/
\'d8<hw>Me*du"sa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <sn>1.</sn> <fld>(Class. Myth.)</fld> <def>The Gorgon; or
one of the Gorgons whose hair was changed into serpents, after which all
who looked upon her were turned into stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <plu>[<it>pl.</it> <plw>Medusae</plw>
<pr>(<?/)</pr>.]</plu> <fld>(Zool.)</fld> <def>Any free swimming
acaleph; a jellyfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The larger <xex>medusae</xex> belong to the Discophora,
and are sometimes called <stype>covered-eyed medusae</stype>; others,
known as <stype>naked-eyed medusae</stype>, belong to the Hydroidea, and
are usually developed by budding from hydroids. See <er>Discophora</er>,
<er>Hydroidea</er>, and <er>Hydromedusa</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Medusa bud</b></col> <fld>(Zool.)</fld>, <cd>one of the
buds of a hydroid, destined to develop into a gonophore or medusa. See
<er>Athecata</er>, and <er>Gonotheca</er>.</cd> -- <col><b>Medusa's
head</b></col>. <sd>(a)</sd> <fld>(Zool.)</fld> <cd>An astrophyton</cd>.
<sd>(b)</sd> <fld>(Astron.)</fld> <cd>A cluster of stars in the
constellation Perseus. It contains the bright star Algol.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medusian</ent><br/
<hw>Me*du"si*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A medusa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medusiform</ent><br/
<hw>Me*du"si*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Medusa</ets> + <ets>-form</ets>.]</ety> <fld>(Zool.)</fld>
<def>Resembling a medusa in shape or structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Medusoid</ent><br/
<hw>Me*du"soid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Medusa</ets>
+ <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like a medusa; having
the fundamental structure of a medusa, but without a locomotive disk; --
said of the sessile gonophores of hydroids.</def> -- <def2><pos>n.</pos>
<def>A sessile gonophore. See <xex>Illust.</xex> under
<er>Gonosome</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meech</ent><br/
<hw>Meech</hw> <pr>(m<emac/ch)</pr>, <pos>v. i.</pos> <def>See
<er>Mich</er>.</def> <mark>[Obs. or Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meed</ent><br/
<hw>Meed</hw> <pr>(m<emac/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mede</ets>, AS. <ets>m<emac/d</ets>, <ets>meord</ets>; akin to OS.
<ets>m<emac/da</ets>, OHG. <ets>miata</ets>, <ets>mieta</ets>, G.
<ets>miethe</ets> hire, Goth. <ets>mizd<omac/</ets> reward, Bohem. &
Russ. <ets>mzda</ets>, Gr. <grk>misqo`s</grk>, Skr.
<ets>m<imac/dha</ets>. <root/276.]</ety> <sn>1.</sn> <def>That which is
bestowed or rendered in consideration of merit; reward;
recompense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A rosy garland was the victor's <qex>meed</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Merit or desert; worth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>meed</qex> hath got me fame.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A gift; also, a bride.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meed</ent><br/
<hw>Meed</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To reward; to
repay.</def> <mark>[Obs.]</mark> <rj><au>Waytt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deserve; to merit.</def> <mark>[Obs.]</mark>
<rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meedful</ent><br/
<hw>Meed"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Worthy of meed,
reward, or recompense; meritorious.</def> <ldquo/<xex>Meedful</xex>
works.<rdquo/ <rj><au>Wiclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meedfully</ent><br/
<hw>Meed"ful*ly</hw>, <pos>adv.</pos> <def>According to merit;
suitably.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meek</ent><br/
<hw>Meek</hw> <pr>(m<emac/k)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Meeker</adjf>
<pr>(m<emac/k"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Meekest</adjf>.]</amorph> <ety>[OE. <ets>mek</ets>,
<ets>meoc</ets>; akin to Icel. <ets>mj<umac/kr</ets> mild, soft, Sw.
<ets>mjuk</ets>, Dan. <ets>myg</ets>, D. <ets>muik</ets>, Goth.
<ets>muka</ets>m<omac/dei gentleness.]</ety> <sn>1.</sn> <def>Mild of
temper; not easily provoked or irritated; patient under injuries; not
vain, or haughty, or resentful; forbearing; submissive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now the man Moses was very <qex>meek</qex>.</q> <rj><qau>Num. xii.
3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Evincing mildness of temper, or patience;
characterized by mildness or patience; <as>as, a <ex>meek</ex> answer; a
<ex>meek</ex> face.</as></def> <ldquo/Her <xex>meek</xex> prayer.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Gentle; mild; soft; yielding; pacific;
unassuming; humble. See <er>Gentle</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meeken</ent><br/
<ent>Meek</ent><br/
<mhw>{ <hw>Meek</hw>, <hw>Meek"en</hw> <pr>(-'n)</pr> }</mhw>, <pos>v.
t.</pos> <def>To make meek; to nurture in gentleness and humility.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meekly</ent><br/
<hw>Meek"ly</hw>, <pos>adv.</pos> <def>In a meek manner.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meekness</ent><br/
<hw>Meek"ness</hw>, <pos>n.</pos> <def>The quality or state of being
meek.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meer</ent><br/
<hw>Meer</hw> <pr>(m<emac/r)</pr>, <pos>a.</pos> <def>Simple; unmixed.
See <er>Mere</er>, <pos>a.</pos></def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meer</ent><br/
<hw>Meer</hw>, <pos>n.</pos> <def>See <er>Mere</er>, a lake.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meer</ent><br/
<hw>Meer</hw>, <pos>n.</pos> <def>A boundary. See
<er>Mere</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meerkat</ent><br/
\'d8<hw>Meer"kat</hw> <pr>(m<emac/r"k<acr/t)</pr>, <pos>n.</pos>
<ety>[D.]</ety> <fld>(Zool.)</fld> <def>A South African carnivore
(<spn>Suricata suricata</spn>, formerly <spn>Cynictis
penicillata</spn>), allied to the ichneumons, having a lemurlike face
and only four toes; called also <altname>yellow mongoose</altname> and
<altname>suricate</altname>.</def> <altsp>[Also spelled
<asp>mierkat</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>While his compatrioits scuffle about in the sand for delicious
scorpions or fat, tasty mice, one <qex>meerkat</qex> stands alone, bolt
upright on an exposed perch, scanning for hawks with dark eyes wide,
ready to call out at the first sign of danger. Like other such guards in
the animal kingdom, these endearingly vulnerable <qex>meerkat</qex>
sentinels have long impressed biologists as true altruists -- creatures
willing to forgo food and brave danger to protect others.<br/
Now a study in the current <publ>Science</publ> suggests that these
beasts may not be such adorable heroes after all. Researchers have
discovered that <qex>meerkats</qex> abandon their hunting to act as
guards only when their bellies are good and full. And they appear to do
so, not as an act of noble daring, but because by being the first to see
a predator, they can be sure of being the first down a hole and out of
harm's way. Standing guard, researchers concluded, may be the safest
thing to do once a <qex>meerkat</qex> has had enough to eat.<br/
. . .<br/
Even the adorable <qex>meerkat</qex> may yet redeem itself as a bit of
an altruist. Although being a sentinel may itself not entail great risk,
it is hard to imagine a selfish reason for their giving a shout of
warning before dashing for cover. . . .</q> <rj><qau>Carol Kaesuk Yoon
(N. Y. Times, June 8, 1999 p. F3)</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>Meerschaum</ent><br/
<hw>Meer"schaum</hw> <pr>(m<emac/r"sh<add/m; 277)</pr>, <pos>n.</pos>
<ety>[G., lit., sea foam; <ets>meer</ets> sea + <ets>schaum</ets> foam;
but it perh. is a corruption of the Tartaric name <ets>myrsen</ets>. Cf.
<er>Mere</er> a lake, and <er>Scum</er>.]</ety> <sn>1.</sn>
<fld>(Min.)</fld> <def>A fine white claylike mineral, soft, and light
enough when in dry masses to float in water. It is a hydrous silicate of
magnesia, and is obtained chiefly in Asia Minor. It is manufactured into
tobacco pipes, cigar holders, etc. Also called
<altname>sepiolite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tobacco pipe made of this mineral; a
<ecol><b>meerschaum pipe</b></ecol>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meet</ent><br/
<hw>Meet</hw> <pr>(m<emac/t)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Met</conjf> <pr>(m<ecr/t)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Meeting</conjf>.]</vmorph> <ety>[OE. <ets>meten</ets>,
AS. <ets>m<emac/tan</ets>, fr. <ets>m<omac/t</ets>,
<ets>gem<omac/t</ets>, a meeting; akin to OS. <ets>m<omac/tian</ets> to
meet, Icel. <ets>maeta</ets>, Goth. <ets>gam<omac/tjan</ets>. See
<er>Moot</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To join, or come
in contact with; esp., to come in contact with by approach from an
opposite direction; to come upon or against, front to front, as
distinguished from contact by following and overtaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come in collision with; to confront in conflict;
to encounter hostilely; <as>as, they <ex>met</ex> the enemy and defeated
them; the ship <ex>met</ex> opposing winds and currents.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To come into the presence of without contact; to
come close to; to intercept; to come within the perception, influence,
or recognition of; <as>as, to <ex>meet</ex> a train at a junction; to
<ex>meet</ex> carriages or persons in the street; to <ex>meet</ex>
friends at a party; sweet sounds <ex>met</ex> the ear.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>His daughter came out to <qex>meet</qex> him.</q> <rj><qau>Judg.
xi. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To perceive; to come to a knowledge of; to have
personal acquaintance with; to experience; to suffer; <as>as, the eye
<ex>met</ex> a horrid sight; he <ex>met</ex> his fate.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of vice or virtue, whether blest or curst,<br/
Which <qex>meets</qex> contempt, or which compassion first.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To come up to; to be even with; to equal; to match;
to satisfy; to answer; <as>as, to <ex>meet</ex> one's expectations; the
supply <ex>meets</ex> the demand.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To meet half way</b></col>, <cd>literally, to go half the
distance between in order to meet (one); hence, figuratively, to yield
or concede half of the difference in order to effect a compromise or
reconciliation with.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meet</ent><br/
<hw>Meet</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To come together by
mutual approach; esp., to come in contact, or into proximity, by
approach from opposite directions; to join; to come face to face; to
come in close relationship; <as>as, we <ex>met</ex> in the street; two
lines <ex>meet</ex> so as to form an angle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, when <qex>meet</qex> now<br/
Such pairs in love and mutual honor joined !</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come together with hostile purpose; to have an
encounter or conflict.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Weapons more violent, when next we <qex>meet</qex>,<br/
May serve to better us and worse our foes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To assemble together; to congregate; <as>as,
Congress <ex>meets</ex> on the first Monday of December</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . appointed a day to <qex>meet</qex> together.</q>
<rj><qau>2. Macc. xiv. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To come together by mutual concessions; hence, to
agree; to harmonize; to unite.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To meet with</b></col>. <sd>(a)</sd> <cd>To light upon;
to find; to come to; -- often with the sense of unexpectedness.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>met with</qex> many things worthy of observation.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <cd>To join; to unite in company.</cd> <au>Shak.</au>
<sd>(c)</sd> <cd>To suffer unexpectedly; <as>as, to <ex>meet with</ex> a
fall; to <ex>meet with</ex> a loss</as>.</cd> <sd>(d)</sd> <cd>To
encounter; to be subjected to.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Prepare <qex>to meet with</qex> more than brutal fury<br/
From the fierce prince.</q> <rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <cd>To obviate.</cd> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Meet</ent><br/
<hw>Meet</hw>, <pos>n.</pos> <def>An assembling together; esp., the
assembling of huntsmen for the hunt; also, the persons who so assemble,
and the place of meeting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meet</ent><br/
<hw>Meet</hw>, <pos>a.</pos> <ety>[OE. <ets>mete</ets> fitting,
moderate, scanty, AS. <ets>m<aemac/te</ets> moderate; akin to
<ets>gemet</ets> fit, meet, <ets>metan</ets> to mete, and G.
<ets>m<aum/ssig</ets> moderate, <ets>gem<aum/ss</ets> fitting. See
<er>Mete</er>.]</ety> <def>Suitable; fit; proper; appropriate;
qualified; convenient.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was <qex>meet</qex> that we should make merry.</q>
<rj><qau>Luke xv. 32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be meet with</b></col>, <cd>to be even with; to be
equal to.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 909 --></p>

<p><ent>Meet</ent><br/
<hw>Meet</hw> <pr>(m<emac/t)</pr>, <pos>adv.</pos> <def>Meetly.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meeten</ent><br/
<hw>Meet"en</hw> <pr>(m<emac/t'n)</pr>, <pos>v. t.</pos> <def>To render
fit.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meeter</ent><br/
<hw>Meet"er</hw> <pr>(m<emac/t"<etil/r)</pr>, <pos>n.</pos> <def>One who
meets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meeth</ent><br/
<hw>Meeth</hw> <pr>(m<emac/th)</pr>, <pos>n.</pos> <def>Mead. See
<er>Meathe</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meeting</ent><br/
<hw>Meet"ing</hw> <pr>(m<emac/t"<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A coming together; an assembling; <as>as, the <ex>meeting</ex> of
Congress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A junction, crossing, or union; <as>as, the
<ex>meeting</ex> of the roads or of two rivers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A congregation; a collection of people; a
convention; <as>as, a large <ex>meeting</ex>; an harmonious
<ex>meeting</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An assembly for worship; <as>as, to attend
<ex>meeting</ex> on Sunday</as>; -- in England, applied distinctively
and disparagingly to the worshiping assemblies of Dissenters.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Conference; assembly; company; convention;
congregation; junction; confluence; union.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meetinghouse</ent><br/
<hw>Meet"ing*house`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A house used
as a place of worship; a church; -- in England, applied only to a house
so used by Dissenters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meetly</ent><br/
<hw>Meet"ly</hw>, <pos>adv.</pos> <def>Fitly; suitably;
properly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meetness</ent><br/
<hw>Meet"ness</hw>, <pos>n.</pos> <def>Fitness; suitableness;
propriety.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalo-</ent><br/
<ent>Mega</ent><br/
<ent>Meg-</ent><br/
<mhw>{ <hw>Meg-</hw> <pr>(m<ecr/g-)</pr>, <hw>Meg"a</hw>
<pr>(m<ecr/g"<adot/-)</pr>, <hw>Meg"a*lo-</hw>
<pr>(m<ecr/g"<adot/*l<osl/-)</pr> }</mhw>. <ety>[Gr. <grk>me`gas</grk>,
gen. <grk>mega`loy</grk>, great.]</ety> <def>Combining forms signifying:
<sd>(a)</sd> <sig>Great</sig>, <sig>extended</sig>, <sig>powerful</sig>;
<as>as, <ex>mega</ex>scope, <ex>mega</ex>cosm</as>.</def> <sd>(b)</sd>
<fld>(Metric System, Elec., Mech., etc.)</fld> <def><sig>A million
times</sig>, <sig>a million of</sig>; <as>as, <ex>mega</ex>byte, a
million bytes; <ex>mega</ex>watt, a million watts; <ex>mega</ex>meter, a
million meters; <ex>mega</ex>farad, a million farads; <ex>meg</ex>ohm, a
million ohms</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Megacephalous</ent><br/
<ent>Megacephalic</ent><br/
<mhw>{ <hw>Meg`a*ce*phal"ic</hw>
<pr>(m<ecr/g`<adot/*s<esl/*f<acr/l"<icr/k)</pr>,
<hw>Meg`a*ceph"a*lous</hw>
<pr>(m<ecr/g`<adot/*s<ecr/f"<adot/*l<ucr/s)</pr> }</mhw>, <pos>a.</pos>
<ety>[<ets>Mega-</ets> + Gr. <grk>kefalh`</grk> head.]</ety>
<fld>(Biol.)</fld> <def>Large headed; -- applied to animals, and to
plants when they have large flower heads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megaceros</ent><br/
\'d8<hw>Me*gac"e*ros</hw> <pr>(m<esl/*g<acr/s"<esl/*r<ocr/s)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>me`gas</grk> great +
<grk>ke`ras</grk> horn.]</ety> <fld>(Paleon.)</fld> <def>The Irish
elk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megachile</ent><br/
<hw>Meg"a*chile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ Gr. <?/ lip.]</ety> <fld>(Zool.)</fld> <def>A leaf-cutting bee of the
genus <gen>Megachilus</gen>. See <cref>Leaf cutter</cref>, under
<er>Leaf</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megacosm</ent><br/
<hw>Meg"a*cosm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> +
Gr. <?/ world.]</ety> <def>See <er>Macrocosm</er>.</def>
<rj><au>Croft.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megacoulomb</ent><br/
<hw>Meg`a*cou`lomb"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mega-</ets> + <ets>coulomb</ets>.]</ety> <fld>(Elec.)</fld>
<def>A million coulombs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megaderm</ent><br/
<hw>Meg"a*derm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> +
Gr. <?/ skin.]</ety> <fld>(Zool.)</fld> <def>Any one of several species
of Old World blood-sucking bats of the genus
<gen>Megaderma</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megadyne</ent><br/
<hw>Meg"a*dyne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> +
<ets>dyne</ets>.]</ety> <fld>(Physics)</fld> <def>One of the larger
measures of force, amounting to one million dynes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megafarad</ent><br/
<hw>Meg"a*far`ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ <ets>farad</ets>.]</ety> <fld>(Elec.)</fld> <def>One of the larger
measures of electrical capacitance, amounting to one million farads; a
macrofarad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>megakaryocyte</ent><br/
<hw>meg`a*kar"y*o*cyte</hw>
<pr>(m<ecr/g`<adot/*k<acr/r"<icr/*<osl/*s<imac/t)</pr> <pos>n.</pos>
<fld>(Anat.)</fld> <def>A large bone marrow cell not usually found in
the circulating blood; it is regarded as the precursors of blood
platelets; it is up to 100 <mu/m in diameter, with a polyploid nucleus.
Also referred to as <altname>megacaryocyte</altname>,
<altname>megalokaryocyte</altname>, and
<altname>thromboblast</altname>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>megakaryocytic</ent><br/
<hw>megakaryocytic</hw> <pos>adj.</pos> <def>Of or pertaining to a
megakaryocyte.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Megalerg</ent><br/
<hw>Meg"a*lerg</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Megalo-</ets>
+ <ets>erg</ets>.]</ety> <fld>(Physics)</fld> <def>A million ergs; a
megerg.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalesian</ent><br/
<hw>Meg`a*le"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Megalesius</ets>, fr. Gr. <grk>Mega`lh</grk> the Great, a surname
of Cybele, the Magna Mater.]</ety> <def>Pertaining to, or in honor of,
Cybele; <as>as, the <ex>Megalesian</ex> games at Rome</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalethoscope</ent><br/
<hw>Meg`a*leth"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mega-</ets> + <ets>alethoscope</ets>.]</ety> <def>An optical
apparatus in which pictures are viewed through a large lens with
stereoptical effects. It is often combined with the
stereoscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalith</ent><br/
<hw>Meg"a*lith</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> +
<ets>-lith</ets>; cf. F. <ets>m<eacute/galithe</ets>.]</ety> <def>A
large stone; especially, a large stone used in constructing ancient
monuments.</def> -- <wordforms><wf>Meg`a*lith"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>megalithic</ent><br/
<hw>megalithic</hw> <pos>adj.</pos> <def>Of or pertaining to megaliths
or the period during which they were erected; <as>as,
<ex>megalithic</ex> monuments like Stonehenge</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Megalo-</ent><br/
<hw>Meg"a*lo-</hw> <pr>(?)</pr>. <def>See <er>Meg-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalobatrachus</ent><br/
<hw>Megalobatrachus</hw> <pos>prop. n.</pos> <def>A genus of giant
salamanders; in some classifications included in the genus
<gen>Cryptobranchus</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Megalobatrachus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Megalocephaly</ent><br/
<ent>Megalocephalia</ent><br/
<mhw>{ \'d8<hw>Meg`a*lo*ce*pha"li*a</hw> <pr>(?)</pr>,
<hw>Meg`a*lo*ceph"a*ly</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos>
<ety>[NL. <ets>megalocephalia</ets>, fr. Gr. <?/ having a large
head.]</ety> <fld>(Med.)</fld> <def>The condition of having an
abnormally large head; called also <altname>megacephaly</altname>.</def>
-- <wordforms><wf>Meg`a*lo*ce*phal"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Megalocyte</ent><br/
<hw>Meg"a*lo*cyte</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Megalo-</ets> + Gr. <?/ a hollow vessel.]</ety>
<fld>(Physiol.)</fld> <def>A large, flattened red blood cell corpuscle
having no nucleus, twice the diameter of the ordinary red corpuscle,
found in considerable numbers in the blood in profound
anaemia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalomania</ent><br/
<hw>Meg`a*lo*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
<ets>megalo-</ets> + <ets>mania</ets>.]</ety> <fld>(Pathol.)</fld>
<def>A form of mental alienation in which the patient has grandiose
delusions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>megalomanic</ent><br/
<ent>megalomaniacal</ent><br/
<mhw><hw>megalomaniacal</hw>, <hw>megalomanic</hw></mhw> <pos>adj.</pos>
<def>Suffering from megalomania.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Megalonychidae</ent><br/
<hw>Megalonychidae</hw> <pos>prop. n.</pos> <def>A natural family
consisting of the two-toed sloths.</def><br/
<syn><b>Syn. --</b> family <fam>Megalonychidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Megalonyx</ent><br/
\'d8<hw>Meg`a*lon"yx</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>me`gas</grk>, <grk>mega`lh</grk>, great + <grk>'o`nyx</grk>
claw.]</ety> <fld>(Paleon.)</fld> <def>An extinct quaternary mammal, of
great size, allied to the sloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalophonous</ent><br/
<hw>Meg`a*loph"o*nous</hw>
<pr>(m<ecr/g`<adot/*l<ocr/f"<osl/*n<ucr/s)</pr>, <pos>a.</pos>
<ety>[<ets>Megalo-</ets> + Gr. <grk>fwnh`</grk> voice.]</ety>
<def>Having a loud voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalopolis</ent><br/
<ent>Megapolis</ent><br/
<mhw><hw>Meg`a*lop"o*lis</hw>, <hw>Meg`a"po*lis</hw></mhw>
<pr>(m<ecr/g`<adot/*l<ocr/p"<osl/*l<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>megalo`polis</grk>; <grk>me`gas</grk>,
<grk>mega`lh</grk>, great + <grk>po`lis</grk> city.]</ety> <sn>1.</sn>
<def>A chief city; a very large city; a metropolis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A region in which the suburbs of several large
cities merge to form one large predominantly urbanized area.</def><br/
[<source>PJC</source>]</p>

<p><ent>Megalops</ent><br/
<hw>Meg"a*lops</hw> <pr>(m<ecr/g"<adot/*l<ocr/ps)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>me`gas</grk>, <grk>-a`loy</grk>, large +
<grk>'w`ps</grk> eye.]</ety> <fld>(Zool.)</fld> <sn>1.</sn> <def>A
larva, in a stage following the zoea, in the development of most crabs.
In this stage the legs and abdominal appendages have appeared, the
abdomen is relatively long, and the eyes are large. Also used
adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A large fish; the tarpum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>megalopsychy</ent><br/
<hw>meg`a*lop"sy*chy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Megalo-</ets> + Gr. <grk>psychh`</grk> soul, mind.]</ety>
<def>Greatness of soul.</def> <mark>[Obs. & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megalosaurus</ent><br/
<ent>Megalosaur</ent><br/
<mhw>{ <hw>Meg"a*lo*saur`</hw> <pr>(?)</pr>,
\'d8<hw>Meg`a*lo*sau"rus</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[NL. <ets>megalosaurus</ets>, fr. Gr. <grk>me`gas</grk>,
<grk>mega`lh</grk>, great + <grk>say^ros</grk> lizard: cf. F.
<ets>m<eacute/galosaure</ets>.]</ety> <fld>(Paleon.)</fld> <def>A
gigantic carnivorous dinosaur, whose fossil remains have been found in
England and elsewhere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megameter</ent><br/
<hw>Me*gam"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ <ets>-meter</ets>: cf. F. <ets>m<eacute/gam<egrave/tre</ets>.]</ety>
<fld>(Physics)</fld> <sn>1.</sn> <def>An instrument for determining
longitude by observation of the stars.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A micrometer.</def> <mark>[R. & Obs.]</mark>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megametre</ent><br/
<ent>Megameter</ent><br/
<mhw>{ <hw>Meg"a*me`ter</hw>, <hw>Meg"a*me`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> + <ets>meter</ets>,
<ets>metre</ets>, n., 2.]</ety> <def>In the metric system, one million
meters, or one thousand kilometers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megampere</ent><br/
<hw>Meg`am`p<egrave/re"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mega-</ets> + <ets>amp<egrave/re</ets>.]</ety>
<fld>(Elec.)</fld> <def>A million amp<egrave/res.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megaphone</ent><br/
<hw>Meg"a*phone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ Gr. <grk>fwnh`</grk> voice.]</ety> <def>A device to magnify sound, or
direct it in a given direction in a greater volume, as a very large
funnel used as an ear trumpet or as a speaking trumpet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megaphyton</ent><br/
\'d8<hw>Me*gaph"y*ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>me`gas</grk> great + <grk>fyto`n</grk> plant.]</ety>
<fld>(Paleon.)</fld> <def>An extinct genus of tree ferns with large,
two-ranked leaves, or fronds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megapode</ent><br/
<hw>Meg"a*pode</hw> <pr>(m<ecr/g"<adot/*p<omac/d)</pr>, <pos>n.</pos>
<ety>[<ets>Mega-</ets> + Gr. <grk>poy`s</grk>, <grk>podo`s</grk>,
foot.]</ety> <fld>(Zool.)</fld> <def>Any one of several species of
large-footed, gallinaceous birds of the genera <gen>Megapodius</gen> and
<gen>Leipoa</gen>, inhabiting Australia and other Pacific islands.
Called also <altname>mound builder</altname>, <altname>scrub
fowl</altname>, <altname>moundbird</altname>, and <altname>brush
turkey</altname>. See <cref>Jungle fowl</cref> <sd>(b)</sd> under
<er>Jungle</er>, and <er>Leipoa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megapolis</ent><br/
<hw>Me*gap"o*lis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`gas</grk> great + <grk>po`lis</grk> city.]</ety> <def>A
metropolis.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megaric</ent><br/
<ent>Megarian</ent><br/
<mhw>{ <hw>Me*ga"ri*an</hw> <pr>(?)</pr>, <hw>Me*gar"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Belonging, or pertaining, to
Megara, a city of ancient Greece.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Megarian school</b></col>, <it>or</it>
<col><b>Megaric school</b></col></mcol>, <cd>a school of philosophy
established at <city>Megara</city>, after the death of Socrates, by his
disciples, and remarkable for its logical subtlety.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megascope</ent><br/
<hw>Meg"a*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ <ets>-scope</ets>: cf. F. <ets>m<eacute/gascope</ets>.]</ety> <def>A
modification of the magic lantern (projector), used esp. for throwing a
magnified image of an opaque object on a screen, solar or artificial
light being used.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megascopical</ent><br/
<ent>Megascopic</ent><br/
<mhw>{ <hw>Meg`a*scop"ic</hw> <pr>(?)</pr>, <hw>Meg`a*scop"ic*al</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <sn>1.</sn> <fld>(Physics)</fld>
<def>Of or pertaining to the megascope or the projection upon a screen
of images of opaque objects.</def> <sd>(b)</sd> <def>Enlarged or
magnified; -- said of images or of photographic pictures, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Large enough to be seen; -- said
of the larger structural features and components of rocks which do not
require the use of the microscope to be perceived. Opposed to
<ant>microscopic</ant>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Megaseme</ent><br/
<hw>Meg"a*seme</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mega-</ets> +
Gr. <?/ sing, mark: cf. F. <ets>m<eacute/gas<egrave/me</ets>.]</ety>
<fld>(Anat.)</fld> <def>Having the orbital index relatively large;
having the orbits narrow transversely; -- opposed to
<contr>microseme</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megasse</ent><br/
<ent>Megass</ent><br/
<mhw>{ <hw>Me"gass"</hw> <pr>(?)</pr>, <hw>Me*gasse"</hw> }</mhw>,
<pos>n.</pos> <def>See <er>Bagasse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megasthene</ent><br/
<hw>Meg"as*thene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`gas</grk> great + <grk>sqe`nos</grk> strength.]</ety>
<fld>(Zool.)</fld> <def>One of a group which includes the higher orders
of mammals, having a large size as a typical characteristic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megasthenic</ent><br/
<hw>Meg`as*then"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a typically large size; belonging to the
megasthenes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megastome</ent><br/
<hw>Meg"a*stome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`gas</grk> great + <grk>sto`ma</grk> mouth.]</ety>
<fld>(Zool.)</fld> <def>One of a group of univalve shells, having a
large aperture or mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megatherium</ent><br/
<ent>Megathere</ent><br/
<mhw>{ <hw>Meg"a*there</hw> <pr>(?)</pr>, \'d8<hw>Meg`a*the"ri*um</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>megatherium</ets>,
fr. Gr. <grk>me`gas</grk> great + <grk>qhri`on</grk> beast.]</ety>
<fld>(Paleon.)</fld> <def>An extinct gigantic quaternary mammal, allied
to the ant-eaters and sloths. Its remains are found in South
America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megatheroid</ent><br/
<hw>Meg`a*the"roid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Megatherium</ets> + <ets>-oid</ets>.]</ety>
<fld>(Paleon.)</fld> <def>One of a family of extinct edentates found in
America. The family includes the megatherium, the megalonyx,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megavolt</ent><br/
<hw>Meg`a*volt"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ <ets>volt</ets>.]</ety> <fld>(Elec.)</fld> <def>One of the larger
measures of electro-motive force, amounting to one million
volts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megaweber</ent><br/
<hw>Meg`a*we"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets>
+ <ets>weber</ets>.]</ety> <fld>(Elec.)</fld> <def>A million
webers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megerg</ent><br/
<hw>Meg"erg`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> +
<ets>erg</ets>.]</ety> <fld>(Physics)</fld> <def>One of the larger
measures of work, amounting to one million ergs; -- called also
<altname>megalerg</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megilph</ent><br/
<ent>Megilp</ent><br/
<mhw>{ <hw>Me*gilp"</hw> <pr>(?)</pr>, <hw>Me*gilph"</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <fld>(Paint.)</fld> <def>A gelatinous compound of
linseed oil and mastic varnish, used by artists as a vehicle for
colors.</def> <altsp>[Written also <asp>magilp</asp>, and
<asp>magilph</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>MEGO</ent><br/
<hw>MEGO</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>M</ets>y
<ets>e</ets>yes <ets>g</ets>laze <ets>o</ets>ver.]</ety> <def>A very
dull article, speech, or book, which causes the reader or listener to
rapidly lose interest; -- often used of involved discussions of a
technical nature, especially in newspapers.</def> <mark>[Acronym,
Slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Megohm</ent><br/
<hw>Meg"ohm"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mega-</ets> +
<ets>ohm</ets>.]</ety> <fld>(Elec.)</fld> <def>One of the larger
measures of electrical resistance, amounting to one million
ohms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megrim</ent><br/
<hw>Me"grim</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>migrim</ets>, <ets>migrene</ets>, F. <ets>migraine</ets>, LL.
<ets>hemigrania</ets>, L. <ets>hemicrania</ets>, <ets>hemicranium</ets>,
Gr. <?/; <?/- half + <?/ skull. See <er>Hemi-</er> and <er>Cranium</er>,
and cf. <er>Hemicrania</er>, <er>Migraine</er>.]</ety> <sn>1.</sn>
<def>A kind of sick or nervous headache, usually periodical and confined
to one side of the head; now more commonly called <altname>migraine
headache</altname> or <altname>migraine</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A fancy; a whim; a freak; a humor; esp., in the
plural, lowness of spirits.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These are his <qex>megrims</qex>, firks, and melancholies.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <fld>(Far.)</fld> <def>A sudden vertigo
in a horse, succeeded sometimes by unconsciousness, produced by an
excess of blood in the brain; a mild form of apoplexy.</def>
<rj><au>Youatt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Megrim</ent><br/
<hw>Me"grim</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety>
<fld>(Zool.)</fld> <def>The British smooth sole, or scaldfish
(<spn>Psetta arnoglossa</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meibomian</ent><br/
<hw>Mei*bo"mi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of, pertaining to, or discovered by,
<persfn><etsep>Meibomius</etsep></persfn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meibomian glands</b></col>, <cd>the slender sebaceous
glands of the eyelids, which discharge, through minute orifices in the
edges of the lids, a fatty secretion serving to lubricate the adjacent
parts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meine</ent><br/
<hw>Meine</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Menge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meiny</ent><br/
<ent>Meine</ent><br/
<mhw>{ <hw>Mein"e</hw>, <hw>Mein"y</hw>, <pr>(<?/)</pr>, }</mhw>
<pos>n.</pos> <ety>[OF. <ets>maisni<eacute/e</ets>, <ets>maisnie</ets>.
See <er>Menial</er>.]</ety> <sn>1.</sn> <def>A family, including
servants, etc.; household; retinue; train.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer. Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Company; band; army.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meiocene</ent><br/
<hw>Mei"o*cene</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Geol.)</fld>
<def>See <er>Miocene</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meionite</ent><br/
<hw>Mei"o*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mei`wn</grk> smaller. So called in a allusion to the low pyramids
of the crystals.]</ety> <fld>(Min.)</fld> <def>A member of the scapolite
group, occurring in glassy crystals on Monte Somma, near
Naples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meiosis</ent><br/
\'d8<hw>Mei*o"sis</hw> <pr>(m<isl/*<omac/"s<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>mei`wsis</grk>, fr. <grk>meioy^n</grk> to make
smaller, from <grk>mei`wn</grk>. See <er>Meionite</er>.]</ety>
<sn>1.</sn> <fld>(Rhet.)</fld> <def>Diminution; a species of hyperbole,
representing a thing as being less than it really is; understatement;
see also <stype>litotes</stype>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Cell Biology)</fld> <def>The cellular process by
which a diploid progenitor cell forms haploid gametes, including a
division of one diploid cell into two cells, each with one of the
homologous sets of chromosomes.</def><br/
[<source>PJC</source>]</p>

<p><ent>Meiostemonous</ent><br/
<hw>Mei`o*stem"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>mei`wn</grk> smaller + <?/ warp, thread.]</ety> <fld>(Bot.)</fld>
<def>Having fever stamens than the parts of the corolla.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>meiotic</ent><br/
<hw>mei*ot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>meiosis</er>.]</ety> <fld>(Cell Biology)</fld> <def>Of or pertaining
to <er>meiosis</er>; <as>as, <ex>meiotic</ex> division</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>-meister</ent><br/
<hw>-meister</hw> <pos>suff.</pos> <ety>[G., master]</ety> <def>A suffix
denoting <sig>master</sig> or <sig>professional practitioner</sig>, as
in spin<ex>meister</ex> or hype<ex>meister</ex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Meistersinger</ent><br/
\'d8<hw>Meis"ter*sing`er</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[G.]</ety> <def>See <er>Mastersinger</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mekhitarist</ent><br/
<hw>Mekh"i*tar*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>See <er>Mechitarist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melaconite</ent><br/
<hw>Me*lac"o*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`las</grk> black + <?/ dust.]</ety> <fld>(Min.)</fld> <def>An
earthy black oxide of copper, arising from the decomposition of other
ores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melado</ent><br/
<ent>Melada</ent><br/
<mhw>{ \'d8<hw>Me*la"da</hw> <pr>(?)</pr>, \'d8<hw>Me*la"do</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Sp., prop. p. p. of
<ets>melar</ets> to sugar, candy, fr. L. <ets>mel</ets> honey. See
<er>Molasses</er>.]</ety> <def>A mixture of sugar and molasses; crude
sugar as it comes from the pans without being drained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melaena</ent><br/
\'d8<hw>Me*lae"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`las</grk>, m., <grk>me`laina</grk>, f., black.]</ety>
<fld>(Med.)</fld> <def>A discharge from the bowels of black matter,
consisting of altered blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melain</ent><br/
<hw>Mel"ain</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Melaena</er>.]</ety> <def>The dark coloring matter of the liquid of
the cuttlefish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melainotype</ent><br/
<hw>Me*lai"no*type</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Melanotype</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melam</ent><br/
<hw>Me"lam</hw> <pr>(m<emac/"l<acr/m)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/lam</ets>.]</ety> <fld>(Chem.)</fld> <def>A white or
buff-colored granular powder, <chform>C6H9N11</chform>, obtained by
heating ammonium sulphocyanate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>melamine</ent><br/
<hw>mel"a*mine</hw> <pr>(m<ecr/l"<adot/*m<emac/n)</pr> <pos>n.</pos>
<fld>(Chem.)</fld> <def>A nitrogenous strongly basic chemical substance
(<chform>C3H6N6</chform>), structurally
<chname>2,4,6-triamino-1,3,5-triazine</chname>, produced from several
cyanogen compounds, and obtained as a white crystalline substance; --
formerly supposed to be produced by the decomposition of
<etsep>melam</etsep>. Called also <altname>cyanuramide</altname>. It is
used as one of the starting components (together with formaldehyde) in
the preparation of melamine resins, including the commercially marketed
<er>Formica</er> (TM). It is solid at room temperature, and sublimes at
temperatures approaching 250<deg/ C, decomposing at 345<deg/ C. Density
1.573.</def> <au>HCP61</au><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>melamine-fromaldehyde methanal resin</ent><br/
<ent>melamine resin</ent><br/
<hw>melamine resin</hw> <hw>melamine-fromaldehyde methanal resin</hw>
<pos>n.</pos> <def>A thermosetting plastic formed by the reaction of
melamine and formaldehyde. It is used for molding and for preparing
laminated sheets used to surface counter tops, walls, and furniture. The
commercially marketed <styp><er>Formica</er></styp> (TM) is one type of
melamine resin.</def><br/
[<source>PJC</source>]</p>

<p><ent>Melampode</ent><br/
<hw>Mel"am*pode</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>melampo`dion</grk>; of uncertain origin.]</ety> <def>The black
hellebore.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melampsoraceae</ent><br/
<hw>Melampsoraceae</hw> <pos>prop. n.</pos> <def>A natural family of
rust fungi.</def><br/
<syn><b>Syn. --</b> family <fam>Melampsoraceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melampyrite</ent><br/
<ent>Melampyrin</ent><br/
<mhw>{ <hw>Mel`am*py"rin</hw> <pr>(?)</pr>, <hw>Mel`am*py"rite</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>Melampyrum</ets>
cowwheat; Gr. <grk>me`las</grk> black + <grk>pyro`s</grk> wheat.]</ety>
<fld>(Chem.)</fld> <def>The saccharine substance dulcite; -- so called
because found in the leaves of cowwheat (<gen>Melampyrum</gen>). See
<er>Dulcite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanaemia</ent><br/
\'d8<hw>Mel`a*nae"mi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`las</grk>, <grk>me`lanos</grk>, black + <grk>a"i^ma</grk>
blood.]</ety> <fld>(Med.)</fld> <def>A morbid condition in which the
blood contains black pigment either floating freely or imbedded in the
white blood corpuscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanagogue</ent><br/
<hw>Me*lan"a*gogue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black + <?/ leading, driving,
<?/ to lead.]</ety> <fld>(Med.)</fld> <def>A medicine supposed to expel
black bile or choler.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholia</ent><br/
\'d8<hw>Mel`an*cho"li*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Melancholy</er>.]</ety> <fld>(Med.)</fld> <def>A kind of mental
unsoundness characterized by extreme depression of spirits, ill-grounded
fears, delusions, and brooding over one particular subject or train of
ideas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholian</ent><br/
<hw>Mel`an*cho"li*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person
affected with melancholy; a melancholic.</def> <mark>[Obs.]</mark>
<rj><au>Dr. J. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholic</ent><br/
<hw>Mel"an*chol`ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>melancholicus</ets>, Gr. <?/: cf. F.
<ets>m<eacute/lancholique</ets>.]</ety> <def>Given to melancholy;
depressed; melancholy; dejected; unhappy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Just as the <qex>melancholic</qex> eye<br/
Sees fleets and armies in the sky.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholic</ent><br/
<hw>Mel"an*chol`ic</hw>, <pos>n.</pos> <mark>[Obs.]</mark> <sn>1.</sn>
<def>One affected with a gloomy state of mind.</def> <rj><au>J.
Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A gloomy state of mind; melancholy.</def>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholily</ent><br/
<hw>Mel"an*chol`i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
melancholy manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholiness</ent><br/
<hw>Mel"an*chol`i*ness</hw>, <pos>n.</pos> <def>The state or quality of
being melancholy.</def> <rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholious</ent><br/
<hw>Mel`an*cho"li*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>melancholieux</ets>.]</ety> <def>Melancholy.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholist</ent><br/
<hw>Mel"an*chol*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One affected
with melancholy or dejection.</def> <mark>[Obs.]</mark>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholize</ent><br/
<hw>Mel"an*cho*lize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To become
gloomy or dejected in mind.</def> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholize</ent><br/
<hw>Mel"an*cho*lize</hw>, <pos>v. t.</pos> <def>To make
melancholy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholy</ent><br/
<hw>Mel"an*chol*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>melancolie</ets>, F. <ets>m<eacute/lancolie</ets>, L.
<ets>melancholia</ets>, fr. Gr. <?/; <grk>me`las</grk>,
<grk>me`lanos</grk>, black + <?/ gall, bile. See <er>Malice</er>, and
1st <er>Gall</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Depression of spirits; a gloomy state continuing a
considerable time; deep dejection; gloominess.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Great and continued depression of spirits, amounting
to mental unsoundness; melancholia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Pensive meditation; serious thoughtfulness.</def>
<mark>[Obs.]</mark> <ldquo/Hail, divinest <xex>Melancholy</xex> !<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Ill nature.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melancholy</ent><br/
<hw>Mel"an*chol*y</hw>, <pos>a.</pos> <sn>1.</sn> <def>Depressed in
spirits; dejected; gloomy dismal.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Producing great evil and grief; causing dejection;
calamitous; afflictive; <as>as, a <ex>melancholy</ex>
event</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Somewhat deranged in mind; having the judgement
impaired.</def> <mark>[Obs.]</mark> <rj><au>Bp. Reynolds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Favorable to meditation; somber.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A pretty, <qex>melancholy</qex> seat, well wooded and watered.</q>
<rj><qau>Evelin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Gloomy; sad; dispirited; low-spirited;
downhearted; unhappy; hypochondriac; disconsolate; heavy, doleful;
dismal; calamitous; afflictive.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanconiaceae</ent><br/
<hw>Mel`an*co`ni*a"ce*ae</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Bot.)</fld> <def>A family of fungi constituting
the order <ord>Melanconiales</ord>.</def> --
<wordforms><wf>Mel`an*co`ni*a"ceous</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Melanconiales</ent><br/
<hw>Mel`an*co`ni*a"les</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. <ets>Melanconium</ets>, name of the typical genus, fr. Gr.
<grk>me`las</grk> black + <?/ dust, in allusion to the dark
spores.]</ety> <fld>(Bot.)</fld> <def>The smallest of the three orders
of Fungi Imperfecti, including those with no asci nor pycnidia, but as a
rule having the spores in cavities without special walls. They cause
many of the plant diseases known as
<causes>anthracnose</causes>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Melanesian</ent><br/
<hw>Mel`a*ne"sian</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black + <?/ island.
<ets>Melanesia</ets> was so called from the dark complexion of the
natives.]</ety> <def>Of or pertaining to Melanesia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melange</ent><br/
\'d8<hw>M<eacute/`lange"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Mell</er>, <er>Meddle</er>.]</ety> <def>A mixture; a
medley.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanian</ent><br/
<hw>Me*la"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of a family of fresh-water pectinibranchiate mollusks, having a
turret-shaped shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanic</ent><br/
<hw>Me*lan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>-anos</grk>, black.]</ety> <sn>1.</sn>
<def>Melanotic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Ethnol.)</fld> <def>Of or pertaining to the
black-haired races.</def> <rj><au>Prichard.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melaniline</ent><br/
<hw>Me*lan"i*line</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A complex nitrogenous hydrocarbon obtained artificially (as by the
action of cyanogen chloride on aniline) as a white, crystalline
substance; -- called also <altname>diphenyl
guanidin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanin</ent><br/
<hw>Mel"a*nin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black.]</ety>
<fld>(Physiol.)</fld> <def>A black pigment found in the pigment-bearing
cells of the skin (particularly in the skin of the negro), in the
epithelial cells of the external layer of the retina (then called
<altname>fuscin</altname>), in the outer layer of the choroid, and
elsewhere. It is supposed to be derived from the decomposition of
hemoglobin.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 910 --></p>

<p><ent>Melanism</ent><br/
<hw>Mel"a*nism</hw> <pr>(m<ecr/l"<adot/*n<icr/z'm)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>me`las</grk>, <grk>-anos</grk>, black.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An undue development of dark-colored pigment in the
skin or its appendages; -- the opposite of
<contr>albinism</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A disease; black jaundice. See
<er>Melaena</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanism</ent><br/
<hw>Mel"a*nism</hw> <pr>(m<ecr/l"<adot/*n<icr/z'm)</pr>, <pos>n.</pos>
<fld>(Ethnol.)</fld> <def>The character of having a high degree of
pigmentation, as shown in dark skin, eyes, and hair.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Melanistic</ent><br/
<hw>Mel`a*nis"tic</hw> <pr>(m<ecr/l`<adot/*n<icr/s"t<icr/k)</pr>,
<pos>a.</pos> <def>Affected with melanism; of the nature of
melanism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanite</ent><br/
<hw>Mel"a*nite</hw> <pr>(m<ecr/l"<adot/*n<imac/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>me`las</grk>, <grk>me`lanos</grk>, black: cf. F.
<ets>m<eacute/lanite</ets>.]</ety> <fld>(Min.)</fld> <def>A black
variety of garnet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanochroi</ent><br/
\'d8<hw>Mel`a*noch"ro*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Melanochroic</er>.]</ety> <fld>(Ethnol.)</fld> <def>A group of
the human race, including the dark whites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanochroic</ent><br/
<hw>Mel`a*no*chro"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>melana`chroos</grk>; <grk>me`las</grk>, <grk>-anos</grk>, black +
<grk>chroa`</grk> color.]</ety> <def>Having a dark complexion; of or
pertaining to the Melanochroi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanochroite</ent><br/
<hw>Mel`a*no*chro"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Melanochroic</er>.]</ety> <fld>(Min.)</fld> <def>A mineral of a red,
or brownish or yellowish red color. It is a chromate of lead; -- called
also <altname>phoenicocroite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanocomous</ent><br/
<hw>Mel`a*noc"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black + <?/ hair.]</ety>
<def>Having very dark or black hair; black-haired.</def>
<rj><au>Prichard.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanoma</ent><br/
\'d8<hw>Mel`a*no"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>L. pl.
<plw>-nomata</plw> <pr>(#)</pr></plu>. <ety>[NL.; Gr. <?/, <?/, black +
<ets>-oma</ets>.]</ety> <fld>(Med.)</fld> <sd>(a)</sd> <def>A tumor
containing dark pigment. Such tumors are usually malignant and often
fatal.</def> <sd>(b)</sd> <def>Development of dark-pigmented
tumors.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Melanorrhoea</ent><br/
\'d8<hw>Mel`a*nor*rhoe"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`las</grk>, <grk>me`lanos</grk>, black + <?/ to flow.]</ety>
<fld>(Bot.)</fld> <def>An East Indian genus of large trees.
<spn>Melanorrh<oe/a usitatissima</spn> is the lignum-vitae of Pegu (in
Burma), and yields a valuable black varnish.</def><-- #"Pegu" is part of
Burma (now Myanmar) --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanoscope</ent><br/
<hw>Me*lan"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black +
<ets>-scope</ets>.]</ety> <fld>(Opt.)</fld> <def>An instrument
containing a combination of colored glasses such that they transmit only
red light, so that objects of other colors, as green leaves, appear
black when seen through it. It is used for viewing colored flames, to
detect the presence of potassium, lithium, etc., by the red light which
they emit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanosis</ent><br/
\'d8<hw>Mel`a*no"sis</hw> <pr>(?)</pr>, <ety>[NL., fr. Gr. <?/ a growing
black, fr. <grk>me`las</grk>, <grk>me`lanos</grk>, black.]</ety>
<fld>(Med.)</fld> <def>The morbid deposition of black matter, often of a
malignant character, causing pigmented tumors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanosperm</ent><br/
<hw>Me*lan"o*sperm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black + <grk>spe`rma</grk>
seed.]</ety> <fld>(Bot.)</fld> <def>An alga of any kind that produces
blackish spores, or seed dust. The melanosperms include the rockweeds
and all kinds of kelp.</def> -- <wordforms><wf>Mel`a*no*sper"mous</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanotic</ent><br/
<hw>Mel`a*not"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Melanistic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanotype</ent><br/
<hw>Me*lan"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black + <ets>-type</ets>.]</ety>
<fld>(Photog.)</fld> <def>A positive picture produced with sensitized
collodion on a smooth surface of black varnish, coating a thin plate of
iron; also, the process of making such a picture.</def> <altsp>[Written
also <asp>melainotype</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanterite</ent><br/
<hw>Me*lan"ter*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A hydrous sulphate of iron of a green color and vitreous luster;
iron vitriol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanure</ent><br/
<hw>Mel"a*nure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>melanurus</ets>, fr. Gr. <grk>me`las</grk>, <grk>me`lanos</grk>,
black + <grk>'oura`</grk> tail.]</ety> <fld>(Zool.)</fld> <def>A small
fish of the Mediterranean; a gilthead. See <er>Gilthead</er>
<sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melanuric</ent><br/
<hw>Mel`a*nu"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Melam</ets>
+ <ets>urea</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, a complex nitrogenous acid obtained by decomposition of
melam, or of urea, as a white crystalline powder; -- called also
<altname>melanurenic acid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melaphyre</ent><br/
<hw>Mel"a*phyre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Gr.
<grk>me`las</grk>, <grk>me`lanos</grk>, black + por<ets>phyre</ets>
porphyry.]</ety> <fld>(Min.)</fld> <def>Any one of several dark-colored
augitic, eruptive rocks allied to basalt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melasma</ent><br/
\'d8<hw>Me*las"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ black spot.]</ety> <fld>(Med.)</fld> <def>A dark discoloration of
the skin, usually local; <as>as, Addison's <ex>melasma</ex>, or
Addison's disease</as>.</def> -- <wordforms><wf>Me*las"mic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melasses</ent><br/
<hw>Me*las"ses</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Molasses</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melassic</ent><br/
<hw>Me*las"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Molasses</er>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, an acid obtained from molasses or glucose, and probably
identical with <altname>saccharic</altname> acid (also called
<altname>D-glucaric</altname> acid or
<altname>tetrahydroxyadipic</altname> acid). See
<er>Saccharic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melastoma</ent><br/
\'d8<hw>Me*las"to*ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`las</grk> black + <grk>sto`ma</grk> mouth.]</ety>
<fld>(Bot.)</fld> <def>A genus of evergreen tropical shrubs; -- so
called from the black berries of some species, which stain the
mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melastomaceous</ent><br/
<hw>Mel`a*sto*ma"ceous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Belonging to the order of which
<gen>Melastoma</gen> is the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>melatonin</ent><br/
<hw>mel`a*tonin</hw> <pos>n.</pos> <fld>(Physiology)</fld> <def>A
hormone secreted by the pineal gland. Chemically it is
<chname>N-acety-5-methoxytryptamine</chname>. Research has indicated
that there are daily rhythms in secretion of melatonin, in particular
due to the depressing effect on melatonin production by light received
by the retina. Conversely it appears that melatonin may influence the
circadian rhythms of animals. There is some experimental evidence that
administration of melatonin may increase the amount of sleep in people
with sleep disorders. However, the evidence is not convincing and the
effect is not profound. Nevertheless, the deregulation of melatonin and
its availability over-the-counter has led to many people taking
melatonin to help sleep, without consulting a physician.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><q>A role for melatonin in sleep facilitation has been inferred from
its effect on electroencephalogram patterns, but it has not been
possible to demonstrate that wakefulness sleep cycles are driven by
periodic accumulation, depletion, or regeneration of melatonin.</q>
<rj><qau>Uwe Ackermann, Essentials of Human Physiology,
1992</qau></rj></p>

<p><ent>Melchite</ent><br/
<hw>Mel"chite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>melek</ets> king.]</ety> <fld>(Eccl. Hist.)</fld> <def>One of a
sect, chiefly in Syria and Egypt, which acknowledges the authority of
the pope, but adheres to the liturgy and ceremonies of the Eastern
Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meld</ent><br/
<hw>Meld</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Melded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Melding</conjf>.]</vmorph> <ety>[G. <ets>melden</ets> to
announce.]</ety> <fld>(Card Playing)</fld> <def>In the game of pinochle,
to declare or announce for a score; <as>as, to <ex>meld</ex> a
sequence</as>.</def> <wns>[wns=1]</wns><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>to mix together so that the components are
indistinguishable.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> blend, mix, conflate, commingle, immix, fuse,
coalesce, combine, merge.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>meld</ent><br/
<hw>meld</hw>, <pos>n.</pos> <fld>(Card Playing)</fld> <sn>1.</sn>
<def>Any combination or score which may be declared, or melded, in
pinochle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A form of <isa>rummy</isa> using two decks and four
jokers; jokers and deuces are wild; the object is to meld groups of
seven of the same rank.</def><br/
<syn><b>Syn. --</b> canasta, basket rummy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meleagrididae</ent><br/
<hw>Meleagrididae</hw> <pos>prop. n.</pos> <def>A natural family of
fowls including the turkeys and some extinct forms.</def><br/
<syn><b>Syn. --</b> family <fam>Meleagrididae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meleagrine</ent><br/
<hw>Mel`e*a"grine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the genus <gen>Meleagris</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meleagris</ent><br/
\'d8<hw>Mel`e*a"gris</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L.,
the Guinea fowl.]</ety> <fld>(Zool.)</fld> <def>A genus of American
gallinaceous birds, including the <member>common turkey</member> and the
<members>wild turkeys</members>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Melee</ent><br/
\'d8<hw>M<ecir/`l<eacute/e"</hw> <pr>(m<asl/`l<asl/")</pr>,
<pos>n.</pos> <ety>[F., fr. <ets>m<ecir/ler</ets> to mix. See
<er>Meddle</er>, <er>Mell</er>, and cf. <er>Mellay</er>.]</ety>
<sn>1.</sn> <def>A fight in which the combatants are mingled in one
confused mass; a hand to hand conflict; an affray.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cavalry exercise in which two groups of riders try
to cut paper plumes off the helmets of their opponents, the contest
continuing until no member of one group retains his plume; -- sometimes
called <altname>Balaklava m<ecir/l<eacute/e</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Melena</ent><br/
\'d8<hw>Me*le"na</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>See <er>Melaena</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melene</ent><br/
<hw>Mel"ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mel</ets>issic +
ethyl<ets>ene</ets>.]</ety> <fld>(Chem.)</fld> <def>An unsaturated
hydrocarbon, <chform>C30H60</chform>, of the ethylene series, obtained
from beeswax as a white, scaly, crystalline wax; -- called also
<altname>melissene</altname>, and
<altname>melissylene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melenite</ent><br/
<hw>Mel"e*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`li</grk> honey.]</ety> <def>An explosive of great destructive
power; -- so called from its color, which resembles honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meletin</ent><br/
<hw>Mel"e*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Quercitin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melezitose</ent><br/
<hw>Me*lez"i*tose`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/l<egrave/ze</ets> the larch + mel<ets>itose</ets>.]</ety>
<fld>(Chem.)</fld> <def>A variety of sugar, isomeric with sucrose,
extracted from the manna of the larch (<gen>Larix</gen>).</def>
<altsp>[Written also <asp>melicitose</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliaceous</ent><br/
<hw>Me`li*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Pertaining to a natural order (<ord>Meliacae</ord>) of plants of
which the genus <gen>Melia</gen> is the type. It includes the mahogany
and the Spanish cedar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliboean</ent><br/
<ent>Melibean</ent><br/
<mhw>{ <hw>Mel`i*be"an</hw> <pr>(?)</pr>, <hw>Mel`i*b<oe/"an</hw>
}</mhw>, <pos>a.</pos> <ety>[From L. <ets>Meliboeus</ets>, one of the
interlocutors in <persfn>Virgil's</persfn> first Eclogue.]</ety>
<fld>(Rhet.)</fld> <def>Alternately responsive, as verses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melic</ent><br/
<hw>Mel"ic</hw> <pr>(?)</pr>, <ety>[Gr. <?/, fr. <?/ song.]</ety>
<def>Of or pertaining to song; lyric; tuneful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melicerous</ent><br/
<hw>Me*lic"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>meliceris</ets> a kind of tumor, fr. Gr. <?/; <grk>me`li</grk>
honey + <?/ wax.]</ety> <fld>(Med.)</fld> <def>Consisting of or
containing matter like honey; -- said of certain encysted
tumors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melic grass</ent><br/
<hw>Mel"ic grass`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>A genus of
grasses (<gen>Melica</gen>) of little agricultural importance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melicotoon</ent><br/
<hw>Mel`i*co*toon"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Melocoton</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melicratory</ent><br/
<hw>Me*lic"ra*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>meli`kraton</grk>.]</ety> <def>A meadlike drink.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melilite</ent><br/
<hw>Mel"i*lite</hw> <pr>(m<ecr/l"<icr/*l<imac/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>me`li</grk> honey + <ets>-lite</ets>; cf. F.
<ets>m<eacute/lilithe</ets>.]</ety> <fld>(Min.)</fld> <def>A mineral
occurring in small yellow crystals, found in the lavas (<it>melilite
basalt</it>) of Vesuvius, and elsewhere.</def> <altsp>[Written also
<asp>mellilite</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melilot</ent><br/
<hw>Mel"i*lot</hw> <pr>(-l<ocr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/lilot</ets>, L. <ets>melilotus</ets>, fr. Gr. <?/, <?/, a
kind of clover containing honey; <grk>me`li</grk> honey + <?/
lotus.]</ety> <fld>(Bot.)</fld> <def>Any species of
<gen>Melilotus</gen>, a genus of leguminous herbs having a vanillalike
odor; sweet clover; hart's clover. The blue melilot (<spn>Melilotus
caerulea</spn>) is used in Switzerland to give color and flavor to
sapsago cheese.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melilotic</ent><br/
<hw>Mel`i*lot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, pertaining to, or obtained from, sweet clover or melilot;
specifically, designating an acid of the aromatic series, obtained from
melilot as a white crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melinae</ent><br/
<hw>Melinae</hw> <pos>n.</pos> <def>A subdivision of mammals not used in
some classifications; it includes the badgers.</def><br/
<syn><b>Syn. --</b> subfamily <subfam>Melinae</subfam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melinite</ent><br/
<hw>M<eacute/"lin*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Chem.)</fld> <def>A high explosive similar to lyddite, consisting
principally of picric acid, used in the French military
service.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Meliorate</ent><br/
<hw>Mel"io*rate</hw> <pr>(m<emac/l"y<osl/*r<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Meliorated</conjf>
<pr>(m<emac/l"y<osl/*r<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Meliorating</conjf>.]</vmorph> <ety>[L. <ets>melioratus</ets>, p.
p. of <ets>meliorare</ets> to meliorate, fr. <ets>melior</ets> better;
akin to Gr. <grk>ma^llon</grk> rather, <grk>ma`la</grk> very. Cf.
<er>Ameliorate</er>.]</ety> <def>To make better; to improve; to
ameliorate; to soften; to make more tolerable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nature by art we nobly <qex>meliorate</qex>.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The pure and benign light of revelation has had a
<qex>meliorating</qex> influence on mankind.</q>
<rj><qau>Washington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliorate</ent><br/
<hw>Mel"io*rate</hw>, <pos>v. i.</pos> <def>To grow better.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliorater</ent><br/
<hw>Mel"io*ra`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Meliorator</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melioration</ent><br/
<hw>Mel`io*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>melioratio</ets>.]</ety> <def>The act or operation of meliorating,
or the state of being meliorated; improvement.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliorator</ent><br/
<hw>Mel"io*ra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
meliorates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliorism</ent><br/
<hw>Mel"io*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>melior</ets> better.]</ety> <def>The doctrine that there is a
tendency throughout nature toward improvement.</def> <rj><au>J.
Sully.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliority</ent><br/
<hw>Mel*ior"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>melioritas</ets>, fr. L. <ets>melior</ets>. See
<er>Meliorate</er>.]</ety> <def>The state or quality of being better;
melioration.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliphagan</ent><br/
<hw>Me*liph"a*gan</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>me`li</grk> honey + <?/ to eat.]</ety> <fld>(Zool.)</fld>
<def>Belonging to the genus <gen>Meliphaga</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliphagan</ent><br/
<hw>Me*liph"a*gan</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any bird
of the genus <gen>Meliphaga</gen> and allied genera; a honey eater; --
called also <altname>meliphagidan</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meliphagous</ent><br/
<hw>Me*liph"a*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Meliphagan</er>.]</ety> <fld>(Zool.)</fld> <def>Eating, or feeding
upon, honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melisma</ent><br/
\'d8<hw>Me*lis"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Melismata</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>me`lisma</grk> a song.]</ety> <fld>(Mus.)</fld> <sd>(a)</sd> <def>A
piece of melody; a song or tune, -- as opposed to
<contr>recitative</contr> or musical declamation.</def> <sd>(b)</sd>
<def>A grace or embellishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melissa</ent><br/
\'d8<hw>Me*lis"sa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`lissa</grk> a bee, honey.]</ety> <fld>(Bot.)</fld> <def>A genus
of labiate herbs, including the balm, or bee balm (<spn>Melissa
officinalis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melissic</ent><br/
<hw>Me*lis"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>me`lissa</grk> a bee, honey.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, beeswax; specif., denoting an acid
obtained by oxidation of myricin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melissyl</ent><br/
<hw>Me*lis"syl</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meliss</ets>ic +<ets>yl</ets>.]</ety> <fld>(Chem.)</fld>
<def>See <er>Myricyl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melissylene</ent><br/
<hw>Me*lis"sy*lene</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meliss</ets>ic + <ets>-yl</ets> + <ets>-ene</ets>.]</ety>
<fld>(Chem.)</fld> <def>See <er>Melene</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melitose</ent><br/
<hw>Mel"i*tose`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`li</grk> honey.]</ety> <fld>(Chem.)</fld> <def>A variety of
sugar isomeric with sucrose, extracted from cotton seeds and from the
so-called Australian manna (a secretion of certain species of
Eucalyptus).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mell</ent><br/
<hw>Mell</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <ety>[F.
<ets>m<ecir/ler</ets>, OF. <ets>meller</ets>, <ets>mester</ets>. See
<er>Meddle</er>.]</ety> <def>To mix; to meddle.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mell</ent><br/
<hw>Mell</hw>, <pos>n.</pos> <ety>[See <er>Mellifluous</er>.]</ety>
<def>Honey.</def> <mark>[Obs.]</mark> <rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mell</ent><br/
<hw>Mell</hw>, <pos>n.</pos> <def>A mill.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellate</ent><br/
<hw>Mel"late</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>mel</ets>,
<ets>mellis</ets>, honey. Cf. <er>Mellitate</er>.]</ety>
<fld>(Chem.)</fld> <def>A mellitate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellay</ent><br/
<hw>Mel"lay</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A m<ecir/l<eacute/e; a
conflict.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellic</ent><br/
<hw>Mel"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld> <def>See
<er>Mellitic</er>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melliferous</ent><br/
<hw>Mel*lif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mellifer</ets>; <ets>mel</ets>, <ets>mellis</ets>, honey +
<ets>ferre</ets> to bear.]</ety> <def>Producing honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellific</ent><br/
<hw>Mel*lif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>mel</ets>,
<ets>mellis</ets>, honey + <ets>-ficare</ets> (in comp.) to make. See
<er>-fy</er>.]</ety> <def>Producing honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellification</ent><br/
<hw>Mel`li*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mellificare</ets> to make honey: cf. F. <ets>mellification</ets>.
See <er>Mellific</er>.]</ety> <def>The making or production of
honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellifluence</ent><br/
<hw>Mel*lif"lu*ence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flow of
sweetness, or a sweet, smooth flow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellifluent</ent><br/
<hw>Mel*lif"lu*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mellifluens</ets>. See <er>Mellifluous</er>.]</ety> <def>Flowing as
with honey; smooth; mellifluous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellifluently</ent><br/
<hw>Mel*lif"lu*ent*ly</hw>, <pos>adv.</pos> <def>In a mellifluent
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellifluous</ent><br/
<hw>Mel*lif"lu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mellifluus</ets>; <ets>mel</ets>, <ets>mellis</ets>, honey (akin to
Gr. <?/, Goth. <ets>milip</ets>) + <ets>fluere</ets> to flow. See
<er>Mildew</er>, <er>Fluent</er>, and cf. <er>Marmalade</er>.]</ety>
<def>Flowing as with honey; smooth; flowing sweetly or smoothly; <as>as,
a <ex>mellifluous</ex> voice</as>.</def> --
<wordforms><wf>Mel*lif"lu*ous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melligenous</ent><br/
<hw>Mel*lig"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mel</ets>, <ets>mellis</ets> + <ets>-genous</ets>.]</ety>
<def>Having the qualities of honey.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melligo</ent><br/
\'d8<hw>Mel*li"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Honeydew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melliloquent</ent><br/
<hw>Mel*lil"o*quent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mel</ets>, <ets>mellis</ets> honey + <ets>loquens</ets> speaking,
p. pr. of <ets>loqui</ets> to speak.]</ety> <def>Speaking sweetly or
harmoniously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melliphagan</ent><br/
<hw>Mel*liph"a*gan</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Meliphagan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melliphagous</ent><br/
<hw>Mel*liph"a*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Meliphagous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellitate</ent><br/
<hw>Mel"li*tate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mellitate</ets>. See <er>Mellitic</er>.]</ety> <fld>(Chem.)</fld>
<def>A salt of mellitic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellite</ent><br/
<hw>Mel"lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>mel</ets>,
<ets>mellis</ets>, honey: cf. F. <ets>mellite</ets>.]</ety>
<fld>(Min.)</fld> <def>A mineral of a honey color, found in brown coal,
and partly the result of vegetable decomposition; honeystone. It is a
mellitate of alumina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellitic</ent><br/
<hw>Mel*lit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mellitique</ets>. See <er>Mellite</er>.]</ety> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>Containing saccharine matter; marked by saccharine
secretions; <as>as, <ex>mellitic</ex> diabetes</as>.</def> <sd>(b)</sd>
<def>Pertaining to, or derived from, the mineral mellite.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mellitic acid</b></col> <fld>(Chem.)</fld>, <cd>a white,
crystalline, organic substance, <chform>C6(CO2H)6</chform>, occurring
naturally in combination with aluminium in the mineral mellite, and
produced artificially by the oxidation of coal, graphite, etc., and
hence called also <altname>graphitic acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellone</ent><br/
<hw>Mel"lone</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
yellow powder, <chform>C6H3N9</chform>, obtained from certain
sulphocyanates. It has acid properties and forms compounds called
<xex>mellonides</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellonide</ent><br/
<hw>Mel"lon*ide</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mellone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellow</ent><br/
<hw>Mel"low</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Mellower</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Mellowest</adjf>.]</amorph> <ety>[OE. <ets>melwe</ets>; cf. AS.
<ets>mearu</ets> soft, D. <ets>murw</ets>, Prov. G. <ets>mollig</ets>
soft, D. <ets>malsch</ets>, and E. <ets>meal</ets> flour.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Soft or tender by reason of ripeness; having a
tender pulp; <as>as, a <ex>mellow</ex> apple</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Hence: <sd>(a)</sd> <def>Easily worked or penetrated; not
hard or rigid; <as>as, a <ex>mellow</ex> soil</as>.</def>
<ldquo/<xex>Mellow</xex> glebe.<rdquo/ <au>Drayton</au> <sd>(b)</sd>
<def>Not coarse, rough, or harsh; subdued; soft; rich; delicate; -- said
of sound, color, flavor, style, etc.</def> <ldquo/The <xex>mellow</xex>
horn.<rdquo/ <au>Wordsworth.</au> <ldquo/The <xex>mellow</xex>-tasted
Burgundy.<rdquo/ <au>Thomson.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>The tender flush whose <qex>mellow</qex> stain imbues<br/
Heaven with all freaks of light.</q> <rj><qau>Percival.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Well matured; softened by years; genial;
jovial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>May health return to <qex>mellow</qex> age.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As merry and <qex>mellow</qex> an old bachelor as ever followed a
hound.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Warmed by liquor; slightly intoxicated.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellow</ent><br/
<hw>Mel"low</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mellowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mellowing</conjf>.]</vmorph> <def>To make mellow.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If the Weather prove frosty to <qex>mellow</qex> it [the ground],
they do not plow it again till April.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The fervor of early feeling is tempered and <qex>mellowed</qex> by
the ripeness of age.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellow</ent><br/
<hw>Mel"low</hw>, <pos>v. i.</pos> <def>To become mellow; <as>as, ripe
fruit soon <ex>mellows</ex></as>.</def> <ldquo/Prosperity begins to
<xex>mellow</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mellowed</ent><br/
<hw>mellowed</hw> <pos>adj.</pos> <sn>1.</sn> <def>having a mild and
pleasing flavor through proper aging.</def><br/
<syn><b>Syn. --</b> mellow.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having attained to kindliness or gentleness through
age and experience; -- of people.</def><br/
<syn><b>Syn. --</b> gentle, mellow.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mellowing</ent><br/
<hw>mellowing</hw> <pos>adj.</pos> <def><pos>pr. p.</pos> of
<er>mellow</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mellowing</ent><br/
<hw>mellowing</hw> <pos>n.</pos> <def>The act or process of acquiring
desirable qualities by being left undisturbed for some time.</def><br/
<syn><b>Syn. --</b> ripening, aging, ageing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mellowly</ent><br/
<hw>Mel"low*ly</hw>, <pos>adv.</pos> <def>In a mellow manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellowness</ent><br/
<hw>Mel"low*ness</hw>, <pos>n.</pos> <def>Quality or state of being
mellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mellowy</ent><br/
<hw>Mel"low*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Soft;
unctuous.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melluco</ent><br/
\'d8<hw>Mel*lu"co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A climbing plant (<spn>Ullucus officinalis</spn>) of the Andes,
having tuberous roots which are used as a substitute for
potatoes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melne</ent><br/
<hw>Mel"ne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mill.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melocotoon</ent><br/
<ent>Melocoton</ent><br/
<mhw>{ <hw>Mel`o*co*ton"</hw>, <hw>Mel`o*co*toon"</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. <ets>melocoton</ets> a kind of
peach tree and its fruit, L. <ets>malum cotonium</ets>, or
<ets>cotonea</ets>, or <ets>Cydonia</ets>, a quince, or quince tree,
lit., apple of <ets>Cydonia</ets>, Gr. <?/ <?/. See
<er>Quince</er>.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>A
quince.</def> <sd>(b)</sd> <def>A kind of peach having one side deep
red, and the flesh yellow.</def> <altsp>[Written also
<asp>malacatoon</asp>, <asp>malacotune</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodeon</ent><br/
<hw>Me*lo"de*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
musical. See <er>Melody</er>, and cf. <er>Odeon</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Mus.)</fld> <def>A kind of small reed organ; -- a
portable form of the seraphine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A music hall.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodic</ent><br/
<hw>Me*lod"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>melodicus</ets>, Gr. <?/: cf. F.
<ets>m<eacute/lodique</ets>.]</ety> <def>Of the nature of melody;
relating to, containing, or made up of, melody; melodious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodics</ent><br/
<hw>Me*lod"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The branch of
musical science which treats of the pitch of tones, and of the laws of
melody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodiograph</ent><br/
<hw>Me*lo"di*o*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Melody</ets> + <ets>-graph</ets>.]</ety> <def>A contrivance
for preserving a record of music, by recording the action of the keys of
a musical instrument when played upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodious</ent><br/
<hw>Me*lo"di*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/lodieux</ets>. See <er>Melody</er>.]</ety>
<def>Containing, or producing, melody; musical; agreeable to the ear by
a sweet succession of sounds; <as>as, a <ex>melodious</ex>
voice</as>.</def> <ldquo/A <xex>melodious</xex> voice.<rdquo/ <ldquo/A
<xex>melodious</xex> undertone.<rdquo/ <au>Longfellow.</au> --
<wordforms><wf>Me*lo"di*ous*ly</wf>, <pos>adv.</pos> --
<wf>Me*lo"di*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodist</ent><br/
<hw>Mel"o*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/lodiste</ets>.]</ety> <def>A composer or singer of
melodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodize</ent><br/
<hw>Mel"o*dize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Melodized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Melodizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To make
melodious; to form into, or set to, melody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodize</ent><br/
<hw>Mel"o*dize</hw>, <pos>v. i.</pos> <def>To make melody; to compose
melodies; to harmonize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodrama</ent><br/
<hw>Mel`o*dra"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/lodrame</ets>, fr. Gr. <grk>me`los</grk> song +
<grk>dra^ma</grk> drama.]</ety> <def>Formerly, a kind of drama having a
musical accompaniment to intensify the effect of certain scenes. Now, a
drama abounding in romantic sentiment and agonizing situations, with a
musical accompaniment only in parts which are especially thrilling or
pathetic. In opera, a passage in which the orchestra plays a somewhat
descriptive accompaniment, while the actor speaks; <as>as, the
<ex>melodrama</ex> in the gravedigging scene of Beethoven's
<ldquo/Fidelio<rdquo/</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodramatic</ent><br/
<hw>Mel`o*dra*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/lodramatique</ets>.]</ety> <def>Of or pertaining to
melodrama; like or suitable to a melodrama; unnatural in situation or
action.</def> -- <wordforms><wf>Mel`o*dra*mat"ic*al*ly</wf>
<pr>(#)</pr>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodramatist</ent><br/
<hw>Mel`o*dram"a*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who acts
in, or writes, melodramas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melodrame</ent><br/
<hw>Mel"o*drame</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Melodrama.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melody</ent><br/
<hw>Mel"o*dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Melodies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>melodie</ets>, F.
<ets>m<eacute/lodie</ets>, L. <ets>melodia</ets>, fr. Gr. <?/ a singing,
choral song, fr. <?/ musical, melodious; <grk>me`los</grk> song, tune +
<?/ song. See <er>Ode</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A sweet or agreeable succession of sounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lulled with sound of sweetest <qex>melody</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A rhythmical succession of single
tones, ranging for the most part within a given key, and so related
together as to form a musical whole, having the unity of what is
technically called a musical thought, at once pleasing to the ear and
characteristic in expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Melody</xex> consists in a succession of single
tones; <xex>harmony</xex> is a consonance or agreement of tones, also a
succession of consonant musical combinations or chords.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The air or tune of a musical piece.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Harmony</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meloe</ent><br/
\'d8<hw>Mel"o*e</hw> <pr>(?)</pr>, <ety>[ NL., fr. Gr. <?/ to probe a
wound.]</ety> <fld>(Zool.)</fld> <def>A genus of beetles without wings,
but having short oval elytra; the oil beetles. These beetles are
sometimes used instead of cantharides for raising blisters. See
<cref>Oil beetle</cref>, under <er>Oil</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 911 --></p>

<p><ent>Melograph</ent><br/
<hw>Mel"o*graph</hw> <pr>(m<ecr/l"<osl/*gr<adot/f)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>me`los</grk> a song + <ets>-graph</ets> : cf. F.
<ets>m<eacute/lographe</ets>.]</ety> <def>Same as
<er>Melodiograph</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>meloid</ent><br/
<hw>meloid</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A beetle belonging
to the family <fam>Meloidae</fam>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Meloidae</ent><br/
<hw>Meloidae</hw> <pos>prop. n.</pos> <def>A natural family of insects
comprising the blister beetles.</def><br/
<syn><b>Syn. --</b> family <fam>Meloidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melolonthidae</ent><br/
<hw>Melolonthidae</hw> <pos>prop. n.</pos> <def>A natural subfamily of
beetles, considered a separate family in some classification
systems.</def><br/
<syn><b>Syn. --</b> subfamily <fam>Melolonthidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melolonthidian</ent><br/
<hw>Mel`o*lon*thid"i*an</hw>
<pr>(m<ecr/l`<osl/*l<ocr/n*th<icr/d"<icr/*<ait/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>mhlolo`nqh</grk> the cockchafer.]</ety>
<fld>(Zool.)</fld> <def>A beetle of the genus <gen>Melolontha</gen>, and
allied genera. See <cref>May beetle</cref>, under
<er>May</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melon</ent><br/
<hw>Mel"on</hw> <pr>(m<ecr/l"<ucr/n)</pr>, <pos>n.</pos> <ety>[F., fr.
L. <ets>melo</ets>, for <ets>melopepo</ets> an apple-shaped melon, Gr.
<grk>mhlope`pwn</grk> ; <grk>mh^lon</grk> apple + <grk>pe`pwn</grk> a
species of large melon; cf. L. <ets>malum</ets> apple. Cf.
<er>Marmalade</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>The juicy fruit of certain
cucurbitaceous plants, as the muskmelon, watermelon, and citron melon;
also, the plant that produces the fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A large, ornamental, marine,
univalve shell of the genus <gen>Melo</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Melon beetle</b></col> <fld>(Zool.)</fld>, <cd>a small
leaf beetle (<spn>Diabrotiea vittata</spn>), which damages the leaves of
melon vines.</cd> -- <mcol><col><b>Melon cactus</b></col>, <col><b>Melon
thistle</b></col></mcol>. <sd>(a)</sd> <fld>(Bot.)</fld> <cd>A genus of
cactaceous plants (<gen>Melocactus</gen>) having a fleshy and usually
globose stem with the surface divided into spiny longitudinal ridges,
and bearing at the top a prickly and woolly crown in which the small
pink flowers are half concealed</cd>. <spn>Melocactus communis</spn>,
from the West Indies, is often cultivated, and sometimes called
<stype>Turk's cap</stype>. <sd>(b)</sd> <cd>The related genus
<gen>Mamillaria</gen>, in which the stem is tubercled rather than
ribbed, and the flowers sometimes large. See <xex>Illust.</xex> under
<er>Cactus</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melopiano</ent><br/
<hw>Mel`o*pi*a"no</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`los</grk> song + E. <ets>piano</ets>.]</ety> <def>A piano having
a mechanical attachment which enables the player to prolong the notes at
will.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meloplastic</ent><br/
<hw>Mel`o*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to meloplasty, or the artificial formation of a new
cheek.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meloplasty</ent><br/
<hw>Mel"o*plas`ty</hw> <pr>(m<ecr/l"<osl/*pl<acr/s`t<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>mh^lon</grk> an apple, a cheek +
<ets>-plasty</ets>: cf. F. <ets>m<eacute/loplastie</ets>.]</ety>
<fld>(Surg.)</fld> <def>The process of restoring a cheek which has been
destroyed wholly or in part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melopoeia</ent><br/
\'d8<hw>Mel`o*p<oe/"ia</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/; <grk>me`los</grk> song + <grk>poiei^n</grk> to make.]</ety>
<fld>(Mus.)</fld> <def>The art of forming melody; melody; -- now often
used for a melodic passage, rather than a complete melody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>melosa</ent><br/
<hw>melosa</hw> <pos>n.</pos> <def>A South American herb (<spn>Madia
sativa</spn>) with sticky glandular foliage; it is a source of
<prod>madia oil</prod>.</def><br/
<syn><b>Syn. --</b> Chile tarweed, madia oil plant, <spn>Madia
sativa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melospiza</ent><br/
<hw>Melospiza</hw> <pos>prop. n.</pos> <def>A genus of American song
sparrows and swamp sparrows.</def><br/
<syn><b>Syn. --</b> genus <gen>Melospiza</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melotype</ent><br/
<hw>Mel"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Photog.)</fld>
<def>A picture produced by a process in which development after exposure
may be deferred indefinitely, so as to permit transportation of exposed
plates; also, the process itself.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Melpomene</ent><br/
<hw>Mel*pom"e*ne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/,
lit., the songstress, fr. <?/, <?/, to sing.]</ety> <sn>1.</sn>
<fld>(Class. Myth.)</fld> <def>The Muse of tragedy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>The eighteenth
asteroid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melrose</ent><br/
<hw>Mel"rose</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Honey of
roses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melt</ent><br/
<hw>Melt</hw> <pr>(m<ecr/lt)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See 2d <er>Milt</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melt</ent><br/
<hw>Melt</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Melted</conjf> <mark>(obs.)</mark> <pos>p. p.</pos>
<conjf>Molten</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Melting</conjf>.]</vmorph> <ety>[AS. <ets>meltan</ets>; akin to
Gr. <grk>me`ldein</grk>, E. <ets>malt</ets>, and prob. to E.
<ets>smelt</ets>, v. <root/108. Cf. <er>Smelt</er>, <pos>v.</pos>,
<er>Malt</er>, <er>Milt</er> the spleen.]</ety> <sn>1.</sn> <def>To
reduce from a solid to a liquid state, as by heat; to liquefy; <as>as,
to <ex>melt</ex> wax, tallow, or lead; to <ex>melt</ex> ice or
snow.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>To soften, as by a warming
or kindly influence; to relax; to render gentle or susceptible to mild
influences; sometimes, in a bad sense, to take away the firmness of; to
weaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou would'st have . . . <qex>melted</qex> down thy youth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For pity <qex>melts</qex> the mind to love.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To liquefy; fuse; thaw; mollify;
soften.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melt</ent><br/
<hw>Melt</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be changed from a
solid to a liquid state under the influence of heat; <as>as, butter and
wax <ex>melt</ex> at moderate temperatures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dissolve; <as>as, sugar <ex>melts</ex> in the
mouth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>To be softened; to become
tender, mild, or gentle; also, to be weakened or subdued, as by
fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My soul <qex>melteth</qex> for heaviness.</q> <rj><qau>Ps. cxix.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Melting</qex> with tenderness and kind compassion.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To lose distinct form or outline; to blend. See
<er>fondue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soft, green, rounded hills, with their flowing outlines,
overlapping and <qex>melting</qex> into each other.</q> <rj><qau>J. C.
Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To disappear by being dispersed or dissipated;
<as>as, the fog <ex>melts</ex> away</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meltable</ent><br/
<hw>Melt"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
melted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melter</ent><br/
<hw>Melt"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who, or
that which, melts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melting</ent><br/
<hw>Melt"ing</hw>, <pos>n.</pos> <def>Liquefaction; the act of causing
(something) to melt, or the process of becoming melted.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Melting point</b></col> <fld>(Chem.)</fld>, <cd>the
degree of temperature at which a solid substance melts or fuses; <as>as,
the <ex>melting point</ex> of ice is 0<deg/ Centigrade or 32<deg/ Fahr.,
that of urea is 132<deg/ Centigrade</as>. Pressure affects the melting
point somewhat, and if not specified the melting point is usually taken
to be at atmospheric pressure.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melting</ent><br/
<hw>Melt"ing</hw> <pos>a.</pos> <def>Causing to melt; becoming melted;
-- used literally or figuratively; <as>as, a <ex>melting</ex> heat; a
<ex>melting</ex> appeal; a <ex>melting</ex> mood</as>.</def> --
<wordforms><wf>Melt"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melting pot</ent><br/
<hw>Melt"ing pot</hw> <pos>n.</pos> <sn>1.</sn> <def>A vessel in which
anything is melted; a crucible.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Sociology)</fld> <mark>(fig.)</mark> <def>A place
where people of different backgrounds become similar in culture. The
United States has often been referred to as a <ex>melting pot</ex>,
though the differences in cultures of recently arrived immigrants
persists beyond the generation of immigrants.</def><br/
[<source>PJC</source>]</p>

<p><ent>Melton</ent><br/
<hw>Mel"ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A kind of stout woolen cloth with unfinished face
and without raised nap. A commoner variety has a cotton warp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Melungeon</ent><br/
<hw>Me*lun"geon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/langer</ets> to mix, <ets>m<eacute/lange</ets> a
mixture.]</ety> <def>One of a mixed white and Indian people living in
parts of Tennessee and the Carolinas. They are descendants of early
intermixtures of white settlers with natives. In North Carolina the
<col><b>Croatan Indians</b></col>, regarded as descended from
<person>Raleigh's</person> lost colony of Croatan, formerly classed with
negroes, are now legally recognized as distinct.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Melursus</ent><br/
<hw>Melursus</hw> <pos>prop. n.</pos> <def>A genus of mammals including
the sloth bears; in some classifications not a separate genus from
<gen>Ursus</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Melursus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Melville</ent><br/
<hw>Melville</hw> <pos>prop. n.</pos> <def>Herman Melville, American
novelist, author of <booki>Moby Dick</booki>; b. 1819, d.
1891.</def><br/
<syn><b>Syn. --</b> Herman Melville.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mem</ent><br/
<hw>mem</hw> <pos>n.</pos> <def>the 13th letter of the Hebrew
alphabet.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Member</ent><br/
<hw>Mem"ber</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Remember</er>.]</ety> <def>To remember; to cause to remember; to
mention.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Member</ent><br/
<hw>Mem"ber</hw>, <pos>n.</pos> <ety>[OE. <ets>membre</ets>, F.
<ets>membre</ets>, fr. L. <ets>membrum</ets>; cf. Goth. <ets>mimz</ets>
flesh, Skr. <ets>mamsa</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>A part of an animal capable of
performing a distinct office; an organ; a limb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have many <qex>members</qex> in one body, and all
<qex>members</qex> have not the same office.</q> <rj><qau>Rom. xii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A part of a whole; an
independent constituent of a body</def>; as: <sd>(a)</sd> <def>A part of
a discourse or of a period or sentence; a clause; a part of a
verse.</def> <sd>(b)</sd> <fld>(Math.)</fld> <def>Either of the two
parts of an algebraic equation, connected by the sign of equality.</def>
<sd>(c)</sd> <fld>(Engin.)</fld> <def>Any essential part, as a post, tie
rod, strut, etc., of a framed structure, as a bridge truss.</def>
<sd>(d)</sd> <fld>(Arch.)</fld> <def>Any part of a building, whether
constructional, as a pier, column, lintel, or the like, or decorative,
as a molding, or group of moldings.</def> <sd>(e)</sd> <def>One of the
persons composing a society, community, or the like; an individual
forming part of an association; <as>as, a <ex>member</ex> of the society
of Friends</as>.</def> <sd>(f)</sd> <fld>(Math.)</fld> <def>one of the
elements which, taken together, comprise a set.</def> <sd>(g)</sd>
<fld>(Math.)</fld> <def>one of the individual objects which comprise a
group or class.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><mcol><col><b>Compression member</b></col>, <col><b>Tension
member</b></col></mcol> <fld>(Engin.)</fld>, <cd>a member, as a rod,
brace, etc., which is subjected to compression or tension,
respectively.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membered</ent><br/
<hw>Mem"bered</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
limbs; -- chiefly used in composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Having legs of a different
tincture from that of the body; -- said of a bird in heraldic
representations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membership</ent><br/
<hw>Mem"ber*ship</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being
a member.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The collective body of members, as of a
society.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membral</ent><br/
<hw>Mem"bral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Relating to a member.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membranaceous</ent><br/
<hw>Mem`bra*na"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>membranaceus</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Same as <er>Membranous</er>.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Thin and rather soft or pliable,
as the leaves of the rose, peach tree, and aspen poplar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membrane</ent><br/
<hw>Mem"brane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>membrana</ets> the skin that covers the separate members of the
body, fr. L. <ets>membrum</ets>. See <er>Member</er>.]</ety>
<fld>(Anat.)</fld> <def>A thin layer or fold of tissue, usually
supported by a fibrous network, serving to cover or line some part or
organ, and often secreting or absorbing certain fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is also often applied to the thin, expanded
parts, of various texture, both in animals and vegetables.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Adventitious membrane</b></col>, <cd>a membrane
connecting parts not usually connected, or of a different texture from
the ordinary connection; as, the membrane of a cicatrix.</cd> --
<col><b>Jacob's membrane</b></col>. <cd>See under <er>Retina</er>.</cd>
-- <col><b>Mucous membranes</b></col> <fld>(Anat.)</fld>, <cd>the
membranes lining passages and cavities which communicate with the
exterior, as well as ducts and receptacles of secretion, and habitually
secreting mucus.</cd> -- <col><b>Schneiderian membrane</b></col>.
<fld>(Anat.)</fld> <cd>See <er>Schneiderian</er>.</cd> -- <col><b>Serous
membranes</b></col> <fld>(Anat.)</fld> <cd>, the membranes, like the
peritoneum and pleura, which line, or lie in, cavities having no obvious
outlet, and secrete a serous fluid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membraneous</ent><br/
<hw>Mem*bra"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>membraneus</ets> of parchment.]</ety> <def>See
<er>Membranous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membraniferous</ent><br/
<hw>Mem`bra*nif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Membrane</ets> + <ets>-ferous</ets>.]</ety> <def>Having or
producing membranes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membraniform</ent><br/
<hw>Mem*bra"ni*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Membrane</ets> + <ets>-form</ets>: cf. F.
<ets>membraniforme</ets>.]</ety> <def>Having the form of a membrane or
of parchment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membranology</ent><br/
<hw>Mem`bra*nol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Membrane</ets> + <ets>-logy</ets>.]</ety> <def>The science
which treats of membranes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Membranous</ent><br/
<hw>Mem"bra*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>membraneux</ets>.]</ety> <sn>1.</sn> <def>Pertaining to, consisting
of, or resembling, membrane; <as>as, a <ex>membranous</ex> covering or
lining</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Membranaceous.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Membranous croup</b></col> <fld>(Med.)</fld>, <cd>true
croup. See <er>Croup</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memento</ent><br/
<hw>Me*men"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mementos</plw> <pr>(#)</pr>.</plu> <ety>[L., remember, be mindful,
imper. of <ets>meminisse</ets> to remember. See <er>Mention</er>.]</ety>
<def>A hint, suggestion, token, or memorial, to awaken memory; that
which reminds or recalls to memory; a souvenir.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seasonable <qex>mementos</qex> may be useful.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memento mori</ent><br/
\'d8<hw>Me*men"to mo"ri</hw> <pr>(?)</pr>. <ety>[L.]</ety> <def>Lit.,
remember to die, i.e., that you must die; a warning to be prepared for
death; an object, as a death's-head or a personal ornament, usually
emblematic, used as a reminder of death.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Meminna</ent><br/
\'d8<hw>Me*min"na</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small deerlet, or chevrotain, of India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memnon</ent><br/
<hw>Mem"non</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., from Gr. <?/,
lit., the Steadfast, Resolute, the son of <persfn>Tithonus</persfn> and
<persfn>Aurora</persfn>, and king of the Ethiopians, killed by
<persfn>Achilles</persfn>.]</ety> <fld>(Antiq.)</fld> <def>A celebrated
Egyptian statue near Thebes, said to have the property of emitting a
harplike sound at sunrise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memoirs</ent><br/
<ent>Memoir</ent><br/
<mhw>{ <hw>Mem"oir</hw> <pr>(?)</pr>, or <pluf>pl.</pluf>
<hw>Mem"oirs</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/moire</ets>, m., memorandum, fr.
<ets>m<eacute/moire</ets>, f., memory, L. <ets>memoria</ets>. See
<er>Memory</er>.]</ety> <sn>1.</sn> <def>A memorial account; a history
composed from personal experience and memory; an account of transactions
or events (usually written in familiar style) as they are remembered by
the writer. See <er>History</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A memorial of any individual; a biography; often, a
biography written without special regard to method and
completeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An account of something deemed noteworthy; an essay;
a record of investigations of any subject; the journals and proceedings
of a society.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memoirist</ent><br/
<hw>Mem"oir*ist</hw>, <pos>n.</pos> <def>A writer of memoirs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>memorabilia</ent><br/
<hw>mem`o*ra*bil"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., fr.
<ets>memorabilis</ets> memorable. See <er>Memorable</er>.]</ety>
<sn>1.</sn> <def>Things remarkable and worthy of remembrance or record;
also, the record of them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mementos of past events; souvenirs.</def><br/
[<source>PJC</source>]</p>

<p><ent>Memorability</ent><br/
<hw>Mem`o*ra*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
or state of being memorable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorable</ent><br/
<hw>Mem"o*ra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>memorabilis</ets>, fr. <ets>memorare</ets> to bring to remembrance,
fr. <ets>memor</ets> mindful, remembering. See <er>Memory</er>, and cf.
<er>Memorabilia</er>.]</ety> <def>Worthy to be remembered; very
important or remarkable.</def> -- <wordforms><wf>Mem"o*ra*ble*ness</wf>,
<pos>n.</pos> -- <wf>Mem"o*ra*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Surviving fame to gain,<br/
Buy tombs, by books, by <qex>memorable</qex> deeds.</q> <rj><qau>Sir J.
Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorandum</ent><br/
<hw>Mem`o*ran"dum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Memorandums</plw>, L. <plw>Memoranda</plw> <pr>(#)</pr>.</plu>
<ety>[L., something to be remembered, neut. of <ets>memorandus</ets>,
fut. pass. p. of <ets>memorare</ets>. See <er>Memorable</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A record of something which it is desired to
remember; a note to help the memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . entered a <qex>memorandum</qex> in my pocketbook.</q>
<rj><qau>Guardian.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I wish you would, as opportunity offers, make
<qex>memorandums</qex> of the regulations of the academies.</q>
<rj><qau>Sir J. Reynolds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A brief or informal note in writing
of some transaction, or an outline of an intended instrument; an
instrument drawn up in a brief and compendious form.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Memorandum check</b></col>, <cd>a check given as an
acknowledgment of indebtedness, but with the understanding that it will
not be presented at bank unless the maker fails to take it up on the day
the debt becomes due. It usually has <xex>Mem.</xex> written on its
face.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorate</ent><br/
<hw>Mem"o*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>memoratus</ets>, p. p. of <ets>memorare</ets>. See
<er>Memorable</er>.]</ety> <def>To commemorate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorative</ent><br/
<hw>Mem"o*ra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/moratif</ets>.]</ety> <def>Commemorative.</def>
<mark>[Obs.]</mark> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memoria</ent><br/
\'d8<hw>Me*mo"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Memoria technica</b></col>, <cd>technical memory; a
contrivance for aiding the memory.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorial</ent><br/
<hw>Me*mo"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>m<eacute/morial</ets>, L. <ets>memorialis</ets>, fr.
<ets>memoria</ets>. See <er>Memory</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Serving to preserve remembrance; commemorative;
<as>as, a <ex>memorial</ex> building</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There high in air, <qex>memorial</qex> of my name,<br/
Fix the smooth oar, and bid me live to fame.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Contained in memory; <as>as, a <ex>memorial</ex>
possession</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Mnemonic; assisting the memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This succession of Aspirate, Soft, and Hard, may be expressed by
the <qex>memorial</qex> word ASH.</q> <rj><qau>Skeat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Memorial Day</b></col>. <cd>See <er>Memorial Day</er> in
the vocabulary. Also called <altname><er>Decoration
Day</er></altname>.</cd> <mark>[U.S.]</mark></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Memorial</ent><br/
<hw>Me*mo"ri*al</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/morial</ets>.]</ety> <sn>1.</sn> <def>Anything intended to
preserve the memory of a person or event; something which serves to keep
something else in remembrance; a monument.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Churches have names; some as <qex>memorials</qex> of peace, some
of wisdom, some in memory of the Trinity itself.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A memorandum; a record.</def> <mark>[Obs. or
R.]</mark> <rj><au>Hayward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A written representation of facts, addressed to the
government, or to some branch of it, or to a society, etc., -- often
accompanied with a petition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Memory; remembrance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Precious is the <qex>memorial</qex> of the just.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Diplomacy)</fld> <def>A species of informal state
paper, much used in negotiation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorial Day</ent><br/
<hw>Me*mo"ri*al Day</hw>. <sn>1.</sn> <def>A day, originally May 30,
appointed for commemorating, by decorating their graves with flowers, by
patriotic exercises, etc., the dead soldiers and sailors who served the
Civil War (1861-65) in the United States; Also called
<altname>Decoration Day</altname>. It is a legal holiday in most of the
States. In the Southern States, the Confederate Memorial Day is: May 30
in Virginia; April 26 in Alabama, Florida, Georgia, and Mississippi; May
10 in North Carolina and South Carolina; the second Friday in May in
Tennessee; June 3 in Louisiana.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A day designated for commemoration of all of the war
dead of the United States, celebrated on the last Monday in May in most
states. It supersedes the original <ex>Memorial Day</ex> celebrated May
30th.</def><br/
[<source>PJC</source>]</p>

<p><ent>memorialise</ent><br/
<hw>me*mo"ri*al*ise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Same as
memorialize.</def> <mark>[Chiefly Brit.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Memorialist</ent><br/
<hw>Me*mo"ri*al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/morialiste</ets>.]</ety> <def>One who writes or signs a
memorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorialize</ent><br/
<hw>Me*mo"ri*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Memorialized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Memorializing</conjf>
<pr>(?)</pr>.]</vmorph> <def>To address or petition by a memorial; to
present a memorial to; <as>as, to <ex>memorialize</ex> the
legislature</as>.</def> <rj><au>T. Hook.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorializer</ent><br/
<hw>Me*mo"ri*al*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
petitions by a memorial.</def> <rj><au>T. Hook.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorial rose</ent><br/
<hw>Memorial rose</hw>. <def>A Japanese evergreen rose (<spn>Rosa
wichuraiana</spn>) with creeping branches, shining leaves, and single
white flowers. It is often planted in cemeteries.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Memorist</ent><br/
<hw>Mem"o*rist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Memorize</er>.]</ety> <def>One who, or that which, causes to be
remembered.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memoriter</ent><br/
\'d8<hw>Me*mor"i*ter</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[L., fr.
<ets>memor</ets> mindful. See <er>Memorable</er>.]</ety> <def>By, or
from, memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memorize</ent><br/
<hw>Mem"o*rize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Memorized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Memorizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[See
<er>Memory</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To cause to be remembered ; hence, to record.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They neglect to <qex>memorize</qex> their conquest.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They meant to . . . <qex>memorize</qex> another Golgotha.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To commit to memory; to learn by heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>memorizer</ent><br/
<hw>memorizer</hw> <pos>n.</pos> <def>A person who learns by
rote.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Memory</ent><br/
<hw>Mem"o*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Memories</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>memorie</ets>,
OF. <ets>memoire</ets>, <ets>memorie</ets>, F.
<ets>m<eacute/moire</ets>, L. <ets>memoria</ets>, fr. <ets>memor</ets>
mindful; cf. <ets>mora</ets> delay. Cf. <er>Demur</er>, <er>Martyr</er>,
<er>Memoir</er>, <er>Remember</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The faculty of the mind by which it retains the
knowledge of previous thoughts, impressions, or events.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Memory</qex> is the purveyor of reason.</q>
<rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The reach and positiveness with which a person can
remember; the strength and trustworthiness of one's power to reach and
represent or to recall the past; <as>as, his <ex>memory</ex> was never
wrong</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The actual and distinct retention and recognition of
past ideas in the mind; remembrance; <as>as, in <ex>memory</ex> of
youth; <ex>memories</ex> of foreign lands.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The time within which past events can be or are
remembered; <as>as, within the <ex>memory</ex> of man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And what, before thy <qex>memory</qex>, was done<br/
From the begining.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Something, or an aggregate of things, remembered;
hence, character, conduct, etc., as preserved in remembrance, history,
or tradition; posthumous fame; <as>as, the war became only a
<ex>memory</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>memory</qex> of the just is blessed.</q> <rj><qau>Prov.
x. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That ever-living man of <qex>memory</qex>, Henry the Fifth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Nonconformists . . . have, as a body, always venerated her
[Elizabeth's] <qex>memory</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A memorial.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These weeds are <qex>memories</qex> of those worser hours.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Memory</er>, <er>Remembrance</er>,
<er>Recollection</er>, <er>Reminiscence</er>.</syn> <usage>
<xex>Memory</xex> is the generic term, denoting the power by which we
reproduce past impressions. <xex>Remembrance</xex> is an exercise of
that power when things occur <xex>spontaneously</xex> to our thoughts.
In <xex>recollection</xex> we make a distinct effort to <xex>collect
again</xex>, or call back, what we know has been formerly in the mind.
<xex>Reminiscence</xex> is intermediate between <xex>remembrance</xex>
and <xex>recollection</xex>, being a conscious process of recalling past
occurrences, but without that full and varied reference to particular
things which characterizes <xex>recollection</xex>. <ldquo/When an idea
again recurs without the operation of the like object on the external
sensory, it is <xex>remembrance</xex>; if it be sought after by the
mind, and with pain and endeavor found, and brought again into view, it
is <xex>recollection</xex>.<rdquo/ <rj><au>Locke.</au></rj> </usage><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To draw to memory</b></col>, <cd>to put on record; to
record. </cd> <mark>[Obs.]</mark> <rj><au>Chaucer.
Gower.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Memphian</ent><br/
<hw>Mem"phi*an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <sn>1.</sn>
<def>Of or pertaining to the ancient city of <city>Memphis</city> in
Egypt; hence, Egyptian; <as>as, <ex>Memphian</ex>
darkness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the city of <city>Memphis</city>
in Tennessee.</def><br/
[<source>PJC</source>]</p>

<p><ent>Memphian</ent><br/
<hw>Mem"phi*an</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A native or
resident of the city of <city>Memphis</city> in Tennessee.</def><br/
[<source>PJC</source>]</p>

<p><ent>mem-sahib</ent><br/
<ent>memsahib</ent><br/
<mhw><hw>mem"sa`hib</hw>, <hw>mem"-sa`hib</hw></mhw>
<pr>(m<ecr/m"s<aum/`<icr/b)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>mem-s<amac/hib</ets>; <ets>mem</ets> (fr. E. <ets>ma'am</ets>) +
Ar. <ets><cced/<amac/hib</ets> master. See <er>Sahib</er>.]</ety>
<def>Lady; mistress; -- used by Hindustani-speaking natives in India in
addressing European women.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Men</ent><br/
<hw>Men</hw> <pr>(m<ecr/n)</pr>, <pos>n.</pos>, <def><pos>pl.</pos> of
<er>Man</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Men</ent><br/
<hw>Men</hw>, <pos>pron.</pos> <ety>[OE. <ets>me</ets>, <ets>men</ets>.
<ldquo/Not the plural of <ets>man</ets>, but a weakened form of the word
<ets>man</ets> itself.<rdquo/ <ets>Skeat</ets>.]</ety> <def>A man; one;
-- used with a verb in the singular, and corresponding to the present
indefinite <xex>one</xex> or <xex>they</xex>.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Men</qex> moot give silver to the poure friars.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A privy thief, <qex>men</qex> clepeth death.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menaccanite</ent><br/
<hw>Me*nac"can*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<etsep>Menaccan</etsep>, in Cornwall, where it was first found.]</ety>
<fld>(Min.)</fld> <def>An iron-black or steel-gray mineral, consisting
chiefly of the oxides of iron and titanium. It is commonly massive, but
occurs also in rhombohedral crystals. Called also <altname>titanic iron
ore</altname>, and <altname>ilmenite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menace</ent><br/
<hw>Men"ace</hw> <pr>(m<ecr/n"<asl/s; 48)</pr>, <pos>n.</pos> <ety>[F.,
fr. L. <ets>minaciae</ets> threats, menaces, fr. <ets>minax</ets>,
<ets>-acis</ets>, projecting, threatening, <ets>minae</ets> projecting
points or pinnacles, threats. Cf. <er>Amenable</er>, <er>Demean</er>,
<er>Imminent</er>, <er>Minatory</er>.]</ety> <def>The show of an
intention to inflict evil; a threat or threatening; indication of a
probable evil or catastrophe to come.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His (the pope's) commands, his rebukes, his
<qex>menaces</qex>.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The dark <qex>menace</qex> of the distant war.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 912 --></p>

<p><ent>Menace</ent><br/
<hw>Men"ace</hw> <pr>(m<ecr/n"<asl/s; 48)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Menaced</conjf>
<pr>(<amac/st)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Menacing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[OF. <ets>menacier</ets>, F.
<ets>menacer</ets>. See <er>Menace</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To express or show an intention to inflict, or to hold
out a prospect of inflicting, evil or injury upon; to threaten; --
usually followed by <xex>with</xex> before the harm threatened; <as>as,
to <ex>menace</ex> a country with war</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My master . . . did <qex>menace</qex> me with death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To threaten, as an evil to be inflicted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By oath he <qex>menaced</qex><br/
Revenge upon the cardinal.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menace</ent><br/
<hw>Men"ace</hw>, <pos>v. i.</pos> <def>To act in threatening manner; to
wear a threatening aspect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who ever knew the heavens <qex>menace</qex> so?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menacer</ent><br/
<hw>Men"a*cer</hw> <pr>(m<ecr/n"<asl/*s<etil/r)</pr>, <pos>n.</pos>
<def>One who menaces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menacingly</ent><br/
<hw>Men"a*cing*ly</hw>, <pos>adv.</pos> <def>In a threatening
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>menage</ent><br/
\'d8<hw>m<eacute/`nage"</hw> <pr>(m<asl/`n<adot/zh")</pr>, <pos>n.</pos>
<def>See <er>manege</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>menage</ent><br/
\'d8<hw>m<eacute/`nage"</hw> <pr>(m<asl/`n<adot/zh")</pr>, <pos>n.</pos>
<ety>[See <er>Menagerie</er>.]</ety> <sn>1.</sn> <def>A collection of
animals; a menagerie.</def> <mark>[Obs.]</mark>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A social group living together; a
household.</def><br/
<syn><b>Syn. --</b> family, household, house.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>A <er>menage a trois</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>menage a trois</ent><br/
<ent>menage-a-trois</ent><br/
\'d8<hw>m<eacute/`nage <agrave/` trois"</hw> <pr>(m<asl/`n<adot/zh"
<adot/ trw<adot/)</pr>, <pos>n.</pos> <ety>[F., household for
three]</ety> <sn>1.</sn> <def>A relationship involving three people,
especially one in which three people live together and have sexual
relations, such as a married couple and a lover of one of the
pair.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A single sexual encounter in which three people
participate.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <mark>[figurative]</mark> <def>An unlikely situation in
which a group of three people not normally associated with each other
participate in an activity together.</def><br/
[<source>PJC</source>]</p>

<p><q> For the first time in World Championships history, two racers
shared the first-place gold medal. <persfn>Maier</persfn> and
<persfn>Kjus</persfn> arm-in-arm on the podium, with Austrian
<person>Hans Knauss</person> just .01 seconds back from making it a
<qex>menage-a-trois</qex>.</q><br/
<qau>Andrew Hood
(http://classic.mountainzone.com/ski/worldcup/99/worldchamps/superg-m.html)</qau><br/
[<source>PJC</source>]</p>

<p><ent>Menagerie</ent><br/
<hw>Men*ag"er*ie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/nagerie</ets>, fr. <ets>m<eacute/nager</ets> to keep
house, <ets>m<eacute/nage</ets> household. See <er>Menial</er>,
<er>Mansion</er>.]</ety> <sn>1.</sn> <def>A place where animals are kept
and trained.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A collection of wild or exotic animals, kept for
exhibition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menagogue</ent><br/
<hw>Men"a*gogue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/nagogue</ets>, fr. Gr. <grk>mh`n</grk> month + <?/
leading.]</ety> <fld>(Med.)</fld> <def>Emmenagogue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menaion</ent><br/
\'d8<hw>Me*na"ion</hw> <pr>(m<esl/*n<amac/"y<ocr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Menaia</plw> <pr>(-y<adot/)</pr>.</plu>
<ety>[NL., from Gr. <grk>mhnai^os</grk> monthly.]</ety>
<fld>(Eccl.)</fld> <def>A work of twelve volumes, each containing the
offices in the Greek Church for a month; also, each volume of the
same.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menald</ent><br/
<ent>Menild</ent><br/
<mhw>{ <hw>Men"ald</hw> <pr>(m<ecr/n"<acr/ld)</pr>, <hw>Men"ild</hw>
<pr>(m<ecr/n"<icr/ld)</pr>, }</mhw> <pos>a.</pos> <def>Covered with
spots; speckled; variegated.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mend</ent><br/
<hw>Mend</hw> <pr>(m<ecr/nd)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mending</conjf>.]</vmorph> <ety>[Abbrev. fr. <ets>amend</ets>.
See <er>Amend</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To repair, as anything that is torn, broken,
defaced, decayed, or the like; to restore from partial decay, injury, or
defacement; to patch up; to put in shape or order again; to re-create;
<as>as, to <ex>mend</ex> a garment or a machine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To alter for the better; to set right; to reform;
hence, to quicken; <as>as, to <ex>mend</ex> one's manners or
pace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The best service they could do the state was to <qex>mend</qex>
the lives of the persons who composed it.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To help, to advance, to further; to add
to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though in some lands the grass is but short, yet it
<qex>mends</qex> garden herbs and fruit.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>mend</qex> the jewel by the wearing it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To improve; help; better; emend; amend; correct;
rectify; reform.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mend</ent><br/
<hw>Mend</hw>, <pos>v. i.</pos> <def>To grow better; to advance to a
better state; to become improved; to recover; to heal.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>on the mend</b></col> <pos>pred. a.</pos> <cd>recovering
from an illness or injury.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Mendable</ent><br/
<hw>Mend"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
mended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendacious</ent><br/
<hw>Men*da"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mendax</ets>, <ets>-acis</ets>, lying, cf. <ets>mentiri</ets> to
lie.]</ety> <sn>1.</sn> <def>Given to deception or falsehood; lying;
<as>as, a <ex>mendacious</ex> person</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>False; counterfeit; containing falsehood; <as>as, a
<ex>mendacious</ex> statement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Men*da"cious*ly</wf>, <pos>adv.</pos> --
<wf>Men*da"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendacity</ent><br/
<hw>Men*dac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mendacities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>mendacitas</ets>.]</ety> <sn>1.</sn> <def>The quality or state of
being mendacious; a habit of lying.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A falsehood; a lie.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Lying; deceit; untruth; falsehood.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendel</ent><br/
<hw>Mendel</hw> <pos>prop. n.</pos> <def><person>Gregor Johann
Mendel</person>, founder of the science of genetics (1822-1884);
<person>Gregor Mendel</person>.</def><br/
<syn><b>Syn. --</b> <person>Gregor Mendel</person>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mendelevium</ent><br/
<hw>men*de*le"vi*um</hw>
<pr>(m<ecr/n*d<ecr/*l<emac/"v<emac/*<ucr//m)</pr>, <pos>a.</pos>
<ety>[From <person>Dmitri <etsep>Mendeleyev</etsep></person>, discoverer
of the periodic law.]</ety> <fld>(Chem.)</fld> <def>an unstable
radioactive element discovered in 1955 and produced artificially only in
very small quantities; symbol Md (also Mv). It is a <isa>transuranic
element</isa> with atomic number 101. Isotopes 255, 256, 257, and 258
have been prepared. Md<sup>258</sup>, the longest-lived, has a half-life
of two months.</def> <au>HCP61</au><br/
[<source>PJC</source>]</p>

<p><ent>Mendelian</ent><br/
<hw>Men*de"li*an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <ety>[See
<er>Mendel's law</er>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>Pert.
to <persfn>Mendel</persfn>, or to Mendel's law; <as>as,
<ex>Mendelian</ex> inheritance</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Behaving or being in accordance
with Mendel's laws of inheritance; -- said of the distribution of
inherited characteristics and of traits thus distributed.</def> --
<wordforms><wf>Men*de"li*an*ism</wf> <pr>(#)</pr>, <wf>Men*del"ism</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Mendelian character</ent><br/
<hw>Mendelian character</hw>. <fld>(Biol.)</fld> <def>A character which
obeys Mendel's law in regard to its hereditary transmission.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mendel's law</ent><br/
<hw>Men"del's law</hw> <pr>(?)</pr>. <def>A principle governing the
inheritance of many characters in animals and plants, discovered by
<person>Gregor J. Mendel</person> (Austrian Augustinian abbot, 1822-84)
in breeding experiments with peas. He showed that the height, color, and
other characters depend on the presence of determinating factors
behaving as units. In any given germ cell each of these is either
present or absent.</def></p>

<note><p>The following example (using letters as
symbols of the determining factors and hence also of the individuals
possessing them) shows the operation of the law: Tallness being due to a
factor <xex>T</xex>, a tall plant, arising by the union in fertilization
of two germ cells both bearing this factor, is <xex>TT</xex>; a dwarf,
being without <xex>T</xex>, is <xex>tt</xex>. Crossing these,
crossbreeds, <xex>Tt</xex>, result (called generation
<it>F</it><subs>1</subs>). In the formation of the germ cells of these
crossbreeds a process of segregation occurs such that germ cells,
whether male or female, are produced of two kinds, <xex>T</xex> and
<xex>t</xex>, in equal numbers. The <xex>T</xex> cells bear the factor
<ldquo/tallness,<rdquo/ the <xex>t</xex> cells are devoid of it. The
offspring, generation <it>F</it><subs>2</subs>, which arise from the
chance union of these germ cells in pairs, according to the law of
probability, are therefore on an average in the following
proportions:</p>

<p>1 <xex>TT</xex> : 2 <xex>Tt</xex> : 1 <xex>tt</xex>;</p>

<p>and thus plants pure in tallness (<xex>TT</xex>) and dwarfness
(<xex>tt</xex>), as well as crossbreeds (<xex>Tt</xex>), are formed by
the interbreeding of crossbreeds. Frequently, as in this example, owning
to what is called the <xex>dominance</xex> of a factor, the operation of
Mendel's law may be complicated by the fact that when a
<xex>dominant</xex> factor (as <xex>T</xex>) occurs with its allelomorph
(as <xex>t</xex>), called <xex>recessive</xex>, in the crossbreed
<xex>Tt</xex>, the individual <xex>Tt</xex> is itself indistinguishable
from the pure form <xex>TT</xex>. Generation <it>F</it><subs>1</subs>,
containing only the <xex>Tt</xex> form, consists entirely of dominants
(tall plants) and generation <it>F</it><subs>2</subs> consists of three
dominants (2 <xex>Tt</xex>, 1 <xex>TT</xex>) to one dwarf
(<xex>tt</xex>), which, displaying the feature suppressed in
<it>F</it><subs>1</subs>, is called <xex>recessive</xex>. Such
qualitative and numerical regularity has been proved to exist in regard
to very diverse qualities or characters which compose living things,
both wild and domesticated, such as colors of flowers, of hair or eyes,
patterns, structure, chemical composition, and power of resisting
certain diseases. The diversity of forms produced in crossbreeding by
horticulturists and fanciers generally results from a process of
analytical variation or recombination of the factors composing the
parental types. Purity of type consequently acquires a specific meaning.
An individual is pure in respect of a given character when it results
from the union of two sexual cells both bearing that character, or both
without it.<br/
[<source>Webster 1913 Suppl.</source>]</p></note>

<p><ent>Mender</ent><br/
<hw>Mend"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who mends or
repairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendiant</ent><br/
<hw>Men"di*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mendinant</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendicancy</ent><br/
<hw>Men"di*can*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
being mendicant; beggary; begging.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendicant</ent><br/
<hw>Men"di*cant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mendicans</ets>, <ets>-antis</ets>, p. pr. of <ets>mendicare</ets>
to beg, fr. <ets>mendicus</ets> beggar, indigent.]</ety> <def>Practicing
beggary; begging; living on alms; <as>as, <ex>mendicant</ex>
friars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mendicant orders</b></col> <fld>(R. C. Ch.)</fld>,
<cd>certain monastic orders which are forbidden to acquire landed
property and are required to be supported by alms, esp. the Franciscans,
the Dominicans, the Carmelites, and the Augustinians.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendicant</ent><br/
<hw>Men"di*cant</hw>, <pos>n.</pos> <def>A beggar; esp., one who makes a
business of begging; specifically, a begging friar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendicate</ent><br/
<hw>Men"di*cate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[L.
<ets>mendicatus</ets>, p. p. of <ets>mendicare</ets> to beg.]</ety>
<def>To beg.</def> <mark>[R.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendication</ent><br/
<hw>Men`di*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
practice of begging; beggary; mendicancy.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendicity</ent><br/
<hw>Men*dic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mendicitas</ets>: cf. F. <ets>mendicit<eacute/</ets>. See
<er>Mendicant</er>.]</ety> <def>The practice of begging; the life of a
beggar; mendicancy.</def> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendinant</ent><br/
<hw>Men"di*nant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mendicant or
begging friar.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendment</ent><br/
<hw>Mend"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Amendment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendole</ent><br/
<hw>Men"dole</hw> <pr>(m<ecr/n"d<omac/l)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>mendol</ets>, <ets>mendole</ets>.]</ety> <fld>(Zool.)</fld>
<def>The cackerel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mendregal</ent><br/
<hw>Men"dre*gal</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Medregal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mends</ent><br/
<hw>Mends</hw> <pr>(m<ecr/ndz)</pr>, <pos>n.</pos> <def>See
<er>Amends</er>.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menge</ent><br/
<hw>Menge</hw> <pr>(m<ecr/nj)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Mente</conjf>, <conjf>Meinte</conjf>;
<pos>p. p.</pos> <conjf>Ment</conjf>, <conjf>Meint</conjf>.]</vmorph>
<ety>[See <er>Mingle</er>.]</ety> <def>To mix.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>menhaden</ent><br/
<hw>men*ha"den</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An American marine fish (<spn>Brevoortia tyrannus</spn>) of the
<membof>Herring family</membof> (<fam>Clupeidae</fam>), chiefly valuable
for its oil and as a component of fertilizers; -- called also
<altname>mossbunker</altname>, <altname>bony fish</altname>,
<altname>chebog</altname>, <altname>pogy</altname>,
<altname>hardhead</altname>, <altname>whitefish</altname>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menhir</ent><br/
<hw>Men"hir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Armor.
<ets>men</ets> stone + <ets>hir</ets> high.]</ety> <def>A large stone
set upright in olden times as a memorial or monument. Many, of unknown
date, are found in Brittany and throughout Northern Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menial</ent><br/
<hw>Men"ial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>meneal</ets>, fr. <ets>meine</ets>, <ets>maine</ets>, household,
OF. <ets>maisni<eacute/e</ets>, <ets>maisnie</ets>, LL.
<ets>mansionaticum</ets>. See <er>Mansion</er>, and cf. <er>Meine</er>,
<pos>n.</pos>, <er>Meiny</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Belonging to a retinue or train of servants;
performing servile office; serving.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Two <qex>menial</qex> dogs before their master pressed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to servants, esp. domestic servants;
servile; low; mean; <as>as, <ex>menial</ex> tasks</as>.</def> <ldquo/
<xex>Menial</xex> offices.<rdquo/ <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menial</ent><br/
<hw>Men"ial</hw>, <pos>n.</pos> <sn>1.</sn> <def>A domestic servant or
retainer, esp. one of humble rank; one employed in low or servile
offices.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person of a servile character or
disposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meniere's disease</ent><br/
<hw>M<eacute/`ni<egrave/re's" dis*ease"</hw> <pr>(?)</pr>.
<fld>(Med.)</fld> <def>A disease characterized by deafness and vertigo,
resulting in incoordination of movement. It is supposed to depend upon a
morbid condition of the semicircular canals of the internal ear. Named
after <persfn><etsep>M<eacute/ni<egrave/re</etsep></persfn>, a French
physician.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menilite</ent><br/
<hw>Men"i*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/nilite</ets>; -- so called because it is found at
<ets>M<eacute/nil</ets>montant, near Paris.]</ety> <fld>(Min.)</fld>
<def>See <er>Opal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>meningeal</ent><br/
<hw>me*nin"ge*al</hw> <pr>(m<esl/*n<icr/n"j<esl/*<ait/l)</pr>,
<pos>a.</pos> <fld>(Anat.)</fld> <def>Of or pertaining to the
meninges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meninges</ent><br/
<hw>Me*nin"ges</hw> <pr>(m<esl/*n<icr/n"j<emac/z)</pr>, <pos>n.
pl.</pos>; <sing>sing. <singw>Meninx</singw>
<pr>(m<esl/*n<icr/<nsm/ks")</pr></sing>. <ety>[NL., fr. Gr.
<grk>mh^nigx</grk>, <grk>mh^niggos</grk>, a membrane.]</ety>
<fld>(Anat.)</fld> <def>The three membranes that envelop the brain and
spinal cord; the pia mater, dura mater, and arachnoid
membrane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meningitis</ent><br/
<hw>Men`in*gi"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meninges</er>, and <er>-itis</er>.]</ety> <fld>(Med.)</fld>
<def>Inflammation of the membranes of the brain or spinal
cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cerebro-spinal meningitis</b></col>. <cd>See under
<er>Cerebro-spinal</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meniscal</ent><br/
<hw>Me*nis"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
having the form of, a meniscus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meniscoid</ent><br/
<hw>Me*nis"coid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meniscus</ets> + <ets>-oid</ets>.]</ety> <def>Concavo-convex,
like a meniscus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meniscus</ent><br/
<hw>Me*nis"cus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Menisci</plw> <pr>(-s<imac/)</pr>, E. <plw>Meniscuses</plw>
<pr>(#)</pr>.</plu> <ety>[NL., from Gr. <grk>mhni`skos</grk>, dim. of
<grk>mh`nh</grk> the moon.]</ety> <sn>1.</sn> <def>A crescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Opt.)</fld> <def>A lens convex on one side and
concave on the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>An interarticular synovial
cartilage or membrane; esp., one of the intervertebral synovial disks in
some parts of the vertebral column of birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Converging meniscus</b></col>, <col><b>Diverging
meniscus</b></col></mcol>. <cd>See <er>Lens</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menispermaceous</ent><br/
<hw>Men`i*sper*ma"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>mh`nh</grk> the moon + <grk>spe`rma</grk> seed.]</ety>
<fld>(Bot.)</fld> <def>Pertaining to a natural order
(<ord>Menispermaceae</ord>) of climbing plants of which moonseed
(<gen>Menispermum</gen>) is the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menispermic</ent><br/
<hw>Men`i*sper"mic</hw> <pr>(<?/)</pr>, <pos>a.</pos> <def>Pertaining
to, or obtained from, moonseed (<gen>Menispermum</gen>), or other plants
of the same family, as the <spn>Anamirta Cocculus</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menispermine</ent><br/
<hw>Men`i*sper"mine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/nispermine</ets>.]</ety> <fld>(Chem.)</fld> <def>An
alkaloid distinct from picrotoxin and obtained from the cocculus indicus
(the fruit of <spn>Anamirta Cocculus</spn>, formerly <spn>Menispermum
Cocculus</spn>) as a white, crystalline, tasteless powder; -- called
also <altname>menispermina</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meniver</ent><br/
<hw>Men"i*ver</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>menuver</ets>, <ets>menuveir</ets>, <ets>menuvair</ets>, a grayish
fur; <ets>menu</ets> small + <ets>vair</ets> a kind of fur. See
<er>Minute</er>, <pos>a.</pos>, and <er>Vair</er>.]</ety> <def>Same as
<er>Miniver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mennonite</ent><br/
<ent>Mennonist</ent><br/
<mhw>{ <hw>Men"non*ist</hw> <pr>(?)</pr>, <hw>Men"non*ite</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One of
a small denomination of Christians, so called from
<person><etsep>Menno</etsep> Simons</person> of Friesland, their
founder. They believe that the New Testament is the only rule of faith,
that there is no original sin, that infants should not be baptized, and
that Christians ought not to take oath, hold office, or render military
service.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menobranchus</ent><br/
<ent>menobranch</ent><br/
<mhw>{ <hw>men"o*branch</hw> <pr>(?)</pr>, \'d8<hw>Men`o*bran"chus</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>menobranchus</ets>,
fr. Gr. <?/ to remain + <?/ a gill.]</ety> <fld>(Zool.)</fld> <def>A
large aquatic American salamander of the genus <gen>Necturus</gen>,
having permanent external gills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menology</ent><br/
<ent>Menologium</ent><br/
<mhw>{ \'d8<hw>Men`o*lo"gi*um</hw> <pr>(?)</pr>, <hw>Me*nol"o*gy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Menologia</plw> <pr>(#)</pr>, E. <plw>Menologies</plw>
<pr>(#)</pr>.</plu> <ety>[NL. <ets>menologium</ets>, fr. Gr.
<grk>mh`n</grk> month + <grk>lo`gos</grk> discourse : cf. F.
<ets>m<eacute/nologe</ets>.]</ety> <sn>1.</sn> <def>A register of
months.</def> <rj><au>Bp. Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gr. Church)</fld> <def>A brief calendar of the
lives of the saints for each day in the year, or a simple remembrance of
those whose lives are not written.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menopause</ent><br/
<hw>Men"o*pause</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mh`n</grk> month + <?/ to cause to cease. See
<er>Menses</er>.]</ety> <fld>(Med.)</fld> <def>The period of natural
cessation of menstruation. See <cref>Change of life</cref>, under
<er>Change</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menopome</ent><br/
<ent>Menopoma</ent><br/
<mhw>{ \'d8<hw>Men`o*po"ma</hw> <pr>(?)</pr>, <hw>Men"o*pome</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>menopoma</ets>, fr.
Gr. <?/ to remain + <?/ lid.]</ety> <fld>(Zool.)</fld> <def>The
hellbender.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menorrhagia</ent><br/
\'d8<hw>Men`or*rha"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>mh`n</grk> month + <?/ to break.]</ety> <fld>(Med.)</fld>
<sd>(a)</sd> <def>Profuse menstruation.</def> <sd>(b)</sd> <def>Any
profuse bleeding from the uterus; Metrorrhagia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menostasis</ent><br/
\'d8<hw>Me*nos"ta*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>mh`n</grk> month + <grk>'ista`nai</grk> to stop.]</ety>
<fld>(Med.)</fld> <def>Stoppage of the menses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menostation</ent><br/
<hw>Men`os*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Same as <er>Menostasis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menow</ent><br/
<hw>Men"ow</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
minnow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Men-pleaser</ent><br/
<hw>Men"-pleas`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One whose motive
is to please men or the world, rather than God.</def> <rj><au>Eph. vi.
6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensal</ent><br/
<hw>Men"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mensalis</ets>, fr. <ets>mensa</ets> table.]</ety> <def>Belonging
to the table; transacted at table; <as>as, <ex>mensal</ex>
conversation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensal</ent><br/
<hw>Men"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>mensis</ets>
month.]</ety> <def>Occurring once in a month; monthly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mense</ent><br/
<hw>Mense</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>menske</ets>,
AS. <ets>mennisc</ets> human, man. See <er>Man</er>.]</ety>
<def>Manliness; dignity; comeliness; civility.</def> <mark>[Prov. Eng. &
Scot.]</mark> -- <wordforms><wf>Mense"ful</wf> <pr>(#)</pr>,
<pos>a.</pos> -- <wf>Mense"less</wf>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mense</ent><br/
<hw>Mense</hw>, <pos>v. t.</pos> <def>To grace.</def> <mark>[Prov. Eng.
& Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menses</ent><br/
\'d8<hw>Men"ses</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>mensis</ets> month, pl. <ets>menses</ets> months, and the monthly
courses of women. Cf. <er>Month</er>.]</ety> <fld>(Med.)</fld> <def>The
catamenial or menstrual discharge, a periodic flow of blood or bloody
fluid from the uterus or female generative organs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstrual</ent><br/
<hw>Men"stru*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>menstrualis</ets>: cf. F. <ets>menstruel</ets>. See
<er>Menstruous</er>.]</ety> <sn>1.</sn> <def>Recurring once a month;
monthly; gone through in a month; <as>as, the <ex>menstrual</ex>
revolution of the moon</as>; pertaining to monthly changes; <as>as, the
<ex>menstrual</ex> equation of the sun's place</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the menses; <as>as,
<ex>menstrual</ex> discharges; the <ex>menstrual</ex>
period.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to a menstruum.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstruant</ent><br/
<hw>Men"stru*ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>menstruans</ets>, p. pr. of <ets>menstruare</ets> to have a monthly
term, fr. <ets>menstruus</ets>. See <er>Menstruous</er>.]</ety>
<def>Subject to monthly flowing or menses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstruate</ent><br/
<hw>Men"stru*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Menstruous.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstruate</ent><br/
<hw>Men"stru*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Menstruated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Menstruating</conjf> <pr>(?)</pr>.]</vmorph> <def>To
discharge the menses; to have the catamenial flow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>menstruating</ent><br/
<hw>menstruating</hw> <pos>adj.</pos> <def>discharging menstrual fluid;
-- of women during their menstrual period.</def><br/
<syn><b>Syn. --</b> unwell.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Menstruation</ent><br/
<hw>Men`stru*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The discharge
of the menses; also, the state or the period of menstruating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstrue</ent><br/
<hw>Men"strue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>menstrues</ets>. See <er>Menstruous</er>.]</ety> <def>The menstrual
flux; menses.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstruous</ent><br/
<hw>Men"stru*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>menstruus</ets>, fr. <ets>mensis</ets> month. Cf.
<er>Menstruum</er>.]</ety> <sn>1.</sn> <def>Having the monthly flow or
discharge; menstruating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the monthly flow;
catamenial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menstruum</ent><br/
<hw>Men"stru*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Menstruums</plw> <pr>(#)</pr>, L. <plw>Menstrua</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>menstruus</ets>. See
<er>Menstruous</er>.]</ety> <def>Any substance which dissolves a solid
body; a solvent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The proper <qex>menstruum</qex> to dissolve metal.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All liquors are called <xex>menstruums</xex> which are used as
dissolvents, or to extract the virtues of ingredients by infusion or
decoction.</q> <rj><qau>Quincy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The use is supposed to have originated in some notion of
the old chemists about the influence of the moon in the preparation of
dissolvents.</note> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensurability</ent><br/
<hw>Men`su*ra*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mensurabilit<eacute/</ets>.]</ety> <def>The quality of being
mensurable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensurable</ent><br/
<hw>Men"su*ra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mensurabilis</ets>, fr. <ets>mensurare</ets> to measure, fr.
<ets>mensura</ets> measure: cf. F. <ets>mensurable</ets>. See
<er>Measurable</er>, <er>Measure</er>.]</ety> <def>Capable of being
measured; measurable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensurableness</ent><br/
<hw>Men"su*ra*ble*ness</hw>, <pos>n.</pos> <def>The quality or state of
being mensurable; measurableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensural</ent><br/
<hw>Men"su*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mensuralis</ets>.]</ety> <def>Of or pertaining to
measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensurate</ent><br/
<hw>Men"su*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>mensuratus</ets>, p. p. of <ets>mensurare</ets>. See
<er>Measure</er>, <pos>v.</pos>]</ety> <def>To measure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mensuration</ent><br/
<hw>Men`su*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mensuratio</ets> : cf. F. <ets>mensuration</ets>.]</ety>
<sn>1.</sn> <def>The act, process, or art, of measuring.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That branch of applied geometry which gives rules
for finding the length of lines, the areas of surfaces, or the volumes
of solids, from certain simple data of lines and angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-ment</ent><br/
<hw>-ment</hw> <pr>(?)</pr>, <ety>[F. <ets>-ment</ets>, L.
<ets>-mentum</ets>.]</ety> <def>A suffix denoting <sig>that which
does</sig> a thing; <sig>an act</sig> or <sig>process</sig>; <sig>the
result of an act</sig> or <sig>process</sig>; <sig>state</sig> or
<sig>condition</sig>; <as>as, ali<ex>ment</ex>, that which nourishes,
orna<ex>ment</ex>, incre<ex>ment</ex>; frag<ex>ment</ex>, piece broken,
seg<ex>ment</ex>; abridg<ex>ment</ex>, act of abridging,
imprison<ex>ment</ex>, move<ex>ment</ex>, adjourn<ex>ment</ex>;
amaze<ex>ment</ex>, state of being amazed,
astonish<ex>ment</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ment</ent><br/
<hw>Ment</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Menge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentagra</ent><br/
\'d8<hw>Men"ta*gra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>mentum</ets> chin + Gr. <?/ a catching.]</ety> <fld>(Med.)</fld>
<def>Sycosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mental</ent><br/
<hw>Men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>mentum</ets>
the chin.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to the chin;
genian; <as>as, the <ex>mental</ex> nerve; the <ex>mental</ex>
region.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mental</ent><br/
<hw>Men"tal</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A plate or scale
covering the mentum or chin of a fish or reptile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mental</ent><br/
<hw>Men"tal</hw>, <pos>a.</pos> <ety>[F., fr. L. <ets>mentalis</ets>,
fr. <ets>mens</ets>, <ets>mentis</ets>, the mind; akin to E.
<ets>mind</ets>. See <er>Mind</er>.]</ety> <def>Of or pertaining to the
mind; intellectual; <as>as, <ex>mental</ex> faculties; <ex>mental</ex>
operations, conditions, or exercise.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>What a <qex>mental</qex> power<br/
This eye shoots forth!</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mental alienation</b></col>, <cd>insanity.</cd> --
<col><b>Mental arithmetic</b></col>, <cd>the art or practice of solving
arithmetical problems by mental processes, unassisted by written
figures.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mentalism</ent><br/
<hw>mentalism</hw> <pos>n.</pos> <sn>1.</sn> <def>a doctrine that mind
is the only true reality and that objects exist only as aspects of the
mind's awareness.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Any theory of psychology that accepts introspective
data about the functioning of the mind as a valid object of study;
contrasted to <contr>behaviorism</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>mentalistic</ent><br/
<hw>men`tal*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to mentalism.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mentality</ent><br/
<hw>Men*tal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality or state
of mind.</def> <ldquo/The same hard <xex>mentality</xex>.<rdquo/
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentally</ent><br/
<hw>Men"tal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the mind; in
thought or meditation; intellectually; in idea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mentation</ent><br/
<hw>men*ta"tion</hw> <pr>(m<ecr/n*t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>the process of thinking (especially thinking carefully); mental
activity.</def><br/
<syn><b>Syn. --</b> thinking, thought, cerebration,
intellection.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mentha</ent><br/
\'d8<hw>Men"tha</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Mint</er> the plant.]</ety> <fld>(Bot.)</fld> <def>A widely
distributed genus of fragrant herbs, including the peppermint,
spearmint, etc. The plants have small flowers, usually arranged in dense
axillary clusters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menthene</ent><br/
<hw>Men"thene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Menth</ets>ol
+ terp<ets>ene</ets>.]</ety> <fld>(Chem.)</fld> <def>A colorless liquid
hydrocarbon resembling oil of turpentine, obtained by dehydrating
menthol. It has an agreeable odor and a cooling taste.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>menthol</ent><br/
<hw>men"thol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mentha</ets> +
<ets>-ol</ets>.]</ety> <fld>(Chem.)</fld> <def>A white, crystalline,
aromatic substance (<chform>C10H20O</chform>) resembling camphor,
extracted from oil of peppermint (<gen>Mentha</gen>); -- called also
<altname>mint camphor</altname> or <altname>peppermint
camphor</altname>. It has the peculiar effect on skin and membranes of
making them feel cool, and is used in liqueurs, confections, cigarettes,
cough drops and perfumes, among other things.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Menthyl</ent><br/
<hw>Men"thyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mentha</ets> +
<ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A compound radical
forming the base of menthol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menticirrhus</ent><br/
<hw>Menticirrhus</hw> <pos>prop. n.</pos> <def>A genus of kingfishes,
including the whiting.</def><br/
<syn><b>Syn. --</b> genus <gen>Menticirrhus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Menticultural</ent><br/
<hw>Men`ti*cul"tur*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to mental culture; serving to improve or strengthen the
mind.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mention</ent><br/
<hw>Men"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mencioun</ets>, F. <ets>mention</ets>, L. <ets>mentio</ets>, from
the root of <ets>meminisse</ets> to remember. See <er>Mind</er>.]</ety>
<def>A speaking or notice of anything, -- usually in a brief or cursory
manner. Used especially in the phrase <xex>to make mention
of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will make <qex>mention</qex> of thy righteousness.</q>
<rj><qau>Ps. lxxi. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And sleep in dull, cold marble, where no <qex>mention</qex><br/
Of me more must be heard of.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 913 --></p>

<p><ent>Mention</ent><br/
<hw>Men"tion</hw> <pr>(m<ecr/n"sh<ucr/n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Mentioned</conjf>
<pr>(m<ecr/n"sh<ucr/nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mentioning</conjf>.]</vmorph> <ety>[Cf. F.
<ets>mentionner</ets>.]</ety> <def>To make mention of; to speak briefly
of; to name.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>mention</qex> the loving-kindnesses of the Lord.</q>
<rj><qau>Is. lxiii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentionable</ent><br/
<hw>Men"tion*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fit to be
mentioned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentomeckelian</ent><br/
<hw>Men`to*meck*e"li*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[1st
<ets>ment</ets>al + <ets>Meckelian</ets>.]</ety> <fld>(Anat.)</fld>
<def>Of or pertaining to the chin and lower jaw.</def> --
<def2><pos>n.</pos> <def>The bone or cartilage forming the anterior
extremity of the lower jaw in some adult animals and the young of
others.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentor</ent><br/
<hw>Men"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<etsep>Mentor</etsep>, the counselor of <persfn>Telemachus</persfn>, Gr.
<grk>Me`ntwr</grk>, prop., counselor. Cf. <er>Monitor</er>.]</ety>
<def>A wise and faithful counselor or monitor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentorial</ent><br/
<hw>Men*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Mentor</er>.]</ety> <def>Containing advice or admonition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mentum</ent><br/
\'d8<hw>men"tum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., chin.]</ety>
<fld>(Zool.)</fld> <def>The front median plate of the labium in insects.
See <er>Labium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mentzelia</ent><br/
<hw>Mentzelia</hw> <pos>prop. n.</pos> <def>A genus of bristly herbs or
subshrubs of Western America lacking stinging hairs.</def><br/
<syn><b>Syn. --</b> genus <gen>Mentzelia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>menu</ent><br/
<hw>men"u</hw> <pr>(m<ecr/n"y<oomac/)</pr>, <pos>n.</pos> <ety>[F.,
slender, thin, minute. See 4th <er>Minute</er>.]</ety> <sn>1.</sn>
<def>The details of a banquet; a list of the dishes served at a meal,
whether or not one has a choice.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Any list of objects, activities, etc. from which to
choose; a selection of alternatives.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif><def>A list of dishes form which
to choose at a restaurant; a bill of fare.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <fld>(Computers)</fld> <def>A
list displayed on the computer screen, by which a program provides the
user with different options for processing by the program. It usually
includes a mechanism, such as pointing by a mouse or selection by arrow
keys, to select the desired option from those on the list. Depending on
how the menu is displayed, it may be a <stype>pop-up menu</stype> or
<stype>pull-down menu</stype>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Menurae</ent><br/
<hw>Menurae</hw> <pos>prop. n.</pos> <def>A suborder of birds including
lyrebirds and scrubbirds.</def><br/
<syn><b>Syn. --</b> suborder <subord>Menurae</subord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Menuridae</ent><br/
<hw>Menuridae</hw> <pos>prop. n.</pos> <def>A natural family of birds
including the lyrebirds.</def><br/
<syn><b>Syn. --</b> family <fam>Menuridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Menuse</ent><br/
<hw>Me"nuse</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Amenuse</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Menyanthes</ent><br/
<hw>Menyanthes</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Menyanthaceae</fam>, having only one species: the
bogbeans.</def><br/
<syn><b>Syn. --</b> genus <gen>Menyanthes</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Menziesia</ent><br/
<hw>Menziesia</hw> <pos>prop. n.</pos> <def>A genus of deciduous shrubs
of North America and eastern Asia.</def><br/
<syn><b>Syn. --</b> genus <gen>Menziesia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meow</ent><br/
<hw>Me*ow"</hw> <pr>(?)</pr>, <pos>v. i. & n.</pos> <def>See 6th and 7th
<er>Mew</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mepacrine</ent><br/
<hw>mepacrine</hw> <pos>n.</pos> <def>Quinacrine, a drug once used to
treat malaria; <altname>Atabrine</altname> is a trademark.</def><br/
<syn><b>Syn. --</b> quinacrine, Atabrine.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>meperidine</ent><br/
<hw>meperidine</hw> <pos>n.</pos> <def>A synthetic narcotic drug used as
a sedative; <altname>Demerol</altname> is the trademark of a brand of
meperidine.</def><br/
<syn><b>Syn. --</b> meperidine hydrochloride, Demerol.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mephistophelian</ent><br/
<ent>Mephistophelean</ent><br/
<mhw><hw>Meph`is*to*phe"le*an</hw>, <hw>Meph`is*to*phe"li*an</hw></mhw>
<pr>(? <or/ ?)</pr>, <pos>prop. a.</pos> <def>Pertaining to, or
resembling, the devil <persfn>Mephistopheles</persfn>, <ldquo/a crafty,
scoffing, relentless fiend;<rdquo/ devilish in character or aspect;
crafty; showing cunning or ingenuity or wickedness; <as>as, a
<ex>mephistophelean</ex> glint in his eye</as>.</def><br/
<syn><b>Syn. --</b> devilish, diabolic, diabolical,
mephistophelean.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mephistopheles</ent><br/
<hw>Meph*is*toph"e*les</hw> <pr>(m<ecr/f*<icr/s*tof"<esl/*l<emac/z)</pr>
<ety>[Written Mephostophilus in Shakespeare, Fletcher etc.,
Mephostophilis in Marlowe, but now generally Mephistopheles, as in
Goethe: a made-up name, like most of the names of the medieval devils,
but supposed by some to be formed (irregularly) from Gr. <grk>mh`</grk>,
not, <grk>fw^s</grk> (<grk>fwt-</grk>), light, and <grk>fi`los</grk>,
loving.]</ety> <def>A familiar spirit mentioned in the old legend of
<person>Sir John Faustus</person>, and a principal agent in Marlowe's
play <publ><it>Dr. Faustus</it></publ> and in Goethe's
<publ><it>Faust</it></publ>. In medieval demonology, he was one of the
seven chief devils.</def><br/
[<source>Century Dictionary 1906</source>]</p>

<p><q> He is frequently referred to as <ldquo/the Devil,<rdquo/ but it
was well understood that he was only a devil. Goethe took only the name
and a few circumstances connected with the first appearance of
Mephistopheles from the legend: the character, from first to last, is
his own creation; and, in his own words, <ldquo/on account of the irony
and knowledge of the world it displays, is not easily
comprehended.<rdquo/ Although he sometimes slyly used it (though less
frequently than Faust) as a mask through which to speak with his own
voice, he evidently drew the germ of some characteristics from his early
associate, <persfn>Merck</persfn>. . . . The original form of this name
was Mephostophiles. There has been much discussion in regard to its
meaning, but <persfn>D<uum/ntzen's</persfn> conjecture is probably
correct, -- that it was imperfectly formed by some one who knew little
Greek, and was intended to signify <ldquo/not loving the
light.<rdquo/</q> <rj><qau>B. Taylor, Notes to Faust.</qau></rj><br/
[<source>Century Dictionary 1906</source>]</p>

<p><ent>Mephitical</ent><br/
<ent>Mephitic</ent><br/
<mhw>{ <hw>Me*phit"ic</hw> <pr>(?)</pr>, <hw>Me*phit"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>mephiticus</ets>, fr.
<ets>mephitis</ets> mephitis: cf. F.
<ets>m<eacute/phitique</ets>.]</ety> <sn>1.</sn> <def>Tending to destroy
life; poisonous; noxious; <as>as, <ex>mephitic</ex> exhalations;
<ex>mephitic</ex> regions.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Offensive to the smell; <as>as, <ex>mephitic</ex>
odors</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mephitic air</b></col> <fld>(Chem.)</fld>, <cd>carbon
dioxide; -- so called because of its deadly suffocating power. See
<cref>Carbonic acid</cref>, under <er>Carbonic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mephitinae</ent><br/
<hw>Mephitinae</hw> <pos>prop. n.</pos> <def>A subfamily of mammals
including the skunks; it is a subdivision not used in some
classifications.</def><br/
<syn><b>Syn. --</b> subfamily <subfam>Mephitinae</subfam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mephitis</ent><br/
\'d8<hw>Me*phi"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mephitis</ets> : cf. F. <ets>m<eacute/phitis</ets>.]</ety>
<sn>1.</sn> <def>Noxious, pestilential, or foul exhalations from
decomposing substances, filth, or other source.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A genus of mammals, including the
skunks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mephitism</ent><br/
<hw>Meph"i*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mephitis</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meracious</ent><br/
<hw>Me*ra"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>meracus</ets>, fr. <ets>merus</ets> pure, inmixed.]</ety>
<def>Being without mixture or adulteration; hence, strong; racy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercable</ent><br/
<hw>Mer"ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mercabilis</ets>, fr. <ets>mercari</ets> to trade, traffic, buy.
See <er>Merchant</er>.]</ety> <def>Capable of being bought or
sold.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>merbromine</ent><br/
<hw>merbromine</hw> <pos>n.</pos> <def>A mercurial compound applied
topically as an antiseptic; <altname>Mercurochrome</altname> is the
trademark.</def><br/
<syn><b>Syn. --</b> Mercurochrome.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mercantile</ent><br/
<hw>Mer"can*tile</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[F.
<ets>mercantile</ets>, It. <ets>mercantile</ets>, fr. L.
<ets>mercans</ets>, <ets>-antis</ets>, p. pr. of <ets>mercari</ets> to
traffic. See <er>Merchant</er>.]</ety> <def>Of or pertaining to
merchants, or the business of merchants; having to do with trade, or the
buying and selling of commodities; commercial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The expedition of the Argonauts was partly <qex>mercantile</qex>,
partly military.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mercantile agency</b></col>, <cd>an agency for procuring
information of the standing and credit of merchants in different parts
of the country, for the use of dealers who sell to them.</cd> --
<col><b>Mercantile marine</b></col>, <cd>the persons and vessels
employed in commerce, taken collectively.</cd> -- <col><b>Mercantile
paper</b></col>, <cd>the notes or acceptances given by merchants for
goods bought, or received on consignment; drafts on merchants for goods
sold or consigned.</cd> <rj><au>McElrath.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Mercantile</er>, <er>Commercial</er>.</syn>
<usage> <xex>Commercial</xex> is the wider term, being sometimes used to
embrace <xex>mercantile</xex>. In their stricter use,
<xex>commercial</xex> relates to the shipping, freighting, forwarding,
and other business connected with the <xex>commerce</xex> of a country
(whether external or internal), that is, the exchange of commodities;
while <xex>mercantile</xex> applies to the sale of merchandise and goods
when brought to market. As the two employments are to some extent
intermingled, the two words are often interchanged.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercaptal</ent><br/
<hw>Mer*cap"tal</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mercapt</ets>an + <ets>al</ets>dehyde.]</ety>
<fld>(Chem.)</fld> <def>Any one of a series of compounds of mercaptans
with aldehydes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercaptan</ent><br/
<hw>Mer*cap"tan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. NL.
<ets>mercurius</ets> mercury + L. <ets>captans</ets>, p. pr. of
<ets>captare</ets> to seize, v. intens. fr. <ets>capere</ets>.]</ety>
<fld>(Chem.)</fld> <def>Any one of series of compounds having an
<chform>-SH</chform> radical attached to a carbon atom, also considered
as hydrosulphides of alcohol radicals, in composition resembling the
alcohols, but containing sulphur in place of oxygen, and hence called
also the <altname>sulphur alcohols</altname>. In general, they are
colorless liquids having a strong, repulsive, garlic odor. The name is
specifically applied to ethyl mercaptan, <chform>C2H5SH</chform>. So
called from its avidity for <xex>mercury</xex>, and other
metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercaptide</ent><br/
<hw>Mer*cap"tide</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A compound of mercaptan formed by replacing its
sulphur hydrogen by a metal; <as>as, potassium <ex>mercaptide</ex>,
<chform>C2H5SK</chform></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercat</ent><br/
<hw>Mer"cat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mercatus</ets> : cf. It. <ets>mercato</ets>. See
<er>Market</er>.]</ety> <def>Market; trade.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Sprat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercatante</ent><br/
<hw>Mer`ca*tan"te</hw> <pr>(?; It. ?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Merchant</er>.]</ety> <def>A foreign trader.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercator's chart</ent><br/
<hw>Mer*ca"tor's chart"</hw> <pr>(?)</pr>. <def>See under
<er>Chart</er>, and see <cref>Mercator's projection</cref>, under
<er>Projection</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercature</ent><br/
<hw>Mer"ca*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>mercatura</ets> commerce.]</ety> <def>Commerce; traffic;
trade.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merce</ent><br/
<hw>Merce</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Amerce</er>.]</ety> <def>To subject to fine or amercement; to mulct;
to amerce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercenaria</ent><br/
\'d8<hw>Mer`ce*na"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Mercenary</er>.]</ety> <fld>(Zool.)</fld> <def>The
<er>quahog</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercenarian</ent><br/
<hw>Mer`ce*na"ri*an</hw> <pr>(-<it>a</it>n)</pr>, <pos>n.</pos> <def>A
mercenary.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercenarily</ent><br/
<hw>Mer"ce*na`ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
mercenary manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercenariness</ent><br/
<hw>Mer"ce*na*ri*ness</hw>, <pos>n.</pos> <def>The quality or state of
being mercenary; venality.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercenary</ent><br/
<hw>Mer"ce*na*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>mercenarie</ets>, F. <ets>mercenaire</ets>, fr. L.
<ets>mercenarius</ets>, fr. <ets>merces</ets> wages, reward. See
<er>Mercy</er>.]</ety> <sn>1.</sn> <def>Acting for reward; serving for
pay; paid; hired; hireling; venal; <as>as, <ex>mercenary</ex>
soldiers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Moved primarily by
considerations of pay or profit; greedy of gain; sordid; selfish.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For God forbid I should my papers blot<br/
With <qex>mercenary</qex> lines, with servile pen.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Venal</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercenary</ent><br/
<hw>Mer"ce*na*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mercenaries</plw> <pr>(<?/)</pr>.</plu> <def>One who is hired; a
hireling; especially, a soldier hired into foreign service.</def>
<rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercer</ent><br/
<hw>Mer"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mercier</ets>, fr. L. <ets>merx</ets>, <ets>mercis</ets>, wares,
merchandise. See <er>Merchant</er>.]</ety> <def>Originally, a dealer in
any kind of goods or wares; now restricted to a dealer in textile
fabrics, as silks or woolens.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercerize</ent><br/
<hw>Mer"cer*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>-ized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>-izing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From (John)
<etsep>Mercer</etsep> (1791-1866), an English calico printer who
introduced the process + <ets>-ize</ets>.]</ety> <def>To treat (cotton
fiber or fabrics) with a solution of caustic alkali. Such treatment
causes the fiber to shrink in length and become stronger and more
receptive of dyes. If the yarn or cloth is kept under tension during the
process, it assumes a silky luster.</def> --
<wordforms><wf>Mer`cer*i*za"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mercership</ent><br/
<hw>Mer"cer*ship</hw>, <pos>n.</pos> <def>The business of a
mercer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercery</ent><br/
<hw>Mer"cer*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mercerie</ets>.]</ety> <def>The trade of mercers; the goods in
which a mercer deals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchand</ent><br/
<hw>Mer"chand</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[F.
<ets>marchander</ets>. See <er>Merchant</er>.]</ety> <def>To
traffic.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchandisable</ent><br/
<hw>Mer"chan*di`sa*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can
be used or transferred as merchandise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchandise</ent><br/
<hw>Mer"chan*dise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>marchandise</ets>, OF. <ets>marcheandise</ets>.]</ety> <sn>1.</sn>
<def>The objects of commerce; whatever is usually bought or sold in
trade, or market, or by merchants; wares; goods; commodities.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or business of trading; trade;
traffic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchandise</ent><br/
<hw>Mer"chan*dise</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Merchandised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Merchandising</conjf> <pr>(?)</pr>.]</vmorph> <def>To
trade; to carry on commerce.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchandise</ent><br/
<hw>Mer"chan*dise</hw>, <pos>v. t.</pos> <def>To make merchandise of; to
buy and sell.</def> <ldquo/Love is <xex>merchandised</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchandiser</ent><br/
<hw>Mer"chan*di`ser</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
trader.</def> <rj><au>Bunyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>merchandising</ent><br/
<hw>mer"chan*dis`ing</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Commerce)</fld> <def>The activities associated with selling
products, such as identification of the market{7}, advertising at the
right time in the right media{7}, and creating attractive packaging and
displays; also, the study of the best methods to accomplish such
goals.</def><br/
[<source>PJC</source>]</p>

<p><ent>Merchandry</ent><br/
<hw>Mer"chand*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Merchant</er>.]</ety> <def>Trade; commerce.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Sanderson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchant</ent><br/
<hw>Mer"chant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>marchant</ets>, OF. <ets>marcheant</ets>, F. <ets>marchand</ets>,
fr. LL. <ets>mercatans</ets>, <ets>-antis</ets>, p. pr. of
<ets>mercatare</ets> to negotiate, L. <ets>mercari</ets> to traffic, fr.
<ets>merx</ets>, <ets>mercis</ets>, wares. See <er>Market</er>,
<er>Merit</er>, and cf. <er>Commerce</er>.]</ety> <sn>1.</sn> <def>One
who traffics on a large scale, especially with foreign countries; a
trafficker; a trader.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Others, like <qex>merchants</qex>, venture trade abroad.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trading vessel; a merchantman.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who keeps a store or shop for the sale of goods;
a shopkeeper.</def> <mark>[U. S. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchant</ent><br/
<hw>Mer"chant</hw>, <pos>a.</pos> <def>Of, pertaining to, or employed
in, trade or merchandise; <as>as, the <ex>merchant</ex>
service</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Merchant bar</b></col>, <col><b>Merchant
iron</b></col> <it>or</it> <col><b>Merchant steel</b></col></mcol>,
<cd>certain common sizes of wrought iron and steel bars.</cd> --
<mcol><col><b>Merchant service</b> <it>or</it> <b>Merchant
marine</b></col></mcol>, <cd>the mercantile marine of a country.</cd>
<au>Am. Cyc.</au> -- <col><b>Merchant ship</b></col>, <cd>a ship
employed in commerce.</cd> -- <col><b>Merchant tailor</b></col>, <cd>a
tailor who keeps and sells materials for the garments which he
makes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchant</ent><br/
<hw>Mer"chant</hw>, <pos>v. i.</pos> <def>To be a merchant; to
trade.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchantable</ent><br/
<hw>Mer"chant*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fit for
market; such as is usually sold in market, or such as will bring the
ordinary price; <as>as, <ex>merchantable</ex> wheat</as>; sometimes, a
technical designation for a particular kind or class.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchantly</ent><br/
<hw>Mer"chant*ly</hw>, <pos>a.</pos> <def>Merchantlike; suitable to the
character or business of a merchant.</def> <mark>[Obs.]</mark>
<rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merchantman</ent><br/
<hw>Mer"chant*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Merchantmen</plw> <pr>(<?/)</pr>.</plu><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A merchant.</def> <mark>[Obs.]</mark> <rj><au>Matt.
xiii. 45.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trading vessel; a ship employed in the
transportation of goods, <as>as, distinguished from a
man-of-war</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>merchant marine</ent><br/
<hw>mer"chant ma*rine"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The ships
owned by nationals of a particular country that are engaged in civilian
commerce; also, the personnel operating those vessels. Distinguished
from the <contr>navy</contr>, which contains the vessels of
war.</def><br/
[<source>PJC</source>]</p>

<p><ent>merchantry</ent><br/
<hw>mer"chant*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
body of merchants taken collectively; <as>as, the <ex>merchantry</ex> of
a country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The business of a merchant; merchandise.</def>
<rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merciable</ent><br/
<hw>Mer"ci*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.]</ety>
<def>Merciful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merciful</ent><br/
<hw>Mer"ci*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mercy</ets> +
<ets>-ful</ets>.]</ety> <sn>1.</sn> <def>Full of mercy; having or
exercising mercy; disposed to pity and spare offenders; unwilling to
punish. Opposite of <ant>merciless</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord, the Lord God, <qex>merciful</qex> and gracious.</q>
<rj><qau>Ex. xxxiv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be <qex>merciful</qex>, great duke, to men of mold.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unwilling to give pain; compassionate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>merciful</qex> man will be <qex>merciful</qex> to his
beast.</q> <rj><qau>Old Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Compassionate; tender; humane; gracious; kind;
mild; clement; benignant.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mer"ci*ful*ly</wf>, <pos>adv.</pos> --
<wf>Mer"ci*ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercify</ent><br/
<hw>Mer"ci*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To pity.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merciless</ent><br/
<hw>Mer"ci*less</hw>, <pos>a.</pos> <def>Destitute of mercy; cruel;
unsparing; -- said of animate beings, and also, figuratively, of things;
<as>as, a <ex>merciless</ex> tyrant; <ex>merciless</ex>
waves.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The foe is <qex>merciless</qex>, and will not pity.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Cruel; unmerciful; remorseless; ruthless;
pitiless; barbarous; savage.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mer"ci*less*ly</wf>, <pos>adv.</pos> --
<wf>Mer"ci*less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurammonium</ent><br/
<hw>Mer`cur*am*mo"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mercur</ets>ic + <ets>ammonium</ets>.]</ety>
<fld>(Chem.)</fld> <def>A radical regarded as derived from ammonium by
the substitution of mercury for a portion of the hydrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurial</ent><br/
<hw>Mer*cu"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mercurialis</ets>, fr. <ets>Mercurius</ets> Mercury: cf. F.
<ets>mercuriel</ets>.]</ety> <sn>1.</sn> <def>Having the qualities
fabled to belong to the god <persfn>Mercury</persfn>; swift; active;
sprightly; fickle; volatile; changeable; <as>as, a <ex>mercurial</ex>
youth; a <ex>mercurial</ex> temperament.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>mercurial</qex> man<br/
Who fluttered over all things like a fan.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the form or image of
<persfn>Mercury</persfn>; -- applied to ancient guideposts.</def>
<mark>[Obs.]</mark> <rj><au>Chillingworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to <persfn>Mercury</persfn> as the
god of trade; hence, money-making; crafty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mercurial</qex> wand of commerce.</q> <rj><qau>J. Q.
Adams.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of or pertaining to, or containing, mercury; <as>as,
<ex>mercurial</ex> preparations, barometer</as>. See <er>Mercury</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Med.)</fld> <def>Caused by the use of mercury;
<as>as, <ex>mercurial</ex> sore mouth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurial</ent><br/
<hw>Mer*cu"ri*al</hw>, <pos>n.</pos> <sn>1.</sn> <def>A person having
mercurial qualities.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A preparation containing
mercury.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mercurialism</ent><br/
<hw>mer*cu"ri*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mercurial</ets> + <ets>-ism</ets>.]</ety> <fld>(Med.)</fld>
<def>The syndrome produced by poisoning due to exposure to mercury, it
fumes, or its compounds; <altname>mercury poisoning</altname>. Such
exposure may occur in mining or smelting, or in using mercurial
compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurialist</ent><br/
<hw>Mer*cu"ri*al*ist</hw>, <pos>n.</pos> <sn>1.</sn> <def>One under the
influence of Mercury; one resembling Mercury in character.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A physician who uses much mercury,
in any of its forms, in his practice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurialize</ent><br/
<hw>Mer*cu"ri*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Mercurialized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Mercurializing</conjf>
<pr>(?)</pr>.]</vmorph> <sn>1.</sn> <fld>(Med.)</fld> <def>To affect
with mercury.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Photography)</fld> <def>To treat with mercury; to
expose to the vapor of mercury.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurialize</ent><br/
<hw>Mer*cu"ri*al*ize</hw>, <pos>v. i.</pos> <def>To be sprightly,
fantastic, or capricious.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurially</ent><br/
<hw>Mer*cu"ri*al*ly</hw>, <pos>adv.</pos> <def>In a mercurial
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercuric</ent><br/
<hw>Mer*cu"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, pertaining to, or derived from, mercury; containing mercury; --
said of those compounds of mercury into which this element enters in its
lowest proportion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mercuric chloride</b></col>, <cd>corrosive sublimate. See
<er>mercury bichloride</er> and <er>Corrosive</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurification</ent><br/
<hw>Mer*cu`ri*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mercurification</ets>. See <er>Mercurify</er>.]</ety> <sn>1.</sn>
<fld>(Metal.)</fld> <def>The process or operation of obtaining the
mercury, in its fluid form, from mercuric minerals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The act or process of
compounding, or the state of being compounded, with mercury.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurify</ent><br/
<hw>Mer*cu"ri*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Mercurified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mercurifying</conjf> <pr>(?)</pr>.]</vmorph>
<ety>[<ets>Mercury</ets> + <ets>-fy</ets>.]</ety> <sn>1.</sn> <def>To
obtain mercury from, as mercuric minerals, which may be done by any
application of intense heat that expels the mercury in fumes, which are
afterward condensed.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To combine or mingle mercury with; to impregnate
with mercury; to mercurialize.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurism</ent><br/
<hw>Mer"cu*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A communication of
news; an announcement.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercurous</ent><br/
<hw>Mer*cu"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, pertaining to, or derived from, mercury; containing mercury; --
said of those compounds of mercury in which it is present in its highest
proportion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mercurous chloride</b></col>. <fld>(Chem.)</fld> <cd>See
<er>Calomel</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercury</ent><br/
<hw>Mer"cu*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Mercurius</ets>; akin to <ets>merx</ets> wares.]</ety> <sn>1.</sn>
<fld>(Rom. Myth.)</fld> <def>A Latin god of commerce and gain; --
treated by the poets as identical with the Greek
<persfn>Hermes</persfn>, messenger of the gods, conductor of souls to
the lower world, and god of eloquence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A metallic element mostly
obtained by reduction from cinnabar, one of its ores. It is a heavy,
opaque, glistening liquid (commonly called
<altname>quicksilver</altname>), and is used in barometers,
thermometers, etc. Specific gravity 13.6. Symbol Hg
(<it>Hydrargyrum</it>). Atomic weight 199.8. Mercury has a molecule
which consists of only one atom. It was named by the alchemists after
the god Mercury, and designated by his symbol, <Mercury/.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Mercury forms alloys, called <xex>amalgams</xex>, with
many metals, and is thus used in applying tin foil to the backs of
mirrors, and in extracting gold and silver from their ores. It is
poisonous, and is used in medicine in the free state as in blue pill,
and in its compounds as calomel, corrosive sublimate, etc. It is the
only metal which is liquid at ordinary temperatures, and it solidifies
at about -39<deg/ Centigrade to a soft, malleable, ductile
metal.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>One of the planets of the solar
system, being the one nearest the sun, from which its mean distance is
about 36,000,000 miles. Its period is 88 days, and its diameter 3,000
miles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A carrier of tidings; a newsboy; a messenger; hence,
also, a newspaper.</def> <au>Sir J. Stephen.</au> <ldquo/The monthly
<xex>Mercuries</xex>.<rdquo/ <au>Macaulay.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Sprightly or mercurial quality; spirit; mutability;
fickleness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was so full of <qex>mercury</qex> that he could not fix long in
any friendship, or to any design.</q> <rj><qau>Bp.
Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Bot.)</fld> <def>A plant (<spn>Mercurialis
annua</spn>), of the Spurge family, the leaves of which are sometimes
used for spinach, in Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also applied, in the United States, to
certain climbing plants, some of which are poisonous to the skin, esp.
to the <spn>Rhus Toxicodendron</spn>, or poison ivy.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dog's mercury</b></col> <fld>(Bot.)</fld>,
<cd><spn>Mercurialis perennis</spn>, a perennial plant differing from
<spn>Mercurialis annua</spn> by having the leaves sessile.</cd> --
<col><b>English mercury</b></col> <fld>(Bot.)</fld>, <cd>a kind of
goosefoot formerly used as a pot herb; -- called <altname>Good King
Henry</altname>.</cd> -- <col><b>Horn mercury</b></col>
<fld>(Min.)</fld>, <cd>a mineral chloride of mercury, having a
semitranslucent, hornlike appearance.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mercury</ent><br/
<hw>Mer"cu*ry</hw>, <pos>v. t.</pos> <def>To wash with a preparation of
mercury.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mercury bichloride</ent><br/
<hw>mercury bichloride</hw> <pos>n.</pos> <def>the compound
(<chform>HgCl2</chform>) consisting of two atoms of chlorine united with
one atom of mercury. Also called <altname>bichloride of
mercury</altname>, <altname>mercuric chloride</altname>,
<altname>corrosive sublimate</altname>, and <altname>mercury
perchloride</altname>. It is used as <ldquo/a topical antiseptic and
disinfectant for inanimate objects<rdquo/.</def> <au>Stedman's
25th</au><br/
[<source>PJC</source>]</p>

<p><ent>mercury fulminate</ent><br/
<hw>mer"cu*ry ful"mi*nate</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The mercury salt of fulminic acid
(<chform>Hg(CNO)2</chform>), called also <altname>fulminate of
mercury</altname>. It is an explosive compound prepared as gray
crystals, and is used primarily in detonators for detonating high
explosives, such as dynamite or TNT. It is sensitive to shock and may be
detonated by a blow.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mercy</ent><br/
<hw>Mer"cy</hw> <pr>(m<etil/r"s<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mercies</plw> <pr>(#)</pr>.</plu> <ety>[OE.
<ets>merci</ets>, F. <ets>merci</ets>, L. <ets>merces</ets>,
<ets>mercedis</ets>, hire, pay, reward, LL., equiv. to
<ets>misericordia</ets> pity, mercy. L. <ets>merces</ets> is probably
akin to <ets>merere</ets> to deserve, acquire. See <er>Merit</er>, and
cf. <er>Amerce</er>.]</ety> <sn>1.</sn> <def>Forbearance to inflict harm
under circumstances of provocation, when one has the power to inflict
it; compassionate treatment of an offender or adversary;
clemency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Examples of justice must be made for terror to some; examples of
<qex>mercy</qex> for comfort to others.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Compassionate treatment of the unfortunate and
helpless; sometimes, favor, beneficence.</def> <rj><au>Luke x.
37.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Disposition to exercise compassion or favor; pity;
compassion; willingness to spare or to help.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In whom <qex>mercy</qex> lacketh and is not founden.</q>
<rj><qau>Sir T. Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A blessing regarded as a manifestation of compassion
or favor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Father of <qex>mercies</qex> and the God of all comfort.</q>
<rj><qau>2 Cor. i. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mercy seat</b></col> <fld>(Bib.)</fld>, <cd>the golden
cover or lid of the Ark of the Covenant. See <er>Ark</er>, 2.</cd> --
<col><b>Sisters of Mercy</b></col> <fld>(R. C. Ch.)</fld>,<cd>a
religious order founded in Dublin in the year 1827. Communities of the
same name have since been established in various American cities. The
duties of those belonging to the order are, to attend lying-in
hospitals, to superintend the education of girls, and protect decent
women out of employment, to visit prisoners and the sick, and to attend
persons condemned to death.</cd> -- <col><b>To be at the mercy
of</b></col>, <cd>to be wholly in the power of.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Grace</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merd</ent><br/
<hw>Merd</hw> <pr>(m<etil/rd)</pr>, <pos>n.</pos> <ety>[F.
<ets>merde</ets>, L. <ets>merda</ets>.]</ety> <def>Ordure; dung.</def>
<mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-mere</ent><br/
<hw>-mere</hw> <pr>(?)</pr>. <ety>[Gr. <?/ part.]</ety> <def>A combining
form meaning <xex>part</xex>, <xex>portion</xex>; <as>as,
blasto<ex>mere</ex>, epi<ex>mere</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mere</ent><br/
<hw>Mere</hw> <pr>(m<emac/r)</pr>, <pos>n.</pos> <ety>[Written also
<ets>mar</ets>.]</ety> <ety>[OE. <ets>mere</ets>, AS. <ets>mere</ets>
mere, sea; akin to D. <ets>meer</ets> lake, OS. <ets>meri</ets> sea,
OHG. <ets>meri</ets>, <ets>mari</ets>, G. <ets>meer</ets>, Icel.
<ets>marr</ets>, Goth. <ets>marei</ets>, Russ. <ets>more</ets>, W.
<ets>mor</ets>, Ir. & Gael. <ets>muir</ets>, L. <ets>mare</ets>, and
perh. to L. <ets>mori</ets> to die, and meaning originally, that which
is dead, a waste. Cf. <er>Mortal</er>, <er>Marine</er>, <er>Marsh</er>,
<er>Mermaid</er>, <er>Moor</er>.]</ety> <def>A pool or lake.</def>
<rj><au>Drayton.</au> <au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mere</ent><br/
<hw>Mere</hw>, <pos>n.</pos> <ety>[Written also <ets>meer</ets> and
<ets>mear</ets>.]</ety> <ety>[AS. <ets>gem<aemac/re</ets>.
<root/269.]</ety> <def>A boundary.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 914 --></p>

<p><ent>Mere</ent><br/
<hw>Mere</hw> <pr>(m<emac/r)</pr>, <pos>v. t.</pos> <def>To divide,
limit, or bound.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which <qex>meared</qex> her rule with Africa.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mere</ent><br/
<hw>Mere</hw>, <pos>n.</pos> <def>A mare.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mere</ent><br/
<hw>Mere</hw> <pr>(m<emac/r)</pr>, <pos>a.</pos>
<amorph>[<pos>Superl.</pos> <adjf>Merest</adjf>. The comparative is
rarely or never used.]</amorph> <ety>[L. <ets>merus</ets>.]</ety>
<sn>1.</sn> <def>Unmixed; pure; entire; absolute; unqualified.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then entered they the <qex>mere</qex>, main sea.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sorrows of this world would be <qex>mere</qex> and
unmixed.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Only this, and nothing else; such, and no more;
simple; bare; <as>as, a <ex>mere</ex> boy; a <ex>mere</ex>
form.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>From <qex>mere</qex> success nothing can be concluded in favor of
any nation.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merely</ent><br/
<hw>Mere"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>Purely; unmixedly;
absolutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ulysses was to force forth his access,<br/
Though <qex>merely</qex> naked.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not otherwise than; simply; barely; only.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prize not your life for other ends<br/
Than <qex>merely</qex> to oblige your friends.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Solely; simply; purely; barely;
scarcely.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merenchyma</ent><br/
\'d8<hw>Me*ren"chy*ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ a part + <ets>-enchyma</ets>, as in
<ets>parenchyma</ets>.]</ety> <fld>(Bot.)</fld> <def>Tissue composed of
spheroidal cells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meresman</ent><br/
<hw>Meres"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An officer who
ascertains meres or boundaries.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merestead</ent><br/
<hw>Mere"stead</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mere</ets>
boundary + <ets>stead</ets> place.]</ety> <def>The land within the
boundaries of a farm; a farmstead or farm.</def> <mark>[Archaic.]</mark>
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merestone</ent><br/
<hw>Mere"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stone
designating a limit or boundary; a landmark.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meretricious</ent><br/
<hw>Mer`e*tri"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>meretricius</ets>, from <ets>meretrix</ets>, <ets>-icis</ets>, a
prostitute, lit., one who earns money, <it>i. e.</it>, by prostitution,
fr. <ets>merere</ets> to earn, gain. See <er>Merit</er>.]</ety>
<sn>1.</sn> <def>Of or pertaining to prostitutes; having to do with
harlots; lustful; <as>as, <ex>meretricious</ex> traffic</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling the arts of a harlot; alluring by false
show; gaudily and deceitfully ornamental; tawdry; <as>as,
<ex>meretricious</ex> dress or ornaments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Deceptive or based on deception; seeming plausible,
but based on pretense or insincerity; deceptive; misleading; insincere;
specious; <as>as, <ex>meretricious</ex> arguments</as>.</def><br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>Mer`e*tri"cious*ly</wf>, <pos>adv.</pos> --
<wf>Mer`e*tri"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>meretriciousness</ent><br/
<hw>mer`e*tri"cious*ness</hw> <pos>n.</pos> <sn>1.</sn> <def>an
appearance of truth that is false or deceptive; seeming
plausibility.</def><br/
<syn><b>Syn. --</b> speciousness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>tasteless showiness.</def><br/
<syn><b>Syn. --</b> flashiness, garishness, gaudiness, loudness,
tawdriness, glitz.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Merganser</ent><br/
<hw>Mer*gan"ser</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>merg<aacute/nsar</ets>, fr. <ets>mergo</ets> a diver (L.
<ets>mergus</ets>, fr. <ets>mergere</ets> to dip, dive) +
<ets><aacute/nsar</ets> goose, L. <ets>anser</ets>.]</ety>
<fld>(Zool.)</fld> <def>Any bird of the genus <gen>Mergus</gen>
(<gen>Merganser</gen>), and allied genera of the subfamily
<subfam>Merginae</subfam>. They are allied to the ducks, but have a
sharply serrated bill, eat fish, and dive for food. Also called
<altname>fish duck</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ The red-breasted merganser (<spn>Merganser
serrator</spn>) inhabits both hemispheres. It is called also
<altname>sawbill</altname>, <altname>harle</altname>, and
<altname>sheldrake</altname>. The American merganser (<spn>Merganser
Americanus</spn>.) and the hooded merganser (<spn>Lophodytes
cucullatus</spn>) are well-known species.</note> -- <cs><col><b>White
merganser</b></col>, <cd>the smew or white nun.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>merge</ent><br/
<hw>merge</hw> <pr>(m<etil/rj)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Merged</conjf> <pr>(m<etil/rjd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Merging</conjf>
<pr>(m<etil/r"j<icr/ng)</pr>.]</vmorph> <ety>[L. <ets>mergere</ets>,
<ets>mersum</ets>. Cf. <er>Emerge</er>, <er>Immerse</er>,
<er>Marrow</er>.]</ety> <def>To cause to be swallowed up; to immerse; to
sink; to absorb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>merge</qex> all natural . . . sentiment in inordinate
vanity.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whig and Tory were <qex>merged</qex> and swallowed up in the
transcendent duties of patriots.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merge</ent><br/
<hw>Merge</hw>, <pos>v. i.</pos> <def>To be sunk, swallowed up, or
lost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Native irresolution had <qex>merged</qex> in stronger motives.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>merged</ent><br/
<hw>merged</hw> <pos>adj.</pos> <def>formed or united into a whole; --
of formerly separate objects, groups, etc.</def><br/
<syn><b>Syn. --</b> incorporate, incorporated, integrated,
unified.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Merger</ent><br/
<hw>Mer"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, merges.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An absorption of one estate, or one
contract, in another, or of a minor offense in a greater.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The combining of two groups into a unified single
group under a single leadership, with voluntary participation by the
leaders or management of both groups.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Specifically:</specif> <fld>(Business,
Finance)</fld> <def>The combining of two commercial enterprises into a
unified single enterprise under a single management, with voluntary
participation by both parties; <as>as, the <ex>merger</ex> of
<corpn>Daimler-Benz</corpn> and <corpn>Chrysler</corpn> into
<corpn>Daimler-Chrysler</corpn> created a powerful competitor in the
automobile manufacturing industry</as>. Compare
<contr>acquisition</contr> and <contr>takeover</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>merging</ent><br/
<hw>merging</hw> <pos>adj.</pos> <sn>1.</sn> <def>combining or
mixing.</def><br/
<syn><b>Syn. --</b> blending, mingling.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>flowing together.</def>
<mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> confluent.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>merging</ent><br/
<hw>merging</hw> <pos>n.</pos> <sn>1.</sn> <def>The act or process of
joining together into one entity.</def><br/
<syn><b>Syn. --</b> meeting, coming together.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a flowing together (as of rivers).</def><br/
<syn><b>Syn. --</b> confluence, conflux.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mergus</ent><br/
<hw>Mergus</hw> <pos>prop. n.</pos> <def>A genus of ducks consisting of
mergansers.</def><br/
<syn><b>Syn. --</b> genus <gen>Mergus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mericarp</ent><br/
<hw>Mer"i*carp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`ros</grk> a part + <grk>karpo`s</grk> fruit.]</ety>
<fld>(Bot.)</fld> <def>One carpel of an umbelliferous fruit. See
<er>Cremocarp</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meride</ent><br/
<hw>Mer"ide</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
part.]</ety> <fld>(Biol.)</fld> <def>A permanent colony of cells or
plastids which may remain isolated, like Rotifer, or may multiply by
gemmation to form higher aggregates, termed <xex>zoides</xex>.</def>
<rj><au>Perrier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meridian</ent><br/
<hw>Me*rid"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>m<eacute/ridien</ets>, L. <ets>meridianus</ets> pertaining to noon,
fr. <ets>meridies</ets> noon, midday, for older <ets>medidies</ets>;
<ets>medius</ets> mid, middle + <ets>dies</ets> day. See <er>Mid</er>,
and <er>Diurnal</er>.]</ety> <sn>1.</sn> <def>Being at, or pertaining
to, midday; belonging to, or passing through, the highest point attained
by the sun in his diurnal course.</def> <ldquo/<xex>Meridian</xex>
hour.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tables . . . to find the altitude <qex>meridian</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to the highest point or culmination;
<as>as, <ex>meridian</ex> splendor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meridian</ent><br/
<hw>Me*rid"i*an</hw>, <pos>n.</pos> <ety>[F. <ets>m<eacute/ridien</ets>.
See <er>Meridian</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Midday; noon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: The highest point, as of success, prosperity,
or the like; culmination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have touched the highest point of all my greatness,<br/
And from that full <qex>meridian</qex> of my glory<br/
I haste now to my setting.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>A great circle of the sphere
passing through the poles of the heavens and the zenith of a given
place. It is crossed by the sun at midday.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geog.)</fld> <def>A great circle on the surface of
the earth, passing through the poles and any given place; also, the half
of such a circle included between the poles.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The planes of the geographical and astronomical
meridians coincide. Meridians, on a map or globe, are lines drawn at
certain intervals due north and south, or in the direction of the
poles.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Calculated for the meridian of</b></col>,
<it>or</it> <col><b>fitted to the meridian of</b></col>, <it>or</it>
<col><b>adapted to the meridian of</b></col></mcol>, <cd>suited to the
local circumstances, capabilities, or special requirements
of.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>All other knowledge merely serves the concerns of this life, and
is <qex>fitted to the meridian</qex> there<qex>of</qex>.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <cs><mcol><col><b>First meridian</b></col> <it>or</it>
<col><b>prime meridian</b></col></mcol>, <cd>the meridian from which
longitudes are reckoned. The meridian of Greenwich is the one commonly
employed in calculations of longitude by geographers, and in actual
practice, although in various countries other and different meridians,
chiefly those which pass through the capitals of the countries, are
occasionally used; as, in France, the meridian of Paris; in the United
States, the meridian of Washington, etc.</cd> -- <col><b>Guide
meridian</b></col> <fld>(Public Land Survey)</fld>, <cd>a line, marked
by monuments, running North and South through a section of country
between other more carefully established meridians called <xex>principal
meridians</xex>, used for reference in surveying.</cd>
<mark>[U.S.]</mark> -- <col><b>Magnetic meridian</b></col>, <cd>a great
circle, passing through the zenith and coinciding in direction with the
magnetic needle, or a line on the earth's surface having the same
direction.</cd> -- <col><b>Meridian circle</b></col>
<fld>(Astron.)</fld>, <cd>an instrument consisting of a telescope
attached to a large graduated circle and so mounted that the telescope
revolves like the transit instrument in a meridian plane. By it the
right ascension and the declination of a star may be measured in a
single observation.</cd> -- <col><b>Meridian instrument</b></col>
<fld>(Astron.)</fld>, <cd>any astronomical instrument having a telescope
that rotates in a meridian plane.</cd> -- <mcol><col><b>Meridian of a
globe</b></col>, <it>or</it> <col><b>Brass meridian</b></col></mcol>,
<cd>a graduated circular ring of brass, in which the artificial globe is
suspended and revolves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meridional</ent><br/
<hw>Me*rid"i*o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>m<eacute/ridional</ets>, L. <ets>meridionalis</ets>, fr.
<ets>meridies</ets> midday. See <er>Meridian</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of or pertaining to the meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a southern aspect; southern;
southerly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Offices that require heat . . . should be
<qex>meridional</qex>.</q> <rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Meridional distance</b></col>, <cd>the distance or
departure from the meridian; the easting or westing.</cd> --
<col><b>Meridional parts</b></col>, <cd>parts of the meridian in
Mercator's projection, corresponding to each minute of latitude from the
equator up to 70 or 80 degrees; tabulated numbers representing these
parts used in projecting charts, and in solving cases in Mercator's
sailing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meridionality</ent><br/
<hw>Me*rid`i*o*nal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The state of being in the meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Position in the south; aspect toward the
south.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meridionally</ent><br/
<hw>Me*rid"i*o*nal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the
direction of the meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merils</ent><br/
<hw>Mer"ils</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/relle</ets>, <ets>marelle</ets>, <ets>marelles</ets>, LL.
<ets>marella</ets>, <ets>marrella</ets>. Cf. <er>Morris</er> the
game.]</ety> <def>A boy's play, called also <altname>fivepenny
morris</altname>. See <er>Morris</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meringue</ent><br/
\'d8<hw>Me`ringue"</hw> <pr>(F. m<etil/`r<acr/N"g'; E.
m<ecr/*r<acr/ng")</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A delicate
pastry made of powdered sugar and the whites of eggs whipped up, -- with
jam or cream added.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merino</ent><br/
<hw>Me*ri"no</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Sp.
<ets>merino</ets> moving from pasture to pasture, fr. <ets>merino</ets>
a royal judge and superintendent or inspector of sheep walks, LL.
<ets>merinus</ets>, fr. <ets>majorinus</ets>, i. e., major vill<?/, fr.
L. <ets>major</ets> greater. See <er>Major</er>. Merino sheep are driven
at certain seasons from one part of Spain to another, in large flocks,
for pasturage.]</ety> <sn>1.</sn> <def>Of or pertaining to a variety of
sheep with very fine wool, originally bred in Spain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made of the wool of the merino sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merino</ent><br/
<hw>Me*ri"no</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Merinos</plw>
<pr>(#)</pr>.</plu> <ety>[Sp.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>A breed of sheep originally from Spain, noted for the fineness of
its wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fine fabric of merino wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merismatic</ent><br/
<hw>Mer`is*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
division, fr. <?/ part.]</ety> <fld>(Biol.)</fld> <def>Dividing into
cells or segments; characterized by separation into two or more parts or
sections by the formation of internal partitions; <as>as,
<ex>merismatic</ex> growth, where one cell divides into
many</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meristem</ent><br/
<hw>Mer"i*stem</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
divisible.]</ety> <fld>(Bot.)</fld> <def>A tissue of growing cells, or
cells capable of further division.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merit</ent><br/
<hw>Mer"it</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/rite</ets>, L. <ets>meritum</ets>, fr. <ets>merere</ets>,
<ets>mereri</ets>, to deserve, merit; prob. originally, to get a share;
akin to Gr. <?/ part, <?/ fate, doom, <?/ to receive as one's portion.
Cf. <er>Market</er>, <er>Merchant</er>, <er>Mercer</er>,
<er>Mercy</er>.]</ety> <sn>1.</sn> <def>The quality or state of
deserving well or ill; desert.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here may men see how sin hath his <qex>merit</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be it known, that we, the greatest, are misthought<br/
For things that others do; and when we fall,<br/
We answer other's <qex>merits</qex> in our name.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Esp. in a good sense:</specif> <def>The quality
or state of deserving well; worth; excellence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reputation is . . . oft got without <qex>merit</qex>, and lost
without deserving.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To him the wit of Greece and Rome was known,<br/
And every author's <qex>merit</qex>, but his own.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Reward deserved; any mark or token of excellence or
approbation; <as>as, his teacher gave him ten
<ex>merits</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those laurel groves, the <qex>merits</qex> of thy youth.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merit</ent><br/
<hw>Mer"it</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Merited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Meriting</conjf>.]</vmorph> <ety>[F. <ets>m<eacute/riter</ets>,
L. <ets>meritare</ets>, v. intens. fr. <ets>merere</ets>. See
<er>Merit</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To earn by service
or performance; to have a right to claim as reward; to deserve;
sometimes, to deserve in a bad sense; <as>as, to <ex>merit</ex>
punishment</as>.</def> <ldquo/This kindness <xex>merits</xex>
thanks.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reward.</def> <mark>[R. & Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merit</ent><br/
<hw>Mer"it</hw>, <pos>v. i.</pos> <def>To acquire desert; to gain value;
to receive benefit; to profit.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meritable</ent><br/
<hw>Mer"it*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deserving of
reward.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meritedly</ent><br/
<hw>Mer"it*ed*ly</hw>, <pos>adv.</pos> <def>By merit;
deservedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merithallus</ent><br/
<ent>Merithal</ent><br/
<mhw>{ <hw>Mer"i*thal</hw> <pr>(?)</pr>, \'d8<hw>Mer`i*thal"lus</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>merithallus</ets>,
fr. Gr. <?/, <ets>or</ets> <?/, a part + <?/ a young shoot.]</ety>
<fld>(Bot.)</fld> <def>Same as <er>Internode</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meritmonger</ent><br/
<hw>Mer"it*mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who depends
on merit for salvation.</def> <mark>[Obs.]</mark>
<rj><au>Milner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>meritocracy</ent><br/
<hw>meritocracy</hw> <pos>n.</pos> <sn>1.</sn> <def>A form of social
system in which power goes to those with superior intellects.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The belief that rulers should be chosen for their
superior abilities and not because of their wealth or birth.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>meritocratic</ent><br/
<hw>meritocratic</hw> <pos>adj.</pos> <def>Of or pertaining to
meritocracy; <as>as, <ex>meritocratic</ex> society</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meritorious</ent><br/
<hw>Mer`i*to"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>meritorius</ets> that brings in money.]</ety> <def>Possessing
merit; deserving of reward or honor; worthy of recompense;
valuable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>meritorious</qex> shall that hand be called,<br/
Canonized, and worshiped as a saint.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mer`i*to"ri*ous*ly</wf>, <pos>adv.</pos> --
<wf>Mer`i*to"ri*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meritory</ent><br/
<hw>Mer"i*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Meritorious.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meritot</ent><br/
<hw>Mer"i*tot</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A play of children,
in swinging on ropes, or the like, till they are dizzy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merk</ent><br/
<hw>Merk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Marc</er>.]</ety> <def>An old Scotch silver coin; a mark or
marc.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merk</ent><br/
<hw>Merk</hw>, <pos>n.</pos> <def>A mark; a sign.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merke</ent><br/
<hw>Merke</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Murky.</def>
<mark>[Obs.]</mark> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>merkin</ent><br/
<hw>mer"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Originally, a wig; afterwards, a mop for cleaning cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A patch of false hair, or something resembling hair,
worn on a string over the female pudenda; -- used by
stripteasers.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The hair on the female pubic area.</def>
<mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Merle</ent><br/
<ent>Merl</ent><br/
<mhw>{ <hw>Merl</hw> <pr>(?)</pr>, <hw>Merle</hw>, }</mhw> <pos>n.</pos>
<ety>[F. <ets>merle</ets>, L. <ets>merula</ets>, <ets>merulus</ets>. Cf.
<er>Ousel</er>.]</ety> <fld>(Zool.)</fld> <def>The European blackbird.
See <er>Blackbird</er>.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merlin</ent><br/
<hw>Mer"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>merlion</ets>, F. <ets><eacute/merillon</ets> ; cf. OHG.
<ets>smirl</ets>, G. <ets>schmerl</ets> ; prob. fr. L. <ets>merula</ets>
blackbird. Cf. <er>Merle</er>.]</ety> <fld>(Zool.)</fld> <def>A small
European falcon (<spn>Falco columbarius</spn>, syn. <spn>Falco
lithofalco</spn>, or <spn>Falco aesalon</spn>). In North America called
also <altname>pigeon hawk</altname>.</def><br/
[<source>1913 Webster</source>  <source>+PJC</source>]</p>

<p><ent>Merling</ent><br/
<hw>Mer"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European whiting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merlon</ent><br/
<hw>Mer"lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., perh. fr. L.
<ets>moerus</ets>, for <ets>murus</ets> a wall, through (assumed) dim.
<ets>moerulus</ets>.]</ety> <fld>(Fort.)</fld> <def>One of the solid
parts of a battlemented parapet; a battlement. See <xex>Illust.</xex> of
<er>Battlement</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merluce</ent><br/
<hw>Mer"luce</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>merluche</ets>, <ets>merlus</ets>.]</ety> <fld>(Zool.)</fld>
<def>The European hake; -- called also <altname>herring hake</altname>
and <altname>sea pike</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mermaid</ent><br/
<hw>Mer"maid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>mere</ets>
lake, sea. See <er>Mere</er> lake, and <er>maid</er>.]</ety> <def>A
fabled marine creature, typically represented as having the upper part
like that of a woman, and the lower like a fish; a sea nymph, sea woman,
or woman fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Chaucer uses this word as equivalent to the
<xex>siren</xex> of the ancients.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mermaid fish</b></col> <fld>(Zool.)</fld> <cd>the angel
fish (<gen>Squatina</gen>).</cd> -- <col><b>Mermaid's glove</b></col>
<fld>(Zool.)</fld>, <cd>a British branched sponge somewhat resembling a
glove.</cd> -- <col><b>Mermaid's head</b></col> <fld>(Zool.)</fld>,
<cd>a European spatangoid sea urchin (<spn>Echinocardium cordatum</spn>)
having some resemblance to a skull.</cd> -- <col><b>Mermaid
weed</b></col> <fld>(Bot.)</fld>, <cd>an aquatic herb with dentate or
pectinate leaves (<spn>Proserpinaca palustris</spn> and
<spn>Proserpinaca pectinacea</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merman</ent><br/
<hw>Mer"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mermen</plw> <pr>(<?/)</pr>.</plu> <def>The male corresponding to
<contr>mermaid</contr>; a sea man, or man fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mero cabrolla</ent><br/
<ent>Mero de lo alto</ent><br/
<ent>Mero</ent><br/
\'d8<hw>Me"ro</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.; cf. Pg.
<ets>mero</ets>.]</ety> <def>Any of several large groupers of warm seas,
esp. the guasa (<spn>Epinephelus guaza</spn>), the red grouper
(<spn>Epinephelus morio</spn>), the black grouper (<spn>Epinephelus
nigritas</spn>), distinguished as <styp><hw>Me"ro de lo
al"to</hw></styp> <pr>(<?/)</pr>, and a species called also <stype>rock
hind</stype>, distinguished as <styp><hw>Me"ro ca*brol"la</hw></styp>
<pr>(<?/)</pr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Meroblast</ent><br/
<hw>Mer"o*blast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`ros</grk> part + <ets>-blast</ets>.]</ety> <fld>(Biol.)</fld>
<def>An ovum, as that of a mammal, only partially composed of germinal
matter, that is, consisting of both a germinal portion and an albuminous
or nutritive one; -- opposed to <contr>holoblast</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meroblastic</ent><br/
<hw>Mer`o*blas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Consisting only in part of germinal matter; characterized by
partial segmentation only; <as>as, <ex>meroblastic</ex> ova, in which a
portion of the yolk only undergoes fission; <ex>meroblastic</ex>
segmentation; -- opposed to <ex>holoblastic</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merocele</ent><br/
<hw>Me"ro*cele</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mhro`s</grk> thigh + <?/ tumor.]</ety> <fld>(Med.)</fld>
<def>Hernia in the thigh; femoral hernia .</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meroistic</ent><br/
<hw>Mer`o*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>me`ros</grk> part + <?/ an egg.]</ety> <fld>(Zool.)</fld>
<def>Applied to the ovaries of insects when they secrete vitelligenous
cells, as well as ova.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meropidan</ent><br/
<hw>Me*rop"i*dan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>merops</ets> a bee-eating bird, Gr. <grk>me`rops</grk>.]</ety>
<fld>(Zool.)</fld> <def>One of a family of birds (<fam>Meropidae</fam>),
including the bee-eaters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meropodite</ent><br/
<hw>Me*rop"o*dite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`ros</grk> thigh + <grk>poy`s</grk>, <grk>podo`s</grk>,
foot.]</ety> <fld>(Zool.)</fld> <def>The fourth joint of a typical
appendage of Crustacea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merorganization</ent><br/
<hw>Mer*or`gan*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`ros</grk> part + E. <ets>organization</ets>.]</ety>
<def>Organization in part.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meros</ent><br/
\'d8<hw>Me"ros</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<grk>me`ros</grk> part.]</ety> <fld>(Arch.)</fld> <def>The plain surface
between the channels of a triglyph.</def> <altsp>[Written also
<asp>merus</asp>.]</altsp> <rj><au>Weale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meros</ent><br/
\'d8<hw>Me"ros</hw>, <pos>n.</pos> <ety>[NL., fr. Gr. <grk>me`ros</grk>
the thigh.]</ety> <fld>(Anat.)</fld> <def>The proximal segment of the
hind limb; the thigh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merosome</ent><br/
<hw>Mer"o*some</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`ros</grk> part + <ets>-some</ets> body.]</ety>
<fld>(Zool.)</fld> <def>One of the serial segments, or metameres, of
which the bodies of vertebrate and articulate animals are
composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merostomata</ent><br/
\'d8<hw>Mer`o*stom"a*ta</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. Gr. <grk>me`ros</grk> thigh + <?/, -<?/, mouth.]</ety>
<fld>(Zool.)</fld> <def>A class of <phylum>Arthropoda</phylum>, allied
to the <class>Crustacea</class>. It includes the trilobites,
<ord>Eurypteroidea</ord>, and <ord>Limuloidea</ord>. All are extinct
except the horseshoe crabs (<gen>Limulus</gen>) of the last group. See
<er>Limulus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merou</ent><br/
\'d8<hw>M<eacute/`rou"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>See <er>Jack</er>, 8 <sd>(c)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merovingian</ent><br/
<hw>Mer`o*vin"gi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<persfn><etsep>Merovaeus</etsep></persfn>, the Latin name of a king of
the Franks.]</ety> <def>Of or pertaining to the first Frankish dynasty
in Gaul or France.</def> -- <def2><pos>n.</pos> <def>One of the kings of
this dynasty.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merozoite</ent><br/
<hw>Mer`o*zo"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>me`ros</grk> part + Sporo<ets>zoa</ets>.]</ety> <fld>(Zool.)</fld>
<def>A form of spore, usually elongate or falciform, and somewhat
amoeboid, produced by segmentation of the schizonts of certain Sporozoa,
as the malaria parasite.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Merrily</ent><br/
<hw>Mer"ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Merry</er>.]</ety> <def>In a merry manner; with mirth; with gayety
and laughter; jovially. See <er>Mirth</er>, and
<er>Merry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Merrily</qex> sing, and sport, and play.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrimake</ent><br/
<hw>Mer"ri*make`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Merrymake</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrimake</ent><br/
<hw>Mer"ri*make`</hw>, <pos>v. i.</pos> <def>See <er>Merrymake</er>,
<pos>v.</pos></def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merriment</ent><br/
<hw>Mer"ri*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Gayety, with
laughter; mirth; frolic.</def> <ldquo/Follies and light
<xex>merriment</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Methought it was the sound<br/
Of riot and ill-managed <qex>merriment</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merriness</ent><br/
<hw>Mer"ri*ness</hw>, <pos>n.</pos> <def>The quality or state of being
merry; merriment; mirth; gayety, with laughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merry</ent><br/
<hw>Mer"ry</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Merrier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Merriest</adjf>.]</amorph> <ety>[OE. <ets>merie</ets>,
<ets>mirie</ets>, <ets>murie</ets>, merry, pleasant, AS.
<ets>merge</ets>, <ets>myrige</ets>, pleasant; cf. <ets>murge</ets>,
adv.; prob. akin to OHG. <ets>murg</ets>, short, Goth.
<ets>gama<uacute/rgjan</ets> to shorten; cf. L. <ets>murcus</ets> a
coward, who cuts off his thumb to escape military service; the
Anglo-Saxon and English meanings coming from the idea of making the time
seem short. Cf. <er>Mirth</er>.]</ety> <sn>1.</sn> <def>Laughingly gay;
overflowing with good humor and good spirits; jovial; inclined to
laughter or play; sportive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They drank, and were <qex>merry</qex> with him.</q> <rj><qau>Gen.
xliii. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am never <qex>merry</qex> when I hear sweet music.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 915 --></p>

<p><sn>2.</sn> <def>Cheerful; joyous; not sad; happy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is any <qex>merry</qex>? let him sing psalms.</q> <rj><qau>Jas. v.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Causing laughter, mirth, gladness, or delight;
<as>as, a <ex>merry</ex> jest</as>.</def> <ldquo/<xex>Merry</xex> wind
and weather.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Merry dancers</b></col>. <cd>See under
<er>Dancer</er>.</cd> -- <col><b>Merry men</b></col>, <cd>followers;
retainers.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>merie men</qex> commanded he<br/
To make him bothe game and glee.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To make merry</b></col>, <cd>to be jovial; to indulge in
hilarity; to feast with mirth.</cd> <au>Judg. ix. 27.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- Cheerful; blithe; lively; sprightly; vivacious;
gleeful; joyous; mirthful; jocund; sportive; hilarious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merry</ent><br/
<hw>Mer"ry</hw> <pr>(m<ecr/r"r<ycr/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A kind of wild red cherry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merry-andrew</ent><br/
<hw>Mer"ry-an"drew</hw> <pr>(m<ecr/r"r<ycr/-<acr/n"dr<udd/)</pr>,
<pos>n.</pos> <def>One whose business is to make sport for others; a
buffoon; a zany; especially, one who attends a mountebank or quack
doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term is said to have originated from one
<person>Andrew Borde</person>, an English physician of the 16th century,
who gained patients by facetious speeches to the multitude.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merry-go-round</ent><br/
<hw>Mer"ry-go`-round"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Any
revolving contrivance for affording amusement; esp., a group of seats in
the shape of hobbyhorses or other fanciful animals, arranged in a circle
on a platform that is rotated by a mechanical drive, often to the
accompaniment of music; the seats often move up and down in synchrony
with the rotation; -- called also <altname>carousel</altname>. It is
employed primarily for the amusement of children, and is typically found
at an amusement park.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrymake</ent><br/
<hw>Mer"ry*make`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mirth; frolic; a
meeting for mirth; a festival.</def> <altsp>[Written also
<asp>merrimake</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrymake</ent><br/
<hw>Mer"ry*make`</hw>, <pos>v. i.</pos> <def>To make merry; to be jolly;
to feast.</def> <altsp>[Written also <asp>merrimake</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrymaker</ent><br/
<hw>Mer"ry*mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes
merriment or indulges in conviviality; a jovial comrade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrymaking</ent><br/
<hw>Mer"ry*mak`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Making or
producing mirth; convivial; jolly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrymaking</ent><br/
<hw>Mer"ry*mak`ing</hw>, <pos>n.</pos> <def>The act of making merry;
conviviality; merriment; jollity.</def>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrymeeting</ent><br/
<hw>Mer"ry*meet`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A meeting for
mirth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merrythought</ent><br/
<hw>Mer"ry*thought`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The forked
bone of a fowl's breast; -- called also <altname>wishbone</altname>. See
<er>Furculum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is a sportive custom for two persons to break this
bone by pulling the ends apart to see who will get the longer piece, the
securing of which is regarded as a lucky omen, signifying that the
person holding it will obtain the gratification of some secret
wish.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mersion</ent><br/
<hw>Mer"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mersio</ets>. See <er>Merge</er>.]</ety> <def>Immersion.</def>
<mark>[R.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merulidan</ent><br/
<hw>Me*ru"li*dan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>merula</ets>, <ets>merulus</ets>, blackbird. See
<er>Merle</er>.]</ety> <fld>(Zool.)</fld> <def>A bird of the Thrush
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Merus</ent><br/
\'d8<hw>Me"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Arch.)</fld> <def>See <er>Meros</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mervaille</ent><br/
<hw>Mer"vaille`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Marvel.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mes-</ent><br/
<hw>Mes-</hw> <pr>(m<ecr/s-)</pr>. <def>See <er>Meso-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mesa</ent><br/
\'d8<hw>me"sa</hw> <pr>(m<asl/"s<adot/)</pr>, <pos>n.</pos>
<ety>[Sp.]</ety> <def>A high tableland; a plateau on a hill.</def>
<mark>[Southwestern U.S.]</mark> <rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesaconate</ent><br/
<hw>Mes*ac"o*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of mesaconic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesaconic</ent><br/
<hw>Mes`a*con"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mes-</ets>
+ <ets>-aconic</ets>, as in <ets>citraconic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, one of several
isomeric acids obtained from citric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mesad</ent><br/
<hw>mes"ad</hw> <pr>(m<ecr/s"<acr/d)</pr>, <pos>adv.</pos> <def>Same as
<er>mesiad</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mesal</ent><br/
<hw>mes"al</hw> <pr>(m<ecr/s"<ait/l)</pr>, <pos>a.</pos> <def>Same as
<er>Mesial</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesalliance</ent><br/
\'d8<hw>M<eacute/`sal`li`ance"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A marriage with a person of inferior social
position; a misalliance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mesally</ent><br/
<hw>mes"al*ly</hw> <pr>(m<ecr/s"<ait/l*l<ycr/)</pr>, <pos>adv.</pos>
<def>Same as <er>Mesially</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesamoeboid</ent><br/
<hw>Mes`a*m<oe/"boid</hw> <pr>(m<ecr/s`<adot/*m<emac/"boid)</pr>,
<pos>n.</pos> <ety>[<ets>Mes-</ets> + <ets>am<oe/boid</ets>.]</ety>
<fld>(Biol.)</fld> <def>One of a class of independent, isolated cells
found in the mesoderm, while the germ layers are undergoing
differentiation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesaraic</ent><br/
<hw>Mes`a*ra"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>mesa`raion</grk> mesentery; <grk>me`sos</grk> middle +
<grk>'araia`</grk> flank.]</ety> <fld>(Anat.)</fld>
<def>Mesenteric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesaticephalic</ent><br/
<hw>Mes`a*ti*ce*phal"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<ets><?/</ets> midmost + E. <ets>cephalic</ets>.]</ety>
<fld>(Anat.)</fld> <def>Having the ratio of the length to the breadth of
the cranium a medium one; neither brachycephalic nor
dolichocephalic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesaticephalous</ent><br/
<hw>Mes`a*ti*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Mesaticephalic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mescal</ent><br/
\'d8<hw>Mes*cal"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>A distilled liquor prepared in Mexico from a species of agave. See
<er>Agave</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesdames</ent><br/
\'d8<hw>Mes`dames"</hw> <pr>(F. ?, E. ?)</pr>, <pos>n.</pos>,
<def><pos>pl.</pos> of <er>Madame</er> and <er>Madam</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meseems</ent><br/
<hw>Me*seems"</hw> <pr>(?)</pr>, <pos>v. impers.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Meseemed</conjf> <pr>(?)</pr>.]</vmorph>
<def>It seems to me.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesel</ent><br/
<hw>Me"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Measle</er>.]</ety> <def>A leper.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meselry</ent><br/
<hw>Me"sel*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Leprosy.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesembryanthemum</ent><br/
\'d8<hw>Me*sem`bry*an"the*mum</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>meshmbri`a</grk> midday + <grk>'a`nqos</grk>
flower.]</ety> <fld>(Bot.)</fld> <def>A genus of herbaceous or
suffruticose plants, chiefly natives of South Africa. The leaves are
opposite, thick, and fleshy. The flowers usually open about midday,
whence the name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesencephalic</ent><br/
<hw>Mes`en*ce*phal"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to the mesencephalon or
midbrain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesencephalon</ent><br/
\'d8<hw>Mes`en*ceph"a*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meso-</er> and <er>Encephalon</er>.]</ety> <fld>(Anat.)</fld>
<def>The middle segment of the brain; the midbrain. Sometimes
abbreviated to <altname>mesen</altname>. See <er>Brain</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesenchyma</ent><br/
\'d8<hw>Mes*en"chy*ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <ets>-enchyma</ets>, as in E.
<ets>parenchyma</ets>.]</ety> <fld>(Biol.)</fld> <def>The part of the
mesoblast which gives rise to the connective tissues and
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesenteric</ent><br/
<hw>Mes`en*ter"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/sent<eacute/rique</ets>.]</ety> <fld>(Anat.)</fld>
<def>Pertaining to a mesentery; mesaraic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesenteron</ent><br/
\'d8<hw>Mes*en"te*ron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meso-</er>, and <er>Enteron</er>.]</ety> <fld>(Anat.)</fld> <def>All
that part of the alimentary canal which is developed from the primitive
enteron and is lined with hypoblast. It is distinguished from the
<xex>stomodaeum</xex>, a part at the anterior end of the canal,
including the cavity of the mouth, and the <xex>proctodaeum</xex>, a
part at the posterior end, which are formed by invagination and are
lined with epiblast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesentery</ent><br/
<hw>Mes"en*ter*y</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mesente`rion</grk>, <grk>me`sos</grk> + <grk>'e`nteron</grk>
intestine: cf. F. <ets>m<eacute/sent<egrave/re</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>The membranes, or one of the
membranes (consisting of a fold of the peritoneum and inclosed tissues),
which connect the intestines and their appendages with the dorsal wall
of the abdominal cavity. The mesentery proper is connected with the
jejunum and ilium, the other mesenteries being called
<xex>mesocaecum</xex>, <xex>mesocolon</xex>, <xex>mesorectum</xex>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the vertical muscular
radiating partitions which divide the body cavity of Anthozoa into
chambers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meseraic</ent><br/
<hw>Mes`e*ra"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Mesaraic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesethmoid</ent><br/
<hw>Mes*eth"moid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mes-</ets>
+ <ets>ethmoid</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to
the middle of the ethmoid region or ethmoid bone.</def> --
<def2><pos>n.</pos> <fld>(Anat.)</fld> <def>The median vertical plate,
or median element, of the ethmoid bone.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesh</ent><br/
<hw>Mesh</hw> <pr>(m<ecr/sh)</pr>, <pos>n.</pos> <ety>[AS.
<ets>masc</ets>, <ets>max</ets>, <ets>m<ae/scre</ets>; akin to D.
<ets>maas</ets>, <ets>masche</ets>, OHG. <ets>masca</ets>, Icel.
<ets>m<oum/skvi</ets>; cf. Lith. <ets>mazgas</ets> a knot,
<ets>megsti</ets> to weave nets, to knot.]</ety> <sn>1.</sn> <def>The
opening or space inclosed by the threads of a net between knot and knot,
or the threads inclosing such a space; network; a net.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A golden <qex>mesh</qex> to entrap the hearts of men.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gearing)</fld> <def>The engagement of the teeth of
wheels, or of a wheel and rack.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mesh stick</b></col>, <cd>a stick on which the mesh is
formed in netting.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesh</ent><br/
<hw>Mesh</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Meshed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Meshing</conjf>.]</vmorph> <def>To catch in a mesh.</def>
<rj><au>Surrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesh</ent><br/
<hw>Mesh</hw>, <pos>v. i.</pos> <fld>(Gearing)</fld> <def>To engage with
each other, as the teeth of wheels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meshed</ent><br/
<hw>Meshed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mashed; brewed.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meshy</ent><br/
<hw>Mesh"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed with meshes;
netted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesiad</ent><br/
<hw>Mes"i*ad</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[Gr.
<grk>me`sos</grk> middle + L. <ets>ad</ets> to.]</ety>
<fld>(Anat.)</fld> <def>Toward, or on the side toward, the mesial plane;
mesially; -- opposed to <contr>laterad</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesial</ent><br/
<hw>Me"sial</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>me`sos</grk> middle.]</ety> <fld>(Anat.)</fld> <def>Middle; median;
in, or in the region of, the mesial plane; internal; -- opposed to
<contr>lateral</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mesial plane</b></col>. <fld>(Anat.)</fld> <cd>See
<er>Meson</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesially</ent><br/
<hw>Me"sial*ly</hw>, <pos>adv.</pos> <fld>(Anat.)</fld> <def>In, near,
or toward, the mesial plane; mesiad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesityl</ent><br/
<hw>Mes"i*tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
hypothetical radical formerly supposed to exist in mesityl
oxide.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mesityl oxide</b></col> <fld>(Chem.)</fld>, <cd>a
volatile liquid having the odor of peppermint, obtained by certain
dehydrating agents from acetone; -- formerly called also
<altname>dumasin</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesitylenate</ent><br/
<hw>Me*sit"y*le*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of mesitylenic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesitylene</ent><br/
<hw>Me*sit"y*lene</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A colorless, fragrant liquid, <chform>C6H3(CH3)3</chform>, of the
benzene series of hydrocarbons, obtained by distilling acetone with
sulphuric acid.</def> -- <wordforms><wf>Me*sit`y*len"ic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesitylol</ent><br/
<hw>Me*sit"y*lol</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mesityl</ets>ene + <ets>-ol</ets>.]</ety> <fld>(Chem.)</fld>
<def>A crystalline substance obtained from mesitylene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meslin</ent><br/
<hw>Mes"lin</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>See
<er>Maslin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesmeree</ent><br/
<hw>Mes`mer*ee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person subjected
to mesmeric influence; one who is mesmerized.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesmerical</ent><br/
<ent>Mesmeric</ent><br/
<mhw>{ <hw>Mes*mer"ic</hw> <pr>(?)</pr>, <hw>Mes*mer"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>mesm<eacute/rique</ets>.]</ety> <def>Of, pertaining to, or induced
by, mesmerism; <as>as, <ex>mesmeric</ex> sleep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesmerism</ent><br/
<hw>Mes"mer*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<persfn><etsep>Mesmer</etsep></persfn>, who first brought it into notice
at Vienna, about 1775: cf. F. <ets>mesm<eacute/risme</ets>.]</ety>
<def>An earlier name for <altname>hypnosis</altname> or
<altname>hypnotism</altname>, the art of inducing an extraordinary or
abnormal state of the nervous system, in which the actor claims to
control the actions, and communicate directly with the mind, of the
recipient. It is believed to be a state between sleep and wakefulness,
in which a person is more susceptible to suggestion than when awake. See
<cref>Animal magnetism</cref>, under <er>Magnetism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesmerist</ent><br/
<hw>Mes"mer*ist</hw>, <pos>n.</pos> <def>One who practices, or believes
in, mesmerism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesmerization</ent><br/
<hw>Mes`mer*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
mesmerizing; the state of being mesmerized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesmerize</ent><br/
<hw>Mes"mer*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mesmerized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mesmerizing</conjf> <pr>(?)</pr>.]</vmorph> <altsp>[Also
spelled <asp>mesmerise</asp>.]</altsp><sn>1.</sn> <def>To bring into a
state of mesmeric sleep; to hypnotize.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To produce an intense fascination in; to
spellbind.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mesmerizer</ent><br/
<hw>Mes"mer*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mesmerizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesne</ent><br/
<hw>Mesne</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. <er>Mean</er>
intermediate.]</ety> <fld>(Law)</fld> <def>Middle; intervening; <as>as,
a <ex>mesne</ex> lord, that is, a lord who holds land of a superior, but
grants a part of it to another person, in which case he is a
<ex>tenant</ex> to the superior, but <ex>lord</ex> or superior to the
second grantee, and hence is called the <ex>mesne</ex>
lord</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mesne process</b></col>, <cd>intermediate process;
process intervening between the beginning and end of a suit, sometimes
understood to be the whole process preceding the execution.</cd>
<au>Blackstone.</au> <au>Burrill.</au> -- <col><b>Mesne
profits</b></col>, profits of premises during the time the owner has
been wrongfully kept out of the possession of his estate.
<rj><au>Burrill.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mes-</ent><br/
<ent>Meso-</ent><br/
<mhw>{ <hw>Mes"o-</hw> <pr>(?)</pr>, <hw>Mes-</hw> <pr>(?)</pr> }</mhw>.
<ety>[Gr. <grk>me`sos</grk> in the middle.]</ety> <sn>1.</sn> <def>A
combining form denoting <sig>in the middle</sig>,
<sig>intermediate</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>specif.</specif> <fld>(Chem.)</fld>,
<def>Denoting <xex>a type of hydrocarbons</xex> which are regarded as
<xex>methenyl derivatives</xex>. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>Optically inactive due to
compensating optical activity at two or more asymmetric centers, often
due to a plane of symmetry within the molecular structure; <as>as,
<ex>meso-</ex>tartaric acid</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Attached to a carbon atom located between two
hereoatoms in a heterocyclic ring.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mesoarium</ent><br/
\'d8<hw>Mes`o*a"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>me`sos</grk> middle + <grk>'w,a`rion</grk>, dim. of
<grk>'w,o`n</grk> an egg.]</ety> <fld>(Anat.)</fld> <def>The fold of
peritoneum which suspends the ovary from the dorsal wall of the body
cavity; the <altname>mesovarium</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoblast</ent><br/
<hw>Mes"o*blast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets>
+ <ets>-blast</ets>.]</ety> <fld>(Biol.)</fld> <sd>(a)</sd> <def>The
mesoderm.</def> <sd>(b)</sd> <def>The cell nucleus; mesoplast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoblastic</ent><br/
<hw>Mes`o*blas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Relating to the mesoblast; <as>as, the <ex>mesoblastic</ex>
layer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesobranchial</ent><br/
<hw>Mes`o*bran"chi*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + <ets>branchial</ets>.]</ety> <fld>(Zool.)</fld>
<def>Of or pertaining to a region of the carapace of a crab covering the
middle branchial region.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesobronchium</ent><br/
\'d8<hw>Mes`o*bron"chi*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mesobronchia</plw> <pr>(#)</pr>.</plu> <ety>[NL.
See <er>Meso-</er>, and <er>Bronchia</er>.]</ety> <fld>(Anat.)</fld>
<def>The main bronchus of each lung.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocaecum</ent><br/
\'d8<hw>Mes`o*cae"cum</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Anat.)</fld> <ety>[NL. See <er>Meso-</er>, and
<er>Caecum</er>.]</ety> <def>The fold of peritoneum attached to the
caecum.</def> -- <wordforms><wf>Mes`o*cae"cal</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocarp</ent><br/
<hw>Mes"o*carp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets> +
Gr. <grk>karpo`s</grk> fruit.]</ety> <fld>(Bot.)</fld> <def>The middle
layer of a pericarp which consists of three distinct or dissimilar
layers.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocephalic</ent><br/
<hw>Mes`o*ce*phal"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + <ets>cephalic</ets>.]</ety> <fld>(Anat.)</fld>
<sd>(a)</sd> <def>Of or pertaining to, or in the region of, the middle
of the head; <as>as, the <ex>mesocephalic</ex> flexure</as>.</def>
<sd>(b)</sd> <def>Having the cranial cavity of medium capacity; neither
megacephalic nor microcephalic.</def> <sd>(c)</sd> <def>Having the ratio
of the length to the breadth of the cranium a medium one;
mesaticephalic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocephalon</ent><br/
\'d8<hw>Mes`o*ceph"a*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meso-</er>, and <er>Cephalon</er>.]</ety> <fld>(Anat.)</fld>
<def>The pons Varolii.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocephalous</ent><br/
<hw>Mes`o*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Mesocephalic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocoelia</ent><br/
<ent>Mesocoele</ent><br/
<mhw>{ <hw>Mes`o*coe"le</hw> <pr>(?)</pr>, \'d8<hw>Mes`o*coe"li*a</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>mesocoelia</ets>. See
<er>Meso-</er>, and <er>Coelia</er>.]</ety> <fld>(Anat.)</fld> <def>The
cavity of the mesencephalon; the iter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocolon</ent><br/
<hw>Mes`o*co"lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>meso`kwlon</grk>; <grk>me`sos</grk> middle + <grk>kw^lon</grk> the
colon: cf. F. <ets>m<eacute/soc<ocir/lon</ets>.]</ety>
<fld>(Anat.)</fld> <def>The fold of peritoneum, or mesentery, attached
to the colon.</def> -- <wordforms><wf>Mes`o*col"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocoracoid</ent><br/
<hw>Mes`o*cor"a*coid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>coracoid</ets>.]</ety> <fld>(Anat.)</fld>
<def>A process from the middle of the coracoid in some
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesocuniform</ent><br/
<ent>Mesocuneiform</ent><br/
<mhw>{ <hw>Mes`o*cu*ne"i*form</hw> <pr>(?)</pr>,
<hw>Mes`o*cu"ni*form</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>cuneiform</ets>,
<ets>cuniform</ets>.]</ety> <fld>(Anat.)</fld> <def>One of the bones of
the tarsus. See 2d <er>Cuneiform</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoderm</ent><br/
<hw>Mes"o*derm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets> +
Gr. <grk>de`rma</grk> skin.]</ety> <fld>(Biol.)</fld> <sd>(a)</sd>
<def>The layer of the blastoderm, between the ectoderm and endoderm;
mesoblast. See <xex>Illust.</xex> of <er>Blastoderm</er> and
<er>Ectoderm</er>.</def> <sd>(b)</sd> <def>The middle body layer in some
invertebrates.</def> <sd>(c)</sd> <def>The middle layer of tissue in
some vegetable structures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesodermal</ent><br/
<hw>Mes`o*der"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Pertaining to, or derived from, the mesoderm; <as>as,
<ex>mesodermal</ex> tissues</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesodermic</ent><br/
<hw>Mes`o*der"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Mesodermal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesodont</ent><br/
<hw>Mes"o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Meso-</ets> +
Gr. <grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, a tooth.]</ety>
<fld>(Anat.)</fld> <def>Having teeth of moderate size.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesogaster</ent><br/
\'d8<hw>Mes`o*gas"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <?/ belly.]</ety> <fld>(Anat.)</fld>
<def>The fold of peritoneum connecting the stomach with the dorsal wall
of the abdominal cavity; the mesogastrium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesogastric</ent><br/
<hw>Mes`o*gas"tric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + <ets>gastric</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <sd>(a)</sd> <def>Of or pertaining to
the middle region of the abdomen, or of the stomach.</def> <sd>(b)</sd>
<def>Of or pertaining to the mesogaster.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Of or pertaining to the middle
gastric lobe of the carapace of a crab.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesogastrium</ent><br/
\'d8<hw>Mes`o*gas"tri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Mesogaster</er>.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd> <def>The
umbilical region.</def> <sd>(b)</sd> <def>The mesogaster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesogloea</ent><br/
\'d8<hw>Mes`o*gl<oe/"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <?/ a glutinous substance.]</ety>
<fld>(Zool.)</fld> <def>A thin gelatinous tissue separating the ectoderm
and endoderm in certain coelenterates.</def> --
<wordforms><wf>Mes`o*gl<oe/"al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesognathous</ent><br/
<hw>Me*sog"na*thous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + Gr. <grk>gna`qos</grk> jaw.]</ety>
<fld>(Anat.)</fld> <def>Having the jaws slightly projecting; between
prognathous and orthognathous. See <cref>Gnathic index</cref>, under
<er>Gnathic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesohepar</ent><br/
\'d8<hw>Mes`o*he"par</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meso-</er>, and <er>Hepar</er>.]</ety> <fld>(Anat.)</fld> <def>A
fold of the peritoneum connecting the liver with the dorsal wall of the
abdominal cavity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesohippus</ent><br/
\'d8<hw>Mes`o*hip"pus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <?/ a horse.]</ety> <fld>(Paleon.)</fld>
<def>An extinct mammal of the Horse family, but not larger than a sheep,
and having three toes on each foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesolabe</ent><br/
<hw>Mes"o*labe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mesolabium</ets>, Gr. <?/; <grk>me`sos</grk> middle + <?/ to
take.]</ety> <def>An instrument of the ancients for finding two mean
proportionals between two given lines, required in solving the problem
of the duplication of the cube.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesole</ent><br/
<hw>Mes"ole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>me`sos</grk>
middle.]</ety> <fld>(Min.)</fld> <def>Same as
<er>Thomsonite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesolite</ent><br/
<hw>Mes"o*lite</hw> <pr>(?; 277)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>-lite</ets>.]</ety> <fld>(Min.)</fld>
<def>A zeolitic mineral, grayish white or yellowish, occuring in
delicate groups of crystals, also fibrous massive. It is a hydrous
silicate of alumina, lime, and soda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesologarithm</ent><br/
<hw>Mes`o*log"a*rithm</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>logarithm</ets> : cf. F.
<ets>m<eacute/sologarithme</ets>.]</ety> <fld>(Math.)</fld> <def>A
logarithm of the cosine or cotangent.</def> <mark>[Obs.]</mark>
<rj><au>Kepler. Hutton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesometrium</ent><br/
\'d8<hw>Mes`o*me"tri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meso-</er>, and <er>Metrium</er>.]</ety> <fld>(Anat.)</fld> <def>The
fold of the peritoneum supporting the oviduct.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesomycetes</ent><br/
\'d8<hw>Mes`o*my*ce"tes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.;
<ets>meso-</ets> + <ets>mycetes</ets>.]</ety> <fld>(Bot.)</fld> <def>One
of the three classes into which the fungi are divided in
<persfn>Brefeld's</persfn> classification.</def> --
<wordforms><wf>Mes`o*my*ce"tous</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mesomyodian</ent><br/
<hw>Mes`o*my*o"di*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A bird having a mesomyodous larynx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesomyodous</ent><br/
<hw>Mes`o*my"o*dous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + Gr. <?/, <?/, a muscle.]</ety>
<fld>(Zool.)</fld> <def>Having the intrinsic muscles of the larynx
attached to the middle of the semirings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meson</ent><br/
\'d8<hw>Mes"on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`son</grk> middle, neut. of <grk>me`sos</grk>, a., middle.]</ety>
<sn>1.</sn> <fld>(Anat.)</fld> <def>The mesial plane dividing the body
of an animal into similar right and left halves. The line in which it
meets the dorsal surface has been called the <part>dorsimeson</part>,
and the corresponding ventral edge the <part>ventrimeson</part>.</def>
<rj><au>B. G. Wilder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>An <isa>elementary
particle</isa> made up of two quarks; a hadron having a baryon number of
zero; any hadron other than a baryon. Mesons are bosons with integral
values of spin, having a mass intermediate between those of the electron
and a nucleon; they may have positive or negative charges, or may be
neutral. Mesons are of three types: the <stype>pion</stype>
(<pi/-meson), <stype>kaon</stype> (K-mesons), and
<stype><eta/-mesons</stype>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>mu meson</b></col> <fld>(Physics)</fld> <cd>the former
name for the <altname>muon</altname>, a particle which is not a true
meson{2}. The term is no longer used in technical literature, except
historically.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>mesonic</ent><br/
<hw>me*son"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
a meson.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mesonasal</ent><br/
<hw>Mes`o*na"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Meso-</ets>
+ <ets>nasal</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to
the middle portion of the nasal region.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesonephric</ent><br/
<hw>Mes`o*neph"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the mesonephros; <as>as, the
<ex>mesonephric</ex>, or Wolffian, duct</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesonephros</ent><br/
\'d8<hw>Mes`o*neph"ros</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <grk>nefro`s</grk> kidney.]</ety>
<fld>(Anat.)</fld> <def>The middle one of the three pairs of embryonic
renal organs developed in most vertebrates; the Wolffian body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesonotum</ent><br/
\'d8<hw>Mes`o*no"tum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`sos</grk> middle + <grk>nw^ton</grk> the back.]</ety>
<fld>(Zool.)</fld> <def>The dorsal portion of the mesothorax of
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesophloeum</ent><br/
\'d8<hw>Mes`o*phl<oe/"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <grk>floio`s</grk> bark.]</ety>
<fld>(Bot.)</fld> <def>The middle bark of a tree; the green layer of
bark, usually soon covered by the outer or corky layer, and
obliterated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesophryon</ent><br/
\'d8<hw>Me*soph"ry*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>meso`fryon</grk>.]</ety> <fld>(Anat.)</fld> <def>See
<er>Glabella</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesophyllum</ent><br/
\'d8<hw>Mes`o*phyl"lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <grk>fy`llon</grk> leaf.]</ety>
<fld>(Bot.)</fld> <def>The parenchyma of a leaf between the skin of the
two surfaces.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoplast</ent><br/
<hw>Mes"o*plast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets>
+ <ets>-plast</ets>.]</ety> <fld>(Biol.)</fld> <def>The nucleus of a
cell; mesoblast.</def> <rj><au>Agassiz.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 916 --></p>

<p><ent>Mesopodial</ent><br/
<hw>Mes`o*po"di*al</hw> <pr>(m<ecr/s`<osl/*p<omac/"d<icr/*<ait/l)</pr>,
<pos>a.</pos> <fld>(Anat.)</fld> <def>Of or pertaining to the
mesopodialia or to the parts of the limbs to which they
belong.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesopodiale</ent><br/
\'d8<hw>Mes`o*po`di*a"le</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mesopodialia</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
fr. Gr. <grk>me`sos</grk> middle + <?/, dim. of <grk>poy`s</grk>,
<grk>podo`s</grk>, foot.]</ety> <fld>(Anat.)</fld> <def>One of the bones
of either the carpus or tarsus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesopodium</ent><br/
\'d8<hw>Mes`o*po"di*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Mesopodiale</er>.]</ety> <fld>(Zool.)</fld> <def>The middle portion
of the foot in the Gastropoda and Pteropoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesopterygium</ent><br/
\'d8<hw>Me*sop`te*ryg"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>me`sos</grk> middle + <?/ a fin.]</ety> <fld>(Anat.)</fld>
<def>The middle one of the three principal basal cartilages in the fins
of fishes.</def> -- <wordforms><wf>Me*sop`ter*yg"i*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesorchium</ent><br/
\'d8<hw>Me*sor"chi*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <?/ a testicle.]</ety> <fld>(Anat.)</fld>
<def>The fold of peritoneum which attaches the testis to the dorsal wall
of the body cavity or scrotal sac.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesorectum</ent><br/
\'d8<hw>Mes`o*rec"tum</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>rectum</ets>.]</ety> <fld>(Anat.)</fld>
<def>The fold of peritoneum, or mesentery, attached to the rectum.</def>
-- <wordforms><wf>Mes`o*rec"tal</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesorhine</ent><br/
<hw>Mes"o*rhine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Meso-</ets>
+ Gr. <?/, <?/, the nose.]</ety> <fld>(Anat.)</fld> <def>Having the nose
of medium width; between leptorhine and platyrhine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesosauria</ent><br/
\'d8<hw>Mes`o*sau"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mosasauria</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoscapula</ent><br/
\'d8<hw>Mes`o*scap"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>scapula</ets>.]</ety> <fld>(Anat.)</fld>
<def>A process from the middle of the scapula in some animals; the spine
of the scapula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoscapular</ent><br/
<hw>Mes`o*scap"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the mesoscapula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoscutum</ent><br/
\'d8<hw>Mes`o*scu"tum</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>scutum</ets>.]</ety> <fld>(Zool.)</fld>
<def>The scutum or dorsal plate of the middle thoracic segment of an
insect. See <xex>Illust.</xex> of <er>Butterfly</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoseme</ent><br/
<hw>Mes"o*seme</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Meso-</ets> +
Gr. <?/ sign, mark; cf. F. <ets>m<eacute/sos<egrave/me</ets>.]</ety>
<fld>(Anat.)</fld> <def>Having a medium orbital index; having orbits
neither broad nor narrow; between megaseme and microseme.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesosiderite</ent><br/
<hw>Mes`o*sid"er*ite</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>siderite</ets>.]</ety> <fld>(Min.)</fld>
<def>See the Note under <er>Meteorite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesosperm</ent><br/
<hw>Mes"o*sperm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets>
+ Gr. <?/ seed: cf. F. <ets>m<eacute/sosperme</ets>.]</ety>
<fld>(Bot.)</fld> <def>A membrane of a seed. See
<er>Secundine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesostate</ent><br/
<hw>Mes"o*state</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets>
+ Gr. <?/ to make to stand.]</ety> <fld>(Physiol.)</fld> <def>A product
of metabolic action.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Every <xex>mesostate</xex> is either an
<xex>anastate</xex> or <xex>katastate</xex>, according as it is formed
by an anabolic or katabolic process. See <er>Metabolism</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesosternal</ent><br/
<hw>Mes`o*ster"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the mesosternum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesosternum</ent><br/
\'d8<hw>Mes`o*ster"num</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>sternum</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anat.)</fld> <def>The middle portion, or body, of
the sternum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The ventral piece of the middle
segment of the thorax in insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mesotartaric</ent><br/
<hw>mes`o*tar*tar"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + <ets>tartaric</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an acid called also
<altname>inactive tartaric acid</altname>. It is an optically inactive
stereoisomer of <isa>tartaric acid</isa> due to internal compensation of
the rotatory activity of the two asymmetric centers; it has a plane of
symmetry in the molecule.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mesotheca</ent><br/
\'d8<hw>Mes`o*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>me`sos</grk> middle + <?/ box.]</ety> <fld>(Zool.)</fld> <def>The
middle layer of the gonophore in the Hydrozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesothelium</ent><br/
\'d8<hw>Mes`o*the"li*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + E. epi<ets>thelium</ets>.]</ety>
<fld>(Biol.)</fld> <def>Epithelial mesoderm; a layer of cuboidal
epithelium cells, formed from a portion of the mesoderm during the
differetiation of the germ layers. It constitutes the boundary of the
c<oe/lum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesothoracic</ent><br/
<hw>Mes`o*tho*rac"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the mesothorax.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesothorax</ent><br/
<hw>Mes`o*tho"rax</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meso-</ets> + <ets>thorax</ets>: cf. F.
<ets>m<eacute/sothorax</ets>.]</ety> <fld>(Zool.)</fld> <def>The middle
segment of the thorax in insects. See <xex>Illust.</xex> of
<er>Coleoptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesothorium</ent><br/
<hw>Mes`o*tho"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.;
<ets>meso-</ets> + <ets>thorium</ets>.]</ety> <fld>(Chem.)</fld> <def>a
radioactive isotope of radium (radium-228) with a half-life of 5.8
years. Also called <altname>mesothorium-1</altname> or
<altname>mesothorium I</altname> to distinguish it from a subsequent
decay product, mesothorium II (actinium-228). It was discovered in 1907
by Otto Hahn as a decay product of thorium (produced by decay of
thorium-232). Mesothorium-1 (radium-228) in turn produces actinium-228
(mesothorium-2) as the first product of its radioactive decay, and the
actinium-228 in turn decays quickly (half-life of 6 hours) to
thorium-228 (which is also called <er>radiothorium</er>; the thorium-228
has a half-life of 1.91 years, shorter than that of the radium-228). It
was discovered and named before full recognition of the nature of
isotopes of the elements, and was distinguished from other variants of
radium by its half-life and mode of production and decay. It was also
cheaper to prepare than other short-lived radium isotopes, and was thus
sold commercially, for use, e.g. in making watch dials readable in the
dark by painting the hands and hour marks with a self-luminous paint
containing the radioactive substance; it is therefore often referred to
(e.g. in regulatory legislation) as though distinct from radium. It was
one of the isotopes believed responsible for radiation-induced diseases
observed in industrial workers who painted radium on watch dials in the
late 1950's and early 1960's. The primary isotope of radium (radium-226)
has a half-life of 1620 years, and these isotopes with shorter
half-lives proved difficult to isolate and study for the purpose of
finding the cause of such diseases.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Mesotrochal</ent><br/
<hw>Mes"o*tro`chal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meso-</ets> + Gr. <?/ anything round, a hoop.]</ety>
<fld>(Zool.)</fld> <def>Having the middle of the body surrounded by
bands of cilia; -- said of the larvae of certain marine
annelids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesotype</ent><br/
<hw>Mes"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meso-</ets> +
<ets>-type</ets>: cf. F. <ets>m<eacute/sotype</ets>.]</ety>
<fld>(Min.)</fld> <def>An old term covering natrolite or <xex>soda
mesolite</xex>, scolecite or <xex>lime mesotype</xex>, and mesolite or
<xex>lime-soda mesotype</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesovarium</ent><br/
\'d8<hw>Mes`o*va"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meso-</er>, and <er>Ovary</er>.]</ety> <fld>(Anat.)</fld> <def>The
fold of peritoneum connecting the ovary with the wall of the abdominal
cavity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoxalate</ent><br/
<hw>Mes*ox"a*late</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of mesoxalic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesoxalic</ent><br/
<hw>Mes`ox*al"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mes-</ets>
+ <ets>oxalic</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, an acid, <chform>CH2O2(CO2H)2</chform>, obtained from amido
malonic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesozoa</ent><br/
\'d8<hw>Mes`o*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Mesozoic</er>.]</ety> <fld>(Zool.)</fld> <def>A group of very lowly
organized, wormlike parasites, including the Dicyemata. They are found
in cephalopods. See <er>Dicyemata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesozoic</ent><br/
<hw>Mes`o*zo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Meso-</ets>
+ Gr. <?/ life, fr. <?/ to live.]</ety> <fld>(Geol.)</fld>
<def>Belonging, or relating, to the secondary or reptilian age, or the
era between the Paleozoic and Cenozoic. See <xex>Chart</xex> of
<er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesozoic</ent><br/
<hw>Mes`o*zo"ic</hw>, <pos>n.</pos> <def>The Mesozoic age or
formation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesprise</ent><br/
<hw>Mes*prise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mespris</ets>, F. <ets>m<eacute/pris</ets>. See
<er>Misprize</er>.]</ety> <sn>1.</sn> <def>Contempt; scorn.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Perh. for F. <ets>m<eacute/prise</ets> mistake. Cf.
<er>Misprision</er>.]</ety> <def>Misadventure; ill-success.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesquit</ent><br/
<ent>Mesquite</ent><br/
<mhw>{ <hw>Mes*qui"te</hw> <pr>(m<ecr/s*k<emac/"t<asl/)</pr>,
<hw>Mes*quit"</hw> <pr>(m<ecr/s*k<emac/t")</pr> }</mhw>, <pos>n.</pos>
<ety>[Sp. <ets>mezquite</ets>; said to be a Mexican Indian word.]</ety>
<fld>(Bot.)</fld> <def>Aany of several small spiny trees or shrubs of
the southwestern part of North America belonging to the genus
<gen>Prosopis</gen> having small flowers in axillary cylindrical spikes
followed by large sugar-rich pods, especially the <stype>honey
mesquite</stype>, and <stype>screw-pod mesquite</stype>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><cs><col><b>Honey mesquite</b></col>. <cd>See <er>Algaroba</er>
<sd>(b)</sd>.</cd> -- <col><b>Screw-pod mesquite</b></col>, <cd>a
smaller tree (<spn>Prosopis pubescens</spn>), having spiral pods used as
fodder and sometimes as food by the Indians.</cd> -- <col><b>Mesquite
grass</b></col>, <cd>a rich native grass in Western Texas
(<spn>Bouteloua oligostachya</spn>, and other species); -- so called
from its growing in company with the mesquite tree; -- called also
<altname>muskit grass</altname>, <altname>grama
grass</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesquite bean</ent><br/
<hw>Mes*qui"te bean</hw>. <def>The pod or seed of the
mesquite.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mess</ent><br/
<hw>Mess</hw> <pr>(m<ecr/s)</pr>, <pos>n.</pos> <def>Mass; church
service.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mess</ent><br/
<hw>Mess</hw> <pr>(m<ecr/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mes</ets>, OF. <ets>mets</ets>, LL. <ets>missum</ets>, p. p. of
<ets>mittere</ets> to put, place (<it>e. g.</it>, on the table), L.
<ets>mittere</ets> to send. See <er>Mission</er>, and cf. <er>Mass</er>
religious service.]</ety> <sn>1.</sn> <def>A quantity of food set on a
table at one time; provision of food for a person or party for one meal;
<as>as, a <ex>mess</ex> of pottage</as>; also, the food given to a beast
at one time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At their savory dinner set<br/
Of herbs and other country <qex>messes</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A number of persons who eat together, and for whom
food is prepared in common; especially, persons in the military or naval
service who eat at the same table; <as>as, the wardroom
<ex>mess</ex></as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A set of four; -- from the old practice of dividing
companies into sets of four at dinner.</def> <mark>[Obs.]</mark>
<rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The milk given by a cow at one milking.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[Perh. corrupt. fr. OE. <ets>mesh</ets> for
<ets>mash</ets>: cf. <ets>muss</ets>.]</ety> <def>A disagreeable mixture
or confusion of things; hence, a situation resulting from blundering or
from misunderstanding; <as>as, he made a <ex>mess</ex> of it</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mess</ent><br/
<hw>Mess</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Messed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Messing</conjf>.]</vmorph> <def>To take meals with a mess; to
belong to a mess; to eat (with others); <as>as, I <ex>mess</ex> with the
wardroom officers</as>.</def> <rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mess</ent><br/
<hw>Mess</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To supply with a
mess.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a mess{5} of; to disorder or muddle; to
muss; to jumble; to disturb; to mess up.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>It was n't right either to be <qex>messing</qex> another man's
sleep.</q> <rj><qau>Scribner's Mag.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Message</ent><br/
<hw>Mes"sage</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[F., fr. LL.
<ets>missaticum</ets>, fr. L. <ets>mittere</ets>, <ets>missum</ets>, to
send. See <er>Mission</er>, and cf. <er>Messenger</er>.]</ety>
<sn>1.</sn> <def>Any notice, word, or communication, written or verbal,
sent from one person to another.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ehud said, I have a <qex>message</qex> from God unto thee.</q>
<rj><qau>Judg. iii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, specifically, an official communication, not
made in person, but delivered by a messenger; <as>as, the President's
<ex>message</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Message shell</b></col>. <cd>See
<er>Shell</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Message</ent><br/
<hw>Mes"sage</hw>, <pos>v. t.</pos> <def>To bear as a message.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Message</ent><br/
<hw>Mes"sage</hw>, <pos>n.</pos> <ety>[OE., fr. OF. <ets>message</ets>,
fr. LL. <ets>missaticus</ets>. See 1st <er>Message</er>.]</ety> <def>A
messenger.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messager</ent><br/
<hw>Mes"sa*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.]</ety> <def>A
messenger.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Message stick</ent><br/
<hw>Mes"sage stick</hw>. <def>A stick, carved with lines and dots, used,
esp. by Australian aborigines, to convey information.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mess beef</ent><br/
<hw>Mess beef</hw>. <def>Barreled salt beef, packed with about 80 pounds
chuck and rump, two flanks, and the rest plates.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Messenger</ent><br/
<hw>Mes"sen*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>messager</ets>, OF. <ets>messagier</ets>, F. <ets>messager</ets>.
See <er>Message</er>.]</ety> <sn>1.</sn> <def>One who bears a message;
the bearer of a verbal or written communication, notice, or invitation,
from one person to another, or to a public body; specifically, an office
servant who bears messages.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who, or that which, foreshows, or
foretells.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yon gray lines<br/
That fret the clouds are <qex>messengers</qex> of day.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A hawser passed round the
capstan, and having its two ends lashed together to form an endless rope
or chain; -- formerly used for heaving in the cable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>A person appointed to perform
certain ministerial duties under bankrupt and insolvent laws, such as to
take charge of the estate of the bankrupt or insolvent.</def>
<rj><au>Bouvier. Tomlins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Carrier; intelligencer; courier; harbinger;
forerunner; precursor; herald.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Messenger bird</b></col>, <cd>the secretary bird, from
its swiftness.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messet</ent><br/
<hw>Mes"set</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dog.</def>
<mark>[Obs. or Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messiad</ent><br/
<hw>Mes*si"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A German epic poem
on the Messiah, by Klopstock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messiah</ent><br/
<hw>Mes*si"ah</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>m<amac/sh<imac/akh</ets> anointed, fr. <ets>m<amac/shakh</ets> to
anoint. Cf. <er>Messias</er>.]</ety> <def>The expected king and
deliverer of the Hebrews; the Savior; Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And told them the <qex>Messiah</qex> now was born.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messiahship</ent><br/
<hw>Mes*si"ah*ship</hw>, <pos>n.</pos> <def>The state or office of the
Messiah.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messianic</ent><br/
<hw>Mes`si*an"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or relating to
the Messiah; <as>as, the <ex>Messianic</ex> office or
character</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messias</ent><br/
<hw>Mes*si"as</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL., fr. Gr. <?/.
See <er>Messiah</er>.]</ety> <def>The Messiah.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I know that <qex>Messias</qex> cometh, which is called Christ.</q>
<rj><qau>John iv. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messidor</ent><br/
\'d8<hw>Mes`si`dor"</hw> <pr>(F. ?; E. ?)</pr>, <pos>n.</pos> <ety>[F.,
fr. L. <ets>messis</ets> harvest.]</ety> <def>The tenth month of the
French republican calendar dating from September 22, 1792. It began June
19, and ended July 18. See <er>Vend<eacute/miaire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messieurs</ent><br/
<hw>Mes"sieurs</hw> <pr>(?; F. ?; 277)</pr>, <pos>n. pl.</pos> <ety>[F.;
pl. of <ets>monsieur</ets>.]</ety> <def>Sirs; gentlemen; -- abbreviated
to <abbr>Messrs.</abbr>, which is used as the plural of
<it>Mr.</it></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messinese</ent><br/
<hw>Mes`si*nese"</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Of or
pertaining to <city>Messina</city>, or its inhabitans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messmate</ent><br/
<hw>Mess"mate`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An associate in a
mess.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Messuage</ent><br/
<hw>Mes"suage</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>mesuage</ets>, <ets>masnage</ets>, LL. <ets>messuagium</ets>,
<ets>mansionaticum</ets>, fr. L. <ets>mansio</ets>, <ets>-onis</ets>, a
staying, remaining, dwelling, fr. <ets>manere</ets>, <ets>mansum</ets>,
to stay, remain, E. <ets>mansion</ets>, <ets>manse</ets>.]</ety>
<fld>(Law)</fld> <def>A dwelling house, with the adjacent buildings and
curtilage, and the adjoining lands appropriated to the use of the
household.</def> <rj><au>Cowell. Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They wedded her to sixty thousand pounds,<br/
To lands in Kent, and <qex>messuages</qex> in York.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mess up</ent><br/
<hw>mess up</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To make
a mess{5} of; to confuse, disorder, or muddle; to muss; to jumble; to
disturb.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To botch{3}; to bungle.</def><br/
[<source>PJC</source>]</p>

<p><ent>mess-up</ent><br/
<hw>mess-up</hw> <pos>n.</pos> <def>Something badly botched or
muddled.</def> <mark>[British]</mark> <br/
<syn><b>Syn. --</b> ballup, balls-up, cockup.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mest</ent><br/
<hw>Mest</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Most.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mestee</ent><br/
<hw>Mes*tee"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mestizo</er>.]</ety> <def>The offspring of a white person and a
quadroon; -- so called in the West Indies.</def> <altsp>[Written also
<asp>mustee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mester</ent><br/
<hw>Mes"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Mister</er>, a trade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mestino</ent><br/
<hw>Mes*ti"no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mestinos</plw> <pr>(<?/)</pr>.</plu> <def>See
<er>Mestizo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mestizo</ent><br/
<hw>Mes*ti"zo</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mestizos</plw> <pr>(#)</pr>.</plu> <ety>[Sp. <ets>mestizo</ets>;
akin to OF. <ets>mestis</ets>, F. <ets>m<eacute/tis</ets>; all fr.
(assumed) LL. <ets>mixtitius</ets>, fr. L. <ets>mixtus</ets> mixed, p.
p. of <ets>miscere</ets> to mix. See <er>Mix</er>, and cf.
<er>Mestee</er>, <er>M<eacute/tif</er>, <er>M<eacute/tis</er>,
<er>Mustee</er>.]</ety> <def>The offspring of an Indian or a negro and a
European or person of European stock.</def> <mark>[Spanish
America]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mestizo wool</b></col>, <cd>wool imported from South
America, and produced by mixed breeds of sheep.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mestling</ent><br/
<hw>Mest"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of brass. See
<er>Maslin</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mesymnicum</ent><br/
\'d8<hw>Me*sym"ni*cum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>me`sos</grk> middle + <?/ a festive song. See
<er>Hymn</er>.]</ety> <fld>(Anc. Poetry)</fld> <def>A repetition at the
end of a stanza.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Met</ent><br/
<hw>Met</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Meet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Met</ent><br/
<hw>Met</hw>, <mark>obs.</mark> <def><pos>imp. & p. p.</pos> of
<er>Mete</er>, to measure.</def> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Met</ent><br/
<hw>Met</hw>, <mark>obs.</mark> <def><pos>p. p.</pos> of <er>Mete</er>,
to dream.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Met-</ent><br/
<ent>Meta-</ent><br/
<mhw>{ <hw>Met"a-</hw> <pr>(?)</pr>, <hw>Met-</hw> <pr>(?)</pr> }</mhw>.
<ety>[Gr. <grk>meta`</grk> between, with, after; akin to AS.
<ets>mid</ets> with, G. <ets>mit</ets>, Goth. <ets>mi<thorn/</ets>, E.
<ets>mid</ets>, in <ets>midwife</ets>.]</ety> <sn>1.</sn> <def>A prefix
meaning <sig>between</sig>, <sig>with</sig>, <sig>after</sig>,
<sig>behind</sig>, <sig>over</sig>, <sig>about</sig>,
<sig>reversely</sig>; <as>as, <ex>meta</ex>chronism, the error of
placing after the correct time; <ex>meta</ex>phor, lit., a carrying
over; <ex>meta</ex>thesis, a placing reversely.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> A prefix denoting: <sd>(a)</sd>
<def><sig>Other</sig>; <sig>duplicate</sig>, <sig>corresponding
to</sig>; <sig>resembling</sig>; hence, <sig>metameric</sig>; <as>as,
<ex>meta</ex>-arabinic, <ex>met</ex>aldehyde</as>.</def> <sd>(b)</sd>
<fld>(Organic Chem.)</fld> <def>That two replacing radicals, in the
benzene nucleus, occupy the <xex>relative positions</xex> of 1 and 3, 2
and 4, 3 and 5, 4 and 6, 5 and 1, or 6 and 2; <as>as,
<ex>meta</ex>cresol, etc.</as> See <er>Ortho-</er>, and
<er>Para-</er>.</def> <sd>(c)</sd> <fld>(Inorganic Chem.)</fld>
<def>Having <sig>less than the highest number</sig> of hydroxyl groups;
-- said of acids; <as>as, <ex>meta</ex>phosphoric acid</as>. Also used
adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A prefix meaning <sig>at a level above</sig>, as in
<ex>meta</ex>physics, <ex>meta</ex>language.</def><br/
[<source>PJC</source>]</p>

<p><ent>Metabasis</ent><br/
<hw>Me*tab"a*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Metabases</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/, fr. <?/
to pass over; <?/ beyond, over + <?/ to go.]</ety> <sn>1.</sn>
<fld>(Rhet.)</fld> <def>A transition from one subject to
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Same as
<er>Metabola</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabole</ent><br/
<ent>Metabola</ent><br/
<mhw>{ \'d8<hw>Me*tab"o*la</hw> <pr>(?)</pr>, \'d8<hw>Me*tab"o*le</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL., from Gr. <?/ change; <?/
beyond + <?/ to throw.]</ety> <fld>(Med.)</fld> <def>A change or
mutation; a change of disease, symptoms, or treatment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabolia</ent><br/
<ent>Metabola</ent><br/
<mhw>{ \'d8<hw>Me*tab"o*la</hw> <pr>(?)</pr>, \'d8<hw>Met`a*bo"li*a</hw>
<pr>(?)</pr>, }</mhw> <pos>n. pl.</pos> <ety>[NL. See 1st
<er>Metabola</er>.]</ety> <fld>(Zool.)</fld> <def>A comprehensive group
of insects, including those that undegro a metamorphosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabolian</ent><br/
<hw>Met`a*bo"li*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Metabola</er>.]</ety> <fld>(Zool.)</fld> <def>An insect which
undergoes a metamorphosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabolic</ent><br/
<hw>Met`a*bol"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/. See
<er>Metabola</er>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>Of or
pertaining to metamorphosis; pertaining to, or involving,
change.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>Of or pertaining to
metabolism; <as>as, <ex>metabolic</ex> activity; <ex>metabolic</ex>
force.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabolisis</ent><br/
\'d8<hw>Met`a*bol"i*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <def>Metabolism.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabolism</ent><br/
<hw>Me*tab"o*lism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.)</fld>
<sn>1.</sn> <def>The act or process, by which living tissues or cells
take up and convert into their own proper substance the nutritive
material brought to them by the blood, or by which they transform their
cell protoplasm into simpler substances, which are fitted either for
excretion or for some special purpose, as in the manufacture of the
digestive enzymes. Hence, metabolism may be either constructive
(<stype>anabolism</stype>), or destructive
(<stype>catabolism</stype>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The series of chemical changes
which take place in an organism, by means of which food is manufactured
and utilized and waste materials are eliminated.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Metabolite</ent><br/
<hw>Me*tab"o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol
Chem.)</fld> <def>A product of metabolism; a substance produced by
metabolic action, as urea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabolize</ent><br/
<hw>Me*tab"o*lize</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<fld>(Physiol.)</fld> <def>To change by a metabolic process. See
<er>Metabolism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metabranchial</ent><br/
<hw>Met`a*bran"chi*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meta-</ets> + <ets>branchial</ets>.]</ety> <fld>(Zool.)</fld>
<def>Of or pertaining to the lobe of the carapace of crabs covering the
posterior branchiae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacarpal</ent><br/
<hw>Met`a*car"pal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the metacarpus.</def> -- <def2><pos>n.</pos>
<def>A metacarpal bone.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacarpus</ent><br/
<hw>Met`a*car"pus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/; <?/ beyond, between + <?/ the wrist.]</ety> <fld>(Anat.)</fld>
<def>That part of the skeleton of the hand or forefoot between the
carpus and phalanges. In man it consists of five bones. See
<xex>Illust.</xex> of <er>Artiodactyla</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacentre</ent><br/
<ent>Metacenter</ent><br/
<mhw>{ <hw>Met`a*cen"ter</hw> <pr>(?)</pr> <it>or</it>
<hw>Met`a*cen"tre</hw> }</mhw>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>center</ets>.]</ety> <fld>(Hydrostatics)</fld>
<def>The point of intersection of a vertical line through the center of
gravity of the fluid displaced by a floating body which is tipped
through a small angle from its position of equilibrium, and the inclined
line which was vertical through the center of gravity of the body when
in equilibrium.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When the metacenter is above the center of gravity, the
position of the body is stable; when below it, unstable.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacetone</ent><br/
<hw>Me*tac"e*tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>met-</ets> + <ets>acetone</ets>.]</ety> <fld>(Chem.)</fld> <def>A
colorless liquid of an agreeable odor, <chform>C6H10O</chform>, obtained
by distilling a mixture of sugar and lime; -- so called because formerly
regarded as a polymeric modification of acetone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metachloral</ent><br/
<hw>Met`a*chlo"ral</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>chloral</ets>.]</ety> <fld>(Chem.)</fld> <def>A
white, amorphous, insoluble substance regarded as a polymeric variety of
chloral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metachronism</ent><br/
<hw>Me*tach"ro*nism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/,
after the time, happening afterward; <?/ beyond + <?/ time: cf. F.
<ets>m<eacute/tachronisme</ets>.]</ety> <def>An error committed in
chronology by placing an event after its real time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metachrosis</ent><br/
\'d8<hw>Met`a*chro"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <?/ beyond + <?/ a coloring.]</ety> <fld>(Biol.)</fld> <def>The
power of changing color at will by the expansion of special pigment
cells, under nerve influence, as seen in many reptiles, fishes,
etc.</def> <rj><au>Cope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacinnabarite</ent><br/
<hw>Met`a*cin"na*bar*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>cinnabar</ets>.]</ety> <fld>(Min.)</fld>
<def>Sulphide of mercury in isometric form and black in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacism</ent><br/
<hw>Met"a*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metacismus</ets>, Gr. <?/ fondness for the letter <mu/.]</ety>
<def>A defect in pronouncing the letter <xex>m</xex>, or a too frequent
use of it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacrolein</ent><br/
<hw>Met`a*cro"le*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>met-</ets> + <ets>acrolein</ets>.]</ety> <fld>(Chem.)</fld> <def>A
polymeric modification of acrolein obtained by heating it with caustic
potash. It is a crystalline substance having an aromatic odor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metacromion</ent><br/
\'d8<hw>Met`a*cro"mi*on</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <fld>(Anat.)</fld> <def>A process projecting backward
and downward from the acromion of the scapula of some mammals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metadiscoidal</ent><br/
<hw>Met`a*dis*coid"al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Meta-</ets> + <ets>discoidal</ets>.]</ety> <fld>(Anat.)</fld>
<def>Discoidal by derivation; -- applied especially to the placenta of
man and apes, because it is supposed to have been derived from a
diffused placenta.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagastric</ent><br/
<hw>Met`a*gas"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>gastric</ets>.]</ety> <fld>(Zool.)</fld> <def>Of
or pertaining to the two posterior gastric lobes of the carapace of
crabs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metage</ent><br/
<hw>Met"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[From
<er>Mete</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>Measurement,
especially of coal.</def> <rj><au>De Foe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Charge for, or price of, measuring.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagenesis</ent><br/
<hw>Met`a*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>genesis</ets>.]</ety> <sn>1.</sn>
<fld>(Biol.)</fld> <def>The change of form which one animal species
undergoes in a series of successively produced individuals, extending
from the one developed from the ovum to the final perfected individual.
Hence, metagenesis involves the production of sexual individuals by
nonsexual means, either directly or through intervening sexless
generations. Opposed to <contr>monogenesis</contr>. See <cref>Alternate
generation</cref>, under <er>Generation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Alternation of sexual and asexual
or gemmiparous generations; -- in distinction from
<contr>heterogamy</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 917 --></p>

<p><ent>Metagenetic</ent><br/
<hw>Met`a*ge*net"ic</hw>
<pr>(m<ecr/t`<adot/*j<esl/*n<ecr/t"<icr/k)</pr>, <pos>a.</pos>
<fld>(Biol.)</fld> <def>Of or pertaining to metagenesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagenic</ent><br/
<hw>Met`a*gen"ic</hw> <pr>(m<ecr/t`<adot/*j<esl/n"<icr/k)</pr>,
<pos>a.</pos> <fld>(Biol.)</fld> <def>Metagenetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagnathous</ent><br/
<hw>Me*tag"na*thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + Gr. <grk>gna`qos</grk> the jaw.]</ety>
<fld>(Zool.)</fld> <def>Cross-billed; -- said of certain birds, as the
crossbill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagrammatism</ent><br/
<hw>Met`a*gram"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Anagrammatism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagraphic</ent><br/
<hw>Met`a*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>By or
pertaining to metagraphy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metagraphy</ent><br/
<hw>Me*tag"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>-graphy</ets>.]</ety> <def>The art or act of
rendering the letters of the alphabet of one language into the possible
equivalents of another; transliteration.</def>
<rj><au>Stormonth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metal</ent><br/
<hw>Met"al</hw> <pr>(? <or/ ?; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/tal</ets>, L. <ets>metallum</ets> metal, mine, Gr. <?/
mine; cf. Gr. <?/ to search after. Cf. <er>Mettle</er>,
<er>Medal</er>.]</ety> <sn>1.</sn> <fld>(Chem.)</fld> <def>An elementary
substance, as sodium, calcium, or copper, whose oxide or hydroxide has
basic rather than acid properties, as contrasted with the nonmetals, or
metalloids. No sharp line can be drawn between the metals and nonmetals,
and certain elements partake of both acid and basic qualities, as
chromium, manganese, bismuth, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Popularly, the name is applied to certain hard, fusible
metals, as gold, silver, copper, iron, tin, lead, zinc, nickel, etc.,
and also to the mixed metals, or metallic alloys, as brass, bronze,
steel, bell metal, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ore from which a metal is derived; -- so called by
miners.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mine from which ores are taken.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Slaves . . . and persons condemned to <qex>metals</qex>.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The substance of which anything is made; material;
hence, constitutional disposition; character; temper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not till God make men of some other <qex>metal</qex> than
earth.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Courage; spirit; mettle. See <er>Mettle</er>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The allusion is to the temper of the metal of a sword
blade.</note> <rj><au>Skeat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The broken stone used in macadamizing roads and
ballasting railroads.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The effective power or caliber of guns carried by a
vessel of war.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Glass in a state of fusion.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <pluf>pl.</pluf> <def>The rails of a railroad.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Base metal</b></col> <fld>(Chem.)</fld>, <cd>any one of
the metals, as iron, lead, etc., which are readily tarnished or
oxidized, in contrast with the noble metals. In general, a metal of
small value, as compared with gold or silver.</cd> -- <col><b>Fusible
metal</b></col> <fld>(Metal.)</fld>, <cd>a very fusible alloy, usually
consisting of bismuth with lead, tin, or cadmium.</cd> -- <col><b>Heavy
metals</b></col> <fld>(Chem.)</fld>, <cd>the metallic elements not
included in the groups of the alkalies, alkaline earths, or the earths;
specifically, the heavy metals, as gold, mercury, platinum, lead,
silver, etc.</cd> -- <col><b>Light metals</b></col> <fld>(Chem.)</fld>,
<cd>the metallic elements of the alkali and alkaline earth groups, as
sodium, lithium, calcium, magnesium, etc.; also, sometimes, the metals
of the earths, as aluminium.</cd> -- <col><b>Muntz metal</b></col>,
<cd>an alloy for sheathing and other purposes, consisting of about sixty
per cent of copper, and forty of zinc. Sometimes a little lead is added.
It is named from the inventor.</cd> -- <col><b>Prince's metal</b></col>
<fld>(Old Chem.)</fld>, <cd>an alloy resembling brass, consisting of
three parts of copper to one of zinc; -- also called <altname>Prince
Rupert's metal</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metal</ent><br/
<hw>Met"al</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Metaled</conjf> <pr>(? <or/ ?)</pr> or <conjf>Metalled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Metaling</conjf> or
<conjf>Metalling</conjf>.]</vmorph> <def>To cover with metal; <as>as, to
<ex>metal</ex> a ship's bottom; to <ex>metal</ex> a road.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalammonium</ent><br/
<hw>Met`al*am*mo"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Metal</ets> + <ets>ammonium</ets>.]</ety> <fld>(Chem.)</fld>
<def>A hypothetical radical derived from ammonium by the substitution of
metallic atoms in place of hydrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metalanguage</ent><br/
<hw>metalanguage</hw> <pos>n.</pos> <def>Any language that can be used
to describe another language or system of symbols.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Metalbumin</ent><br/
<hw>Met`al*bu"min</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>met-</ets> + <ets>albumin</ets>.]</ety> <fld>(Physiol. Chem.)</fld>
<def>A form of albumin found in ascitic and certain serous fluids. It is
sometimes regarded as a mixture of albumin and mucin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaldehyde</ent><br/
<hw>Me*tal"de*hyde</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>met-</ets> + <ets>aldehyde</ets>.]</ety> <fld>(Chem.)</fld> <def>A
white crystalline substance isomeric with, and obtained from, acetic
aldehyde by polymerization, and reconvertible into the same.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalepsis</ent><br/
\'d8<hw>Met`a*lep"sis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Metalepses</plw> <pr>(#)</pr>.</plu> <ety>[L.,
fr. Gr. <?/ participation, alteration, fr. <?/ to partake, to take in
exchange; <?/ beyond + <?/ to take.]</ety> <fld>(Rhet.)</fld> <def>The
continuation of a trope in one word through a succession of
significations, or the union of two or more tropes of a different kind
in one word.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalepsy</ent><br/
<hw>Met"a*lep`sy</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Exchange; replacement; substitution; metathesis.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaleptic</ent><br/
<hw>Met`a*lep"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/]</ety>
<sn>1.</sn> <def>Of or pertaining to a metalepsis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Transverse; <as>as, the <ex>metaleptic</ex> motion
of a muscle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>Of, pertaining to, concerned in,
or occurring by, metalepsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaleptical</ent><br/
<hw>Met`a*lep"tic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Metaleptic.</def> -- <wordforms><wf>Met`a*lep"tic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallic</ent><br/
<hw>Me*tal"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>metallicus</ets>, fr. <ets>metallum</ets>: cf. F.
<ets>m<eacute/tallique</ets>. See <er>Metal</er>.]</ety> <sn>1.</sn>
<def>Of or pertaining to a metal; of the nature of metal; resembling
metal; <as>as, a <ex>metallic</ex> appearance; a <ex>metallic</ex>
alloy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Of, pertaining to, or
characterized by, the essential and implied properties of a metal, as
contrasted with a nonmetal or metalloid; conductive of electricity;
basic; forming positive ions in solution; antacid.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Metallic iron</b></col>, <cd>iron in the state of the
metal, as distinquished from its ores, as magnetic iron.</cd> --
<col><b>Metallic paper</b></col>, <cd>paper covered with a thin solution
of lime, whiting, and size. When written upon with a pewter or brass
pencil, the lines can hardly be effaced.</cd> -- <col><b>Metallic
tinking</b></col> <fld>(Med.)</fld>, <cd>a sound heard in the chest,
when a cavity communicating with the air passages contains both air and
liquid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallical</ent><br/
<hw>Me*tal"lic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Metallic</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallicly</ent><br/
<hw>Me*tal"lic*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a metallic
manner; by metallic means.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallifacture</ent><br/
<hw>Me*tal`li*fac"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + <ets>facere</ets>, <ets>factum</ets>, to
make.]</ety> <def>The production and working or manufacture of
metals.</def> <mark>[R.]</mark> <rj><au>R. Park.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalliferous</ent><br/
<hw>Met`al*lif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>metallifer</ets>; <ets>metallum</ets> metal + <ets>ferre</ets> to
bear: cf. F. <ets>m<eacute/tallif<egrave/re</ets>.]</ety> <def>Producing
metals; yielding metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalliform</ent><br/
<hw>Me*tal"li*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>metallum</ets> metal + <ets>-form</ets>: cf. F.
<ets>m<eacute/talliforme</ets>.]</ety> <def>Having the form or structure
of a metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalline</ent><br/
<hw>Met"al*line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/tallin</ets>.]</ety> <fld>(Chem.)</fld> <sd>(a)</sd>
<def>Pertaining to, or resembling, a metal; metallic; <as>as,
<ex>metalline</ex> properties</as>.</def> <sd>(b)</sd> <def>Impregnated
with metallic salts; chalybeate; <as>as, <ex>metalline</ex>
water</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalline</ent><br/
<hw>Met"al*line</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A substance of variable composition, but
resembling a soft, dark-colored metal, used in the bearings of machines
for obviating friction, and as a substitute for lubricants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallist</ent><br/
<hw>Met"al*list</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A worker in
metals, or one skilled in metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallization</ent><br/
<hw>Met`al*li*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/tallisation</ets>.]</ety> <def>The act or process of
metallizing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallize</ent><br/
<hw>Met"al*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Metallized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Metallizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>m<eacute/talliser</ets>.]</ety> <def>To impart metallic properties
to; to impregnate with a metal.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallochrome</ent><br/
<hw>Me*tal"lo*chrome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Metallochromy</er>.]</ety> <def>A coloring produced by the
deposition of some metallic compound; specifically, the prismatic tints
produced by depositing a film of peroxide of lead on polished steel by
electricity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallochromy</ent><br/
<hw>Me*tal"lo*chro`my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + Gr. <?/ color.]</ety> <def>The art or
process of coloring metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallograph</ent><br/
<hw>Me*tal"lo*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + <ets>-graph</ets>.]</ety> <def>A print made
by metallography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallographic</ent><br/
<hw>Me*tal`lo*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or by means of, metallography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallographist</ent><br/
<hw>Met`al*log"ra*phist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
writes on the subject of metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallography</ent><br/
<hw>Met`al*log"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + <ets>-graphy</ets>: cf. F.
<ets>m<eacute/tallographie</ets>.]</ety> <sn>1.</sn> <def>The science or
art of metals and metal working; also, a treatise on metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A method of transferring impressions of the grain of
wood to metallic surfaces by chemical action.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A substitute for lithography, in which metallic
plates are used instead of stone.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalloid</ent><br/
<hw>Met"al*loid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + <ets>-oid</ets>: cf. F.
<ets>m<eacute/tallo<ium/de</ets>.]</ety> <sd>(a)</sd> <def>Formerly, the
metallic base of a fixed alkali, or alkaline earth; -- applied by
<person>Sir Humphrey Davy</person> to sodium, potassium, and some other
metallic substances whose metallic character was supposed to be not well
defined.</def> <sd>(b)</sd> <def>Now, one of several elementary
substances which in the free state are unlike metals, and whose
compounds possess or produce acid, rather than basic, properties; a
nonmetal; <as>as, boron, carbon, phosphorus, nitrogen, oxygen, sulphur,
chlorine, bromine, etc.</as>, are <xex>metalloids</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalloid</ent><br/
<hw>Met"al*loid</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having the
appearance of a metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Having the properties of a
nonmetal; nonmetallic; acid; negative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalloidal</ent><br/
<hw>Met`al*loid"al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Metalloid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallophone</ent><br/
<hw>Me*tal"lo*phone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + Gr. <?/ sound.]</ety> <fld>(Music)</fld>
<sd>(a)</sd> <def>An instrument like a pianoforte, but having metal bars
instead of strings.</def> <sd>(b)</sd> <def>An instrument like the
xylophone, but having metallic instead of wooden bars.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Metallorganic</ent><br/
<hw>Met`al*lor*gan"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Metalorganic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallotherapy</ent><br/
<hw>Me*tal`lo*ther"a*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metallum</ets> metal + E. <ets>therapy</ets>.]</ety>
<fld>(Med.)</fld> <def>Treatment of disease by applying metallic plates
to the surface of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallurgical</ent><br/
<ent>Metallurgic</ent><br/
<mhw>{ <hw>Met`al*lur"gic</hw> <pr>(?)</pr>, <hw>Met`al*lur"gic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/tallurgique</ets>.]</ety> <def>Of or pertaining to
metallurgy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallurgist</ent><br/
<hw>Met"al*lur`gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/tallurgiste</ets>.]</ety> <def>One who works in metals, or
prepares them for use; one who is skilled in metallurgy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metallurgy</ent><br/
<hw>Met"al*lur`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/tallurgie</ets>, fr. L. <ets>metallum</ets> metal, Gr. <?/
a mine + the root of <?/ work. See <er>Metal</er>, and
<er>Work</er>.]</ety> <def>The art of working metals, comprehending the
whole process of separating them from other matters in the ore,
smelting, refining, and parting them; sometimes, in a narrower sense,
only the process of extracting metals from their ores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalman</ent><br/
<hw>Met"al*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Metalmen</plw> <pr>(<?/)</pr>.</plu> <def>A worker in
metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metalogical</ent><br/
<hw>Met`a*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Beyond the
scope or province of logic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metalorganic</ent><br/
<hw>met`al*or*gan"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Metal</ets>, L. <ets>metallum</ets> + E.
<ets>organic</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
denoting, any one of a series of compounds of certain metallic elements
with organic radicals; as, zinc methyl, sodium ethyl, etc.; now usually
<altname>organometallic</altname>.</def> <altsp>[Written also
<asp>metallorganic</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamer</ent><br/
<hw>Met"a*mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Metamere</er>.]</ety> <fld>(Chem.)</fld> <def>Any one of several
metameric forms of the same substance, or of different substances having
the same composition; <as>as, xylene has three <ex>metamers</ex>, viz.,
orthoxylene, metaxylene, and paraxylene</as>; an isomer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamere</ent><br/
<hw>Met"a*mere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>-mere</ets>.]</ety> <fld>(Biol.)</fld> <def>One
of successive or homodynamous parts in animals and plants; one of a
series of similar parts that follow one another in a vertebrate or
articulate animal, as in an earthworm; a segment; a somite. See
<xex>Illust.</xex> of <er>Loeven's larva</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metameric</ent><br/
<hw>Met`a*mer"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + Gr. <?/ part.]</ety> <sn>1.</sn> <fld>(Chem.)</fld>
<def>Having the same molecular formula, but possessing a different
bonding structure and different properties; <as>as, methyl ether and
ethyl alcohol are <ex>metameric</ex> compounds</as>. See
<er>Isomeric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The existence of metameric compounds is due to different
arrangements of the same atoms in the molecule.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Of or pertaining to a metamere or
its formation; <as>as, <ex>metameric</ex> segmentation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamerically</ent><br/
<hw>Met`a*mer"ic*al*ly</hw>, <pos>adv.</pos> <def>In a metameric
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamerism</ent><br/
<hw>Me*tam"er*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Biol.)</fld> <def>The symmetry of a metameric structure; serial
symmetry; the state of being made up of metameres.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The state or quality of being
metameric; isomerism due to different bonding patterns in two substances
having the same molecular formula. Contrasted with
<contr>steroisomerism</contr> or <contr>optical isomerism</contr>. Also,
the relation or condition of metameric compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphic</ent><br/
<hw>Met`a*mor"phic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Metamorphosis</er>.]</ety> <sn>1.</sn> <def>Subject to change;
changeable; variable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Causing a change of structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>Pertaining to, produced by, or
exhibiting, certain changes which minerals or rocks may have undergone
since their original deposition; -- especially applied to the
recrystallization which sedimentary rocks have undergone through the
influence of heat and pressure, after which they are called
<xex>metamorphic</xex> rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphism</ent><br/
<hw>Met`a*mor"phism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Geol.)</fld>
<def>The state or quality of being metamorphic; the process by which the
material of rock masses has been more or less recrystallized by heat,
pressure, etc., as in the change of sedimentary limestone to
marble.</def> <rj><au>Murchison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphist</ent><br/
<hw>Met`a*mor"phist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.)</fld>
<def>One who believes that the body of Christ was merged into the Deity
when he ascended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphize</ent><br/
<hw>Met`a*mor"phize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
metamorphose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphose</ent><br/
<hw>Met`a*mor"phose</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Metamorphosed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Metamorphosing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>m<eacute/tamorphoser</ets>.]</ety> <def>To change into a different
form; to transform; to transmute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And earth was <qex>metamorphosed</qex> into man.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphose</ent><br/
<hw>Met`a*mor"phose</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/tamorphose</ets>. See <er>Metamorphosis</er>.]</ety>
<def>Same as <er>Metamorphosis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphoser</ent><br/
<hw>Met`a*mor"pho*ser</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
metamorphoses.</def> <mark>[R.]</mark> <rj><au>Gascoigne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphosic</ent><br/
<hw>Met`a*mor"pho*sic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Changing the
form; transforming.</def> <mark>[R.]</mark>
<rj><au>Pownall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metamorphosis</ent><br/
<hw>Met`a*mor"pho*sis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Metamorphoses</plw> <pr>(#)</pr>.</plu> <ety>[L.,
fr. Gr. <?/, fr. <?/ to be transformed; <grk>meta`</grk> beyond, over +
<grk>morfh`</grk> form.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Change of form, or structure;
transformation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>A change in the form or function
of a living organism, by a natural process of growth or development;
<as>as, the <ex>metamorphosis</ex> of the yolk into the embryo, of a
tadpole into a frog, or of a bud into a blossom</as>. Especially, that
form of sexual reproduction in which an embryo undergoes a series of
marked changes of external form, as the chrysalis stage, pupa stage,
etc., in insects. In these intermediate stages sexual reproduction is
usually impossible, but they ultimately pass into final and sexually
developed forms, from the union of which organisms are produced which
pass through the same cycle of changes. See
<er>Transformation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physiol.)</fld> <def>The change of material of one
kind into another through the agency of the living organism;
metabolism.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Vegetable metamorphosis</b></col> <fld>(Bot.)</fld>,
<cd>the doctrine that flowers are homologous with leaf buds, and that
the floral organs are transformed leaves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metanauplius</ent><br/
\'d8<hw>Met`a*nau"pli*us</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Meta-</er>, and <er>Nauplius</er>.]</ety> <fld>(Zool.)</fld> <def>A
larval crustacean in a stage following the nauplius, and having about
seven pairs of appendages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metanephritic</ent><br/
<hw>Met`a*ne*phrit"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to the metanephros.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metanephros</ent><br/
\'d8<hw>Met`a*neph"ros</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ behind + <?/ kidney.]</ety> <fld>(Anat.)</fld> <def>The most
posterior of the three pairs of embryonic renal organs developed in many
vertebrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metanotum</ent><br/
\'d8<hw>Met`a*no"tum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ behind + <?/ back.]</ety> <fld>(Zool.)</fld> <def>The dorsal portion
of the metaphorax of insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metantimonate</ent><br/
<hw>Met`an*ti*mo"nate</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A salt of metantimonic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metantimonic</ent><br/
<hw>Met`an*ti*mon"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>met-</ets> + <ets>antimonic</ets>.]</ety> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>Pertaining to, or designating, an acid (formerly
called <altname>antimonic acid</altname>) analogous to metaphosphoric
acid, and obtained as a white amorphous insoluble substance,
(<chform>HSbO3</chform>).</def> <sd>(b)</sd> <def>Formerly, designating
an acid, which is now properly called <altname>pyroantimonic
acid</altname>, and analogous to <contr>pyrophosphoric
acid</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapectic</ent><br/
<hw>Met`a*pec"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>pectic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a supposed acid obtained from
pectin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapectin</ent><br/
<hw>Met`a*pec"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A substance obtained from, and resembling, pectin, and occurring in
overripe fruits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapeptone</ent><br/
<hw>Met`a*pep"tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>peptone</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>An intermediate product formed in the gastric
digestion of albuminous matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metaphor</ent><br/
<hw>met"a*phor`</hw> <pr>(m<ecr/t"<adot/*f<ocir/r` <it>or</it>
m<ecr/t"<adot/*f<etil/r)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/taphore</ets>, L. <ets>metaphora</ets>, fr. Gr.
<grk>metafora`</grk>, fr. <grk>metafe`rein</grk> to carry over,
transfer; <grk>meta`</grk> beyond, over + <grk>fe`rein</grk> to bring,
bear.]</ety> <fld>(Rhet.)</fld> <def>The transference of the relation
between one set of objects to another set for the purpose of brief
explanation; a compressed simile; <it>e. g.</it>, the ship plows the
sea.</def> <au>Abbott & Seeley.</au> <ldquo/All the world's a
stage.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The statement, <ldquo/that man is a fox,<rdquo/ is a
metaphor; but <ldquo/that man is like a fox,<rdquo/ is a simile,
similitude, or comparison.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphorical</ent><br/
<ent>Metaphoric</ent><br/
<mhw>{ <hw>Met`a*phor"ic</hw> <pr>(?)</pr>, <hw>Met`a*phor"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/: cf. F.
<ets>m<eacute/taphorique</ets>.]</ety> <def>Of or pertaining to
metaphor; comprising a metaphor; not literal; figurative; tropical;
<as>as, a <ex>metaphorical</ex> expression; a <ex>metaphorical</ex>
sense.</as></def> -- <wordforms><wf>Met`a*phor"ic*al*ly</wf>,
<pos>adv.</pos> -- <wf>Met`a*phor"ic*al*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphorist</ent><br/
<hw>Met"a*phor*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes
metaphors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphosphate</ent><br/
<hw>Met`a*phos"phate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of metaphosphoric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metaphosphoric</ent><br/
<hw>met`a*phos*phor"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>phosphoric</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a monobasic acid,
<chform>HPO3</chform>, analogous to nitric acid, and, by heating
phosphoric acid, obtained as a crystalline substance, commonly called
<altname>glacial phosphoric acid</altname>. Compare the tribasic
<contr>orthophosphoric acid</contr>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Metaphrase</ent><br/
<hw>Met"a*phrase</hw> <pr>(m<ecr/t"<adot/*fr<amac/z)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>meta`frasis</grk>, from <grk>metafra`zein</grk> to
paraphrase; <grk>meta`</grk> beyond, over + <grk>fra`zein</grk> to
speak: cf. F. <ets>m<eacute/taphrase</ets>.]</ety> <sn>1.</sn> <def>A
verbal translation; a version or translation from one language into
another, word for word; a literal translation; -- opposed to
<contr>paraphrase</contr>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An answering phrase; repartee.</def> <rj><au>Mrs.
Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 918 --></p>

<p><ent>metaphrased</ent><br/
<hw>met"a*phrased</hw> <pr>(m<ecr/t"<adot/*fr<amac/zd)</pr>,
<pos>a.</pos> <def>Translated literally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphrasis</ent><br/
<hw>Me*taph"ra*sis</hw> <pr>(m<esl/*t<acr/f"r<adot/*s<icr/s)</pr>,
<pos>n.</pos> <ety>[NL. See <er>Metaphrase</er>.]</ety>
<def>Metaphrase.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphrast</ent><br/
<hw>Met"a*phrast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf. F.
<ets>m<eacute/taphraste</ets>.]</ety> <def>A literal
translator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphrastical</ent><br/
<ent>Metaphrastic</ent><br/
<mhw>{ <hw>Met`a*phras"tic</hw> <pr>(?)</pr>,
<hw>Met`a*phras"tic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Gr. <?/.]</ety> <def>Close, or literal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysic</ent><br/
<hw>Met`a*phys"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/taphysique</ets>.]</ety> <def>See
<er>Metaphysics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysic</ent><br/
<hw>Met`a*phys"ic</hw>, <pos>a.</pos> <def>Metaphysical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysical</ent><br/
<hw>Met`a*phys"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/taphysique</ets>. See <er>Metaphysics</er>.]</ety>
<sn>1.</sn> <def>Of or pertaining to metaphysics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>According to rules or principles of metaphysics;
<as>as, <ex>metaphysical</ex> reasoning</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Preternatural or supernatural.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The golden round<br/
Which fate and metaphysical aid doth seem<br/
To have thee crowned withal.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysically</ent><br/
<hw>Met`a*phys"ic*al*ly</hw>, <pos>adv.</pos> <def>In the manner of
metaphysical science, or of a metaphysician.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysician</ent><br/
<hw>Met`a*phy*si"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/taphysicien</ets>.]</ety> <def>One who is versed in
metaphysics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysics</ent><br/
<hw>Met`a*phys"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ <?/
<?/ after those things which relate to external nature, after physics,
fr. <?/ beyond, after + <?/ relating to external nature, natural,
physical, fr. <?/ nature: cf. F. <ets>m<eacute/taphysique</ets>. See
<er>Physics</er>. The term was first used by the followers of Aristotle
as a name for that part of his writings which came <ets>after</ets>, or
followed, the part which treated of <ets>physics</ets>.]</ety>
<sn>1.</sn> <def>The science of real as distinguished from phenomenal
being; ontology; also, the science of being, with reference to its
abstract and universal conditions, as distinguished from the science of
determined or concrete being; the science of the conceptions and
relations which are necessarily implied as true of every kind of being;
philosophy in general; first principles, or the science of first
principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Metaphysics</xex> is distinguished as
<xex>general</xex> and <xex>special</xex>. <stype>General
metaphysics</stype> is the science of all being as being. <stype>Special
metaphysics</stype> is the science of one kind of being; as, the
<xex>metaphysics</xex> of chemistry, of morals, or of politics.
According to Kant, a systematic exposition of those notions and truths,
the knowledge of which is altogether independent of experience, would
constitute the science of metaphysics.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Commonly, in the schools, called <qex>metaphysics</qex>, as being
part of the philosophy of Aristotle, which hath that for title; but it
is in another sense: for there it signifieth as much as <ldquo/books
written or placed after his natural philosophy.<rdquo/ But the schools
take them for <ldquo/books of supernatural philosophy;<rdquo/ for the
word <qex>metaphysic</qex> will bear both these senses.</q>
<rj><qau>Hobbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now the science conversant about all such inferences of unknown
being from its known manifestations, is called ontology, or
<qex>metaphysics</qex> proper.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Metaphysics</qex> are [is] the science which determines what
can and what can not be known of being, and the laws of being, a
priori.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>The scientific knowledge of
mental phenomena; mental philosophy; psychology.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Metaphysics</qex>, in whatever latitude the term be taken, is
a science or complement of sciences exclusively occupied with mind.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whether, after all,<br/
A larger <qex>metaphysics</qex> might not help<br/
Our physics.</q> <rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaphysis</ent><br/
\'d8<hw>Me*taph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ after + <?/ nature.]</ety> <def>Change of form;
transformation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaplasm</ent><br/
<hw>Met"a*plasm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metaplasmus</ets>, Gr. <?/; <?/ beyond, over + <?/ to mold: cf. F.
<ets>m<eacute/taplasme</ets>.]</ety> <fld>(Gram.)</fld> <def>A change in
the letters or syllables of a word.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaplast</ent><br/
<hw>Met"a*plast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Metaplasm</er>.]</ety> <fld>(Gram.)</fld> <def>A word having more
than one form of the root.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapode</ent><br/
<hw>Met"a*pode</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>metapodium</ets>, from Gr. <?/ behind + <?/, dim. of
<grk>poy`s</grk>, <grk>podo`s</grk>, foot.]</ety> <fld>(Zool.)</fld>
<def>The posterior division of the foot in the Gastropoda and
Pteropoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapodial</ent><br/
<hw>Met`a*po"di*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the metapodialia, or to the parts of the limbs
to which they belong.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapodiale</ent><br/
\'d8<hw>Met`a*po`di*a"le</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Metapodialia</plw> <pr>(#)</pr>.</plu> <ety>[NL.
See <er>Metapode</er>.]</ety> <fld>(Anat.)</fld> <def>One of the bones
of either the metacarpus or metatarsus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapodium</ent><br/
\'d8<hw>Met`a*po"di*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Metapodia</plw> <pr>(#)</pr>.</plu>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Metapode</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapophysis</ent><br/
\'d8<hw>Met`a*poph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Metapophyses</plw> <pr>(#)</pr>.</plu> <ety>[NL.
See <er>Meta-</er>, and <er>Apophysis</er>.]</ety> <fld>(Anat.)</fld>
<def>A tubercle projecting from the anterior articular processes of some
vertebrae; a mammillary process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metapterygium</ent><br/
\'d8<hw>Me*tap`te*ryg"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <?/ after + <?/ fin.]</ety> <fld>(Anat.)</fld> <def>The
posterior of the three principal basal cartilages in the fins of
fishes.</def> -- <wordforms><wf>Me*tap`ter*yg"i*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metasilicate</ent><br/
<hw>Met`a*sil"i*cate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of metasilicic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metasilicic</ent><br/
<hw>Met`a*si*lic"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>silicic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Designating an acid derived from silicic acid by the removal of
water; of or pertaining to such an acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The salts of metasilicic acid are often called
<xex>bisilicates</xex>, in mineralogy, as Wollastonite
(<chform>CaSiO3</chform>).</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Metasilicic acid</b></col> <fld>(Chem.)</fld>, <cd>a
gelatinous substance, or white amorphous powder, analogous to carbonic
acid, and forming many stable salts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metasomatism</ent><br/
<hw>Met`a*so"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + Gr. <?/, <?/, body.]</ety> <fld>(Geol.)</fld> <def>An
alteration in a mineral or rock mass when involving a chemical change of
the substance, as of chrysolite to serpentine; -- opposed to ordinary
<xex>metamorphism</xex>, as implying simply a recrystallization.</def>
-- <wordforms><wf>Met`a*so*mat"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metasome</ent><br/
<hw>Met"a*some</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>-some</ets> body.]</ety> <fld>(Zool.)</fld>
<def>One of the component segments of the body of an animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metastannate</ent><br/
<hw>Met`a*stan"nate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of metastannic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metastannic</ent><br/
<hw>Met`a*stan"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a compound of tin (metastannic
acid), obtained, as an isomeric modification of stannic acid, in the
form of a white amorphous substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metastasis</ent><br/
<hw>Me*tas"ta*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Metastases</plw> <pr>(#)</pr>.</plu> <ety>[L., transition, fr. Gr.
<?/, fr. <?/ to place in another way; <?/ after + <?/ to place.]</ety>
<sn>1.</sn> <fld>(Theol.)</fld> <def>A spiritual change, as during
baptism.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A change in the location of a
disease, as from one part to another.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Especially:</specif> <def>The migration of
cancerous or malignant cells from the site of their origin to other
parts of the body. Such cells may migrate to multiple new locations,
making therapy more difficult and often leading to death.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Physiol.)</fld> <def>The act or process by which
matter is taken up by cells or tissues and is transformed into other
matter; in plants, the act or process by which are produced all of those
chemical changes in the constituents of the plant which are not
accompanied by a production of organic matter; metabolism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metastasize</ent><br/
<hw>metastasize</hw> <pos>v.</pos> <def>to spread from one part of the
body to other parts, and grow there; to spread by metastasis{3}; -- said
of cancer cells.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Metastatic</ent><br/
<hw>Met`a*stat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining
to, or caused by, metastasis; <as>as, a <ex>metastatic</ex> abscess; the
<ex>metastatic</ex> processes of growth; a <ex>metastatic</ex>
tumor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metasternal</ent><br/
<hw>Met`a*ster"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the metasternum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metasternum</ent><br/
\'d8<hw>Met`a*ster"num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>sternum</ets>.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <def>The most posterior element of the sternum; the
ensiform process; xiphisternum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The ventral plate of the third or
last segment of the thorax of insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metastome</ent><br/
<ent>Metastoma</ent><br/
<mhw>{ \'d8<hw>Me*tas"to*ma</hw> <pr>(?)</pr>, <hw>Met"a*stome</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>metastoma</ets>, from
Gr. <grk>meta`</grk> behind + <grk>sto`ma</grk> mouth.]</ety>
<fld>(Zool.)</fld> <def>A median elevation behind the mouth in the
arthropods.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metatarsal</ent><br/
<hw>Met`a*tar"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the metatarsus.</def> -- <def2><pos>n.</pos>
<def>A metatarsal bone.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metatarse</ent><br/
<hw>Met"a*tarse</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>Metatarsus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metatarsus</ent><br/
<hw>Met`a*tar"sus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Metatarsi</plw> <pr>(#)</pr>.</plu> <ety>[NL. See <er>Meta-</er>,
and <er>Tarsus</er>.]</ety> <fld>(Anat.)</fld> <def>That part of the
skeleton of the hind or lower limb between the tarsus and phalanges;
metatarse. It consists, in the human foot, of five bones. See
<xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metate</ent><br/
\'d8<hw>me*ta"te</hw> <pr>(m<asl/*t<aum/"t<asl/)</pr>, <pos>n.</pos>
<ety>[Sp., fr. Mex. <ets>metlatl</ets>.]</ety> <def>A flat or somewhat
hollowed stone upon which grain or other food is ground, by means of a
smaller stone or pestle.</def> <mark>[Southwestern U. S. & Sp.
Amer.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Metatheria</ent><br/
<hw>Metatheria</hw> <pos>prop. n.</pos> <def>A subclass of pouched
animals.</def><br/
<syn><b>Syn. --</b> subclass <subclass>Metatheria</subclass>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>metatherian</ent><br/
<hw>metatherian</hw> <pos>n.</pos> <def>Any of a group of primitive
pouched mammals found mainly in Australia and the Americas.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Metathesis</ent><br/
<hw>Me*tath"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Metatheses</plw> <pr>(<?/)</pr>.</plu> <ety>[L., fr. Gr.
<grk>meta`qesis</grk>, fr. <grk>metatiqe`nai</grk> to place differently,
to transpose; <grk>meta`</grk> beyond, over + <grk>tiqe`nai</grk> to
place, set. See <er>Thesis</er>.]</ety> <sn>1.</sn> <fld>(Gram.)</fld>
<def>Transposition, as of the letters or syllables of a word; <as>as,
<xex>pistris</xex> for <xex>pristis</xex>; <xex>meagre</xex> for
<xex>meager</xex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A mere change in place of a morbid
substance, without removal from the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>The act, process, or result of
exchange, substitution, or replacement of atoms and radicals; <as>thus,
by <ex>metathesis</ex> an acid gives up all or part of its hydrogen,
takes on an equivalent amount of a metal or base, and forms a
salt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metathetical</ent><br/
<ent>Metathetic</ent><br/
<mhw>{ <hw>Met`a*thet"ic</hw> <pr>(?)</pr>, <hw>Met`a*thet"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to
metathesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metathoracic</ent><br/
<hw>Met`a*tho*rac"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the metathorax.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metathorax</ent><br/
<hw>Met`a*tho"rax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf. F.
<ets>m<eacute/tathorax</ets>. See <er>Meta-</er>, and
<er>Thorax</er>.]</ety> <fld>(Zool.)</fld> <def>The last or posterior
segment of the thorax in insects. See <xex>Illust.</xex> of
<er>Coleoptera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metatitanic</ent><br/
<hw>Met`a*ti*tan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>titanic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Of, pertaining to, or designating, an acid of titanium analogous to
metasilicic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metatungstate</ent><br/
<hw>Met`a*tung"state</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of metatungstic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metatungstic</ent><br/
<hw>Met`a*tung"stic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>tungstic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Of, pertaining to, or designating, an acid known only in its salts
(the <xex>metatungstates</xex>) and properly called
<xex>polytungstic</xex>, or <xex>pyrotungstic</xex>, acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metavanadate</ent><br/
<hw>Met`a*van"a*date</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of metavanadic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metavanadic</ent><br/
<hw>Met`a*va*nad"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>vanadic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Of, pertaining to, or designating, a vanadic acid analogous to
metaphosphoric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metaxylene</ent><br/
<hw>Met`a*xy"lene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>meta-</ets> + <ets>xylene</ets>.]</ety> <fld>(Chem.)</fld>
<def>That variety of xylene, or dimethyl benzene, in which the two
methyl groups occupy the meta position with reference to each other. It
is a colorless inflammable liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metayage</ent><br/
\'d8<hw>M<eacute/`ta`yage"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>M<eacute/tayer</er>.]</ety> <def>A system of farming on
halves.</def> <mark>[France & Italy]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metayer</ent><br/
\'d8<hw>M<eacute/`ta`yer"</hw> <pr>(F. ?; E. ?)</pr>, <pos>n.</pos>
<ety>[F., fr. LL. <ets>medietarius</ets>, fr. L. <ets>medius</ets>
middle, half. See <er>Mid</er>, <pos>a.</pos>]</ety> <def>One who
cultivates land for a share (usually one half) of its yield, receiving
stock, tools, and seed from the landlord; a type of
<isa>sharecropper</isa>.</def> <mark>[France & Italy]</mark>
<rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Metazoa</ent><br/
\'d8<hw>Met`a*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ after + <grk>zw^,on</grk> an animal.]</ety> <fld>(Zool.)</fld>
<def>Those animals in which the protoplasmic mass, constituting the egg,
is converted into a multitude of cells, which are metamorphosed into the
tissues of the body. A central cavity is commonly developed, and the
cells around it are at first arranged in two layers, -- the
<xex>ectoderm</xex> and <xex>endoderm</xex>. The group comprises nearly
all animals except the Protozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metazoan</ent><br/
<hw>Met`a*zo"an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Metazoans</plw> <pr>(<?/)</pr>.</plu> <fld>(Zool.)</fld> <def>One
of the Metazoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metazoic</ent><br/
<hw>Met`a*zo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Metazoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metazoon</ent><br/
\'d8<hw>Met`a*zo"on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>One of the Metazoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mete</ent><br/
<hw>Mete</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Meat.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mete</ent><br/
<hw>Mete</hw>, <pos>v. t. & i.</pos> <def>To meet.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mete</ent><br/
<hw>Mete</hw>, <pos>v. i. & t.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Mette</conjf> <pr>(?)</pr>; <pos>p. p.</pos>
<conjf>Met</conjf>.]</vmorph> <ety>[AS. <ets>m<?/tan</ets>.]</ety>
<def>To dream; also impersonally; <as>as, <ex>me mette</ex>, I
dreamed</as>.</def> <mark>[Obs.]</mark> <ldquo/I <xex>mette</xex> of him
all night.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mete</ent><br/
<hw>Mete</hw> <pr>(m<emac/t)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Meted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Meting</conjf>.]</vmorph> <ety>[AS. <ets>metan</ets>; akin to D.
<ets>meten</ets>, G. <ets>messen</ets>, OHG. <ets>mezzan</ets>, Icel.
<ets>meta</ets>, Sw. <ets>m<aum/ta</ets>, Goth. <ets>mitan</ets>, L.
<ets>modus</ets> measure, moderation, <ets>modius</ets> a corn measure,
Gr. <?/ to rule, <?/ a corn measure, and ultimately from the same root
as E. <ets>measure</ets>, L. <ets>metiri</ets> to measure; cf. Skr.
<ets>m<amac/</ets> to measure. <root/99. Cf. <er>Measure</er>,
<er>Meet</er>, <pos>a.</pos>, <er>Mode</er>.]</ety> <def>To find the
quantity, dimensions, or capacity of, by any rule or standard; to
measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mete</ent><br/
<hw>Mete</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To measure.</def>
<mark>[Obs.]</mark> <rj><au>Mark iv. 24.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mete</ent><br/
<hw>Mete</hw>, <pos>n.</pos> <ety>[AS. <ets>met</ets>. See <er>Mete</er>
to measure.]</ety> <def>Measure; limit; boundary; -- used chiefly in the
plural, and in the phrase <xex>metes and bounds</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metecorn</ent><br/
<hw>Mete"corn`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A quantity of corn
formerly given by the lord to his customary tenants, as an encouragement
to, or reward for, labor and faithful service.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metely</ent><br/
<hw>Mete"ly</hw>, <pos>a.</pos> <def>According to measure or proportion;
proportionable; proportionate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metempirical</ent><br/
<ent>Metempiric</ent><br/
<mhw>{ <hw>Met`em*pir"ic</hw> <pr>(?)</pr>, <hw>Met`em*pir"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Pref. <ets>met-</ets> +
<ets>empiric</ets>, <ets>-ical</ets>.]</ety> <fld>(Metaph.)</fld>
<def>Related, or belonging, to the objects of knowledge within the
province of metempirics.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If then the empirical designates the province we include within
the range of science, the province we exclude may be fitly styled the
<qex>metempirical</qex>.</q> <rj><qau>G. H. Lewes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metempiricism</ent><br/
<hw>Met*em*pir"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The science
that is concerned with metempirics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metempirics</ent><br/
<hw>Met`em*pir"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The concepts
and relations which are conceived as beyond, and yet as related to, the
knowledge gained by experience.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metempsychose</ent><br/
<hw>Me*temp"sy*chose</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Metempsychosed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Metempsychosing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[See <er>Metempsychosis</er>.]</ety>
<def>To translate or transfer, as the soul, from one body to
another.</def> <mark>[R.]</mark> <rj><au>Peacham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metempsychosis</ent><br/
<hw>Me*temp`sy*cho"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/; <?/ beyond, over + <?/ to animate; <?/ in + <?/ soul. See
<er>Psychology</er>.]</ety> <def>The passage of the soul, as an immortal
essence, at the death of the animal body it had inhabited, into another
living body, whether of a brute or a human being; transmigration of
souls.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metemptosis</ent><br/
<hw>Met`emp*to"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<?/ beyond, after + <?/ a falling upon, fr. <?/ to fall in or upon; <?/
in + <?/ to fall.]</ety> <fld>(Chron.)</fld> <def>The suppression of a
day in the calendar to prevent the date of the new moon being set a day
too late, or the suppression of the bissextile day once in 134 years.
The opposite to this is the <xex>proemptosis</xex>, or the addition of a
day every 330 years, and another every 2,400 years.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metencephalon</ent><br/
<hw>Met`en*ceph"a*lon</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Met-</ets> + <ets>encephalon</ets>.]</ety> <fld>(Anat.)</fld>
<def>The posterior part of the brain, including the medulla; the
afterbrain. Sometimes abbreviated to <xex>meten</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metensomatosis</ent><br/
\'d8<hw>Met`en*so`ma*to"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
change of body (by the soul), fr. Gr. <?/.]</ety> <fld>(Biol.)</fld>
<def>The assimilation by one body or organism of the elements of
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteor</ent><br/
<hw>Me"te*or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/t<eacute/ore</ets>, Gr. <?/, pl. <?/ things in the air,
fr. <?/ high in air, raised off the ground; <?/ beyond + <?/, <?/, a
suspension or hovering in the air, fr. <?/ to lift, raise up.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Any phenomenon or appearance in the atmosphere, as
clouds, rain, hail, snow, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hail, an ordinary <qex>meteor</qex>.</q> <rj><qau>Bp.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specif.: A transient luminous body or appearance
seen in the atmosphere, or in a more elevated region.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vaulty top of heaven<br/
Figured quite o'er with burning <qex>meteors</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mass of stone or other substance which sometimes
falls to the earth from space beyond the moon, burning up from
atomospheric friction and creating a brilliant but usually very brief
trail of light in the atmosphere; also called a <altname>shooting
star</altname>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ The term is especially applied to fireballs, and the
masses of stone or other substances which sometimes fall to the earth;
also to shooting stars and to ignes fatui. Meteors are often classed as:
<xex>aerial meteors</xex>, winds, tornadoes, etc.; <xex>aqueous
meteors</xex>, rain, hail, snow, dew, etc.; <xex>luminous meteors</xex>,
rainbows, halos, etc.; and <xex>igneous meteors</xex>, lightning,
shooting stars, and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteoric</ent><br/
<hw>Me`te*or"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/t<eacute/orique</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to a meteor, or to meteors; atmospheric, <as>as,
<ex>meteoric</ex> phenomena; <ex>meteoric</ex> stones.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Influenced by the weather; <as>as, <ex>meteoric</ex>
conditions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Flashing; transient and brilliant, like a meteor{3};
<as>as, <ex>meteoric</ex> fame</as>.</def> <ldquo/<xex>Meteoric</xex>
politician.<rdquo/ <rj><au>Craik.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Meteoric iron</b></col>, <col><b>Meteoric
stone</b></col></mcol>. <fld>(Min.)</fld> <cd>See
<er>Meteorite</er>.</cd> -- <col><b>Meteoric paper</b></col>, <cd>a
substance of confervoid origin found floating in the air, and resembling
bits of coarse paper; -- so called because formerly supposed to fall
from meteors.</cd> -- <col><b>Meteoric showers</b></col>, <cd>periodical
exhibitions of shooting stars, occuring about the 9th or 10th of August
and 13th of November, more rarely in April and December, and also at
some other periods.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorical</ent><br/
<hw>Me`te*or"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Meteoric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorism</ent><br/
<hw>Me"te*or*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Flatulent distention of the abdomen; tympanites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorite</ent><br/
<hw>Me"te*or*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/t<eacute/orite</ets>.]</ety> <fld>(Min.)</fld> <def>A mass
of stone or iron which has fallen to the earth from space; an
aerolite.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Meteorites usually show a pitted surface with a fused
crust, caused by the heat developed in their rapid passage through the
earth's atmosphere. A meteorite may consist: <bold>1</bold>. Of metallic
iron, alloyed with a small percentage of nickel (<xex>meteoric
iron</xex>, <xex>holosiderite</xex>). When etched this usually exhibits
peculiar crystalline figures, called <xex>Widmanst<aum/tten
figures</xex>. <bold>2</bold>. Of a cellular mass of iron with imbedded
silicates (<xex>mesosiderite</xex> or <xex>siderolite</xex>).
<bold>3</bold>. Of a stony mass of silicates with little iron
(<xex>meteoric stone</xex>, <xex>sporadosiderite</xex>). <bold>4</bold>.
Of a mass without iron (<xex>asiderite</xex>).</note> <-- Comm:
carbonaceous? Add mark for composition? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorize</ent><br/
<hw>Me"te*or*ize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Gr. <?/ to
raise to a height.]</ety> <def>To ascend in vapors; to take the form of
a meteor.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorograph</ent><br/
<hw>Me`te*or"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meteor</ets> + <ets>-graph</ets>.]</ety> <def>An instrument
which registers meteorologic phases or conditions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorographic</ent><br/
<hw>Me`te*or`o*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to meteorography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorography</ent><br/
<hw>Me`te*or*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meteor</ets> + <ets>-graphy</ets>.]</ety> <def>The
registration of meteorological phenomena.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 919 --></p>

<p><ent>Meteoroid</ent><br/
<hw>Me"te*or*oid</hw> <pr>(m<emac/"t<esl/*<etil/r*oid)</pr>,
<pos>n.</pos> <ety>[<ets>Meteor</ets> + <ets>-oid</ets>.]</ety>
<fld>(Astron.)</fld> <def>A small body moving through space, or
revolving about the sun, which on entering the earth's atmosphere would
be deflagrated and appear as a meteor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These bodies [small, solid bodies] before they come into the air,
I call <qex>meteoroids</qex>.</q> <rj><qau>H. A. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteoroidal</ent><br/
<hw>Me`te*or*oid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to a meteoroid or to meteoroids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorolite</ent><br/
<hw>Me`te*or"o*lite</hw> <pr>(?; 277)</pr>, <pos>n.</pos>
<ety>[<ets>Meteor</ets> + <ets>-lite</ets> : cf. F.
<ets>m<eacute/t<eacute/orolithe</ets>.]</ety> <def>A meteoric stone; an
aerolite; a meteorite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorological</ent><br/
<ent>Meteorologic</ent><br/
<mhw>{ <hw>Me`te*or`o*log"ic</hw> <pr>(?)</pr>,
<hw>Me`te*or`o*log"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Gr. <?/: cf. F. <ets>m<eacute/t<eacute/orologique</ets>.]</ety>
<def>Of or pertaining to the atmosphere and its phenomena, or to
meteorology.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Meteorological table</b></col>,
<col><b>Meteorological register</b></col></mcol>, <cd>a table or
register exhibiting the state of the air and its temperature, weight,
dryness, moisture, motion, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorologist</ent><br/
<hw>Me`te*or*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/t<eacute/orologiste</ets>.]</ety> <def>A person skilled in
meteorology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorology</ent><br/
<hw>Me`te*or*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/
+ <grk>lo`gos</grk> discourse: cf. F.
<ets>m<eacute/t<eacute/orologie</ets>. See <er>Meteor</er>.]</ety>
<def>The science which treats of the atmosphere and its phenomena,
particularly of its variations of heat and moisture, of its winds,
storms, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteoromancy</ent><br/
<hw>Me`te*or"o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meteor</ets> + <ets>-mancy</ets> : cf. F.
<ets>m<eacute/t<eacute/oromancie</ets>.]</ety> <def>A species of
divination by atmospheric phenomena, chiefly by thunder and lightning,
which was held in high estimation by the Romans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorometer</ent><br/
<hw>Me`te*or*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Meteor</ets> + <ets>-meter</ets>.]</ety> <def>An apparatus
which transmits automatically to a central station atmospheric
conditions as marked by the anemometer, barometer, thermometer,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteoroscope</ent><br/
<hw>Me`te*or"o*scope</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[Gr.
<?/, fr. <?/ observing the heavenly bodies; <?/ + <?/ to view: cf. F.
<ets>m<eacute/t<eacute/oroscope</ets>. See <er>Meteor</er>.]</ety>
<fld>(Astron.)</fld> <sd>(a)</sd> <def>An astrolabe; a
planisphere.</def> <mark>[Obs.]</mark> <sd>(b)</sd> <def>An instrument
for measuring the position, length, and direction, of the apparent path
of a shooting star.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteorous</ent><br/
<hw>Me*te"o*rous</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[See
<er>Meteor</er>.]</ety> <def>Of the nature or appearance of a
meteor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-meter</ent><br/
<hw>-me"ter</hw> <pr>(?)</pr>. <ety>[L. <ets>metrum</ets> measure, or
the allied Gr. <?/. See <er>Meter</er> rhythm.]</ety> <def>A suffix
denoting <xex>that by which anything is measured</xex>; <as>as,
baro<ex>meter</ex>, chrono<ex>meter</ex>,
dynamo<ex>meter</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meter</ent><br/
<hw>Me"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Mete</er> to
measure.]</ety> <sn>1.</sn> <def>One who, or that which, metes or
measures. See <er>Coal-meter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instrument for measuring, and usually for
recording automatically, the quantity measured.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dry meter</b></col>, <cd>a gas meter having measuring
chambers, with flexible walls, which expand and contract like bellows
and measure the gas by filling and emptying.</cd> -- <col><b>Wet
meter</b></col>, <cd>a gas meter in which the revolution of a chambered
drum in water measures the gas passing through it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meter</ent><br/
<hw>Me"ter</hw>, <pos>n.</pos> <def>A line above or below a hanging net,
to which the net is attached in order to strengthen it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metre</ent><br/
<ent>Meter</ent><br/
<mhw>{ <hw>Me"ter</hw>, <hw>Me"tre</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[OE. <ets>metre</ets>, F. <ets>m<egrave/tre</ets>, L.
<ets>metrum</ets>, fr. Gr. <?/; akin to Skr. <ets>m<amac/</ets> to
measure. See <er>Mete</er> to measure.]</ety> <sn>1.</sn>
<def>Rhythmical arrangement of syllables or words into verses, stanzas,
strophes, etc.; poetical measure, depending on number, quantity, and
accent of syllables; rhythm; measure; verse; also, any specific
rhythmical arrangements; <as>as, the Horatian <ex>meters</ex>; a
dactylic <ex>meter</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The only strict antithesis to prose is <qex>meter</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A poem.</def> <mark>[Obs.]</mark> <rj><au>Robynson
(More's Utopia).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A measure of length, equal to 39.37 English inches,
the standard of linear measure in the metric system of weights and
measures. It was intended to be, and is very nearly, the ten millionth
part of the distance from the equator to the north pole, as ascertained
by actual measurement of an arc of a meridian. See <cref>Metric
system</cref>, under <er>Metric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Common meter</b></col> <fld>(Hymnol.)</fld>, <cd>four
iambic verses, or lines, making a stanza, the first and third having
each four feet, and the second and fourth each three feet; -- usually
indicated by the initials C. M.</cd> -- <col><b>Long meter</b></col>
<fld>(Hymnol.)</fld>, <cd>iambic verses or lines of four feet each, four
verses usually making a stanza; -- commonly indicated by the initials L.
M.</cd> -- <col><b>Short meter</b></col> <fld>(Hymnol.)</fld>,
<cd>iambic verses or lines, the first, second, and fourth having each
three feet, and the third four feet. The stanza usually consists of four
lines, but is sometimes doubled. <xex>Short meter</xex> is indicated by
the initials S. M.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meterage</ent><br/
<hw>Me"ter*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Meter</er>.]</ety> <def>The act of measuring, or the cost of
measuring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metergram</ent><br/
<hw>Me"ter*gram`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mech.)</fld>
<def>A measure of energy or work done; the power exerted in raising one
gram through the distance of one meter against gravitation; 100
gram-centimeters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metewand</ent><br/
<hw>Mete"wand`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mete</ets> to
measure + <ets>wand</ets>.]</ety> <def>A measuring rod.</def>
<rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meteyard</ent><br/
<hw>Mete"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>metgeard</ets>. See <er>Mete</er> to measure, and <er>Yard</er>
stick.]</ety> <def>A yard, staff, or rod, used as a measure.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meth</ent><br/
<hw>Meth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Meathe</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methaemoglobin</ent><br/
<hw>Met`haem*o*glo"bin</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<ety>[Pref. <ets>met-</ets> + <ets>haemoglobin</ets>.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A stable crystalline compound obtained
by the decomposition of hemoglobin. It is found in old blood
stains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>methadone</ent><br/
<ent>methadon</ent><br/
<mhw><hw>methadon</hw>, <hw>methadone</hw></mhw> <pos>n.</pos> <def>a
narcotic drug similar to morphine but less habit-forming; used in
treating heroin addiction.</def><br/
<syn><b>Syn. --</b> methadone hydrochloride.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Methal</ent><br/
<hw>Meth"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>M</ets>yristic +
<ets>eth</ets>er + <ets>al</ets>cohol.]</ety> <fld>(Chem.)</fld> <def>A
white waxy substance, found in small quantities in spermaceti as an
ethereal salt of several fatty acids, and regarded as an alcohol of the
methane series.</def><-- cetyl alcohol?? = ethal --><br/
[<source>1913 Webster</source>]</p>

<p><ent>methanal</ent><br/
<hw>methanal</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>Same as
<er>formaldehyde</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Methane</ent><br/
<hw>Meth"ane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Methal</er>.]</ety> <fld>(Chem.)</fld> <def>A light, colorless,
gaseous, inflammable hydrocarbon, <chform>CH4</chform>; marsh gas. It is
the simplest of the aliphatic hydrocarbons. See <cref>Marsh gas</cref>,
under <er>Gas</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Methane series</b></col> <fld>(Chem.)</fld>, <cd>a series
of saturated hydrocarbons, of which methane is the first member and
type, and (because of their general chemical inertness and indifference)
called also the <altname>paraffin (little affinity) series</altname>.
The lightest members are gases, as methane, ethane; intermediate members
are liquids, as hexane, heptane, etc. (found in benzine, kerosene,
etc.); while the highest members are white, waxy, or fatty solids, as
paraffin proper.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>methanogen</ent><br/
<hw>methanogen</hw> <pos>n.</pos> <def>A type of archaebacteria found in
anaerobic environments such as animal intestinal tracts or sediments or
sewage, and capable of producing <prod>methane</prod>; a source of
natural gas.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>methanol</ent><br/
<hw>methanol</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>The simplest
alcohol of the paraffin series, <chform>CH3.OH</chform>; methyl alcohol.
Called also <altname>wood alcohol</altname>. It is used as an antifreeze
solvent, as a fuel, and as a denaturant for ethyl alcohol.</def><br/
<syn><b>Syn. --</b> methyl alcohol, wood alcohol, wood spirit.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Methanometer</ent><br/
<hw>Meth`a*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Methane</ets> + <ets>-meter</ets>.]</ety> <def>An instrument,
resembling a eudiometer, to detect the presence and amount of methane,
as in coal mines.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Metheglin</ent><br/
<hw>Me*theg"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W.
<ets>meddyglyn</ets>; <ets>medd</ets> mead + <ets>llyn</ets> liquor,
juice. See <er>Mead</er> a drink.]</ety> <def>A fermented beverage made
of honey and water; mead.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methene</ent><br/
<hw>Meth"ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meth</ets>yl +
ethyl<ets>ene</ets>.]</ety> <fld>(Chem.)</fld> <def>See
<er>Methylene</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methenyl</ent><br/
<hw>Meth"e*nyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Methene</ets>
+ <ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>The hypothetical
hydrocarbon radical <chform>CH</chform>, regarded as an essential
residue of certain organic compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methide</ent><br/
<hw>Meth"ide</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[See
<er>Methyl</er>.]</ety> <fld>(Chem.)</fld> <def>A binary compound of
methyl with some element; <as>as, aluminium <ex>methide</ex>,
<chform>Al2(CH3)6</chform></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methinks</ent><br/
<hw>Me*thinks"</hw> <pr>(?)</pr>, <pos>v. impers.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Methought</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[AS. <ets><thorn/yncan</ets> to seem,
<ets>m<emac/ <thorn/ynce<edh/</ets>, <ets>m<emac/
<thorn/<umac/hte</ets>, OE. <ets>me thinketh</ets>, <ets>me
thoughte</ets>; akin to G. <ets>d<uum/nken</ets> to seem,
<ets>denken</ets> to think, and E. <ets>think</ets>. See <er>Me</er>,
and <er>Think</er>.]</ety> <def>It seems to me; I think. See
<er>Me</er>.</def> <mark>[R., except in poetry.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In all ages poets have been had in special reputation, and,
<qex>methinks</qex>, not without great cause.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methionate</ent><br/
<hw>Me*thi"on*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of methionic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methionic</ent><br/
<hw>Meth`i*on"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Me</ets>thyl + <ets>thionic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Of, pertaining to, or designating, a sulphonic (<it>thionic</it>)
acid derivative of methane, obtained as a stable white crystalline
substance, <chform>CH2.(SO3H)2</chform>, which forms well defined
salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Method</ent><br/
<hw>Meth"od</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/thode</ets>, L. <ets>methodus</ets>, fr. Gr.
<grk>meqodos</grk> method, investigation following after;
<grk>meta`</grk> after + <grk>"odo`s</grk> way.]</ety> <sn>1.</sn>
<def>An orderly procedure or process; regular manner of doing anything;
hence, manner; way; mode; <as>as, a <ex>method</ex> of teaching
languages; a <ex>method</ex> of improving the mind.</as></def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Orderly arrangement, elucidation, development, or
classification; clear and lucid exhibition; systematic arrangement
peculiar to an individual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though this be madness, yet there's <qex>method</qex> in it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>method</qex> is a rational progress, a progress toward an
end.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Nat. Hist.)</fld> <def>Classification; a mode or
system of classifying natural objects according to certain common
characteristics; <as>as, the <ex>method</ex> of Theophrastus; the
<ex>method</ex> of Ray; the Linnaean <ex>method</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A technique used in acting in which the actor tries
to identify with the individual personality of the specific character
being portrayed, so as to provide a realistic rendering of the
character's role. Also called <altname>the Method</altname>,
<altname>method acting</altname>, the <ecol><b>Stanislavsky
Method</b></ecol> or <altname>Stanislavsky System</altname>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Order; system; rule; regularity; way; manner;
mode; course; process; means.</syn> <usage> -- <er>Method</er>,
<er>Mode</er>, <er>Manner</er>. <xex>Method</xex> implies arrangement;
<xex>mode</xex>, mere action or existence. <xex>Method</xex> is a way of
reaching a given end by a <xex>series</xex> of acts which tend to secure
it; <xex>mode</xex> relates to a single action, or to the form which a
series of acts, viewed as a whole, exhibits. <xex>Manner</xex> is
literally the <xex>handling</xex> of a thing, and has a wider sense,
embracing both <xex>method</xex> and <xex>mode</xex>. An instructor may
adopt a good <xex>method</xex> of teaching to write; the scholar may
acquire a bad <xex>mode</xex> of holding his pen; the <xex>manner</xex>
in which he is corrected will greatly affect his success or
failure.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodical</ent><br/
<ent>Methodic</ent><br/
<mhw>{ <hw>Me*thod"ic</hw> <pr>(?)</pr>, <hw>Me*thod"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>methodicus</ets>, Gr.
<?/: cf. F. <ets>m<eacute/thodique</ets>.]</ety> <sn>1.</sn>
<def>Arranged with regard to method; disposed in a suitable manner, or
in a manner to illustrate a subject, or to facilitate practical
observation; well-ordered; <as>as, the <ex>methodical</ex> arrangement
of arguments; a <ex>methodical</ex> treatise.</as></def>
<wns>[wns=2]</wns> <ldquo/<xex>Methodical</xex> regularity.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proceeding with regard to method; characterized by
method or orderliness; systematic; <as>as, a <ex>methodical</ex>
investigation</as>.</def> <wns>[wns=1]</wns> <ldquo/Aristotle, strict,
<xex>methodic</xex>, and orderly.<rdquo/ <rj><au>Harris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to the ancient school of physicians
called methodists.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Me*thod"ic*al*ly</wf>, <pos>adv.</pos> --
<wf>Me*thod"ic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodios</ent><br/
<hw>Me*thod"ios</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art and
principles of method.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodism</ent><br/
<hw>Meth"o*dism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.)</fld>
<def>The system of doctrines, polity, and worship, of the sect called
Methodists.</def> <rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodist</ent><br/
<hw>Meth"o*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/thodiste</ets>. See <er>Method</er>.]</ety> <sn>1.</sn>
<def>One who observes method.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of an ancient school of physicians who rejected
observation and founded their practice on reasoning and theory.</def>
<rj><au>Sir W. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Theol.)</fld> <def>One of a sect of Christians, the
outgrowth of a small association called the <ldquo/Holy Club,<rdquo/
formed at Oxford University, <sc>a. d.</sc> 1729, of which the most
conspicuous members were <person>John Wesley</person> and his brother
<person>Charles Wesley</person>; -- originally so called from the
methodical strictness of members of the club in all religious
duties.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person of strict piety; one who lives in the exact
observance of religious duties; -- sometimes so called in contempt or
ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodist</ent><br/
<hw>Meth"o*dist</hw>, <pos>a.</pos> <def>Of or pertaining to the sect of
Methodists; <as>as, <ex>Methodist</ex> hymns; a <ex>Methodist</ex>
elder.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodistical</ent><br/
<ent>Methodistic</ent><br/
<mhw>{ <hw>Meth`o*dis"tic</hw> <pr>(?)</pr>, <hw>Meth`o*dis"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to methodists,
or to the Methodists.</def> -- <wordforms><wf>Meth`o*dis"tic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodization</ent><br/
<hw>Meth`od*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of methodizing, or the state of being methodized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodize</ent><br/
<hw>Meth"od*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Methodized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Methodizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
reduce to method; to dispose in due order; to arrange in a convenient
manner; <as>as, to <ex>methodize</ex> one's work or thoughts</as>.</def>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodizer</ent><br/
<hw>Meth"od*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
methodizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodological</ent><br/
<hw>Meth`od*o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to methodology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methodology</ent><br/
<hw>Meth`od*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
method + <ets>-logy</ets>.]</ety> <def>The science of method or
arrangement; a treatise on method.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methol</ent><br/
<hw>Meth"ol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ wine +
<ets>-ol</ets>.]</ety> <fld>(Chem.)</fld> <def>An earlier technical name
of methyl alcohol or wood spirit, now called
<altname>methanol</altname>; also, by extension, the class name of any
of the series of alcohols of the methane series of which
<xex>methol</xex> proper is the type. See <cref>Methyl alcohol</cref>,
under <er>Methyl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methought</ent><br/
<hw>Me*thought"</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Methinks</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methoxyl</ent><br/
<hw>Meth*ox"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Meth</ets>yl
+ hydr<ets>oxyl</ets>.]</ety> <fld>(Chem.)</fld> <def>A hypothetical
radical, <chform>CH3O</chform>, analogous to hydroxyl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methyl</ent><br/
<hw>Meth"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Methylene</er>.]</ety> <fld>(Chem.)</fld> <def>A univalent
hydrocarbon radical, <chform>CH3-</chform>, not existing alone but
regarded as an essential residue of methane, and appearing as a
component part of many derivatives; <as>as, <ex>methyl</ex> alcohol,
<ex>methyl</ex> ether, <ex>methyl</ex> amine, etc.</as></def>
<altsp>[Formerly written also <asp>methule</asp>, <asp>methyle</asp>,
etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Methyl alcohol</b></col> <fld>(Chem.)</fld>, <cd>a light,
volatile, inflammable liquid, <chform>CH3.OH</chform>, obtained by the
distillation of wood, and hence called <altname>wood alcohol</altname>
or <altname>wood spirit</altname>; tecnically referred to as
<altname>methanol</altname>; -- called also <altname>methol</altname>,
<altname>carbinol</altname>, etc.</cd> -- <col><b>Methyl amine</b></col>
<fld>(Chem.)</fld>, <cd>a colorless, inflammable, alkaline gas,
<chform>CH3.NH2</chform>, having an ammoniacal, fishy odor. It is
produced artificially, and also occurs naturally in herring brine and
other fishy products. It is regarded as ammonia in which a third of its
hydrogen is replaced by methyl, and is a type of the class of
<isa>substituted ammonias</isa>.</cd> -- <col><b>Methyl ether</b></col>
<fld>(Chem.)</fld>, <cd>a light, volatile ether
<chform>CH3.O.CH3</chform>, obtained by the etherification of methyl
alcohol; -- called also <altname>methyl oxide</altname> or
<altname>dimethyl ether</altname>.</cd> -- <col><b>Methyl
green</b></col>. <fld>(Chem.)</fld> <cd>See under <er>Green</er>,
<pos>n.</pos></cd> -- <col><b>Methyl orange</b></col>.
<fld>(Chem.)</fld> <cd>See <er>Helianthin</er>.</cd> -- <col><b>Methyl
violet</b></col> <fld>(Chem.)</fld>, <cd>an artificial dye, consisting
of certain methyl halogen derivatives of rosaniline.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methylal</ent><br/
<hw>Meth"yl*al</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Methyl</ets>ene + <ets>al</ets>cohol.]</ety>
<fld>(Chem.)</fld> <def>A light, volatile liquid,
<chform>H2C(OCH3)2</chform>, regarded as a complex ether, and having a
pleasant ethereal odor. It is obtained by the partial oxidation of
methyl alcohol. Called also <altname>formal</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methylamine</ent><br/
<hw>Meth`yl*am"ine</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>See <cref>Methyl amine</cref>, under
<er>Methyl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methylate</ent><br/
<hw>Meth"yl*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Methyl</ets>
+ alcohol<ets>ate</ets>.]</ety> <fld>(Chem.)</fld> <def>An alcoholate of
methyl alcohol in which the hydroxyl hydrogen is replaced by a metal,
after the analogy of a hydrate; <as>as, sodium <ex>methylate</ex>,
<chform>CH3ONa</chform></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methylate</ent><br/
<hw>Meth"yl*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To impregnate
or mix with methyl or methyl alcohol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methylated</ent><br/
<hw>Meth"yl*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Impregnated with, or containing, methyl alcohol or wood spirit;
<as>as, <ex>methylated</ex> spirits</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methylene</ent><br/
<hw>Meth"yl*ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/thyl<egrave/ne</ets>, from Gr. <?/ wine + <?/ wood; -- a
word coined to correspond to the name <ets>wood spirit</ets>.]</ety>
<fld>(Chem.)</fld> <def>A divalent hydrocarbon radical,
<chform>-CH2-</chform>, not known in the free state, but regarded as an
essential residue and component of certain derivatives of methane;
<as>as, <ex>methylene</ex> bromide, <chform>CH2Br2</chform></as>; --
formerly called also <altname>methene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Methylene blue</b></col> <fld>(Chem.)</fld>, <cd>an
artificial dyestuff consisting of a complex sulphur derivative of
diphenyl amine; -- called also <altname>pure
blue</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>methylenedioxymethamphetamine</ent><br/
<hw>methylenedioxymethamphetamine</hw> <pos>n.</pos> <def>a drug
designed to have the effects of amphetamines but to avoid the drug laws,
but now a controlled substance. Called also
<altname>MDMA</altname>.</def><br/
<syn><b>Syn. --</b> MDMA, Adam, ecstasy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Methylic</ent><br/
<hw>Me*thyl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, derived from, or containing, methyl; specifically,
designating methyl alcohol. See under <er>Methyl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Methysticin</ent><br/
<hw>Me*thys"ti*cin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A white, silky, crystalline substance extracted from the thick
rootstock of a species of pepper (<spn>Piper methysticum</spn>) of the
South Sea Islands; -- called also <altname>kanakin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metic</ent><br/
<hw>Met"ic</hw> <pr>(? <or/ ?; 277)</pr>, <pos>n.</pos> <ety>[Gr. <?/,
prop., changing one's abode; <?/, indicating change + <?/ house, abode:
cf. L. <ets>metoecus</ets>, F. <ets>m<eacute/t<egrave/que</ets>.]</ety>
<fld>(Gr. Antiq.)</fld> <def>A sojourner; an immigrant; an alien
resident in a Grecian city, but not a citizen.</def>
<rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole force of Athens, <qex>metics</qex> as well as citizens,
and all the strangers who were then in the city.</q> <rj><qau>Jowett
(Thucyd. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>meticulosity</ent><br/
<hw>meticulosity</hw> <pos>n.</pos> <def>strict attention to minute
details; the quality of being meticulous.</def><br/
<syn><b>Syn. --</b> meticulousness, punctiliousness,
scrupulousness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meticulous</ent><br/
<hw>Me*tic"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>meticulosus</ets>, fr. <ets>metus</ets> fear: cf. F.
<ets>m<eacute/ticuleux</ets>.]</ety> <def>Timid; fearful.</def>
<mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Taking great care to get every detail correct;
working thoroughly and with precision; <as>as, <ex>meticulous</ex>
workmanship</as>.</def><br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>Me*tic"u*lous*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metier</ent><br/
\'d8<hw>M<eacute/`tier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>Calling; vocation; business; trade.</def></p>

<p><q>Not only is it the business of no one to preach the truth but it
is the <qex>m<eacute/tier</qex> of many to conceal it.</q> <rj><qau>A.
R. Colquhoun.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>the field or activity at which one excels; one's
forte.</def><br/
[<source>PJC</source>]</p>

<p><ent>Metive</ent><br/
<ent>Metif</ent><br/
<mhw>{ \'d8<hw>M<eacute/`tif"</hw> <pr>(?)</pr>, <pos>n. m.</pos>
\'d8<hw>M<eacute/`tive"</hw> <pr>(?)</pr>, <pos>n. f.</pos>
}</mhw><ety>[F.]</ety> <def>See <er>M<eacute/tis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metisse</ent><br/
<ent>Metis</ent><br/
<mhw>{ \'d8<hw>M<eacute/`tis"</hw> <pr>(?)</pr>, <pos>n. m.</pos>
\'d8<hw>M<eacute/`tisse"</hw> <pr>(?)</pr>, <pos>n. f.</pos>
}</mhw><ety>[F.; akin to Sp. <ets>mestizo</ets>. See
<er>Mestizo</er>.]</ety> <sn>1.</sn> <def>The offspring of a white
person and an American Indian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The offspring of a white person and a quadroon; an
octoroon.</def> <mark>[Local, U. S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metoche</ent><br/
<hw>Met"o*che</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/ a
sharing, fr. <?/ to share in; <?/ with + <?/ to have.]</ety>
<fld>(Arch.)</fld> <sd>(a)</sd> <def>The space between two
dentils.</def> <sd>(b)</sd> <def>The space between two
triglyphs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metol</ent><br/
<hw>Me"tol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.; trade name, fr.
<ets>meta-</ets> + kre<ets>sol</ets> cresol.]</ety> <def>A whitish
soluble powder used as a developer in photography. Chemically, it is the
sulphate of
<chname>methyl-<it>p</it>-amino-<it>m</it>-cresol</chname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Metonic</ent><br/
<hw>Me*ton"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/tonique</ets>.]</ety> <def>Pertaining to, or discovered
by, <persfn><etsep>Meton</etsep></persfn>, the Athenian.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Metonic year</b></col> <it>or</it> <col><b>Metonic
cycle</b></col></mcol>. <fld>(Astron.)</fld> <cd>See under
<er>Cycle</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metonymical</ent><br/
<ent>Metonymic</ent><br/
<mhw>{ <hw>Met`o*nym"ic</hw> <pr>(?)</pr>, <hw>Met`o*nym"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Metonymy</er>.]</ety>
<def>Used by way of metonymy; using the name of one thing for that of
another with which it is closely associated.</def> --
<wordforms><wf>Met`o*nym"ic*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metonymy</ent><br/
<hw>Me*ton"y*my</hw> <pr>(m<esl/*t<ocr/n"<icr/*m<ycr/; 277)</pr>,
<pos>n.</pos> <ety>[L. <ets>metonymia</ets>, Gr. <grk>metwnymi`a</grk>;
<grk>meta`</grk>, indicating change + <grk>'o`nyma</grk> , for
<grk>'o`noma</grk> a name: cf. F. <ets>m<eacute/tonymie</ets>. See
<er>Name</er>.]</ety> <fld>(Rhet.)</fld> <def>A trope in which one word
is put for another that suggests it; <as>as, we say, a man keeps a good
<examp>table</examp> instead of good <ex>provisions</ex>; we read
<examp>Virgil</examp>, that is, his <ex>poems</ex>; a man has a warm
<examp>heart</examp>, that is, warm <ex>affections</ex>; a city dweller
has no <examp>wheels</examp>, that is, no automobile.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metope</ent><br/
<hw>Met"o*pe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/;
<grk>meta`</grk> with, between + <?/ opening, hole, the hole in the
frieze between the beam ends.]</ety> <sn>1.</sn> <fld>(Arch.)</fld>
<def>The space between two triglyphs of the Doric frieze, which, among
the ancients, was often adorned with carved work. See <xex>Illust.</xex>
of <er>Entablature</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The face of a crab.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the Parthenon, groups of centaurs and heroes in high
relief occupy the metopes.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metopic</ent><br/
<hw>Me*top"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ the
forehead.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining to the
forehead or frontal bones; frontal; <as>as, the <ex>metopic</ex>
suture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metopomancy</ent><br/
<hw>Met"o*po*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ the
forehead + <ets>-mancy</ets>.]</ety> <def>Fortune telling by
physiognomy.</def> <mark>[R.]</mark> <rj><au>Urquhart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metoposcopical</ent><br/
<ent>Metoposcopic</ent><br/
<mhw>{ <hw>Met`o*po*scop"ic</hw> <pr>(?)</pr>,
<hw>Met`o*po*scop"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of
or relating to metoposcopy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metoposcopist</ent><br/
<hw>Met`o*pos"co*pist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed
in metoposcopy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metoposcopy</ent><br/
<hw>Met`o*pos"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
observing the forehead; <?/ the forehead + <?/ to view: cf. F.
<ets>m<eacute/toposcopie</ets>.]</ety> <def>The study of physiognomy;
the art of discovering the character of persons by their features, or
the lines of the face.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metosteon</ent><br/
\'d8<hw>Me*tos"te*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ after + <?/ bone.]</ety> <fld>(Anat.)</fld> <def>The postero-lateral
ossification in the sternum of birds; also, the part resulting from such
ossification.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 920 --></p>

<p><ent>Metre</ent><br/
<hw>Me"tre</hw> <pr>(m<emac/"t<etil/r)</pr>, <pos>n.</pos> <def>See
<er>Meter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metric</ent><br/
<hw>Met"ric</hw> <pr>(m<ecr/t"r<icr/k)</pr>, <pos>a.</pos> <ety>[L.
<ets>metricus</ets>, Gr. <?/: cf. F. <ets>m<eacute/trique</ets>. See
<er>Meter</er> rhythm.]</ety> <sn>1.</sn> <def>Relating to measurement;
involving, or proceeding by, measurement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the meter as a standard of
measurement; of or pertaining to the decimal system of measurement of
which a meter is the unit; <as>as, the <ex>metric</ex> system; a
<ex>metric</ex> measurement.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Metric analysis</b></col> <fld>(Chem.)</fld>,
<cd>analysis by volume; volumetric analysis.</cd> -- <col><b>Metric
system</b></col>, <cd>See <er>metric system</er> in the
vocabulary.</cd></cs> <-- nano-, pico-, femto-, atto-; giga-, tera, etc.
--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrical</ent><br/
<hw>Met"ric*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to the meter; arranged in meter; consisting of verses;
<as>as, <ex>metrical</ex> compositions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to measurement; <as>as, the inch,
foot, yard, etc.</as>, are <xex>metrical</xex> terms; esp., of or
pertaining to the metric system.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrically</ent><br/
<hw>Met"ric*al*ly</hw>, <pos>adv.</pos> <def>In a metrical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>metrication</ent><br/
<hw>met`ri*ca"tion</hw> <pr>(m<ecr/t`r<icr/*k<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>The act or process of converting the standard system
of units of a country to those of the <er>metric system</er>;
metrification; <as>as, Great Britain has completed its
<ex>metrification</ex>, but the United States still resists complete
change</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Metrician</ent><br/
<hw>Me*tri"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/tricien</ets>. See <er>Meter</er> rhythm.]</ety> <def>A
composer of verses.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metric system</ent><br/
<hw>Met"ric sys"tem</hw> <pr>(?)</pr> <pos>n.</pos> <def>A system of
weights and measures originating in France, the use of which is required
by law in many countries, and permitted in many others, including the
United States; the system is also called by its French name, <altname>Le
Syst<egrave/me International de Unit<eacute/s</altname> (abbreviated
<abbr>SI</abbr>). The principal unit of length is the <xex>meter</xex>
(see <er>Meter</er>). From this are formed the <xex>are</xex>, the
<xex>liter</xex>, the <xex>stere</xex>, the <xex>gram</xex>, etc. These
units, and others derived from them, are divided decimally, and larger
units are formed from multiples by 10, 100, 1,000, and 10,000. The
successive multiplies are designated by the prefixes, <xex>deka-</xex>
(formerly <xex>deca-</xex>), <xex>hecto-</xex>, <xex>kilo-</xex>, and
<xex>myria-</xex> (seldom used); successive parts by <xex>deci-</xex>,
<xex>centi-</xex>, and <xex>milli-</xex>. The prefixes <xex>mega-</xex>
and <xex>micro-</xex> are used to denote a multiple by one million, and
the millionth part, respectively; <xex>giga-</xex> and <xex>nano-</xex>
denote multiples of one billion (1,000,000,000) and one billionth,
respectively. The prefix for one trillion (10<sup>12</sup>) is
<xex>tera</xex>, and for one trillionth (10<sup>-12</sup>) is
<xex>pico</xex>; for one quintillion (10<sup>15</sup>) <xex>peta</xex>,
and for (10<sup>-15</sup>) (one quintillionth) <xex>femto</xex>; for
(10<sup>-18</sup>) <xex>atto</xex>. See the words formed with these
prefixes in the Vocabulary. For <xex>metric tables</xex>, see p.
1682.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Metric ton</ent><br/
<hw>Met"ric ton</hw>. <def>A weight of 1,000 kilograms, or 2,204.6
pounds avoirdupois.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Metrification</ent><br/
<hw>Met`ri*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Composition in metrical form; versification.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or process of converting the standard system
of units of a country to those of the metric system;
metrication.</def><br/
[<source>PJC</source>]</p>

<p><ent>Metrify</ent><br/
<hw>Met"ri*fy</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>metrum</ets> meter + <ets>-fy</ets>: cf. F.
<ets>m<eacute/trifier</ets>.]</ety> <def>To make verse.</def>
<mark>[R.]</mark> <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrist</ent><br/
<hw>Me"trist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A maker of
verses.</def> <rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Spenser was no mere <qex>metrist</qex>, but a great composer.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metritis</ent><br/
\'d8<hw>Me*tri"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ womb + <ets>-tis</ets>.]</ety> <fld>(Med.)</fld> <def>Inflammation
of the womb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrochrome</ent><br/
<hw>Met"ro*chrome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ + <?/
color.]</ety> <def>An instrument for measuring colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrograph</ent><br/
<hw>Met"ro*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ measure
+ <ets>-graph</ets>.]</ety> <def>An instrument attached to a locomotive
for recording its speed and the number and duration of its
stops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrological</ent><br/
<hw>Met`ro*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>m<eacute/trologique</ets>.]</ety> <def>Of or pertaining to
metrology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrology</ent><br/
<hw>Me*trol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ measure
+ <ets>-m<eacute/trologie</ets>.]</ety> <def>The science of, or a system
of, weights and measures; also, a treatise on the subject.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metromania</ent><br/
<hw>Met`ro*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
measure + E. <ets>mania</ets>.]</ety> <def>A mania for writing
verses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metromaniac</ent><br/
<hw>Met`ro*ma"ni*ac</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who has
metromania.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrometer</ent><br/
<hw>Me*trom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ womb +
<ets>-meter</ets>.]</ety> <fld>(Med.)</fld> <def>An instrument for
measuring the size of the womb.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metronome</ent><br/
<hw>Met"ro*nome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ measure +
<?/ distribute, assign: cf. F. <ets>m<eacute/tronome</ets>, It.
<ets>metronomo</ets>.]</ety> <def>An instrument consisting of a short
pendulum with a sliding weight. It is set in motion by clockwork, and
serves to measure time in music.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metronomy</ent><br/
<hw>Me*tron"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Metronome</er>.]</ety> <def>Measurement of time by an
instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metronymic</ent><br/
<hw>Met`ro*nym"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/; <?/
mother + <?/, for <?/ name.]</ety> <def>Derived from the name of one's
mother, or other female ancestor; <as>as, a <ex>metronymic</ex> name or
appellation</as>.</def> -- <def2><pos>n.</pos> <def>A metronymic
appellation.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metropole</ent><br/
<hw>Met"ro*pole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/tropole</ets>. See <er>Metropolis</er>.]</ety> <def>A
metropolis.</def> <mark>[Obs.]</mark> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metropolis</ent><br/
<hw>Me*trop"o*lis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metropolis</ets>, Gr. <?/, prop., the mother city (in relation to
colonies); <?/ mother + <?/ city. See <er>Mother</er>, and
<er>Police</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The mother city; the chief city of a kingdom, state,
or country.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Edinburgh] gray <qex>metropolis</qex> of the North.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>The seat, or see, of the
metropolitan, or highest church dignitary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The great <qex>metropolis</qex> and see of Rome.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any large city.</def><br/
[<source>PJC</source>]</p>

<p><ent>Metropolitan</ent><br/
<hw>Met`ro*pol"i*tan</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>metropolitanus</ets>: cf. F.
<ets>m<eacute/tropolitain</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to the capital or principal city of a country; <as>as,
<ex>metropolitan</ex> luxury</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>Of, pertaining to, or
designating, a metropolitan or the presiding bishop of a country or
province, his office, or his dignity; <as>as, <ex>metropolitan</ex>
authority</as>.</def> <ldquo/Bishops <xex>metropolitan</xex>.<rdquo/
<rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metropolitan</ent><br/
<hw>Met`ro*pol"i*tan</hw>, <pos>n.</pos> <ety>[LL.
<ets>metropolitanus</ets>.]</ety> <sn>1.</sn> <def>The superior or
presiding bishop of a country or province.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Lat. Church.)</fld> <def>An archbishop.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gr. Church)</fld> <def>A bishop whose see is a
civil metropolis. His rank is intermediate between that of an archbishop
and a patriarch; <as>as, the <ex>metropolitan</ex> of
Constantinople</as>.</def> <rj><au>Hook.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metropolitanate</ent><br/
<hw>Met`ro*pol"i*tan*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The see
of a metropolitan bishop.</def> <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metropolite</ent><br/
<hw>Me*trop"o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>metropolita</ets>, Gr. <?/.]</ety> <def>A metropolitan.</def>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metropolitical</ent><br/
<hw>Met`ro*po*lit"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to a metropolis; being a metropolis; metropolitan; <as>as,
the <ex>metropolitical</ex> chair</as>.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrorrhagia</ent><br/
\'d8<hw>Met`ror*rha"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ womb + <?/ to break.]</ety> <fld>(Med.)</fld> <def>Profuse
bleeding from the womb, esp. such as does not occur at the menstrual
period.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metroscope</ent><br/
<hw>Met"ro*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ womb +
<ets>-scope</ets>.]</ety> <def>A modification of the stethoscope, for
directly auscultating the uterus from the vagina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrosideros</ent><br/
\'d8<hw>Met`ro*si*de"ros</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ heart of a tree + <?/ iron.]</ety> <fld>(Bot.)</fld> <def>A
myrtaceous genus of trees or shrubs, found in Australia and the South
Sea Islands, and having very hard wood. <spn>Metrosideros vera</spn> is
the true ironwood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrotome</ent><br/
<hw>Met"ro*tome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Metrotomy</er>.]</ety> <fld>(Surg.)</fld> <def>An instrument for
cutting or scarifying the uterus or the neck of the uterus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Metrotomy</ent><br/
<hw>Me*trot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ womb +
<?/ to cut: cf. F. <ets>m<eacute/trotomie</ets>.]</ety>
<fld>(Surg.)</fld> <def>The operation of cutting into the uterus;
hysterotomy; the Caesarean section.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-metry</ent><br/
<hw>-me*try</hw> <pr>(?)</pr>. <ety>[See <er>-meter</er>.]</ety> <def>A
suffix denoting the <xex>art</xex>, <xex>process</xex>, or
<xex>science</xex>, <xex>of measuring</xex>; <as>as,
acidi<ex>metry</ex>, bathy<ex>metry</ex>, chloro<ex>metry</ex>,
chrono<ex>metry</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mette</ent><br/
<hw>Mette</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Mete</er>, to dream.</def> <au>Chaucer.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mettle</ent><br/
<hw>Met"tle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[E. <ets>metal</ets>,
used in a tropical sense in allusion to the temper of the metal of a
sword blade. See <er>Metal</er>.]</ety> <def>Substance or quality of
temperament; spirit, esp. as regards honor, courage, fortitude, ardor,
etc.; disposition; -- usually in a good sense; <as>as, to test a
person's <ex>mettle</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A certain critical hour which shall . . . try what
<qex>mettle</qex> his heart is made of.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gentlemen of brave <qex>mettle</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The winged courser, like a generous horse,<br/
Shows most true <qex>mettle</qex> when you check his course.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To put one one's mettle</b></col>, <cd>to cause or incite
one to use one's best efforts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mettled</ent><br/
<hw>Met"tled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having mettle;
high-spirited; ardent; full of fire.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mettlesome</ent><br/
<hw>Met"tle*some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of spirit;
possessing constitutional ardor; fiery; <as>as, a <ex>mettlesome</ex>
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Met"tle*some*ly</wf>, <pos>adv.</pos> --
<wf>Met"tle*some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meum</ent><br/
\'d8<hw>Me"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., neut. of
<ets>meus</ets> mine.]</ety> <def>Lit., mine; that which is mine; --
used in the phrase <xex>meum et tuum</xex>, or <xex>meum and tuum</xex>;
<as>as, to confound <ex>meum and tuum</ex>, to fail to distinguish one's
own property from that of others</as>; to be dishonest.</def></p>

<p><q>Ancestors . . . generally esteemed more renowned for ancient
family and high courage than for accurately regarding the trifling
distinction of <qex>meum and tuum</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Meuse</ent><br/
<hw>Meuse</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A European river,
flowing into the North Sea.</def><br/
<syn><b>Syn. --</b> Meuse River.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An American operation in World War I (1918);
American troops under Pershing drove back the German armies which were
saved only by the Armistice on November 11.</def><br/
<syn><b>Syn. --</b> Meuse River, Argonne, Argonne Forest, Meuse-Argonne,
Meuse-Argonne operation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meuse-Argonne</ent><br/
<hw>Meuse-Argonne</hw> <pos>prop. n.</pos> <def>an American operation in
World War I (1918); American troops under Pershing drove back the German
armies which were saved only by the Armistice on November 11.</def><br/
<syn><b>Syn. --</b> Meuse, Meuse River, Argonne, Argonne Forest,
Meuse-Argonne operation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Meute</ent><br/
<hw>Meute</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cage for hawks; a mew.
See 4th <er>Mew</er>, 1.</def> <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meve</ent><br/
<hw>Meve</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To move.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>m<?/w</ets>,
akin to D. <ets>meeuw</ets>, G. <ets>m<oum/we</ets>, OHG.
<ets>m<?/h</ets>, Icel. <ets>m<amac/r</ets>.]</ety> <fld>(Zool.)</fld>
<def>A gull, esp. the common British species (<spn>Larus canus</spn>);
called also <altname>sea mew</altname>, <altname>maa</altname>,
<altname>mar</altname>, <altname>mow</altname>, and
<altname>cobb</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mewed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mewing</conjf>.]</vmorph> <ety>[OE. <ets>muen</ets>, F.
<ets>muer</ets>, fr. L. <ets>mutare</ets> to change, fr.
<ets>movere</ets> to move. See <er>Move</er>, and cf. <er>Mew</er> a
cage, <er>Molt</er>.]</ety> <def>To shed or cast; to change; to molt;
<as>as, the hawk <ex>mewed</ex> his feathers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nine times the moon had <qex>mewed</qex> her horns.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw>, <pos>v. i.</pos> <def>To cast the feathers; to molt;
hence, to change; to put on a new appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now everything doth <qex>mew</qex>,<br/
And shifts his rustic winter robe.</q>
<rj><qau>Turbervile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw>, <pos>n.</pos> <ety>[OE. <ets>mue</ets>, F. <ets>mue</ets>
change of feathers, scales, skin, the time or place when the change
occurs, fr. <ets>muer</ets> to molt, mew, L. <ets>mutare</ets> to
change. See 2d <er>Mew</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A cage for hawks while mewing; a coop for fattening
fowls; hence, any inclosure; a place of confinement or shelter; -- in
the latter sense usually in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full many a fat partrich had he in <qex>mewe</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Forthcoming from her darksome <qex>mew</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Violets in their secret <qex>mews</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stable or range of stables for horses; -- compound
used in the plural, and so called from the royal stables in London,
built on the site of the king's mews for hawks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw>, <pos>v. t.</pos> <ety>[From <er>Mew</er> a cage.]</ety>
<def>To shut up; to inclose; to confine, as in a cage or other
inclosure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More pity that the eagle should be <qex>mewed</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Close <qex>mewed</qex> in their sedans, for fear of air.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw>, <pos>v. i.</pos> <ety>[Of imitative origin; cf. G.
<ets>miauen</ets>.]</ety> <def>To cry as a cat.</def> <altsp>[Written
also <asp>meaw</asp>, <asp>meow</asp>.]</altsp>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mew</ent><br/
<hw>Mew</hw>, <pos>n.</pos> <def>The common cry of a cat.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mewl</ent><br/
<hw>Mewl</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mewled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mewling</conjf>.]</vmorph> <ety>[Cf. F. <ets>miauler</ets> to
mew, E. <ets>mew</ets> to cry as a cat. Cf. <er>Miaul</er>.]</ety>
<def>To cry, as a young child; to squall.</def> <altsp>[Written also
<asp>meawl</asp>.]</altsp> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mewler</ent><br/
<hw>Mewl"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One that
mewls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mews</ent><br/
<hw>Mews</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos> <ety>[Prop. pl. of
<ets>mew</ets>. See <er>Mew</er> a cage.]</ety> <def>An alley where
there are stables; a narrow passage; a confined place.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Mr. Turveydrop's great room . . . was built out into a
<qex>mews</qex> at the back.</q> <rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mexical</ent><br/
<ent>Mexal</ent><br/
<mhw>\'d8<hw>Mex*al"</hw> <pr>(?)</pr>, <hw>Mex"i*cal</hw>
<pr>(#)</pr></mhw>, <pos>n.</pos> <ety>[Sp. <ets>mexcal</ets>.]</ety>
<def>See <er>Mescal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mexican</ent><br/
<hw>Mex"i*can</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to Mexico or its people.</def> -- <def2><pos>n.</pos> <def>A
native or inhabitant of Mexico.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mexican poppy</b></col> <pos>prop. n.</pos>
<fld>(Bot.)</fld>, <cd>a tropical American herb of the Poppy family
(<spn>Argemone Mexicana</spn>) with much the look of a thistle, but
having large yellow or white blossoms.</cd> -- <col><b>Mexican
tea</b></col> <pos>prop. n.</pos> <fld>(Bot.)</fld>, <cd>an aromatic
kind of pigweed from tropical America (<spn>Chenopodium
ambrosioides</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mexicanize</ent><br/
<hw>Mex"i*can*ize</hw> <pr>(?)</pr>, <pos>prop. v. t.</pos> <def>To
cause to be like the Mexicans, or their country.</def> <note>At one time
this word referred to frequent revolutions of government, considered
characteristic of Mexican politics.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mexicanize</ent><br/
<hw>Mex"i*can*ize</hw>, <pos>prop. v. i.</pos> <def>To become like the
Mexicans, or their country or government.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Meyne</ent><br/
<hw>Meyn"e</hw> <pr>(m<ecr/n"<esl/)</pr>, <pos>n.</pos>
<mark>[Obs.]</mark> <def>Same as <er>Meine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezcal</ent><br/
<hw>Mez*cal"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mescal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezereon</ent><br/
<hw>Me*ze"re*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/z<eacute/r<eacute/on</ets>, Per.
<ets>m<amac/zriy<umac/n</ets>.]</ety> <fld>(Bot.)</fld> <def>A small
European shrub (<spn>Daphne Mezereum</spn>), whose acrid bark is used in
medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezquita</ent><br/
\'d8<hw>Mez*qui"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>A mosque.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezuzoth</ent><br/
<ent>Mezuzah</ent><br/
<ent>Mezuza</ent><br/
<mhw><hw>Me*zu"za</hw>, <hw>Me*zu"zah</hw>, <hw>Mez"u*zoth</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>m<ecr/z<umac/z<omac/th</ets>, pl. of
<ets>m<ecr/z<umac/z<amac/h</ets> doorpost.]</ety> <def>A piece of
parchment bearing the Decalogue and attached to the doorpost; -- in use
among orthodox Hebrews. The term is also used to refer to the small case
containing this scroll, together with the biblical inscription inside.
The text is usually taken from Deuteronomy 6:4-9 and 11:13-21.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mezza majolica</ent><br/
\'d8<hw>Mez"za ma*jol"i*ca</hw> <pr>(?)</pr>. <ety>[It. See
<er>Mezzo</er>; <er>Majolica</er>.]</ety> <fld>(Ceramics)</fld>
<def>Italian pottery of the epoch and general character of majolica, but
less brilliantly decorated, esp. such pottery without tin enamel, but
painted and glazed.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mezzanine</ent><br/
<hw>Mez"za*nine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mezzanine</ets>, It. <ets>mezzanino</ets>, fr. <ets>mezzano</ets>
middle, fr. <ets>mezzo</ets> middle, half. See <er>Mezzo</er>.]</ety>
<sn>1.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>Same as
<er>Entresol</er>.</def> <sd>(b)</sd> <def>A partial story which is not
on the same level with the story of the main part of the edifice, as of
a back building, where the floors are on a level with landings of the
staircase of the main house.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flooring laid over a floor to bring it up to some
height or level.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> Also <col><b>mezzanine floor</b></col>.
<fld>(Theat.)</fld> <def>A floor under the stage, from which various
contrivances, as traps, are worked.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>The lowest balcony in a theater, or the forward part
of the first balcony.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mezza voce</ent><br/
\'d8<hw>Mez"za vo"ce</hw> <pr>(?)</pr>. <ety>[It., fr. <ets>mezzo</ets>,
fem. <ets>mezza</ets> middle, half + <ets>voce</ets> voice, L.
<ets>vox</ets>.]</ety> <fld>(Mus.)</fld> <def>With a medium fullness of
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzo</ent><br/
\'d8<hw>Mez"zo</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It., from L.
<ets>medius</ets> middle, half. See <er>Mid</er>, <pos>a.</pos>]</ety>
<fld>(Mus.)</fld> <def>Mean; not extreme.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzo-relievo</ent><br/
<hw>Mez"zo-re*lie"vo</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Mezzo-rilievo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzo-rilievo</ent><br/
\'d8<hw>Mez"zo-ri*lie"vo</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[It.]</ety> <sd>(a)</sd> <def>A middle degree of relief in figures,
between high and low relief.</def> <sd>(b)</sd> <def>Sculpture in this
kind of relief. See under <er>Alto-rilievo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzo-soprano</ent><br/
<hw>Mez"zo-so*pra"no</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Mus.)</fld>
<def>Having a medium compass between the soprano and contralto; -- said
of the voice of a female singer.</def> -- <def2><pos>n.</pos>
<sd>(a)</sd> <def>A mezzo-soprano voice.</def> <sd>(b)</sd> <def>A
person having such a voice.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzotint</ent><br/
<hw>Mez"zo*tint</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mezzo-tinto</ets>.]</ety> <def>A manner of engraving on copper or
steel by drawing upon a surface previously roughened, and then removing
the roughness in places by scraping, burnishing, etc., so as to produce
the requisite light and shade. Also, an engraving so produced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzotint</ent><br/
<hw>Mez"zo*tint</hw>, <pos>v. t.</pos> <def>To engrave in
mezzotint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzotinter</ent><br/
<hw>Mez"zo*tint`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
engraves in mezzotint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzotinto</ent><br/
<hw>Mez`zo*tin"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>mezzo</ets> half + <ets>tinto</ets> tinted, p. p. of
<ets>tingere</ets> to dye, color, tinge, L. <ets>tingere</ets>. See
<er>Mezzo</er>.]</ety> <def>Mezzotint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mezzotinto</ent><br/
<hw>Mez`zo*tin"to</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mezzotintoed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mezzotintoing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
engrave in mezzotint; to represent by mezzotint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mho</ent><br/
<hw>Mho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Anagram of
<ets>ohm</ets>.]</ety> <fld>(Elec.)</fld> <def>A unit of conductivity,
being the reciprocal of the ohm.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mhometer</ent><br/
<hw>Mhom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mho</ets> +
<ets>-meter</ets>.]</ety> <fld>(Elec.)</fld> <def>An instrument for
measuring conductivity.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mhorr</ent><br/
<hw>Mhorr</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Mohr</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mi</ent><br/
<hw>Mi</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>A syllable applied to the third tone of the scale
of C, <it>i. e.</it>, to E, in European solmization, but to the third
tone of any scale in the American system.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miamis</ent><br/
<hw>Mi*a"mis</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Miami</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld> <def>A
tribe of Indians that formerly occupied the country between the Wabash
and Maumee rivers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miargyrite</ent><br/
<hw>Mi*ar"gy*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ less +
<?/ silver. So called because it contains less silver than some kindred
ore.]</ety> <fld>(Min.)</fld> <def>A mineral of an iron-black color, and
very sectile, consisting principally of sulphur, antimony, and
silver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mias</ent><br/
<hw>Mi"as</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Malayan.]</ety>
<def>The orang-outang.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miascite</ent><br/
<hw>Mi*asc"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named from
<ets>Miask</ets>, in the Ural Mountains.]</ety> <fld>(Min.)</fld> <def>A
granitoid rock containing feldspar, biotite, elaeolite, and
sodalite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miasm</ent><br/
<hw>Mi"asm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>miasme</ets>.]</ety> <def>Miasma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miasma</ent><br/
<hw>Mi*as"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Miasmata</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/
defilement, fr. <?/ to pollute.]</ety> <def>Infectious particles or
germs floating in the air; air made noxious by the presence of such
particles or germs; noxious effluvia; malaria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miasmal</ent><br/
<hw>Mi*as"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing miasma;
miasmatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miasmatical</ent><br/
<ent>Miasmatic</ent><br/
<mhw>{ <hw>Mi`as*mat"ic</hw> <pr>(?)</pr>, <hw>Mi`as*mat"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>miasmatique</ets>.]</ety> <def>Containing, or relating to, miasma;
caused by miasma; <as>as, <ex>miasmatic</ex> diseases</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miasmatist</ent><br/
<hw>Mi*as"ma*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who has made
a special study of miasma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miasmology</ent><br/
<hw>Mi`as*mol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Miasma</ets> + <ets>-logy</ets>.]</ety> <def>That department
of medical science which treats of miasma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miaul</ent><br/
<hw>Mi*aul"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Miauled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Miauling</conjf>.]</vmorph> <ety>[Cf. F. <ets>miauler</ets>, of
imitative origin, and E. <ets>mew</ets>. Cf. <er>Mewl</er>.]</ety>
<def>To cry as a cat; to mew; to caterwaul.</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miaul</ent><br/
<hw>Mi*aul"</hw>, <pos>n.</pos> <def>The crying of a cat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mica</ent><br/
<hw>Mi"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>mica</ets>
crumb, grain, particle; cf. F. <ets>mica</ets>.]</ety> <fld>(Min.)</fld>
<def>The name of a group of minerals characterized by highly perfect
cleavage, so that they readily separate into very thin leaves, more or
less elastic. They differ widely in composition, and vary in color from
pale brown or yellow to green or black. The transparent forms are used
in lanterns, the doors of stoves, etc., being popularly called
<altname>isinglass</altname>. Formerly called also
<altname>cat-silver</altname>, and <altname>glimmer</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<note>
<p><hand/ The important species of the <xex>mica group</xex> are:
<stype>muscovite</stype>, common or potash mica, pale brown or green,
often silvery, including <stype>damourite</stype> (also called
<altname>hydromica</altname> and <altname>muscovy glass</altname>);
<stype>biotite</stype>, iron-magnesia mica, dark brown, green, or black;
<stype>lepidomelane</stype>, iron, mica, black;
<stype>phlogopite</stype>, magnesia mica, colorless, yellow, brown;
<stype>lepidolite</stype>, lithia mica, rose-red, lilac.<br/
[<source>1913 Webster</source>]</p>

<p> <ex>Mica</ex> (usually muscovite, also biotite) is an essential
constituent of granite, gneiss, and mica slate; <stype>biotite</stype>
is common in many eruptive rocks; <stype>phlogopite</stype> in
crystalline limestone and serpentine.<br/
[<source>1913 Webster</source>]</p>
</note>

<p><cs><col><b>Mica diorite</b></col> <fld>(Min.)</fld>, <cd>an eruptive
rock allied to diorite but containing mica (biotite) instead of
hornblende.</cd> -- <col><b>Mica powder</b></col>, <cd>a kind of
dynamite containing fine scales of mica.</cd> -- <mcol><col><b>Mica
schist</b></col>, <col><b>Mica slate</b></col></mcol>
<fld>(Geol.)</fld>, <cd>a schistose rock, consisting of mica and quartz
with, usually, some feldspar.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micaceo-calcareous</ent><br/
<hw>Mi*ca`ce*o-cal*ca"re*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Geol.)</fld> <def>Partaking of the nature of, or consisting of,
mica and lime; -- applied to a mica schist containing carbonate of
lime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micaceous</ent><br/
<hw>Mi*ca"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>micac<eacute/</ets>.]</ety> <def>Pertaining to, or containing,
mica; splitting into laminae or leaves like mica.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mice</ent><br/
<hw>mice</hw> <pr>(m<imac/s)</pr>, <pos>n.</pos>, <def><pos>pl.</pos> of
<er>Mouse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micella</ent><br/
\'d8<hw>Mi*cel"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Micellae</plw> <pr>(#)</pr>.</plu> <ety>[NL., dim. of L.
<ets>mica</ets> a morsel, grain.]</ety> <fld>(Biol.)</fld> <def>A
theoretical aggregation of molecules constituting a structural particle
of protoplasm, capable of increase or diminution without change in
chemical nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miche</ent><br/
<ent>Mich</ent><br/
<mhw>{ <hw>Mich</hw>, <hw>Miche</hw> }</mhw> <pr>(?)</pr>, <pos>v.
i.</pos> <ety>[OE. <ets>michen</ets>; cf. OE. <ets>muchier</ets>,
<ets>mucier</ets>, to conceal, F. <ets>musser</ets>, and OHG.
<ets>m<umac/hhen</ets> to waylay. Cf. <er>Micher</er>,
<er>Curmudgeon</er>, <er>Muset</er>.]</ety> <def>To lie hid; to skulk;
to act, or carry one's self, sneakingly.</def> <mark>[Obs. or
Colloq.]</mark> <altsp>[Written also <asp>meach</asp> and
<asp>meech</asp>.]</altsp> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Michaelmas</ent><br/
<hw>Mich"ael*mas</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Michael</ets> + <ets>mass</ets> religious service; OE.
<ets>Mighelmesse</ets>.]</ety> <def>The feast of the archangel Michael,
a church festival, celebrated on the 29th of September. Hence,
colloquially, autumn.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Michaelmas daisy</b></col>. <fld>(Bot.)</fld> <cd>See
under <er>Daisy</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Michelangelesque</ent><br/
<hw>Michelangelesque</hw> <pos>prop. adj.</pos> <def>Of or pertaining to
Michelangelo.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Michelangelo</ent><br/
<hw>Michelangelo</hw> <pr>(m<imac/`k<ecr/l*<acr/n"j<esl/*l<osl/; It.
pron. m<esl/`k<ecr/l*<aum/n"j<esl/*l<osl/)</pr> <pos>prop. n.</pos>
<def>Michelangelo Buonarroti, renowned Italian painter, sculptor and
architect; 1475-1564.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><bio> Born <person><b>Michelagnolo Buonarroti</b></person> at
Caprese, March 6, 1475: died at Rome, Feb. 18, 1564. A famous Italian
sculptor, painter, architect, and poet. He came of an ancient but poor
Florentine family. He was apprenticed to the painter
<persfn>Ghirlandajo</persfn> April 1, 1488, and with other boys from the
atelier began soon after to study the antique marbles collected by
<person>Lorenzo de' Medici</person> in the garden of San Marco. Lorenzo
discovered him there, and in 1489 took him into his palace, where he had
every opportunity for improvement and study. The Centaur relief in the
Casa Buonarroti was made at this time, at the suggestion of
<person>Angelo Poliziano</person>. In 1491 he came under the influence
of <persfn>Savonarola</persfn>, whom he always held in great reverence.
In 1492 <persfn>Lorenzo</persfn> died, and Michelangelo's intimate
relations with the Medici family terminated. In 1493 he made a large
wooden crucifix for the prior of S. Spirito, and with the assistance of
the prior began the profound study of anatomy in which he delighted.
Before the expulsion of the Medici he fled to Bologna, where he was soon
engaged upon the Arca di San Domenico begun by <person>Niccolo
Pisano</person> in 1265, to which he added the well-known kneeling angel
of Bologna. He was probably much influenced by the reliefs of
<person>Della Quercia</person> about the door of San Petronio: two of
these he afterward imitated in the Sistine chapel. In 1495 he returned
to Florence, when he is supposed to have made the San Giovannino in the
Berlin Museum. From 1496 to 1501 he lived in Rome. To this period are
attributed the Bacchus of the Bargello and the Cupid of the South
Kensington Museum. The most important work of this time is the
Piet<agrave/ di San Pietro (1408). In 1501 he returned to
<city>Florence</city>, and Sept. 18 began the great David of the
Signoria, made from a block of marble abandoned by <person>Agostino di
Duccio</person>, which was placed in position May 18, 1504. The two
roundels of the Madonna and Child in Burlington House and the Bargello
were probably made then, and also the picture of the Holy Family in the
Uffizi. In 1503 <person>Piero Soderini</person>, gonfaloniere, projected
two frescos for the Sala Grande of the Palazzo Vecchio. The commission
for one was given to <person>Leonardo da Vinci</person>, that for the
other to <persfn>Michelangelo</persfn> in 1504. For it he prepared the
great cartoon of the Battle of Cascina, an incident in the war with Pisa
when, July 28, 1364, a band of 400 Florentines were attacked while
bathing by <person>Sir John Hawkwood's</person> English troopers. This
cartoon contained 288 square feet of surface, and was crowded with nude
figures in every position. It had, probably, more influence upon the art
of the Renaissance than any other single work. To about this time may be
attributed the beginning of his poetic creations, of the multitude of
which undoubtedly written a few only have come down to us. In Nov.,
1505, he was called to Rome by <person>Pope Julius II.</person> to
design his mausoleum, the history of which runs through the entire life
of the master. Repeated designs and repeated attempts to carry them out
were made, only to be frustrated by the successors of the great Pope.
The matter finally ended in the reign of <person>Paul III.</person> by
the placing in San Pietro in Vincoli of the statue of
<persfn>Moses</persfn> surrounded by mediocre works finished by
<person>Raffaello da Montelupo</person> and others. The Two Captives of
the Louvre are part of the work as originally designed. In the spring of
1506 he assisted in the discovery of the Laocoon in the palace of Titus.
His favorite antique was the Belvedere Torso, supposed to be a copy of
the Hercules Epitrapezius of Lysippus. In April, 1506, probably as a
result of the intrigues of <persfn>Bramante</persfn>, he was forced to
abandon <city>Rome</city> for <city>Florence</city>. In the autumn he
joined the Pope at <city>Bologna</city>, and made (1506-07) the bronze
statue of <persfn>Julius</persfn> which stood over the door of San
Petronio and was destroyed in 1511. The ceiling of the Sistine Chapel
was begun early in 1508, and finished in Oct., 1512. <person>Julius
II.</person> died Feb. 21, 1513, and was succeeded by <person>Cardinal
Giovanni de' Medici</person>, son of the great <persfn>Lorenzo</persfn>,
as <person>Leo X,</person> <persfn>Michelangelo</persfn> was diverted
from the tomb of <persfn>Julius</persfn> by <persfn>Leo</persfn>, and
employed from 1517 to 1520 in an abortive attempt to build the
fa<cced/ade of San Lorenzo in <city>Florence</city>, and in developing
the quarries of Carrara and Seravezza. In 1520 he began, by order of
<person>Cardinal Giulio de' Medici</person>, the sacristy of San Lorenzo
and the tombs of <persfn>Giuliano</persfn> and <person>Lorenzo de'
Medici</person> with the famous reclining figures on the sarcophagi,
perhaps the most thoroughly characteristic of all his works. <person>Leo
X.</person> was succeeded by <person>Adrian VI.</person> in 1521, and he
in turn by <person>Giulio de' Medici</person> as <person>Clement
VII.</person> in 1523. On April 6, 1529, <persfn>Michelangelo</persfn>
was appointed "governor and procurator-general over the construction and
fortification of the city walls" in <city>Florence</city>. On Sept. 21,
1529, occurred his unexplained flight to <city>Venice</city>. He
returned Nov. 20 of the same year, and was engaged in the defense of the
city until its capitulation, Aug. 12, 1530. Before the end of the year
1534 he left <city>Florence</city>, never to return. The statues of the
sacristy, including the Madonna and Child, were arranged after his
departure. <person>Alessandro Farnese</person> succeeded <person>Clement
VII.</person> as <person>Paul III.</person>, Oct., 1534. The Last
Judgment was begun about Sept. 1, 1535, and finished before Christmas,
1541. Michelangelo's friendship for <person>Vittoria Colonna</person>
began about 1538. (See Colonna, Vittoria.) The frescos of the Pauline
Chapel were painted between 1542 and 1549. They represent the conversion
of <person>St. Paul</person> and the martyrdom of <person>St.
Peter</person>. He succeeded <person>Antonio da Sangallo</person> in
1546 in the offices which he held, and became architect of St Peter's
Jan. 1, 1547. From this time until his death he worked on the church
without compensation. The dome alone was completed with any regard to
his plans.</bio><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Micher</ent><br/
<hw>Mich"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>michare</ets>, <ets>muchare</ets>. See <er>Mich</er>.]</ety>
<def>One who skulks, or keeps out of sight; hence, a truant; an idler; a
thief, etc.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Michery</ent><br/
<hw>Mich"er*y</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>Theft;
cheating.</def> <mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Michigander</ent><br/
<hw>Michigander</hw> <pos>n.</pos> <def>A resident of
Michigan.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Miching</ent><br/
<hw>Mich"ing</hw>, <pos>a.</pos> <def>Hiding; skulking; cowardly.</def>
<mark>[Colloq.]</mark> <altsp>[Written also <asp>meaching</asp> and
<asp>meeching</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mickey</ent><br/
<ent>Mick</ent><br/
<mhw><hw>Mick</hw>, <hw>Mickey</hw></mhw> <pos>n.</pos> <def>a person of
Irish descent; -- an ethnic slur, offensive and disparaging.</def><br/
<syn><b>Syn. --</b> Paddy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 921 --></p>

<p><ent>Mickle</ent><br/
<hw>Mic"kle</hw> <pr>(m<icr/k"k'l)</pr>, <pos>a.</pos> <ety>[OE.
<ets>mikel</ets>, <ets>muchel</ets>, <ets>mochel</ets>,
<ets>mukel</ets>, AS. <ets>micel</ets>, <ets>mycel</ets>; akin to OS.
<ets>mikil</ets>, OHG. <ets>mihil</ets>, <ets>mihhil</ets>, Icel.
<ets>mikill</ets>, <ets>mykill</ets>, Goth. <ets>mikils</ets>, L.
<ets>magnus</ets>, Gr. <grk>me`gas</grk>, gen. <grk>mega`loy</grk>; cf.
Skr. <ets>mahat</ets>. <root/103. Cf. <er>Much</er>, <er>Muckle</er>,
<er>Magnitude</er>.]</ety> <def>Much; great.</def> <altsp>[Written also
<asp>muckle</asp> and <asp>mockle</asp>.]</altsp> <mark>[Old Eng. &
Scot.]</mark> <ldquo/A man of <xex>mickle</xex> might.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micmacs</ent><br/
<hw>Mic"macs</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Micmac</singw> <pr>(<?/)</pr>.</sing> <fld>(Ethnol.)</fld> <def>A
tribe of Indians inhabiting Nova Scotia and New Brunswick.</def>
<altsp>[Written also <asp>Mikmaks</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mico</ent><br/
<hw>Mi"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. or Pg.
<ets>mico</ets>.]</ety> <fld>(Zool.)</fld> <def>A small South American
monkey (<spn>Mico melanurus</spn>), allied to the marmoset. The name was
originally applied to an albino variety.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micracoustic</ent><br/
<hw>Mi`cra*cous"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Microustic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micraster</ent><br/
\'d8<hw>Mi*cras"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>mikro`s</grk> small + <?/ star.]</ety> <fld>(Paleon.)</fld> <def>A
genus of sea urchins, similar to Spatangus, abounding in the chalk
formation; -- from the starlike disposal of the ambulacral
furrows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrencephalous</ent><br/
<hw>Mi`cren*ceph"a*lous</hw> <pr>(?)</pr>, <ety>[<ets>Micr-</ets> + Gr.
<?/ brain.]</ety> <def>Having a small brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micr-</ent><br/
<ent>Micro-</ent><br/
<mhw>{ <hw>Mi"cro-</hw> <pr>(?)</pr>, <hw>Mi"cr-</hw> }</mhw>. <ety>[Gr.
<grk>mikro`s</grk> small.]</ety> <def>A combining form</def> signifying:
<sd>(a)</sd> <def><sig>Small</sig>, <sig>little</sig>,
<sig>trivial</sig>, <sig>slight</sig>; <as>as, <ex>micro</ex>cosm,
<ex>micro</ex>scope</as>.</def> <sd>(b)</sd> <fld>(Metric System, Elec.,
Mech., etc.)</fld> <def><sig>A millionth part of</sig>; <as>as,
<ex>micro</ex>farad, <ex>micro</ex>ohm,
<ex>micro</ex>meter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microampere</ent><br/
<hw>Mi`cro*am`p<egrave/re"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micr-</ets> + <ets>amp<egrave/re</ets>.]</ety>
<fld>(Elec.)</fld> <def>One of the smaller measures of electrical
currents; the millionth part of one amp<egrave/re.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microanalysis</ent><br/
<hw>Mi`cro*a*nal"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>analysis</ets>.]</ety> <sn>1.</sn>
<def>Analysis of the structure of materials from careful observation of
photomicrographs.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Chemical analysis of very small
quantities of substances, requiring special apparatus to handle and
weigh small amounts of materials.</def><br/
[<source>PJC</source>]</p>

<p><ent>Microbacteria</ent><br/
\'d8<hw>Mi`cro*bac*te"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Micro-</er>, and <er>Bacterium</er>.]</ety>
<fld>(Biol.)</fld> <def>In the classification of <persfn>Cohn</persfn>,
one of the four tribes of Bacteria.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this classification bacteria are divided into four
tribes: 1. <fam>Spherobacteria</fam>, or spherical bacteria, as the
genus <gen>Micrococcus</gen>. 2. <fam>Microbacteria</fam>, or bacteria
in the form of short rods, including the genus <gen>Bacterium</gen>. 3.
<fam>Desmobacteria</fam>, or bacteria in straight filaments, of which
the genus <gen>Bacillus</gen> is a type. 4. <fam>Spirobacteria</fam>, or
bacteria in spiral filaments, as the genus <gen>Vibrio</gen>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microbarograph</ent><br/
<hw>Mi`cro*bar"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>barograph</ets>.]</ety> <def>An
instrument for recording minor fluctuations of atmospheric pressure, as
opposed to general barometric surges.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microbion</ent><br/
<ent>Microbe</ent><br/
<mhw>{ <hw>Mi"crobe</hw> <pr>(?)</pr>, \'d8<hw>Mi*cro"bi*on</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>microbion</ets>, fr.
Gr. <?/ little + <?/ life.]</ety> <fld>(Biol.)</fld> <def>A microscopic
organism; a microorganism; -- particularly applied to bacteria and
especially to pathogenic forms; <as>as, the <ex>microbe</ex> of fowl
cholera</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>microbian</ent><br/
<ent>microbial</ent><br/
<mhw><hw>mi*cro"bi*al</hw>, <hw>mi*cro"bi*an</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <fld>(Biol.)</fld> <def>Of, pertaining to, or caused by,
microbes; <as>as, <ex>microbial</ex> growth; the <ex>microbian</ex>
theory; a <ex>microbian</ex> disease.</as></def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Microbic</ent><br/
<hw>Mi*crob"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of or pertaining to a microbe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microbicide</ent><br/
<hw>Mi*crob"i*cide</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Microbe</ets> + L. <ets>caedere</ets> to kill.]</ety>
<fld>(Biol.)</fld> <def>Any agent detrimental to, or destructive of, the
life of microbes or bacterial organisms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microbiology</ent><br/
<hw>Mi`cro*bi*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Microbe</er>; <er>-logy</er>.]</ety> <def>The branch of biology
studying minute organisms, or microbes, such as the bacteria, fungi,
viruses, and protozoa.</def> --
<wordforms><wf>Mi`cro*bi`o*log"ic*al</wf> <pr>(#)</pr>, <pos>a.</pos> --
<wf>Mi`cro*bi*ol"o*gist</wf> <pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Microcephalous</ent><br/
<ent>Microcephalic</ent><br/
<mhw>{ <hw>Mi`cro*ce*phal"ic</hw> <pr>(?)</pr>,
<hw>Mi`cro*ceph"a*lous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Micro-</ets> + <ets>cephalic</ets>,
<ets>cephalous</ets>.]</ety> <fld>(Anat.)</fld> <def>Having a small
head; having the cranial cavity small; -- opposed to
<ant>megacephalic</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>micro-chemical</ent><br/
<ent>microchemical</ent><br/
<mhw><hw>mi`cro*chem"ic*al</hw>, <hw>mi`cro-chem"ic*al</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to microchemistry;
<as>as, a <ex>micro-chemical</ex> test</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>micro-chemistry</ent><br/
<ent>microchemistry</ent><br/
<mhw><hw>mi`cro*chem"is*try</hw>, <hw>mi`cro-chem"is*try</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets> +
<ets>chemistry</ets>.]</ety> <def>The application of chemical tests to
minute objects or portions of matter, usually assisted by sensitive
instruments; -- distinguished from <xex>macro-chemistry</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microchronometer</ent><br/
<hw>Mi`cro*chro*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
chronoscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcline</ent><br/
<hw>Mi"cro*cline</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + Gr. <?/ to incline.]</ety> <fld>(Min.)</fld>
<def>A mineral of the feldspar group, like orthoclase or common feldspar
in composition, but triclinic in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrococcal</ent><br/
<hw>Mi`cro*coc"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to micrococci; caused by micrococci.</def>
<rj><au>Nature.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrococcus</ent><br/
\'d8<hw>Mi`cro*coc"cus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Micrococci</plw> <pr>(#)</pr>.</plu> <ety>[NL.
See <er>Micro-</er>, and <er>Coccus</er>.]</ety> <fld>(Biol.)</fld>
<def>A genus of <fam>Spherobacteria</fam>, in the form of very small
globular or oval cells, forming, by transverse division, filaments, or
chains of cells, or in some cases single organisms shaped like
dumb-bells (<gen>Diplococcus</gen>), all without the power of motion.
See <xex>Illust.</xex> of <er>Ascoccus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Physiologically, micrococci are divided into three
groups; <xex>chromogenic</xex>, characterized by their power of forming
pigment; <xex>zymogenic</xex>, including those associated with definite
chemical processes; and <xex>pathogenic</xex>, those connected with
disease.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>microcomputer</ent><br/
<hw>microcomputer</hw> <pos>n.</pos> <def>A small computer based on a
microprocessor; in practise, at any given time in the technology of
computer development, a <ex>microcomputer</ex> will be one that is less
powerful than a <contr>minicomputer</contr>.</def><br/
<syn><b>Syn. --</b> personal computer, PC.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Microcosm</ent><br/
<hw>Mi"cro*cosm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>microcosme</ets>, L. <ets>microcosmus</ets>, fr. Gr.
<grk>mikro`s</grk> small + <grk>ko`smos</grk> the world.]</ety>
<sn>1.</sn> <def>A little world; a miniature universe. Hence (so called
by Paracelsus), a man, as a supposed epitome of the exterior universe or
great world. Opposed to <contr>macrocosm</contr>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A relatively small object or system considered as
representative of a larger system of which it is part, exhibiting many
features of the complete system.</def><br/
[<source>PJC</source>]</p>

<p><ent>Microcosmical</ent><br/
<ent>Microcosmic</ent><br/
<mhw>{ <hw>Mi`cro*cos"mic</hw> <pr>(?)</pr>, <hw>Mi`cro*cos"mic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>microcosmique</ets>.]</ety> <def>Of or pertaining to the
microcosm.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Microcosmic salt</b></col> <fld>(Chem.)</fld>, <cd>a
white crystalline substance obtained by mixing solutions of sodium
phosphate and ammonium phosphate, and also called
<altname>hydric-sodic-ammonic-phosphate</altname>. It is a powerful
flux, and is used as a substitute for borax as a blowpipe reagent in
testing for the metallic oxides. Originally obtained by the alchemists
from human urine, and called <altname>sal
microcosmicum</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcosmography</ent><br/
<hw>Mi`cro*cos*mog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Microcosm</ets> + <ets>-graphy</ets>.]</ety> <def>Description
of man as a microcosm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcoulomb</ent><br/
<hw>Mi`cro*cou`lomb"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>coulomb</ets>.]</ety> <fld>(Elec.)</fld>
<def>A measure of electrical quantity; the millionth part of one
coulomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcoustic</ent><br/
<hw>Mi`cro*cous"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Micro-</ets> + <ets>acoustic</ets>: cf. F.
<ets>microcoustique</ets>, <ets>micracoustique</ets>.]</ety>
<def>Pertaining, or suited, to the audition of small sounds; fitted to
assist hearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcoustic</ent><br/
<hw>Mi`cro*cous"tic</hw>, <pos>n.</pos> <def>An instrument for making
faint sounds audible, as to a partially deaf person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcrith</ent><br/
<hw>Mi`cro*crith"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>crith</ets>.]</ety> <fld>(Chem.)</fld>
<def>The weight of the half hydrogen molecule, or of the hydrogen atom,
at one time taken as the standard in comparing the atomic weights of the
elements; <as>thus, an atom of oxygen weighs sixteen
<ex>microcriths</ex>. This unit is no longer used, and has been replaced
by the <altname>Dalton</altname>, which is of approximately the same
value. See <er>molecular weight</er> and <er>Crith</er></as>.</def>
<rj><au>J. P. Cooke.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Microcrystalline</ent><br/
<hw>Mi`cro*crys"tal*line</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Micro-</ets> + <ets>crystalline</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Crystalline on a fine, or microscopic,
scale; consisting of fine crystals; <as>as, the ground mass of certain
porphyrics is <ex>microcrystalline</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microcyte</ent><br/
<hw>Mi"cro*cyte</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ Gr. <?/ a hollow vessel.]</ety> <fld>(Physiol.)</fld> <def>One of the
elementary granules found in blood. They are much smaller than an
ordinary corpuscle, and are particularly noticeable in disease, as in
anaemia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microdont</ent><br/
<hw>Mic"ro*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Micr-</ets>
+ Gr. <grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, a tooth.]</ety>
<fld>(Anat.)</fld> <def>Having small teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microfarad</ent><br/
<hw>Mi`cro*far"ad</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>farad</ets>.]</ety> <fld>(Elec.)</fld>
<def>The millionth part of a farad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microfilm</ent><br/
<hw>Mic"ro*film</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ <ets>film</ets>.]</ety> <def>a photographic film with one or more very
small images of printed or other graphic matter. Numerous images,
corresponding to the contents of a book, newspaper, or journal, are
typically produced on one long roll of film, and may be viewed for
reading in a special apparatus called a <usedby>microfilm
reader</usedby>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Microfilm</ent><br/
<hw>Mic"ro*film</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>to photograph
and produce images of on microfilm.</def><br/
[<source>PJC</source>]</p>

<p><ent>Microform</ent><br/
<hw>Mi"cro*form</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ <ets>form</ets>, n.]</ety> <fld>(Biol.)</fld> <def>A microscopic form
of life; an animal or vegetable organism of microscopic size.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micro-geological</ent><br/
<hw>Mi`cro-ge`o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to micro-geology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micro-geology</ent><br/
<hw>Mi`cro-ge*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>geology</ets>.]</ety> <def>The part of
geology relating to structure and organisms which require to be studied
with a microscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrograph</ent><br/
<hw>Mi"cro*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Micrography</er>.]</ety> <sn>1.</sn> <def>An instrument for
executing minute writing or engraving.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a graphic image, such as a photograph or drawing,
representing an object as seen with a microscope, usually much enlarged
as compared with the original object. A photograph of a microscopic
image is also called a <altname>photomicrograph</altname> or
<altname>microphotograph</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Micrographic</ent><br/
<hw>Mi`cro*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to micrography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrography</ent><br/
<hw>Mi*crog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>-graphy</ets>: cf. F.
<ets>micrographie</ets>.]</ety> <sn>1.</sn> <def>The description of
microscopic objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Examination or study by means of the microscope, as
of an etched surface of metal to determine its structure.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microhm</ent><br/
<hw>Mi*crohm"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micr-</ets> +
<ets>ohm</ets>.]</ety> <fld>(Elec.)</fld> <def>The millionth part of an
ohm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microlepidoptera</ent><br/
\'d8<hw>Mi`cro*lep`i*dop"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Micro-</er>, and <er>Lepidoptera</er>.]</ety>
<fld>(Zool.)</fld> <def>A tribe of <ord>Lepidoptera</ord>, including a
vast number of minute species, as the plume moth, clothes moth,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microlestes</ent><br/
\'d8<hw>Mi`cro*les"tes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>mikro`s</grk> small + <?/ a robber.]</ety> <fld>(Paleon.)</fld>
<def>An extinct genus of small Triassic mammals, the oldest yet found in
European strata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microlite</ent><br/
<hw>Mi"cro*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ <ets>-lite</ets>.]</ety> <fld>(Min.)</fld><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A rare mineral of resinous luster and high specific
gravity. It is a tantalate of calcium, and occurs in octahedral crystals
usually very minute.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>A minute inclosed crystal, often
observed when minerals or rocks are examined in thin sections under the
microscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microlith</ent><br/
<hw>Mi"cro*lith</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ <ets>lith</ets>.]</ety> <fld>(Min.)</fld> <def>Same as
<er>Microlite</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microlithic</ent><br/
<hw>Mi`cro*lith"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed of small
stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrological</ent><br/
<ent>Micrologic</ent><br/
<mhw>{ <hw>Mi`cro*log"ic</hw> <pr>(?)</pr>, <hw>Mi`cro*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to micrology;
very minute; <as>as, <ex>micrologic</ex> examination</as>.</def> --
<wordforms><wf>Mi`cro*log"ic*al*ly</wf>, <pos>adv.</pos></wordforms><--
pref. = microscopic --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrology</ent><br/
<hw>Mi*crol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>-logy</ets>.]</ety> <sn>1.</sn> <def>That
part of science which treats of microscopic objects, or depends on
microscopic observation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Attention to petty items or differences.</def>
<rj><au>W. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>micromercurialism</ent><br/
<hw>micromercurialism</hw> <pos>n.</pos> <ety>[<ets>micro</ets> +
<ets>mercurialism</ets>. Coined by the chemist <person>A. Stock</person>
in 1926. See <er>mercurialism</er>.]</ety> <fu>(1926)</fu> <def>A form
of mercury poisoning resulting from long term exposure to low doses of
mercury. The syndrome of micromercurialism involves complex symptoms of
stress, fatigue, memory loss, fine tremors, muscular and reflex
insufficiency and low blood pressure, caused by accumulation of mercury
in the system. A condition of hyperthermia is accompanied by a series of
functional changes under the effects of mercury. The combined
simultaneous effect of toxic action, temperature and galvanic response
infers a cycle of disintegration and change.</def> <au>Work With Mercury
(1972)</au> <note>As proposed by Stock, the syndrome was considered as
the union of pathological changes in human body caused by means of low
concentrations (as low as 0.01 mg per cubic meter) of mercury vapor over
long exposure times (up to 10 years).</note><br/
[<source>PJC</source>]</p>

<p><ent>Micromere</ent><br/
<hw>Mi"cro*mere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ <ets>-mere</ets>.]</ety> <fld>(Biol.)</fld> <def>One of the smaller
cells, or blastomeres, resulting from the complete segmentation of a
telolecithal ovum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>micrometeorite</ent><br/
<hw>micrometeorite</hw> <pos>n.</pos> <def>A meteorite so small that it
drifts down to Earth without becoming intensely heated in the earth's
atmosphere.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>micrometeoritic</ent><br/
<hw>micrometeoritic</hw> <pos>adj.</pos> <def>of or relating to a
micrometeorite.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Micrometer</ent><br/
<hw>Mi*crom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>-meter</ets>: cf. F.
<ets>microm<egrave/tre</ets>.]</ety> <def>An instrument, used with a
telescope or microscope, for measuring minute distances, or the apparent
diameters of objects which subtend minute angles. The measurement given
directly is that of the image of the object formed at the focus of the
object glass.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Circular micrometer</b></col>, <it>or</it>
<col><b>Ring micrometer</b></col></mcol>, <cd>a metallic ring fixed in
the focus of the object glass of a telescope, and used to determine
differences of right ascension and declination between stars by
observations of the times at which the stars cross the inner or outer
periphery of the ring.</cd> -- <col><b>Double image
micrometer</b></col>, <cd>a micrometer in which two images of an object
are formed in the field, usually by the two halves of a bisected lens
which are movable along their line of section by a screw, and distances
are determined by the number of screw revolutions necessary to bring the
points to be measured into optical coincidence. When the two images are
formed by a bisected object glass, it is called a
<xex>divided-object-glass micrometer</xex>, and when the instrument is
large and equatorially mounted, it is known as a
<xex>heliometer</xex>.</cd> -- <col><b>Double refraction
micrometer</b></col>, <cd>a species of double image micrometer, in which
the two images are formed by the double refraction of rock crystal.</cd>
-- <mcol><col><b>Filar micrometer</b></col>, <it>or</it> <col><b>Bifilar
micrometer</b></col></mcol>. <cd>See under <er>Bifilar</er>.</cd> --
<mcol><col><b>Micrometer caliper</b></col> <it>or</it>
<col><b>Micrometer gauge</b></col></mcol> <fld>(Mech.)</fld>, <cd>a
caliper or gauge with a micrometer screw, for measuring dimensions with
great accuracy.</cd> -- <col><b>Micrometer head</b></col>, <cd>the head
of a micrometer screw.</cd> -- <col><b>Micrometer microscope</b></col>,
<cd>a compound microscope combined with a filar micrometer, used chiefly
for reading and subdividing the divisions of large astronomical and
geodetical instruments.</cd> -- <col><b>Micrometer screw</b></col>,
<cd>a screw with a graduated head used in some forms of micrometers;
turning the head one full revolution advances the position of the tip of
the screw only by a little.</cd> -- <col><b>Position
micrometer</b></col>. <cd>See under <er>Position</er>.</cd> --
<mcol><col><b>Scale micrometer</b></col>, <it>or</it> <col><b>Linear
micrometer</b></col></mcol>, <cd>a minute and very delicately graduated
scale of equal parts used in the field of a telescope or microscope, for
measuring distances by direct comparison.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrometrical</ent><br/
<ent>Micrometric</ent><br/
<mhw>{ <hw>Mi`cro*met"ric</hw> <pr>(?)</pr>, <hw>Mi`cro*met"ric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>microm<eacute/trique</ets>.]</ety> <def>Belonging to micrometry;
made by the micrometer.</def> --
<wordforms><wf>Mi`cro*met"ric*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micrometry</ent><br/
<hw>Mi*crom"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
measuring with a micrometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micromillimeter</ent><br/
<hw>Mi`cro*mil"li*me`ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>millimeter</ets>.]</ety> <def>The
millionth part of a meter.</def> <note>The millionth part of a meter is
now termed a <altname>micron</altname>, and the word
<ex>micromillimeter</ex> does not conform to the IS use of the prefix
<er>micro-</er>.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Micromyx</ent><br/
<hw>Micromyx</hw> <pos>prop. n.</pos> <def>A genus of Old World harvest
mice.</def><br/
<syn><b>Syn. --</b> genus <gen>Micromyx</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>micron</ent><br/
<hw>mic"ron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>mikro`s</grk> small.]</ety> <fld>(Physics)</fld> <def>A measure of
length; the thousandth part of one millimeter; the millionth part of a
meter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micronesian</ent><br/
<hw>Mi"cro*ne"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<ets>Micronesia</ets>, fr. Gr. <grk>mikro`s</grk> small +
<grk>nh^sos</grk> an island.]</ety> <def>Of or pertaining to Micronesia,
a collective designation of the islands in the western part of the
Pacific Ocean, embracing the Marshall and Gilbert groups, the Ladrones,
the Carolines, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micronesians</ent><br/
<hw>Mi`cro*ne"sians</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Micronesian</singw></sing>. <fld>(Ethnol.)</fld> <def>A dark race
inhabiting the Micronesian Islands. They are supposed to be a mixed
race, derived from Polynesians and Papuans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micronometer</ent><br/
<hw>Mi`cro*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + chro<ets>nometer</ets>.]</ety> <def>An
instrument for noting minute portions of time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microorganism</ent><br/
<hw>Mi`cro*or"gan*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>organism</ets>.]</ety> <fld>(Biol.)</fld>
<def>Any microscopic form of life; a form of life too small to be seen
by the naked eye; -- particularly applied to bacteria, protozoa, yeasts,
and similar organisms, esp. such are supposed to cause infectious
diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micropantograph</ent><br/
<hw>Mi`cro*pan"to*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>pantograph</ets>.]</ety> <def>A kind of
pantograph which produces copies microscopically minute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microparasite</ent><br/
<hw>Mi`cro*par"a*site</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A parasitic
microorganism.</def> -- <wordforms><wf>Mi`cro*par`a*sit"ic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Micropegmatite</ent><br/
<hw>Mi`cro*peg"ma*tite</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>pegmatite</ets>.]</ety> <fld>(Min.)</fld>
<def>A rock showing under the microscope the structure of a graphic
granite (pegmatite).</def> -- <wordforms><wf>Mi`cro*peg`ma*tit"ic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>microphone</ent><br/
<hw>mi"cro*phone</hw> <pr>(m<imac/"kr<osl/*f<omac/n)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + Gr. <grk>fwnh`</grk> sound, voice: cf. F.
<ets>microphone</ets>.]</ety> <fld>(Physics)</fld> <def>An instrument
for converting sounds into electrical signals, for the purpose of
recording or amplifying the sounds. It produces its effects in various
ways, as for example by the changes of intensity in an electric current,
occasioned by the variations in the contact resistance of conducting
bodies, especially of imperfect conductors, under the action of acoustic
vibrations. Other forms of microphone may use changes in capacitance or
other phenomena to transduce the sounds into electrical signals.</def>
<note>The electrical signals produced in a microphone may be transmitted
to recording or amplifying equipment through a conducting wire, or by
transmission as radio waves. The latter method is popular for use in
small mobile microphones used by performers in plays and other
entertainment events, at public meetings, and by broadcast
personnel.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>microphonic</ent><br/
<hw>mi`cro*phon"ic</hw> <pr>(m<imac/`kr<osl/*f<ocr/n"<icr/k)</pr>,
<pos>a.</pos> <def>Of or pertaining to a microphone; serving to
intensify weak sounds.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>microphonics</ent><br/
<hw>mi`cro*phon"ics</hw> <pr>(m<imac/`kr<osl/*f<ocr/n"<icr/ks)</pr>,
<pos>n.</pos> <ety>[See <er>Microphone</er>.]</ety> <def>The science
which treats of the means of increasing the intensity of low or weak
sounds, or of the microphone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>microphonous</ent><br/
<hw>mi*croph"o*nous</hw> <pr>(m<isl/*kr<ocr/f"<osl/*n<ucr/s or
m<icr/*kr<ocr/f"<osl/*n<ucr/s)</pr>, <pos>a.</pos> <def>Serving to
augment the intensity of weak sounds; microcoustic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>microphotograph</ent><br/
<hw>mi`cro*pho"to*graph</hw>
<pr>(m<imac/`kr<osl/*f<omac/"t<osl/*gr<adot/f or
m<icr/k`r<osl/*f<omac/"t<osl/*gr<adot/f)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>photograph</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A microscopically small photograph of a picture,
writing, printed page, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An enlarged representation of a microscopic object,
produced by throwing upon a sensitive plate the magnified image of an
object formed by a microscope or other suitable combination of
lenses.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A picture of this kind is preferably called a
<xex>photomicrograph</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microphotography</ent><br/
<hw>Mi`cro*pho*tog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art
of making microphotographs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microphthalmy</ent><br/
<ent>Microphthalmia</ent><br/
<mhw>{ <hw>Mi`croph*thal"mi*a</hw> <pr>(?)</pr>,
<hw>Mi`croph*thal"my</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[<ets>Micro-</ets> + Gr. <grk>'ofqalmo`s</grk> eye.]</ety> <def>An
unnatural smallness of the eyes, occurring as the result of disease or
of imperfect development.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microphyllous</ent><br/
<hw>Mi*croph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Micro-</ets> + Gr. <grk>fy`llon</grk> leaf.]</ety>
<fld>(Bot.)</fld> <def>Small-leaved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microphytal</ent><br/
<hw>Mi*croph"y*tal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Pertaining to, or of the nature of, microphytes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microphyte</ent><br/
<hw>Mi"cro*phyte</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + Gr. <?/ a plant: cf. F.
<ets>microphyte</ets>.]</ety> <fld>(Bot.)</fld> <def>A very minute
plant, one of certain unicellular algae, such as the germs of various
infectious diseases are believed to be.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Micropyle</ent><br/
<hw>Mi"cro*pyle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ Gr. <?/ gate, orifice: cf. F. <ets>micropyle</ets>.]</ety>
<fld>(Biol.)</fld> <sd>(a)</sd> <def>An opening in the membranes
surrounding the ovum, by which nutrition is assisted and the entrance of
the spermatozoa permitted.</def> <sd>(b)</sd> <def>An opening in the
outer coat of a seed, through which the fecundating pollen enters the
ovule.</def> -- <wordforms><wf>Mi*crop"y*lar</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microscopal</ent><br/
<hw>Mi*cros"co*pal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
microscopy, or to the use of the microscope.</def>
<rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microscope</ent><br/
<hw>Mi"cro*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>-scope</ets>.]</ety> <def>An optical
instrument, consisting of a lens, or combination of lenses, for making
an enlarged image of an object which is too minute to be viewed by the
<cref>naked eye</cref>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Compound microscope</b></col>, <cd>an instrument
consisting of a combination of lenses such that the image formed by the
lens or set of lenses nearest the object (called the
<xex>objective</xex>) is magnified by another lens called the
<xex>ocular</xex> or <xex>eyepiece</xex>.</cd> --
<mcol><col><b>Oxyhydrogen microscope</b></col>, and <col><b>Solar
microscope</b></col></mcol>. <cd>See under <er>Oxyhydrogen</er>, and
<er>Solar</er>.</cd> -- <mcol><col><b>Simple microscope</b></col>,
<it>or</it> <col><b>Single microscope</b></col></mcol>, <cd>a single
convex lens used to magnify objects placed in its focus.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microscopial</ent><br/
<hw>Mi`cro*sco"pi*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Microscopic.</def> <mark>[R.]</mark>
<rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microscopical</ent><br/
<ent>Microscopic</ent><br/
<mhw>{ <hw>Mi`cro*scop"ic</hw> <pr>(?)</pr>, <hw>Mi`cro*scop"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>microscopique</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of or pertaining to the microscope or to microscopy;
made with a microscope; <as>as, <ex>microscopic</ex>
observation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Able to see extremely minute objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why has not man a <qex>microscopic</qex> eye?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Very small.</def> <specif>Specifically,</specif>
<def>visible only by the aid of a microscope; <as>as, a
<ex>microscopic</ex> insect</as>; also used figuratively; <as>as, a
<ex>microscopic</ex> advantage</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Microscopically</ent><br/
<hw>Mi`cro*scop"ic*al*ly</hw>, <pos>adv.</pos> <def>By the microscope;
with minute inspection; in a microscopic manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microscopist</ent><br/
<hw>Mi*cros"co*pist</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <def>One
skilled in, or given to, microscopy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microscopy</ent><br/
<hw>Mi*cros"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The use of the
microscope; investigation with the microscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microseism</ent><br/
<hw>Mi"cro*seism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + Gr. <?/ an earthquake, fr. <?/ to
shake.]</ety> <def>A feeble earth tremor not directly perceptible, but
detected only by means of specially constructed apparatus.</def> --
<wordforms><wf>Mi`cro*seis"mic</wf> <pr>(#)</pr>,
<wf>Mi`cro*seis"mic*al</wf> <pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microseismograph</ent><br/
<hw>Mi`cro*seis"mo*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Microseiem</ets> + <ets>-graph</ets>.]</ety> <def>A
microseismometer; specif., a microseismometer producing a graphic
record.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microseismology</ent><br/
<hw>Mi`cro*seis*mol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Microseiem</ets> + <ets>-logy</ets>.]</ety> <def>Science or
study of microseisms.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microseismometer</ent><br/
<hw>Mi`cro*seis*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Microseism</ets> + <ets>-meter</ets>.]</ety> <def>A
seismometer for measuring amplitudes or periods, or both, of
microseisms.</def> -- <wordforms><wf>Mi`cro*seis*mom"e*try</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microseme</ent><br/
<hw>Mi"cro*seme</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Micro-</ets>
+ Gr. <?/ sign, mark: cf. F. <ets>micros<egrave/me</ets>.]</ety>
<fld>(Anat.)</fld> <def>Having the orbital index relatively small;
having the orbits broad transversely; -- opposed to
<ant>megaseme</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>microsome</ent><br/
<hw>microsome</hw> <pos>n.</pos> <fld>(Cell biology)</fld> <def>a tiny
granule in the cytoplasm of a cell; it consists of ribosomes bound to
fragments of the endoplasmic reticulum and mitochondria.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Microsorium</ent><br/
<hw>Microsorium</hw> <pos>prop. n.</pos> <def>A genus of tropical
usually epiphytic ferns, found from Africa to Asia, and from Polynesia
to Australia.</def><br/
<syn><b>Syn. --</b> genus <gen>Microsorium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 922 --></p>

<p><ent>Microspectroscope</ent><br/
<hw>Mi`cro*spec"tro*scope</hw>
<pr>(m<imac/`kr<osl/*sp<ecr/k"tr<osl/*sk<omac/p <it>or</it>
m<icr/`kr<osl/*sp<ecr/k"tr<osl/*sk<omac/p)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>spectroscope</ets>.]</ety>
<fld>(Physics)</fld> <def>A spectroscope arranged for attachment to a
microscope, for observation of the spectrum of light from minute
portions of any substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microsporangium</ent><br/
\'d8<hw>Mi`cro*spo*ran"gi*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
See <er>Micro-</er>, and <er>Sporangium</er>.]</ety> <fld>(Bot.)</fld>
<def>A sporangium or conceptacle containing only very minute spores. Cf.
<er>Macrosporangium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microspore</ent><br/
<hw>Mi"cro*spore</hw> <pr>(m<imac/"kr<osl/*sp<omac/r)</pr>,
<pos>n.</pos> <ety>[<ets>Micro-</ets> + <ets>spore</ets>.]</ety>
<fld>(Bot.)</fld> <def>One of the exceedingly minute spores found in
certain flowerless plants, as <gen>Selaginella</gen> and
<gen>Isoetes</gen>, which bear two kinds of spores, one very much
smaller than the other. Cf. <er>Macrospore</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microsporic</ent><br/
<hw>Mi`cro*spor"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Of or pertaining to microspores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microsthene</ent><br/
<hw>Mi"cro*sthene</hw> <pr>(m<imac/"kr<osl/*sth<emac/n)</pr>,
<pos>n.</pos> <ety>[<ets>Micro-</ets> + Gr. <grk>sqe`nos</grk> might,
strength.]</ety> <fld>(Zool.)</fld> <def>One of a group of mammals
having a small size as a typical characteristic. It includes the lower
orders, as the <ord>Insectivora</ord>, <ord>Cheiroptera</ord>,
<ord>Rodentia</ord>, and <ord>Edentata</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microsthenic</ent><br/
<hw>Mi`cro*sthen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a typically small size; of or pertaining to the
microsthenes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microtasimeter</ent><br/
<hw>Mi`cro*ta*sim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>tasimeter</ets>.]</ety>
<fld>(Physics)</fld> <def>A tasimeter, especially when arranged for
measuring very small extensions. See <er>Tasimeter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microtome</ent><br/
<hw>Mi"cro*tome</hw> <pr>(m<imac/"kr<osl/*t<omac/m)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + Gr. <grk>te`mnein</grk> to cut.]</ety> <def>An
instrument for making very thin sections for microscopical
examination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microtomical</ent><br/
<ent>Microtomic</ent><br/
<mhw>{ <hw>Mi`cro*tom"ic</hw> <pr>(?)</pr>, <hw>Mi`cro*tom"ic*al</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <def>Of or pert. to the microtome or
microtomy; cutting thin slices.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Microtomist</ent><br/
<hw>Mi*crot"o*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
skilled in or practices microtomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microtomy</ent><br/
<hw>Mi*crot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of using
the microtome; investigation carried on with the microtome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microvolt</ent><br/
<hw>Mi`cro*volt"</hw> <pr>(m<imac/"kr<osl/*v<omac/lt`)</pr>,
<pos>n.</pos> <ety>[<ets>Micro-</ets> + <ets>volt</ets>.]</ety>
<fld>(Elec.)</fld> <def>A measure of electro-motive force; the millionth
part of one volt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microweber</ent><br/
<hw>Mi`cro*we"ber</hw> <pr>(m<imac/`kr<osl/*v<amac/"b<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Micro-</ets> + <ets>weber</ets>.]</ety>
<fld>(Elec.)</fld> <def>The millionth part of one weber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microzoa</ent><br/
\'d8<hw>Mi`cro*zo"a</hw> <pr>(m<imac/`kr<osl/*z<omac/"<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>mikro`s</grk> small +
<grk>zw^,on</grk> an animal.]</ety> <fld>(Zool.)</fld> <def>The
Infusoria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microzo0spore</ent><br/
<hw>Mi`cro*zo"o*spore</hw>
<pr>(m<imac/`kr<osl/*z<omac/"<osl/*sp<omac/r)</pr>, <pos>n.</pos>
<ety>[<ets>Micro-</ets> + <ets>zoospore</ets>.]</ety> <fld>(Bot.)</fld>
<def>A small motile spore furnished with two vibratile cilia, found in
certain green algae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Microzyme</ent><br/
<hw>Mi"cro*zyme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Micro-</ets>
+ Gr. <grk>zy`mh</grk> leaven.]</ety> <fld>(Biol.)</fld> <def>A
microorganism which is supposed to act like a ferment in causing or
propagating certain infectious or contagious diseases; a pathogenic
bacterial organism.</def> <mark>[obsolete]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Micruroides</ent><br/
<hw>Micruroides</hw> <pos>prop. n.</pos> <def>A genus of coral
snakes.</def><br/
<syn><b>Syn. --</b> genus <gen>Micruroides</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Micrurus</ent><br/
<hw>Micrurus</hw> <pos>prop. n.</pos> <def>A genus of snakes including
certain of the coral snakes, such as the <member>eastern coral
snake</member> (<spn>Micrurus fulvius</spn>).</def><br/
<syn><b>Syn. --</b> genus <gen>Micrurus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>micturate</ent><br/
<hw>micturate</hw> <pos>v. i.</pos> <def>to pass urine through the
ureter; to urinate.</def> <mark>[Medical]</mark><br/
<syn><b>Syn. --</b> urinate, piddle, puddle, piss, pee, pee-pee, make
water, relieve oneself, take a leak, spend a penny, wee, wee-wee, make,
pass water.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Micturition</ent><br/
<hw>Mic`tu*ri"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>micturire</ets> to desire to make water, v. desid. fr.
<ets>mingere</ets>, <ets>mictum</ets>, to make water.]</ety> <def>The
act of voiding urine; urination; also, a morbidly frequent passing of
the urine, in consequence of disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mid</ent><br/
<hw>Mid</hw> <pr>(m<icr/d)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <it>wanting</it>; <pos>superl.</pos>
<adjf>Midmost</adjf>.]</amorph> <ety>[AS. <ets>midd</ets>; akin to OS.
<ets>middi</ets>, D. <ets>mid</ets> (in comp.), OHG. <ets>mitti</ets>,
Icel. <ets>mi<edh/r</ets>, Goth. <ets>midjis</ets>, L.
<ets>medius</ets>, Gr. <grk>me`sos</grk>, Skr. <ets>madhya</ets>.
<root/271. Cf. <er>Amid</er>, <er>Middle</er>, <er>Midst</er>,
<er>Mean</er>, <er>Mediate</er>, <er>Meridian</er>, <er>Mizzen</er>,
<er>Moiety</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Denoting the middle part; <as>as, in <ex>mid</ex>
ocean</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No more the mounting larks, while Daphne sings,<br/
Shall list'ning in <qex>mid</qex> air suspend their wings.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occupying a middle position; middle; <as>as, the
<ex>mid</ex> finger; the <ex>mid</ex> hour of night.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Phon.)</fld> <def>Made with a somewhat elevated
position of some certain part of the tongue, in relation to the palate;
midway between the <xex>high</xex> and the <xex>low</xex>; -- said of
certain vowel sounds; <as>as, <amac/ (<amac/le), <ecr/ (<ecr/ll), <omac/
(<omac/ld)</as>. See <xex>Guide to Pronunciation</xex>, <sect/<sect/ 10,
11.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mid</xex> is much used as a prefix, or combining
form, denoting the <xex>middle</xex> or <xex>middle part</xex> of a
thing; as, <xex>mid</xex>-air, <xex>mid</xex>-channel,
<xex>mid</xex>-age, <xex>mid</xex>day, <xex>mid</xex>land, etc. Also,
specifically, in geometry, to denote a circle inscribed in a triangle (a
<xex>mid</xex>circle), or relation to such a circle; as,
<xex>mid</xex>-center, <xex>mid</xex>radius.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mid</ent><br/
<hw>Mid</hw>, <pos>n.</pos> <def>Middle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>About the <qex>mid</qex> of night come to my tent.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mid</ent><br/
<hw>Mid</hw>, <pos>prep.</pos> <def>See <er>Amid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mida</ent><br/
<hw>Mi"da</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a destructive
insect in pulse.]</ety> <fld>(Zool.)</fld> <def>The larva of the bean
fly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>midair</ent><br/
<hw>mid*air"</hw> <pos>n.</pos> <def>some point in the air; above ground
level; <as>as, the planes collided in <ex>midair</ex></as>; also used
attributively; <as>as, a <ex>midair</ex> collision</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Midas</ent><br/
<hw>Mi"das</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from L.
<ets>Midas</ets>, a man fabled to have had ass's ears.]</ety>
<fld>(Zool.)</fld> <def>A genus of longeared South American monkeys,
including numerous species of marmosets. See
<er>Marmoset</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midas's ear</ent><br/
<hw>Mi"das's ear"</hw> <pr>(?)</pr>. <ety>[See <er>Midas</er>.]</ety>
<fld>(Zool.)</fld> <def>A pulmonate mollusk (<spn>Auricula
aurismidae</spn> or <spn>Ellobium aurismidae</spn>); -- so called from
resemblance to a human ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midbrain</ent><br/
<hw>Mid"brain`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mid</ets>, a.
+ <ets>brain</ets>.]</ety> <fld>(Anat.)</fld> <def>The middle segment of
the brain; the mesencephalon. See <er>Brain</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midday</ent><br/
<hw>Mid"day`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>middaeg</ets>. See <er>Mid</er>, <pos>a.</pos>, and
<er>Day</er>.]</ety> <def>The middle part of the day; noon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midday</ent><br/
<hw>Mid"day`</hw>, <pos>a.</pos> <def>Of or pertaining to noon;
meridional; <as>as, the <ex>midday</ex> sun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midden</ent><br/
<hw>Mid"den</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Also
<asp>midding</asp>.]</altsp> <ety>[Cf. Dan. <ets>m<oum/gdynge</ets>, E.
<ets>muck</ets>, and <ets>dung</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A dunghill.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An accumulation of refuse about a dwelling place;
especially, an accumulation of shells or of cinders, bones, and other
refuse on the supposed site of the dwelling places of prehistoric
tribes, -- as on the shores of the Baltic Sea and in many other places.
See <er>Kitchen middens</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midden crow</ent><br/
<hw>Mid"den crow"</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>The common
European crow.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middest</ent><br/
<hw>Mid"dest</hw> <pr>(?)</pr>, <pos>a.</pos>; <pos>superl.</pos> of
<er>Mid</er>. <ety>[See <er>Midst</er>.]</ety> <def>Situated most nearly
in the middle; middlemost; midmost.</def> <mark>[Obs.]</mark> <ldquo/
'Mongst the <xex>middest</xex> crowd.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middest</ent><br/
<hw>Mid"dest</hw>, <pos>n.</pos> <def>Midst; middle.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midding</ent><br/
<hw>Mid"ding</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Midden</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middle</ent><br/
<hw>Mid"dle</hw> <pr>(m<icr/d"d'l)</pr>, <pos>a.</pos> <ety>[OE.
<ets>middel</ets>, AS. <ets>middel</ets>; akin to D. <ets>middel</ets>,
OHG. <ets>muttil</ets>, G. <ets>mittel</ets>. <root/271. See
<er>Mid</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Equally distant from the extreme either of a number
of things or of one thing; mean; medial; <as>as, the <ex>middle</ex>
house in a row; a <ex>middle</ex> rank or station in life; flowers of
<ex>middle</ex> summer; men of <ex>middle</ex> age.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Intermediate; intervening.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Will, seeking good, finds many <qex>middle</qex> ends.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Middle</xex> is sometimes used in the formation of
self-explaining compounds; as, <xex>middle</xex>-sized,
<xex>middle</xex>-witted.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Middle Ages</b></col>, <cd>the period of time intervening
between the decline of the Roman Empire and the revival of letters.
<persfn>Hallam</persfn> regards it as beginning with the sixth and
ending with the fifteenth century.</cd> -- <col><b>Middle
class</b></col>, <cd>in England, people who have an intermediate
position between the aristocracy and the artisan class. It includes
professional men, bankers, merchants, and small landed
proprietors</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>middle-class</qex> electorate of Great Britain.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Middle distance</b></col>. <fld>(Paint.)</fld> <cd>See
<er>Middle-ground</er>.</cd> -- <col><b>Middle English</b></col>.
<cd>See <er>English</er>, <pos>n.</pos>, 2.</cd> -- <col><b>Middle
Kingdom</b></col>, <cd>China.</cd> -- <col><b>Middle oil</b></col>
<fld>(Chem.)</fld>, <cd>that part of the distillate obtained from coal
tar which passes over between 170<deg/ and 230<deg/ Centigrade; --
distinguished from the <contr>light oil</contr>, and the <contr>heavy
oil</contr> or <contr>dead oil</contr>.</cd> -- <col><b>Middle
passage</b></col>, <cd>in the slave trade, that part of the Atlantic
Ocean between Africa and the West Indies.</cd> -- <col><b>Middle
post</b></col>. <fld>(Arch.)</fld> <cd>Same as <er>King-post</er>.</cd>
-- <col><b>Middle States</b></col>, <cd>New York, New Jersey,
Pennsylvania, and Delaware; which, at the time of the formation of the
Union, occupied a middle position between the Eastern States (or New
England) and the Southern States.</cd> <mark>[U.S.]</mark> --
<col><b>Middle term</b></col> <fld>(Logic)</fld>, <cd>that term of a
syllogism with which the two extremes are separately compared, and by
means of which they are brought together in the conclusion.</cd>
<au>Brande.</au> -- <col><b>Middle tint</b></col> <fld>(Paint.)</fld>,
<cd>a subdued or neutral tint.</cd> <au>Fairholt.</au> -- <col><b>Middle
voice</b></col>. <fld>(Gram.)</fld> <cd>See under <er>Voice</er>.</cd>
-- <col><b>Middle watch</b></col>, <cd>the period from midnight to four
<sc>a. m.</sc></cd>; <specif>also,</specif> <cd>the men on watch during
that time.</cd> <au>Ham. Nav. Encyc.</au> -- <col><b>Middle
weight</b></col>, <cd>a pugilist, boxer, or wrestler classed as of
medium weight, <it>i. e.</it>, over 140 and not over 160 lbs., in
distinction from those classed as <contr>light weights</contr>,
<contr>heavy weights</contr>, etc.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Middle</ent><br/
<hw>Mid"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>middel</ets>. See <er>Middle</er>, <pos>a.</pos>]</ety> <def>The
point or part equally distant from the extremities or exterior limits,
as of a line, a surface, or a solid; an intervening point or part in
space, time, or order of series; the midst; central portion</def>;
<specif>specif.,</specif> <def>the waist.</def> <au>Chaucer.</au>
<ldquo/The <xex>middle</xex> of the land.<rdquo/ <au>Judg. ix.
37.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>In this, as in most questions of state, there is a
<qex>middle</qex>.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Midst</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middle-age</ent><br/
<hw>Mid"dle-age`</hw> <pr>(?)</pr>, <ety>[<ets>Middle</ets> +
<ets>age</ets>. Cf. <er>Mediaeval</er>.]</ety> <def>Of or pertaining to
the Middle Ages; mediaeval.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middle-aged</ent><br/
<hw>Mid"dle-aged`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Being about the
middle of the ordinary age of man; early in the century, it was
considered between 30 and 50 years old, but by the end of the 19th
centruy it was considered as 40 to 60.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Middle-earth</ent><br/
<hw>Mid"dle-earth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The world,
considered as lying between heaven and hell.</def>
<mark>[Obs.]</mark><-- a land in Tolkien's "Hobbit" and "Ring" books -->
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middle-ground</ent><br/
<hw>Mid"dle-ground`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Paint.)</fld>
<def>That part of a picture between the foreground and the
background.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>middle-level</ent><br/
<hw>middle-level</hw> <pos>adj.</pos> <def>intermediate in rank or
position; <as>as, <ex>middle-level</ex> management</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Middleman</ent><br/
<hw>Mid"dle*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Middlemen</plw> <pr>(<?/)</pr>.</plu><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An agent between two parties; a broker; a
go-between; any dealer between the producer and the consumer; in
Ireland, one who takes land of the proprietors in large tracts, and then
rents it out in small portions to the peasantry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person of intermediate rank; a commoner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>The man who occupies a central
position in a file of soldiers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middlemost</ent><br/
<hw>Mid"dle*most`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf.
<er>Midmost</er>.]</ety> <def>Being in the middle, or nearest the
middle; midmost.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>middle-of-the-road</ent><br/
<hw>middle-of-the-road</hw> <pos>adj.</pos> <sn>1.</sn> <def>supporting
or pursuing a course of action that is neither liberal nor
conservative.</def><br/
<syn><b>Syn. --</b> centrist, moderate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>not extreme, especially in political
views.</def><br/
[<source>WordNet 1.5</source>]</p>

<p> -- <wordforms><wf>middle-of-the-roader</wf>, <pos>n.</pos> --
<wf>middle-of-the-roadism</wf>, <pos>n.</pos></wordforms></p>

<p><ent>Middler</ent><br/
<hw>Mid"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of a middle or
intermediate class in some schools and seminaries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middling</ent><br/
<hw>Mid"dling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of middle rank,
state, size, or quality; about equally distant from the extremes;
medium; moderate; mediocre; ordinary.</def> <ldquo/A town of but
<xex>middling</xex> size.<rdquo/ <rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Plainly furnished, as beseemed the <qex>middling</qex>
circumstances of its inhabitants.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mid"dling*ly</wf>, <pos>adv.</pos> --
<wf>Mid"dling*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middlings</ent><br/
<hw>Mid"dlings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <sn>1.</sn> <def>A
combination of the coarser parts of ground wheat the finest bran,
separated from the fine flour and coarse bran in bolting; -- formerly
regarded as valuable only for feed; but now, after separation of the
bran, used for making the best quality of flour. <xex>Middlings</xex>
contain a large proportion of gluten.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In the southern and western parts of the United
States, the portion of the hog between the ham and the shoulder; bacon;
-- called also <altname>middles</altname>.</def>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Middy</ent><br/
<hw>Mid"dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Middies</plw> <pr>(<?/)</pr>.</plu> <def>A colloquial abbreviation
of <altname>midshipman</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mid-eighties</ent><br/
<hw>mid-eighties</hw> <pos>n.</pos> <def>the time of life between 80 and
90.</def><br/
<syn><b>Syn. --</b> eighties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midfeather</ent><br/
<hw>Mid"feath`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Steam Boilers)</fld> <def>A vertical water space in a fire box or
combustion chamber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A support for the center of a
tunnel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mid-February</ent><br/
<hw>mid-February</hw> <pos>n.</pos> <def>the middle part of
February.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>midfield</ent><br/
<hw>midfield</hw> <pos>n.</pos> <fld>(sport)</fld> <def>the middle part
of a playing field (as in football or lacrosse); <as>as, he ran the
kickoff back to <ex>midfield</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-fifties</ent><br/
<hw>mid-fifties</hw> <pos>n.</pos> <def>the time of life between 50 and
60.</def><br/
<syn><b>Syn. --</b> fifties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-forties</ent><br/
<hw>mid-forties</hw> <pos>n.</pos> <def>the time of life between 40 and
50.</def><br/
<syn><b>Syn. --</b> forties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mithgarthr</ent><br/
<ent>Midgarth</ent><br/
<ent>Midgard</ent><br/
<mhw>{ <hw>Mid"gard</hw> <pr>(m<icr/d"g<aum/rd)</pr>, <pos>n.</pos> Also
<hw>Mid"garth</hw> <pr>(-g<aum/r<th/)</pr>, \'d8<hw>Mith"garthr</hw>
<pr>(<it>Icel.</it> m<esl/<th/"g<aum/r<th/r')</pr> }</mhw>. <ety>[Icel.
<ets>mi<edh/gar<edh/r</ets>.]</ety> <fld>(Teut. Myth.)</fld> <def>The
middle space or region between heaven and hell, the abode of human
beings; the earth.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Midge</ent><br/
<hw>Midge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>migge</ets>,
AS. <ets>mycge</ets>; akin to OS. <ets>muggia</ets>, D. <ets>mug</ets>,
G. <ets>m<uum/cke</ets>, OHG. <ets>mucca</ets>, Icel. <ets>m<?/</ets>,
Sw. <ets>mygga</ets>, <ets>mygg</ets>, Dan. <ets>myg</ets>; perh. named
from its buzzing; cf. Gr. <?/ to low, bellow.]</ety>
<fld>(Zool.)</fld><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Any one of many small, delicate, long-legged flies
of the <gen>Chironomus</gen>, and allied genera, which do not bite.
Their larvae are usually aquatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A very small fly, abundant in many parts of the
United States and Canada, noted for the irritating quality of its
bite.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also applied to various other small flies.
See <cref>Wheat midge</cref>, under <er>Wheat</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midget</ent><br/
<hw>Midg"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>midge</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A minute
bloodsucking fly.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A very diminutive person having normal proportions
of the body parts; compare <contr>dwarf</contr>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Midgut</ent><br/
<hw>Mid"gut`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mid</ets>, a. +
<ets>gut</ets>.]</ety> <fld>(Anat.)</fld> <def>The middle part of the
alimentary canal from the stomach, or entrance of the bile duct, to, or
including, the large intestine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midheaven</ent><br/
<hw>Mid"heav`en</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
midst or middle of heaven or the sky.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>The meridian, or middle line of
the heavens; the point of the ecliptic on the meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>midiron</ent><br/
<hw>midiron</hw> <pos>n.</pos> <fld>(Golf)</fld> <def>a long iron{5}
with a nearly vertical face.</def><br/
<syn><b>Syn. --</b> two iron.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-January</ent><br/
<hw>mid-January</hw> <pos>n.</pos> <def>the middle part of
January.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-July</ent><br/
<hw>mid-July</hw> <pos>n.</pos> <def>the middle part of July.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-June</ent><br/
<hw>mid-June</hw> <pos>n.</pos> <def>the middle part of June.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midland</ent><br/
<hw>Mid"land</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Being in
the interior country; distant from the coast or seashore; <as>as,
<ex>midland</ex> towns or inhabitants</as>.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Surrounded by the land; mediterranean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And on the <qex>midland</qex> sea the French had awed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midland</ent><br/
<hw>Mid"land</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The interior or
central region of a country; -- usually in the plural.</def>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midmain</ent><br/
<hw>Mid"main`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The middle part of
the main or sea.</def> <mark>[Poetic]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mid-March</ent><br/
<hw>mid-March</hw> <pos>n.</pos> <def>the middle part of
March.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-May</ent><br/
<hw>mid-May</hw> <pos>n.</pos> <def>the middle part of May.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midmost</ent><br/
<hw>Mid"most`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>middemiste</ets>. Cf. <er>Foremost</er>.]</ety> <def>Middle;
middlemost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere night's <qex>midmost</qex>, stillest hour was past.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midnight</ent><br/
<hw>Mid"night`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>midniht</ets>.]</ety> <def>The middle of the night; twelve o'clock
at night.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The iron tongue of <qex>midnight</qex> hath told twelve.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midnight</ent><br/
<hw>Mid"night`</hw>, <pos>a.</pos> <def>Being in, or characteristic of,
the middle of the night; <as>as, <ex>midnight</ex> studies;
<ex>midnight</ex> gloom.</as></def> <ldquo/<xex>Midnight</xex> shout and
revelry.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midnight sun</ent><br/
<hw>Mid"night` sun</hw>. <def>The sun shining at midnight in the arctic
or antarctic summer.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mid-nineties</ent><br/
<hw>mid-nineties</hw> <pos>n.</pos> <def>the time of life between 90 and
100.</def><br/
<syn><b>Syn. --</b> nineties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-November</ent><br/
<hw>mid-November</hw> <pos>n.</pos> <def>the middle part of
November.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-October</ent><br/
<hw>mid-October</hw> <pos>n.</pos> <def>the middle part of
October.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-off</ent><br/
<hw>mid-off</hw> <pos>n.</pos> <fld>(Cricket)</fld> <def>the fielding
position in cricket closest to the bowler on the off side.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-on</ent><br/
<hw>mid-on</hw> <pos>n.</pos> <fld>(Cricket)</fld> <def>the fielding
position in cricket closest to the bowler on the on side.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midrash</ent><br/
\'d8<hw>Mid*rash"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Midrashim</plw> <pr>(#)</pr>, <plw>Midrashoth</plw>
<pr>(#)</pr>.</plu> <ety>[Heb., explanation.]</ety> <def>A talmudic
exposition of the Hebrew law, or of some part of it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midrib</ent><br/
<hw>Mid"rib`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
continuation of the petiole, extending from the base to the apex of the
lamina of a leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midriff</ent><br/
<hw>Mid"riff</hw> <pr>(m<icr/d"r<icr/f)</pr>, <pos>n.</pos> <ety>[AS.
<ets>midhrif</ets>; <ets>midd</ets> mid, middle + <ets>hrif</ets>
bowels, womb; akin to OFries. <ets>midref</ets> midriff, <ets>rif</ets>,
<ets>ref</ets>, belly, OHG. <ets>href</ets> body, and to L.
<ets>corpus</ets> body. See <er>Corpse</er>.]</ety> <fld>(Anat.)</fld>
<sn>1.</sn> <def>See <er>Diaphragm</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The middle part of the front of the body, from the
waist to the chest.</def><br/
[<source>PJC</source>]</p>

<p><q>Smote him into the <qex>midriff</qex> with a stone.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That part of a garment, especially a dress or
bodice, that covers the midriff{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mid-sea</ent><br/
<ent>Mid sea</ent><br/
<mhw>{ <hw>Mid" sea"</hw>, <it>or</it> <hw>Mid"-sea"</hw> <pr>(?)</pr>
}</mhw> <pos>n.</pos> <def>The middle part of the sea or ocean.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Mid-sea</b></col>, <cd>the Mediterranean Sea.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mid-September</ent><br/
<hw>mid-September</hw> <pos>n.</pos> <def>the middle part of
September.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-seventies</ent><br/
<hw>mid-seventies</hw> <pos>n.</pos> <def>the time of life between 70
and 80.</def><br/
<syn><b>Syn. --</b> seventies.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midship</ent><br/
<hw>Mid"ship`</hw>, <pos>a.</pos> <def>Of or pertaining to, or being in,
the middle of a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Midship beam</b></col> <fld>(Naut.)</fld>, <cd>the beam
or timber upon which the broadest part of a vessel is formed.</cd> --
<col><b>Midship bend</b></col>, <cd>the broadest frame in a vessel.</cd>
<au>Weale.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midshipman</ent><br/
<hw>Mid"ship`man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Midshipmen</plw> <pr>(<?/)</pr>.</plu><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <sd>(a)</sd> <def>Formerly, a kind of naval cadet, in a
ship of war, whose business was to carry orders, messages, reports,
etc., between the officers of the quarter-deck and those of the
forecastle, and render other services as required.</def> <sd>(b)</sd>
<def>In the English naval service, the second rank attained by a
combatant officer after a term of service as naval cadet. Having served
three and a half years in this rank, and passed an examination, he is
eligible to promotion to the rank of lieutenant.</def> <sd>(c)</sd>
<def>In the United States navy, the lowest grade of officers in line of
promotion, being students or graduates of the Naval Academy awaiting
promotion to the rank of ensign.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>An American marine fish of the
genus <gen>Porichthys</gen>, allied to the toadfish; also called
<altname>singingfish</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cadet midshipman</b></col>, <cd>formerly a title
distinguishing a cadet line officer from a cadet engineer at the U. S.
Naval Academy. See under <er>Cadet</er>.</cd> -- <col><b>Cadet
midshipman</b></col>, <cd>formerly, a naval cadet who had served his
time, passed his examinations, and was awaiting promotion; -- now
called, in the United States, <altname>midshipman</altname>; in England,
<altname>sublieutenant</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midships</ent><br/
<hw>Mid"ships`</hw>, <pos>adv.</pos> <ety>[For
<ets>amidships</ets>.]</ety> <fld>(Naut.)</fld> <def>In the middle of a
ship; -- properly <altname>amidships</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midships</ent><br/
<hw>Mid"ships`</hw>, <pos>n. pl.</pos> <fld>(Naut.)</fld> <def>The
timbers at the broadest part of the vessel.</def> <rj><au>R. H. Dana,
Jr.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mid-sixties</ent><br/
<hw>mid-sixties</hw> <pos>n.</pos> <def>the time of life between 60 and
70.</def><br/
<syn><b>Syn. --</b> sixties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midst</ent><br/
<hw>Midst</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>middest</ets>, <ets>in the middest</ets>, for older <ets>in
middes</ets>, where <ets>-s</ets> is adverbial (orig. forming a
genitive), or still older <ets>a midde</ets>, <ets>a midden</ets>,
<ets>on midden</ets>. See <er>Mid</er>, and cf.
<er>Amidst</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The interior or central part or place; the middle;
-- used chiefly in the objective case after <xex>in</xex>; <as>as, in
the <ex>midst</ex> of the forest</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And when the devil had thrown him in the <qex>midst</qex>, he came
out of him.</q> <rj><qau>Luke iv. 35.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is nothing . . . in the <qex>midst</qex> [of the play] which
might not have been placed in the beginning.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, figuratively, the condition of being
surrounded or beset; the press; the burden; <as>as, in the
<ex>midst</ex> of official duties; in the <ex>midst</ex> of secular
affairs.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The expressions <xex>in our midst</xex>, <xex>in their
midst</xex>, etc., are avoided by some good writers, the forms <xex>in
the midst of us</xex>, <xex>in the midst of them</xex>, etc., being
preferred.</note><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Midst</er>, <er>Middle</er>.</syn> <usage>
<xex>Midst</xex> in present usage commonly denotes a part or place
surrounded on enveloped by or among other parts or objects (see
<er>Amidst</er>); while <xex>middle</xex> is used of the center of
length, or surface, or of a solid, etc. We say in the <xex>midst</xex>
of a thicket; in the <xex>middle</xex> of a line, or the
<xex>middle</xex> of a room; in the <xex>midst</xex> of darkness; in the
<xex>middle</xex> of the night.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midst</ent><br/
<hw>Midst</hw>, <pos>prep.</pos> <def>In the midst of; amidst.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midst</ent><br/
<hw>Midst</hw>, <pos>adv.</pos> <def>In the middle.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>midstream</ent><br/
<hw>midstream</hw> <pos>n.</pos> <def>the middle of a stream; <as>as,
don't change horses in <ex>midstream</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midsummer</ent><br/
<hw>Mid"sum`mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>midsumor</ets>.]</ety> <def>The middle of summer.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Midsummer daisy</b></col> <fld>(Bot.)</fld>, <cd>the
oxeye daisy.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>midsummer-men</ent><br/
<hw>midsummer-men</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A Eurasian
mountain plant (<spn>Sedum rosea</spn>) with fleshy pink-tipped leaves
and a cluster of yellow flowers.</def><br/
<syn><b>Syn. --</b> rose-root, <spn>Sedum rosea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>midterm</ent><br/
<hw>midterm</hw> <pos>n.</pos> <sn>1.</sn> <def>the middle of the
gestation period.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The middle of an academic term or a political term
in office.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>An examination given in the middle of an academic
term; a midterm examination.</def><br/
<syn><b>Syn. --</b> midterm examination, midterm exam,
midterm.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-thirties</ent><br/
<hw>mid-thirties</hw> <pos>n.</pos> <def>the time of life between 30 and
40.</def><br/
<syn><b>Syn. --</b> thirties, thirty-something.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mid-twenties</ent><br/
<hw>mid-twenties</hw> <pos>n.</pos> <def>the time of life between 20 and
30.</def><br/
<syn><b>Syn. --</b> twenties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midward</ent><br/
<hw>Mid"ward</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Situated in the
middle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midward</ent><br/
<hw>Mid"ward</hw>, <pos>adv.</pos> <def>In or toward the
midst.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midway</ent><br/
<hw>Mid"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The middle of the way
or distance; a middle way or course.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Paths indirect, or in the <qex>midway</qex> faint.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midway</ent><br/
<hw>Mid"way`</hw>, <pos>a.</pos> <def>Being in the middle of the way or
distance; <as>as, the <ex>midway</ex> air</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midway</ent><br/
<hw>Mid"way`</hw>, <pos>adv.</pos> <def>In the middle of the way or
distance; half way.</def> <ldquo/She met his glance
<xex>midway</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midweek</ent><br/
<hw>Mid"week`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The middle of the
week. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>midweekly</ent><br/
<hw>midweekly</hw> <pos>adj.</pos> <def>occurring during the middle of
the week; <as>as, a <ex>midweekly</ex> prayer meeting</as>.</def><br/
<syn><b>Syn. --</b> midweek.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midwest</ent><br/
<hw>Midwest</hw> <pos>n.</pos> <def>The north central region of the U.
S.</def><br/
<syn><b>Syn. --</b> Middle West.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>midwestern</ent><br/
<hw>midwestern</hw> <pos>adj.</pos> <def>Of or pertaining to the Midwest
region of the U. S., generally including Ohio; Indiana; Illinois; Iowa;
Missouri; Kansas; Nebraska; and sometimes Michigan; Wisconsin;
Minnesota; <as>as, a <ex>midwestern</ex> city; <ex>midwestern</ex>
accent</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Midwife</ent><br/
<hw>Mid"wife`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Midwives</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>midwif</ets>, fr.
AS. <ets>mid</ets> with (akin to Gr. <?/) + <?/ woman, wife. Properly,
the woman or wife who is attendant upon a woman in childbirth. See
<er>Meta-</er>, and <er>Wife</er>.]</ety> <def>A woman who assists other
women in childbirth; a female practitioner of the obstetric
art.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midwife</ent><br/
<hw>Mid"wife`</hw>, <pos>v. t.</pos> <def>To assist in
childbirth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midwife</ent><br/
<hw>Mid"wife`</hw>, <pos>v. i.</pos> <def>To perform the office of
midwife.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midwifery</ent><br/
<hw>Mid"wife`ry</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The art or practice of assisting women in childbirth;
obstetrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Assistance at childbirth; help or cooperation in
production.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Midwinter</ent><br/
<hw>Mid"win`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>midwinter</ets>.]</ety> <def>The middle of winter.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 923 --></p>

<p><ent>Midwive</ent><br/
<hw>Mid"wive`</hw> <pr>(m<icr/d"w<imac/v`)</pr>, <pos>v. t.</pos>
<def>To midwife.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mien</ent><br/
<hw>Mien</hw> <pr>(m<emac/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>mine</ets>; perh. from sane source as <ets>mener</ets> to lead; cf.
E. <ets>demean</ets>, <ets>menace</ets>, <ets>mine</ets>, n.]</ety>
<def>Aspect; air; manner; demeanor; carriage; bearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vice is a monster of so frightful <qex>mien</qex>,<br/
As, to be hated, needs but to be seen.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mierkat</ent><br/
<hw>mierkat</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>A South African
mongooselike viverrine (<spn>Suricata suricata</spn>) having a lemurlike
face and only four toes; called also <altname>suricate</altname>.</def>
<altsp>[Also spelled <asp>meerkat</asp>.]</altsp><br/
<syn><b>Syn. --</b> meerkat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Miff</ent><br/
<hw>Miff</hw> <pr>(m<icr/f)</pr>, <pos>n.</pos> <ety>[Cf. Prov. G.
<ets>muff</ets> sullenness, sulkiness, <ets>muffen</ets> to be silky,
<ets>muff<ium/g</ets> sullen, pouting.]</ety> <def>A petty falling out;
a tiff; a quarrel; offense.</def> <rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miff</ent><br/
<hw>Miff</hw>, <pos>v. t.</pos> <def>To offend slightly.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Might</ent><br/
<hw>Might</hw> <pr>(m<imac/t)</pr>, <def><pos>imp.</pos> of
<er>May</er>.</def> <ety>[AS. <ets>meahte</ets>,
<ets>mihte</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><ent>Might</ent><br/
<hw>Might</hw>, <pos>n.</pos> <ety>[AS. <ets>meaht</ets>,
<ets>miht</ets>, from the root of <ets>magan</ets> to be able, E.
<ets>may</ets>; akin to D. <ets>magt</ets>, OS. <ets>maht</ets>, G.
<ets>macht</ets>, Icel. <ets>m<amac/ttr</ets>, Goth. <ets>mahts</ets>.
<root/103. See <er>May</er>, <pos>v.</pos>]</ety> <def>Force or power of
any kind, whether of body or mind; energy or intensity of purpose,
feeling, or action; means or resources to effect an object; strength;
force; power; ability; capacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What so strong,<br/
But wanting rest, will also want of <qex>might</qex>?</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt love the Lord thy God with all thine heart, and with
all thy soul, and with all thy <qex>might</qex>.</q> <rj><qau>Deut. vi.
5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>With might and main</b></col>. <cd>See under 2d
<er>Main</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mightful</ent><br/
<hw>Might"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mighty.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mightily</ent><br/
<hw>Might"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Mighty</er>.]</ety> <sn>1.</sn> <def>In a mighty manner; with might;
with great earnestness; vigorously; powerfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whereunto I also labor, striving according to his working, which
worketh in me <qex>mightily</qex>.</q> <rj><qau>Col. i.
29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To a great degree; very much.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Practical jokes amused us <qex>mightily</qex>.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mightiness</ent><br/
<hw>Might"i*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality of
being mighty; possession of might; power; greatness; high
dignity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How soon this <qex>mightiness</qex> meets misery.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Highness; excellency; -- with a possessive pronoun,
a title of dignity; <as>as, their high
<ex>mightinesses</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mightless</ent><br/
<hw>Might"less</hw>, <pos>a.</pos> <def>Without; weak.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mighty</ent><br/
<hw>Might"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Mightier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Mightiest</adjf>.]</amorph> <ety>[AS. <ets>meahtig</ets>,
<ets>mihtig</ets>; akin to G. <ets>m<aum/chtig</ets>, Goth.
<ets>mahteigs</ets>. See <er>Might</er>, <pos>n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Possessing might; having great power or
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wise in heart, and <qex>mighty</qex> in strength.</q> <rj><qau>Job
ix. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Accomplished by might; hence, extraordinary;
wonderful.</def> <ldquo/His <xex>mighty</xex> works.<rdquo/
<rj><au>Matt. xi. 20.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Denoting an extraordinary degree or quality in
respect of size, character, importance, consequences, etc.</def>
<ldquo/A <xex>mighty</xex> famine.<rdquo/ <au>Luke xv. 14.</au>
<ldquo/Giants of <xex>mighty</xex> bone.<rdquo/ <au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mighty</qex> was their fuss about little matters.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mighty</ent><br/
<hw>Might"y</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Mighties</plw>
<pr>(#)</pr>.</plu> <def>A warrior of great force and courage.</def>
<mark>[R. & Obs.]</mark> <rj><au>1 Chron. xi. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mighty</ent><br/
<hw>Might"y</hw>, <pos>adv.</pos> <def>In a great degree; very.</def>
<mark>[Colloq.]</mark> <ldquo/He was <xex>mighty</xex>
methodical.<rdquo/ <rj><au>Jeffrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We have a <qex>mighty</qex> pleasant garden.</q>
<rj><qau>Doddridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Migniard</ent><br/
<hw>Mign"iard</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>mignard</ets>, akin to <ets>mignon</ets>. See
<er>Minion</er>.]</ety> <def>Soft; dainty.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Migniardise</ent><br/
<hw>Mign"iard*ise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mignardise</ets>.]</ety> <def>Delicate fondling.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mignon</ent><br/
<hw>Mi"gnon</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.]</ety> <def>See 3d
<er>Minion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mignon</ent><br/
<hw>Mi"gnon</hw>, <pos>v. t.</pos> <def>To flatter.</def> <mark>[R. &
Obs.]</mark> <rj><au>Danie<?/.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mignonette</ent><br/
<hw>Mi`gnon*ette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mignonnette</ets>, dim. of <ets>mignon</ets> darling. See 2d
<er>Minion</er>.]</ety> <fld>(Bot.)</fld> <def>A plant (<spn>Reseda
odorata</spn>) having greenish flowers with orange-colored stamens, and
exhaling a delicious fragrance. In Africa it is a low shrub, but further
north it is usually an annual herb.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mignonette pepper</b></col>, <cd>coarse
pepper.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>migraine</ent><br/
<hw>mi*graine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>migraine</ets>, LL. <ets>hemigrania</ets>, L.
<ets>hemicrania</ets>, <ets>hemicranium</ets>, Gr.
<grk>"hmikrani`a</grk>; <grk>"hmi-</grk> half + <grk>krani`on</grk>
skull. See <er>Hemi-</er> and <er>Cranium</er>, and cf.
<er>Hemicrania</er>, <er>Migraine</er>.]</ety> <sn>1.</sn> <def>A kind
of intense sick or nervous headache, usually periodical and confined to
one side of the head; called also <altname>migraine headache</altname>.
Same as <er>megrim</er>.</def> -- <wordforms><wf>Mi*grain"ous</wf>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Migrant</ent><br/
<hw>Mi"grant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>migrans</ets>, p. pr. of <ets>migrare</ets>. See
<er>Migrate</er>.]</ety> <def>Migratory.</def> <au>Sir T.
Browne.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Migrant</ent><br/
<hw>Mi"grant</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
migratory bird, person, or other animal.</def></p>

<p><sn>2.</sn> <def>A person who changes residence frequently in search
of employment, especially farm labor, such as harvesting crops
seasonally; also called <altname>migrant laborer</altname> or
<altname>migrant worker</altname>. Sometimes the migrant worker is not a
resident of the country in which the work is performed.</def><br/
[<source>PJC</source>]</p>

<p><ent>Migrate</ent><br/
<hw>Mi"grate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Migrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Migrating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>migratus</ets>, p. p. of <ets>migrare</ets> to migrate,
transfer.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To remove from one country or region to another,
with a view to residence; to change one's place of residence; to remove;
<as>as, the Moors who <ex>migrated</ex> from Africa into Spain; to
<ex>migrate</ex> to the West.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pass periodically from one region or climate to
another for feeding or breeding; -- said of certain birds, fishes, and
quadrupeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Migration</ent><br/
<hw>Mi*gra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>migratio</ets>: cf. F. <ets>migration</ets>.]</ety> <def>The act of
migrating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Migratory</ent><br/
<hw>Mi"gra*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>migratoire</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Removing regularly or occasionally from one region
or climate to another; <as>as, <ex>migratory</ex> birds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, roving; wandering; nomad; <as>as,
<ex>migratory</ex> habits; a <ex>migratory</ex> life.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Migratory locust</b></col> <fld>(Zool.)</fld> <cd>See
<er>Locust</er>.</cd> -- <col><b>Migratory thrush</b></col>
<fld>(Zool.)</fld>, <cd>the American robin. See
<er>Robin</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mikado</ent><br/
<hw>Mi*ka"do</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Jap.]</ety> <def>The
popular designation of the hereditary sovereign of Japan; the emperor of
Japan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mike</ent><br/
<hw>mike</hw> <pos>n.</pos> <ety>[shortened from
<ets>microphone</ets>.]</ety> <def>A <er>microphone</er>, the device for
converting sound waves into electrical energy.</def>
<mark>[informal]</mark> <br/
<syn><b>Syn. --</b> microphone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mikmaks</ent><br/
<hw>Mik"maks</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Micmacs</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mil</ent><br/
<hw>mil</hw> <pos>n.</pos> <sn>1.</sn> <def>an obsolete monetary unit of
Cyprus equal in value to <frac1x1000/ of a pound.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a unit of length equal to <frac1x1000/ inch, used
especially in measuring the thickness of sheets of materials.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>one milliliter; -- used mostly in informal
speech.</def> <mark>[laboratory slang]</mark><br/
<syn><b>Syn. --</b> milliliter, millilitre, ml, cubic centimeter, cubic
centimetre, cc.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>a unit of angular size equal to <frac1x6400/ of 360
degrees; -- it is used especially in artillery ranging.</def><br/
<syn><b>Syn. --</b> mil.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mil</ent><br/
<hw>mil</hw> <pos>n.</pos> <ety>[by contraction from
<ets>million</ets>.]</ety> <def>One million dollars; <as>as, his new
house cost over a <ex>mil</ex></as>.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Milady</ent><br/
<hw>Mi*la"dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
English.]</ety> <def>Lit., my lady; hence (as used on the Continent), an
English noblewoman or gentlewoman.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Milage</ent><br/
<hw>Mil"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>Same as
<er>Mileage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milanese</ent><br/
<hw>Mil`an*ese"</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to Milan in Italy, or to its inhabitants.</def> --
<def2><pos>n. sing. & pl.</pos> <def>A native or inhabitant of Milan;
people of Milan.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milch</ent><br/
<hw>Milch</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>milche</ets>;
akin to G. <ets>melk</ets>, Icel. <ets>milkr</ets>,
<ets>mj<omac/lkr</ets>, and to E. <ets>milk</ets>. See
<er>Milk</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Giving milk; -- now applied only to beasts.</def>
<ldquo/<xex>Milch</xex> camels.<rdquo/ <au>Gen. xxxii.</au>
<ldquo/<xex>Milch</xex> kine.<rdquo/ <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tender; pitiful; weeping.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mild</ent><br/
<hw>Mild</hw> <pr>(m<imac/ld)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Milder</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Mildest</adjf>.]</amorph> <ety>[AS.
<ets>milde</ets>; akin to OS. <ets>mildi</ets>, D. & G. <ets>mild</ets>,
OHG. <ets>milti</ets>, Icel. <ets>mildr</ets>, Sw. & Dan.
<ets>mild</ets>, Goth. <ets>milds</ets>; cf. Lith. <ets>melas</ets>
dear, Gr. <?/ gladdening gifts.]</ety> <def>Gentle; pleasant; kind;
soft; bland; clement; hence, moderate in degree or quality; -- the
opposite of <xex>harsh</xex>, <xex>severe</xex>, <xex>irritating</xex>,
<xex>violent</xex>, <xex>disagreeable</xex>, etc.; -- applied to persons
and things; <as>as, a <ex>mild</ex> disposition; a <ex>mild</ex> eye; a
<ex>mild</ex> air; a <ex>mild</ex> medicine; a <ex>mild</ex>
insanity.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rosy morn resigns her light<br/
And <qex>milder</qex> glory to the noon.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Adore him as a <qex>mild</qex> and merciful Being.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Mild steel</b></col>, <it>or</it> <col><b>Low
steel</b></col></mcol>, <cd>steel that has but little carbon in it and
is not readily hardened.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Soft; gentle; bland; calm; tranquil; soothing;
pleasant; placid; meek; kind; tender; indulgent; clement; mollifying;
lenitive; assuasive. See <er>Gentle</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milden</ent><br/
<hw>Mild"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make mild, or
milder.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mildew</ent><br/
<hw>Mil"dew</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>melede<aacute/w</ets>; akin to OHG. <ets>militou</ets>, G.
<ets>mehlthau</ets>, <ets>mehltau</ets>; prob. orig. meaning, honeydew;
cf. Goth. <ets>milip</ets> honey. See <er>Mellifluous</er>, and
<er>Dew</er>.]</ety> <fld>(Bot.)</fld> <def>A growth of minute powdery
or webby fungi, whitish or of different colors, found on various
diseased or decaying substances.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>powdery mildew</b></col> <cd>a fungal disease of plants
caused by an ascomycete of the order <ord>Erysiphales</ord>,
characterized by a powdery white film on the surface of the affected
plants. It is damaging to, e.g., roses and lilacs. Also, a fungus that
causes such a disease.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Mildew</ent><br/
<hw>Mil"dew</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mildewed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mildewing</conjf>.]</vmorph> <def>To taint with mildew; <as>as,
<ex>mildewed</ex> clothing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . <qex>mildews</qex> the white wheat.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mildew</ent><br/
<hw>Mil"dew</hw>, <pos>v. i.</pos> <def>To become tainted with
mildew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mildly</ent><br/
<hw>Mild"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mild
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mildness</ent><br/
<hw>Mild"ness</hw>, <pos>n.</pos> <def>The quality or state of being
mild; <as>as, <ex>mildness</ex> of temper; the <ex>mildness</ex> of the
winter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mile</ent><br/
<hw>Mile</hw> <pr>(m<imac/l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>m<imac/l</ets>, fr. L. <ets>millia</ets>, <ets>milia</ets>; pl. of
<ets>mille</ets> a thousand, i. e., <ets>milia passuum</ets> a thousand
paces. Cf. <er>Mill</er> the tenth of a cent, <er>Million</er>.]</ety>
<def>A certain measure of distance, being equivalent in England and the
United States to 320 poles or rods, or 5,280 feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The distance called a <xex>mile</xex> varies greatly in
different countries. Its length in yards is, in Norway, 12,182; in
Brunswick, 11,816; in Sweden, 11,660; in Hungary, 9,139; in Switzerland,
8,548; in Austria, 8,297; in Prussia, 8,238; in Poland, 8,100; in Italy,
2,025; in England and the United States, 1,760; in Spain, 1,552; in the
Netherlands, 1,094.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Geographical mile</b></col> <it>or</it>
<col><b>Nautical mile</b></col></mcol>, <cd>one sixtieth of a degree of
a great circle of the earth, or 6080.27 feet.</cd> -- <col><b>Mile
run</b></col>. <cd>Same as <cref>Train mile</cref>. See under
<er>Train</er>.</cd> -- <col><b>Roman mile</b></col>, <cd>a thousand
paces, equal to 1,614 yards English measure.</cd> -- <col><b>Statute
mile</b></col>, <cd>a mile conforming to statute, that is, in England
and the United States, a mile of 5,280 feet, as distinguished from any
other mile.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mileage</ent><br/
<hw>Mile"age</hw> <pr>(m<imac/l"<asl/j; 48)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>An allowance for traveling expenses at a certain rate
per mile.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Aggregate length or distance in miles; esp., the sum
of lengths of tracks or wires of a railroad company, telegraph company,
etc.</def> <altsp>[Written also <asp>milage</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The number of miles that a vehicle can travel after
consuming a certain quantity of fuel; in the United States, usually
expressed in units of <unit>miles per gallon</unit>; <as>as, smaller
cars tend to get better <ex>mileage</ex></as>. It is sometimes used as a
nmeasure of the energy efficiency of a vehicle.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Use, profit or advantage; <as>as, he got a lot of
<ex>mileage</ex> out of one hit record</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Constructive mileage</b></col>, <cd>a mileage allowed for
journeys supposed to be made, but not actually made.</cd>
<rj><au>Bartlett.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mileometer</ent><br/
<hw>mileometer</hw> <pos>n.</pos> <def>a meter that shows mileage
traversed.</def><br/
<syn><b>Syn. --</b> odometer, hodometer, milometer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milepost</ent><br/
<hw>Mile"post`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A post,
or one of a series of posts, set up to indicate spaces of a mile each or
the distance in miles from a given place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An event or accomplishment marking a significant
advance in an endeavor; a notable achievment; <as>as, putting a man in
orbit was a big <ex>milepost</ex> on the way to the moon</as>.</def><br/
<syn><b>Syn. --</b> milestone.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Milesian</ent><br/
<hw>Mi*le"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Milesius</ets>, Gr. <?/.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Anc. Geog.)</fld> <def>Of or pertaining to Miletus,
a city of Asia Minor, or to its inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Irish Legendary Hist.)</fld> <def>Descended from
King Milesius of Spain, whose two sons are said to have conquered
Ireland about 1300 <sc>b. c.</sc>; or pertaining to the descendants of
King Milesius; hence, Irish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milesian</ent><br/
<hw>Mi*le"sian</hw>, <pos>n.</pos> <sn>1.</sn> <def>A native or
inhabitant of Miletus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A native or inhabitant of Ireland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milestone</ent><br/
<hw>Mile"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
stone serving the same purpose as a milepost.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An event or accomplishment marking a significant
advance in an endeavor; a notable achievment; <as>as, putting a man in
orbit was a major <ex>milestone</ex> on the way to the
moon</as>.</def><br/
<syn><b>Syn. --</b> milepost.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Milfoil</ent><br/
<hw>Mil"foil</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mille-feuille</ets>, L. <ets>millefolium</ets>; <ets>mille</ets>
thousand + <ets>folium</ets> leaf. See <er>Foil</er> a leaf.]</ety>
<fld>(Bot.)</fld> <def>A common composite herb (<spn>Achillea
Millefolium</spn>) with white flowers and finely dissected leaves;
yarrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Water milfoil</b></col> <fld>(Bot.)</fld>, <cd>an aquatic
herb with dissected leaves (<spn>Myriophyllum</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miliaria</ent><br/
\'d8<hw>Mil`i*a"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Miliary</er>.]</ety> <fld>(Med.)</fld> <def>A fever accompanied by
an eruption of small, isolated, red pimples, resembling a millet seed in
form or size; miliary fever.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miliary</ent><br/
<hw>Mil"ia*ry</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>miliarius</ets>, fr. <ets>milium</ets> millet: cf. F.
<ets>miliaire</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Like millet seeds; <as>as, a <ex>miliary</ex>
eruption</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Accompanied with an eruption like
millet seeds; <as>as, a <ex>miliary</ex> fever</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Small and numerous; <as>as, the
<ex>miliary</ex> tubercles of Echini</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miliary</ent><br/
<hw>Mil"ia*ry</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
small tubercles of Echini.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milice</ent><br/
\'d8<hw>Mi`lice"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Militia.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milieu</ent><br/
\'d8<hw>Mi`lieu"</hw> <pr>(m<esl/*ly<etil/")</pr>, <pos>n.</pos>
<ety>[F., fr. <ets>mi</ets> middle (L. <ets>medius</ets>) +
<ets>lieu</ets> place. See <er>Demi-</er>, <er>Lieu</er>.]</ety>
<def>Environment.</def></p>

<p><q>The intellectual and moral <qex>milieu</qex> created by multitudes
of self-centered, cultivated personalities.</q> <rj><qau>J. A.
Symonds.</qau></rj></p>

<p><q>It is one of the great outstanding facts of his progressive
relation to the elements of his social <qex>milieu</qex>.</q>
<rj><qau>J. M. Baldwin.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Miliola</ent><br/
\'d8<hw>Mil"i*o`la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of
L. <ets>milium</ets> millet. So named from its resemblance to millet
seed.]</ety> <fld>(Zool.)</fld> <def>A genus of <ord>Foraminifera</ord>,
having a porcelanous shell with several longitudinal chambers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miliolite</ent><br/
<hw>Mil"i*o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Paleon.)</fld>
<def>A fossil shell of, or similar to, the genus
<gen>Miliola</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miliolite</ent><br/
<hw>Mil"i*o*lite</hw>, <pos>a.</pos> <def>The same
<er>Miliolitic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Miliolite limestone</b></col> <fld>(Geol.)</fld>, <cd>a
building stone, one of the group of the Paris basin, almost entirely
made up of many-chambered microscopic shells.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miliolitic</ent><br/
<hw>Mil`i*o*lit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the genus <gen>Miliola</gen>; containing
miliolites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militancy</ent><br/
<hw>Mil"i*tan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Militant</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The state of being militant; warfare.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A military spirit or system; militarism.</def>
<rj><au>H. Spencer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militant</ent><br/
<hw>Mil"i*tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>militans</ets>, <ets>-antis</ets>, p. pr. of <ets>militare</ets> to
be soldier: cf. F. <ets>militant</ets>. See <er>Militate</er>.]</ety>
<def>Engaged in warfare; fighting; combating; serving as a
soldier.</def> -- <wordforms><wf>Mil"i*tant*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>At which command the powers <qex>militant</qex> . . .<br/
Moved on in silence.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Church militant</b></col>, <cd>the Christian church on
earth, which is supposed to be engaged in a constant warfare against its
enemies, and is thus distinguished from the <xex>church
triumphant</xex>, in heaven.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militar</ent><br/
<hw>Mil"i*tar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Military.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militarily</ent><br/
<hw>Mil"i*ta*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a military
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>militarisation</ent><br/
<hw>militarisation</hw> <pos>n.</pos> <def>militarization.</def>
<mark>[mostly Brit.]</mark> <br/
<syn><b>Syn. --</b> mobilization, mobilisation,
militarization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Militarism</ent><br/
<hw>Mil"i*ta*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>militarisme</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A military state or condition; a military system;
reliance on military force in administering government.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The spirit and traditions of military life.</def>
<rj><au>H. Spencer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The view that military strength, efficiency and
values should dominate the country's public policy choices and take
precedence over other interests.</def><br/
[<source>1913 Webster</source> <source>PJC</source>]</p>

<p><sn>4.</sn> <def>The policy of maintaining a large military force,
even in peacetime; -- a term usually used by opponents of such a policy
on the assumption that such a large force is unnecessary for national
defense.</def><br/
[<source>PJC</source>]</p>

<p><ent>Militarist</ent><br/
<hw>Mil"i*ta*rist</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
military man.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person having a strong spirit of militarism, in
senses 3 or 4.</def><br/
[<source>PJC</source>]</p>

<p><ent>militaristic</ent><br/
<hw>militaristic</hw> <pos>adj.</pos> <def>imbued with militarism, in
senses 3 or 4.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>militarization</ent><br/
<hw>militarization</hw> <pos>n.</pos> <def>act of assembling and putting
into readiness the military forces for war or other emergency.</def><br/
<syn><b>Syn. --</b> mobilization, mobilisation,
militarisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>militarize</ent><br/
<hw>militarize</hw> <pos>v. t. & i.</pos> <def>to lend a military
character to (a country), as by building up a military force.</def><br/
<syn><b>Syn. --</b> make military.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>militarized</ent><br/
<hw>militarized</hw> <pos>adj.</pos> <sn>1.</sn> <def>Equipped with
weapons; armed; -- used of persons, regions, or the military. Contrasted
to <ant>unarmed</ant> and <contr>demilitarized</contr>; <as>as, if
that's a demilitarized zone, I wonder what a <ex>militarized</ex> zone
would look like</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Military</ent><br/
<hw>Mil"i*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>militaris</ets>, <ets>militarius</ets>, from <ets>miles</ets>,
<ets>militis</ets>, soldier: cf. F. <ets>militaire</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of or pertaining to soldiers, to arms, or to war;
belonging to, engaged in, or appropriate to, the affairs of war; <as>as,
a <ex>military</ex> parade; <ex>military</ex> discipline;
<ex>military</ex> bravery; <ex>military</ex> conduct; <ex>military</ex>
renown.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor do I, as an enemy to peace,<br/
Troop in the throngs of <qex>military</qex> men.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Performed or made by soldiers; <as>as, a
<ex>military</ex> election; a <ex>military</ex> expedition.</as></def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Military law</b></col>. <cd>See <cref>Martial law</cref>,
under <er>Martial</er>.</cd> -- <col><b>Military order</b></col>.
<fld>(a)</fld> <cd>A command proceeding from a military superior.</cd>
<sd>(b)</sd> <cd>An association of military persons under a bond of
certain peculiar rules; especially, such an association of knights in
the Middle Ages, or a body in modern times taking a similar form,
membership of which confers some distinction.</cd> -- <col><b>Military
tenure</b></col>, <cd>tenure of land, on condition of performing
military service.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Military</ent><br/
<hw>Mil"i*ta*ry</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>militaire</ets>.]</ety> <def>The whole body of soldiers; soldiery;
militia; troops; the army.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militate</ent><br/
<hw>Mil"i*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Militated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Militating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>militare</ets>, <ets>militatum</ets>, to be a soldier, fr.
<ets>miles</ets>, <ets>militis</ets>, soldier.]</ety> <def>To make war;
to fight; to contend; -- usually followed by <xex>against</xex> and
<xex>with</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These are great questions, where great names <qex>militate</qex>
against each other.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The invisible powers of heaven seemed to <qex>militate</qex> on
the side of the pious emperor.</q> <rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>militate against</ent><br/
<hw>mil"i*tate a*gainst"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
argue against; to cast doubt on; -- used in reference to facts which
tend to disprove a hypothesis; <as>as, the absence of a correlation of
budget deficits with inflation <ex>militates against</ex> any causal
relation between the two</as>. Opposite of
<contr>support</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Militia</ent><br/
<hw>Mi*li"tia</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., military
service, soldiery, fr. <ets>miles</ets>, <ets>militis</ets>, soldier:
cf. F. <ets>milice</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>In the widest sense, the whole military force of a
nation, including both those engaged in military service as a business,
and those competent and available for such service; specifically, the
body of citizens enrolled for military instruction and discipline, but
not subject to be called into actual service except in
emergencies.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king's captains and soldiers fight his battles, and yet . . .
the power of the <qex>militia</qex> is he.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Military service; warfare.</def> <mark>[Obs.]</mark>
<rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militiaman</ent><br/
<hw>Mi*li"tia*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Militiamen</plw> <pr>(<?/)</pr>.</plu> <def>One who belongs to the
militia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Militiate</ent><br/
<hw>Mi*li"ti*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To carry on,
or prepare for, war.</def> <mark>[Obs.]</mark>
<rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milk</ent><br/
<hw>Milk</hw> <pr>(m<icr/lk)</pr>, <pos>n.</pos> <ety>[AS.
<ets>meoluc</ets>, <ets>meoloc</ets>, <ets>meolc</ets>, <ets>milc</ets>;
akin to OFries. <ets>meloc</ets>, D. <ets>melk</ets>, G.
<ets>milch</ets>, OHG. <ets>miluh</ets>, Icel. <ets>mj<omac/lk</ets>,
Sw. <ets>mj<oum/lk</ets>, Dan. <ets>melk</ets>, Goth. <ets>miluks</ets>,
G. <ets>melken</ets> to milk, OHG. <ets>melchan</ets>, Lith.
<ets>milszti</ets>, L. <ets>mulgere</ets>, Gr. <grk>'ame`lgein</grk>.
<root/107. Cf. <er>Milch</er>, <er>Emulsion</er>, <er>Milt</er> soft roe
of fishes.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Physiol.)</fld> <def>A white fluid secreted by the
mammary glands of female mammals for the nourishment of their young,
consisting of minute globules of fat suspended in a solution of casein,
albumin, milk sugar, and inorganic salts.</def> <ldquo/White as morne
<xex>milk</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A kind of juice or sap, usually
white in color, found in certain plants; latex. See
<er>Latex</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An emulsion made by bruising seeds; <as>as, the
<ex>milk</ex> of almonds, produced by pounding almonds with sugar and
water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>The ripe, undischarged spat of an
oyster.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Condensed milk</b></col>. <cd>See under
<er>Condense</er>, <pos>v. t.</pos></cd> -- <col><b>Milk crust</b></col>
<fld>(Med.)</fld>, <cd>vesicular eczema occurring on the face and scalp
of nursing infants. See <er>Eczema</er>.</cd> -- <col><b>Milk
fever</b></col>. <sd>(a)</sd> <fld>(Med.)</fld> <cd>A fever which
accompanies or precedes the first lactation</cd>. It is usually
transitory. <sd>(b)</sd> <fld>(Vet. Surg.)</fld> <cd>A form puerperal
peritonitis in cattle; also, a variety of meningitis occurring in cows
after calving.</cd> -- <col><b>Milk glass</b></col>, <cd>glass having a
milky appearance.</cd> -- <col><b>Milk knot</b></col> <fld>(Med.)</fld>,
<cd>a hard lump forming in the breast of a nursing woman, due to
obstruction to the flow of milk and congestion of the mammary
glands.</cd> -- <col><b>Milk leg</b></col> <fld>(Med.)</fld>, <cd>a
swollen condition of the leg, usually in puerperal women, caused by an
inflammation of veins, and characterized by a white appearance
occasioned by an accumulation of serum and sometimes of pus in the
cellular tissue.</cd> -- <col><b>Milk meats</b></col>, <cd>food made
from milk, as butter and cheese.</cd> <mark>[Obs.]</mark>
<au>Bailey.</au> -- <col><b>Milk mirror</b></col>. <cd>Same as
<er>Escutcheon</er>, 2.</cd> -- <col><b>Milk molar</b></col>
<fld>(Anat.)</fld>, <cd>one of the deciduous molar teeth which are shed
and replaced by the premolars.</cd> -- <col><b>Milk of lime</b></col>
<fld>(Chem.)</fld>, <cd>a watery emulsion of calcium hydrate, produced
by macerating quicklime in water.</cd> -- <col><b>Milk parsley</b></col>
<fld>(Bot.)</fld>, <cd>an umbelliferous plant (<spn>Peucedanum
palustre</spn>) of Europe and Asia, having a milky juice.</cd> --
<col><b>Milk pea</b></col> <fld>(Bot.)</fld>, <cd>a genus
(<gen>Galactia</gen>) of leguminous and, usually, twining plants.</cd>
-- <col><b>Milk sickness</b></col> <fld>(Med.)</fld>, <cd>See <er>milk
sickness</er> in the vocabulary.</cd> -- <col><b>Milk snake</b></col>
<fld>(Zool.)</fld>, <cd>a harmless American snake (<spn>Ophibolus
triangulus</spn>, or <spn>Ophibolus eximius</spn>). It is variously
marked with white, gray, and red. Called also <altname>milk
adder</altname>, <altname>chicken snake</altname>, <altname>house
snake</altname>, etc.</cd> -- <col><b>Milk sugar</b></col>.
<fld>(Physiol. Chem.)</fld> <cd>See <er>Lactose</er>, and <cref>Sugar of
milk</cref> (below).</cd> -- <col><b>Milk thistle</b></col>
<fld>(Bot.)</fld>, <cd>an esculent European thistle (<spn>Silybum
marianum</spn>), having the veins of its leaves of a milky
whiteness.</cd> -- <col><b>Milk thrush</b></col>. <fld>(Med.)</fld>
<cd>See <er>Thrush</er>.</cd> -- <col><b>Milk tooth</b></col>
<fld>(Anat.)</fld>, <cd>one of the temporary first set of teeth in young
mammals; in man there are twenty.</cd> -- <col><b>Milk tree</b></col>
<fld>(Bot.)</fld>, <cd>a tree yielding a milky juice, as the cow tree of
South America (<spn>Brosimum Galactodendron</spn>), and the
<spn>Euphorbia balsamifera</spn> of the Canaries, the milk of both of
which is wholesome food.</cd> -- <col><b>Milk vessel</b></col>
<fld>(Bot.)</fld>, <cd>a special cell in the inner bark of a plant, or a
series of cells, in which the milky juice is contained. See
<er>Latex</er>.</cd> -- <col><b>Rock milk</b></col>. <cd>See
<cref>Agaric mineral</cref>, under <er>Agaric</er>.</cd> --
<col><b>Sugar of milk</b></col>. <cd>The sugar characteristic of milk; a
hard white crystalline slightly sweet substance obtained by evaporation
of the whey of milk. It is used in pellets and powder as a vehicle for
homeopathic medicines, and as an article of diet. See
<er>Lactose</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 924 --></p>

<p><ent>Milk</ent><br/
<hw>Milk</hw> <pr>(m<icr/lk)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Milked</conjf> <pr>(m<icr/lkt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Milking</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To draw or press milk from the breasts or udder of,
by the hand or mouth; to withdraw the milk of.</def>
<ldquo/<xex>Milking</xex> the kine.<rdquo/ <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have given suck, and know<br/
How tender 't is to love the babe that <qex>milks</qex> me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To draw from the breasts or udder; to extract, as
milk; <as>as, to <ex>milk</ex> wholesome milk from healthy
cows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To draw anything from, as if by milking; to compel
to yield profit or advantage; to plunder.</def>
<rj><au>Tyndale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They [the lawyers] <qex>milk</qex> an unfortunate estate as
regularly as a dairyman does his stock.</q> <rj><qau>London
Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To milk the street</b></col>, <cd>to squeeze the smaller
operators in stocks and extract a profit from them, by alternately
raising and depressing prices within a short range; -- said of the large
dealers.</cd> <mark>[Cant]</mark> -- <col><b>To milk a
telegram</b></col>, <cd>to use for one's own advantage the contents of a
telegram belonging to another person.</cd> <mark>[Cant]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milk</ent><br/
<hw>Milk</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To draw or
to yield milk.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>To give off small gas bubbles
during the final part of the charging operation; -- said of a storage
battery.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>milkcap</ent><br/
<hw>milkcap</hw> <pos>n.</pos> <def>A type of edible mushroom
(<spn>Lactarius delicioso</spn>).</def><br/
<syn><b>Syn. --</b> <spn>Lactarius delicioso</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milken</ent><br/
<hw>Milk"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of
milk.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milker</ent><br/
<hw>Milk"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
milks; also, a mechanical apparatus for milking cows.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cow or other animal that gives milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milkful</ent><br/
<hw>Milk"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of milk;
abounding with food.</def> <mark>[R.]</mark> <ldquo/<xex>Milkful</xex>
vales.<rdquo/ <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milkily</ent><br/
<hw>Milk"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a milky
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milkiness</ent><br/
<hw>Milk"i*ness</hw>, <pos>n.</pos> <def>State or quality of being
milky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milk-livered</ent><br/
<hw>Milk"-liv`ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>White-livered;
cowardly; timorous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milkmaid</ent><br/
<hw>Milk"maid`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who milks
cows or is employed in the dairy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milkman</ent><br/
<hw>Milk"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Milkmen</plw> <pr>(<?/)</pr>.</plu> <def>A man who sells milk or
delivers it to customers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>milk shake</ent><br/
<ent>milkshake</ent><br/
<mhw><hw>milk"shake`</hw>, <hw>milk" shake`</hw></mhw> <pr>(m<icr/lk"
sh<amac/k`)</pr> <pos>n.</pos> <def>A frothy drink of milk and flavoring
and sometimes fruit or ice cream, shaken together or blended in a
blender.</def><br/
<syn><b>Syn. --</b> milk shake, shake.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milk sickness</ent><br/
<hw>Milk sickness</hw>. <fld>(Veter., Med.)</fld> <def>A peculiar
malignant disease, occurring in parts of the western United States, and
affecting certain kinds of farm stock (esp. cows), and persons using the
meat or dairy products of infected cattle. Its chief symptoms in man are
uncontrollable vomiting, obstinate constipation, pain, and muscular
tremors. Its origin in cattle has been variously ascribed to the
presence of certain plants in their food, and to polluted
water.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Milksop</ent><br/
<hw>Milk"sop`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A piece of bread
sopped in milk; figuratively, an effeminate or weak-minded person.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To wed a <qex>milksop</qex> or a coward ape.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milk vetch</ent><br/
<hw>Milk" vetch`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>A leguminous
herb (<spn>Astragalus glycyphyllos</spn>) of Europe and Asia, supposed
to increase the secretion of milk in goats.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is sometimes taken for the whole genus
<gen>Astragalus</gen>, of which there are about two hundred species in
North America, and even more elsewhere.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>milkwagon</ent><br/
<hw>milkwagon</hw> <pos>n.</pos> <def>a wagon for delivering
milk.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milkweed</ent><br/
<hw>Milk"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Any plant of the genera <gen>Asclepias</gen> and
<gen>Acerates</gen>, abounding in a milky juice, and having its seed
attached to a long silky down; silkweed. The name is also applied to
several other plants with a milky juice, as to several kinds of spurge.
Its leaves are a favorite food source for the larvae of the monarch
butterfly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milkwort</ent><br/
<hw>Milk"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus of plants (<gen>Polygala</gen>) of many species. The common
European <spn>Polygala vulgaris</spn> was supposed to have the power of
producing a flow of milk in nurses.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The species of <gen>Campanula</gen>, or bellflower, are
sometimes called <xex>milkwort</xex>, from their juice.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milky</ent><br/
<hw>Milk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Consisting
of, or containing, milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pails high foaming with a <qex>milky</qex> flood.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like, or somewhat like, milk; whitish and turbid;
<as>as, the water is <ex>milky</ex>. <ldquo/<ex>Milky</ex>
juice.<rdquo/</as></def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Yielding milk.</def> <ldquo/<xex>Milky</xex>
mothers.<rdquo/ <rj><au>Roscommon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Mild; tame; spiritless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Has friendship such a faint and <qex>milky</qex> heart?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Milky Way</b></col>. <fld>(Astron.)</fld> <cd>See
<er>Galaxy</er>, 1.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mill</ent><br/
<hw>Mill</hw> <pr>(m<icr/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>mille</ets> a thousand. Cf. <er>Mile</er>.]</ety> <def>A money of
account of the United States, having the value of the tenth of a cent,
or the thousandth of a dollar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mill</ent><br/
<hw>Mill</hw>, <pos>n.</pos> <ety>[OE. <ets>mille</ets>,
<ets>melle</ets>, <ets>mulle</ets>, <ets>milne</ets>, AS.
<ets>myln</ets>, <ets>mylen</ets>; akin to D. <ets>molen</ets>, G.
<ets>m<uum/hle</ets>, OHG. <ets>mul<imac/</ets>, <ets>mul<imac/n</ets>,
Icel. <ets>mylna</ets>; all prob. from L. <ets>molina</ets>, fr.
<ets>mola</ets> millstone; prop., that which grinds, akin to
<ets>molere</ets> to grind, Goth. <ets>malan</ets>, G.
<ets>mahlen</ets>, and to E. <ets>meal</ets>. <root/108. See
<ets>Meal</ets> flour, and cf. <er>Moline</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A machine for grinding or comminuting any substance,
as grain, by rubbing and crushing it between two hard, rough, or
indented surfaces; <as>as, a grist<ex>mill</ex>, a coffee <ex>mill</ex>;
a bone <ex>mill</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A machine used for expelling the juice, sap, etc.,
from vegetable tissues by pressure, or by pressure in combination with a
grinding, or cutting process; <as>as, a cider <ex>mill</ex>; a cane
<ex>mill</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A machine for grinding and polishing; <as>as, a
lapidary <ex>mill</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A common name for various machines which produce a
manufactured product, or change the form of a raw material by the
continuous repetition of some simple action; <as>as, a saw<ex>mill</ex>;
a stamping <ex>mill</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A building or collection of buildings with machinery
by which the processes of manufacturing are carried on; <as>as, a cotton
<ex>mill</ex>; a powder <ex>mill</ex>; a rolling
<ex>mill</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Die Sinking)</fld> <def>A hardened steel roller
having a design in relief, used for imprinting a reversed copy of the
design in a softer metal, as copper.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mining)</fld> <sd>(a)</sd> <def>An excavation in
rock, transverse to the workings, from which material for filling is
obtained.</def> <sd>(b)</sd> <def>A passage underground through which
ore is shot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A milling cutter. See <xex>Illust.</xex> under
<er>Milling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A pugilistic encounter.</def> <mark>[Cant]</mark>
<rj><au>R. D. Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Short for <er>Treadmill</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>11.</sn> <def>The raised or ridged edge or surface made in
milling anything, as a coin or screw.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>12.</sn> <def>A building or complex of buildings containing a
mill{1} or other machinery to grind grains into flour.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Edge mill</b></col>, <col><b>Flint
mill</b></col></mcol>, <cd>etc. See under <er>Edge</er>, <er>Flint</er>,
etc.</cd> -- <col><b>Mill bar</b></col> <fld>(Iron Works)</fld>, <cd>a
rough bar rolled or drawn directly from a bloom or puddle bar for
conversion into merchant iron in the mill.</cd> -- <col><b>Mill
cinder</b></col>, <cd>slag from a puddling furnace.</cd> -- <col><b>Mill
head</b></col>, <cd>the head of water employed to turn the wheel of a
mill.</cd> -- <col><b>Mill pick</b></col>, <cd>a pick for dressing
millstones.</cd> -- <col><b>Mill pond</b></col>, <cd>a pond that
supplies the water for a mill.</cd> -- <col><b>Mill race</b></col>,
<cd>the canal in which water is conveyed to a mill wheel, or the current
of water which drives the wheel.</cd> -- <col><b>Mill tail</b></col>,
<cd>the water which flows from a mill wheel after turning it, or the
channel in which the water flows.</cd> -- <col><b>Mill tooth</b></col>,
<cd>a grinder or molar tooth.</cd> -- <col><b>Mill wheel</b></col>,
<cd>the water wheel that drives the machinery of a mill.</cd> --
<col><b>Gin mill</b></col>, <cd>a tavern; a bar; a saloon; especially, a
cheap or seedy establishment that serves liquor by the drink.</cd> --
<col><b>Roller mill</b></col>, <cd>a mill in which flour or meal is made
by crushing grain between rollers.</cd> -- <col><b>Stamp mill</b></col>
<fld>(Mining)</fld>, <cd>a mill in which ore is crushed by stamps.</cd>
-- <col><b>To go through the mill</b></col>, <cd>to experience the
suffering or discipline necessary to bring one to a certain degree of
knowledge or skill, or to a certain mental state.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mill</ent><br/
<hw>Mill</hw> <pr>(m<icr/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Milled</conjf> <pr>(m<icr/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Milling</conjf>.]</vmorph> <ety>[See <er>Mill</er>,
<pos>n.</pos>, and cf. <er>Muller</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To reduce to fine particles, or to small pieces, in
a mill; to grind; to comminute.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To shape, finish, or transform by passing through a
machine; specifically, to shape or dress, as metal, by means of a rotary
cutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make a raised border around the edges of, or to
cut fine grooves or indentations across the edges of, as of a coin, or a
screw head; also, to stamp in a coining press; to coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To pass through a fulling mill; to full, as
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To beat with the fists.</def> <mark>[Cant]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To roll into bars, as steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To mill chocolate</b></col>, <cd>to make it frothy, as by
churning.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mill</ent><br/
<hw>Mill</hw>, <pos>v. i.</pos> <fld>(Zool.)</fld> <def>To swim under
water; -- said of air-breathing creatures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To undergo hulling, as maize.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>To move in a circle, as cattle upon a plain; to move
around aimlessly; -- usually used with <ptcl>around</ptcl>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The deer and the pig and the nilghar were <qex>milling</qex> round
and round in a circle of eight or ten miles radius.</q>
<rj><qau>Kipling.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>To swim suddenly in a new direction; -- said of
whales.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>5.</sn> <def>To take part in a mill; to box.</def>
<mark>[Cant]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mill</ent><br/
<hw>Mill</hw>, <pos>v. t.</pos> <sn>1.</sn> <fld>(Mining)</fld> <def>To
fill (a winze or interior incline) with broken ore, to be drawn out at
the bottom.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To cause to mill, or circle round, as
cattle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Millboard</ent><br/
<hw>Mill"board`</hw> <pr>(m<icr/l"b<omac/rd`)</pr>, <pos>n.</pos> <def>A
kind of stout pasteboard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mill-cake</ent><br/
<hw>Mill"-cake`</hw> <pr>(m<icr/l"k<amac/k`)</pr>, <pos>n.</pos>
<def>The incorporated materials for gunpowder, in the form of a dense
mass or cake, ready to be subjected to the process of
granulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milldam</ent><br/
<hw>Mill"dam`</hw> <pr>(m<icr/l"d<acr/m)</pr>, <pos>n.</pos> <def>A dam
or mound to obstruct a water course, and raise the water to a height
sufficient to turn a mill wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milled</ent><br/
<hw>Milled</hw> <pr>(m<icr/ld)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having been subjected to some process of milling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>Having multiple fine
grooves on the rim, in the direction from obverse to reverse; -- of
coins. Coins of silver and gold were <ex>milled</ex> to make it
impossible for uncrupulous persons to shave small pieces from the edge
without detection.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Milled cloth</b></col>, <cd>cloth that has been beaten in
a fulling mill.</cd> -- <col><b>Milled lead</b></col>, <cd>lead rolled
into sheets.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millefiore glass</ent><br/
<hw>Mil`le*fi*o"re glass`</hw> <pr>(?)</pr>. <ety>[It. <ets>mille</ets>
thousand + <ets>fiore</ets> flower.]</ety> <def>Slender rods or tubes of
colored glass fused together and embedded in clear glass; -- used for
paperweights and other small articles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millenarian</ent><br/
<hw>Mil`le*na"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Millenary</er>.]</ety> <def>Consisting of a thousand years; of or
pertaining to the millennium, or to the Millenarians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millenarian</ent><br/
<hw>Mil`le*na"ri*an</hw>, <pos>n.</pos> <def>One who believes that
Christ will personally reign on earth a thousand years; a
Chiliast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millenarism</ent><br/
<ent>Millenarianism</ent><br/
<mhw>{ <hw>Mil`le*na"ri*an*ism</hw> <pr>(?)</pr>,
<hw>Mil"le*na*rism</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The
doctrine of Millenarians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millenary</ent><br/
<hw>Mil"le*na*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>millenarius</ets>, fr. <ets>milleni</ets> a thousand each, fr.
<ets>mille</ets> a thousand: cf. F. <ets>mill<eacute/naire</ets>. See
<er>Mile</er>.]</ety> <def>Consisting of a thousand;
millennial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millenary</ent><br/
<hw>Mil"le*na*ry</hw>, <pos>n.</pos> <def>The space of a thousand years;
a millennium; also, a <er>Millenarian</er>.</def><ldquo/During that
<xex>millenary</xex>.<rdquo/ <rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millennial</ent><br/
<hw>Mil*len"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to the millennium, or to a thousand years; <as>as, a <ex>millennial</ex>
period; <ex>millennial</ex> happiness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millennialist</ent><br/
<hw>Mil*len"ni*al*ist</hw>, <pos>n.</pos> <def>One who believes that
Christ will reign personally on earth a thousand years; a Chiliast;
also, a believer in the universal prevalence of Christianity for a long
period.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millenniarism</ent><br/
<ent>Millennianism</ent><br/
<mhw>{ <hw>Mil*len"ni*an*ism</hw> <pr>(?)</pr>,
<hw>Mil*len"ni*a*rism</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<def>Belief in, or expectation of, the millennium{2};
millenarianism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millennist</ent><br/
<hw>Mil"len*nist</hw> <pr>(m<icr/l"l<ecr/n*n<icr/st)</pr>, <pos>n.</pos>
<def>One who believes in the millennium{2}.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millennium</ent><br/
<hw>Mil*len"ni*um</hw> <pr>(m<icr/l*l<ecr/n"n<icr/*<ucr/m)</pr>,
<pos>n.</pos> <ety>[LL., fr. L. <ets>mille</ets> a thousand +
<ets>annus</ets> a year. See <er>Mile</er>, and <er>Annual</er>.]</ety>
<sn>1.</sn> <def>A period of one thousand years.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>The period of a
thousand years mentioned in the twentieth chapter of Revelation, during
which holiness is to be triumphant throughout the world. Some believe
that, during this period, Christ will reign on earth in person with his
saints.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>A long period of happiness,
righteousness, and prosperity, usually considered as being in the
indefinite future.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A thousandth anniversary;</def>
<specif>especially,</specif> <def>Each first day of January falling in a
year which is a multiple of one thousand, such as in 1000 <sc>a. d.</sc>
or 2000 <sc>a. d.</sc>; <as>as, the second <ex>millenium</ex> will be
celebrated on January 1, 2000; also used attributively, as a
<ex>millenium</ex> celebration</as>.</def> <note>Technically, if the
calendar of the Common Era (Anno Domini) is considered as beginning on
January 1, 1 <sc>a. d.</sc>, then the <ex>millenium</ex> will fall in
each year ending in <it>001</it>, as in 1001 <sc>a. d.</sc> or January
1, 2001 <sc>a. d.</sc>. However in the common culture, the change of the
first digit of the year from 1 to 2, as from 1999 to 2000 is considered
as the more symbolic event, especially since the dating of the beginning
of the Christian era is somewhat arbitrary, having been an attempt to
fix the date of the birth of Christ, and being considered by scholars as
being in error by as much as five years.</note><br/
[<source>PJC</source>]</p>

<p><ent>millennium bug</ent><br/
<hw>mil*len"ni*um bug`</hw> <pr>(m<icr/l*l<ecr/n"n<icr/*<ucr/m
b<ucr/g`)</pr>, <pos>n.</pos> <fld>(Computers)</fld> <def>An error in
the coding of certain computer programs which store the year component
of the date as two digits, assuming that the first two digits are
<it>19</it>, rather than as a complete number of four digits; when such
programs are used after January 1, 2000, the date may be misinterpreted,
causing serious errors or total failure of the program; -- called also
<altname>year 2000 bug</altname>, <altname>year 2000 problem</altname>
and <altname>Y2K bug</altname>.</def> <note>In the several years leading
up to the year 2000, large corporations and other users of computers in
total spent many billions of dollars correcting this error in the
programs they use.</note><br/
[<source>PJC</source>]</p>

<p><ent>Milleped</ent><br/
<hw>Mil"le*ped</hw> <pr>(m<icr/l"l<esl/*p<ecr/d<icr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>millepeda</ets>; <ets>mille</ets> a thousand
+ <ets>pes</ets>, <ets>pedis</ets>, foot: cf. F.
<ets>mille-pieds</ets>.]</ety> <fld>(Zool.)</fld> <def>A myriapod with
many legs, esp. a chilognath, as the galleyworm.</def> <altsp>[Written
also <asp>millipede</asp> and <asp>milliped</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millepora</ent><br/
\'d8<hw>Mil*le*po"ra</hw> <pr>(m<icr/l*l<esl/*p<omac/"r<adot/)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A genus of
Hydrocorallia, which includes the millipores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millepore</ent><br/
<hw>Mil"le*pore</hw> <pr>(m<icr/l"l<esl/*p<omac/r)</pr>, <pos>n.</pos>
<ety>[L. <ets>mille</ets> thousand + <ets>porus</ets> pore: cf. F.
<ets>mill<eacute/pore</ets>.]</ety> <fld>(Zool.)</fld> <def>Any coral of
the genus Millepora, having the surface nearly smooth, and perforated
with very minute unequal pores, or cells. The animals are hydroids, not
Anthozoa. See <er>Hydrocorallia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milleporite</ent><br/
<hw>Mil"le*po*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Paleon.)</fld>
<def>A fossil millepore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miller</ent><br/
<hw>Mill"er</hw> <pr>(m<icr/l"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who keeps or attends a flour mill or gristmill.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A milling machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A moth or
lepidopterous insect; -- so called because the wings appear as if
covered with white dust or powder, like a miller's clothes. Called also
<altname>moth miller</altname>.</def> <sd>(b)</sd> <def>The eagle
ray.</def> <sd>(c)</sd> <def>The hen harrier.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Miller's thumb</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>A small fresh-water fish of the genus <gen>Uranidea</gen> (formerly
<gen>Cottus</gen>), as the European species (<spn>Uranidea gobio</spn>),
and the American (<spn>Uranidea gracilis</spn>); -- called also
<altname>bullhead</altname>.</cd> <sd>(b)</sd> <cd>A small bird, as the
gold-crest, chiff-chaff, and long-tailed tit.</cd> <mark>[Prov.
Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millerite</ent><br/
<hw>Mil"ler*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A believer in the
doctrine of <person>William <etsep>Miller</etsep></person> (d. 1849),
who taught that the end of the world and the second coming of Christ
were at hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millerite</ent><br/
<hw>Mil"ler*ite</hw>, <pos>n.</pos> <ety>[From <person>W. H.
<etsep>Miller</etsep></person>, of Cambridge, Eng.]</ety>
<fld>(Min.)</fld> <def>A sulphide of nickel, commonly occurring in
delicate capillary crystals, also in incrustations of a bronze yellow;
-- sometimes called <altname>hair pyrites</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millesimal</ent><br/
<hw>Mil*les"i*mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>millesimus</ets>, fr. <ets>mille</ets> a thousand.]</ety>
<def>Thousandth; consisting of thousandth parts; <as>as,
<ex>millesimal</ex> fractions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>millet</ent><br/
<hw>mil"let</hw> <pr>(m<icr/l"l<ecr/t)</pr>, <pos>n.</pos> <ety>[F.,
dim. of <ets>mil</ets>, L. <ets>milium</ets>; akin to Gr.
<grk>meli`nh</grk>, AS. <ets>mil</ets>.]</ety> <fld>(Bot.)</fld>
<def>The name of several cereal and forage grasses which bear an
abundance of small roundish grains. The common millets of Germany and
Southern Europe are <spn>Panicum miliaceum</spn>, and <spn>Setaria
Italica</spn>.</def></p>

<p><-- all species in this note are subtypes --> <note><hand/
<col><b>Arabian millet</b></col> is <spn>Sorghum Halepense</spn>. --
<col><b>Egyptian millet</b></col> <it>or</it> <col><b>East Indian
millet</b></col> is <spn>Penicillaria spicata</spn>. -- <col><b>Indian
millet</b></col> is <spn>Sorghum vulgare</spn>. (See under
<er>Indian</er>.) -- <col><b>Italian millet</b></col> is <spn>Setaria
Italica</spn>, a coarse, rank-growing annual grass, valuable for fodder
when cut young, and bearing nutritive seeds; -- called also
<altname>Hungarian grass</altname>. -- <col><b>Texas millet</b></col> is
<spn>Panicum Texanum</spn>. -- <col><b>Wild millet</b></col>,
<xex>or</xex> <col><b>Millet grass</b></col>, is <spn>Milium
effusum</spn>, a tall grass growing in woods.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>mill-girl</ent><br/
<hw>mill-girl</hw> <pos>n.</pos> <def>a girl who works in a
mill.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milli-</ent><br/
<hw>Mil"li-</hw> <pr>(m<icr/l"l<icr/-)</pr>. <ety>[From L.
<ets>mille</ets> a thousand.]</ety> <fld>(Metric System, Elec., Mech.,
etc.)</fld> <def>A prefix denoting a <sig>thousandth part of</sig>;
<as>as, <ex>milli</ex>meter, <ex>milli</ex>gram,
<ex>milli</ex>amp<egrave/re</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>milliammeter</ent><br/
<hw>milliammeter</hw> <pos>n.</pos> <def>a sensitive ammeter for
detecting small currents, graduated in milliamperes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milliampere</ent><br/
<hw>Mil`li*am`p<egrave/re"</hw>
<pr>(m<icr/l"l<icr/*<aum/N`p<acir/r")</pr>, <pos>n.</pos>
<ety>[<ets>Milli-</ets> + <ets>amp<egrave/re</ets>.]</ety>
<fld>(Elec.)</fld> <def>The thousandth part of one ampere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milliard</ent><br/
\'d8<hw>Mil`liard"</hw> <pr>(F. m<esl/l`y<adot/r"; E.
m<icr/l"l<icr/*<aum/rd)</pr>, <pos>n.</pos> <ety>[F., from
<ets>mille</ets>, <ets>mil</ets>, thousand, L. <ets>mille</ets>.]</ety>
<def>A thousand millions; -- usually called <altname>billion</altname>
in the United States. See <er>Billion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milliary</ent><br/
<hw>Mil"li*a*ry</hw> <pr>(m<icr/l"l<icr/*<asl/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[L. <ets>milliarius</ets> containing a thousand, fr.
<ets>mille</ets> thousand: cf. F. <ets>milliaire</ets> milliary. See
<er>Mile</er>.]</ety> <def>Of or pertaining to a mile, or to distance by
miles; denoting a mile or miles.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>milliary</qex> column, from which they used to compute the
distance of all the cities and places of note.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milliary</ent><br/
<hw>Mil"li*a*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Milliaries</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>milliarium</ets>. See <er>Milliary</er>, <pos>a.</pos>]</ety>
<def>A milestone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millier</ent><br/
\'d8<hw>Mil`lier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>mille</ets> thousand.]</ety> <def>A weight of the metric system,
being one million grams; a metric ton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millifold</ent><br/
<hw>Mil"li*fold`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mille</ets> thousand + E. <ets>fold</ets> times.]</ety>
<def>Thousandfold.</def> <mark>[R.]</mark> <rj><au>Davies (Holy
Roode).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milligramme</ent><br/
<ent>Milligram</ent><br/
<mhw>{ <hw>Mil"li*gram</hw>, <hw>Mil"li*gramme</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>milligramme</ets>;
<ets>milli-</ets> milli- + <ets>gramme</ets>. See 3d
<er>Gram</er>.]</ety> <def>A measure of mass and weight, in the metric
system, being the thousandth part of a gram, very nearly equal to the
weight of a cubic millimeter of water, or .01543 of a grain
avoirdupois.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millilitre</ent><br/
<ent>Milliliter</ent><br/
<mhw>{ <hw>Mil"li*li`ter</hw>, <hw>Mil"li*li`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>millilitre</ets>;
<ets>milli-</ets> milli- + <ets>litre</ets>. See <er>Liter</er>.]</ety>
<def>A measure of capacity in the metric system, containing the
thousandth part of a liter. It is very nearly equal to a cubic
centimeter, and is equal to .061025 of an English cubic inch, or to
.033815 of an American fluid ounce.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millimetre</ent><br/
<ent>Millimeter</ent><br/
<mhw>{ <hw>Mil"li*me`ter</hw>, <hw>Mil"li*me`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>millim<egrave/tre</ets>;
<ets>milli-</ets> milli- + <ets>m<egrave/tre</ets>. See 3d
<er>Meter</er>.]</ety> <def>A lineal measure in the metric system,
containing the thousandth part of a meter; equal to .03937 of an inch.
See 3d <er>Meter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millimicron</ent><br/
<hw>Mil"li*mi`cron</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Milli-</ets> + <ets>micron</ets>.]</ety> <def>The thousandth
part of a micron or the millionth part of a millimeter; one nanometer;
-- a unit of length sometimes used in measuring light waves,
etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>milline</ent><br/
<hw>milline</hw> <pos>n.</pos> <def>an advertising measure; one agate
line appearing in one million copies of a publication.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milliner</ent><br/
<hw>Mil"li*ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Milaner</ets> an inhabitant of <ets>Milan</ets>, in Italy; hence, a
man from <ets>Milan</ets> who imported women's finery.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Formerly, a man who imported and dealt in small
articles of a miscellaneous kind, especially such as please the fancy of
women.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>milliner</qex> can so fit his customers with gloves.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who designs, makes, trims, or deals in
hats, bonnets, headdresses, etc., for women.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Man milliner</b></col>, <cd>a man who makes or deals in
millinery, that occupation having been at one time predominantly
performed by women; hence, contemptuously, a man who is busied with
trifling occupations or embellishments.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Millinery</ent><br/
<hw>Mil"li*ner*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
articles made or sold by milliners, as headdresses, hats or bonnets,
laces, ribbons, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The business of work of a milliner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millinet</ent><br/
<hw>Mil`li*net"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stiff cotton
fabric used by milliners for lining bonnets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milling</ent><br/
<hw>Mill"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or employment
of grinding or passing through a mill; the process of fulling; the
process of making a raised or intented edge upon coin, etc.; the process
of dressing surfaces of various shapes with rotary cutters. See
<er>Mill</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>High milling</b></col>, <cd>milling in which grain is
reduced to flour by a succession of crackings, or of slight and partial
crushings, alternately with sifting and sorting the product.</cd> --
<col><b>Low milling</b></col>, <cd>milling in which the reduction is
effected in a single crushing or grinding.</cd> -- <col><b>Milling
cutter</b></col>, <cd>a fluted, sharp-edged rotary cutter for dressing
surfaces, as of metal, of various shapes.</cd> -- <col><b>Milling
machine</b></col>, <cd>a machine tool for dressing surfaces by rotary
cutters.</cd> -- <col><b>Milling tool</b></col>, <cd>a roller with
indented edge or surface, for producing like indentations in metal by
rolling pressure, as in turning; a knurling tool; a milling
cutter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Million</ent><br/
<hw>Mil"lion</hw> <pr>(m<icr/l"y<ucr/n)</pr>, <pos>n.</pos> <ety>[F.,
from LL. <ets>millio</ets>, fr. L. <ets>mille</ets> a thousand. See
<er>Mile</er>.]</ety> <sn>1.</sn> <def>The number of ten hundred
thousand, or a thousand thousand, -- written 1,000,000. See the Note
under <er>Hundred</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A very great number; an indefinitely large
number.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Millions</qex> of truths that a man is not concerned to
know.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The mass of common people; -- with the article
<xex>the</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For the play, I remember, pleased not the <qex>million</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millionaire</ent><br/
<hw>Mil`lion*aire"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>millionnaire</ets>.]</ety> <def>One whose wealth is counted by
millions of francs, dollars, or pounds; a very rich person; a person
worth a million or more.</def> <altsp>[Written also
<asp>millionnaire</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millionairess</ent><br/
<hw>Mil`lion*air"ess</hw>, <pos>n.</pos> <def>A woman who is a
millionaire, or the wife of a millionaire.</def> <mark>[Humorous]</mark>
<rj><au>Holmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millionary</ent><br/
<hw>Mil"lion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to millions; consisting of millions; <as>as, the <ex>millionary</ex>
chronology of the pundits</as>.</def> <rj><au>Pinkerton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millioned</ent><br/
<hw>Mil"lioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Multiplied by
millions; innumerable.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millionnaire</ent><br/
\'d8<hw>Mil`lion`naire"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Millionaire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millionth</ent><br/
<hw>Mil"lionth</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Being the last one
of a million of units or objects counted in regular order from the first
of a series or succession; being one of a million.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millionth</ent><br/
<hw>Mil"lionth</hw>, <pos>n.</pos> <def>The quotient of a unit divided
by one million; one of a million equal parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milliped</ent><br/
<hw>Mil"li*ped</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The same <er>Milleped</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millistere</ent><br/
<hw>Mil"li*stere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>millist<egrave/re</ets>, from <ets>milli-</ets> milli- +
<ets>st<egrave/re</ets>.]</ety> <def>A liter, or cubic
decimeter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milliweber</ent><br/
<hw>Mil`li*we"ber</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Milli-</ets> + <ets>weber</ets>.]</ety> <fld>(Physics)</fld>
<def>The thousandth part of one weber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>millpond</ent><br/
<hw>millpond</hw> <pos>n.</pos> <def>a pond formed by damming a stream
to provide a head of water to turn a mill wheel.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>millrace</ent><br/
<hw>millrace</hw> <pos>n.</pos> <def>a channel from a millpond to a
millwheel, to provide the water current that turns the
millwheel.</def><br/
<syn><b>Syn. --</b> millrun.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 925 --></p>

<p><ent>Millreis</ent><br/
<ent>Millree</ent><br/
<ent>Millrea</ent><br/
<mhw>{ <hw>Mill"rea`</hw> <pr>(m<icr/l"r<emac/`)</pr>,
<hw>Mill"ree`</hw>, <hw>Mill"reis`</hw> <pr>(m<icr/l"r<emac/s`)</pr>
}</mhw>, <pos>n.</pos> <def>See <er>Milreis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millrynd</ent><br/
<ent>Millrind</ent><br/
<mhw>{ <hw>Mill"rind`</hw> <pr>(m<icr/l"r<imac/nd`)</pr>,
<hw>Mill"rynd`</hw> <pr>(m<icr/l"r<imac/nd`)</pr> }</mhw>, <pos>n.</pos>
<ety>[<ets>Mill</ets> + <ets>rynd</ets>.]</ety> <fld>(Her.)</fld> <def>A
figure supposed to represent the iron which holds a millstone by being
set into its center.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>millrun</ent><br/
<hw>millrun</hw> <pos>n.</pos> <def>a <er>millrace</er>.</def><br/
<syn><b>Syn. --</b> millrace.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mill-sixpence</ent><br/
<hw>Mill"-sixpence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A milled
sixpence; -- the sixpence being one of the first English coins milled
(1561).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millstone</ent><br/
<hw>Mill"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of two
circular stones used for grinding grain or other substance in a
mill{1}.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No man shall take the nether or the upper <qex>millstone</qex> to
pledge.</q> <rj><qau>Deut. xxiv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The cellular siliceous rock called buhrstone is usually
employed for millstones; also, some kinds of lava, as that Niedermendig,
or other firm rock with rough texture. The surface of a millstone has
usually a series of radial grooves in which the powdered material
collects.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Millstone girt</b></col> <fld>(Geol.)</fld>, <cd>a hard
and coarse, gritty sandstone, dividing the Carboniferous from the
Subcarboniferous strata. See <cref>Farewell rock</cref>, under
<er>Farewell</er>, <pos>a.</pos>, and <xex>Chart</xex> of
<er>Geology</er>.</cd> -- <mcol><col><b>To see into a
millstone</b></col> <it>or</it> <col><b>To see through a
millstone</b></col></mcol>, <cd>to see into or through a difficult
matter.</cd> <mark>(Colloq.)</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>millwheel</ent><br/
<hw>millwheel</hw> <pos>n.</pos> <def>a waterwheel that is used to drive
machinery in a mill.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Millwork</ent><br/
<hw>Mill"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
shafting, gearing, and other driving machinery of mills.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The business of setting up or of operating mill
machinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Millwright</ent><br/
<hw>Mill"wright`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mechanic whose
occupation is to build mills, or to set up their machinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>milometer</ent><br/
<hw>milometer</hw> <pos>n.</pos> <def>a meter that shows mileage
traversed.</def><br/
<syn><b>Syn. --</b> odometer, hodometer, mileometer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milord</ent><br/
<hw>Mi*lord"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. (also It., Sp.,
Russ.), fr. E. <ets>my lord</ets>.]</ety> <def>Lit., my lord; hence (as
used on the Continent), an English nobleman or gentleman.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Milquetoast</ent><br/
<hw>Milquetoast</hw> <pos>n.</pos> <ety>[From Caspar Milquetoast, a
character in a cartoon strip by H. T. Webster, <publ>The Timid
Soul</publ> (1935).]</ety> <def>a timid, unassertive man or boy fearful
of confrontation and easily manipulated and dominated.</def><br/
<syn><b>Syn. --</b> sissy, pantywaist, pansy, milksop.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Milreis</ent><br/
<hw>Mil"reis`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg. <ets>mil
reis</ets>, i. e., one thousand reis; <ets>mil</ets> a thousand +
<ets>reis</ets>, pl. of <ets>real</ets> a rei.]</ety> <def>A Portuguese
money of account rated in the treasury department of the United States
at one dollar and eight cents; also, a Brazilian money of account rated
at fifty-four cents and six mills (1913).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milt</ent><br/
<hw>Milt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>milte</ets>;
akin to D. <ets>milt</ets>, G. <ets>milz</ets>, OHG. <ets>milzi</ets>,
Icel. <ets>milti</ets>, Dan. <ets>milt</ets>, Sw. <ets>mj<aum/lte</ets>,
and prob. to E. <ets>malt</ets>, <ets>melt</ets>. <root/108. See
<er>Malt</er> the grain.]</ety> <fld>(Anat.)</fld> <def>The
spleen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milt</ent><br/
<hw>Milt</hw>, <pos>n.</pos> <ety>[Akin to Dan. <ets>melk</ets>, Sw.
<ets>mj<oum/lke</ets>, G. <ets>milch</ets>, and E. <ets>milk</ets>. See
<er>Milk</er>.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The spermatic
fluid of fishes.</def> <sd>(b)</sd> <def>The testes, or spermaries, of
fishes when filled with spermatozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milt</ent><br/
<hw>Milt</hw>, <pos>v. t.</pos> <def>To impregnate (the roe of a fish)
with milt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milter</ent><br/
<hw>Milt"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>milter</ets>, G. <ets>milcher</ets>, <ets>milchner</ets>. See 2d
<er>Milt</er>.]</ety> <fld>(Zool.)</fld> <def>A male fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miltonian</ent><br/
<hw>Mil*to"ni*an</hw> <pr>(?)</pr>, <pos>prop. a.</pos>
<def>Miltonic.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miltonic</ent><br/
<hw>Mil*ton"ic</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of,
pertaining to, or resembling, <persfn>Milton</persfn>, or his writings;
<as>as, <ex>Miltonic</ex> prose</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miltwaste</ent><br/
<hw>Milt"waste`</hw> <pr>(?)</pr>, <ety>[1st <ets>milt</ets> +
<ets>waste</ets>.]</ety> <fld>(Bot.)</fld> <def>A small European fern
(<spn>Asplenium Ceterach</spn>) formerly used in medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milvine</ent><br/
<hw>Mil"vine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>milvus</ets>
kite.]</ety> <fld>(Zool.)</fld> <def>Of or resembling birds of the kite
kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milvine</ent><br/
<hw>Mil"vine</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A bird related
to the kite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Milvus</ent><br/
\'d8<hw>Mil"vus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
kite.]</ety> <fld>(Zool.)</fld> <def>A genus of raptorial birds,
including the European kite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mime</ent><br/
<hw>Mime</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>mimus</ets>, Gr.
<?/, akin to <?/ to imitate, to mimic: cf. F. <ets>mime</ets>. Cf.
<er>Mimosa</er>.]</ety> <sn>1.</sn> <def>A kind of drama in which real
persons and events were generally represented in a ridiculous manner; an
ancient Greek or Roman form of farce.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>An actor in such representations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The art of representing actions, events, situations,
or stories solely by gestures and body movements, without speaking;
pantomime{3}.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>An actor who performs or specializes in mime{3}; an
actor who communicates entirely by gesture and facial expression; a
pantomime{2}; a pantomimist; a mimer.</def><br/
<syn><b>Syn. --</b> mummer, pantomimer, pantomimist.</syn><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>A mimic.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mime</ent><br/
<hw>Mime</hw>, <pos>v. i.</pos> <def>To mimic.</def> <mark>[Obs.]</mark>
-- <wordforms><wf>Mim"er</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>mimeo</ent><br/
<hw>mimeo</hw> <pos>n.</pos> <ety>[by shortening.]</ety> <def>A
mimeograph.</def><br/
<syn><b>Syn. --</b> mimeograph, mimeograph machine, Roneo.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mimeo</ent><br/
<hw>mimeo</hw> <pos>v. t.</pos> <def>to make copies of using a
mimeograph.</def><br/
<syn><b>Syn. --</b> mimeograph.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mimeograph</ent><br/
<hw>Mim"e*o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ to
imitate + <ets>-graph</ets>.]</ety> <def>A copying device that uses a
stencil through which ink is pressed; it was invented by
<persfn>Edison</persfn>.</def><br/
<syn><b>Syn. --</b> mimeo, mimeograph machine, Roneo.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>mimeograph</ent><br/
<hw>mimeograph</hw> <pos>v. t.</pos> <def>to make copies of using a
mimeograph; <as>as, She <ex>mimeographed</ex> the
syllabus</as>.</def><br/
<syn><b>Syn. --</b> mimeo.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mimer</ent><br/
<hw>mim"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A person
who performs in a mime.</def><br/
<syn><b>Syn. --</b> mime, mummer, pantomimer, pantomimist.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A mimic.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mimesis</ent><br/
\'d8<hw>Mi*me"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ imitation.]</ety> <fld>(Rhet. & Biol.)</fld> <def>Imitation;
mimicry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimetene</ent><br/
<hw>Mim"e*tene</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>See <er>Mimetite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimetical</ent><br/
<ent>Mimetic</ent><br/
<mhw>{ <hw>Mi*met"ic</hw> <pr>(?; 277)</pr>, <hw>Mi*met"ic*al</hw>
<pr>(?)</pr>, }</mhw><ety>[Gr. <?/, fr. <?/ to imitate.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Apt to imitate; given to mimicry;
imitative.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Characterized by mimicry; --
applied to animals and plants; <as>as, <ex>mimetic</ex> species;
<ex>mimetic</ex> organisms. See <er>Mimicry</er>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimetism</ent><br/
<hw>Mim"e*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Gr. <?/ to
mimic.]</ety> <fld>(Biol.)</fld> <def>Same as
<er>Mimicry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimetite</ent><br/
<hw>Mim"e*tite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ an
imitator. So called because it resembles pyromorphite.]</ety>
<fld>(Min.)</fld> <def>A mineral occurring in pale yellow or brownish
hexagonal crystals. It is an arseniate of lead.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimical</ent><br/
<ent>Mimic</ent><br/
<mhw>{ <hw>Mim"ic</hw> <pr>(?)</pr>, <hw>Mim"ic*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>mimicus</ets>, Gr. <?/, fr. <?/
mime: cf. F. <ets>mimique</ets>. See <er>Mime</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Imitative; mimetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Oft, in her absence, <qex>mimic</qex> fancy wakes<br/
To imitate her.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Man is, of all creatures, the most <qex>mimical</qex>.</q>
<rj><qau>W. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of, or formed by, imitation; imitated;
<as>as, <ex>mimic</ex> gestures</as>.</def> <ldquo/<xex>Mimic</xex>
hootings.<rdquo/ <rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Min.)</fld> <def>Imitative; characterized by
resemblance to other forms; -- applied to crystals which by twinning
resemble simple forms of a higher grade of symmetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mimic</xex> often implies something droll or
ludicrous, and is less dignified than <xex>imitative</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mimic beetle</b></col> <fld>(Zool.)</fld>, <cd>a beetle
that feigns death when disturbed, esp. the species of <gen>Hister</gen>
and allied genera.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimic</ent><br/
<hw>Mim"ic</hw>, <pos>n.</pos> <def>One who imitates or mimics,
especially one who does so for sport; a copyist; a buffoon.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimic</ent><br/
<hw>Mim"ic</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mimicked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mimicking</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To imitate or ape for sport; to ridicule by
imitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The walk, the words, the gesture, could supply,<br/
The habit <qex>mimic</qex>, and the mien belie.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>To assume a resemblance to (some
other organism of a totally different nature, or some surrounding
object), as a means of protection or advantage.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To ape; imitate; counterfeit; mock.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimically</ent><br/
<hw>Mim"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In an imitative
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimicker</ent><br/
<hw>Mim"ick*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
mimics; a mimic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>An animal which imitates
something else, in form or habits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimicry</ent><br/
<hw>Mim"ic*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or practice of one who mimics; ludicrous imitation for sport or
ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Protective resemblance; the
resemblance which certain animals and plants exhibit to other animals
and plants or to the natural objects among which they live, -- a
characteristic which serves as their chief means of protection against
enemies; imitation; mimesis; mimetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimir</ent><br/
<hw>Mimir</hw> <pos>prop. n.</pos> <fld>(Norse mythology)</fld> <def>A
giant who guarded the well of wisdom.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mimographer</ent><br/
<hw>Mi*mog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mimographus</ets>, Gr. <?/; <?/ a mime + <?/ to write: cf. F.
<ets>mimographe</ets>.]</ety> <def>A writer of mimes.</def> <rj><au>Sir
T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimosa</ent><br/
\'d8<hw>Mi*mo"sa</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ imitator. Cf. <er>Mime</er>.]</ety> <fld>(Bot.)</fld> <def>A
genus of leguminous plants, containing many species, and including the
sensitive plants (<spn>Mimosa sensitiva</spn>, and <spn>Mimosa
pudica</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <ex>mimosa</ex> is also applied in commerce to
several kinds bark imported from Australia, and used in tanning; --
called also <altname>wattle bark</altname>.</note>
<rj><au>Tomlinson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimosaceae</ent><br/
<hw>Mimosaceae</hw> <pos>prop. n.</pos> <def>A natural family of spiny
woody plants (usually shrubs or small trees) whose leaves mimic animals
in sensitivity to touch; commonly included in the family
<fam>Leguminosae</fam>.</def><br/
<syn><b>Syn. --</b> family <fam>Mimosaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mimosoideae</ent><br/
<hw>Mimosoideae</hw> <pos>prop. n.</pos> <def>An alternative name used
in some classification systems for the family
<altname>Mimosaceae</altname>.</def><br/
<syn><b>Syn. --</b> subfamily <subfam>Mimosoideae</subfam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mimotannic</ent><br/
<hw>Mi`mo*tan"nic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mimo</ets>sa + <ets>tannic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a variety of tannin or tannic acid
found in Acacia, Mimosa, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mimus</ent><br/
<hw>Mimus</hw> <pos>prop. n.</pos> <def>The type genus of the family
<fam>Mimidae</fam>, comprising certain of the mockingbirds.</def><br/
<syn><b>Syn. --</b> genus Mimus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>min.</ent><br/
<hw>min.</hw> <pos>n.</pos> <def>An abbreviation for
<abbr>minute</abbr>, a unit of time equal to 60 seconds or 1/60th of an
hour.</def><br/
<syn><b>Syn. --</b> minute, min.[abbrev.].</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Min</ent><br/
<hw>Min</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>a dialect of
Chinese.</def><br/
<syn><b>Syn. --</b> Min dialect, Fukkianese, Hokkianese, Amoy,
Taiwanese.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>an Egyptian god of procreation.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mina</ent><br/
\'d8<hw>mi"na</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Minae</plw> <pr>(#)</pr>, E. <plw>Minas</plw> <pr>(#)</pr>.</plu>
<ety>[L., fr. Gr. <?/.]</ety> <def>An ancient weight or denomination of
money, of varying value. The Attic mina was valued at a hundred
drachmas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mina</ent><br/
<hw>Mi"na</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Myna</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minable</ent><br/
<hw>Min"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
mined; <as>as, <ex>minable</ex> earth</as>.</def> <rj><au>Sir T.
North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minacious</ent><br/
<hw>Mi*na"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>minax</ets>, <ets>-acis</ets>. See <er>Menace</er>.]</ety>
<def>Threatening; menacing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minacity</ent><br/
<hw>Mi*nac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disposition to
threaten.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minaret</ent><br/
<hw>Min"a*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>minarete</ets>, Ar. <ets>man<amac/rat</ets> lamp, lantern,
lighthouse, turret, fr. <ets>n<amac/r</ets> to shine.]</ety>
<fld>(Arch.)</fld> <def>A slender, lofty tower attached to a mosque and
surrounded by one or more projecting balconies, from which the summon to
prayer is cried by the muezzin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minargent</ent><br/
<hw>Min*ar"gent</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. contr. from
alu<ets>min</ets>ium + L. <ets>argent</ets>um silver.]</ety> <def>An
alloy consisting of copper, nickel, tungsten, and aluminium; -- used by
jewelers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minatorily</ent><br/
<ent>Minatorially</ent><br/
<mhw>{ <hw>Min`a*to"ri*al*ly</hw> <pr>(?)</pr>, <hw>Min"a*to*ri*ly</hw>
<pr>(?)</pr> }</mhw>, <pos>adv.</pos> <def>In a minatory manner; with
threats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minatory</ent><br/
<hw>Min"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>minatorius</ets>, fr. <ets>minari</ets> to threaten. See
<er>Menace</er>.]</ety> <def>Threatening; menacing.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minaul</ent><br/
<hw>Mi*naul"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Manul</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mince</ent><br/
<hw>Mince</hw> <pr>(m<icr/ns)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Minced</conjf> <pr>(m<icr/nst)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Minging</conjf>
<pr>(m<icr/n"s<icr/ng)</pr>.]</vmorph> <ety>[AS. <ets>minsian</ets> to
grow less, dwindle, fr. <ets>min</ets> small; akin to G.
<ets>minder</ets> less, Goth. <ets>minniza</ets> less, <ets>mins</ets>
less, adv., L. <ets>minor</ets>, adj. (cf. <er>Minor</er>); or more
likely fr. F. <ets>mincer</ets> to mince, prob. from (assumed) LL.
<ets>minutiare</ets>. <root/101. See <er>Minish</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To cut into very small pieces; to chop fine; to
hash; <as>as, to <ex>mince</ex> meat</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To suppress or weaken the force of; to extenuate; to
palliate; to tell by degrees, instead of directly and frankly; to clip,
as words or expressions; to utter half and keep back half of; <as>as, he
doesn't <ex>mince</ex> words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I know no ways to <qex>mince</qex> it in love, but directly to say
-- <ldquo/I love you.<rdquo/</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Siren, now <qex>mince</qex> the sin,<br/
And mollify damnation with a phrase.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If, to <qex>mince</qex> his meaning, I had either omitted some
part of what he said, or taken from the strength of his expression, I
certainly had wronged him.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To affect; to make a parade of.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mince</ent><br/
<hw>Mince</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To walk with short
steps; to walk in a prim, affected manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The daughters of Zion are haughty, and walk with stretched forth
necks and wanton eyes, . . . <qex>mincing</qex> as they go.</q>
<rj><qau>Is. iii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll . . . turn two <qex>mincing</qex> steps<br/
Into a manly stride.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act or talk with affected nicety; to affect
delicacy in manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mince</ent><br/
<hw>Mince</hw>, <pos>n.</pos> <def>A short, precise step; an affected
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mince-meat</ent><br/
<hw>Mince"-meat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Minced meat; meat
chopped very fine; a mixture of boiled meat, suet, apples, etc., chopped
very fine, to which spices and raisins are added; -- used in making
mince pie.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mince pie</ent><br/
<hw>Mince" pie`</hw> <pr>(?)</pr>. <def>A pie made of
mince-meat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mincer</ent><br/
<hw>Min"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
minces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mincing</ent><br/
<hw>Min"cing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That minces;
characterized by primness or affected nicety.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mincingly</ent><br/
<hw>Min"cing*ly</hw>, <pos>adv.</pos> <def>In a mincing manner; not
fully; with affected nicety.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mind</ent><br/
<hw>Mind</hw> <pr>(m<imac/nd)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mynd</ets>, <ets>gemynd</ets>; akin to OHG. <ets>minna</ets>
memory, love, G. <ets>minne</ets> love, Dan. <ets>minde</ets> mind,
memory, remembrance, consent, vote, Sw. <ets>minne</ets> memory, Icel.
<ets>minni</ets>, Goth. <ets>gamunds</ets>, L. <ets>mens</ets>,
<ets>mentis</ets>, mind, Gr. <grk>me`nos</grk>, Skr. <ets>manas</ets>
mind, <ets>man</ets> to think. <root/104, 278. Cf. <er>Comment</er>,
<er>Man</er>, <er>Mean</er>, <pos>v.</pos>, 3d <er>Mental</er>,
<er>Mignonette</er>, <er>Minion</er>, <er>Mnemonic</er>,
<er>Money</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The intellectual or rational faculty in man; the
understanding; the intellect; the power that conceives, judges, or
reasons; also, the entire spiritual nature; the soul; -- often in
distinction from the <contr>body</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By the <qex>mind</qex> of man we understand that in him which
thinks, remembers, reasons, wills.</q> <rj><qau>Reid.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What we mean by <qex>mind</qex> is simply that which perceives,
thinks, feels, wills, and desires.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let every man be fully persuaded in his own <qex>mind</qex>.</q>
<rj><qau>Rom. xiv. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mind</qex> shall banquet, though the body pine.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state, at any given time, of the faculties of
thinking, willing, choosing, and the like; psychical activity or
state;</def> <specif>as:</specif> <sd>(a)</sd> <def>Opinion; judgment;
belief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A fool uttereth all his <qex>mind</qex>.</q> <rj><qau>Prov. xxix.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Being so hard to me that brought your <qex>mind</qex>, I fear
she'll prove as hard to you in telling her <qex>mind</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Choice; inclination; liking; intent;
will.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If it be your <qex>minds</qex>, then let none go forth.</q>
<rj><qau>2 Kings ix. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>Courage; spirit.</def>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Memory; remembrance; recollection; <as>as, to have
or keep in <ex>mind</ex>, to call to <ex>mind</ex>, to put in
<ex>mind</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To have a mind</b></col> <it>or</it> <col><b>To
have a great mind</b></col></mcol>, <cd>to be inclined or strongly
inclined in purpose; -- used with an infinitive.</cd> <ldquo/Sir Roger
de Coverly . . . told me that he <xex>had a great mind</xex> to see the
new tragedy with me.<rdquo/ <au>Addison.</au> -- <col><b>To lose one's
mind</b></col>, <cd>to become insane, or imbecile.</cd> -- <col><b>To
make up one's mind</b></col>, <cd>to come to an opinion or decision; to
determine.</cd> -- <col><b>To put in mind</b></col>, <cd>to remind.</cd>
<ldquo/Regard us simply as <xex>putting you in mind</xex> of what you
already know to be good policy.<rdquo/ <au>Jowett (Thucyd.
).</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mind</ent><br/
<hw>Mind</hw> <pr>(m<imac/nd)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Minded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Minding</conjf>.]</vmorph> <ety>[AS. <ets>myndian</ets>,
<ets>gemynd<imac/an</ets> to remember. See <er>Mind</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To fix the mind or thoughts on; to
regard with attention; to treat as of consequence; to consider; to heed;
to mark; to note.</def> <ldquo/<xex>Mind</xex> not high things, but
condescend to men of low estate.<rdquo/ <rj><au>Rom. xii.
16.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My lord, you nod: you do not <qex>mind</qex> the play.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To occupy one's self with; to employ one's self
about; to attend to; <as>as, to <ex>mind</ex> one's
business</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bidding him be a good child, and <qex>mind</qex> his book.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To obey; <as>as, to <ex>mind</ex> parents; the dog
<ex>minds</ex> his master.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To have in mind; to purpose.</def>
<rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>mind</qex> to tell him plainly what I think.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To put in mind; to remind.</def>
<mark>[Archaic]</mark> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>minded</qex> them of the mutability of all earthly
things.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I do thee wrong to <qex>mind</qex> thee of it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Never mind</b></col>, <cd>do not regard it; it is of no
consequence; no matter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To notice; mark; regard; obey. See
<er>Attend</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mind</ent><br/
<hw>Mind</hw>, <pos>v. i.</pos> <def>To give attention or heed; to obey;
<as>as, the dog <ex>minds</ex> well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mind-altering</ent><br/
<hw>mind-altering</hw> <pos>adj.</pos> <def>producing mood changes or
distorted perception; -- used mostly of psychoactive substances; <as>as,
hallucinogenic drugs are <ex>mind-altering</ex>
substances</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mind-bending</ent><br/
<hw>mind-bending</hw> <pos>adj.</pos> <def>intensely affecting the mind,
especially in producing hallucinations; -- usually of chemical
substances.</def> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> mind-blowing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mind-blowing</ent><br/
<hw>mind-blowing</hw> <pos>adj.</pos> <sn>1.</sn>
<def>mind-bending.</def> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> .</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>intensely affecting the mind or emotions;
astonishing; -- usually referring to extraordinary experiences; <as>as,
spending a week in the jungle was a <ex>mind-blowing</ex> experience; a
<ex>mind-blowing</ex> horror story</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mind-boggling</ent><br/
<hw>mind-boggling</hw> <pos>adj.</pos> <def>intellectually or
emotionally overwhelming; straining one's capacity to comprehend or
cope; <as>as, a <ex>mind-boggling</ex> display; a <ex>mind-boggling</ex>
puzzle</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minded</ent><br/
<hw>Mind"ed</hw>, <pos>a.</pos> <def>Disposed; inclined; having a
mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Joseph . . . was <qex>minded</qex> to put her away privily.</q>
<rj><qau>Matt. i. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If men were <qex>minded</qex> to live virtuously.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Minded</xex> is much used in composition; as,
high-<xex>minded</xex>, feeble-<xex>minded</xex>,
bloody-<xex>minded</xex>, sober-<xex>minded</xex>,
double-<xex>minded</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minden</ent><br/
<hw>Minden</hw> <pos>prop. n.</pos> <def>A battle in the Seven Years'
War (1759) in which the Anglo-Allied forces under duke <person>Ferdinand
of Brunswick</person> defeated the French under <person>Marshal
Contades</person>.</def><br/
<syn><b>Syn. --</b> battle of Minden.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minder</ent><br/
<hw>Mind"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
minds, tends, or watches something, as a child, a machine, or cattle;
<as>as, a <ex>minder</ex> of a loom</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One to be attended; specif., a pauper child
intrusted to the care of a private person.</def> <mark>[Eng.]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mindful</ent><br/
<hw>Mind"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bearing in mind;
regardful; attentive; heedful; observant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What is man, that thou art <qex>mindful</qex> of him?</q>
<rj><qau>Ps. viii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I promise you to be <qex>mindful</qex> of your admonitions.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mind"ful*ly</wf>, <pos>adv.</pos> --
<wf>Mind"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minding</ent><br/
<hw>Mind"ing</hw>, <pos>n.</pos> <def>Regard; mindfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mindless</ent><br/
<hw>Mind"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Not indued with mind
or intellectual powers; stupid; unthinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unmindful; inattentive; heedless;
careless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cursed Athens, <qex>mindless</qex> of thy worth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mine</ent><br/
<hw>Mine</hw> <pr>(m<emac/n)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>See <er>Mien</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mine</ent><br/
<hw>Mine</hw> <pr>(m<imac/n)</pr>, <pos>pron. & a.</pos> <ety>[OE.
<ets>min</ets>, fr. AS. <ets>m<imac/n</ets>; akin to D. <ets>mijn</ets>,
OS., OFries., & OHG. <ets>m<imac/n</ets>, G. <ets>mein</ets>, Sw. & Dan.
<ets>min</ets>, Icel. <ets>minn</ets>, Goth. <ets>meins</ets> my, mine,
<ets>meina</ets> of me, and E. <ets>me</ets>. <root/187. See
<er>Me</er>, and cf. <er>My</er>.]</ety> <def>Belonging to me; my. Used
as a pronominal to me; my. Used as a pronominal adjective in the
predicate; <as>as, <ldquo/Vengeance is <ex>mine</ex>; I will
repay.<rdquo/ <au>Rom. xii. 19</au></as>. Also, in the old style, used
attributively, instead of <xex>my</xex>, before a noun beginning with a
vowel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I kept myself from <qex>mine</qex> iniquity.</q> <rj><qau>Ps.
xviii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mine</xex> is often used absolutely, the thing
possessed being understood; as, his son is in the army, <xex>mine</xex>
in the navy.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>When a man deceives me once, says the Italian proverb, it is his
fault; when twice, it is <qex>mine</qex>.</q> <rj><qau>Bp.
Horne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This title honors me and <qex>mine</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She shall have me and <qex>mine</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mine</ent><br/
<hw>Mine</hw>, <pos>v. i.</pos> <ety>[F. <ets>miner</ets>, L.
<ets>minare</ets> to drive animals, in LL. also, to lead, conduct, dig a
mine (cf. E. <ets>lode</ets>, and <ets>lead</ets> to conduct), akin to
L. <ets>minari</ets> to threaten; cf. Sp. <ets>mina</ets> mine, conduit,
subterraneous canal, a spring or source of water, It. <ets>mina</ets>.
See <er>Menace</er>, and cf. <er>Mien</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To dig a mine or pit in the earth; to get ore,
metals, coal, or precious stones, out of the earth; to dig in the earth
for minerals; to dig a passage or cavity under anything in order to
overthrow it by explosives or otherwise.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form subterraneous tunnel or hole; to form a
burrow or lodge in the earth; <as>as, the <ex>mining</ex>
cony</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mine</ent><br/
<hw>Mine</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mining</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To dig away, or otherwise remove, the substratum or
foundation of; to lay a mine under; to sap; to undermine; hence, to ruin
or destroy by slow degrees or secret means.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>mined</qex> the walls.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Too lazy to cut down these immense trees, the spoilers . . . had
<qex>mined</qex> them, and placed a quantity of gunpowder in the
cavity.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dig into, for ore or metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lead veins have been traced . . . but they have not been
<qex>mined</qex>.</q> <rj><qau>Ure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To get, as metals, out of the earth by
digging.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The principal ore <qex>mined</qex> there is the bituminous
cinnabar.</q> <rj><qau>Ure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mine</ent><br/
<hw>Mine</hw>, <pos>n.</pos> <ety>[F., fr. LL. <ets>mina</ets>. See
<er>Mine</er>, <pos>v. i.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A subterranean cavity or passage</def>;
<specif>especially:</specif> <sd>(a)</sd> <def>A pit or excavation in
the earth, from which metallic ores, precious stones, coal, or other
mineral substances are taken by digging; -- distinguished from the pits
from which stones for architectural purposes are taken, and which are
called <xex>quarries</xex>.</def> <sd>(b)</sd> <fld>(Mil.)</fld> <def>A
cavity or tunnel made under a fortification or other work, for the
purpose of blowing up the superstructure with some explosive
agent.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 926 --></p>

<p><sn>2.</sn> <def>Any place where ore, metals, or precious stones are
got by digging or washing the soil; <as>as, a placer
<ex>mine</ex></as>.</def><-- esp. in <cref>gold mine</cref> --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <mark>(Fig.)</mark>: <def>A rich source of wealth or
other good.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>An explosive device placed
concealed in a location, on land or at sea, where an enemy vehicle or
enemy personnel may pass through, having a triggering mechanism which
detects people or vehicles, and which will explode and kill or maim
personnel or destroy or damage vehicles. A mine placed at sea (formerly
called a <altname>torpedo</altname>, see <er>torpedo</er>{2}
<sd>(a)</sd>) is also called an <ecol><b>marine mine</b></ecol> and
<ecol><b>underwater mine</b></ecol> and sometimes called a
<styp><ecol><b>floating mine</b></ecol></styp>, even though it may be
anchored to the floor of the sea and not actually float freely. A mine
placed on land (formerly called a <altname>torpedo</altname>, see
<er>torpedo</er>{3}), usually buried, is called a <ecol><b>land
mine</b></ecol>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Mine dial</b></col>, <cd>a form of magnetic compass used
by miners.</cd> -- <col><b>Mine pig</b></col>, <cd>pig iron made wholly
from ore; in distinction from <contr>cinder pig</contr>, which is made
from ore mixed with forge or mill cinder.</cd> -- <col><b>gold
mine</b></col> <sd>(a)</sd> <cd>a mine where gold is obtained.</cd>
<sd>(b)</sd> <mark>(Fig.)</mark> <cd>a rich source of wealth or other
good; same as <er>Mine</er> 3.</cd></cs> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mined</ent><br/
<hw>mined</hw> <pos>adj.</pos> <def>extracted from a source of supply as
of minerals from the earth.</def> [Narrower terms:
<stype>deep-mined</stype>; <stype>exploited</stype>;
<stype>strip-mined</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>minefield</ent><br/
<hw>minefield</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Mil.)</fld> <def>a
region in which explosive mines{4} have been placed, especially a region
on land.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>(Fig.)</mark> <def>A
situation in which a simple mistake can have disastrous consequences; a
touchy or dangerous situation requiring great caution; <as>as, the
candidate threaded his way skillfully through a <ex>minefield</ex> of
loaded questions from the audience</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>minelayer</ent><br/
<hw>minelayer</hw> <pos>n.</pos> <def>a ship equipped for laying
underwater mines.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>minelaying</ent><br/
<hw>minelaying</hw> <pos>n.</pos> <def>The act or process of laying
explosive mines in concealed places to destroy enemy personnel and
equipment.</def><br/
<syn><b>Syn. --</b> mining.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Miner</ent><br/
<hw>Min"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mineur</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One who mines; a digger for metals, etc.; one
engaged in the business of getting ore, coal, or precious stones, out of
the earth; one who digs military mines; <as>as, armies have sappers and
<ex>miners</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any of numerous
insects which, in the larval state, excavate galleries in the parenchyma
of leaves. They are mostly minute moths and dipterous flies.</def>
<sd>(b)</sd> <def>The chattering, or garrulous, honey eater of Australia
(<spn>Myzantha garrula</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Miner's elbow</b></col> <fld>(Med.)</fld>, <cd>a swelling
on the black of the elbow due to inflammation of the bursa over the
olecranon; -- so called because of frequent occurrence in miners.</cd>
-- <col><b>Miner's inch</b></col>, <cd>in hydraulic mining, the amount
of water flowing under a given pressure in a given time through a hole
one inch in diameter. It is a unit for measuring the quantity of water
supplied.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineral</ent><br/
<hw>Min"er*al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>min<eacute/ral</ets>, LL. <ets>minerale</ets>, fr.
<ets>minera</ets> mine. See <er>Mine</er>, <pos>v. i.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An inorganic species or substance occurring in
nature, having a definite chemical composition and usually a distinct
crystalline form. Rocks, except certain glassy igneous forms, are either
simple minerals or aggregates of minerals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mine.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything which is neither animal nor vegetable, as
in the most general classification of things into three kingdoms
(animal, vegetable, and mineral).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineral</ent><br/
<hw>Min"er*al</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
minerals; consisting of a mineral or of minerals; <as>as, a
<ex>mineral</ex> substance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Impregnated with minerals; <as>as, <ex>mineral</ex>
waters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mineral acids</b></col> <fld>(Chem.)</fld>, <cd>inorganic
acids, as sulphuric, nitric, phosphoric, hydrochloric, acids, etc., as
distinguished from the <contr>organic acids</contr>.</cd> --
<col><b>Mineral blue</b></col>, <cd>the name usually given to azurite,
when reduced to an impalpable powder for coloring purposes.</cd> --
<col><b>Mineral candle</b></col>, <cd>a candle made of paraffin.</cd> --
<col><b>Mineral caoutchouc</b></col>, <cd>an elastic mineral pitch, a
variety of bitumen, resembling caoutchouc in elasticity and softness.
See <er>Caoutchouc</er>, and <er>Elaterite</er>.</cd> -- <col><b>Mineral
chameleon</b></col> <fld>(Chem.)</fld> <cd>See <cref>Chameleon
mineral</cref>, under <er>Chameleon</er>.</cd> -- <col><b>Mineral
charcoal</b></col>. <cd>See under <er>Charcoal</er>.</cd> --
<col><b>Mineral cotton</b></col>. <cd>See <cref>Mineral wool</cref>
(below).</cd> -- <col><b>Mineral green</b></col>, <cd>a green carbonate
of copper; malachite.</cd> -- <col><b>Mineral kingdom</b></col>
<fld>(Nat. Sci.)</fld>, <cd>that one of the three grand divisions of
nature which embraces all inorganic objects, as distinguished from
plants or animals.</cd> -- <col><b>Mineral oil</b></col>. <cd>See
<er>Naphtha</er>, and <er>Petroleum</er>.</cd> -- <col><b>Mineral
paint</b></col>, <cd>a pigment made chiefly of some natural mineral
substance, as red or yellow iron ocher.</cd> -- <col><b>Mineral
patch</b></col>. <cd>See <er>Bitumen</er>, and <er>Asphalt</er>.</cd> --
<col><b>Mineral right</b></col>, <cd>the right of taking minerals from
land.</cd> -- <col><b>Mineral salt</b></col> <fld>(Chem.)</fld>, <cd>a
salt of a mineral acid.</cd> -- <col><b>Mineral tallow</b></col>, <cd>a
familiar name for <altname>hatchettite</altname>, from its fatty or
spermaceti-like appearance.</cd> -- <col><b>Mineral water</b></col>.
<cd>See under <er>Water</er>.</cd> -- <col><b>Mineral wax</b></col>.
<cd>See <er>Ozocerite</er>.</cd> -- <col><b>Mineral wool</b></col>,
<cd>a fibrous wool-like material, made by blowing a powerful jet of air
or steam through melted slag. It is a poor conductor of
heat.</cd></cs><-- = glass wool? Also used in filters and sound
insulation. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralist</ent><br/
<hw>Min"er*al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>min<eacute/raliste</ets>.]</ety> <def>One versed in minerals;
mineralogist.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralization</ent><br/
<hw>Min`er*al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>min<eacute/ralisation</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The process of mineralizing, or forming a mineral by
combination of a metal with another element; also, the process of
converting into a mineral, as a bone or a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of impregnating with a mineral, as
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>The conversion of a cell wall into
a material of a stony nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralize</ent><br/
<hw>Min"er*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Mineralized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mineralizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf.
F. <ets>min<eacute/raliser</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To transform into a mineral.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In these caverns the bones are not <qex>mineralized</qex>.</q>
<rj><qau>Buckland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To impregnate with a mineral; <as>as,
<ex>mineralized</ex> water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To charge or impregnate with ore.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mineralize</ent><br/
<hw>Min"er*al*ize</hw>, <pos>v. i.</pos> <def>To go on an excursion for
observing and collecting minerals; to mineralogize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mineralized</ent><br/
<hw>mineralized</hw> <pos>adj.</pos> <sn>1.</sn> <def>containing or
impregnated with minerals; <as>as, <ex>mineralized</ex> water; red
stains that signify <ex>mineralized</ex> land</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>converted into a mineral.</def><br/
<syn><b>Syn. --</b> petrified.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mineralizer</ent><br/
<hw>Min"er*al*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An element
which is combined with a metal, thus forming an ore. <as>Thus, in
galena, or lead ore, sulphur is a <ex>mineralizer</ex>; in hematite,
oxygen is a <ex>mineralizer</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralogical</ent><br/
<hw>Min`er*al*og"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>min<eacute/ralogique</ets>. See <er>Mineralogy</er>.]</ety> <def>Of
or pertaining to mineralogy; <as>as, a <ex>mineralogical</ex>
table</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralogically</ent><br/
<hw>Min`er*al*og"ic*al*ly</hw>, <pos>adv.</pos> <def>According to the
principles of, or with reference to, mineralogy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralogist</ent><br/
<hw>Min`er*al"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>min<eacute/ralogiste</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One versed in mineralogy; one devoted to the study
of minerals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A carrier shell
(<spn>Phorus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralogize</ent><br/
<hw>Min`er*al"o*gize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To study
mineralogy by collecting and examining minerals.</def> <rj><au>Miss
Edgeworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mineralogy</ent><br/
<hw>Min`er*al"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mineralogies</plw> <pr>(#)</pr>.</plu> <ety>[<ets>Mineral</ets> +
<ets>-logy</ets>: cf. F. <ets>min<eacute/ralogie</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The science which treats of minerals, and teaches
how to describe, distinguish, and classify them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A treatise or book on this science.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- minerology, minerological = misspelling for mineralogy,
mineralogical --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minerva</ent><br/
<hw>Mi*ner"va</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Rom. Myth.)</fld> <def>The goddess of wisdom, of war, of the arts
and sciences, of poetry, and of spinning and weaving; -- identified with
the Grecian <altname>Pallas Athene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>minesweeper</ent><br/
<hw>minesweeper</hw> <pos>n.</pos> <def>A boat designed for the purpose
of detecting and disposing of marine mines.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>minesweeping</ent><br/
<hw>minesweeping</hw> <pos>n.</pos> <sn>1.</sn> <def>the activity of
detecting and disposing of marine mines.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minette</ent><br/
<hw>Mi*nette"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The smallest of
regular sizes of portrait photographs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minever</ent><br/
<hw>Min"e*ver</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Miniver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minge</ent><br/
<hw>Minge</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>myngian</ets>; akin to E. <ets>mind</ets>.]</ety> <def>To mingle;
to mix.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minge</ent><br/
<hw>Minge</hw>, <pos>n.</pos> <ety>[Prob. corrupt. fr.
<ets>midge</ets>.]</ety> <fld>(Zool.)</fld> <def>A small biting fly; a
midge.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>minginess</ent><br/
<hw>minginess</hw> <pos>n.</pos> <def>an extreme stinginess.</def><br/
<syn><b>Syn. --</b> meanness, niggardliness, niggardness, parsimony,
parsimoniousness, tightfistedness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mingle</ent><br/
<hw>Min"gle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mingled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mingling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From OE.
<ets>mengen</ets>, AS. <ets>mengan</ets>; akin to D. & G.
<ets>mengen</ets>, Icel. <ets>menga</ets>, also to E. <ets>among</ets>,
and possibly to <ets>mix</ets>. Cf. <er>Among</er>,
<er>Mongrel</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To mix; intermix; to combine or join, as an
individual or part, with other parts, but commonly so as to be
distinguishable in the product; to confuse; to confound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was . . . fire <qex>mingled</qex> with the hail.</q>
<rj><qau>Ex. ix. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To associate or unite in society or by ties of
relationship; to cause or allow to intermarry; to intermarry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The holy seed have <qex>mingled</qex> themselves with the people
of those lands.</q> <rj><qau>Ezra ix. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of purity by mixture; to
contaminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>mingled</qex>, imperfect virtue.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To put together; to join.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make or prepare by mixing the ingredients
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] proceeded to <qex>mingle</qex> another draught.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mingle</ent><br/
<hw>Min"gle</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become mixed or
blended.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To associate (with certain people); <as>as, he's too
highfalutin to <ex>mingle</ex> with working stiffs</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To move (among other people); -- of people; <as>as,
the president left his car to <ex>mingle</ex> with the crowd; a host at
a a party should <ex>mingle</ex> with his guests</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mingle</ent><br/
<hw>Min"gle</hw>, <pos>n.</pos> <def>A mixture.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mingleable</ent><br/
<hw>Min"gle*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That can be
mingled.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mingledly</ent><br/
<hw>Min"gled*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Confusedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mingle-mangle</ent><br/
<hw>Min"gle-man`gle</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<ety>[Reduplicated fr. <ets>mingle</ets>.]</ety> <def>To mix in a
disorderly way; to make a mess of.</def> <mark>[Obs.]</mark>
<rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mingle-mangle</ent><br/
<hw>Min"gle-man`gle</hw>, <pos>n.</pos> <def>A hotchpotch.</def>
<mark>[Obs.]</mark> <rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minglement</ent><br/
<hw>Min"gle*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
mingling, or the state of being mixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mingler</ent><br/
<hw>Min"gler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mingles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minglingly</ent><br/
<hw>Min"gling*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mingling
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minaceous</ent><br/
<hw>Min`*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of the color of
minium or red lead; miniate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniard</ent><br/
<hw>Min"iard</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Migniard.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniardize</ent><br/
<hw>Min"iard*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
delicate or dainty.</def> <mark>[Obs.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniate</ent><br/
<hw>Min"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Miniated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Miniating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>miniatus</ets>, p. p. of <ets>miniare</ets>. See
<er>Minium</er>.]</ety> <def>To paint or tinge with red lead or
vermilion; also, to decorate with letters, or the like, painted red, as
the page of a manuscript.</def> <rj><au>T. Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniate</ent><br/
<hw>Min"i*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the color of red lead or vermilion; painted with vermilion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniature</ent><br/
<hw>Min"i*a*ture</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[It.
<ets>miniatura</ets>, fr. L. <ets>miniare</ets>. See <er>Miniate</er>,
<pos>v.</pos>,<er>Minium</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Originally, a painting in colors such as those in
mediaeval manuscripts; in modern times, any very small painting,
especially a portrait.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Greatly diminished size or form; reduced
scale.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lettering in red; rubric distinction.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A particular feature or trait.</def>
<mark>[Obs.]</mark> <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniature</ent><br/
<hw>Min"i*a*ture</hw>, <pos>a.</pos> <def>Being on a small scale; much
reduced from the reality; <as>as, a <ex>miniature</ex>
copy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniature</ent><br/
<hw>Min"i*a*ture</hw>, <pos>v. t.</pos> <def>To represent or depict in a
small compass, or on a small scale.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>miniaturisation</ent><br/
<hw>miniaturisation</hw> <pos>n.</pos> <def>miniaturization.</def>
<mark>[Chiefly Brit.]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>miniaturise</ent><br/
<hw>miniaturise</hw> <pos>v. t.</pos> <def>miniaturize.</def>
<mark>[Chiefly Brit.]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Miniaturist</ent><br/
<hw>Min"i*a*tur`ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A painter of
miniatures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>miniaturization</ent><br/
<hw>miniaturization</hw> <pos>n.</pos> <def>The act or process of making
on a greatly reduced scale.</def><br/
<syn><b>Syn. --</b> miniaturisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>miniaturize</ent><br/
<hw>miniaturize</hw> <pos>v. t.</pos> <def>To design or construct on a
smaller scale.</def><br/
<syn><b>Syn. --</b> miniaturise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minibus</ent><br/
<hw>Min"i*bus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>minor</ets>
less + <ets>-bus</ets>, as in <ets>omnibus</ets>.]</ety> <sn>1.</sn>
<def>A kind of light passenger vehicle, carrying four persons.</def>
<mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A type of bus (omnibus) similar in general
appearnace to a standard-sized bus, but smaller and having a smaller
passenger capacity, typically about 15 persons. It is usually used for
transportation over relatively short distances.</def><br/
[<source>PJC</source>]</p>

<p><ent>minicomputer</ent><br/
<hw>minicomputer</hw> <pos>n.</pos> <fld>(Computers)</fld> <def>a
mid-sized digital computer; at any given point in the development of
computer technology, a <ex>minicomputer</ex> will be faster and have
greater capacity than a <contr>microcomputer</contr>, but will be slower
and have less capacity than a <contr>mainframe
computer</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minie ball</ent><br/
<hw>Min"ie ball`</hw> <pr>(?)</pr>. <ety>[From the inventor, Captain
<ets>Mini<eacute/</ets>, of France.]</ety> <def>A conical rifle bullet,
with a cavity in its base plugged with a piece of iron, which, by the
explosion of the charge, is driven farther in, expanding the sides to
fit closely the grooves of the barrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minie rifle</ent><br/
<hw>Min"ie ri"fle</hw> <pr>(?)</pr>. <def>A rifle adapted to minie
balls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minify</ent><br/
<hw>Min"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Minified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Minifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>minor</ets> less + <ets>-fly</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To make small, or smaller; to diminish the apparent
dimensions of; to lessen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To degrade by speech or action.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minikin</ent><br/
<hw>Min"i*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OD.
<ets>minneken</ets> a darling, dim. of <ets>minne</ets> love; akin to G.
<ets>minne</ets>, and to E. <ets>mind</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A little darling; a favorite; a minion.</def>
<mark>[Obs.]</mark> <rj><au>Florio.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little pin.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minikin</ent><br/
<hw>Min"i*kin</hw>, <pos>a.</pos> <def>Small; diminutive.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minim</ent><br/
<hw>Min"im</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>minime</ets>,
L. <ets>minimus</ets> the least, smallest, a superl. of
<ets>minor</ets>: cf. It. <ets>minima</ets> a note in music. See
<er>Minor</er>, and cf. <ets>Minimum</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Anything very minute; <as>as, the <ex>minims</ex> of
existence</as>; -- applied to animalcula; and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The smallest liquid measure, equal to about one
drop; the sixtieth part of a fluid drachm, equal to one
four-hundred-eightieth of a fluid ounce, or 0.06161 milliliter (U. S.
measure) or 0.05919 milliliters (British measure).</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A small fish; a minnow.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A little man or being; a dwarf.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Eccl. Hist.)</fld> <def>One of an austere order of
mendicant hermits or friars founded in the 15th century by <person>St.
Francis of Paola</person>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mus.)</fld> <def>A time note, formerly the shortest
in use; a half note, equal to half a semibreve, or two quarter notes or
crotchets.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A short poetical encomium.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minim</ent><br/
<hw>Min"im</hw>, <pos>a.</pos> <def>Minute.</def>
<ldquo/<xex>Minim</xex> forms.<rdquo/ <rj><au>J. R. Drake.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minimal</ent><br/
<hw>Min"i*mal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining to,
or having a character of, a minim or minimum; least; smallest; <as>as, a
<ex>minimal</ex> amount or value</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Miniment</ent><br/
<hw>Min"i*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. corrupt. of
<ets>moniment</ets>.]</ety> <def>A trifle; a trinket; a token.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>minimisation</ent><br/
<hw>minimisation</hw> <pos>n.</pos> <def>minimization.</def>
<mark>[Chiefly Brit.]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minimization</ent><br/
<hw>Min`i*mi*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of minimizing.</def> <rj><au>Bentham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>minimize</ent><br/
<hw>min"i*mize</hw> <pr>(m<icr/n"<icr/*m<imac/z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>minimized</conjf>
<pr>(m<icr/n"<icr/*m<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>minimizing</conjf>
<pr>(m<icr/n"<icr/*m<imac/*z<icr/ng)</pr>.]</vmorph> <sn>1.</sn> <def>To
reduce to the smallest part or proportion possible; to reduce to a
minimum.</def> <rj><au>Bentham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To represent, to oneself or others, as of no
importance or minimal importance or effect; to belittle or
disarage.</def><br/
[<source>PJC</source>]</p>

<p><ent>minimized</ent><br/
<hw>minimized</hw> <pos>adj.</pos> <def>Reduced to the smallest possible
size or amount or degree.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minimum</ent><br/
<hw>Min"i*mum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Minima</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. <ets>minimus</ets>.
See <er>Minim</er>.]</ety> <def>The least quantity assignable,
admissible, or possible, in a given case; hence, a thing of small
consequence; -- opposed to <ant>maximum</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Minimum thermometer</b></col>, <cd>a thermometer for
recording the lowest temperature since its last
adjustment.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minimus</ent><br/
\'d8<hw>Min"i*mus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Minimi</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Minim</er>.]</ety> <sn>1.</sn> <def>A being of the smallest
size.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The little finger; the fifth
digit, or that corresponding to it, in either the manus or
pes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>de minimis</b></col> <it>or</it> <col><b>de
minimus</b></col></mcol> <pos>a.</pos><cd>of trifling consequence or
importance; too insignificant to be worthy of concern; -- a reference to
the phrase <cref>de minimis non curat lex</cref>.</cd> -- <col><b>de
minimis non curat lex</b></col> <ety>[Latin]</ety> <cd>The law does not
concern itself with trifles; -- a principle of law, that even if a
technical violation of a law appears to exist according to the letter of
the law, if the effect is too small to be of consequence, the violation
of the law will not be considered as a sufficient cause of action,
whether in civil or criminal proceedings.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Mining</ent><br/
<hw>Min"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Mine</er>,
<pos>v. i.</pos>]</ety> <def>The act or business of making mines or of
working them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mining</ent><br/
<hw>Min"ing</hw>, <pos>a.</pos> <def>Of or pertaining to mines; <as>as,
<ex>mining</ex> engineer; <ex>mining</ex> machinery; a <ex>mining</ex>
region.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mining engineering</b></col>. <cd>See the Note under
<er>Engineering</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minion</ent><br/
<hw>Min"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Minimum.</def>
<mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minion</ent><br/
<hw>Min"ion</hw>, <pos>n.</pos> <ety>[F. <ets>mignon</ets>, fr. OHG.
<ets>minni</ets> love, G. <ets>minne</ets>; akin to E. <ets>mind</ets>.
See <er>Mind</er>, and cf. <er>Mignonette</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A loved one; one highly esteemed and favored; -- in
a good sense.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God's disciple and his dearest <qex>minion</qex>.</q>
<rj><qau>Sylvester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Is this the Athenian <qex>minion</qex> whom the world<br/
Voiced so regardfully?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An obsequious or servile dependent or agent of
another; a fawning favorite.</def> <rj><au>Sir J. Davies.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Go, rate thy <qex>minions</qex>, proud, insulting boy!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Print.)</fld> <def>A small kind of type, in size
between brevier and nonpareil.</def><br/
[<source>1913 Webster</source>]</p>

<p><hand/ <miniontype>This line is printed in <it>minion</it>
type.</miniontype><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An ancient form of ordnance, the caliber of which
was about three inches.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minion</ent><br/
<hw>Min"ion</hw>, <pos>a.</pos> <ety>[See 2d <er>Minion</er>.]</ety>
<def>Fine; trim; dainty.</def> <mark>[Obs.]</mark> <ldquo/Their . . .
<xex>minion</xex> dancing.<rdquo/ <rj><au>Fryth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minionette</ent><br/
<hw>Min`ion*ette"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Small;
delicate.</def> <mark>[Obs.]</mark> <ldquo/His <xex>minionette</xex>
face.<rdquo/ <rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minionette</ent><br/
<hw>Min"ion*ette</hw>, <pos>n.</pos> <fld>(Print.)</fld> <def>A size of
type between nonpareil and minion; -- used in ornamental borders,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minioning</ent><br/
<hw>Min"ion*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Kind
treatment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minionize</ent><br/
<hw>Min"ion*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
flavor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minionly</ent><br/
<ent>Minionlike</ent><br/
<mhw>{ <hw>Min"ion*like`</hw> <pr>(?)</pr>, <hw>Min"ion*ly</hw>, }</mhw>
<pos>a. & adv.</pos> <def>Like a minion; daintily.</def>
<rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minionship</ent><br/
<hw>Min"ion*ship</hw>, <pos>n.</pos> <def>State of being a minion.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minious</ent><br/
<hw>Min"ious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>minium</ets>
red lead.]</ety> <def>Of the color of red or vermilion.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minish</ent><br/
<hw>Min"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>menusen</ets>, F. <ets>menuiser</ets> to make small, cut small, fr.
(assumed) LL. <ets>minutiare</ets>, for <ets>minutare</ets>, fr. L.
<ets>minutus</ets> small. See <er>Minute</er>, <pos>a.</pos>, and cf.
<er>Diminish</er>, <er>Minge</er>.]</ety> <def>To diminish; to
lessen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The living of poor men thereby <qex>minished</qex>.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minishment</ent><br/
<hw>Min"ish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
diminishing, or the state of being diminished; diminution.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minister</ent><br/
<hw>Min"is*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ministre</ets>, F. <ets>ministre</ets>, fr. L. <ets>minister</ets>,
orig. a double comparative from the root of <ets>minor</ets> less, and
hence meaning, an inferior, a servant. See 1st <er>Minor</er>, and cf.
<er>Master</er>, <er>Minstrel</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A servant; a subordinate; an officer or assistant of
inferior rank; hence, an agent, an instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Moses rose up, and his <qex>minister</qex> Joshua.</q>
<rj><qau>Ex. xxiv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I chose<br/
Camillo for the <qex>minister</qex>, to poison<br/
My friend Polixenes.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An officer of justice.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I cry out the on the <qex>ministres</qex>, quod he,<br/
That shoulde keep and rule this cit<eacute/.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One to whom the sovereign or executive head of a
government intrusts the management of affairs of state, or some
department of such affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Ministers</qex> to kings, whose eyes, ears, and hands they
are, must be answerable to God and man.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A representative of a government, sent to the court,
or seat of government, of a foreign nation to transact diplomatic
business.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Ambassadors are classed (in the diplomatic sense) in the
first rank of public ministers, ministers plenipotentiary in the second.
<ldquo/The United States diplomatic service employs two classes of
ministers, -- ministers plenipotentiary and ministers
resident.<rdquo/</note> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One who serves at the altar; one who performs
sacerdotal duties; the pastor of a church duly authorized or licensed to
preach the gospel and administer the sacraments.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Delegate; official; ambassador; clergyman;
parson; priest.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minister</ent><br/
<hw>Min"is*ter</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ministered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ministering</conjf>.]</vmorph> <ety>[OE. <ets>ministren</ets>,
OF. <ets>ministrer</ets>, fr. L. <ets>ministrare</ets>. See
<er>Minister</er>, <pos>n.</pos>]</ety> <def>To furnish or apply; to
afford; to supply; to administer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that <qex>ministereth</qex> seed to the sower.</q> <rj><qau>2
Cor. ix. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>minister</qex> to God reason to suspect us.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minister</ent><br/
<hw>Min"is*ter</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To act as a
servant, attendant, or agent; to attend and serve; to perform service in
any office, sacred or secular.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Son of man came not to be <qex>ministered</qex> unto, but to
<qex>minister</qex>.</q> <rj><qau>Matt. xx. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To supply or to things needful; esp., to supply
consolation or remedies; <as>as, to <ex>minister</ex> to the
sick</as>.</def> <rj><au>Matt. xxv. 44.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Canst thou not <qex>minister</qex> to a mind diseased?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministerial</ent><br/
<hw>Min`is*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ministerialis</ets>: cf. F. <ets>minist<eacute/riel</ets>. See
<er>Minister</er>, and cf. <er>Minstrel</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of or pertaining to ministry or service; serving;
attendant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Enlightening spirits and <qex>ministerial</qex> flames.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the office of a minister or to
the ministry as a body, whether civil or sacerdotal.</def>
<ldquo/<xex>Ministerial</xex> offices.<rdquo/ <au>Bacon.</au> <ldquo/A
<xex>ministerial</xex> measure.<rdquo/ <au>Junius.</au>
<ldquo/<xex>Ministerial</xex> garments.<rdquo/
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tending to advance or promote; contributive.</def>
<ldquo/<xex>Ministerial</xex> to intellectual culture.<rdquo/ <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The ministerial benches</b></col>, <cd>the benches in the
House of Commons occupied by members of the cabinet and their
supporters; -- also, the persons occupying them.</cd> <ldquo/Very solid
and very brilliant talents distinguish <xex>the ministerial
benches</xex>.<rdquo/ <rj><au>Burke.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Official; priestly; sacerdotal;
ecclesiastical.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministerialist</ent><br/
<hw>Min`is*te"ri*al*ist</hw>, <pos>n.</pos> <def>A supporter of the
ministers, or the party in power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministerially</ent><br/
<hw>Min`is*te"ri*al*ly</hw>, <pos>adv.</pos> <def>In a ministerial
manner; in the character or capacity of a minister.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministery</ent><br/
<hw>Min"is*ter*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ministry</er>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministracy</ent><br/
<hw>Min"is*tra*cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Ministration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministral</ent><br/
<hw>Min"is*tral</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ministerial.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 927 --></p>

<p><ent>Ministrant</ent><br/
<hw>Min"is*trant</hw> <pr>(m<icr/n"<icr/s*tr<ait/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>ministrans</ets>, <ets>-antis</ets>, of
<ets>ministrare</ets> to minister.]</ety> <def>Performing service as a
minister; attendant on service; acting under command; subordinate.</def>
<ldquo/Princedoms and dominations <xex>ministrant</xex>.<rdquo/
<au>Milton.</au> -- <def2><pos>n.</pos> <def>One who
ministers.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministration</ent><br/
<hw>Min`is*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ministratio</ets>, fr. <ets>ministrare</ets>.]</ety> <def>The act
of ministering; service; ministry.</def> <ldquo/The days of his
<xex>ministration</xex>.<rdquo/ <rj><au>Luke i. 23.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministrative</ent><br/
<hw>Min"is*tra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving to
aid; ministering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministress</ent><br/
<hw>Min"is*tress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>ministrix</ets>.]</ety> <def>A woman who ministers.</def>
<rj><au>Akenside.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministry</ent><br/
<hw>Min"is*try</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
Ministries <pr>(#)</pr>.</plu> <ety>[L. <ets>ministerium</ets>. See
<er>Minister</er>, <pos>n.</pos>, and cf. <er>Mystery</er> a
trade.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of ministering; ministration; service.</def>
<ldquo/With tender <xex>ministry</xex>.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Agency;
instrumentality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ordinary <qex>ministry</qex> of second causes.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The wicked <qex>ministry</qex> of arms.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The office, duties, or functions of a minister,
servant, or agent; ecclesiastical, executive, or ambassadorial function
or profession.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The body of ministers of state; also, the clergy, as
a body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Administration; rule; term in power; <as>as, the
<ex>ministry</ex> of Pitt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ministryship</ent><br/
<hw>Min"is*try*ship</hw>, <pos>n.</pos> <def>The office of a
minister.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>minium</ent><br/
<hw>min"i*um</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>minium</ets>, an Iberian word, the Romans getting all their
cinnabar from Spain; cf. Basque <ets>armine<aacute/</ets>.]</ety>
<fld>(Chem.)</fld> <def>A heavy, brilliant red pigment, consisting of an
oxide of lead, <chform>Pb3O4</chform>, obtained by exposing lead or
massicot to a gentle and continued heat in the air. It is used as a
cement, as a paint, and in the manufacture of flint glass. Called also
<altname>red lead</altname>, <altname>lead tetroxide</altname>,
<altname>lead orthoplumbate</altname>, <altname>mineral
orange</altname>, <altname>mineral red</altname>, <altname>Paris
red</altname>, <altname>Saturn red</altname>, and less definitively,
<altname>lead oxide</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miniver</ent><br/
<hw>Min"i*ver</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Meniver</er>.]</ety> <def>A fur esteemed in the Middle Ages as a
part of costume. It is uncertain whether it was the fur of one animal
only or of different animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minivet</ent><br/
<hw>Min"i*vet</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
singing bird of India of the family <fam>Campephagidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mink</ent><br/
<hw>Mink</hw> <pr>(m<icr/<nsm/k)</pr>, <pos>n.</pos> <ety>[Cf. 2d
<er>Minx</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A carnivorous
mammal of the genus <gen>Mustela</gen> (foremrly <gen>Putorius</gen>),
allied to the weasel. The European mink is <spn>Mustela lutreola</spn>.
The common American mink (<spn>Mustela vison</spn>) varies from
yellowish brown to black. Its fur is highly valued. Called also
<altname>minx</altname>, <altname>nurik</altname>, and
<altname>vison</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The fur of the mink{1}. Together with sable, it is
one of the most expensive furs not taken from endangerd species. When
the fur is taken from animals grown on a farm, it called <stype>ranch
mink</stype>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Minnesinger</ent><br/
<hw>Min"ne*sing`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., fr.
<ets>minne</ets> love + <ets>singen</ets> to sing.]</ety> <def>A
love-singer; specifically, one of a class of German poets and musicians
who flourished from about the middle of the twelfth to the middle of the
fourteenth century. They were chiefly of noble birth, and made love and
beauty the subjects of their verses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minnesotan</ent><br/
<hw>Minnesotan</hw> <pos>prop. n.</pos> <def>A resident of
Minnesota.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>minniebush</ent><br/
<hw>minniebush</hw> <pos>n.</pos> <def>A low shrub (<spn>Menziesia
pilosa</spn>) of the eastern U. S. with downy twigs.</def><br/
<syn><b>Syn. --</b> minnie bush, <spn>Menziesia pilosa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minnow</ent><br/
<hw>Min"now</hw>, <pos>n.</pos> <ety>[OE. <ets>menow</ets>, cf. AS.
<ets>myne</ets>; also OE. <ets>menuse</ets>, OF. <ets>menuise</ets>
small fish; akin to E. <ets>minish</ets>, <ets>minute</ets>.]</ety>
<altsp>[Written also <asp>minow</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Zool.)</fld> <def>A small European fresh-water
cyprinoid fish (<spn>Phoxinus laevis</spn>, formerly <spn>Leuciscus
phoxinus</spn>); sometimes applied also to the young of larger kinds; --
called also <altname>minim</altname> and <altname>minny</altname>. The
name is also applied to several allied American species, of the genera
<gen>Phoxinus</gen>, <gen>Notropis</gen>, or <gen>Minnilus</gen>, and
<gen>Rhinichthys</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any of numerous small American
cyprinodont fishes of the genus <gen>Fundulus</gen>, and related genera.
They live both in fresh and in salt water. Called also
<altname>killifish</altname>, <altname>minny</altname>, and
<altname>mummichog</altname>.</def><-- see <er>mummichog</er> --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minny</ent><br/
<hw>Min"ny</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
minnow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mino bird</ent><br/
<hw>Mi"no bird"</hw> <pr>(m<imac/"n<osl/ b<etil/rd)</pr>. <ety>[Hind.
<ets>main<amac/</ets>.]</ety> <fld>(Zool.)</fld> <def>An Asiatic bird
(<spn>Gracula musica</spn>), allied to the starlings. It is black, with
a white spot on the wings, and a pair of flat yellow wattles on the
head. It is often tamed and taught to pronounce words. It is one of the
birds called <isa>mynah bird</isa>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>minor</ent><br/
<hw>mi"nor</hw> <pr>(m<imac/"n<etil/r)</pr>, <pos>a.</pos> <ety>[L., a
comparative with no positive; akin to AS. <ets>min</ets> small, G.
<ets>minder</ets> less, OHG. <ets>minniro</ets>, a., <ets>min</ets>,
adv., Icel. <ets>minni</ets>, a., <ets>minnr</ets>, adv., Goth.
<ets>minniza</ets>, a., <ets>mins</ets>, adv., Ir. & Gael.
<ets>min</ets> small, tender, L. <ets>minuere</ets> to lessen, Gr.
<grk>miny`qein</grk>, Skr. <ets>mi</ets> to damage. Cf. <er>Minish</er>,
<er>Minister</er>, <er>Minus</er>, <er>Minute</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Inferior in bulk, degree, importance, etc.; less;
smaller; of little account; <as>as, <ex>minor</ex> divisions of a
body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Less by a semitone in interval or
difference of pitch; <as>as, a <ex>minor</ex> third</as>.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Asia Minor</b></col> <fld>(Geog.)</fld>, <cd>the Lesser
Asia; that part of Asia which lies between the Euxine, or Black Sea, on
the north, and the Mediterranean on the south.</cd> -- <col><b>Minor
mode</b></col> <fld>(Mus.)</fld>, <cd>that mode, or scale, in which the
third and sixth are minor, -- much used for mournful and solemn
subjects.</cd> -- <col><b>Minor orders</b></col> <fld>(Eccl.)</fld>,
<cd>the rank of persons employed in ecclesiastical offices who are not
in holy orders, as doorkeepers, acolytes, etc.</cd> -- <col><b>Minor
scale</b></col> <fld>(Mus.)</fld> <cd>The form of the minor scale is
various. The strictly correct form has the third and sixth minor, with a
semitone between the seventh and eighth, which involves an augmented
second interval, or three semitones, between the sixth and seventh, as,
<supr>6/F</supr>, <supr>7/G<sharp/</supr>, <supr>8/A</supr>. But, for
melodic purposes, both the sixth and the seventh are sometimes made
major in the ascending, and minor in the descending, scale.</cd><br/
[<source>1913 Webster</source>]</p>

<p><cd>See <er>Major</er>.</cd> -- <col><b>Minor term of a
syllogism</b></col> <fld>(Logic)</fld>, <cd>the subject of the
conclusion.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Minor</ent><br/
<hw>Mi"nor</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A person of
either sex who has not attained the age at which full civil rights are
accorded; an infant; in England and the United States, one under
twenty-one years of age.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In hereditary monarchies, the minority of a sovereign
ends at an earlier age than of a subject. The minority of a sovereign of
Great Britain ends upon the completion of the eighteenth year of his
age.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic)</fld> <def>The minor term, that is, the
subject of the conclusion; also, the minor premise, that is, that
premise which contains the minor term; in hypothetical syllogisms, the
categorical premise. It is the second proposition of a regular
syllogism, as in the following: Every act of injustice partakes of
meanness; to take money from another by gaming is an act of injustice;
therefore, the taking of money from another by gaming partakes of
meanness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A Minorite; a Franciscan friar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minorat</ent><br/
\'d8<hw>Mi`no*rat"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G. Cf.
<er>Minor</er>, <pos>a.</pos>]</ety> <fld>(Law)</fld> <def>A custom or
right, analogous to borough-English in England, formerly existing in
various parts of Europe, and surviving in parts of Germany and Austria,
by which certain entailed estates, as a homestead and adjacent land,
descend to the youngest male heir.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Minorate</ent><br/
<hw>Mi"nor*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>minoratus</ets>; p. p. of <ets>minorare</ets> to diminish, fr.
<ets>minor</ets>, a. See 1st <er>Minor</er>.]</ety> <def>To
diminish.</def> <mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minoration</ent><br/
<hw>Mi`nor*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>minoratio</ets>: cf. F. <ets>minoration</ets>.]</ety> <def>A
diminution.</def> <mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minoress</ent><br/
<hw>Mi"nor*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<cref>Franciscan Nuns</cref>, under <er>Franciscan</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minorite</ent><br/
<hw>Mi"nor*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>minor</ets> less. Cf. 2d <er>Minor</er>, 3.]</ety> <def>A
Franciscan friar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minority</ent><br/
<hw>Mi*nor"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Minorities</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>minorit<eacute/</ets>. See <er>Minor</er>, <pos>a. &
n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The state of being a minor, or under age.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>State of being less or small.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The smaller number; -- opposed to
<ant>majority</ant>; <as>as, the <ex>minority</ex> must be ruled by the
majority</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Those members of a legislature that belong to the
political party which is in the minority in that institution; <as>as,
the bill will pass even if the <ex>minority</ex> are strongly
opposed</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>minor league</ent><br/
<hw>minor league</hw> <pos>n.</pos> <fld>Sport)</fld> <def>A league of
professional sports teams less proficient than a <contr>major
leagues</contr>. Players in the minor leagues generally are paid less
than those in the major leagues, and their games attract less
atention.</def> <note>Certain minor league sports teams are often owned
by those owning a major league club, and the minor league clubs are used
to provide practise and opportunity for evaluation for candidates who
wish to play in the major leagues.</note><br/
<syn><b>Syn. --</b> minor league.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>minor-league</ent><br/
<hw>minor-league</hw> <pos>a.</pos> <def>Of or pertaining to a minor
league.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Of mediocre talent or poor accomplishment;
unimportant; -- of people; <as>as, a <ex>minor-league</ex>
physicist</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>minors</ent><br/
<hw>minors</hw> <pos>n.</pos> <def>The <er>minor leagues</er>, those
leagues of professional sports teams less proficient than the
<contr>majors</contr>, or <contr>major leagues</contr>.</def><br/
<syn><b>Syn. --</b> minor league.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minos</ent><br/
<hw>Mi"nos</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[Gr. <?/.]</ety>
<fld>(Class. Myth.)</fld> <def>A king and lawgiver of Crete, fabled to
be the son of <persfn>Jupiter</persfn> and <persfn>Europa</persfn>.
After death he was made a judge in the Lower Regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minotaur</ent><br/
<hw>Min"o*taur</hw> <pr>(m<icr/n"<osl/*t<add/r)</pr>, <pos>n.</pos>
<ety>[L. <ets>Minotaurus</ets>, Gr. <grk>Minw`tayros</grk>;
<grk>Mi`nos</grk>, the husband of <persfn>Pasiphae</persfn> +
<grk>tay^ros</grk> a bull, the <persfn>Minotaur</persfn> being the
offspring of <persfn>Pasiphae</persfn> and a bull: cf. F.
<ets>minotaure</ets>.]</ety> <fld>(Class. Myth.)</fld> <def>A fabled
monster, half man and half bull, confined in the labyrinth constructed
by <persfn>Daedalus</persfn> in Crete.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minow</ent><br/
<hw>Min"ow</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Minnow</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minster</ent><br/
<hw>Min"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mynster</ets>, fr. L. <ets>monasterium</ets>. See
<er>Monastery</er>.]</ety> <fld>(Arch.)</fld> <def>A church of a
monastery. The name is often retained and applied to the church after
the monastery has ceased to exist (<as>as Beverly <ex>Minster</ex>,
Southwell <ex>Minster</ex>, etc.</as>), and is also improperly used for
any large church.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Minster house</b></col>, <cd>the official house in which
the canons of a cathedral live in common or in rotation.</cd>
<rj><au>Shipley.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minstrel</ent><br/
<hw>Min"strel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>minstrel</ets>, <ets>menestral</ets>, OF. <ets>menestrel</ets>, fr.
LL. <ets>ministerialis</ets> servant, workman (cf.
<ets>ministrellus</ets> harpist), fr. L. <ets>ministerium</ets> service.
See <er>Ministry</er>, and cf. <er>Ministerial</er>.]</ety> <def>In the
Middle Ages, one of an order of men who subsisted by the arts of poetry
and music, and sang verses to the accompaniment of a harp or other
instrument; in modern times, a poet; a bard; a singer and harper; a
musician.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minstrelsy</ent><br/
<hw>Min"strel*sy</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
arts and occupation of minstrels; the singing and playing of a
minstrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Musical instruments.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A collective body of minstrels, or musicians; also,
a collective body of minstrels' songs.</def> <au>Chaucer.</au>
<ldquo/The <xex>minstrelsy</xex> of heaven.<rdquo/ <au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mint</ent><br/
<hw>Mint</hw> <pr>(m<icr/nt)</pr>, <pos>n.</pos> <ety>[AS.
<ets>minte</ets>, fr. L. <ets>mentha</ets>, Gr. <grk>mi`nqa</grk>,
<grk>mi`nqh</grk>.]</ety> <fld>(Bot.)</fld> <def>The name of several
aromatic labiate plants, mostly of the genus <gen>Mentha</gen>, yielding
odoriferous essential oils by distillation. See
<er>Mentha</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <styp><col><b>Corn mint</b></col></styp> is <spn>Mentha
arvensis</spn>. -- <styp><col><b>Horsemint</b></col></styp> is
<spn>Mentha sylvestris</spn>, and in the United States <spn>Monarda
punctata</spn>, which differs from the true mints in several respects.
-- <styp><col><b>Mountain mint</b></col></styp> is any species of the
related genus <gen>Pycnanthemum</gen>, common in North America. --
<styp><col><b>Peppermint</b></col></styp> is <spn>Mentha piperita</spn>.
-- <styp><col><b>Spearmint</b></col></styp> is <spn>Mentha
viridis</spn>. -- <styp><col><b>Water mint</b></col></styp> is
<spn>Mentha aquatica</spn>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mint camphor</b></col>. <fld>(Chem.)</fld> <cd>See
<er>Menthol</er>.</cd> -- <col><b>Mint julep</b></col>. <cd>See
<er>Julep</er>.</cd> -- <col><b>Mint sauce</b></col>, <cd>a sauce
flavored with spearmint, for meats.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mint</ent><br/
<hw>Mint</hw>, <pos>n.</pos> <ety>[AS. <ets>mynet</ets> money, coin, fr.
L. <ets>moneta</ets> the mint, coined money, fr. <ets>Moneta</ets>, a
surname of Juno, in whose at Rome money was coined; akin to
<ets>monere</ets> to warn, admonish, AS. <ets>manian</ets>, and to E.
<ets>mind</ets>. See <er>Mind</er>, and cf. <er>Money</er>,
<er>Monition</er>.]</ety> <sn>1.</sn> <def>A place where money is coined
by public authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any place regarded as a
source of unlimited supply; the supply itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>mint</qex> of phrases in his brain.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <def>A large quantity of
money; <as>as, to make a <ex>mint</ex> in stock trading</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mint</ent><br/
<hw>Mint</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Minted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Minting</conjf>.]</vmorph> <ety>[AS.
<ets>mynetian</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To make by stamping, as money; to coin; to make and
stamp into money.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To invent; to forge; to fabricate; to
fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Titles . . . of such natures as may be easily
<qex>minted</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Minting mill</b></col>, <cd>a coining
press.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mint</ent><br/
<hw>mint</hw>, <pos>a.</pos> <def>Like new; in brand-new condition;
unworn, as a coin recently made at a mint{1}; <as>as, he had a '53
Cadillac in <ex>mint</ex> condition</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <fld>(Numismatics)</fld>
<def>Uncirculated; in the same condition as when it was freshly coined
at the mint{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mintage</ent><br/
<hw>Mint"age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The coin,
or other production, made in a mint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stamped in clay, a heavenly <qex>mintage</qex>.</q>
<rj><qau>Sterling.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The duty paid to the mint for coining. At one time
people could bring precious metals, as gold or silver, to a mint and
receive in return coins of the same value, minus the commision charged
by the mint, which was the <ex>mintage</ex>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>The act or process of minting{1}; <as>as, a coin of
recent <ex>mintage</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>The quantity of coins of a specific type made by the
mint; <as>as, coins of low <ex>mintage</ex> tend to be more valuable as
collectors' items</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Minter</ent><br/
<hw>Mint"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mintman</ent><br/
<hw>Mint"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mintmen</plw> <pr>(<?/)</pr>.</plu> <def>One skilled in coining, or
in coins; a coiner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mint-master</ent><br/
<hw>Mint"-mas`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The master or
superintendent of a mint. Also used figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mint sauce</ent><br/
<hw>Mint sauce</hw>. <sn>1.</sn> <def>A sauce of vinegar and sugar
flavored with spearmint leaves.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Money.</def> <mark>[Slang, Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mint state</ent><br/
<hw>mint state</hw>. <pos>n.</pos> <fld>(Numismatics)</fld> <def>A
numerical grade indicating the degree of perfection of the condition of
a coin which is classified as uncirculated, ranging from 70 for a coin
in perfect condition to 60 for a coin which is uncirculated but may have
a weak strike, or numerous small scratches from being handled in mint
bags; usually used as the abbreviation <abbr>MS</abbr>; <as>as, an
<ex>MS</ex>-67 Morgan Dollar</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>minuend</ent><br/
<hw>min"u*end</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>minuendus</ets> to be diminished, fr. <ets>minuere</ets> to lessen,
diminish. See <er>Minish</er>.]</ety> <fld>(Arith.)</fld> <def>In the
process of subtraction{2}, the number from which another number (the
<corr>subtrahend</corr>) is to be subtracted, to find the
<corr>difference</corr>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Minuet</ent><br/
<hw>Min"u*et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>menu</ets> small, L. <ets>minutus</ets> small. So called on account
of the short steps of the dance. See 4th <er>Minute</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A slow graceful dance consisting of a coupee, a high
step, and a balance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A tune or air to regulate the
movements of the dance so called; a movement in suites, sonatas,
symphonies, etc., having the dance form, and commonly in 3-4, sometimes
3-8, measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minum</ent><br/
<hw>Min"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 2d
<er>Minion</er>, <er>Minum</er>, 6.]</ety> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A small kind of printing type; minion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A minim.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minus</ent><br/
<hw>Mi"nus</hw> <pr>(m<imac/"n<ucr/s)</pr>, <pos>a.</pos> <ety>[L. See
<er>Minor</er>, and cf. <er>Mis-</er> pref. from the French.]</ety>
<fld>(Math.)</fld> <def>Less; requiring to be subtracted; negative;
<as>as, a <ex>minus</ex> quantity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Minus sign</b></col> <fld>(Math.)</fld>, <cd>the sign [-]
denoting <xex>minus</xex>, or <xex>less</xex>, prefixed to negative
quantities, or quantities to be subtracted. See <cref>Negative
sign</cref>, under <er>Negative</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>minus</ent><br/
<hw>mi"nus</hw> <pr>(m<imac/"n<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>minuses</plw>
<pr>(m<imac/"n<ucr/s*<esl/z)</pr>.</plu> <def>A factor counted as a
disadvantage; a loss or potential loss in a situation or plan; <as>as,
he added up all the pluses and <ex>minuses</ex> and decided not to do
it; as, the lack of money is a big <ex>minus</ex> in an election
campaign</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>minuscular</ent><br/
<hw>minuscular</hw> <pos>adj.</pos> <def>of or relating to minuscule
script, a small cursive script developed from uncial, and used in the
7th to 9th centuries.</def><br/
<syn><b>Syn. --</b> minuscule.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Minuscule</ent><br/
<hw>Mi*nus"cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>minusculus</ets> rather small, fr. <ets>minus</ets> less: cf. F.
<ets>minuscule</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Any very small, minute object.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small Roman letter which is neither capital nor
uncial; a manuscript written in such letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>minuscule</ent><br/
<hw>minuscule</hw> <pos>adj.</pos> <pos>a.</pos> <def>Of or relating to
a minuscule{2} or of a script written in minuscules{2}; of the size and
style of minuscules{2}; written in minuscules{2}; minuscular.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>These <qex>minuscule</qex> letters are cursive forms of the
earlier uncials.</q> <rj><qau>I. Taylor (The Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minutary</ent><br/
<hw>Min"u*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
consisting of, minutes.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minute</ent><br/
<hw>Min"ute</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[LL.
<ets>minuta</ets> a small portion, small coin, fr. L. <ets>minutus</ets>
small: cf. F. <ets>minute</ets>. See 4th <er>Minute</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The sixtieth part of an hour; sixty seconds.
(Abbrev. <abbr>m.</abbr> or <abbr>min.</abbr>; <as>as, 4 h. 30
<ex>m.</ex></as>)</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Four <qex>minutes</qex>, that is to say, <qex>minutes</qex> of an
hour.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sixtieth part of a degree; sixty seconds (Marked
thus (<prime/); <as>as, 10<deg/ 20<prime/</as>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A nautical or a geographic mile.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A coin; a half farthing.</def> <mark>[Obs.]</mark>
<rj><au>Wyclif (Mark xii. 42)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A very small part of anything, or anything very
small; a jot; a tittle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Minutes</qex> and circumstances of his passion.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A point of time; a moment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I go this <qex>minute</qex> to attend the king.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <def>The memorandum; a record; a note to
preserve the memory of anything; <as>as, to take <ex>minutes</ex> of a
contract; to take <ex>minutes</ex> of a conversation or debate; to read
the <ex>minutes</ex> of the last meeting.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Arch.)</fld> <def>A fixed part of a module. See
<er>Module</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Different writers take as the minute one twelfth, one
eighteenth, one thirtieth, or one sixtieth part of the
module.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minute</ent><br/
<hw>Min"ute</hw>, <pos>a.</pos> <def>Of or pertaining to a minute or
minutes; occurring at or marking successive minutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Minute bell</b></col>, <cd>a bell tolled at intervals of
a minute, as to give notice of a death or a funeral.</cd> --
<col><b>Minute book</b></col>, <cd>a book in which written minutes are
entered.</cd> -- <col><b>Minute glass</b></col>, <cd>a glass measuring a
minute or minutes by the running of sand.</cd> -- <col><b>Minute
gun</b></col>, <cd>a discharge of a cannon repeated every minute as a
sign of distress or mourning.</cd> -- <col><b>Minute hand</b></col>,
<cd>the long hand of a watch or clock, which makes the circuit of the
dial in an hour, and marks the minutes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minute</ent><br/
<hw>Min"ute</hw>, <pos>v. t.</pos> <ety>[<pos>imp. & p. p.</pos>
<er>Minuted</er>; <pos>p. pr. & vb. n.</pos> <er>Minuting</er>.]</ety>
<def>To set down a short sketch or note of; to jot down; to make a
minute or a brief summary of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Empress of Russia, with her own hand, <qex>minuted</qex> an
edict for universal tolerance.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minute</ent><br/
<hw>Mi*nute"</hw> <pr>(m<imac/*n<umac/t" <it>or</it>
m<icr/*n<umac/t")</pr>, <pos>a.</pos> <ety>[L. <ets>minutus</ets>, p. p.
of <ets>minuere</ets> to lessen. See <er>Minish</er>, <er>Minor</er>,
and cf. <er>Menu</er>, <er>Minuet</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Very small; little; tiny; fine; slight; slender;
inconsiderable; <as>as, <ex>minute</ex> details</as>.</def>
<ldquo/<xex>Minute</xex> drops.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Attentive to small things; paying attention to
details; critical; particular; precise; <as>as, a <ex>minute</ex>
observer; <ex>minute</ex> observation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Little; diminutive; fine; critical; exact;
circumstantial; particular; detailed.</syn> <usage> -- <er>Minute</er>,
<er>Circumstantial</er>, <er>Particular</er>. A
<xex>circumstantial</xex> account embraces all the leading events; a
<xex>particular</xex> account includes each event and movement, though
of but little importance; a <xex>minute</xex> account goes further
still, and omits nothing as to person, time, place, adjuncts,
etc.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minute-jack</ent><br/
<hw>Mi*nute"-jack`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
figure which strikes the hour on the bell of some fanciful clocks; --
called also <altname>jack of the clock house</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A timeserver; an inconstant person.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minutely</ent><br/
<hw>Mi*nute"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From 4th
<er>Minute</er>.]</ety> <def>In a minute manner; with minuteness;
exactly; nicely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minutely</ent><br/
<hw>Min"ute*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From 1st
<er>Minute</er>.]</ety> <def>Happening every minute; continuing;
unceasing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Throwing themselves absolutely upon God's <qex>minutely</qex>
providence.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minutely</ent><br/
<hw>Min"ute*ly</hw>, <pos>adv.</pos> <def>At intervals of a minute; very
often and regularly.</def> <rj><au>J. Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Minutely</qex> proclaimed in thunder from heaven.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minuteman</ent><br/
<hw>Min"ute*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Minutemen</plw> <pr>(<?/)</pr>.</plu> <def>A militiaman who was to
be ready to march at a moment's notice; -- a term used in the American
Revolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minuteness</ent><br/
<hw>Mi*nute"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being minute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minutia</ent><br/
\'d8<hw>Mi*nu"ti*a</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Minutiae</plw> <pr>(-<emac/)</pr>.</plu> <ety>[L., fr.
<ets>minutus</ets> small, minute. See 4th <er>Minute</er>.]</ety> <def>A
minute particular; a small or minor detail; -- used chiefly in the
plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minx</ent><br/
<hw>Minx</hw> <pr>(m<icr/<nsm/ks)</pr>, <pos>n.</pos> <ety>[Prob. of Low
German origin; cf. LG. <ets>minsk</ets> wench, jade, hussy, D.
<ets>mensch</ets>; prop. the same word as D. & G. <ets>mensch</ets> man,
human being, OHG. <ets>mennisco</ets>, AS. <ets>mennisc</ets>, fr.
<ets>man</ets>. See <er>Man</er>.]</ety> <sn>1.</sn> <def>A pert or a
wanton girl.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A she puppy; a pet dog.</def> <mark>[Obs.]</mark>
<rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minx</ent><br/
<hw>Minx</hw>, <pos>n.</pos> <ety>[See <er>Mink</er>.]</ety>
<fld>(Zool.)</fld> <def>The mink; -- called also <cref>minx
otter</cref>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 928 --></p>

<p><ent>Miny</ent><br/
<hw>Min"y</hw> <pr>(m<imac/n"<ycr/)</pr>, <pos>a.</pos> <def>Abounding
with mines; like a mine.</def> <ldquo/<xex>Miny</xex> caverns.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Minyan</ent><br/
<hw>Min*yan"</hw> <pr>(m<esl/n*y<aum/n")</pr>, <pos>n.</pos>
<fld>(Jewish Relig.)</fld> <def>A quorum, or number necessary, for
conducting public worship.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Miocene</ent><br/
<hw>Mi"o*cene</hw> <pr>(m<imac/"<osl/*s<emac/n)</pr>, <pos>prop.
a.</pos> <ety>[Gr. <grk>mei`wn</grk> less + <grk>kaino`s</grk> new,
fresh, recent.]</ety> <fld>(Geol.)</fld> <def>Of or pertaining to the
middle division of the Tertiary.</def> -- <def2><pos>n.</pos> <def>The
Miocene period. See <cref>Chart</cref> of
<er>Geology</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miohippus</ent><br/
\'d8<hw>Mi`o*hip"pus</hw> <pr>(m<imac/`<osl/*h<icr/p"p<ucr/s)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>mei`wn</grk> less +
<grk>"ippo`s</grk> horse.]</ety> <fld>(Paleon.)</fld> <def>An extinct
Miocene mammal of the Horse family, closely related to the genus
<gen>Anhithecrium</gen>, and having three usable hoofs on each
foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miquelet</ent><br/
<hw>Miq"ue*let</hw> <pr>(m<icr/k"w<esl/*l<ecr/t)</pr>, <pos>n.</pos>
<ety>[Sp. <ets>miquelete</ets>.]</ety> <fld>(Mil.)</fld> <def>An
irregular or partisan soldier; a bandit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mir</ent><br/
<hw>Mir</hw> <pr>(m<emac/r)</pr>, <pos>n.</pos> <ety>[Russ.
<ets>mir'</ets>.]</ety> <def>A Russian village community.</def>
<rj><au>D. M. Wallace.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mir</ent><br/
<hw>Mir</hw>, <pos>n.</pos> <ety>[Per. <ets>m<imac/r</ets>.]</ety>
<def>Same as <er>Emir</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mira</ent><br/
\'d8<hw>Mi"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from L.
<ets>mirus</ets> wonderful.]</ety> <fld>(Astron.)</fld> <def>A
remarkable variable star in the constellation Cetus (<altname><omicron/
Ceti</altname>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirabilary</ent><br/
<hw>Mi*rab"i*la*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mirabilaries</plw> <pr>(<?/)</pr>.</plu> <def>One who, or a work
which, narrates wonderful things; one who writes of wonders.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mirabile dictu</ent><br/
<hw>mi*ra"bi*le dic"tu</hw> <pr>(m<esl/*r<aum/"b<icr/*l<asl/
d<icr/k"t<oomac/)</pr>, <pos>adv.</pos> <ety>[Latin.]</ety>
<def>Remarkably; strange to say; marvelous to relate.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mirabilis</ent><br/
\'d8<hw>Mi*rab"i*lis</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L.,
wonderful.]</ety> <fld>(Bot.)</fld> <def>A genus of plants. See
<er>Four-o'clock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirabilite</ent><br/
<hw>Mi*rab"i*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Native sodium sulphate; Glauber's salt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirable</ent><br/
<hw>Mi"ra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mirabilis</ets>, fr. <ets>mirari</ets> to wonder: cf. OF.
<ets>mirable</ets>. See <er>Marvel</er>.]</ety> <def>Wonderful;
admirable.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miracle</ent><br/
<hw>Mir"a*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>miraculum</ets>, fr. <ets>mirari</ets> to wonder. See
<er>Marvel</er>, and cf. <er>Mirror</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A wonder or wonderful thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>miracle</qex> and queen of genus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>An event or effect
contrary to the established constitution and course of things, or a
deviation from the known laws of nature; a supernatural event, or one
transcending the ordinary laws by which the universe is
governed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They considered not the <qex>miracle</qex> of the loaves.</q>
<rj><qau>Mark vi. 52.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A miracle play.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A story or legend abounding in miracles.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When said was all this <qex>miracle</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Miracle monger</b></col>, <cd>an impostor who pretends to
work miracles.</cd> -- <col><b>Miracle play</b></col>, <cd>one of the
old dramatic entertainments founded on legends of saints and martyrs or
(see 2d <er>Mystery</er>, 2) on events related in the
Bible.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miracle</ent><br/
<hw>Mir"a*cle</hw>, <pos>v. t.</pos> <def>To make wonderful.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miraculize</ent><br/
<hw>Mi*rac"u*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause to
seem to be a miracle.</def> <mark>[R.]</mark>
<rj><au>Shaftesbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miraculous</ent><br/
<hw>Mi*rac"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>miraculeux</ets>. See <er>Miracle</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of the nature of a miracle; performed by
supernatural power; effected by the direct agency of almighty power, and
not by natural causes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Supernatural; wonderful.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wonder-working.</def> <ldquo/The
<xex>miraculous</xex> harp.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mi*rac"u*lous*ly</wf>, <pos>adv.</pos> --
<wf>Mi*rac"u*lous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirador</ent><br/
<hw>Mir`a*dor"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., fr.
<ets>mirar</ets> to behold, view. See <er>Mirror</er>.]</ety>
<fld>(Arch.)</fld> <def>Same as <er>Belvedere</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirage</ent><br/
<hw>Mi`rage"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>mirer</ets> to look at carefully, to aim, <ets>se mirer</ets> to
look at one's self in a glass, to reflect, to be reflected, LL.
<ets>mirare</ets> to look at. See <er>Mirror</er>.]</ety> <def>
An inverted image due to atmospheric refraction.  Multiple images,
alternately erect and inverted, are produced by large changes in <er>lapse
rate</er> with height.  Inferior mirages (below eye level) are seen over
paving, water, sand, snow, sunlit walls, freezing lakes and rivers, and
other smooth surfaces warmer than the adjacent air.  Objects appear as
if reflected by a sheet of water, or may seem suspended in the air above
a narrow strip of miraged sky; or the shadowed undersides of vehicles
and leaves appear as dark patches that recede as an observer approaches
them.  Superior mirages are due to thermal inversions above colder
surfaces, and produce inverted images above the horizontal.
The <stype>Fata Morgana</stype> is a superior mirage characterized by a
striated zone of extreme vertical elongation, which may resemble
columnar basalt.  Other types of mirage also occur; all are refraction
phenomena with inverted images.</def><br/
[<source>A. T. Young</source>]</p>

<p><q>By the <qex>mirage</qex> uplifted the land floats vague in the
ether,<br/
Ships and the shadows of ships hang in the motionless air.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirbane</ent><br/
<hw>Mir"bane</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Nitrobenzene</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mire</ent><br/
<hw>Mire</hw> <pr>(m<imac/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>m<imac/re</ets>, <ets>m<ymac/re</ets>; akin to D. <ets>mier</ets>,
Icel. <ets>maurr</ets>, Dan. <ets>myre</ets>, Sw. <ets>myra</ets>; cf.
also Ir. <ets>moirbh</ets>, Gr. <grk>my`rmhx</grk>.]</ety> <def>An
ant.</def> <mark>[Obs.]</mark> <see>See <er>Pismire</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mire</ent><br/
<hw>Mire</hw>, <pos>n.</pos> <ety>[OE. <ets>mire</ets>, <ets>myre</ets>;
akin to Icel. <ets>m<?/rr</ets> swamp, Sw. <ets>myra</ets> marshy
ground, and perh. to E. <ets>moss</ets>.]</ety> <def>Deep mud; wet,
spongy earth.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He his rider from the lofty steed<br/
Would have cast down and trod in dirty <qex>mire</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mire crow</b></col> <fld>(Zool.)</fld>, <cd>the pewit, or
laughing gull.</cd> <mark>[Prov. Eng.]</mark> -- <col><b>Mire
drum</b></col>, <cd>the European bittern.</cd> <mark>[Prov.
Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mire</ent><br/
<hw>Mire</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mired</conjf> <pr>(m<imac/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Miring</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To cause or permit to stick fast in mire; to plunge
or fix in mud; <as>as, to <ex>mire</ex> a horse or wagon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>To stick or entangle; to
involve in difficulties; -- often used in the passive or predicate form;
<as>as, we got <ex>mired</ex> in bureaucratic red tape and it took years
longer than planned</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To soil with mud or foul matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Smirched thus and <qex>mired</qex> with infamy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mire</ent><br/
<hw>Mire</hw>, <pos>v. i.</pos> <def>To stick in mire.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirifical</ent><br/
<ent>Mirific</ent><br/
<mhw>{ <hw>Mi*rif"ic</hw> <pr>(?)</pr>, <hw>Mi*rif"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>mirificus</ets>;
<ets>mirus</ets> wonderful + <ets>-ficare</ets> (in comp.) to make. See
<er>-fy</er>.]</ety> <def>Working wonders; wonderful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirificent</ent><br/
<hw>Mi*rif"i*cent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wonderful.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miriness</ent><br/
<hw>Mir"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being miry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirk</ent><br/
<hw>Mirk</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Murky</er>.]</ety> <def>Dark; gloomy; murky.</def> <rj><au>Spenser.
Mrs. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirk</ent><br/
<hw>Mirk</hw>, <pos>n.</pos> <def>Darkness; gloom; murk.</def> <ldquo/In
<xex>mirk</xex> and mire.<rdquo/ <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirksome</ent><br/
<hw>Mirk"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dark; gloomy;
murky.</def> <mark>[Archaic]</mark> <au>Spenser.</au> --
<wordforms><wf>Mirk"some*ness</wf>, <pos>n.</pos>
<mark>[Archaic]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirky</ent><br/
<hw>Mirk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dark; gloomy. See
<er>Murky</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirliton</ent><br/
<hw>Mir"li*ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>A kind of musical toy into which one sings, hums, or
speaks, producing a coarse, reedy sound. It is also called a
<altname>kazoo</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><q>Trilby singing <ldquo/Ben Bolt<rdquo/ into a <qex>mirliton</qex>
was a thing to be remembered, whether one would or no!</q> <rj><qau>Du
Maurier.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>same as <er>chayote{2}</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mirounga</ent><br/
<hw>Mirounga</hw> <pos>prop. n.</pos> <def>A genus comprising the
elephant seals.</def><br/
<syn><b>Syn. --</b> genus <gen>Mirounga</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mirror</ent><br/
<hw>Mir"ror</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mirour</ets>, F. <ets>miroir</ets>, OF. also <ets>mireor</ets>, fr.
(assumed) LL. <ets>miratorium</ets>, fr. <ets>mirare</ets> to look at,
L. <ets>mirari</ets> to wonder. See <er>Marvel</er>, and cf.
<er>Miracle</er>, <er>Mirador</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A looking-glass or a speculum; any glass or polished
substance that forms images by the reflection of rays of
light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And in her hand she held a <qex>mirror</qex> bright,<br/
Wherein her face she often view<egrave/d fair.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which gives a true representation, or in which
a true image may be seen; hence, a pattern; an exemplar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She is <qex>mirour</qex> of all courtesy.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O goddess, heavenly bright,<br/
<qex>Mirror</qex> of grace and majesty divine.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>See <er>Speculum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mirror carp</b></col> <fld>(Zool.)</fld>, <cd>a
domesticated variety of the carp, having only three or fur rows of very
large scales side.</cd> -- <col><b>Mirror plate</b></col>. <sd>(a)</sd>
<cd>A flat glass mirror without a frame</cd>. <sd>(b)</sd> <cd>Flat
glass used for making mirrors.</cd> -- <col><b>Mirror writing</b></col>,
<cd>a manner or form of backward writing, making manuscript resembling
in slant and order of letters the reflection of ordinary writing in a
mirror. The substitution of this manner of writing for the common manner
is a symptom of some kinds of nervous disease.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirror</ent><br/
<hw>Mir"ror</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mirrored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mirroring</conjf>.]</vmorph> <sn>1.</sn> <def>To
reflect, as in a mirror.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To copy or duplicate; to mimic or imitate; <as>as,
the files at <org>Project Gutenberg</org> were <ex>mirrored</ex> on
several other ftp sites around the world</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To have a close resemblance to; <as>as, his opinions
often <ex>mirrored</ex> those of his wife</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>mirrored</ent><br/
<hw>mirrored</hw> <pos>adj.</pos> <def>Reflected in or as if in a
mirror.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mirrorlike</ent><br/
<hw>mirrorlike</hw> <pos>adj.</pos> <sn>1.</sn> <def>capable of
reflecting light like a mirror; flat and reflective; <as>as, the
<ex>mirrorlike</ex> surface of the lake</as>.</def><br/
<syn><b>Syn. --</b> specular.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mirrorscope</ent><br/
<hw>Mir"ror*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mirror</ets> + <ets>-scope</ets>.]</ety> <def>See
<er>Projector</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mirth</ent><br/
<hw>Mirth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>mirthe</ets>,
<ets>murthe</ets>, <ets>merthe</ets>, AS. <ets>myr<edh/</ets>,
<ets>myrg<edh/</ets>, <ets>merh<edh/</ets>, <ets>mirh<edh/</ets>. See
<er>Merry</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Merriment; gayety accompanied with laughter;
jollity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then will I cause to cease . . . from the streets of Jerusalem,
the voice of <qex>mirth</qex>.</q> <rj><qau>Jer. vii. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which causes merriment.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Merriment; joyousness; gladness; fun; frolic;
glee; hilarity; festivity; jollity. See <er>Gladness</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirthful</ent><br/
<hw>Mirth"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
mirth or merriment; merry; <as>as, <ex>mirthful</ex>
children</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indicating or inspiring mirth; <as>as, a
<ex>mirthful</ex> face</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mirthful</qex>, comic shows.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mirth"ful*ly</wf>, <pos>adv.</pos> --
<wf>Mirth"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mirthless</ent><br/
<hw>Mirth"less</hw>, <pos>a.</pos> <def>Without mirth.</def> --
<wordforms><wf>Mirth"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miry</ent><br/
<hw>Mir"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From 2d
<er>Mire</er>.]</ety> <def>Abounding with deep mud; full of mire; muddy;
<as>as, a <ex>miry</ex> road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miryachit</ent><br/
<hw>Mir"ya*chit`</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>myriachit</asp>.]</altsp> <ety>[Yakoot <ets>merj<aum/k</ets>
epileptic, fr. <ets>imerek</ets> jerk, rage.]</ety> <fld>(Med.)</fld>
<def>A nervous disease in which the patient involuntarily imitates the
words or action of another.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mirza</ent><br/
<hw>Mir"za</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Per.
<ets>m<imac/rz<amac/</ets>, abbrev. fr. <ets>m<imac/rz<amac/deh</ets>
son of the prince; <ets>m<imac/r</ets> prince (Ar. <ets>am<imac/r</ets>,
<ets>em<imac/r</ets>) + <ets>z<amac/deh</ets> son.]</ety> <def>The
common title of honor in Persia, prefixed to the surname of an
individual. When appended to the surname, it signifies
<sig>Prince</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mis-</ent><br/
<hw>Mis-</hw> <pr>(m<icr/s-)</pr>. <ety>[In words of Teutonic origin,
fr. AS. <ets>mis-</ets>; akin to D. <ets>mis-</ets>, G.
<ets>miss-</ets>, OHG. <ets>missa-</ets>, <ets>missi-</ets>, Icel. &
Dan. <ets>mis-</ets>, Sw. <ets>miss-</ets>, Goth. <ets>missa-</ets>;
orig., a p. p. from the root of G. <ets>meiden</ets> to shun, OHG.
<ets>m<imac/dan</ets>, AS. <ets>m<imac/<edh/an</ets> (<root/100. Cf.
<er>Miss</er> to fail of). In words from the French, fr. OF.
<ets>mes-</ets>, F. <ets>m<eacute/-</ets>, <ets>mes-</ets>, fr. L.
<ets>minus</ets> less (see <er>Minus</er>). In present usage these two
prefixes are commonly confounded.]</ety> <def>A prefix used adjectively
and adverbially in the sense of <sig>amiss</sig>, <sig>wrong</sig>,
<sig>ill</sig>, <sig>wrongly</sig>, <sig>unsuitably</sig>; <as>as,
<ex>mis</ex>deed, <ex>mis</ex>lead, <ex>mis</ex>chief,
<ex>mis</ex>creant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mis</ent><br/
<hw>Mis</hw> <pr>(m<icr/s)</pr>, <pos>a. & adv.</pos> <ety>[See
<er>Amiss</er>.]</ety> <def>Wrong; amiss.</def> <mark>[Obs.]</mark>
<ldquo/To correcten that [which] is <xex>mis</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misacceptation</ent><br/
<hw>Mis*ac`cep*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
acceptation; understanding in a wrong sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misaccompt</ent><br/
<hw>Mis`ac*compt"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To account or
reckon wrongly.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadjust</ent><br/
<hw>Mis`ad*just"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To adjust
wrongly of unsuitably; to throw out of adjustment.</def> <rj><au>I.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadjustment</ent><br/
<hw>Mis`ad*just"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
adjustment; unsuitable arrangement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadventure</ent><br/
<hw>Mis`ad*ven"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mesaventure</ets>, F. <ets>m<eacute/saventure</ets>.]</ety>
<def>Mischance; misfortune; ill luck; unlucky accident; ill
adventure.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Homicide by misadventure</b></col> <fld>(Law)</fld>,
<cd>homicide which occurs when a man, doing a lawful act, without any
intention of injury, unfortunately kills another; -- called also
<altname>excusable homicide</altname>. See <er>Homicide</er>.</cd>
<rj><au>Blackstone.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Mischance; mishap; misfortune; disaster;
calamity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadventured</ent><br/
<hw>Mis`ad*ven"tured</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Unfortunate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadventurous</ent><br/
<hw>Mis`ad*ven"tur*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Unfortunate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadvertence</ent><br/
<hw>Mis`ad*vert"ence</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Inadvertence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadvice</ent><br/
<hw>Mis`ad*vice"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Bad
advice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadvise</ent><br/
<hw>Mis`ad*vise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give bad
counsel to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misadvised</ent><br/
<hw>Mis`ad*vised"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ill
advised.</def> -- <wordforms><wf>Mis`ad*vis"ed*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>misaffect</ent><br/
<hw>mis`af*fect"</hw> <pr>(m<icr/s`<acr/f*f<ecr/kt")</pr>, <pos>v.
t.</pos> <def>To dislike.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>misaffected</ent><br/
<hw>mis`af*fect"ed</hw>, <pos>a.</pos> <def>Ill disposed.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>misaffection</ent><br/
<hw>mis`af*fec"tion</hw> <pr>(m<icr/s`<acr/f*f<ecr/k"sh<ucr/n)</pr>,
<pos>n.</pos> <def>An evil or wrong affection; the state of being ill
affected.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>misaffirm</ent><br/
<hw>mis`af*firm"</hw> <pr>(m<icr/s`<acr/f*f<etil/rm")</pr>, <pos>v.
t.</pos> <def>To affirm incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>misaimed</ent><br/
<hw>mis*aimed"</hw> <pr>(m<icr/s*<amac/md")</pr>, <pos>a.</pos> <def>Not
rightly aimed.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>misaligned</ent><br/
<hw>mis`a*ligned"</hw> <pr>(m<icr/s`<adot/*l<imac/nd")</pr>,
<pos>a.</pos> <def>Aligned improperly; not correctly aligned.</def><br/
[<source>PJC</source>]</p>

<p><ent>misalignment</ent><br/
<hw>mis`align"ment</hw> <pr>(m<icr/s`<adot/*l<imac/n"m<eit/nt)</pr>,
<pos>n.</pos> <def>The act of aligning improperly or state of being
improperly aligned.</def><br/
[<source>PJC</source>]</p>

<p><ent>misallegation</ent><br/
<hw>mis*al`le*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A erroneous
statement or allegation.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>misallege</ent><br/
<hw>mis`al*lege"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To state
erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misalliance</ent><br/
<hw>Mis`al*li"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/salliance</ets>.]</ety> <def>A marriage with a person of
inferior rank or social station; an improper alliance; a
mesalliance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A Leigh had made a <qex>misalliance</qex>, and blushed<br/
A Howard should know it.</q> <rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misallied</ent><br/
<hw>Mis`al*lied"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wrongly allied or
associated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misallotment</ent><br/
<hw>Mis`al*lot"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wrong
allotment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misalter</ent><br/
<hw>Mis*al"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To alter
wrongly; esp., to alter for the worse.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>misandrist</ent><br/
<hw>mis"an*drist</hw> <pr>(m<icr/s"<acr/n*dr<icr/st)</pr>, <pos>n.</pos>
<def>one who hates men. Contrast <contr><er>misogynist</er></contr> and
cf. <er>misandry</er>.</def><br/
<syn><b>Syn. --</b> man-hater.</syn><br/
[<source>PJC</source>]</p>

<p><ent>misandry</ent><br/
<hw>mis"an*dry</hw> <pr>(m<icr/s"<acr/n*dr<ycr/)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>misei^n</grk> to hate + <grk>'andh`r</grk> a man.]</ety>
<def>Hatred of men. Contrast <contr><er>misogyny</er></contr> and cf.
<er>misandrist</er>.</def><br/
<syn><b>Syn. --</b> man-hating.</syn><br/
[<source>PJC</source>]</p>

<p><ent>misanthrope</ent><br/
<hw>mis"an*thrope</hw> <pr>(m<icr/s"<acr/n*thr<omac/p)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>misa`nqrwpos</grk>; <grk>misei^n</grk> to
hate + <grk>'a`nqrwpos</grk> a man; cf. F. <ets>misanthrope</ets>. Cf.
<er>Miser</er>.]</ety> <def>A hater of mankind; a
misanthropist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misanthropical</ent><br/
<ent>Misanthropic</ent><br/
<mhw>{ <hw>Mis`an*throp"ic</hw> <pr>(?)</pr>,
<hw>Mis`an*throp"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Cf. F. <ets>misanthropique</ets>.]</ety> <def>Hating or disliking
mankind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misanthropist</ent><br/
<hw>Mis*an"thro*pist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
misanthrope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misanthropos</ent><br/
<hw>Mis*an"thro*pos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Misanthrope</er>.]</ety> <def>A misanthrope.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misanthropy</ent><br/
<hw>Mis*an"thro*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf.
F. <ets>misanthropie</ets>.]</ety> <def>Hatred of, or dislike to,
mankind; -- opposed to <ant>philanthropy</ant>.</def>
<rj><au>Orrery.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misapplication</ent><br/
<hw>Mis*ap`pli*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wrong
application.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misapply</ent><br/
<hw>Mis`ap*ply"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Misapplied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misapplying</conjf>.]</vmorph> <def>To apply wrongly; to
use for a wrong purpose; <as>as, to <ex>misapply</ex> a name or title;
to <ex>misapply</ex> public money.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misappreciated</ent><br/
<hw>Mis`ap*pre"ci*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Improperly
appreciated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misapprehend</ent><br/
<hw>Mis*ap`pre*hend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To take in
a wrong sense; to misunderstand.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misapprehension</ent><br/
<hw>Mis*ap`pre*hen"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
mistaking or mistake; wrong apprehension of one's meaning of a fact;
misconception; misunderstanding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misapprehensively</ent><br/
<hw>Mis*ap`pre*hen"sive*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By,
or with, misapprehension.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misappropriate</ent><br/
<hw>Mis`ap*pro"pri*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
appropriate wrongly; to use for a wrong purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>misappropriated</ent><br/
<hw>mis`ap*pro"pri*a*ted</hw> <pos>adj.</pos> <def>taken for one's own
use in violation of a trust.</def><br/
<syn><b>Syn. --</b> embezzled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Misappropriation</ent><br/
<hw>Mis`ap*pro`pri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
appropriation; wrongful use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misarrange</ent><br/
<hw>Mis`ar*range"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Misarranged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misarranging</conjf> <pr>(?)</pr>.]</vmorph> <def>To
place in a wrong order, or improper manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misarrangement</ent><br/
<hw>Mis`ar*range"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
arrangement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misarcribe</ent><br/
<hw>Mis`ar*cribe"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To ascribe
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misassay</ent><br/
<hw>Mis`as*say"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To assay, or
attempt, improperly or unsuccessfully.</def> <mark>[Obs.]</mark>
<rj><au>W. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misassign</ent><br/
<hw>Mis`as*sign"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To assign
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misattend</ent><br/
<hw>Mis`at*tend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
misunderstand; to disregard.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misaventure</ent><br/
<hw>Mis`a*ven"ture</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Misadventure.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misavize</ent><br/
<hw>Mis`a*vize"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
misadvise.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbear</ent><br/
<hw>Mis*bear"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To carry
improperly; to carry (one's self) wrongly; to misbehave.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbecome</ent><br/
<hw>Mis`be*come"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Not to become;
to suit ill; not to befit or be adapted to.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy father will not act what <qex>misbecomes</qex> him.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbecoming</ent><br/
<hw>Mis`be*com"ing</hw>, <pos>a.</pos> <def>Unbecoming.</def>
<au>Milton.</au> -- <wordforms><wf>Mis`be*com"ing*ly</wf>,
<pos>adv.</pos> -- <wf>Mis`be*com"ing*ness</wf>,
<pos>n.</pos></wordforms> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbede</ent><br/
<hw>Mis*bede"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Misbode</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Misboden</conjf> <pr>(?)</pr>.]</vmorph> <ety>[AS.
<ets>mis-be<ocir/dan</ets>.]</ety> <def>To wrong; to do injury to.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who hath you <qex>misboden</qex> or offended?</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbefitting</ent><br/
<hw>Mis`be*fit"ting</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
befitting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbegotten</ent><br/
<ent>Misbegot</ent><br/
<mhw>{ <hw>Mis`be*got"</hw> <pr>(?)</pr>, <hw>Mis`be*got"ten</hw>
<pr>(<?/)</pr>, }</mhw> <pos>p. a.</pos> <sn>1.</sn> <def>Unlawfully or
irregularly begotten; of bad or disreputable origin; pernicious.</def>
<ldquo/Valor <xex>misbegot</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Poorly designed or planned; badly carried out;
ill-conceived.</def><br/
[<source>PJC</source>]</p>

<p><ent>Misbehave</ent><br/
<hw>Mis`be*have"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Misbehaved</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Misbehaving</conjf>.]</vmorph> <def>To
behave ill; to conduct one's self improperly; -- often used with a
reciprocal pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbehaved</ent><br/
<hw>Mis`be*haved"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Guilty of ill
behavior; illbred; rude.</def> <ldquo/A <xex>misbehaved</xex> and sullen
wench.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbehavior</ent><br/
<hw>Mis`be*hav"ior</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Improper, rude,
or uncivil behavior; ill conduct.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbelief</ent><br/
<hw>Mis`be*lief"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous or
false belief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbelieve</ent><br/
<hw>Mis`be*lieve"</hw> <pr>(<?/)</pr>, <pos>v. i.</pos> <def>To believe
erroneously, or in a false religion.</def> <ldquo/That
<xex>misbelieving</xex> Moor.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbeliever</ent><br/
<hw>Mis`be*liev"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
believes wrongly; one who holds a false religion.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbeseem</ent><br/
<hw>Mis`be*seem"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To suit
ill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbestow</ent><br/
<hw>Mis`be*stow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To bestow
improperly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbestowal</ent><br/
<hw>Mis`be*stow"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
misbestowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbileve</ent><br/
<hw>Mis`bi*leve"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Misbelief;
unbelief; suspicion.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misbode</ent><br/
<hw>Mis*bode"</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Misbede</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misboden</ent><br/
<hw>Mis*bo"den</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Misbede</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misborn</ent><br/
<hw>Mis"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Born to
misfortune.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscalculate</ent><br/
<hw>Mis*cal"cu*late</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <sn>1.</sn>
<def>To calculate erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To judge wrongly, especially about the effects of
action or the likely course of events.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>miscalculation</ent><br/
<hw>mis*cal`cu*la"tion</hw> <pos>n.</pos> <sn>1.</sn> <def>a mistake in
calculating.</def><br/
<syn><b>Syn. --</b> misreckoning, misestimation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An error in judgment, especially about the effects
of action or the likely course of events; <as>as, IBM's
<ex>miscalculation</ex> about the impact of microcomputers cost them
many billions in lost opportunities; Sadam's invasion of Kuwait was only
his worst, but not his last, <ex>miscalculation</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Miscall</ent><br/
<hw>Mis*call"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
call by a wrong name; to name improperly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To call by a bad name; to abuse.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscarriage</ent><br/
<hw>Mis*car"riage</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Unfortunate event or issue of an undertaking; failure to attain a
proper or desired result or reach a destination; <as>as, a serious
<ex>miscarriage</ex> of justice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a counselor, to save himself,<br/
Would lay <qex>miscarriages</qex> upon his prince.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ill conduct; evil or improper behavior; <as>as, the
failings and <ex>miscarriages</ex> of the righteous</as>.</def>
<rj><au>Rogers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of bringing forth a child before the time it
is viable; a premature birth, resulting in death of the fetus;
spontaneous abortion.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Miscarriageable</ent><br/
<hw>Mis*car"riage*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
miscarrying; liable to fail.</def> <mark>[R.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscarry</ent><br/
<hw>Mis*car"ry</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Miscarried</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Miscarrying</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To carry, or go, wrong; to fail of reaching a
destination, or fail of the intended effect; to be unsuccessful; to
suffer defeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My ships have all <qex>miscarried</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The cardinal's letters to the pope <qex>miscarried</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring forth young before the time they are
viable; to have a spontaneous abortion.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Miscast</ent><br/
<hw>Mis*cast"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cast or reckon
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscast</ent><br/
<hw>Mis*cast"</hw>, <pos>n.</pos> <def>An erroneous cast or
reckoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>miscegenate</ent><br/
<hw>miscegenate</hw> <pos>v.</pos> <def>to marry or cohabit with a
person of another race.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Miscegenation</ent><br/
<hw>Mis`ce*ge*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>miscere</ets> to mix + the root of <ets>genus</ets> race.]</ety>
<def>A mixing of races; amalgamation, as by intermarriage of black and
white.</def> <note>Until the late twentieth century,
<ex>misceganation</ex> was a crime in some states of the Southern United
States.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Miscellanarian</ent><br/
<hw>Mis`cel*la*na"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Miscellany</er>.]</ety> <def>Of or pertaining to miscellanies.</def>
<au>Shaftesbury.</au> -- <def2><pos>n.</pos> <def>A writer of
miscellanies.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscellane</ent><br/
<hw>Mis"cel*lane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Miscellaneous</er>, and cf. <er>Maslin</er>.]</ety> <def>A mixture
of two or more sorts of grain; -- now called <altname>maslin</altname>
and <altname>meslin</altname>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscellanea</ent><br/
\'d8<hw>Mis"cel*la"ne*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
See <er>Miscellany</er>.]</ety> <def>A collection of miscellaneous
matters; matters of various kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscellaneous</ent><br/
<hw>Mis`cel*la"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>miscellaneus</ets> mixed, miscellaneous, fr. <ets>miscellus</ets>
mixed, fr. <ets>miscere</ets> to mix. See <er>Mix</er>, and cf.
<er>Miscellany</er>.]</ety> <def>Mixed; mingled; consisting of several
things; of diverse sorts; promiscuous; heterogeneous; <as>as, a
<ex>miscellaneous</ex> collection</as>.</def> <ldquo/A
<xex>miscellaneous</xex> rabble.<rdquo/ <au>Milton.</au> --
<wordforms><wf>Mis`cel*la"ne*ous*ly</wf>, <pos>adv.</pos> --
<wf>Mis`cel*la"ne*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscellanist</ent><br/
<hw>Mis"cel*la*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A writer of
miscellanies; miscellanarian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscellany</ent><br/
<hw>Mis"cel*la*ny</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Miscellanies</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>miscellanea</ets>, neut. pl. of. <ets>miscellaneus</ets>: cf. F.
<ets>miscellan<eacute/e</ets>, pl. <ets>miscellan<eacute/es</ets>. See
<er>Miscellaneous</er>.]</ety> <def>A mass or mixture of various things;
a medley; esp., a collection of compositions on various
subjects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is but a bundle or <qex>miscellany</qex> of sin; sins original,
and sins actual.</q> <rj><qau>Hewyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Miscellany madam</b></col>, <cd>a woman who dealt in
various fineries; a milliner.</cd> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 929 --></p>

<p><ent>Miscellany</ent><br/
<hw>Mis"cel*la*ny</hw> <pr>(m<icr/s"s<ecr/l*l<asl/*n<ycr/)</pr>,
<pos>a.</pos> <def>Miscellaneous; heterogeneous.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscensure</ent><br/
<hw>Mis*cen"sure</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
misjudge.</def> <mark>[Obs.]</mark> <au>Daniel.</au> --
<def2><pos>n.</pos> <def>Erroneous judgment.</def> <mark>[Obs.]</mark>
<au>Sylvester.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischance</ent><br/
<hw>Mis*chance"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>meschance</ets>, OF. <ets>mescheance</ets>.]</ety> <def>Ill luck;
ill fortune; mishap.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Never come <qex>mischance</qex> between us twain.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Calamity; misfortune; misadventure; mishap;
infelicity; disaster. See <er>Calamity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischance</ent><br/
<hw>Mis*chance"</hw>, <pos>v. i.</pos> <def>To happen by
mischance.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischanceful</ent><br/
<hw>Mis*chance"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unlucky.</def>
<rj><au>R. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischaracterize</ent><br/
<hw>Mis*char"ac*ter*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
characterize falsely or erroneously; to give a wrong character
to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They totally <qex>mischaracterize</qex> the action.</q>
<rj><qau>Eton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischarge</ent><br/
<hw>Mis*charge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To charge
erroneously, as in an account.</def> -- <def2><pos>n.</pos> <def>A
mistake in charging.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischief</ent><br/
<hw>Mis"chief</hw> <pr>(m<icr/s"ch<icr/f)</pr>, <pos>n.</pos> <ety>[OE.
<ets>meschef</ets> bad result, OF. <ets>meschief</ets>; pref.
<ets>mes-</ets> (L. <ets>minus</ets> less) + <ets>chief</ets> end, head,
F. <ets>chef</ets> chief. See <er>Minus</er>, and
<er>Chief</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Harm; damage; esp., disarrangement of order; trouble
or vexation caused by human agency or by some living being,
intentionally or not; often, calamity, mishap; trivial evil caused by
thoughtlessness, or in sport.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy tongue deviseth <qex>mischiefs</qex>.</q> <rj><qau>Ps. lii.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The practice whereof shall, I hope, secure me from many
<qex>mischiefs</qex>.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cause of trouble or vexation; trouble.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mischief</qex> was, these allies would never allow that
the common enemy was subdued.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be in mischief</b></col>, <cd>to be doing harm or
causing annoyance.</cd> -- <col><b>To make mischief</b></col>, <cd>to do
mischief, especially by exciting quarrels.</cd> -- <col><b>To play the
mischief</b></col>, <cd>to cause great harm; to throw into
confusion.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Damage; harm; hurt; injury; detriment; evil;
ill.</syn> <usage> -- <er>Mischief</er>, <er>Damage</er>, <er>Harm</er>.
<xex>Damage</xex> is an injury which diminishes the value of a thing;
<xex>harm</xex> is an injury which causes trouble or inconvenience;
<xex>mischief</xex> is an injury which disturbs the order and
consistency of things. We often suffer <xex>damage</xex> or
<xex>harm</xex> from accident, but <xex>mischief</xex> always springs
from perversity or folly.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischief</ent><br/
<hw>Mis"chief</hw>, <pos>v. t.</pos> <def>To do harm to.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischiefable</ent><br/
<hw>Mis"chief*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Mischievous.</def> <mark>[R.]</mark> <rj><au>Lydgate.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischiefful</ent><br/
<hw>Mis"chief*ful</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Mischievous.</def> <mark>[Obs.]</mark> <rj><au>Foote.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischief-maker</ent><br/
<hw>Mis"chief-mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes
mischief; one who excites or instigates quarrels or enmity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischief-making</ent><br/
<hw>Mis"chief-mak`ing</hw>, <pos>a.</pos> <def>Causing harm; exciting
enmity or quarrels.</def> <au>Rowe.</au> -- <def2><pos>n.</pos> <def>The
act or practice of making mischief, inciting quarrels,
etc.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischievous</ent><br/
<hw>Mis"chie*vous</hw> <pr>(m<icr/s"ch<esl/*v<ucr/s)</pr>, <pos>a.</pos>
<def>Causing mischief; harmful; hurtful; -- now often applied where the
evil is done carelessly or in sport; <as>as, a <ex>mischievous</ex>
child</as>.</def> <ldquo/Most <xex>mischievous</xex> foul sin.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This false, wily, doubling disposition is intolerably
<qex>mischievous</qex> to society.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Harmful; hurtful; detrimental; noxious;
pernicious; destructive.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mis"chie*vous*ly</wf>, <pos>adv.</pos> --
<wf>Mis"chie*vous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischna</ent><br/
<hw>Misch"na</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mishna</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischnic</ent><br/
<hw>Misch"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Mishnic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischoose</ent><br/
<hw>Mis*choose"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Mischose</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Mischosen</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mischoosing</conjf>.]</vmorph> <def>To choose
wrongly.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischoose</ent><br/
<hw>Mis*choose"</hw>, <pos>v. i.</pos> <def>To make a wrong
choice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mischristen</ent><br/
<hw>Mis*chris"ten</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To christen
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscibility</ent><br/
<hw>Mis`ci*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>miscibilit<eacute/</ets>.]</ety> <def>Capability of being
mixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscible</ent><br/
<hw>Mis"ci*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>miscible</ets>, fr. L. <ets>miscere</ets> to mix.]</ety>
<def>Capable of being mixed; mixable.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Mixable in all proportions;
forming a single phase when mixed in any proportion; -- of liquids;
<as>as, water and alcohol are <ex>miscible</ex> in all proportions;
water and gasoline are not <ex>miscible</ex>; benzene and ethyl alcohol
are <ex>miscible</ex>, and ethyl alcohol is <ex>miscible</ex> with
water, but water is not <ex>miscible</ex> with benzene.</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Miscitation</ent><br/
<hw>Mis`ci*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
citation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscite</ent><br/
<hw>Mis*cite"</hw>, <pos>v. t.</pos> <def>To cite erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misclaim</ent><br/
<hw>Mis*claim"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mistaken
claim.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscognizant</ent><br/
<hw>Mis*cog"ni*zant</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Law)</fld>
<def>Not cognizant; ignorant; not knowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscognize</ent><br/
<hw>Mis*cog"nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fail to
apprehend; to misunderstand.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscollocation</ent><br/
<hw>Mis*col`lo*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
collocation.</def> <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscolor</ent><br/
<hw>Mis*col"or</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give a wrong
color to.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>[figuratively]</mark> <def>To set forth erroneously
or unfairly; to misrepresent; <as>as, to <ex>miscolor</ex>
facts</as>.</def> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscomfort</ent><br/
<hw>Mis*com"fort</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Discomfort.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscomprehend</ent><br/
<hw>Mis*com`pre*hend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To get a
wrong idea of or about; to misunderstand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscomputation</ent><br/
<hw>Mis*com`pu*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
computation; false reckoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscompute</ent><br/
<hw>Mis`com*pute"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Miscount</er>.]</ety> <def>To compute erroneously.</def> <rj><au>Sir
T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconceit</ent><br/
<hw>Mis`con*ceit"</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Misconception.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconceive</ent><br/
<hw>Mis`con*ceive"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Misconceived</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Misconceiving</conjf>.]</vmorph> <def>To conceive wrongly; to
interpret incorrectly; to receive a false notion of; to misunderstand;
to misjudge; to misapprehend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those things which, for want of due consideration heretofore, they
have <qex>misconceived</qex>.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To misapprehend; misunderstand;
mistake.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconceiver</ent><br/
<hw>Mis`con*ceiv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
misconceives.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconception</ent><br/
<hw>Mis`con*cep"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
conception; false opinion; wrong understanding.</def>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconclusion</ent><br/
<hw>Mis`con*clu"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An erroneous
inference or conclusion.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconduct</ent><br/
<hw>Mis*con"duct</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Wrong
conduct; bad behavior; mismanagement.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unlawful or unethical conduct by a person holding a
public office or having a position of responsibility in the
administration of justice; malfeasance; <as>as, discussing the case out
of court during a trial is <ex>misconduct</ex> by a juror</as>;</def>
<specif>especially,</specif> <def>misuse of office by an elected or
appointed government official, also called <altname>misconduct in
office</altname>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Misbehavior; misdemeanor; mismanagement; misdeed;
delinquency; offense.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconduct</ent><br/
<hw>Mis`con*duct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To conduct
amiss; to mismanage.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To misconduct one's self</b></col>, <cd>to behave
improperly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconduct</ent><br/
<hw>Mis`con*duct"</hw>, <pos>v. i.</pos> <def>To behave amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconfident</ent><br/
<hw>Mis*con"fi*dent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
mistaken confidence; wrongly trusting.</def> <mark>[R.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconjecture</ent><br/
<hw>Mis`con*jec"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>A wrong
conjecture or guess.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconjecture</ent><br/
<hw>Mis`con*jec"ture</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
conjecture wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconsecrate</ent><br/
<hw>Mis*con"se*crate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
consecrate amiss.</def> <ldquo/<xex>Misconsecrated</xex> flags.<rdquo/
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconsecration</ent><br/
<hw>Mis*con`se*cra"tion</hw>, <pos>n.</pos> <def>Wrong
consecration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconsequence</ent><br/
<hw>Mis*con"se*quence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wrong
consequence; a false deduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconstruable</ent><br/
<hw>Mis*con"stru*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can
be misconstrued, as language or conduct.</def> <rj><au>R.
North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconstruct</ent><br/
<hw>Mis`con*struct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
construct wrongly; to construe or interpret erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconstruction</ent><br/
<hw>Mis`con*struc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
construction; wrong interpretation.</def> <rj><au>Bp.
Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconstrue</ent><br/
<hw>Mis*con"strue</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Misconstrued</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Misconstruing</conjf>.]</vmorph> <def>To construe
wrongly; to interpret erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Do not, great sir, <qex>misconstrue</qex> his intent.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Much afflicted to find his actions <qex>misconstrued</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misconstruer</ent><br/
<hw>Mis*con"stru*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
misconstrues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscontent</ent><br/
<hw>Mis`con*tent"</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Discontent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscontinuance</ent><br/
<hw>Mis`con*tin"u*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>Discontinuance; also, continuance by undue process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscopy</ent><br/
<hw>Mis*copy"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To copy
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscopy</ent><br/
<hw>Mis*copy"</hw>, <pos>n.</pos> <def>A mistake in copying.</def>
<rj><au>North Am. Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscorrect</ent><br/
<hw>Mis`cor*rect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fail or
err in attempting to correct.</def> <ldquo/Scaliger
<xex>miscorrects</xex> his author.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscounsel</ent><br/
<hw>Mis*coun"sel</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To counsel or
advise wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscount</ent><br/
<hw>Mis*count"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[Cf. OF.
<ets>mesconter</ets>, F. <ets>m<eacute/compter</ets>. Cf.
<er>Miscompute</er>.]</ety> <def>To count erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscount</ent><br/
<hw>Mis*count"</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/compte</ets> error, OF. <ets>mesconte</ets>.]</ety>
<sn>1.</sn> <def>An erroneous counting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>An erroneous count of
ballots cast in an election.</def><br/
[<source>PJC</source>]</p>

<p><ent>Miscovet</ent><br/
<hw>Mis*cov"et</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To covet
wrongfully.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscreancy</ent><br/
<ent>Miscreance</ent><br/
<mhw>{ <hw>Mis"cre*ance</hw> <pr>(?)</pr>, <hw>Mis"cre*an*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[OF. <ets>mescreance</ets>, F.
<ets>m<eacute/cr<eacute/ance</ets> incredulity.]</ety> <def>The quality
of being miscreant; adherence to a false religion; false faith.</def>
<mark>[Obs.]</mark> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscreant</ent><br/
<hw>Mis"cre*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mescreant</ets>, F. <ets>m<eacute/cr<eacute/ant</ets>; pref.
<ets>mes-</ets> (L. <ets>minus</ets> less) + p. pr. fr. L.
<ets>credere</ets> to believe. See <er>Creed</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One who holds a false religious faith; a
misbeliever.</def> <mark>[Obs.]</mark> <rj><au>Spenser. De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou oughtest not to be slothful to the destruction of the
<qex>miscreants</qex>, but to constrain them to obey our Lord God.</q>
<rj><qau>Rivers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One not restrained by Christian principles; an
unscrupulous villain; a depraved person; a vile wretch.</def>
<rj><au>Addison.</au></rj></p>

<p><ent>Miscreant</ent><br/
<hw>Mis"cre*ant</hw>, <pos>a.</pos> <sn>1.</sn> <def>Holding a false
religious faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of conscience; unscrupulous; villainous;
base; depraved.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Miscreate</ent><br/
<hw>Mis`cre*ate"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Miscreated;
illegitimate; forged; <as>as, <ex>miscreate</ex> titles</as>.</def>
<mark>[Obs. or Poet.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscreate</ent><br/
<hw>Mis`cre*ate"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To create
badly or amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscreated</ent><br/
<hw>Mis`cre*at"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed
unnaturally or illegitimately; deformed.</def> <rj><au>Spenser.
Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscreative</ent><br/
<hw>Mis`cre*a"tive</hw>, <pos>a.</pos> <def>Creating amiss.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscredent</ent><br/
<hw>Mis*cre"dent</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>mis-</ets> + <ets>credent</ets>. Cf. <er>Miscreant</er>.]</ety>
<def>A miscreant, or believer in a false religious doctrine.</def>
<mark>[Obs.]</mark> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscredulity</ent><br/
<hw>Mis`cre*du"li*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
credulity or belief; misbelief.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miscue</ent><br/
<hw>Mis*cue"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Billiards)</fld> <def>A false stroke with a billiard cue, the cue
slipping from the ball struck without impelling it as desired.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>To make a mistake;</def>
<specif>especially</specif> <def>to fail to execute a necessary or
expected action at the proper time, such as making a play in sports, or
saying one's line in a drama.</def><br/
[<source>PJC</source>]</p>

<p><ent>Misdate</ent><br/
<hw>Mis*date"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Misdated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Misdating</conjf>.]</vmorph> <sn>1.</sn> <def>To put a false or
erroneous date on (a document).</def> <rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To assign an incorrect date to; <as>as, the fall of
Troy was <ex>misdated</ex> by medieval writers</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>misdating</ent><br/
<hw>misdating</hw> <pos>n.</pos> <def>The assignment of a date to
something at a time when it could not have existed or
occurred.</def><br/
<syn><b>Syn. --</b> anachronism, mistiming.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Misdeal</ent><br/
<hw>Mis*deal"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Misdealt</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Misdealing</conjf>.]</vmorph> <def>To
deal or distribute wrongly, as cards; to make a wrong
distribution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdeal</ent><br/
<hw>Mis*deal"</hw>, <pos>n.</pos> <def>The act of misdealing; a wrong
distribution of cards to the players.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdeed</ent><br/
<hw>Mis*deed"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>misd<aemac/d</ets>. See <er>Deed</er>, <pos>n.</pos>]</ety> <def>An
evil deed; a wicked action.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Evils which our own <qex>misdeeds</qex> have wrought.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Misconduct; misdemeanor; fault; offense;
trespass; transgression; crime.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdeem</ent><br/
<hw>Mis*deem"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
misjudge.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdemean</ent><br/
<hw>Mis`de*mean"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To behave ill;
-- with a reflexive pronoun; <as>as, to <ex>misdemean</ex> one's
self</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdemeanant</ent><br/
<hw>Mis`de*mean"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One guilty of
a misdemeanor.</def> <rj><au>Sydney Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdemeanor</ent><br/
<hw>Mis`de*mean"or</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Ill
behavior; evil conduct; fault.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A crime less than a felony.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ As a rule, in the old English law, offenses capitally
punishable were felonies; all other indictable offenses were
misdemeanors. In common usage, the word <xex>crime</xex> is employed to
denote the offenses of a deeper and more atrocious dye, while small
faults and omissions of less consequence are comprised under the gentler
name of <xex>misdemeanors</xex>. <rj><au>Blackstone.</au></rj><br/
<br/
The distinction, however, between felonies and misdemeanors is purely
arbitrary, and is in most jurisdictions either abrogated or so far
reduced as to be without practical value. Cf. <er>Felony</er>.
<rj><au>Wharton.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Misdeed; misconduct; misbehavior; fault;
trespass; transgression.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdempt</ent><br/
<hw>Mis*dempt"</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p.
p.</pos> of <er>Misdeem</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdepart</ent><br/
<hw>Mis`de*part"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To distribute
wrongly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>misdeparteth</qex> riches temporal.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misderive</ent><br/
<hw>Mis`de*rive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
turn or divert improperly; to misdirect.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To derive erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdescribe</ent><br/
<hw>Mis`de*scribe"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To describe
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdesert</ent><br/
<hw>Mis`de*sert"</hw>, <pos>n.</pos> <def>Ill desert.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdevotion</ent><br/
<hw>Mis`de*vo"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mistaken
devotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdiet</ent><br/
<hw>Mis*di"et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Improper diet.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdiet</ent><br/
<hw>Mis*di"et</hw>, <pos>v. t.</pos> <def>To diet improperly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdight</ent><br/
<hw>Mis*dight"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Arrayed, prepared,
or furnished, unsuitably.</def> <mark>[Archaic]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdirect</ent><br/
<hw>Mis`di*rect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give a
wrong direction to; <as>as, to <ex>misdirect</ex> a passenger, or a
letter; to <ex>misdirect</ex> one's energies.</as></def>
<rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdirection</ent><br/
<hw>Mis`di*rec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of directing wrongly, or the state of being so
directed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An error of a judge in charging the
jury on a matter of law.</def> <rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The direction of another's attention to an
unimportant place or matter, for the purpose of being able to perform an
action undetected; <as>as, <ex>misdirection</ex> is an important part of
a magician's art</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Misdisposition</ent><br/
<hw>Mis*dis`po*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
disposal or application.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdistinguish</ent><br/
<hw>Mis`dis*tin"guish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
wrong distinctions in or concerning.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdivide</ent><br/
<hw>Mis`di*vide"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To divide
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdivision</ent><br/
<hw>Mis`di*vi"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
division.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdo</ent><br/
<hw>Mis*do"</hw> <pr>(m<icr/s*d<oomac/")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Misdid</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Misdone</conjf> <pr>(m<icr/s*d<ucr/n")</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Misdoing</conjf>.]</vmorph> <ety>[AS.
<ets>misd<omac/n</ets>. See <er>Do</er>, <pos>v.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To do wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Afford me place to show what recompense<br/
Towards thee I intend for what I have <qex>misdone</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To do wrong to; to illtreat.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdo</ent><br/
<hw>Mis*do"</hw>, <pos>v. i.</pos> <def>To do wrong; to commit a
fault.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>misdone</qex>, and I endure the smart.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdoer</ent><br/
<hw>Mis*do"er</hw>, <pos>n.</pos> <def>A wrongdoer.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdoing</ent><br/
<hw>Mis*do"ing</hw>, <pos>n.</pos> <def>A wrong done; a fault or crime;
an offense; <as>as, it was my <ex>misdoing</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdoubt</ent><br/
<hw>Mis*doubt"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To be
suspicious of; to have suspicion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I do not <qex>misdoubt</qex> my wife.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdoubt</ent><br/
<hw>Mis*doubt"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Suspicion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Irresolution; hesitation.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdoubtful</ent><br/
<hw>Mis*doubt"ful</hw> <pr>(?)</pr>, <pos>a</pos> <def>Misgiving;
hesitating.</def> <mark>[Obs.]</mark> <ldquo/Her <xex>misdoubtful</xex>
mind.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misdread</ent><br/
<hw>Mis*dread"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dread of
evil.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mise</ent><br/
<hw>Mise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>mise</ets> a
putting, setting, expense, fr. <ets>mis</ets>, <ets>mise</ets>, p. p. of
<ets>mettre</ets> to put, lay, fr. LL. <ets>mittere</ets> to
send.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Law)</fld> <def>The issue in a writ of
right.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expense; cost; disbursement.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A tax or tallage; in Wales, an honorary gift of the
people to a new king or prince of Wales; also, a tribute paid, in the
country palatine of Chester, England, at the change of the owner of the
earldom.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misease</ent><br/
<hw>Mis*ease"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mesaise</ets>, OF. <ets>mesaise</ets>.]</ety> <def>Want of ease;
discomfort; misery.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miseased</ent><br/
<hw>Mis*eased"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having discomfort
or misery; troubled.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miseasy</ent><br/
<hw>Mis*eas"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not easy;
painful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misedition</ent><br/
<hw>Mis`e*di"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An incorrect or
spurious edition.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miseducate</ent><br/
<hw>Mis*ed"u*cate</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
educate in a wrong manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misemploy</ent><br/
<hw>Mis`em*ploy"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To employ
amiss; <as>as, to <ex>misemploy</ex> time, advantages, talents,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their frugal father's gains they <qex>misemploy</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misemployment</ent><br/
<hw>Mis`em*ploy"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong or
mistaken employment.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misenter</ent><br/
<hw>Mis*en"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To enter or
insert wrongly, as a charge in an account.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misentreat</ent><br/
<hw>Mis`en*treat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To treat
wrongfully.</def> <mark>[Obs.]</mark> <rj><au>Grafton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misentry</ent><br/
<hw>Mis*en"try</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An erroneous entry
or charge, as of an account.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miser</ent><br/
<hw>Mi"ser</hw> <pr>(m<imac/"z<etil/r)</pr>, <pos>n.</pos> <ety>[L.
<ets>miser</ets> wretched, miserable; cf. Gr. <grk>mi^sos</grk> hate,
<grk>misei^n</grk> to hate: cf. It. & Sp. <ets>misero</ets> wretched,
avaricious.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A wretched person; a person afflicted by any great
misfortune.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The woeful words of a <qex>miser</qex> now despairing.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A despicable person; a wretch.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A covetous, grasping, mean person; esp., one having
wealth, who lives miserably for the sake of saving and increasing his
hoard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As some lone <qex>miser</qex>, visiting his store,<br/
Bends at his treasure, counts, recounts it o'er.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A stingy person; one very reluctant to spend
money.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>A kind of large earth auger.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miserable</ent><br/
<hw>Mis"er*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>mis<eacute/rable</ets>, L. <ets>miserabilis</ets>, fr.
<ets>miserari</ets> to lament, pity, fr. <ets>miser</ets> wretched. See
<er>Miser</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Very unhappy; wretched; living in misery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What hopes delude thee, <qex>miserable</qex> man?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Causing unhappiness or misery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What 's more <qex>miserable</qex> than discontent?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Worthless; mean; despicable; <as>as, a
<ex>miserable</ex> fellow; a <ex>miserable</ex> dinner.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Miserable</qex> comforters are ye all.</q> <rj><qau>Job xvi.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Avaricious; niggardly; miserly.</def>
<mark>[Obs.]</mark> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Abject; forlorn; pitiable; wretched.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miserable</ent><br/
<hw>Mis"er*a*ble</hw>, <pos>n.</pos> <def>A miserable person.</def>
<mark>[Obs.]</mark> <rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miserableness</ent><br/
<hw>Mis"er*a*ble*ness</hw>, <pos>n.</pos> <def>The state or quality of
being miserable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miserably</ent><br/
<hw>Mis"er*a*bly</hw>, <pos>adv.</pos> <def>In a miserable; unhappily;
calamitously; wretchedly; meanly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They were <qex>miserably</qex> entertained.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The fifth was <qex>miserably</qex> stabbed to death.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miseration</ent><br/
<hw>Mis`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Commiseration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miserere</ent><br/
\'d8<hw>Mis`e*re"re</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., have
mercy, fr. <ets>misereri</ets> to have mercy, fr. <ets>miser</ets>. See
<er>Miser</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(R. C. Ch.)</fld> <def>The psalm usually appointed
for penitential acts, being the 50th psalm in the Latin version. It
commences with the word <xex>miserere</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A musical composition adapted to the 50th
psalm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where only the wind signs <qex>miserere</qex>.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>A small projecting boss or
bracket, on the under side of the hinged seat of a church stall (see
<er>Stall</er>). It was intended, the seat being turned up, to give some
support to a worshiper when standing. Called also
<xex>misericordia</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>Same as <er>Ileus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misericorde</ent><br/
<hw>Mis"er*i*corde"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mis<eacute/ricorde</ets>. See <er>Misericordia</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Compassion; pity; mercy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anc. Armor.)</fld> <def>Same as
<er>Misericordia</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misericordia</ent><br/
\'d8<hw>Mis`e*ri*cor"di*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
mercy, compassion; <ets>miser</ets> wretched + <ets>cor</ets>,
<ets>cordis</ets>, heart.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(O. Law)</fld> <def>An amercement.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anc. Armor.)</fld> <def>A thin-bladed dagger; so
called, in the Middle Ages, because used to give the death wound or
<ldquo/mercy<rdquo/ stroke to a fallen adversary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Eccl.)</fld> <def>An indulgence as to food or dress
granted to a member of a religious order.</def>
<rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 930 --></p>

<p><ent>Miserly</ent><br/
<hw>Mi"ser*ly</hw> <pr>(m<imac/"z<etil/r*l<ycr/)</pr>, <pos>a.</pos>
<ety>[From <er>Miser</er>.]</ety> <def>Like a miser; very covetous;
avaricious; stingy; sordid; niggardly.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Avaricious; niggardly; sordid; parsimonious;
avaricious; penurious; covetous; stingy; mean. See
<er>Avaricious</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misery</ent><br/
<hw>Mi"ser*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Miseries</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>miserie</ets>, L.
<ets>miseria</ets>, fr. <ets>miser</ets> wretched: cf. F.
<ets>mis<egrave/re</ets>, OF. also, <ets>miserie</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Great unhappiness; extreme pain of body or mind;
wretchedness; distress; woe.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Destruction and <qex>misery</qex> are in their ways.</q>
<rj><qau>Rom. iii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cause of misery; calamity; misfortune.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When we our betters see bearing our woes,<br/
We scarcely think our <qex>miseries</qex> our foes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Covetousness; niggardliness; avarice.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Wretchedness; torture; agony; torment; anguish;
distress; calamity; misfortune.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misesteem</ent><br/
<hw>Mis`es*teem"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>m<eacute/sestime</ets>.]</ety> <def>Want of esteem;
disrespect.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misestimate</ent><br/
<hw>Mis*es"ti*mate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To estimate
erroneously.</def> <rj><au>J. S. Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misexplanation</ent><br/
<hw>Mis*ex`pla*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An
erroneous explanation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misexplication</ent><br/
<hw>Mis*ex`pli*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
explication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misexposition</ent><br/
<hw>Mis*ex`po*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
exposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misexpound</ent><br/
<hw>Mis`ex*pound"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To expound
erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misexpression</ent><br/
<hw>Mis`ex*pres"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfaith</ent><br/
<hw>Mis*faith"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of faith;
distrust.</def> <ldquo/[Anger] born of your <xex>misfaith</xex>.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfall</ent><br/
<hw>Mis*fall"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Misfell</conjf>; <pos>p. p.</pos>
<conjf>Misfallen</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Misfalling</conjf>.]</vmorph> <def>To befall, as ill luck; to
happen to unluckily.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfare</ent><br/
<hw>Mis*fare"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>misfaran</ets>.]</ety> <def>To fare ill.</def> <mark>[Obs.]</mark>
-- <def2><pos>n.</pos> <def>Misfortune.</def></def2> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfashion</ent><br/
<hw>Mis*fash"ion</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To form
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfeasance</ent><br/
<hw>Mis*fea"sance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. pref.
<ets>mes-</ets> wrong (L. <ets>minus</ets> less) + <ets>faisance</ets>
doing, fr. <ets>faire</ets> to do, L. <ets>facere</ets>. Cf.
<er>Malfeasance</er>.]</ety> <fld>(Law)</fld> <def>A trespass; a wrong
arising from an overt act; the improper doing of an act which a person
might lawfully do.</def> <rj><au>Bouvier.</au>
<au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfeature</ent><br/
<hw>Mis*fea"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ill
feature.</def> <mark>[R.]</mark> <rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfeeling</ent><br/
<hw>Mis*feel"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Insensate.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfeign</ent><br/
<hw>Mis*feign"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To feign with an
evil design.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfit</ent><br/
<hw>Mis*fit"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or the state of fitting badly; <as>as, a <ex>misfit</ex> in making a
coat; a ludicrous <ex>misfit</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something that fits badly, as a garment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw an uneasy change in Mr. Micawber, which sat tightly on him,
as if his new duties were a <qex>misfit</qex>.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person who does not fit in comfortably with the
surrounding situation or society; one who cannot conform or adjust to
the circumstances in which he lives.</def><br/
[<source>PJC</source>]</p>

<p><ent>Misform</ent><br/
<hw>Mis*form"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Misformed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misforming</conjf>.]</vmorph> <def>To make in an ill
form.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misformation</ent><br/
<hw>Mis`for*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Malformation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfortunate</ent><br/
<hw>Mis*for"tu*nate</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Producing
misfortune.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfortune</ent><br/
<hw>Mis*for"tune</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Bad fortune or
luck; calamity; an evil accident; disaster; mishap; mischance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Consider why the change was wrought,<br/
You 'll find his <qex>misfortune</qex>, not his fault.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Calamity; mishap; mischance; misadventure; ill;
harm; disaster. See <er>Calamity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfortune</ent><br/
<hw>Mis*for"tune</hw>, <pos>v. i.</pos> <def>To happen unluckily or
unfortunately; to miscarry; to fail.</def> <mark>[Obs.]</mark>
<rj><au>Stow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misfortuned</ent><br/
<hw>Mis*for"tuned</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Unfortunate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misframe</ent><br/
<hw>Mis*frame"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To frame
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misget</ent><br/
<hw>Mis*get"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To get
wrongfully.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgie</ent><br/
<hw>Mis*gie"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Misgye</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgive</ent><br/
<hw>Mis*give"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Misgave</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Misgiven</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misgiving</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To give or grant amiss.</def> <mark>[Obs.]</mark>
<rj><au>Laud.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically: To give doubt and apprehension to,
instead of confidence and courage; to impart fear to; to make
irresolute; -- usually said of the mind or heart, and followed by the
objective personal pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So doth my heart <qex>misgive</qex> me in these conflicts<br/
What may befall him, to his harm and ours.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such whose consciences <qex>misgave</qex> them, how ill they had
deserved.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To suspect; to dread.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgive</ent><br/
<hw>Mis*give"</hw>, <pos>v. i.</pos> <def>To give out doubt and
apprehension; to be fearful or irresolute.</def> <ldquo/My mind
<xex>misgives</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>misgiving</ent><br/
<hw>mis*giv"ing</hw>, <pos>n.</pos> <def>Evil premonition; doubt;
distrust; a feeling of apprehension; -- used commonly in the
plural.</def> <ldquo/Suspicious and <xex>misgivings</xex>.<rdquo/
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgo</ent><br/
<hw>Mis*go"</hw> <pr>(m<icr/s*g<omac/")</pr>, <pos>v. i.</pos> <def>To
go astray.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgotten</ent><br/
<hw>Mis*got"ten</hw> <pr>(m<icr/s*g<ocr/t"t'n)</pr>, <pos>a.</pos>
<def>Unjustly gotten.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgovern</ent><br/
<hw>Mis*gov"ern</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To govern
badly; <as>as, to <ex>misgovern</ex> a country</as>.</def>
<rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgovernance</ent><br/
<hw>Mis*gov"ern*ance</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Misgovernment; misconduct; misbehavior.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer. Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgoverned</ent><br/
<hw>Mis*gov"erned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ill governed, as
a people; ill directed.</def> <ldquo/Rude, <xex>misgoverned</xex>
hands.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgovernment</ent><br/
<hw>Mis*gov"ern*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Bad
government; want of government.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgracious</ent><br/
<hw>Mis*gra"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
gracious.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgraff</ent><br/
<hw>Mis*graff"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
misgraft.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgraft</ent><br/
<hw>Mis*graft"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To graft
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misground</ent><br/
<hw>Mis*ground"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To found
erroneously.</def> <ldquo/<xex>Misgrounded</xex> conceit.<rdquo/
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgrowth</ent><br/
<hw>Mis*growth"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Bad growth; an
unnatural or abnormal growth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misguess</ent><br/
<hw>Mis*guess"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To guess
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misguidance</ent><br/
<hw>Mis*guid"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
guidance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misguide</ent><br/
<hw>Mis*guide"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To guide
wrongly; to lead astray; <as>as, to <ex>misguide</ex> the
understanding</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misguide</ent><br/
<hw>Mis*guide"</hw>, <pos>n.</pos> <def>Misguidance; error.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misguiding</ent><br/
<hw>Mis*guid"ing</hw>, <pos>a.</pos> <def>Misleading.</def> --
<wordforms><wf>Mis*guid"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misgye</ent><br/
<hw>Mis*gye"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To misguide.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishandle</ent><br/
<hw>Mis*han"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To handle ill
or wrongly; to maltreat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishap</ent><br/
<hw>Mis*hap"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Evil accident; ill
luck; misfortune; mischance.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Secure from worldly chances and <qex>mishaps</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishap</ent><br/
<hw>Mis*hap"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To happen
unluckily; -- used impersonally.</def> <mark>[Obs.]</mark> <ldquo/If
that me <xex>mishap</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishappen</ent><br/
<hw>Mis*hap"pen</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To happen ill
or unluckily.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishappy</ent><br/
<hw>Mis*hap"py</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unhappy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishcup</ent><br/
<hw>Mish*cup"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Scup</er>.]</ety> <fld>(Zool.)</fld> <def>The scup.</def>
<mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishear</ent><br/
<hw>Mis*hear"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To hear
incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishmash</ent><br/
<hw>Mish"mash`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>mish-mash</ets>, fr. <ets>mischen</ets> to mix.]</ety> <def>A
hodgepodge or hotchpotch; a confused jumble.</def> <altsp>[Also spelled
<asp>mishmosh</asp>.]</altsp> <rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mishna</ent><br/
<hw>Mish"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NHeb.
<ets>mishn<amac/h</ets>, i. e., repetition, doubling, explanation (of
the divine law), fr. Heb. <ets>sh<amac/n<amac/h</ets> to change, to
repeat.]</ety> <def>A collection or digest of Jewish traditions and
explanations of Scripture, forming the text of the Talmud.</def>
<altsp>[Written also <asp>Mischna</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mishnic</ent><br/
<hw>Mish"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the Mishna.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misimagination</ent><br/
<hw>Mis`im*ag`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
imagination; delusion.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misimprove</ent><br/
<hw>Mis`im*prove"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To use for a
bad purpose; to abuse; to misuse; <as>as, to <ex>misimprove</ex> time,
talents, advantages, etc.</as></def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misimprovement</ent><br/
<hw>Mis`im*prove"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ill use or
employment; use for a bad purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misincline</ent><br/
<hw>Mis"in*cline"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause to
have a wrong inclination or tendency; to affect wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinfer</ent><br/
<hw>Mis`in*fer"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To infer
incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinform</ent><br/
<hw>Mis`in*form"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give untrue
information to; to inform wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinform</ent><br/
<hw>Mis`in*form"</hw>, <pos>v. i.</pos> <def>To give untrue information;
(with <xex>against</xex>) to calumniate.</def> <mark>[R.]</mark>
<rj><au>Bp. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinformant</ent><br/
<hw>Mis`in*form"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
misinformer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinformation</ent><br/
<hw>Mis*in`for*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Untrue or
incorrect information.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinformer</ent><br/
<hw>Mis`in*form"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who gives
untrue or incorrect information.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinstruct</ent><br/
<hw>Mis`in*struct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To instruct
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinstruction</ent><br/
<hw>Mis`in*struc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong or
improper instruction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misintelligence</ent><br/
<hw>Mis`in*tel"li*gence</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Wrong information; misinformation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disagreement; misunderstanding.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misintend</ent><br/
<hw>Mis`in*tend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To aim
amiss.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinterpret</ent><br/
<hw>Mis`in*ter"pret</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
interpret erroneously; to understand or to explain in a wrong
sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinterpretable</ent><br/
<hw>Mis`in*ter"pret*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable
of being misinterpreted; liable to be misunderstood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinterpretation</ent><br/
<hw>Mis`in*ter"pre*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of interpreting erroneously; a mistaken interpretation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misinterpreter</ent><br/
<hw>Mis`in*ter"pret*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
interprets erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misjoin</ent><br/
<hw>Mis*join"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To join unfitly
or improperly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misjoinder</ent><br/
<hw>Mis*join"der</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>An incorrect union of parties or of causes of action in a
procedure, criminal or civil.</def> <rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misjudge</ent><br/
<hw>Mis*judge"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To judge
erroneously or unjustly; to err in judgment; to misconstrue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misjudgment</ent><br/
<hw>Mis*judg"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>misjudgement</ets>.]</ety> <def>A wrong or unjust
judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miskeep</ent><br/
<hw>Mis*keep"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To keep
wrongly.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misken</ent><br/
<hw>Mis*ken"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Not to know.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miskin</ent><br/
<hw>Mis"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. for <ets>music
+ -kin</ets>.]</ety> <fld>(Mus.)</fld> <def>A little bagpipe.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miskindle</ent><br/
<hw>Mis*kin"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To kindle
amiss; to inflame to a bad purpose; to excite wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misknow</ent><br/
<hw>Mis*know"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To have a
mistaken notion of or about.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislactation</ent><br/
<hw>Mis`lac*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Defective flow or vitiated condition of the milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislay</ent><br/
<hw>Mis*lay"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mislaid</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mislaying</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To lay in a wrong place; to ascribe to a wrong
source.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fault is generally <qex>mislaid</qex> upon nature.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay in a place not recollected; to misplace; to
lose.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The . . . charter, indeed, was unfortunately <qex>mislaid</qex>:
and the prayer of their petition was to obtain one of like import in its
stead.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislayer</ent><br/
<hw>Mis*lay"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mislays.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misle</ent><br/
<hw>Mi"sle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Misled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Misling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Prop.
<ets>mistle</ets>, fr. <ets>mist</ets>. Cf. <er>Mistle</er>,
<er>Mizzle</er>.]</ety> <def>To rain in very fine drops, like a thick
mist; to mizzle; to drizzle.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Misle</ent><br/
<hw>Mi"sle</hw>, <pos>n.</pos> <def>A fine rain; a thick mist; a mizzle;
a drizzle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislead</ent><br/
<hw>Mis*lead"</hw> <pr>(m<icr/s*l<emac/d")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Misled</conjf>
<pr>(m<icr/s*l<ecr/d")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Misleading</conjf>.]</vmorph> <ety>[AS.
<ets>misl<aemac/dan</ets>. See <er>Mis-</er>, and <er>Lead</er> to
conduct.]</ety> <def>To lead into a wrong way or path; to lead astray;
to guide into error; to cause to mistake; to deceive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Trust not servants who <qex>mislead</qex> or misinform you.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To give due light<br/
To the <qex>mislead</qex> and lonely traveler.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To delude; deceive. See
<er>Deceive</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misleader</ent><br/
<hw>Mis*lead"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who leads into
error.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misleading</ent><br/
<hw>Mis*lead"ing</hw>, <pos>a.</pos> <def>Leading astray;
delusive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislearn</ent><br/
<hw>Mis*learn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To learn
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misled</ent><br/
<hw>Mis*led"</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Mislead</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislen</ent><br/
<hw>Mis"len</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Maslin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misletoe</ent><br/
<hw>Mis"le*toe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mistletoe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislight</ent><br/
<hw>Mis*light"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deceive or
lead astray with a false light.</def> <rj><au>Herrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislike</ent><br/
<hw>Mis*like"</hw> <pr>(m<icr/s*l<imac/k")</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Misliked</conjf>
<pr>(m<icr/s*l<imac/kt")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Misliking</conjf>.]</vmorph> <ety>[AS. <ets>misl<imac/cian</ets>
to displease. See <er>Like</er>, <pos>v.</pos>]</ety> <def>To dislike;
to disapprove of; to have aversion to; <as>as, to <ex>mislike</ex> a
man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who may like or <qex>mislike</qex> what he says.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislike</ent><br/
<hw>Mis*like"</hw>, <pos>n.</pos> <def>Dislike; disapprobation;
aversion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misliker</ent><br/
<hw>Mis*lik"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dislikes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misliking</ent><br/
<hw>Mis*lik"ing</hw>, <pos>n.</pos> <def>Dislike; aversion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislin</ent><br/
<hw>Mis"lin</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>See
<er>Maslin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislive</ent><br/
<hw>Mis*live"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To live
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mislodge</ent><br/
<hw>Mis*lodge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To lodge
amiss.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misluck</ent><br/
<hw>Mis*luck"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ill luck;
misfortune.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misly</ent><br/
<hw>Mis"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Raining in very small
drops; drizzling.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mismake</ent><br/
<hw>Mis*make"</hw> <pr>(m<icr/s*m<amac/k")</pr>, <pos>v. t.</pos>
<def>To make or form amiss; to spoil in making.</def> <ldquo/Limping
possibilities of <xex>mismade</xex> human nature.<rdquo/ <rj><au>Mrs.
Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismanage</ent><br/
<hw>Mis*man"age</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To manage
ill or improperly; <as>as, to <ex>mismanage</ex> public
affairs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismanagement</ent><br/
<hw>Mis*man"age*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong or bad
management; <as>as, he failed through
<ex>mismagement</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismanager</ent><br/
<hw>Mis*man"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who manages
ill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismark</ent><br/
<hw>Mis*mark"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To mark
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismatch</ent><br/
<hw>Mis*match"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To match
unsuitably.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mismatched</ent><br/
<hw>mis*matched"</hw> <pos>adj.</pos> <sn>1.</sn> <def>Matched
unsuitably; grouped into pairs or sets with incompatible
characteristics.</def> [Narrower terms: <stype>ill-sorted, incompatible,
mismated, unsuited</stype>; <stype>odd, unmatched, unmated, unpaired
</stype>] <see>Also See: <er>incompatible</er>.</see> Antonym:
<ant>matched</ant>.<br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Of very unequal ability; -- of contestants in a
contest. The less able contestant is said to be
<contr>overmatched</contr> or <contr>outclassed</contr>.</def><br/
<syn><b>Syn. --</b> uneven, not fairly matched.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mismate</ent><br/
<hw>Mis*mate"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To mate wrongly
or unsuitably; to mismatch; <as>as, to <ex>mismate</ex> gloves or shoes;
a <ex>mismated</ex> couple.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismeasure</ent><br/
<hw>Mis*meas"ure</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
measure or estimate incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismeasurement</ent><br/
<hw>Mis*meas"ure*ment</hw>, <pos>n.</pos> <def>Wrong
measurement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mismeter</ent><br/
<hw>Mis*me"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give the
wrong meter to, as to a line of verse.</def> <mark>[R.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misname</ent><br/
<hw>Mis*name"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To call by the
wrong name; to give a wrong or inappropriate name to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misnomer</ent><br/
<hw>Mis*no"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. pref.
<ets>mes-</ets> amiss, wrong (L. <ets>minus</ets> less) + F.
<ets>nommer</ets> to name, L. <ets>nominare</ets>, fr. <ets>nomen</ets>
name. See <er>Name</er>.]</ety> <def>The misnaming of a person in a
legal instrument, as in a complaint or indictment; any misnaming of a
person or thing; a wrong or inapplicable name or title.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many of the changes, by a great <qex>misnomer</qex>, called
parliamentary <ldquo/reforms<rdquo/.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The word <ldquo/synonym<rdquo/ is fact a <qex>misnomer</qex>.</q>
<rj><qau>Whately.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misnomer</ent><br/
<hw>Mis*no"mer</hw>, <pos>v. t.</pos> <def>To misname.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misnumber</ent><br/
<hw>Mis*num"ber</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To number
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misnurture</ent><br/
<hw>Mis*nur"ture</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
nurture or train wrongly; <as>as, to <ex>misnurture</ex>
children</as>.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misobedience</ent><br/
<hw>Mis`o*be"di*ence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mistaken
obedience; disobedience.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misobserve</ent><br/
<hw>Mis`ob*serve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To observe
inaccurately; to mistake in observing.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misobserver</ent><br/
<hw>Mis`ob*serv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
misobserves; one who fails to observe properly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misogamist</ent><br/
<hw>Mi*sog"a*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>misei^n</grk> to hate + <?/ marriage.]</ety> <def>A hater of
marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misogamy</ent><br/
<hw>Mi*sog"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>misogamie</ets>.]</ety> <def>Hatred of marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>misogynic</ent><br/
<hw>misogynic</hw> <pos>adj.</pos> <def>misogynous.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>misogynism</ent><br/
<hw>misogynism</hw> <pos>n.</pos> <def>misogyny.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Misogynist</ent><br/
<hw>Mi*sog"y*nist</hw> <pr>(m<icr/*s<ocr/j"<icr/*n<icr/st)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>misogy`nhs</grk>, <grk>misogy`naios</grk>;
<grk>misei^n</grk> to hate + <grk>gynh`</grk> woman: cf. F.
<ets>misogyne</ets>.]</ety> <def>A woman hater. Contrast
<contr>misandrist</contr>.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Misogynous</ent><br/
<hw>Mi*sog"y*nous</hw> <pr>(m<icr/*s<ocr/j"<icr/*n<ucr/s)</pr>,
<pos>a.</pos> <def>Hating women; having deep-seated distrust of women;
-- used of men.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Misogyny</ent><br/
<hw>Mi*sog"y*ny</hw> <pr>(m<icr/*s<ocr/j"<icr/*n<ycr/; 277)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>misogyni`a</grk>: cf. F.
<ets>misogynie</ets>.]</ety> <def>Hatred of women. Contrast
<contr>misandry</contr>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misology</ent><br/
<hw>Mi*sol"o*gy</hw> <pr>(m<icr/*s<ocr/l"<osl/*j<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>misologi`a</grk>; <grk>misei^n</grk> to
hate + <grk>lo`gos</grk> discourse.]</ety> <def>Hatred of argument or
discussion; hatred of enlightenment.</def> <rj><au>G. H.
Lewes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misopinion</ent><br/
<hw>Mis`o*pin"ion</hw>, <pos>n.</pos> <def>Wrong opinion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misorder</ent><br/
<hw>Mis*or"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To order ill; to
manage erroneously; to conduct badly.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misorder</ent><br/
<hw>Mis*or"der</hw>, <pos>n.</pos> <def>Irregularity; disorder.</def>
<mark>[Obs.]</mark> <rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misorderly</ent><br/
<hw>Mis*or"der*ly</hw>, <pos>a.</pos> <def>Irregular; disorderly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misordination</ent><br/
<hw>Mis*or`di*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
ordination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misotheism</ent><br/
<hw>Mis"o*the`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>misei^n</grk> to hate + <grk>qeo`s</grk> god.]</ety> <def>Hatred of
God.</def> <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispaint</ent><br/
<hw>Mis*paint"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To paint ill, or
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispassion</ent><br/
<hw>Mis*pas"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong passion or
feeling.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispay</ent><br/
<hw>Mis*pay"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Appay</er>.]</ety> <def>To dissatisfy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispend</ent><br/
<ent>Mispell</ent><br/
<mhw><hw>Mis*pell"</hw> <pr>(?)</pr>, <pos>v. t.</pos>,
<hw>Mis*pend"</hw> <pr>(<?/)</pr>, <pos>v. t.</pos>, etc.</mhw> <def>See
<er>Misspell</er>, <er>Misspend</er>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispense</ent><br/
<hw>Mis*pense"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Misspense</er>.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misperception</ent><br/
<hw>Mis`per*cep"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
perception.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispersuade</ent><br/
<hw>Mis`per*suade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To persuade
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispersuasion</ent><br/
<hw>Mis`per*sua"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A false
persuasion; wrong notion or opinion.</def> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispickel</ent><br/
<hw>Mis*pick"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.]</ety>
<fld>(Min.)</fld> <def>Arsenical iron pyrites; arsenopyrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misplace</ent><br/
<hw>Mis*place"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Misplaced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misplacing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To put in a wrong place; to set or place on an improper or unworthy
object; <as>as, he <ex>misplaced</ex> his confidence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place in a location that one does not recall; to
mislay; to lose.</def><br/
[<source>PJC</source>]</p>

<p><ent>Misplacement</ent><br/
<hw>Mis*place"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
misplacing, or the state of being misplaced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misplead</ent><br/
<hw>Mis*plead"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To err in
pleading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispleading</ent><br/
<hw>Mis*plead"ing</hw>, <pos>n.</pos> <fld>(Law)</fld> <def>An error in
pleading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispoint</ent><br/
<hw>Mis*point"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To point
improperly; to punctuate wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispolicy</ent><br/
<hw>Mis*pol"i*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong policy;
impolicy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispractice</ent><br/
<hw>Mis*prac"tice</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
practice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispraise</ent><br/
<hw>Mis*praise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To praise
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misprint</ent><br/
<hw>Mis*print"</hw> <pr>(m<icr/s*pr<icr/nt")</pr>, <pos>v. t.</pos>
<def>To print wrongly; to make a mistake in printing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>misprint</ent><br/
<hw>mis"print</hw> <pr>(m<icr/s"pr<icr/nt)</pr>, <pos>n.</pos> <def>A
mistake in printing; a deviation from the copy; <as>as, a book full of
<ex>misprints</ex></as>. Misprints are sometimes noted and corrected in
a list of <partof>corrigenda</partof> distributed with a book.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Misprise</ent><br/
<hw>Mis*prise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Misprize</er>.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misprise</ent><br/
<hw>Mis*prise"</hw>, <pos>v. t.</pos> <ety>[OF. <ets>mesprise</ets>
mistake, F. <ets>m<eacute/prise</ets>, fr. <ets>mespris</ets>, masc.,
<ets>mesprise</ets>, fem., p. p. of <ets>mesprendre</ets> to mistake; F.
<ets>m<eacute/prendre</ets>; pref. <ets>mes-</ets> amiss +
<ets>prendre</ets> to take, L. <ets>prehendere</ets>.]</ety> <def>To
mistake.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misprision</ent><br/
<hw>Mis*pri"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>misprisio</ets>, or OF. <ets>mesprison</ets>, prop., a mistaking,
but confused with OF. <ets>mespris</ets> contempt, F.
<ets>m<eacute/pris</ets>. See 2d <er>Misprise</er>, <er>Misprize</er>,
<er>Prison</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of misprising; misapprehension;
misconception; mistake.</def> <mark>[Archaic]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>misprision</qex> of this passage has aided in fostering
the delusive notion.</q> <rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Neglect; undervaluing; contempt.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A neglect, negligence, or
contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In its larger and older sense it was used to signify
<ldquo/every considerable misdemeanor which has not a certain name given
to it in the law.<rdquo/ <rj><au>Russell.</au></rj><br/
<br/
In a more modern sense it is applied exclusively to two offenses: --<br/
<b>1.</b> <col><b>Misprision of treason</b></col>, which is omission to
notify the authorities of an act of treason by a person cognizant
thereof. <au>Stephen.</au><br/
<b>2.</b> <col><b>Misprision of felony</b></col>, which is a concealment
of a felony by a person cognizant thereof.
<rj><au>Stephen.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 931 --></p>

<p><ent>Misprize</ent><br/
<hw>Mis*prize"</hw> <pr>(m<icr/s*pr<imac/z")</pr>, <pos>v. t.</pos>
<ety>[OF. <ets>mesprisier</ets> to deprise, F.
<ets>m<eacute/priser</ets>; pref. amiss, wrong (L. <ets>minus</ets> less
+ LL. <ets>pretium</ets> price. See <er>price</er>, <er>Prize</er>,
<pos>v.</pos>]</ety> <def>To slight or undervalue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, for those vanished hours, so much <qex>misprized</qex>!</q>
<rj><qau>Hillhouse.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I do not blame them, madam, nor <qex>misprize</qex>.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misproceeding</ent><br/
<hw>Mis`pro*ceed"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong or
irregular proceding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misprofess</ent><br/
<hw>Mis`pro*fess"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To make a
false profession; to make pretensions to skill which is not
possessed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misprofess</ent><br/
<hw>Mis`pro*fess"</hw>, <pos>v. t.</pos> <def>To make a false profession
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispronounce</ent><br/
<hw>Mis`pro*nounce"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Mispronounced</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Mispronouncing</conjf>
<pr>(?)</pr>.]</vmorph> <def>To pronounce incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispronunciation</ent><br/
<hw>Mis`pro*nun`ci*a"tion</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<def>Wrong or improper pronunciation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misproportion</ent><br/
<hw>Mis`pro*por"tion</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give
wrong or unesthetic proportions to; to join without due proportion;
<as>as, the legs were <ex>misrpoportioned</ex> to the
body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>misproportion</ent><br/
<hw>mis`pro*por"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An improper
or unesthetic proportion.</def><br/
[<source>PJC</source>]</p>

<p><ent>Misproud</ent><br/
<hw>Mis*proud"</hw>, <pos>a.</pos> <def>Viciously proud.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mispunctuate</ent><br/
<hw>Mis*punc"tu*ate</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
punctuate wrongly or incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misquotation</ent><br/
<hw>Mis`quo*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous or
inaccurate quotation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misquote</ent><br/
<hw>Mis*quote"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To quote
erroneously or incorrectly.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misraise</ent><br/
<hw>Mis*raise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To raise or
excite unreasonable.</def> <ldquo/<xex>Misraised</xex> fury.<rdquo/
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrate</ent><br/
<hw>Mis*rate"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To rate
erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misread</ent><br/
<hw>Mis*read"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Misread</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misreading</conjf> <pr>(?)</pr>.]</vmorph> <def>To read
amiss; to misunderstand in reading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreceive</ent><br/
<hw>Mis`re*ceive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To receive
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrecital</ent><br/
<hw>Mis`re*cit"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An inaccurate
recital.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrecite</ent><br/
<hw>Mis`re*cite"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To recite
erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreckon</ent><br/
<hw>Mis*reck"on</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To reckon
wrongly; to miscalculate.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreckoning</ent><br/
<hw>Mis*reck"on*ing</hw>, <pos>n.</pos> <def>An erroneous
computation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrecollect</ent><br/
<hw>Mis*rec`ol*lect"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
have an erroneous remembrance of; to suppose erroneously that one
recollects.</def> <rj><au>Hitchcock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrecollection</ent><br/
<hw>Mis*rec`ol*lec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
or inaccurate recollection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreform</ent><br/
<hw>Mis`re*form"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To reform
wrongly or imperfectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misregard</ent><br/
<hw>Mis`re*gard"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
understanding; misconstruction.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misregulate</ent><br/
<hw>Mis*reg"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To regulate
wrongly or imperfectly; to fail to regulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrehearse</ent><br/
<hw>Mis`re*hearse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To rehearse
or quote incorrectly.</def> <rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrelate</ent><br/
<hw>Mis`re*late"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To relate
inaccurately.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrelation</ent><br/
<hw>Mis`re*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
relation or narration.</def> <rj><au>Abp. Bramhall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreligion</ent><br/
<hw>Mis`re*li"gion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>False
religion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misremember</ent><br/
<hw>Mis`re*mem"ber</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
mistake in remembering; not to remember correctly.</def> <rj><au>Sir T.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrender</ent><br/
<hw>Mis*ren"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
wrongly; to translate or recite wrongly.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepeat</ent><br/
<hw>Mis`re*peat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To repeat
wrongly; to give a wrong version of.</def> <rj><au>Gov.
Winthrop.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreport</ent><br/
<hw>Mis`re*port"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To report
erroneously; to give an incorrect account of.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misreport</ent><br/
<hw>Mis`re*port"</hw>, <pos>n.</pos> <def>An erroneous report; a false
or incorrect account given.</def> <rj><au>Denham. South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepresent</ent><br/
<hw>Mis*rep`re*sent"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
represent incorrectly (almost always, unfavorably); to give a false or
erroneous representation of, either maliciously, ignorantly, or
carelessly.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepresent</ent><br/
<hw>Mis*rep`re*sent"</hw>, <pos>v. i.</pos> <def>To make an incorrect or
untrue representation.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepresentation</ent><br/
<hw>Mis*rep`re*sen*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Untrue
representation; false or incorrect statement or account; -- usually
unfavorable to the thing represented; <as>as, a
<ex>misrepresentation</ex> of a person's motives</as>.</def>
<rj><au>Sydney Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In popular use, this word often conveys the idea of
intentional untruth.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepresentative</ent><br/
<hw>Mis*rep`re*sent"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending
to convey a wrong impression; misrepresenting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepresenter</ent><br/
<hw>Mis*rep`re*sent"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
misrepresents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrepute</ent><br/
<hw>Mis`re*pute"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To have in
wrong estimation; to repute or estimate erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrule</ent><br/
<hw>Mis*rule"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To rule
badly; to misgovern.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misrule</ent><br/
<hw>Mis*rule"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act, or the
result, of misruling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disorder; confusion; tumult from
insubordination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Enormous riot and <qex>misrule</qex> surveyed.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Abbot of Misrule</b></col>, <it>or</it>
<col><b>Lord of Misrule</b></col></mcol>. <cd>See under <er>Abbot</er>,
and <er>Lord</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misruly</ent><br/
<hw>Mis*rul"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unruly.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miss</ent><br/
<hw>Miss</hw> <pr>(m<icr/s)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Misses</plw> <pr>(m<icr/s"s<ecr/z)</pr>.</plu> <ety>[Contr. fr.
<ets>mistress</ets>.]</ety> <sn>1.</sn> <def>A title of courtesy
prefixed to the name of a girl or a woman who has not been married. See
<er>Mistress</er>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There is diversity of usage in the application of this
title to two or more persons of the same name. We may write either
<xex>the Miss Browns</xex> or <xex>the Misses Brown</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A young unmarried woman or a girl; <as>as, she is a
<ex>miss</ex> of sixteen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gay vanity, with smiles and kisses,<br/
Was busy 'mongst the maids and misses.</q>
<rj><qau>Cawthorn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kept mistress. See <er>Mistress</er>, 4.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Card Playing)</fld> <def>In the game of three-card
loo, an extra hand, dealt on the table, which may be substituted for the
hand dealt to a player.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miss</ent><br/
<hw>Miss</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Missed</conjf> <pr>(m<icr/st)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Missing</conjf>.]</vmorph> <ety>[AS. <ets>missan</ets>; akin to
D. & G. <ets>missen</ets>, OHG. <ets>missan</ets>, Icel.
<ets>missa</ets>, Sw. <ets>mista</ets>, Dan. <ets>miste</ets>.
<root/100. See <er>Mis-</er>, pref.]</ety> <sn>1.</sn> <def>To fail of
hitting, reaching, getting, finding, seeing, hearing, etc.; <as>as, to
<ex>miss</ex> the mark one shoots at; to <ex>miss</ex> the train by
being late; to <ex>miss</ex> opportunites of getting knowledge; to
<ex>miss</ex> the point or meaning of something said.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a man <qex>misses</qex> his great end, happiness, he will
acknowledge he judged not right.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To omit; to fail to have or to do; to get without;
to dispense with; -- now seldom applied to persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She would never <qex>miss</qex>, one day,<br/
A walk so fine, a sight so gay.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We cannot <qex>miss</qex> him; he does make our fire,<br/
Fetch in our wood.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To discover the absence or omission of; to feel the
want of; to mourn the loss of; to want; <as>as, to <ex>miss</ex> an
absent loved one</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither <qex>missed</qex> we anything . . . Nothing was
<qex>missed</qex> of all that pertained unto him.</q> <rj><qau>1 Sam.
xxv. 15, 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What by me thou hast lost, thou least shalt <qex>miss</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To miss stays</b></col>. <fld>(Naut.)</fld> <cd>See under
<er>Stay</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miss</ent><br/
<hw>Miss</hw> <pr>(m<icr/s)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
fail to hit; to fly wide; to deviate from the true direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men observe when things hit, and not when they
<qex>miss</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Flying bullets now,<br/
To execute his rage, appear too slow;<br/
They <qex>miss</qex>, or sweep but common souls away.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fail to obtain, learn, or find; -- with
<xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon the least reflection, we can not <qex>miss</qex> of them.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To go wrong; to err.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Amongst the angels, a whole legion<br/
Of wicked sprites did fall from happy bliss;<br/
What wonder then if one, of women all, did <qex>miss</qex>?</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be absent, deficient, or wanting.</def>
<mark>[Obs.]</mark> <see>See <er>Missing</er>, <pos>a.</pos></see><br/
[<source>1913 Webster</source>]</p>

<p><q>What here shall <qex>miss</qex>, our toil shall strive to
mend.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miss</ent><br/
<hw>Miss</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of missing;
failure to hit, reach, find, obtain, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Loss; want; felt absence.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There will be no great <qex>miss</qex> of those which are
lost.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Mistake; error; fault.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He did without any great <qex>miss</qex> in the hardest points of
grammar.</q> <rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Harm from mistake.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missa</ent><br/
\'d8<hw>Mis"sa</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Missae</plw> <pr>(#)</pr>.</plu> <ety>[LL. See 1st
<er>Mass</er>.]</ety> <fld>(R. C. Ch.)</fld> <def>The service or
sacrifice of the Mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missal</ent><br/
<hw>Mis"sal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>missale</ets>, liber <ets>missalis</ets>, from <ets>missa</ets>
mass: cf. F. <ets>missel</ets>. See 1st <er>Mass</er>.]</ety> <def>The
book containing the service of the Mass for the entire year; a Mass
book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missal</ent><br/
<hw>Mis"sal</hw>, <pos>a.</pos> <def>Of or pertaining to the Mass, or to
a missal or Mass book.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missay</ent><br/
<hw>Mis*say"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To say
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To speak evil of; to slander.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missay</ent><br/
<hw>Mis*say"</hw>, <pos>v. i.</pos> <def>To speak ill.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misseek</ent><br/
<hw>Mis*seek"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To seek for
wrongly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misseem</ent><br/
<hw>Mis*seem"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
make a false appearance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To misbecome; to be misbecoming.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missel</ent><br/
<hw>Mis"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mistletoe.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Missel bird</b></col>, <col><b>Missel
thrush</b></col></mcol> <fld>(Zool.)</fld>, <cd>a large European thrush
(<spn>Turdus viscivorus</spn>) which feeds on the berries of the
mistletoe; -- called also <altname>mistletoe thrush</altname> and
<altname>missel</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misseldine</ent><br/
<hw>Mis"sel*dine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mistletoe</er>.]</ety> <altsp>[Written also
<asp>misselden</asp>.]</altsp> <def>The mistletoe.</def>
<mark>[Obs.]</mark> <rj><au>Baret.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misseltoe</ent><br/
<hw>Mis"sel*toe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mistletoe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missemblance</ent><br/
<hw>Mis*sem"blance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>False
resemblance or semblance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missend</ent><br/
<hw>Mis*send"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To send amiss or
incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misserve</ent><br/
<hw>Mis*serve"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To serve
unfaithfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misset</ent><br/
<hw>Mis*set"</hw> <pr>(m<icr/s*s<ecr/t")</pr>, <pos>v. t.</pos> <def>To
set or place wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misshape</ent><br/
<hw>Mis*shape"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To shape ill; to
give an ill or unnatural from to; to deform.</def> <ldquo/Figures
monstrous and <xex>misshaped</xex>.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misshapen</ent><br/
<hw>Mis*shap"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a bad or
ugly form.</def> <ldquo/The mountains are <xex>misshapen</xex>.<rdquo/
<rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mis*shap"en*ly</wf>, <pos>adv.</pos> --
<wf>Mis*shap"en*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missheathed</ent><br/
<hw>Mis*sheathed"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sheathed by
mistake; wrongly sheathed; sheathed in a wrong place.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missificate</ent><br/
<hw>Mis*sif"i*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[LL.
<ets>missa</ets> Mass + <ets>-ficare</ets> (in comp.) to make. See
<er>fy-</er>.]</ety> <def>To perform Mass.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missile</ent><br/
<hw>Mis"sile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>missils</ets>, fr. <ets>mittere</ets>, <ets>missum</ets>, to cause
to go, to send, to throw; cf. Lith. <ets>mesti</ets> to throw: cf. F.
<ets>missile</ets>. Cf. <er>Admit</er>, <er>Dismiss</er>, <er>Mass</er>
the religious service, <er>Message</er>, <er>Mission</er>.]</ety>
<def>Capable of being thrown; adapted for hurling or to be projected
from the hand, or from any instrument or engine{2}, so as to strike an
object at a distance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We bend the bow, or wing the <qex>missile</qex> dart.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missile</ent><br/
<hw>Mis"sile</hw>, <pos>n.</pos> <ety>[L. <ets>missile</ets>.]</ety>
<sn>1.</sn> <def>A weapon thrown or projected or intended to be
projected, as a lance, an arrow, or a bullet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rocket-propelled device designed to fly through
the air and deliver a warhead of explosive materials to a
target.</def><br/
[<source>PJC</source>]</p>

<p><note>Numerous types of rocket-propelled missile{2} are now used in
modern warfare. Some types with names indicating their range or function
are: <stype>antiaircraft missile</stype>; <stype>ballistic
missile</stype>; <stype>cruise missile</stype>; <stype>antiballistic
missile missile</stype>; <stype>air-to-air missile</stype>;
<stype>air-to-ground missile</stype>; <stype>guided missile</stype>;
<stype>intercontinental ballistic missile</stype> (<abbr>IBM</abbr>);
<stype>intermediate range ballistic missile</stype> (<abbr>IRBM</abbr>);
<stype>surface-to-air missile</stype>.</note></p>

<p><ent>Missing</ent><br/
<hw>Miss"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Miss</er>,
<pos>v. i.</pos>]</ety> <def>Absent from the place where it was expected
to be found; lost; lacking; wanting; not present when called or looked
for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither was there aught <qex>missing</qex> unto them.</q>
<rj><qau>1 Sam. xxv. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For a time caught up to God, as once<br/
Moses was in the mount, and <qex>missing</qex> long.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missingly</ent><br/
<hw>Miss"ing*ly</hw>, <pos>adv.</pos> <def>With a sense of loss.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mission</ent><br/
<hw>Mis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>missio</ets>, fr. <ets>mittere</ets>, <ets>missum</ets>, to send:
cf. F. <ets>mission</ets>. See <er>Missile</er>.]</ety> <sn>1.</sn>
<def>The act of sending, or the state of being sent; a being sent or
delegated by authority, with certain powers for transacting business;
comission.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose glorious deeds, but in these fields of late,<br/
Made emulous <qex>missions</qex> 'mongst the gods themselves.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That with which a messenger or agent is charged; an
errand; business or duty on which one is sent; a commission.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How to begin, how to accomplish best<br/
His end of being on earth, and <qex>mission</qex> high.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Persons sent; any number of persons appointed to
perform any service; a delegation; an embassy; <as>as, the Russian
<ex>mission</ex> to the United Nations</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>In these ships there should be a <qex>mission</qex> of three of
the fellows or brethren of Solomon's house.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An assotiation or organization of missionaries; a
station or residence of missionaries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An organization for worship and work, dependent on
one or more churches.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A course of extraordinary sermons and services at a
particular place and time for the special purpose of quickening the
faith and zeal participants, and of converting unbelievers.</def>
<rj><au>Addis & Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Dismission; discharge from service.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mission school</b></col>. <sd>(a)</sd> <cd>A school
connected with a mission and conducted by missionaries</cd>.
<sd>(b)</sd> <cd>A school for the religious instruction of children not
having regular church privileges.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Message; errand; commission;
deputation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mission</ent><br/
<hw>Mis"sion</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To send on a
mission.</def> <mark>[Mostly used in the form of the past
participle.]</mark> <rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missionary</ent><br/
<hw>Mis"sion*ary</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Missionaries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>missionnaire</ets>. See <er>Mission</er>, <pos>n</pos>.]</ety>
<def>One who is sent on a mission; especially, one sent to propagate
religion.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Missionary apostolic</b></col>, <cd>a Roman Catholic
missionary sent by commission from the pope.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missionary</ent><br/
<hw>Mis"sion*a*ry</hw>, <pos>a.</pos> <def>Of or pertaining to missions;
<as>as, a <ex>missionary</ex> meeting; a <ex>missionary</ex>
fund.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missioner</ent><br/
<hw>Mis"sion*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A missionary; an
envoy; one who conducts a mission. See <er>Mission</er>, <pos>n.</pos>,
6.</def> <ldquo/Like mighty <xex>missioner</xex> you come.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missis</ent><br/
<hw>Mis"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mistress; a wife; --
so used by the illiterate.</def> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missish</ent><br/
<hw>Miss"ish</hw>, <pos>a.</pos> <def>Like a miss; prim; affected;
sentimental.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Miss"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mississippian</ent><br/
<hw>Mississippian</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A geological
period extending from from 310 million to 345 million years ago; it was
associated with an increase of land areas, the presence of primitive
ammonites, and emergence of winged insects; called also
<altname>Missippian period</altname> and <altname>Lower Carboniferous
period</altname>.</def><br/
<syn><b>Syn. --</b> Missippian period, Lower Carboniferous, Lower
Carboniferous period.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A resident of Mississippi.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Missit</ent><br/
<hw>Mis*sit"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To sit badly or
imperfectly upon; to misbecome.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missive</ent><br/
<hw>Mis"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Missive</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Specially sent;
intended or prepared to be sent; <as>as, a letter
<ex>missive</ex></as>.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Missile.</def> <ldquo/The <xex>missive</xex> weapons
fly.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Letters missive</b></col>, <cd>letters conveying the
permission, comand, or advice of a superior authority, as a sovereign.
They are addressed and sent to some certain person or persons, and are
distinguished from <xex>letters patent</xex>, which are addressed to the
public.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missive</ent><br/
<hw>Mis"sive</hw>, <pos>n.</pos> <ety>[F. lettre <ets>missive</ets>. See
<er>Mission</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>That which is
sent; a writing containing a message.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is sent; a messenger.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missound</ent><br/
<hw>Mis*sound"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To sound
wrongly; to utter or pronounce incorrectly.</def>
<rj><au>E,Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missourian</ent><br/
<hw>Missourian</hw> <pos>prop. n.</pos> <def>A resident of
Missouri.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Misspeak</ent><br/
<hw>Mis*speak"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To err in
speaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspeak</ent><br/
<hw>Mis*speak"</hw>, <pos>v. t.</pos> <def>To utter wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspeech</ent><br/
<hw>Mis*speech"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
speech.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspell</ent><br/
<hw>Mis*spell"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Misspelled</conjf> <pr>(?)</pr>, or
<conjf>Misspelt</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Misspelling</conjf>.]</vmorph> <def>To spell
incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspelling</ent><br/
<hw>Mis*spell"ing</hw>, <pos>n.</pos> <def>A wrong spelling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspend</ent><br/
<hw>Mis*spend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Misspent</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misspending</conjf>.]</vmorph> <def>To spend amiss or
for wrong purposes; to squander; to waste; <as>as, to <ex>misspend</ex>
time or money</as>.</def> <rj><au>J. Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspender</ent><br/
<hw>Mis*spend"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
misspends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>misspense</ent><br/
<hw>mis*spense"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A spending
improperly; a wasting.</def> <mark>[Obs.]</mark>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misspent</ent><br/
<hw>Mis*spent"</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Misspend</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misstate</ent><br/
<hw>Mis*state"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To state
wrongly; <as>as, to <ex>misstate</ex> a question in debate</as>.</def>
<rj><au>Bp. Sanderson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misstatement</ent><br/
<hw>Mis*state"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An incorrect
statement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misstayed</ent><br/
<hw>Mis*stayed"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Naut.)</fld>
<def>Having missed stays; -- said of a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misstep</ent><br/
<hw>Mis*step"</hw>, <pos>n.</pos> <def>A wrong step; an error of
conduct.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misstep</ent><br/
<hw>Mis*step"</hw>, <pos>v. i.</pos> <def>To take a wrong step; to go
astray.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missuccess</ent><br/
<hw>Mis`suc*cess"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Failure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missuggestion</ent><br/
<hw>Mis`sug*ges"tion</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>Wrong
or evil suggestion.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missummation</ent><br/
<hw>Mis`sum*ma"tion</hw>, <pos>n.</pos> <def>Wrong summation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misswear</ent><br/
<hw>Mis*swear"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To swear
falsely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missy</ent><br/
<hw>Mis"sy</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>See
<er>Misy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Missy</ent><br/
<hw>Mis"sy</hw>, <pos>n.</pos> <def>An affectionate, or contemptuous,
form of <xex>miss</xex>; a young girl; a miss.</def> --
<def2><pos>a.</pos> <def>Like a miss, or girl.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>mist</ent><br/
<hw>mist</hw> <pr>(m<icr/st)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mist</ets>; akin to D. & Sw. <ets>mist</ets>, Icel.
<ets>mistr</ets>, G. <ets>mist</ets> dung, Goth.
<ets>ma<iacute/hstus</ets>, AS. <ets>m<imac/gan</ets> to make water,
Icel. <ets>m<imac/ga</ets>, Lith. <ets>migla</ets> mist, Russ.
<ets>mgla</ets>, L. <ets>mingere</ets>, <ets>meiere</ets>, to make
water, Gr. <grk>'omichei^n</grk> to make water, <grk>'omi`chlh</grk>
mist, Skr. <ets>mih</ets> to make water, n., a mist
<ets>m<emac/gha</ets> cloud. <root/102. Cf. <er>Misle</er>,
<er>Mizzle</er>, <er>Mixen</er>.]</ety> <sn>1.</sn> <def>Visible watery
vapor suspended in the atmosphere, at or near the surface of the earth;
fog.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Coarse, watery vapor, floating or falling in visible
particles, approaching the form of rain; <as>as, Scotch
<ex>mist</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, anything which dims or darkens, and obscures
or intercepts vision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His passion cast a <qex>mist</qex> before his sense.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mist flower</b></col> <fld>(Bot.)</fld>, <cd>a composite
plant (<spn>Eupatorium coelestinum</spn>), having heart-shaped leaves,
and corymbs of lavender-blue flowers. It is found in the Western and
Southern United States.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mist</ent><br/
<hw>Mist</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Misted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Misting</conjf>.]</vmorph> <def>To cloud; to cover with mist; to
dim.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mist</ent><br/
<hw>Mist</hw>, <pos>v. i.</pos> <def>To rain in very fine drops; <as>as,
it <ex>mists</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistakable</ent><br/
<hw>Mis*tak"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Liable to be
mistaken; capable of being misconceived.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistake</ent><br/
<hw>Mis*take"</hw> <pr>(m<icr/s*t<amac/k")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & obs. p. p.</pos> <conjf>Mistook</conjf>
<pr>(m<icr/s*t<oocr/k")</pr>; <pos>p. p.</pos> <conjf>Mistaken</conjf>
<pr>(m<icr/s*t<amac/k"'n)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mistaking</conjf>.]</vmorph> <ety>[Pref. <ets>mis-</ets> +
<ets>take</ets>: cf. Icel. <ets>mistaka</ets>.]</ety> <sn>1.</sn>
<def>To take or choose wrongly.</def> <mark>[Obs. or R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take in a wrong sense; to misunderstand
misapprehend, or misconceive; <as>as, to <ex>mistake</ex> a remark; to
<ex>mistake</ex> one's meaning.</as></def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My father's purposes have been <qex>mistook</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To substitute in thought or perception; <as>as, to
<ex>mistake</ex> one person for another</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man may <qex>mistake</qex> the love of virtue for the practice
of it.</q> <rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To have a wrong idea of in respect of character,
qualities, etc.; to misjudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mistake</qex> me not so much,<br/
To think my poverty is treacherous.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistake</ent><br/
<hw>Mis*take"</hw>, <pos>v. i.</pos> <def>To err in knowledge,
perception, opinion, or judgment; to commit an unintentional
error.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Servants <qex>mistake</qex>, and sometimes occasion
misunderstanding among friends.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 932 --></p>

<p><ent>Mistake</ent><br/
<hw>Mis*take"</hw> <pr>(m<icr/s*t<amac/k")</pr>, <pos>n.</pos>
<sn>1.</sn> <def>An apprehending wrongly; a misconception; a
misunderstanding; a fault in opinion or judgment; an unintentional error
of conduct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Infallibility is an absolute security of the understanding from
all possibility of <qex>mistake</qex>.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Misconception, error, which when
non-negligent may be ground for rescinding a contract, or for refusing
to perform it.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>No mistake</b></col>, <cd>surely; without fail; <as>as,
it will happen at the appointed time, and <ex>no mistake</ex></as>.</cd>
<mark>[Low]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Blunder; error; bull. See
<er>Blunder</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistaken</ent><br/
<hw>Mis*tak"en</hw> <pr>(?)</pr>, <pos>p.a.</pos> <sn>1.</sn> <def>Being
in error; judging wrongly; having a wrong opinion or a misconception;
<as>as, a <ex>mistaken</ex> man; he is <ex>mistaken</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Erroneous; wrong; <as>as, a <ex>mistaken</ex>
notion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistakenly</ent><br/
<hw>Mis*tak"en*ly</hw>, <pos>adv.</pos> <def>By mistake.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistakenness</ent><br/
<hw>Mis*tak"en*ness</hw>, <pos>n.</pos> <def>Erroneousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistaker</ent><br/
<hw>Mis*tak"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mistakes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Well meaning ignorance of some <qex>mistakers</qex>.</q>
<rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistaking</ent><br/
<hw>Mis*tak"ing</hw>, <pos>n.</pos> <def>An error; a mistake.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistakingly</ent><br/
<hw>Mis*tak"ing*ly</hw>, <pos>adv.</pos> <def>Erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistaught</ent><br/
<hw>Mis*taught"</hw> <pr>(m<icr/s*t<add/t")</pr>, <pos>a.</pos>
<ety>[See <er>Misteach</er>.]</ety> <def>Wrongly taught; <as>as, a
<ex>mistaught</ex> youth</as>.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misteach</ent><br/
<hw>Mis*teach"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mistaught</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misteaching</conjf>.]</vmorph> <ety>[AS.
<ets>mist<aemac/can</ets>.]</ety> <def>To teach wrongly; to instruct
erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistell</ent><br/
<hw>Mis*tell"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mistold</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mistelling</conjf>.]</vmorph> <def>To tell
erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistemper</ent><br/
<hw>Mis*tem"per</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To temper ill;
to disorder; <as>as, to <ex>mistemper</ex> one's head</as>.</def>
<rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This inundation of <qex>mistempered</qex> humor.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mister</ent><br/
<hw>Mis"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Master</er>,
and cf. <er>Mistress</er>.]</ety> <def>A title of courtesy prefixed to
the name of a man or youth. It is usually written in the abbreviated
form <abbr>Mr.</abbr></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To call your name, inquire your where,<br/
Or what you think of <qex>Mister</qex> Some-one's book,<br/
Or <qex>Mister</qex> Other's marriage or decease.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mister</ent><br/
<hw>Mis"ter</hw>, <pos>v. t.</pos> <def>To address or mention by the
title Mr.; <as>as, he <ex>mistered</ex> me in a formal way</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mister</ent><br/
<hw>Mis"ter</hw>, <pos>n.</pos> <ety>[OF. <ets>mistier</ets> trade,
office, ministry, need, F. <ets>m<eacute/tier</ets> trade, fr. L.
<ets>ministerium</ets> service, office, ministry. See <er>Ministry</er>,
<er>Mystery</er> trade.]</ety> <altsp>[Written also
<asp>mester</asp>.]</altsp> <sn>1.</sn> <def>A trade, art, or
occupation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In youth he learned had a good <qex>mester</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Manner; kind; sort.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But telleth me what <qex>mester</qex> men ye be.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Need; necessity.</def> <mark>[Obs.]</mark>
<rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mister</ent><br/
<hw>Mis"ter</hw>, <pos>v. i.</pos> <def>To be needful or of use.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As for my name, it <qex>mistereth</qex> not to tell.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misterm</ent><br/
<hw>Mis*term"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To call by a
wrong name; to miscall.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistery</ent><br/
<hw>Mis"ter*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mystery</er>, a trade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistful</ent><br/
<hw>Mist"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Clouded with, or as
with, mist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misthink</ent><br/
<hw>Mis*think"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Think</er>.]</ety> <def>To think wrongly.</def> <mark>[Obs.]</mark>
<ldquo/Adam <xex>misthought</xex> of her.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misthink</ent><br/
<hw>Mis*think"</hw>, <pos>v. t.</pos> <def>To have erroneous thoughts or
judgment of; to think ill of.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misthought</ent><br/
<hw>Mis*thought"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Erroneous
thought; mistaken opinion; error.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misthrive</ent><br/
<hw>Mis*thrive"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To thrive
poorly; to be not thrifty or prosperous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misthrow</ent><br/
<hw>Mis*throw"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To throw
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistico</ent><br/
<ent>Mistic</ent><br/
<mhw>{ <hw>Mis"tic</hw> <pr>(?)</pr>, <hw>Mis"ti*co</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Sp. <ets>m<iacute/stico</ets>.]</ety> <def>A
kind of small sailing vessel used in the Mediterranean. It is rigged
partly like a xebec, and partly like a felucca.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistide</ent><br/
<hw>Mis*tide"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>mist<imac/dan</ets>. See <er>Tide</er>.]</ety> <def>To happen or
come to pass unfortunately; also, to suffer evil fortune.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistigri</ent><br/
<ent>Mistigris</ent><br/
<mhw>{ \'d8<hw>Mis`ti`gris"</hw> <pr>(?)</pr>, \'d8<hw>Mis`ti`gri"</hw>
}</mhw>, <pos>n.</pos> <ety>[F. <ets>mistigri</ets>.]</ety> <def>A
variety of the game of poker in which the joker is used, and called
<xex>mistigris</xex> or <xex>mistigri</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistihead</ent><br/
<hw>Mist"i*head</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mistiness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistily</ent><br/
<hw>Mist"i*ly</hw>, <pos>adv.</pos> <def>With mist; darkly;
obscurely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistime</ent><br/
<hw>Mis*time"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>mist<imac/main</ets> to turn out ill.]</ety> <def>To time wrongly;
not to adapt to the time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mistiming</ent><br/
<hw>mistiming</hw> <pos>n.</pos> <def>The act or process of assigning
something to a time when it could not have existed or
occurred.</def><br/
<syn><b>Syn. --</b> anachronism, misdating.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mistiness</ent><br/
<hw>Mist"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
misty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistion</ent><br/
<hw>Mis"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mistio</ets>, <ets>mixtio</ets>. See <er>Mix</er>, and cf.
<er>Mixtion</er>.]</ety> <def>Mixture.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistitle</ent><br/
<hw>Mis*ti"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To call by a
wrong title.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistle</ent><br/
<hw>Mis"tle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Eng.
<ets>mist</ets>. See <er>Misle</er>, and <er>Mizzle</er>.]</ety> <def>To
fall in very fine drops, as rain; to drizzle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistletoe</ent><br/
<hw>Mis"tle*toe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mistelt<amac/n</ets>; <ets>mistel</ets> mistletoe +
<ets>t<amac/n</ets> twig. AS. <ets>mistel</ets> is akin of D., G., Dan.
& Sw. <ets>mistel</ets>, OHG. <ets>mistil</ets>, Icel.
<ets>mistil</ets>teinn; and AS. <ets>t<amac/n</ets> to D.
<ets>teen</ets>, OHG. <ets>zein</ets>, Icel. <ets>teinn</ets>, Goth.
<ets>tains</ets>. Cf. <er>Missel</er>.]</ety> <fld>(Bot.)</fld> <def>A
parasitic evergreen plant of Europe (<spn>Viscum album</spn>), bearing a
glutinous fruit. When found upon the oak, where it is rare, it was an
object of superstitious regard among the Druids. A bird lime is prepared
from its fruit.</def> <altsp>[Written also <asp>misletoe</asp>,
<asp>misseltoe</asp>, and <asp>mistleto</asp>.]</altsp>
<rj><au>Lindley.</au> <au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The mistletoe of the United States is <spn>Phoradendron
serotinum</spn> (syn. <spn>Phoradendron flavescens</spn>), having
broader leaves than the European kind. In different regions various
similar plants are called by this name. The mistletoe is used as a
decoration at Christmas time, and it is a tradition that two persons of
the oposite sex finding each other under a mistletoe sprig should
kiss.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mistonusk</ent><br/
\'d8<hw>Mis"to*nusk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the
Indian name.]</ety> <fld>(Zool.)</fld> <def>The American
badger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistook</ent><br/
<hw>Mis*took"</hw> <pr>(?)</pr>, <def><pos>imp. & obs. p. p.</pos> of
<er>Mistake</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistradition</ent><br/
<hw>Mis`tra*di"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wrong
tradition.</def> <ldquo/Monsters of <xex>mistradition</xex>.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrain</ent><br/
<hw>Mis*train"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To train
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistral</ent><br/
<hw>Mis"tral</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
Proven<cced/al.]</ety> <def>A violent and cold northwest wind
experienced in the Mediterranean provinces of France, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistranslate</ent><br/
<hw>Mis`trans*late"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
translate erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistranslation</ent><br/
<hw>Mis`trans*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
translation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistransport</ent><br/
<hw>Mis`trans*port"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To carry
away or mislead wrongfully, as by passion.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistreading</ent><br/
<hw>Mis*tread"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Misstep;
misbehavior.</def> <ldquo/To punish my <xex>mistreadings</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistreat</ent><br/
<hw>Mis*treat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To treat amiss;
to abuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mistreated</ent><br/
<hw>mistreated</hw> <pos>adj.</pos> <def>physically abused.</def>
[Narrower terms: <stype>assaulted, molested, raped</stype>;
<stype>battered, beaten</stype>; <stype>misunderstood </stype>]<br/
<syn><b>Syn. --</b> abused, ill-treated, maltreated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mistreatment</ent><br/
<hw>Mis*treat"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong
treatment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistress</ent><br/
<hw>Mis"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>maistress</ets>, OF. <ets>maistresse</ets>, F.
<ets>ma<icir/tresse</ets>, LL. <ets>magistrissa</ets>, for L.
<ets>magistra</ets>, fem. of <ets>magister</ets>. See <er>Master</er>,
<er>Mister</er>, and cf. <er>Miss</er> a young woman.]</ety> <sn>1.</sn>
<def>A woman having power, authority, or ownership; a woman who
exercises authority, is chief, etc.; the female head of a family, a
school, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The late queen's gentlewoman! a knight's daughter!<br/
To be her <qex>mistress</qex>' <qex>mistress</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman well skilled in anything, or having the
mastery over it.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A letter desires all young wives to make themselves
<qex>mistresses</qex> of Wingate's Arithmetic.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A woman regarded with love and devotion; she who has
command over one's heart; a beloved object; a sweetheart.</def>
<mark>[Poetic]</mark> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A woman filling the place, but without the rights,
of a wife; a woman having an ongoing usually exclusive sexual
relationship with a man, who may provide her with financial support in
return; a concubine; a loose woman with whom one consorts habitually;
<as>as, both his wife and his <ex>mistress</ex> attended his
funeral</as>.</def> <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>5.</sn> <def>A title of courtesy formerly prefixed to the name of
a woman, married or unmarried, but now superseded by the contracted
forms, <abbr>Mrs.</abbr>, for a married, and <abbr>Miss</abbr>, for an
unmarried, woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now <qex>Mistress</qex> Gilpin (careful soul).</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A married woman; a wife.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Several of the neighboring <qex>mistresses</qex> had assembled to
witness the event of this memorable evening.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The old name of the jack at bowls.</def>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be one's own mistress</b></col>, <cd>to be exempt from
control by another person.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistress</ent><br/
<hw>Mis"tress</hw>, <pos>v. i.</pos> <def>To wait upon a mistress; to be
courting.</def> <mark>[Obs.]</mark> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistressship</ent><br/
<hw>Mis"tress*ship</hw>, <pos>n.</pos> <sn>1.</sn> <def>Female rule or
dominion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ladyship, a style of address; -- with the personal
pronoun.</def> <mark>[Obs.]</mark> <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrial</ent><br/
<hw>Mis*tri"al</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld> <def>A
false or erroneous trial; a trial which has no result; a trial which
comes to no conclusion, such as a criminal trial which does not produce
a unanimous verdict of the jurors.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mistrist</ent><br/
<hw>Mis*trist"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
mistrust.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrow</ent><br/
<hw>Mis*trow"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To think
wrongly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrust</ent><br/
<hw>Mis*trust"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of confidence
or trust; suspicion; distrust.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrust</ent><br/
<hw>Mis*trust"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To regard with
jealousy or suspicion; to suspect; to doubt the integrity of; to
distrust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will never <qex>mistrust</qex> my wife again.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To forebode as near, or likely to occur; to
surmise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By a divine instinct, men's minds <qex>mistrust</qex><br/
Ensuing dangers.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistruster</ent><br/
<hw>Mis*trust"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mistrusts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrustful</ent><br/
<hw>Mis*trust"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having or
causing mistrust, suspicions, or forebodings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their light blown out in some <qex>mistrustful</qex> wood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mis*trust"ful*ly</wf>, <pos>adv.</pos> --
<wf>Mis*trust"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrustingly</ent><br/
<hw>Mis*trust"ing*ly</hw>, <pos>adv.</pos> <def>With distrust or
suspicion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistrustless</ent><br/
<hw>Mis*trust"less</hw>, <pos>a.</pos> <def>Having no mistrust or
suspicion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The swain <qex>mistrustless</qex> of his smutted face.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistune</ent><br/
<hw>Mis*tune"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To tune
wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistura</ent><br/
\'d8<hw>Mis*tu"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Mixture</er>.]</ety> <fld>(Med.)</fld> <sd>(a)</sd> <def>A mingled
compound in which different ingredients are contained in a liquid state;
a mixture. See <er>Mixture</er>, <pos>n.</pos>, 4.</def> <sd>(b)</sd>
<def>Sometimes, a liquid medicine containing very active substances, and
which can only be administered by drops.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misturn</ent><br/
<hw>Mis*turn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To turn amiss; to
pervert.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mistutor</ent><br/
<hw>Mis*tu"tor</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To instruct
amiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misty</ent><br/
<hw>Mist"y</hw> <pr>(m<icr/st"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Mistier</adjf>
<pr>(m<icr/st"<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Mistiest</adjf>.]</amorph> <ety>[AS. <ets>mistig</ets>. See
<er>Mist</er>. In some senses <ets>misty</ets> has been confused with
<ets>mystic</ets>.]</ety> <sn>1.</sn> <def>Accompanied with mist;
characterized by the presence of mist; obscured by, or overspread with,
mist; <as>as, a <ex>misty</ex> morning; <ex>misty</ex> weather;
<ex>misty</ex> mountains; a <ex>misty</ex> atmosphere.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Obscured as if by mist; dim; obscure; clouded;
<as>as, <ex>misty</ex> sight; to peer into the <ex>misty</ex>
future</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The more I muse therein [theology],<br/
The <qex>mistier</qex> it seemeth.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misunderstand</ent><br/
<hw>Mis*un`der*stand"</hw>
<pr>(m<icr/s*<ucr/n`d<etil/r*st<acr/nd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Misunderstood</conjf>
<pr>(m<icr/s*<ucr/n`d<etil/r*st<oocr/d")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Misunderstanding</conjf>.]</vmorph> <def>To misconceive;
to mistake; to miscomprehend; to take in a wrong sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misunderstander</ent><br/
<hw>Mis*un`der*stand"er</hw>
<pr>(m<icr/s*<ucr/n`d<etil/r*st<acr/nd"<etil/r)</pr>, <pos>n.</pos>
<def>One who misunderstands.</def> <rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misunderstanding</ent><br/
<hw>Mis*un`der*stand"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>Mistake of
the meaning; error; misconception.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disagreement; difference of opinion; dissension;
quarrel.</def> <ldquo/<xex>Misunderstandings</xex> among friends.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misurato</ent><br/
\'d8<hw>Mi`su*ra"to</hw> <pr>(m<emac/`s<oomac/*r<aum/"t<osl/)</pr>,
<pos>a.</pos> <ety>[It.]</ety> <fld>(Mus.)</fld> <def>Measured; -- a
direction to perform a passage in strict or measured time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misusage</ent><br/
<hw>Mis*us"age</hw> <pr>(m<icr/s*<umac/z"<asl/j)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>m<eacute/susage</ets>.]</ety> <def>Bad treatment;
abuse.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misuse</ent><br/
<hw>Mis*use"</hw> <pr>(m<icr/s*<umac/z")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>m<eacute/suser</ets>. See <er>Mis-</er>, prefix from French, and
<er>Use</er>.]</ety> <sn>1.</sn> <def>To treat or use improperly; to use
to a bad purpose; to misapply; <as>as, to <ex>misuse</ex> one's
talents</as>.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sweet poison of <qex>misused</qex> wine.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To abuse; to treat ill.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, she <qex>misused</qex> me past the endurance of a block.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To maltreat; abuse; misemploy;
misapply.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misuse</ent><br/
<hw>Mis*use"</hw> <pr>(m<icr/s*<umac/s")</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Wrong use; misapplication; erroneous or improper use.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Words little suspected for any such <qex>misuse</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Violence, or its effects.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misusement</ent><br/
<hw>Mis*use"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Misuse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misuser</ent><br/
<hw>Mis*us"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
misuses.</def> <ldquo/Wretched <xex>misusers</xex> of language.<rdquo/
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Unlawful use of a right; use in
excess of, or varying from, one's right.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misvalue</ent><br/
<hw>Mis*val"ue</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To value wrongly
or too little; to undervalue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But for I am so young, I dread my work<br/
Wot be <qex>misvalued</qex> both of old and young.</q> <rj><qau>W.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misvouch</ent><br/
<hw>Mis*vouch"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To vouch
falsely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miswander</ent><br/
<hw>Mis*wan"der</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To wander in a
wrong path; to stray; to go astray.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misway</ent><br/
<hw>Mis*way"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wrong way.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miswear</ent><br/
<hw>Mis*wear"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To wear
ill.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miswed</ent><br/
<hw>Mis*wed"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To wed
improperly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misween</ent><br/
<hw>Mis*ween"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To ween amiss; to
misjudge; to distrust; to be mistaken.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miswend</ent><br/
<hw>Mis*wend"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To go wrong; to
go astray.</def> <mark>[Obs.]</mark> <ldquo/The world is
<xex>miswent</xex>.<rdquo/ <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misword</ent><br/
<hw>Mis*word"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To word wrongly;
<as>as, to <ex>misword</ex> a message, or a sentence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misword</ent><br/
<hw>Mis*word"</hw>, <pos>n.</pos> <def>A word wrongly spoken; a cross
word.</def> <mark>[Obs.]</mark> <rj><au>Sylvester.</au>
<au>Breton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misworship</ent><br/
<hw>Mis*wor"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Wrong or false
worship; mistaken practices in religion.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such hideous jungle of <qex>misworships</qex>.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misworship</ent><br/
<hw>Mis*wor"ship</hw>, <pos>v. t.</pos> <def>To worship wrongly.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misworshiper</ent><br/
<hw>Mis*wor"ship*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
worships wrongly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miswrite</ent><br/
<hw>Mis*write"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To write
incorrectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miswrought</ent><br/
<hw>Mis*wrought"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Badly
wrought.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misy</ent><br/
<hw>Mi"sy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L. <ets>misy</ets>
a mineral, perh. copperas, Gr. <?/.]</ety> <fld>(Min.)</fld> <def>An
impure yellow sulphate of iron; yellow copperas or copiapite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Misyoke</ent><br/
<hw>Mis*yoke"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To yoke
improperly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miszealous</ent><br/
<hw>Mis*zeal"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mistakenly
zealous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mite</ent><br/
<hw>Mite</hw> <pr>(m<imac/t)</pr>, <pos>n.</pos> <ety>[AS.
<ets>m<imac/te</ets> mite (in sense 1); akin to LG. <ets>mite</ets>, D.
<ets>mijt</ets>, G. <ets>miete</ets>, OHG. <ets>m<imac/za</ets>; cf.
Goth. <ets>maitan</ets> to cut.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>A minute arachnid, of the order <ord>Acarina</ord>, of which there
are many species; <as>as, the <styp>dust <ex>mite</ex></styp>,
<styp>cheese <ex>mite</ex></styp>, <styp>sugar <ex>mite</ex></styp>,
<styp>harvest <ex>mite</ex></styp>, <styp>three-toed spider
<ex>mite</ex></styp>, etc.</as> See <er>Acarina</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[D. <ets>mijt</ets>; prob. the same word.]</ety>
<def>A small coin formerly circulated in England, rated at about a third
of a farthing. The name is also applied to a small coin used in
Palestine in the time of Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Two <qex>mites</qex>, which make a farthing.</q> <rj><qau>Mark
xii. 49.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A small weight; one twentieth of a grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Anything very small; a minute object; a very little
quantity or particle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For in effect they be not worth a <qex>myte</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitella</ent><br/
<hw>Mitella</hw> <pos>prop. n.</pos> <def>A genus of low slender herbs
of North America and Northeast Asia having flowers with trifid or
pinnatifid petals.</def><br/
<syn><b>Syn. --</b> genus <gen>Mitella</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mitre</ent><br/
<ent>Miter</ent><br/
<mhw>{ <hw>Mi"ter</hw>, <hw>Mi"tre</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>mitre</ets>, fr. L. <ets>mitra</ets>
headband, turban, Gr. <?/.]</ety> <sn>1.</sn> <def>A covering for the
head, worn on solemn occasions by bishops and other church dignitaries.
It has been made in many forms, the present form being a lofty cap with
two points or peaks.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The surface forming the beveled end or edge of a
piece where a miter joint is made; also, a joint formed or a junction
effected by two beveled ends or edges; a miter joint.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Numis.)</fld> <def>A sort of base money or
coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Miter box</b></col> <fld>(Carp. & Print.)</fld>, <cd>an
apparatus for guiding a handsaw at the proper angle in making a miter
joint; esp., a wooden or metal trough with vertical kerfs in its upright
sides, for guides.</cd> -- <col><b>Miter dovetail</b></col>
<fld>(Carp.)</fld>, <cd>a kind of dovetail for a miter joint in which
there is only one joint line visible, and that at the angle.</cd> --
<col><b>Miter gauge</b></col> <fld>(Carp.)</fld>, <cd>a gauge for
determining the angle of a miter.</cd> -- <col><b>Miter joint</b></col>,
<cd>a joint formed by pieces matched and united upon a line bisecting
the angle of junction, as by the beveled ends of two pieces of molding
or brass rule, etc. The term is used especially when the pieces form a
right angle, such as the edges of a window frame, and the edge of each
piece at the point of junction is cut at a 45<deg/ angle to its long
direction. See <er>Miter</er>, 2.</cd> -- <col><b>Miter shell</b></col>
<fld>(Zool.)</fld>, <cd>any one of numerous species of marine univalve
shells of the genus <gen>Mitra</gen>.</cd> -- <col><b>Miter
square</b></col> <fld>(Carp.)</fld>, <cd>a bevel with an immovable arm
at an angle of 45<deg/, for striking lines on stuff to be mitered; also,
a square with an arm adjustable to any angle.</cd> -- <col><b>Miter
wheels</b></col>, <cd>a pair of bevel gears, of equal diameter, adapted
for working together, usually with their axes at right
angles.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitre</ent><br/
<ent>Miter</ent><br/
<mhw>{ <hw>Mi"ter</hw>, <hw>Mi"tre</hw> }</mhw>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Mitered</conjf> <pr>(?)</pr> or
<conjf>Mitred</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mitering</conjf> <pr>(?)</pr> or
<conjf>Mitring</conjf>.]</vmorph> <sn>1.</sn> <def>To place a miter
upon; to adorn with a miter.</def> <wns>[wns=2]</wns>
<ldquo/<xex>Mitered</xex> locks.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To match together, as two pieces of molding or brass
rule on a line bisecting the angle of junction; to fit together in a
miter joint.</def> <wns>[wns=3]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bevel the ends or edges of, for the purpose of
matching together at an angle.</def> <wns>[wns=1]</wns><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitre</ent><br/
<ent>Miter</ent><br/
<mhw>{ <hw>Mi"ter</hw>, <hw>Mi"tre</hw> }</mhw>, <pos>v. i.</pos>
<def>To meet and match together, as two pieces of molding, on a line
bisecting the angle of junction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miterwort</ent><br/
<hw>Mi"ter*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Any plant of the genus <gen>Mitella</gen>, -- slender, perennial
herbs with a pod slightly resembling a bishop's miter; bishop's
cap.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>False miterwort</b></col>, <cd>a white-flowered perennial
herb of the United States (<spn>Tiarella
cardifolia</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mithic</ent><br/
<hw>Mith"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Mythic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mithras</ent><br/
<ent>Mithra</ent><br/
<mhw><hw>Mi"thra</hw>, <hw>Mi"thras</hw></mhw> <pr>(?)</pr>, <pos>prop.
n.</pos> <ety>[L., from Gr. <?/.]</ety> <def>The sun god of the ancient
Persians; the god of light and truth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mithraistic</ent><br/
<ent>mithraic</ent><br/
<mhw><hw>mithraic</hw> <hw>mithraistic</hw></mhw> <pos>adj.</pos>
<def>Of or pertaining to Mithraism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mithraicism</ent><br/
<hw>Mithraicism</hw> <pos>prop. n.</pos> <def>Mithraism.</def><br/
<syn><b>Syn. --</b> .</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mithraism</ent><br/
<hw>Mithraism</hw> <pos>prop. n.</pos> <def>The ancient Persian religion
which worshiped <persfn>Mithra</persfn>; it was popular among Romans
during first three centuries <sc>a. d.</sc></def><br/
<syn><b>Syn. --</b> Mithraicism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mithraist</ent><br/
<hw>Mithraist</hw> <pos>prop. n.</pos> <def>An adherent of
Mithraism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mithridate</ent><br/
<hw>Mith"ri*date</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>An antidote against poison, or a composition in form of an
electuary, supposed to serve either as a remedy or a preservative
against poison; an alexipharmic; -- so called from <person>King
<etsep>Mithridates</etsep></person>, its reputed inventor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Love is] a drop of the true elixir; no <qex>mithridate</qex> so
effectual against the infection of vice.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 933 --></p>

<p><ent>Mithridatic</ent><br/
<hw>Mith`ri*dat"ic</hw> <pr>(m<icr/th`r<icr/*d<acr/t"<icr/k)</pr>,
<pos>a.</pos> <def>Of or pertaining to King Mithridates, or to a
mithridate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitigable</ent><br/
<hw>Mit"i*ga*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Admitting of
mitigation; that may be mitigated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitigant</ent><br/
<hw>Mit"i*gant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mitigans</ets>, p. pr. of <ets>mitigare</ets>. See
<er>Mitigate</er>.]</ety> <def>Tending to mitigate; mitigating;
lenitive.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitigate</ent><br/
<hw>Mit"i*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mitigated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mitigating</conjf>.]</vmorph> <ety>[L.
<ets>mitigatus</ets>, p. p. of <ets>mitigare</ets> to soften, mitigate;
<ets>mitis</ets> mild, soft + the root of <ets>agere</ets> to do,
drive.]</ety> <sn>1.</sn> <def>To make less severe, intense, harsh,
rigorous, painful, etc.; to soften; to meliorate; to alleviate; to
diminish; to lessen; <as>as, to <ex>mitigate</ex> heat or cold; to
<ex>mitigate</ex> grief.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make mild and accessible; to mollify; -- applied
to persons.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This opinion . . . <qex>mitigated</qex> kings into companions.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To alleviate; assuage; allay. See
<er>Alleviate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>mitigated</ent><br/
<hw>mitigated</hw> <pos>adj.</pos> <def>made less severe or
intense.</def> <ant>unmitigated</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mitigating</ent><br/
<hw>mitigating</hw> <pos>adj.</pos> <def>serving to reduce blame; -- of
situations; <as>as, <ex>mitigating</ex> factors; <ex>mitigating</ex>
circumstances</as>. Opposite of <ant>aggravating</ant>.</def> [Narrower
terms: <stype>exculpatory</stype>]<br/
<syn><b>Syn. --</b> extenuating.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Mitigation</ent><br/
<hw>Mit`i*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mitigacioun</ets>, F. <ets>mitigation</ets>, fr. L.
<ets>mitigatio</ets>.]</ety> <def>The act of mitigating, or the state of
being mitigated; abatement or diminution of anything painful, harsh,
severe, afflictive, or calamitous; <as>as, the <ex>mitigation</ex> of
pain, grief, rigor, severity, punishment, or penalty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Alleviation; abatement; relief.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitigative</ent><br/
<hw>Mit"i*ga*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mitigativus</ets>: cf. F. <ets>mitigatif</ets>.]</ety> <def>Tending
to mitigate; alleviating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitigator</ent><br/
<hw>Mit"i*ga`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, mitigates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitigatory</ent><br/
<hw>Mit"i*ga*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
mitigate or alleviate; mitigative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Miting</ent><br/
<hw>Mit"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Mite</er>.]</ety> <def>A little one; -- used as a term of
endearment.</def> <mark>[Obs.]</mark> <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitis casting</ent><br/
<hw>Mi"tis cast`ing</hw> <pr>(?)</pr>. <ety>[Perh. fr. L.
<ets>mitis</ets> mild.]</ety> <def>A process, invented by <person>P.
Ostberg</person>, for producing malleable iron castings by melting
wrought iron, to which from 0.05 to 0.1 per cent of aluminum is added to
lower the melting point, usually in a petroleum furnace, keeping the
molten metal at the bubbling point until it becomes quiet, and then
pouring the molten metal into a mold lined with a special mixture
consisting essentially of molasses and ground burnt fire clay; also, a
casting made by this process; -- called also <altname>wrought-iron
casting</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mitis metal</ent><br/
<hw>Mitis metal</hw>. <def>The malleable iron produced by mitis casting;
-- called also simply <altname>mitis</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mitome</ent><br/
<hw>Mi"tome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
thread.]</ety> <fld>(Biol.)</fld> <def>The denser part of the protoplasm
of a cell.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitosis</ent><br/
\'d8<hw>Mi*to"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ a thread.]</ety> <fld>(Biol.)</fld> <def>See
<er>Karyokinesis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitotic</ent><br/
<hw>Mi*tot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of or pertaining to mitosis; karyokinetic; <as>as, <ex>mitotic</ex>
cell division</as>; -- opposed to <ant>amitotic</ant>.</def> --
<wordforms><wf>Mi*tot"ic*al*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mitraille</ent><br/
\'d8<hw>Mi`traille"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Mitrailleur</er>.]</ety> <def>Shot or bits of iron used sometimes in
loading cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitrailleur</ent><br/
\'d8<hw>Mi`tra`illeur"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <fld>(Mil.)</fld> <def>One who serves a
mitrailleuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mitralleuse.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mitrailleuse</ent><br/
\'d8<hw>Mi`tra`illeuse"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>mitrailler</ets> to fire grapeshot, fr. <ets>mitraille</ets> old
iron, grapeshot, dim. of OF. <ets>mite</ets> a mite.]</ety>
<fld>(Mil.)</fld> <def>A breech-loading machine gun consisting of a
number of barrels fitted together, so arranged that the barrels can be
fired simultaneously, or successively, and rapidly.</def>
<mark>[obsolescent]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitral</ent><br/
<hw>Mi"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mitral</ets>. See <er>Miter</er>.]</ety> <def>Pertaining to a
miter; resembling a miter; <as>as, the <ex>mitral</ex> valve between the
left auricle and left ventricle of the heart</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitre</ent><br/
<hw>Mi"tre</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Miter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mitrewort</ent><br/
<hw>mitrewort</hw> <pos>n.</pos> <def>Any of various rhizomatous
perennial herbs of the genus <gen>Mitella</gen> having a capsule
resembling a bishop's miter.</def> <altsp>[Also spelled
<asp>miterwort</asp>.]</altsp><br/
<syn><b>Syn. --</b> miterwort, bishop's cap.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mitriform</ent><br/
<hw>Mit"ri*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Miter</ets>
+ <ets>-form</ets>: cf. F. <ets>mitriforme</ets>.]</ety> <def>Having the
form of a miter, or a peaked cap; <as>as, a <ex>mitriform</ex>
calyptra</as>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitt</ent><br/
<hw>Mitt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Abbrev. fr.
<ets>mitten</ets>.]</ety> <sn>1.</sn> <def>A mitten; also, a covering
for the wrist and hand and not for the fingers, usually worn by
women.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Baseball)</fld> <def>A large glove, usually made of
leather or similar material, with differing degrees of padding and
usually some form of webbing in the large space between the thumb insert
and the insert for the index finger; a baseball glove. It is used to
assist in catching the baseball. The <styp>catcher's
<ex>mitt</ex></styp> has more padding and less webbing.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A hand; -- used mostly in slang expressions; <as>as,
keep your <ex>mitts</ex> off my box of chocolates!</as></def><br/
[<source>PJC</source>]</p>

<p><ent>Mitten</ent><br/
<hw>Mit"ten</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mitaine</ets>, <ets>meteyn</ets>, F. <ets>mitaine</ets>, perh. of
Celtic origin; cf. Ir. <ets>miotog</ets>, Gael. <ets>miotag</ets>, Ir. &
Gael. <ets>mutan</ets> a muff, a thick glove. Cf. <er>Mitt</er>.]</ety>
<sn>1.</sn> <def>A covering for the hand, worn to defend it from cold or
injury. It differs from a glove in not having a separate sheath for each
finger.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cover for the wrist and forearm.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To give the mitten to</b></col>, <cd>to dismiss as a
lover; to reject the suit of.</cd> <mark>[Colloq.]</mark> -- <col><b>To
handle without mittens</b></col>, <cd>to treat roughly; to handle
without gloves.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mittened</ent><br/
<hw>Mit"tened</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered with a
mitten or mittens.</def> <ldquo/<xex>Mittened</xex> hands.<rdquo/
<rj><au>Whittier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mittent</ent><br/
<hw>Mit"tent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mittens</ets>, p. pr. of <ets>mittere</ets> to send.]</ety>
<def>Sending forth; emitting.</def> <mark>[Obs.]</mark>
<rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mittimus</ent><br/
\'d8<hw>Mit"ti*mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., we send,
fr. <ets>mittere</ets> to send.]</ety> <fld>(Law)</fld> <sd>(a)</sd>
<def>A precept or warrant granted by a justice for committing to prison
a party charged with crime; a warrant of commitment to prison.</def>
<au>Burrill.</au> <sd>(b)</sd> <def>A writ for removing records from one
court to another.</def> <au>Brande & C.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mittler's green</ent><br/
<hw>Mit"tler's green`</hw> <pr>(?)</pr>. <fld>(Chem.)</fld> <def>A
pigment of a green color, the chief constituent of which is oxide of
chromium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitty</ent><br/
<hw>Mit"ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The stormy
petrel.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mitu</ent><br/
<hw>Mi"tu</hw> <pr>(m<imac/"t<usl/)</pr>, <pos>n.</pos> <ety>[Braz.
<ets>mitu poranga</ets>.]</ety> <fld>(Zool.)</fld> <def>A South American
curassow of the genus <gen>Mitua</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mity</ent><br/
<hw>Mit"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Mite</er>.]</ety> <def>Having, or abounding with, mites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mix</ent><br/
<hw>Mix</hw> <pr>(m<icr/ks)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mixed</conjf> <pr>(m<icr/kst)</pr> (less properly
<conjf>Mixt</conjf>); <pos>p. pr. & vb. n.</pos>
<conjf>Mixing</conjf>.]</vmorph> <ety>[AS. <ets>miscan</ets>; akin to
OHG. <ets>misken</ets>, G. <ets>mischen</ets>, Russ.
<ets>mieshate</ets>, W. <ets>mysgu</ets>, Gael. <ets>measg</ets>, L.
<ets>miscere</ets>, <ets>mixtum</ets>, Gr. <grk>mi`sgein</grk>,
<grk>migny`nai</grk>, Skr. <ets>mi<cced/ra</ets> mixed. The English word
has been influenced by L. <ets>miscere</ets>, <ets>mixtum</ets> (cf.
<er>Mixture</er>), and even the AS. <ets>miscan</ets> may have been
borrowed fr. L. <ets>miscere</ets>. Cf. <er>Admix</er>, <er>Mash</er> to
bruise, <er>Meddle</er>.]</ety> <sn>1.</sn> <def>To cause a promiscuous
interpenetration of the parts of, as of two or more substances with each
other, or of one substance with others; to unite or blend into one mass
or compound, as by stirring together; to mingle; to blend; <as>as, to
<ex>mix</ex> flour and salt; to <ex>mix</ex> wines.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair persuasions <qex>mixed</qex> with sugared words.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To unite with in company; to join; to
associate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ephraim, he hath <qex>mixed</qex> himself among the people.</q>
<rj><qau>Hos. vii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To form by mingling; to produce by the stirring
together of ingredients; to compound of different parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hast thou no poison <qex>mixed</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have chosen an argument <qex>mixed</qex> of religious and civil
considerations.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To combine (two or more activities) within a
specified or implied time frame; <as>as, to <ex>mix</ex> studying and
partying while at college</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mix</ent><br/
<hw>Mix</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To become
united into a compound; to be blended promiscuously together.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To associate; to mingle; <as>as, Democrats and
Republicans <ex>mixed</ex> freely at the party</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>He had <qex>mixed</qex><br/
Again in fancied safety with his kind.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixable</ent><br/
<hw>Mix"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
mixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixed</ent><br/
<hw>Mixed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed by mixing;
united; mingled; blended. See <er>Mix</er>, <pos>v. t. &
i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mixed action</b></col> <fld>(Law)</fld>, <cd>a suit
combining the properties of a real and a personal action.</cd> --
<col><b>Mixed angle</b></col>, <cd>a mixtilineal angle.</cd> --
<col><b>Mixed fabric</b></col>, <cd>a textile fabric composed of two or
more kinds of fiber, as a poplin.</cd> -- <col><b>Mixed
marriage</b></col>, <cd>a marriage between persons of different races or
religions; specifically, one between a Roman Catholic and a
Protestant.</cd> -- <col><b>Mixed number</b></col>, <cd>a whole number
and a fraction taken together.</cd> -- <col><b>Mixed train</b></col>,
<cd>a railway train containing both passenger and freight cars.</cd> --
<col><b>Mixed voices</b></col> <fld>(Mus.)</fld>, <cd>voices of both
males and females united in the same performance.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixedly</ent><br/
<hw>Mix"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mixed or
mingled manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixen</ent><br/
<hw>Mix"en</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>mixen</ets>,
<ets>myxen</ets>, fr. <ets>meohx</ets>, <ets>meox</ets>, dung, filth;
akin to E. <ets>mist</ets>. See <er>Mist</er>.]</ety> <def>A compost
heap; a dunghill.</def> <rj><au>Chaucer. Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixer</ent><br/
<hw>Mix"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or
that which, mixes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who has social intercourse with others of
many sorts; a person viewed as to his casual sociability; -- commonly
used with some characterizing adjective; <as>as, a good <ex>mixer</ex>;
a bad <ex>mixer</ex></as>.</def> <mark>[Colloq. or Slang, U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>a social gathering, game, or dance organized to
provide an opportunity for people to meet each other; <as>as, on the
first night of the conference they had a wine-and-cheese
<ex>mixer</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a nonalcoholic beverage (such as fruit juice, club
soda or ginger ale) added to an alcoholic beverage to produce a mixed
drink.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>any device used for mixing.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>an electronic device for blending or manipulating
sounds from different sources to produce a composite soundtrack, for an
audio recording, video recording, or a movie.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>The technician who operates a
<er>mixer{6}</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mixogamous</ent><br/
<hw>Mix*og"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ a
mixing + <?/ marriage.]</ety> <fld>(Zool.)</fld> <def>Pairing with
several males; -- said of certain fishes of which several males
accompany each female during spawning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixolydian mode</ent><br/
<hw>Mix`o*lyd"i*an mode`</hw> <pr>(?)</pr>. <ety>[Gr. <?/ a mixing + E.
<ets>Lydian</ets>.]</ety> <fld>(Mus.)</fld> <def>The seventh
ecclesiastical mode, whose scale commences on G.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixtilinear</ent><br/
<ent>Mixtilineal</ent><br/
<mhw>{ <hw>Mix`ti*lin"e*al</hw> <pr>(?)</pr>, <hw>Mix`ti*lin"e*ar</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>mixtus</ets> mixed (p.
p. of <ets>miscere</ets> to mix) + E. <ets>lineal</ets>,
<ets>linear</ets>.]</ety> <def>Containing, or consisting of, lines of
different kinds, as straight, curved, and the like; <as>as, a
<ex>mixtilinear</ex> angle, that is, an angle contained by a straight
line and a curve</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixtion</ent><br/
<hw>Mix"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mixtio</ets>, <ets>mistio</ets>: cf. F. <ets>mixtion</ets>. See
<er>Mistion</er>, <er>Mix</er>.]</ety> <sn>1.</sn> <def>Mixture.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of cement made of mastic, amber, etc., used
as a mordant for gold leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixtly</ent><br/
<hw>Mixt"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With mixture; in a
mixed manner; mixedly.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mixture</ent><br/
<hw>Mix"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mixtura</ets>, fr. <ets>miscere</ets>, <ets>mixtum</ets>, to mix:
cf. F. <ets>mixture</ets>. See <er>Mix</er>.]</ety> <sn>1.</sn> <def>The
act of mixing, or the state of being mixed; <as>as, made by a
<ex>mixture</ex> of ingredients</as>.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which results from mixing different ingredients
together; a compound; <as>as, to drink a <ex>mixture</ex> of molasses
and water</as>; -- also, a medley.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is also a <qex>mixture</qex> of good and evil wisely
distributed by God, to serve the ends of his providence.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An ingredient entering into a mixed mass; an
additional ingredient.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cicero doubts whether it were possible for a community to exist
that had not a prevailing <qex>mixture</qex> of piety in its
constitution.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>A kind of liquid medicine made up
of many ingredients; esp., as opposed to <contr>solution</contr>, a
liquid preparation in which the solid ingredients are not completely
dissolved.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Physics & Chem.)</fld> <def>A mass of two or more
ingredients, the particles of which are separable, independent, and
uncompounded with each other, no matter how thoroughly and finely
commingled; -- contrasted with a <contr>compound</contr> and
<contr>solution</contr>; <as>thus, gunpowder is a mechanical
<ex>mixture</ex> of carbon, sulphur, and niter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mus.)</fld> <def>An organ stop, comprising from two
to five ranges of pipes, used only in combination with the foundation
and compound stops; -- called also <altname>furniture stop</altname>. It
consists of high harmonics, or overtones, of the ground tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Union; admixture; intermixture; medley.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>mix up</ent><br/
<hw>mix up</hw> <pos>n.</pos> <sn>1.</sn> <def>To confuse the identities
of (two or more objects); to mistake (one object for another); <as>as,
at the family gathering he <ex>mixed up</ex> his two nieces, to their
great amusement</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To mix together; -- usually implying a mistake,
whether done intentionally or unintentionally; <as>as, the <ex>mixed
up</ex> this year's receipts with last year's, and it took hours to find
the right ones</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>mix-up</ent><br/
<hw>mix-up</hw> <pos>n.</pos> <def>a mistake that results from taking
one thing to be another.</def><br/
<syn><b>Syn. --</b> confusion, confounding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mizenmast</ent><br/
<hw>mizenmast</hw> <pos>n.</pos> <def>mizzenmast.</def><br/
<syn><b>Syn. --</b> mizzen, mizen.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mizmaze</ent><br/
<hw>Miz"maze`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A maze or
labyrinth.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mizzen</ent><br/
<hw>Miz"zen</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It.
<ets>mezzana</ets>, fr. <ets>mezzano</ets> middle, fr. <ets>mezzo</ets>
middle, half: cf. F. <ets>misaine</ets> foresail. See
<er>Mezzo</er>.]</ety> <fld>(Naut.)</fld> <def>Hindmost; nearest the
stern; <as>as, the <ex>mizzen</ex> shrouds, sails, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mizzen</ent><br/
<hw>Miz"zen</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>The hindmost of
the fore and aft sails of a three-masted vessel; also, the
spanker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mizzenmast</ent><br/
<hw>Miz"zen*mast</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>the third mast from the bow in a vessel having three or more masts;
the after and shorter mast of a yawl, ketch, or dandy.</def> <note>The
definition varies slightly with the dictionary; in some dictionaries it
is the last mast of a three-masted vessel; in others, it is the mast
after the mainmast of a vessel of three or more masts. PJC.</note><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Mizzle</ent><br/
<hw>Miz"zle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mizzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mizzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[See
<er>Misle</er>, and cf. <er>Mistle</er>.]</ety> <sn>1.</sn> <def>To rain
in very fine drops; to drizzle.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take one's self off; to go.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As long as George the Fourth could reign, he reigned,<br/
And then he <qex>mizzled</qex>.</q> <rj><qau>Epigram, quoted by
Wright.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mizzle</ent><br/
<hw>Miz"zle</hw>, <pos>n.</pos> <def>Mist; fine rain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mizzy</ent><br/
<hw>Miz"zy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>moisi</ets> moldy, musty, p. p. of <ets>moisir</ets> to mold, fr.
L. <ets>mucere</ets> to be moldy.]</ety> <def>A bog or quagmire.</def>
<mark>[Obs.]</mark> <rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>ml</ent><br/
<hw>ml</hw> <pr>(?)</pr>, <pos>n.</pos> <def>milliliter; -- the IS
standard abbreviation.</def> <mark>[abbreviation]</mark><br/
[<source>PJC</source>]</p>

<p><ent>mm</ent><br/
<hw>mm</hw> <pr>(?)</pr>, <pos>n.</pos> <def>millimeter; -- the IS
standard abbreviation.</def> <mark>[abbreviation]</mark><br/
[<source>PJC</source>]</p>

<p><ent>mM</ent><br/
<hw>mM</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>Chem.)</fld>
<def>millimolar; -- the IS standard abbreviation.</def>
<mark>[abbreviation]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Mn</ent><br/
<hw>Mn</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>The
chemical symbol for <altname>manganese</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>M'-Naught</ent><br/
<hw>M'-Naught"</hw> <pr>(m<ait/k*n<add/t")</pr>, <pos>v. t.</pos>
<fld>(Steam Engines)</fld> <def>To increase the power of (a
single-cylinder beam engine) by adding a small high-pressure cylinder
with a piston acting on the beam between the center and the flywheel
end, using high-pressure steam and working as a compound engine, -- a
plan introduced by <persfn>M'Naught</persfn>, a Scottish engineer, in
1845.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mnemonical</ent><br/
<ent>Mnemonic</ent><br/
<mhw>{ <hw>Mne*mon"ic</hw> <pr>(n<esl/*m<ocr/n"<icr/k)</pr>,
<hw>Mne*mon"ic*al</hw> <pr>(n<esl/*m<ocr/n"<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[Gr. <grk>mnhmoniko`s</grk>, fr. <grk>mnh`mwn</grk>
mindful, remembering, <grk>mnh`mh</grk> memory, <grk>mna^sqai</grk> to
think on, remember; akin to E. <ets>mind</ets>.]</ety> <def>Assisting in
memory; helping to remember; <as>as, a <ex>mnemonic</ex>
device</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mnemonic</ent><br/
<hw>mnemonic</hw> <pos>n.</pos> <sn>1.</sn> <def>Something used to
assist the memory, as an easily remembered acronym or verse.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An abbreviated word that resembles the full word,
used so as to be easily recognized; <as>as, the CIDE uses <it>...</it>
tags as <ex>mnemnonics</ex> for an italicised word or
field</as>.</def><br/
[<source>PJC</source>]</p>

<p><note> In basic organic chemistry class, one may learn the
<ex>mnenomic</ex> <ldquo/Oh my, such good apple pie<rdquo/ to help
remember the names of the dicarboxylic acids in increasing order of
length, namely: oxalic, malonic, succinic, glutaric, adipic, and pimelic
acids. (From L. Fieser's Organic Chemistry text).</note></p>

<p><ent>Mnemonician</ent><br/
<hw>Mne`mo*ni"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
instructs in the art of improving or using the memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mnemonics</ent><br/
<hw>Mne*mon"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>ta~
mnhmonika`</grk>: cf. F. <ets>mn<eacute/monique</ets>.]</ety> <def>The
art of memory; a method for improving the memory; a system of precepts
and rules intended to assist the memory; artificial memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mnemosyne</ent><br/
<hw>Mne*mos"y*ne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>mnhmosy`nh</grk> remembrance, memory, and the goddess of memory.
See <er>Mnemonic</er>.]</ety> <fld>(Class Myth.)</fld> <def>The goddess
of memory and the mother of the Muses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mnemotechnical</ent><br/
<hw>mnemotechnical</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>mnemonic</er>.</def><br/
<syn><b>Syn. --</b> mnemonic, mnemotechnic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mnemotechny</ent><br/
<hw>Mne"mo*tech`ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ memory
+ <?/ art: cf. F. <ets>mn<eacute/motechnie</ets>.]</ety>
<def>Mnemonics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mniaceae</ent><br/
<hw>Mniaceae</hw> <pos>prop. n.</pos> <def>A natural family of erect
mosses with club-shaped paraphyses andgonal cells of the upper leaf
surface; sometimes treated as a subfamily of
<fam>Bryaceae</fam>.</def><br/
<syn><b>Syn. --</b> family <fam>Mniaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mnium</ent><br/
<hw>Mnium</hw> <pos>prop. n.</pos> <def>A genus of mosses similar to
those of genus <gen>Bryum</gen> but larger.</def><br/
<syn><b>Syn. --</b> genus <gen>Mnium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mo</ent><br/
<hw>Mo</hw> <pr>(m<omac/)</pr>, <pos>a., adv., & n.</pos>
<altsp>[Written also <asp>moe</asp>.]</altsp> <ety>[AS.
<ets>m<amac/</ets>. See <er>More</er>.]</ety> <def>More; -- usually,
more in number.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>An hundred thousand <qex>mo</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Likely to find <qex>mo</qex> to commend than to imitate it.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mo</ent><br/
<hw>Mo</hw> <pr>(<?/)</pr>, <fld>(Chem.)</fld> <def>chemical symbol for
the element <er>molybdenum</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>MO</ent><br/
<hw>MO</hw> <pr>(<?/)</pr>, <def>abbreviation for <er>modus
operandi</er>, manner of operating; -- often used to refer to the method
an habitual criminal uses to perpetrate his crime.</def><br/
[<source>PJC</source>]</p>

<p><ent>-mo</ent><br/
<hw>-mo</hw> <pr>(?)</pr>. <def>A suffix added to the names of certain
numerals or to the numerals themselves, to indicate the number of leaves
made by folding a sheet of paper; <as>as, sixteen<ex>mo</ex> or
16<ex>mo</ex>; eighteen<xex>mo</xex> or 18<xex>mo</xex></as>. It is
taken from the Latin forms similarly used; <as>as, <xex>duodecimo</xex>,
<xex>sextodecimo</xex>, etc.</as> A small circle, placed after the
number and near its top, is often used for <xex>-mo</xex>; as, 16<deg/,
18<deg/, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moa</ent><br/
<hw>mo"a</hw> <pr>(m<omac/"<adot/)</pr>, <pos>n.</pos> <ety>[Native
name.]</ety> <fld>(Zool.)</fld> <def>Any one of several very large
extinct species of wingless birds belonging to <gen>Dinornis</gen>, and
other related genera, of the suborder <ord>Dinornithes</ord>, found in
<country>New Zealand</country>. They are allied to the apteryx and the
ostrich. They were probably exterminated by the natives before
<country>New Zealand</country> was discovered by Europeans. Some species
were much larger than the ostrich.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moabite</ent><br/
<hw>Mo"ab*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the posterity
of Moab, the son of Lot. (<au>Gen. xix. 37.</au>) Also used
adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moabitess</ent><br/
<hw>Mo"ab*i`tess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
Moabite.</def> <rj><au>Ruth i. 22.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moabite stone</ent><br/
<hw>Mo"ab*ite stone</hw> <pr>(?)</pr>. <fld>(Archaeol.)</fld> <def>A
block of black basalt, found at Dibon in Moab by <person>Rev. F. A.
Klein</person>, Aug. 19, 1868, which bears an inscription of thirty-four
lines, dating from the 9th century <sc>b. c.</sc>, and written in the
Moabite alphabet, the oldest Phoenician type of the Semitic alphabet. It
records the victories of <persfn>Mesha</persfn>, king of
<xex>Moab</xex>, esp. those over Israel (<au>2 Kings iii. 4, 5,
27</au>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moabitish</ent><br/
<hw>Mo"ab*i`tish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Moabite.</def>
<rj><au>Ruth ii. 6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moan</ent><br/
<hw>Moan</hw> <pr>(m<omac/n)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Moaned</conjf> <pr>(m<omac/nd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Moaning</conjf>.]</vmorph> <ety>[AS.
<ets>m<aemac/nan</ets> to moan, also, to mean; but in the latter sense
perh. a different word. Cf. <er>Mean</er> to intend.]</ety> <sn>1.</sn>
<def>To make a low prolonged sound of grief or pain, whether articulate
or not; to groan softly and continuously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unpitied and unheard, where misery <qex>moans</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let there bechance him pitiful mischances,<br/
To make him <qex>moan</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To emit a sound like moan; -- said of things
inanimate; <as>as, the wind <ex>moans</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moan</ent><br/
<hw>Moan</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To bewail audibly; to
lament.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye floods, ye woods, ye echoes, <qex>moan</qex><br/
My dear Columbo, dead and gone.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To afflict; to distress.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which infinitely <qex>moans</qex> me.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moan</ent><br/
<hw>Moan</hw>, <pos>n.</pos> <ety>[OE. <ets>mone</ets>. See
<er>Moan</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>A low prolonged
sound, articulate or not, indicative of pain or of grief; a low
groan.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sullen <qex>moans</qex>, hollow groans.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A low mournful or murmuring sound; -- of
things.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rippling waters made a pleasant <qex>moan</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moanful</ent><br/
<hw>Moan"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of moaning;
expressing sorrow.</def> -- <wordforms><wf>Moan"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moat</ent><br/
<hw>Moat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>mote</ets>
hill, dike, bank, F. <ets>motte</ets> clod, turf: cf. Sp. & Pg.
<ets>mota</ets> bank or mound of earth, It. <ets>motta</ets> clod, LL.
<ets>mota</ets>, <ets>motta</ets>, a hill on which a fort is built, an
eminence, a dike, Prov. G. <ets>mott</ets> bog earth heaped up; or perh.
F. <ets>motte</ets>, and OF. <ets>mote</ets>, are from a LL. p. p. of L.
<ets>movere</ets> to move (see <er>Move</er>). The name of
<ets>moat</ets>, properly meaning, bank or mound, was transferred to the
ditch adjoining: cf. F. <ets>dike</ets> and <ets>ditch</ets>.]</ety>
<fld>(Fort.)</fld> <def>A deep trench around the rampart of a castle or
other fortified place, sometimes filled with water; a ditch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moat</ent><br/
<hw>Moat</hw>, <pos>v. t.</pos> <def>To surround with a moat.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moate</ent><br/
<hw>Moate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See <er>Mute</er> to
molt.]</ety> <def>To void the excrement, as a bird; to mute.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mob</ent><br/
<hw>Mob</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mobcap</er>.]</ety> <def>A mobcap.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mob</ent><br/
<hw>Mob</hw>, <pos>v. t.</pos> <def>To wrap up in, or cover with, a
cowl.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mob</ent><br/
<hw>Mob</hw>, <pos>n.</pos> <ety>[L. <ets>mobile vulgus</ets>, the
movable common people. See <er>Mobile</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>The lower classes of a community; the populace, or the
lowest part of it.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A cluster of <qex>mob</qex> were making themselves merry with
their betters.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A throng; a rabble; esp., an
unlawful or riotous assembly; a disorderly crowd.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mob</qex> of gentlemen who wrote with ease.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Had every Athenian citizen been a Socrates, every Athenian
assembly would still have been a <qex>mob</qex>.</q>
<rj><qau>Madison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Confused by brainless <qex>mobs</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A criminal organization or organized criminal gangs,
collectively; the Mafia; the syndicate; <as>as, he was a lawyer for the
<ex>mob</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Mob law</b></col>, <cd>law administered by the mob; lynch
law.</cd> -- <col><b>Swell mob</b></col>, <cd>well dressed thieves and
swindlers, regarded collectively.</cd> <mark>[Slang]</mark>
<au>Dickens.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mob</ent><br/
<hw>Mob</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mobbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mobbing</conjf>.]</vmorph> <def>To crowd about, as a mob, and
attack or annoy; <as>as, to <ex>mob</ex> a house or a
person</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobbish</ent><br/
<hw>Mob"bish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a mob;
tumultuous; lawless; <as>as, a <ex>mobbish</ex> act</as>.</def>
<rj><au>Bp. Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobcap</ent><br/
<hw>Mob"cap`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>mop-muts</ets>; OD. <ets>mop</ets> a woman's coif + D.
<ets>muts</ets> cap.]</ety> <def>A plain cap or headdress for women or
girls; especially, one tying under the chin by a very broad band,
generally of the same material as the cap itself.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobile</ent><br/
<hw>Mo"bile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mobilis</ets>, for <ets>movibilis</ets>, fr. <ets>movere</ets> to
move: cf. F. <ets>mobile</ets>. See <er>Move</er>.]</ety> <sn>1.</sn>
<def>Capable of being moved; not fixed in place or condition;
movable.</def> <ldquo/Fixed or else <xex>mobile</xex>.<rdquo/
<rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by an extreme degree of fluidity;
moving or flowing with great freedom; <as>as, benzine and mercury are
<ex>mobile</ex> liquids; -- opposed to <ex>viscous</ex>,
<ex>viscoidal</ex>, or <ex>oily</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Easily moved in feeling, purpose, or direction;
excitable; changeable; fickle.</def> <rj><au>Testament of
Love.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The quick and <qex>mobile</qex> curiosity of her disposition.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Changing in appearance and expression under the
influence of the mind; <as>as, <ex>mobile</ex> features</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Physiol.)</fld> <def>Capable of being moved,
aroused, or excited; capable of spontaneous movement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Capable of moving readily, or moving frequenty from
place to place; <as>as, a <ex>mobile</ex> work force</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>Having motor vehicles to permit movement from place
to place; <as>as, a <ex>mobile</ex> library; a <ex>mobile</ex>
hospital</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mobile</ent><br/
<hw>Mo"bile</hw> <pr>(m<omac/"b<icr/l; L. m<ocr/b"<icr/*l<emac/)</pr>,
<pos>n.</pos> <ety>[L. <ets>mobile vulgus</ets>. See <er>Mobile</er>,
<pos>a.</pos>, and cf. 3d <er>Mob</er>.]</ety> <def>The mob; the
populace.</def> <mark>[Obs.]</mark> <ldquo/The unthinking
<xex>mobile</xex>.<rdquo/ <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobile</ent><br/
<hw>Mo"bile</hw> <pr>(m<omac/"b<emac/l`)</pr>, <pos>n.</pos> <def>a form
of sculpture having several sheets or rods of a stiff material attached
to each other by thin wire or twine in a balanced and artfully arranged
tree configuration, with the topmost member suspended in air from a
support so that the parts may move independently when set in motion by a
current of air.</def> <br/
[<source>1913 Webster</source>]</p>

<p><ent>mobilise</ent><br/
<hw>mobilise</hw> <pos>n.</pos> <sn>1.</sn> <def>Mobilize.</def>
<mark>[Chiefly Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mobilisation</ent><br/
<hw>mobilisation</hw> <pos>n.</pos> <def>Mobilization.</def>
<mark>[Chiefly Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 934 --></p>

<p><ent>Mobility</ent><br/
<hw>Mo*bil"i*ty</hw> <pr>(m<osl/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>mobilitas</ets>: cf. F.
<ets>mobilit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The quality or state
of being mobile; <as>as, the <ex>mobility</ex> of a liquid, of an army,
of the populace, of features, of a muscle</as>.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mob; the lower classes.</def>
<mark>[Humorous]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobilization</ent><br/
<hw>Mob`i*li*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mobilization</ets>.]</ety> <def>The act of mobilizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobilize</ent><br/
<hw>Mob"i*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mobilized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mobilizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>mobiliser</ets>.]</ety> <sn>1.</sn> <def>To assemble and organize
and make ready for use or action; <as>as, to <ex>mobilize</ex>
volunteers for the election campaign</as>.</def><br/
<syn><b>Syn. --</b> mobilise, marshal.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>To put in a state of
readiness for active service in war, as an army corps; <as>as, to
<ex>mobilize</ex> the National Guard</as>.</def><br/
<syn><b>Syn. --</b> mobilise, militarize, militarise.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobius strip</ent><br/
<ent>Moebius strip</ent><br/
<mhw><hw>Mo"bi*us strip`</hw>, <hw>M<oum/"bi*us strip`</hw>,
<hw>Moe"bi*us strip`</hw></mhw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<person>August F. <etsep>M<oum/bius</etsep></person>, a German
mathematician.]</ety> <def>A mathematical object, or a physical
representation of it, which is a two-dimensional sheet with only one
surface. It is constructed or visualized as a rectangle, one end of
which is held fixed while the opposite end is twisted through a 180
degree angle and joined to the fixed end. It is a two-dimensional object
that can only exist in a three-dimensional space.</def><br/
[<source>PJC</source>]</p>

<p><note>The moebius strip was the subject of a famous woodcut by
<person>M. Escher</person>, published in 1963.</note><br/
[<source>PJC</source>]</p>

<p><ent>Moble</ent><br/
<hw>Mo"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[From <er>Mob</er>
to wrap up.]</ety> <def>To wrap the head of in a hood.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobles</ent><br/
<hw>Mo"bles</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Moebles</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobocracy</ent><br/
<hw>Mob*oc"ra*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mob</ets>
rabble + <ets>-cracy</ets>, as in <ets>democracy</ets>.]</ety> <def>A
condition in which the lower classes of a nation control public affairs
without respect to law, precedents, or vested rights.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is good name that Dr. Stevens has given to our present
situation (for one can not call it a government), a
<qex>mobocracy</qex>.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobocrat</ent><br/
<hw>Mob"o*crat</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who favors a
form of government in which the unintelligent populace rules without
restraint.</def> <rj><au>Bayne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mobocratic</ent><br/
<hw>Mob`o*crat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, or relating
to, a mobocracy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mocassin</ent><br/
<hw>mocassin</hw> <pos>n.</pos> <def>Variant spelling of
<er>moccasin</er>.</def><br/
<syn><b>Syn. --</b> moccasin, moccasins.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>moccasin</ent><br/
<hw>moc"ca*sin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[An Indian word.
Algonquin <ets>makisin</ets>.]</ety> <altsp>[Sometimes written
<asp>moccason</asp>.]</altsp> <sn>1.</sn> <def>A shoe made of deerskin,
or other soft leather, the sole and upper part being one piece. It is
the customary shoe worn by the American Indians.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A poisonous snake of the Southern
United States. The water moccasin (<spn>Ancistrodon piscivorus</spn>
syn. <spn>Agkistrodon piscivorus</spn>, also called
<altname>cottonmouth</altname> and <altname>cottonmouth water
moccasin</altname>) is usually found in or near water. Above, it is
olive brown, barred with black; beneath, it is brownish yellow, mottled
with darker. The upland moccasin is <spn>Ancistrodon atrofuscus</spn>.
They resemble rattlesnakes, but are without rattles.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moccasin flower</b></col> <fld>(Bot.)</fld>, <cd>a
species of lady's slipper (<spn>Cypripedium acaule</spn>) found in North
America. The lower petal is two inches long, and forms a rose-colored
moccasin-shaped pouch. It grows in rich woods under coniferous
trees.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moccasined</ent><br/
<hw>Moc"ca*sined</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered with, or
wearing, a moccasin or moccasins.</def> <ldquo/<xex>Moccasined</xex>
feet.<rdquo/ <rj><au>Harper's Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mocha</ent><br/
<hw>Mo"cha</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A seaport
town of Yemen, on the Red Sea, also spelled <asp>Mukha</asp>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A variety of coffee originally brought from
Mocha.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An Abyssinian weight, equivalent to a Troy
grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A flavoring made from an infusion of coffee or of a
combination of coffee with chocolate or cocoa.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>A color of a deep chocolate brown.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Mocha stone</b></col> <fld>(Min.)</fld>, <cd>moss
agate.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moche</ent><br/
\'d8<hw>Moche</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
bale of raw silk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moche</ent><br/
<hw>Moche</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Much.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mochel</ent><br/
<hw>Moch"el</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <def>Much.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mochila</ent><br/
\'d8<hw>Mo*chi"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>A large leather flap which covers the saddletree.</def>
<mark>[Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mock</ent><br/
<hw>Mock</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mocked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mocking</conjf>.]</vmorph> <ety>[F. <ets>moquer</ets>, of
uncertain origin; cf. OD. <ets>mocken</ets> to mumble, G.
<ets>mucken</ets>, OSw. <ets>mucka</ets>.]</ety> <sn>1.</sn> <def>To
imitate; to mimic; esp., to mimic in sport, contempt, or derision; to
deride by mimicry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To see the life as lively <qex>mocked</qex> as ever<br/
Still sleep <qex>mocked</qex> death.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mocking</qex> marriage with a dame of France.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To treat with scorn or contempt; to
deride.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Elijah <qex>mocked</qex> them, and said, Cry aloud.</q> <rj><qau>1
Kings xviii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let not ambition <qex>mock</qex> their useful toil.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To disappoint the hopes of; to deceive; to
tantalize; <as>as, to <ex>mock</ex> expectation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou hast <qex>mocked</qex> me, and told me lies.</q>
<rj><qau>Judg. xvi. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He will not . . . <br/
<qex>Mock</qex> us with his blest sight, then snatch him hence.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To deride; ridicule; taunt; jeer; tantalize;
disappoint. See <er>Deride</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mock</ent><br/
<hw>Mock</hw>, <pos>v. i.</pos> <def>To make sport in contempt or in
jest; to speak in a scornful or jeering manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When thou <qex>mockest</qex>, shall no man make thee ashamed?</q>
<rj><qau>Job xi. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She had <qex>mocked</qex> at his proposal.</q>
<rj><qau>Froude.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mock</ent><br/
<hw>Mock</hw>, <pos>n.</pos> <sn>1.</sn> <def>An act of ridicule or
derision; a scornful or contemptuous act or speech; a sneer; a jibe; a
jeer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fools make a <qex>mock</qex> at sin.</q> <rj><qau>Prov. xiv.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Imitation; mimicry.</def> <mark>[R.]</mark>
<rj><au>Crashaw.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mock</ent><br/
<hw>Mock</hw>, <pos>a.</pos> <def>Imitating reality, but not real;
false; counterfeit; assumed; sham.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That superior greatness and <qex>mock</qex> majesty.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mock bishop's weed</b></col> <fld>(Bot.)</fld>, <cd>a
genus of slender umbelliferous herbs (<gen>Discopleura</gen>) growing in
wet places.</cd> -- <col><b>Mock heroic</b></col>, <cd>burlesquing the
heroic; <as>as, a <ex>mock heroic</ex> poem</as>.</cd> -- <col><b>Mock
lead</b></col>. <cd>See <er>Blende</er> (<sd>a</sd>).</cd> --
<col><b>Mock nightingale</b></col> <fld>(Zool.)</fld>, <cd>the European
blackcap.</cd> -- <col><b>Mock orange</b></col> <fld>(Bot.)</fld>, <cd>a
genus of American and Asiatic shrubs (<gen>Philadelphus</gen>), with
showy white flowers in panicled cymes. <spn>Philadelphus
coronarius</spn>, from Asia, has fragrant flowers; the American kinds
are nearly scentless.</cd> -- <col><b>Mock sun</b></col>. <cd>See
<er>Parhelion</er>.</cd> -- <col><b>Mock turtle soup</b></col>, <cd>a
soup made of calf's head, veal, or other meat, and condiments, in
imitation of green turtle soup.</cd> -- <col><b>Mock velvet</b></col>,
<cd>a fabric made in imitation of velvet. See
<er>Mockado</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockable</ent><br/
<hw>Mock"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
mocked.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockado</ent><br/
<hw>Mock"a*do</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stuff made in
imitation of velvet; -- probably the same as <altname>mock
velvet</altname>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Our rich <qex>mockado</qex> doublet.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockadour</ent><br/
<hw>Mock"a*dour</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mokadour</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockage</ent><br/
<hw>Mock"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mockery.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockbird</ent><br/
<hw>Mock"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European sedge warbler (<spn>Acrocephalus
phragmitis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mocker</ent><br/
<hw>Mock"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, mocks; a scorner; a scoffer; a derider.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A deceiver; an impostor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A mocking bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mocker nut</ent><br/
<ent>mockernut</ent><br/
<mhw><hw>mockernut</hw>, <hw>mocker nut</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <fld>(Bot.)</fld>, <def>A smooth-barked North American
hickory (<spn>Carya tomentosa</spn>) with 7 to 9 leaflets bearing a
hard-shelled edible nut, which is far inferior to the true shagbark
hickory nut.</def><br/
<syn><b>Syn. --</b> mockernut hickory, black hickory, white-heart
hickory, big-bud hickory, <spn>Carya tomentosa</spn> .</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The fruit of the mockernut{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mockery</ent><br/
<hw>Mock"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mockeries</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>moquerie</ets>.]</ety> <sn>1.</sn> <def>The act of mocking,
deriding, and exposing to contempt, by mimicry, by insincere imitation,
or by a false show of earnestness; a counterfeit appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is, as the air, invulnerable,<br/
And our vain blows malicious <qex>mockery</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Grace at meals is now generally so performed as to look more like
a <qex>mockery</qex> upon devotion than any solemn application of the
mind to God.</q> <rj><qau>Law.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And bear about the <qex>mockery</qex> of woe.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Insulting or contemptuous action or speech;
contemptuous merriment; derision; ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The laughingstock of fortune's <qex>mockeries</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Subject of laughter, derision, or sport.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cruel handling of the city whereof they made a
<qex>mockery</qex>.</q> <rj><qau>2 Macc. viii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mocking</ent><br/
<hw>Mock"ing</hw>, <pos>a.</pos> <def>Imitating, esp. in derision, or so
as to cause derision; mimicking; derisive.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mocking thrush</b></col> <fld>(Zool.)</fld>, <cd>any
species of the genus <gen>Harporhynchus</gen>, as the brown thrush
(<spn>Harporhynchus rufus</spn>).</cd> -- <col><b>Mocking wren</b></col>
<fld>(Zool.)</fld>, <cd>any American wren of the genus
<gen>Thryothorus</gen>, esp. <spn>Thryothorus
Ludovicianus</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mocking bird</ent><br/
<ent>mockingbird</ent><br/
<mhw><hw>mockingbird</hw>, <hw>mocking bird</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld>, <def>A long-tailed gray-and-white songbird of North
America (<spn>Mimus polyglottos</spn>), remarkable for its exact
imitations of the notes of other birds. Its back is gray; the tail and
wings are blackish, with a white patch on each wing; the outer tail
feathers are partly white. Originally its range was confined mostly to
the southern states, but by late 19th century it had migrated as far
north as New York. The name is also applied to other members of thee
same and related genera, found in Mexico, Central America, and the West
Indies, such as the <ecol><b>blue mockingbird</b></ecol> of Mexico,
<spn>Melanotis caerulescens</spn>.</def><br/
<syn><b>Syn. --</b> mocker, <spn>Mimus polyglottos</spn> .</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mockingly</ent><br/
<hw>Mock"ing*ly</hw>, <pos>adv.</pos> <def>By way of derision; in a
contemptuous or mocking manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockingstock</ent><br/
<hw>Mock"ing*stock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A butt of
sport; an object of derision.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockish</ent><br/
<hw>Mock"ish</hw>, <pos>a.</pos> <def>Mock; counterfeit; sham.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mockle</ent><br/
<hw>Moc"kle</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Mickle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moco</ent><br/
<hw>Mo"co</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
South American rodent (<spn>Cavia rupestris</spn>), allied to the Guinea
pig, but larger; -- called also <altname>rock cavy</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modal</ent><br/
<hw>Mo"dal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>modal</ets>. See <er>Mode</er>.]</ety> <sn>1.</sn> <def>Of or
pertaining to a mode or mood; consisting in mode or form only; relating
to form; having the form without the essence or reality.</def>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic & Metaph.)</fld> <def>Indicating, or
pertaining to, some mode of conceiving existence, or of expressing
thought, such as the modes of possibility or obligation.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>Pertaining to or denoting
mood.</def><br/
[<source>PJC</source>]</p>

<p><ent>Modal</ent><br/
<hw>Mo"dal</hw> <pr>(?)</pr> <fld>(Gram.)</fld>, <pos>n.</pos> <def>A
modal auxiliary.</def><br/
[<source>PJC</source>]</p>

<p><ent>modal auxiliary</ent><br/
<hw>mo"dal aux*il"iar*y</hw> <pr>(?)</pr> <fld>(Gram.)</fld>,
<pos>n.</pos> <def>Any one of the auxiliary verbs of English, such as
<examp>can</examp>, <examp>may</examp>, <examp>will</examp>,
<examp>shall</examp>, <examp>must</examp>, <examp>might</examp>,
<examp>could</examp>, <examp>would</examp>, or <examp>should</examp>,
which are used together with the infinitive form of another verb to
express distinctions of mood{2}, such as uncertainty, possibility,
command, emphasis, and obligation.</def><br/
[<source>PJC</source>]</p>

<p><ent>Modalist</ent><br/
<hw>Mo"dal*ist</hw>, <pos>n.</pos> <fld>(Theol.)</fld> <def>One who
regards Father, Son, and Spirit as modes of being, and not as persons,
thus denying personal distinction in the Trinity.</def>
<rj><au>Eadie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modality</ent><br/
<hw>Mo*dal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>modalit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The quality or state
of being modal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic & Metaph.)</fld> <def>A modal relation or
quality; a mode or point of view under which an object presents itself
to the mind. According to Kant, the quality of propositions, as
assertory, problematical, or apodeictic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>modal logic</ent><br/
<hw>mo"dal log"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A system of
logic which studies how to combine propositions which include the
concepts of necessity, possibility, and obligation.</def><br/
[<source>PJC</source>]</p>

<p><ent>Modally</ent><br/
<hw>Mo"dal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a modal
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A compound proposition, the parts of which are united
<qex>modally</qex> . . . by the particles <ldquo/as<rdquo/ and
<ldquo/so.<rdquo/</q> <rj><qau>Gibbs.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mode</ent><br/
<hw>Mode</hw> <pr>(m<omac/d)</pr>, <pos>n.</pos> <ety>[L.
<ets>modus</ets> a measure, due or proper measure, bound, manner, form;
akin to E. <ets>mete</ets>: cf. F. <ets>mode</ets>. See <er>Mete</er>,
and cf. <er>Commodious</er>, <er>Mood</er> in grammar,
<er>Modus</er>.]</ety> <sn>1.</sn> <def>Manner of doing or being;
method; form; fashion; custom; way; style; <as>as, the <ex>mode</ex> of
speaking; the <ex>mode</ex> of dressing.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The duty of itself being resolved on, the <qex>mode</qex> of doing
it may easily be found.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A table richly spread in regal <qex>mode</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Prevailing popular custom; fashion, especially in
the phrase <xex>the mode</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The easy, apathetic graces of a man of the <qex>mode</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Variety; gradation; degree.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Metaph.)</fld> <def>Any combination of qualities or
relations, considered apart from the substance to which they belong, and
treated as entities; more generally, condition, or state of being;
manner or form of arrangement or manifestation; form, as opposed to
<contr>matter</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Modes</qex> I call such complex ideas, which, however
compounded, contain not in them the supposition of subsisting by
themselves, but are considered as dependencies on, or affections of,
substances.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Logic)</fld> <def>The form in which the proposition
connects the predicate and subject, whether by simple, contingent, or
necessary assertion; the form of the syllogism, as determined by the
quantity and quality of the constituent proposition; mood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Gram.)</fld> <def>Same as <er>Mood</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mus.)</fld> <def>The scale as affected by the
various positions in it of the minor intervals; <as>as, the Dorian
<ex>mode</ex>, the Ionic <ex>mode</ex>, etc.</as>, of ancient Greek
music.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In modern music, only the major and the minor mode, of
whatever key, are recognized.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A kind of silk. See <er>Alamode</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Gram.)</fld> <def>the value of the variable in a
frequency distribution or probability distribution, at which the
probability or frequency has a maximum. The maximum may be local or
global. Distributions with only one such maximum are called
<er>unimodal</er>; with two maxima, <er>bimodal</er>, and with more than
two, <er>multimodal</er>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Method; manner. See <er>Method</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- ##??mode of action (Biochem) --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Model</ent><br/
<hw>Mod"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mod<egrave/le</ets>, It. <ets>modello</ets>, fr. (assumed) L.
<ets>modellus</ets>, fr. <ets>modulus</ets> a small measure, dim. of
<ets>modus</ets>. See <er>Mode</er>, and cf. <er>Module</er>.]</ety>
<sn>1.</sn> <def>A miniature representation of a thing, with the several
parts in due proportion; sometimes, a facsimile of the same size;
<as>as, a <frac1x100/ scale <ex>model</ex> of the B-52
bomber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In charts, in maps, and eke in <qex>models</qex> made.</q>
<rj><qau>Gascoigne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I had my father's signet in my purse,<br/
Which was the <qex>model</qex> of that Danish seal.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You have the <qex>models</qex> of several ancient temples, though
the temples and the gods are perished.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something intended to serve, or that may serve, as a
pattern of something to be made; a material representation or embodiment
of an ideal; sometimes, a drawing; a plan; <as>as, the clay
<ex>model</ex> of a sculpture; the inventor's <ex>model</ex> of a
machine.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The application for a patent] must be accompanied by a full
description of the invention, with drawings and a <qex>model</qex> where
the case admits of it.</q> <rj><qau>Am. Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When we mean to build<br/
We first survey the plot, then draw the <qex>model</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything which serves, or may serve, as an example
for imitation; <as>as, a government formed on the <ex>model</ex> of the
American constitution; a <ex>model</ex> of eloquence, virtue, or
behavior.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That by which a thing is to be measured;
standard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that despairs measures Providence by his own little, contracted
<qex>model</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Any copy, or resemblance, more or less
exact.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou seest thy wretched brother die,<br/
Who was the <qex>model</qex> of thy father's life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A person who poses as a pattern for an artist;
<as>as, the artist used his daughter as a <ex>model</ex> for an Indian
maiden</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>7.</sn> <def>A person who is employed to wear clothing for the
purpose of advertising or display, or who poses with a product for the
same purpose; a mannequin{1}; <as>as, a fashion
<ex>model</ex></as>.</def><br/
<syn><b>Syn. --</b> mannequin{1}.</syn><br/
[<source>PJC</source>]</p>

<p><q>A professional <qex>model</qex>.</q> <rj><qau>H.
James.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A particular version or design of an object that is
made in multiple versions; <as>as, the 1993 <ex>model</ex> of the Honda
Accord; the latest <ex>model</ex> of the HP laserjet printer</as>. For
many manufactured products, the <ex>model</ex> name is encoded as part
of the <col><b>model number</b></col>.</def><br/
<syn><b>Syn. --</b> modification{2}.</syn><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <def>An abstract and often simplified conceptual
representation of the workings of a system of objects in the real world,
which often includes mathematical or logical objects and relations
representing the objects and relations in the real-world system, and
constructed for the purpose of explaining the workings of the system or
predicting its behavior under hypothetical conditions; <as>as, the
administration's <ex>model</ex> of the United States economy predicts
budget surpluses for the next fifteen years; different <ex>models</ex>
of the universe assume different values for the cosmological constant;
<ex>models</ex> of proton structure have grown progressively more
complex in the past century</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Working model</b></col>, <cd>a model of a machine which
can do on a small scale the work which the machine itself does, or is
expected to do.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Model</ent><br/
<hw>Mod"el</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Suitable to be taken as
a model or pattern; <as>as, a <ex>model</ex> house; a <ex>model</ex>
husband.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Model</ent><br/
<hw>Mod"el</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Modeled</conjf> <pr>(?)</pr> or <conjf>Modelled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Modeling</conjf> or
<conjf>Modelling</conjf>.]</vmorph> <ety>[Cf. F. <ets>modeler</ets>, It.
<ets>modellare</ets>.]</ety> <def>To plan or form after a pattern; to
form in model; to form a model or pattern for; to shape; to mold; to
fashion; <as>as, to <ex>model</ex> a house or a government; to
<ex>model</ex> an edifice according to the plan
delineated.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Model</ent><br/
<hw>Mod"el</hw>, <pos>v. i.</pos> <fld>(Fine Arts)</fld> <def>To make a
copy or a pattern; to design or imitate forms; <as>as, to <ex>model</ex>
in wax</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>modeled</ent><br/
<hw>modeled</hw> <pos>adj.</pos> <def>resembling sculpture; <as>as, her
finely <ex>modeled</ex> features</as>.</def><br/
<syn><b>Syn. --</b> sculptural, sculptured, sculpturesque.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Modeler</ent><br/
<hw>Mod"el*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who models;
hence, a worker in plastic art.</def> <altsp>[Written also
<asp>modeller</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modeling</ent><br/
<hw>Mod"el*ing</hw>, <pos>n.</pos> <fld>(Fine Arts)</fld> <def>The act
or art of making a model from which a work of art is to be executed; the
formation of a work of art from some plastic material. Also, in
painting, drawing, etc., the expression or indication of solid
form.</def> <altsp>[Written also <asp>modelling</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Modeling plane</b></col>, <cd>a small plane for planing
rounded objects.</cd> -- <col><b>Modeling wax</b></col>, <cd>beeswax
melted with a little Venice turpentine, or other resinous material, and
tinted with coloring matter, usually red, -- used in
modeling.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modelize</ent><br/
<hw>Mod"el*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To model.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>modem</ent><br/
<hw>mo"dem</hw> <pr>(m<omac/"d<ecr/m)</pr>, <pos>n.</pos> <ety>[by
shortening from <ets>mo</ets>dulator-<ets>dem</ets>odulator.]</ety>
<def>An electronic device that converts electronic signals into sound
waves, and sound waves into electronic signals, used to transmit
information between computers by the use of ordinary telephone lines;
also called <altname>modulator-demodulator</altname>; <as>as, the latest
<ex>modems</ex> can transmit data at 56,000 baud over a clear telephone
line</as>. The speed of transmission of information by a modem is
usually measured in units of <er>baud</er>, equivalent to bits per
second.</def><br/
[<source>PJC</source>]</p>

<p><ent>Modena</ent><br/
\'d8<hw>Mod"e*na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Modena</ets>, in Italy.]</ety> <def>A certain crimsonlike
color.</def> <rj><au>Good.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modenese</ent><br/
<hw>Mod`e*nese"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Modena or its inhabitants.</def> -- <def2><pos>n. sing. & pl.</pos>
<def>A native or inhabitant of Modena; the people of
Modena.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moder</ent><br/
<hw>Mo"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. See
<er>Mother</er> female parent.]</ety> <sn>1.</sn> <def>A mother.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The principal piece of an astrolabe, into which the
others are fixed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moder</ent><br/
<hw>Mod"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To moderate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderable</ent><br/
<hw>Mod"er*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>moderabilis</ets>.]</ety> <def>Moderate; temperate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderance</ent><br/
<hw>Mod"er*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Moderation.</def>
<mark>[Obs.]</mark> <rj><au>Caxton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderate</ent><br/
<hw>Mod"er*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>moderatus</ets>, p. p. of <ets>moderate</ets>, <ets>moderati</ets>,
to moderate, regulate, control, fr. <ets>modus</ets> measure. See
<er>Mode</er>.]</ety> <def>Kept within due bounds; observing reasonable
limits; not excessive, extreme, violent, or rigorous; limited;
restrained</def>; as: <sd>(a)</sd> <def>Limited in quantity; sparing;
temperate; frugal; <as>as, <ex>moderate</ex> in eating or drinking; a
<ex>moderate</ex> table</as>.</def> <sd>(b)</sd> <def>Limited in degree
of activity, energy, or excitement; reasonable; calm; slow; <as>as,
<ex>moderate</ex> language; <ex>moderate</ex> endeavors.</as></def>
<sd>(c)</sd> <def>Not extreme in opinion, in partisanship, and the like;
<as>as, a <ex>moderate</ex> Calvinist; a <ex>moderate</ex>
Republican</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A number of <qex>moderate</qex> members managed . . . to obtain a
majority in a thin house.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Not violent or rigorous; temperate; mild; gentle;
<as>as, a <ex>moderate</ex> winter</as>.</def>
<ldquo/<xex>Moderate</xex> showers.<rdquo/ <au>Walter.</au> <sd>(e)</sd>
<def>Limited as to degree of progress; <as>as, to travel at
<ex>moderate</ex> speed</as>.</def> <sd>(f)</sd> <def>Limited as to the
degree in which a quality, principle, or faculty appears; <as>as, an
infusion of <ex>moderate</ex> strength; a man of <ex>moderate</ex>
abilities</as>.</def> <sd>(g)</sd> <def>Limited in scope or effects;
<as>as, a reformation of a <ex>moderate</ex> kind</as>.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderate</ent><br/
<hw>Mod"er*ate</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One of
a party in the Church of Scotland in the 18th century, and part of the
19th, professing moderation in matters of church government, in
discipline, and in doctrine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderate</ent><br/
<hw>Mod"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Moderated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Moderating</conjf>.]</vmorph> <sn>1.</sn> <def>To
restrain from excess of any kind; to reduce from a state of violence,
intensity, or excess; to keep within bounds; to make temperate; to
lessen; to allay; to repress; to temper; to qualify; <as>as, to
<ex>moderate</ex> rage, action, desires, etc.; to <ex>moderate</ex> heat
or wind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>By its astringent quality, it <qex>moderates</qex> the relaxing
quality of warm water.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>moderate</qex> stiff minds disposed to strive.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To preside over, direct, or regulate, as a public
meeting or a discussion; <as>as, to <ex>moderate</ex> a synod; to
<ex>moderate</ex> a debate</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Moderate</ent><br/
<hw>Mod"er*ate</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become less
violent, severe, rigorous, or intense; <as>as, the wind has
<ex>moderated</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To preside as a moderator.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dr. Barlow [was] engaged . . . to <qex>moderate</qex> for him in
the divinity disputation.</q> <rj><qau>Bp. Barlow's Remains
(1693).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>moderated</ent><br/
<hw>moderated</hw> <pos>adj.</pos> <def>having elements or qualities
mixed in proper or suitable proportions; especially, made less severe.
Contrasted with <ant>harsh</ant>.</def><br/
<syn><b>Syn. --</b> qualified, tempered.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Moderately</ent><br/
<hw>Mod"er*ate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a moderate
manner or degree; to a moderate extent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Each nymph but <qex>moderately</qex> fair.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderateness</ent><br/
<hw>Mod"er*ate*ness</hw>, <pos>n.</pos> <def>The quality or state of
being moderate; temperateness; moderation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moderating</ent><br/
<hw>moderating</hw> <pos>adj.</pos> <def>lessening in intensity or
strength. Opposite of <ant>intensifying</ant>.</def> [Narrower terms:
<stype>tempering</stype>; <stype>weakening</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moderation</ent><br/
<hw>Mod`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>moderatio</ets>: cf. F. <ets>mod<eacute/ration</ets>.]</ety>
<sn>1.</sn> <def>The act of moderating, or of imposing due
restraint.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or quality of being mmoderate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>moderation</qex> placing all my glory,<br/
While Tories call me Whig, and Whigs a Tory.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Calmness of mind; equanimity; <as>as, to bear
adversity with <ex>moderation</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The calm and judicious <qex>moderation</qex> of Orange.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>The first public examinations for
degrees at the University of Oxford; -- usually contracted to
<altname>mods</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 935 --></p>

<p><ent>Moderatism</ent><br/
<hw>Mod"er*a*tism</hw> <pr>(m<ocr/d"<etil/r*<asl/*t<icr/z'm)</pr>,
<pos>n.</pos> <def>Moderation in doctrines or opinion, especially in
politics or religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderato</ent><br/
\'d8<hw>Mod`e*ra"to</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[It.
See <er>Moderate</er>.]</ety> <fld>(Mus.)</fld> <def>With a moderate
degree of quickness; moderately.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Allegro moderato</b></col>, <cd>a little slower than
allegro.</cd> -- <col><b>Andante moderato</b></col>, <cd>a little faster
than andante.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderator</ent><br/
<hw>Mod"er*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>mod<eacute/rateur</ets>.]</ety> <sn>1.</sn> <def>One who, or that
which, moderates, restrains, or pacifies.</def> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Angling was . . . a <qex>moderator</qex> of passions.</q>
<rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The officer who presides over an assembly or
discussion to preserve order, propose questions, regulate the
proceedings, and declare the votes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In the University of Oxford, an examiner for
moderations; at Cambridge, the superintendant of examinations for
degrees; at Dublin, either the first (senior) or second (junior) in rank
in an examination for the degree of Bachelor of Arts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A mechanical arrangement for regulating motion in a
machine, or producing equality of effect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderatorship</ent><br/
<hw>Mod"er*a`tor*ship</hw>, <pos>n.</pos> <def>The office of a
moderator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderatress</ent><br/
<hw>Mod"er*a`tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
moderator.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moderatrix</ent><br/
<hw>Mod"er*a`trix</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>A female moderator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modern</ent><br/
<hw>Mod"ern</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>moderne</ets>, L. <ets>modernus</ets>; akin to <ets>modo</ets> just
now, orig. abl. of <ets>modus</ets> measure; hence, by measure, just
now. See <er>Mode</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to the
present time, or time not long past; late; not ancient or remote in past
time; of recent period; <as>as, <ex>modern</ex> days, ages, or time;
<ex>modern</ex> authors; <ex>modern</ex> fashions; <ex>modern</ex>
taste; <ex>modern</ex> practice.</as></def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>New and common; trite; commonplace.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We have our philosophical persons, to make <qex>modern</qex> and
familiar, things supernatural and causeless.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Modern English</b></col>. <cd>See the Note under
<er>English</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modern</ent><br/
<hw>Mod"ern</hw>, <pos>n.</pos> <def>A person of modern times; --
opposed to <ant>ancient</ant>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>modernisation</ent><br/
<hw>modernisation</hw> <pos>n.</pos> <def>Modernization.</def>
<mark>[Chiefly Brit.]</mark> <br/
<syn><b>Syn. --</b> modernizing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Modernism</ent><br/
<hw>Mod"ern*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Modern
practice; a thing of recent date; esp., a modern usage or mode of
expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Certain methods and tendencies which, in Biblical
questions, apologetics, and the theory of dogma, in the endeavor to
reconcile the doctrines of the Roman Catholic Church with the
conclusions of modern science, replace the authority of the church by
purely subjective criteria; -- so called officially by Pope Pius
X.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Modernist</ent><br/
<hw>Mod"ern*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>moderniste</ets>.]</ety> <sn>1.</sn> <def>One who admires the
moderns, or their ways and fashions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An advocate of the teaching of modern subjects, as
modern languages, in preference to the ancient classics.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>modernistic</ent><br/
<hw>modernistic</hw> <pos>adj.</pos> <def>Conspicuously (sometimes
outrageously) modern in style or appearance; <as>as, shiny tables in
<ex>modernistic</ex> design</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Modernity</ent><br/
<hw>Mo*der"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Modernness;
something modern.</def> <rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modernization</ent><br/
<hw>Mod`ern*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
rendering modern in style; the act or process of causing to conform to
modern of thinking or acting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modernize</ent><br/
<hw>Mod"ern*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Modernized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Modernizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>moderniser</ets>.]</ety> <def>To render modern; to adapt to modern
person or things; to cause to conform to recent or present usage or
taste.</def> <rj><au>Percy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modernizer</ent><br/
<hw>Mod"ern*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
modernizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modernly</ent><br/
<hw>Mod"ern*ly</hw>, <pos>adv.</pos> <def>In modern times.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modernness</ent><br/
<hw>Mod"ern*ness</hw>, <pos>n.</pos> <def>The quality or state of being
modern; recentness; novelty.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modest</ent><br/
<hw>Mod"est</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>modeste</ets>, L. <ets>modestus</ets>, fr. <ets>modus</ets>
measure. See <er>Mode</er>.]</ety> <sn>1.</sn> <def>Restraining within
due limits of propriety; not forward, bold, boastful, or presumptious;
rather retiring than pushing one's self forward; not obstructive;
<as>as, a <ex>modest</ex> youth; a <ex>modest</ex> man.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Observing the proprieties of the sex; not unwomanly
in act or bearing; free from undue familiarity, indecency, or lewdness;
decent in speech and demeanor; -- said of a woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mrs. Ford, the honest woman, the <qex>modest</qex> wife.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The blushing beauties of a <qex>modest</qex> maid.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Evincing modestly in the actor, author, or speaker;
not showing presumption; not excessive or extreme; moderate; <as>as, a
<ex>modest</ex> request; <ex>modest</ex> joy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reserved; unobtrusive; diffident; bashful; coy;
shy; decent; becoming; chaste; virtuous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modestly</ent><br/
<hw>Mod"est*ly</hw>, <pos>adv.</pos> <def>In a modest manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modesty</ent><br/
<hw>Mod"es*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>modestia</ets>: cf. F. <ets>modestie</ets>. See
<er>Modest</er>.]</ety> <sn>1.</sn> <def>The quality or state of being
modest; that lowly temper which accompanies a moderate estimate of one's
own worth and importance; absence of self-assertion, arrogance, and
presumption; humility respecting one's own merit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Natural delicacy or shame regarding personal charms
and the sexual relation; purity of thought and manners; due regard for
propriety in speech or action.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her blush is guiltiness, not <qex>modesty</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Modesty piece</b></col>, <cd>a narrow piece of lace worn
by women over the bosom.</cd> <mark>[Obs.]</mark>
<rj><au>Addison.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Bashfulness; humility; diffidence; shyness. See
<er>Bashfulness</er>, and <er>Humility</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modicity</ent><br/
<hw>Mo*dic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>modicitas</ets>; cf. F. <ets>modicit<eacute/</ets>.]</ety>
<def>Moderateness; smallness; meanness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modicum</ent><br/
<hw>Mod"i*cum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>modicus</ets> moderate, fr. <ets>modus</ets>. See
<er>Mode</er>.]</ety> <def>A little; a small quantity; a measured
supply.</def> <ldquo/<xex>Modicums</xex> of wit.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her usual <qex>modicum</qex> of beer and punch.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modifiability</ent><br/
<hw>Mod`i*fi`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Capability
of being modified; state or quality of being modifiable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modifiable</ent><br/
<hw>Mod"i*fi`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Modify</er>.]</ety> <def>Capable of being modified; liable to
modification.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modificable</ent><br/
<hw>Mo*dif"i*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Modifiable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modificate</ent><br/
<hw>Mod"i*fi*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Modify</er>.]</ety> <def>To qualify.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modification</ent><br/
<hw>Mod`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>modificatio</ets> a measuring: cf. F. <ets>modification</ets>. See
<er>Modify</er>.]</ety> <sn>1.</sn> <def>The act of modifying, or the
state of being modified; a change; <as>as, the <ex>modification</ex> of
an opinion, or of a machine.</as></def> <rj><au>Bentley.</au></rj><br/
<syn><b>Syn. --</b> change, alteration, adjustment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something which has been modified; a modified form
or condition; state as modified; <as>as, the various
<ex>modifications</ex> of light; the latest <ex>modification</ex> of the
operating system crashes less frequently</as>.</def><br/
<syn><b>Syn. --</b> model{8}.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>The alteration of the meaning of
a word or phrase by another word or phrase; -- usually a restriction of
the scope of the word modified; <as>as, in the phrase <ldquo/a billion
dollars is a <examp>relatively</examp> small sum to spend on cancer
research<rdquo/ the <ex>modification</ex> of <it>small</it> by
<examp>relatively</examp> is needed to make the sentence accurate,
rather than ludicrous</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Modificative</ent><br/
<hw>Mod"i*fi*ca*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
modifies or qualifies, as a word or clause.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modificatory</ent><br/
<hw>Mod"i*fi*ca`to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending or
serving to modify; modifying.</def> <rj><au>Max
M<uum/ller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modifier</ent><br/
<hw>Mod"i*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, modifies.</def> <rj><au>Hume.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>A word or phrase that modifies
another word, phrase, or sentence, usually by limiting the scope or
restricting the meaning of the sentence element modified.</def><br/
[<source>PJC</source>]</p>

<p><ent>Modify</ent><br/
<hw>Mod"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Modified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Modifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>modifier</ets>, L. <ets>modificare</ets>, <ets>modificari</ets>;
<ets>modus</ets> limit + <ets>-ficare</ets> (in comp.) to make. See
<er>Mode</er>, and <er>-fy</er>.]</ety> <sn>1.</sn> <def>To change
somewhat the form or qualities of; to change a part of something while
leaving most parts unchanged; to alter somewhat; <as>as, to
<ex>modify</ex> a contrivance adapted to some mechanical purpose; to
<ex>modify</ex> the terms of a contract.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To limit or reduce in extent or degree; to moderate;
to qualify; to lower.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of his grace<br/
He <qex>modifies</qex> his first severe decree.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modillion</ent><br/
<hw>Mo*dil"lion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>modillon</ets>, It. <ets>modiglione</ets>. Cf. <er>Module</er>,
<pos>n.</pos>]</ety> <fld>(Arch.)</fld> <def>The enriched block or
horizontal bracket generally found under the cornice of the Corinthian
and Composite entablature, and sometimes, less ornamented, in the Ionic
and other orders; -- so called because of its arrangement at regulated
distances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modiolar</ent><br/
<hw>Mo*di"o*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>modiolus</ets>, dim. of <ets>modius</ets> the Roman corn
measure.]</ety> <def>Shaped like a bushel measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modiolus</ent><br/
\'d8<hw>Mo*di"o*lus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Modioli</plw> <pr>(#)</pr>.</plu> <ety>[L., a small measure.]</ety>
<fld>(Anat.)</fld> <def>The central column in the osseous cochlea of the
ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modish</ent><br/
<hw>Mod"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>According to the mode,
or customary manner; conformed to the fashion; fashionable; hence,
conventional; <as>as, a <ex>modish</ex> dress; a <ex>modish</ex>
feast.</as></def> <au>Dryden.</au> <ldquo/<xex>Modish</xex> forms of
address.<rdquo/ <au>Barrow.</au><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mod"ish*ly</wf>, <pos>adv.</pos> --
<wf>Mod"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modist</ent><br/
<hw>Mod"ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who follows the
fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modiste</ent><br/
\'d8<hw>Mo`diste"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Mode</er>; cf. <er>Modist</er>.]</ety> <def>One, esp. a woman, who
makes, or deals in, articles of fashion, esp. of the fashionable dress
of ladies; a dress-maker or milliner.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Modius</ent><br/
\'d8<hw>Mo"di*us</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Modii</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Rom.
Antiq.)</fld> <def>A dry measure, containing about a peck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modocs</ent><br/
<hw>Mo"docs</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Modoc</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld> <def>A
tribe of warlike Indians formerly inhabiting Northern California. They
are nearly extinct.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modular</ent><br/
<hw>Mod"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
mode, modulation, module, or modius; <as>as, <ex>modular</ex>
arrangement; <ex>modular</ex> accent; <ex>modular</ex>
measure.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modulate</ent><br/
<hw>Mod"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Modulated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Modulating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>modulatus</ets>, p. p. of <ets>modulari</ets> to measure, to
modulate, fr. <ets>modulus</ets> a small measure, meter, melody, dim. of
<ets>modus</ets>. See <er>Mode</er>.]</ety> <sn>1.</sn> <def>To form, as
sound, to a certain key, or to a certain portion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To vary or inflect in a natural, customary, or
musical manner; <as>as, the organs of speech <ex>modulate</ex> the voice
in reading or speaking</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Could any person so <qex>modulate</qex> her voice as to deceive so
many?</q> <rj><qau>Broome.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Electronics)</fld> <def>To alter the amplitude,
frequency, phase, or intensity of (the carrier wave of a radio signal)
at intervals, so as to represent information to be conveyed by the
signal; -- a technique used to convey information by means of radio
waves transmitted by one electronic device and received by
another.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Modulate</ent><br/
<hw>Mod"u*late</hw>, <pos>v. i.</pos> <fld>(Mus.)</fld> <def>To pass
from one key into another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>modulated</ent><br/
<hw>modulated</hw> <pos>adj.</pos> <fld>(Electronics)</fld> <sn>1.</sn>
<def>Having either amplitude, intensity, frequency, or phase altered at
intervals to represent information to be transmitted; -- of the carrier
wave of a radio signal transmitted from one device to another for the
purpose of conveying information. Opposite of
<ant>unmodulated</ant>.</def> [Narrower terms: <stype>frequency
modulated</stype>; <stype>amplitude modulated</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>altered in volume as well as tone or
pitch.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Modulation</ent><br/
<hw>Mod`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>modulatio</ets>: cf. F. <ets>modulation</ets>.]</ety> <sn>1.</sn>
<def>The act of modulating, or the state of being modulated; <as>as, the
<ex>modulation</ex> of the voice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sound modulated; melody.</def> <mark>[R.]</mark>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A change of key, whether
transient, or until the music becomes established in the new key; a
shifting of the tonality of a piece, so that the harmonies all center
upon a new keynote or tonic; the art of transition out of the original
key into one nearly related, and so on, it may be, by successive
changes, into a key quite remote. There are also sudden and unprepared
modulations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Electronics)</fld> <def>The alteration of hte
amplitude, intensity, frequency, or phase (of the carrier wave of a
radio signal) at intervals, so as to represent information to be
transmitted.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Modulator</ent><br/
<hw>Mod"u*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who, or that which, modulates.</def>
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>modulator-demodulator</ent><br/
<hw>mod"u*la`tor-de`mod"u*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>An electronic device that converts electronic signals into sound
waves, and sound waves into electronic signals, used to transmit
information between computers by the use of ordinary telephone lines;
usually called a <altname>modem</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Module</ent><br/
<hw>Mod"ule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>modulus</ets> a small measure, dim. of <ets>modus</ets>. See
<er>Mode</er>, and cf. <er>Model</er>, <er>Modulus</er>, <er>Mold</er> a
matrix.]</ety> <sn>1.</sn> <def>A model or measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>The size of some one part, as the
diameter of semi-diameter of the base of a shaft, taken as a unit of
measure by which the proportions of the other parts of the composition
are regulated. Generally, for columns, the semi-diameter is taken, and
divided into a certain number of parts, called <xex>minutes</xex> (see
<er>Minute</er>), though often the diameter is taken, and any dimension
is said to be so many <xex>modules</xex> and <xex>minutes</xex> in
height, breadth, or projection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Module</ent><br/
<hw>Mod"ule</hw>, <pos>v. t.</pos> <ety>[See <er>module</er>,
<pos>n.</pos>, <er>Modulate</er>.]</ety> <def>To model; also, to
modulate.</def> <mark>[Obs.]</mark> <rj><au>Sandys.</au>
<au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modulus</ent><br/
\'d8<hw>Mod"u*lus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Moduli</plw> <pr>(#)</pr>.</plu> <ety>[L., a small measure. See
<er>Module</er>, <pos>n.</pos>]</ety> <fld>(Math., Mech., &
Physics)</fld> <def>A quantity or coefficient, or constant, which
expresses the measure of some specified force, property, or quality, as
of elasticity, strength, efficiency, etc.; a parameter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Modulus of a machine</b></col>, <cd>a formula expressing
the work which a given machine can perform under the conditions involved
in its construction; the relation between the work done upon a machine
by the moving power, and that yielded at the working points, either
constantly, if its motion be uniform, or in the interval of time which
it occupies in passing from any given velocity to the same velocity
again, if its motion be variable; -- called also the
<xex>efficiency</xex> of the machine.</cd> <au>Mosley.</au>
<au>Rankine.</au> -- <col><b>Modulus of a system of logarithms</b></col>
<fld>(Math.)</fld>, <cd>a number by which all the Napierian logarithms
must be multiplied to obtain the logarithms in another system.</cd> --
<col><b>Modulus of elasticity</b></col>. <sd>(a)</sd> <cd>The measure of
the elastic force of any substance, expressed by the ratio of a stress
on a given unit of the substance to the accompanying distortion, or
strain</cd>. <sd>(b)</sd> <cd>An expression of the force (usually in
terms of the height in feet or weight in pounds of a column of the same
body) which would be necessary to elongate a prismatic body of a
transverse section equal to a given unit, as a square inch or foot, to
double, or to compress it to half, its original length, were that degree
of elongation or compression possible, or within the limits of
elasticity; -- called also <altname>Young's modulus</altname>.</cd> --
<col><b>Modulus of rupture</b></col>, <cd>the measure of the force
necessary to break a given substance across, as a beam, expressed by
eighteen times the load which is required to break a bar of one inch
square, supported flatwise at two points one foot apart, and loaded in
the middle between the points of support.</cd>
<au>Rankine.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modus</ent><br/
\'d8<hw>Mo"dus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Modi</plw> <pr>(#)</pr>.</plu> <ety>[L. See <er>Mode</er>.]</ety>
<fld>(Old Law)</fld> <sn>1.</sn> <def>The arrangement of, or mode of
expressing, the terms of a contract or conveyance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A qualification involving the idea
of variation or departure from some general rule or form, in the way of
either restriction or enlargement, according to the circumstances of the
case, as in the will of a donor, an agreement between parties, and the
like.</def> <rj><au>Bracton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A fixed compensation or equivalent
given instead of payment of tithes in kind, expressed in full by the
phrase <altname>modus decimandi</altname>.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They, from time immemorial, had paid a <qex>modus</qex>, or
composition.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modus operandi</ent><br/
\'d8<hw>Mo"dus op`er*an"di</hw> <pr>(<?/)</pr> <ety>[L.]</ety>,
<def>manner of operating. Often abbreviated to
<altname>MO</altname></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Modus vivendi</ent><br/
\'d8<hw>Mo"dus vi*ven"di</hw> <pr>(?)</pr>. <ety>[L.]</ety> <def>Mode,
or manner, of living; hence, a temporary arrangement of affairs until
disputed matters can be settled.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mody</ent><br/
<hw>Mod"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Mode</er>.]</ety> <def>Fashionable.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moe</ent><br/
<hw>Moe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wry face or mouth; a
mow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moe</ent><br/
<hw>Moe</hw>, <pos>v. i.</pos> <def>To make faces; to mow.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moe</ent><br/
<hw>Moe</hw>, <pos>a., adv., & n.</pos> <ety>[AS. <ets>m<amac/</ets> See
<er>More</er>.]</ety> <def>More. See <er>Mo</er>.</def>
<mark>[Obs.]</mark> <ldquo/Sing no more ditties, sing no
<xex>moe</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moebles</ent><br/
<hw>Moe"bles</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[OE., fr. OF.
<ets>moeble</ets>, <ets>mueble</ets>, movable, from L.
<ets>mobilis</ets>.]</ety> <def>Movables; furniture; -- also used in the
singular (<singw><it>moeble</it></singw>).</def> <mark>[Obs.]</mark> <--
here we mark both the singular word and the written font -->
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moelline</ent><br/
<hw>Mo"el*line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>moelle</ets>, fr. L. <ets>medulla</ets> marrow.]</ety> <def>An
unguent for the hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moellon</ent><br/
<hw>Mo"el*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Rubble masonry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moesogothic</ent><br/
<hw>Moe`so*goth"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging to
the Moesogoths, a branch of the Goths who settled in Moesia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moesogothic</ent><br/
<hw>Moe`so*goth"ic</hw>, <pos>n.</pos> <def>The language of the
Moesogoths; -- also called <altname>Gothic</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moeve</ent><br/
<hw>Moeve</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To move.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moff</ent><br/
<hw>Moff</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A thin silk stuff made in
Caucasia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mog</ent><br/
<hw>Mog</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mogged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mogging</conjf>.]</vmorph> <ety>[Etym. unknown.]</ety> <def>To
move away; to go off.</def> <mark>[Prov. Eng. or Local, U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mogen David</ent><br/
<hw>Mogen David</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hebrew, shield of
David.]</ety> <def>A hexagram{1a}, when used as the symbol of Judaism;
called also <altname>Magen David</altname> and <altname>Star of
David</altname>. It is included on the flag of the state of
Israel</def><br/
<syn><b>Syn. --</b> Star of David, Magen David.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Moggan</ent><br/
<hw>Mog"gan</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A closely fitting knit
sleeve; also, a legging of knitted material.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moghul</ent><br/
<hw>Mo*ghul"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>an alternate from of
<er>mogul</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mogul</ent><br/
<hw>Mo*gul"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the
Mongolian.]</ety> <sn>1.</sn> <def>A person of the Mongolian
race.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>Any of the Mongolian
peoples who conquered parts of India and established an empire lasting
from 1526 to 1857. Also, any of their descendents.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Railroad)</fld> <def>A heavy locomotive for freight
traffic, having three pairs of connected driving wheels and a
two-wheeled truck.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A great personage; magnate; autocrat; <as>as, an
industrial <ex>mogul</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Great Mogul</b></col>, <it>or</it> <col><b>Grand
Mogul</b></col></mcol>, <cd>the sovereign of the empire founded in
Hindustan by the Mongols under <persfn>Baber</persfn> in the sixteenth
century. Hence, a very important personage; a lord; -- sometimes only
<altname>mogul</altname> or <altname>Moghul</altname>.</cd></cs>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mogul</ent><br/
<ent>Moghul</ent><br/
<mhw><hw>Mo*ghul"</hw>, <hw>Mo*gul"</hw></mhw> <pr>(?)</pr>, <pos>prop.
a.</pos> <ety>[See <er>Mogul</er>, <pos>n.</pos>.]</ety> <def>Of or
pertaining to the Moguls{2}; <as>as, The Taj Mahal, the most beautiful
piece of <ex>Mogul</ex> architecture, was built by the <ex>Mogul</ex>
emperor <person>Shah Jehan</person> as a mausoleum for his favorite
wife</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mogul empire</ent><br/
<ent>Moghul empire</ent><br/
<mhw><hw>Mo*ghul" empire</hw>, <hw>Mo*gul" empire</hw></mhw>
<pr>(?)</pr>, <pos>prop. a.</pos> <ety>[See <er>Mogul</er>,
<pos>n.</pos>.]</ety> <def>The empire created in
<country>India</country> by invading Mongolians (Tatars), established
under <persfn>Baber</persfn>, who conquered Hindustan in 1526. The
established religion of the empire was Islam. After the death of the
Great Mogul <persfn>Aurung-Zeb</persfn> in 1707, power passed to the
Mahrattas and the British. The empire existed only nominally in the
early 1800's, and was finally abolished in 1857 by the deposing of the
last emperor.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moha</ent><br/
<hw>Mo"ha</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A kind
of millet (<spn>Setaria Italica</spn>); German millet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mohair</ent><br/
<hw>Mo"hair`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>moire</ets>,
perh. from Ar. <ets>mukhayyar</ets> a kind of coarse camelot or
haircloth; but prob. fr. L. <ets>marmoreus</ets> of marble, resembling
marble. Cf. <er>Moire</er>, <er>Marble</er>.]</ety> <def>The long silky
hair or wool of the Angora goat of Asia Minor; also, a fabric made from
this material, or an imitation of such fabric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mohammed</ent><br/
<hw>Mohammed</hw> <pr>(m<omac/*h<acr/m"m<ecr/d)</pr> <pos>n.</pos>
<ety>['The praised one'.]</ety> <altsp>[Also spelled <asp>Mahomed</asp>,
<asp>Mahomet</asp>, <asp>Muhammad</asp> (the Arabic form),
<asp>Mahmoud</asp>, <asp>Mehemet</asp>, etc.]</altsp> <def>The prophet
who founded Islam (570-632).</def><br/
<syn><b>Syn. --</b> Muhammad, Mahomet, Mahmoud.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><bio> Mohammed (or Mahomet <pr>(ma*hom"et)</pr>) was born at Mecca,
Arabia, about 570: died at Medina, Arabia, June 8, 632. He was the
founder of Islam ('surrender,' namely, to God), formerly also called
Mohammedanism. He was the posthumous son of Abdallah by his wife Amina,
of the family of Hashim, the noblest among the Koreish, and was brought
up in the desert among the Banu Saad by a Bedouin woman named
<persfn>Halima</persfn>. At the age of six he lost his mother, and at
eight his grandfather, when he was cared for by his uncle
<persfn>Abu-Talib</persfn>. When about twelve years old (582) he
accompanied a caravan to Syria, and may on this occasion have come for
the first time in contact with Jews and Christians. A few years later he
took part in the "sacrilegious war" (so called because carried on during
the sacred months, when fighting was forbidden) which raged between the
Koreish and the Banu Hawazin 580-590. He attended sundry preachings and
recitations at Okatz, which may have awakened his poetical and
rhetorical powers and his religious feelings; and for some time was
occupied as a shepherd, to which he later refers as being in accordance
with his career as a prophet, even as it was with that of Moses and
David. When twenty-five years old he entered the service of the widow
<persfn>Khadijah</persfn>, and made a second journey to Syria, on which
he again had an opportunity to come in frequent contact with Jews and
Christians, and to acquire some knowledge of their religious teachings.
He soon married <persfn>Khadijah</persfn>, who was fifteen years his
senior. Of the six children which she bore him, <persfn>Fatima</persfn>
became the most famous. In 605 he attained some influence in
<city>Mecca</city> by settling a dispute about the rebuilding of the
Kaaba. The impressions which he had gathered from his contact with
Judaism and Christianity, and from Arabic lore, began now strongly to
engage his mind. He frequently retired to solitary places, especially to
the cave of Mount Hira, north of Mecca. He passed at that time (he was
then about forty years old) through great mental struggles, and
repeatedly meditated suicide. It must have been during these lonely
contemplations that the yearnings for a messenger from God for his
people, and the thought that he himself might be destined for this
mission, were born in his ardent mind. During one of his reveries, in
the month of Ramadan, 610, he beheld in sleep the angel
<persfn>Gabriel</persfn>, who ordered him to read from a scroll which he
held before him the words which begin the 96th sura (chapter) of the
Koran. After the lapse of some time, a second vision came, and then the
revelations began to follow one another frequently. His own belief in
his mission as apostle and prophet of God was now firmly established.
The first convert was his wife <persfn>Khadijah</persfn>, then followed
his cousin and adopted son <persfn>Ali</persfn>, his other adopted son
<persfn>Zeid</persfn>, and <persfn>Abu-Bekr</persfn>, afterward his
father-in-law and first successor (calif). Gradually about 60 adherents
rallied about him. But after three years' preaching the mass of the
Meccans rose against him, so that part of his followers had to resort to
Abyssinia for safety in 614. This is termed the first hejira. Mohammed
in the meanwhile continued his meetings in the house of one of his
disciples, Arqaan, in front of the Kaaba, which later became known as
the "House of Islam." At one time he offered the Koreish a compromise,
admitting their gods into his system as intercessors with the Supreme
Being, but, becoming conscience-stricken, took back his words. The
conversion of <persfn>Hamza</persfn> and <persfn>Omar</persfn> and 39
others in 615-616 strengthened his cause. The Koreish excommunicated
Mohammed and his followers, who were forced to live in retirement. In
620, at the pilgrimage, he won over to his teachings a small party from
<city>Medina</city>. In <city>Medina</city>, whither a teacher was
deputed, the new religion spread rapidly. To this period belongs the
vision or dream of the miraculous ride, on the winged horse Borak, to
Jerusalem, where he was received by the prophets, and thence ascended to
heaven. In 622 more than 70 persons from Medina bound themselves to
stand by Mohammed. The Meccans proposed to kill him, and he fled on the
20th of June, 622, to Medina. This is known as the hejira ('the
flight'), and marks the beginning of the Muslim era. This event formed a
turning-point in the activity of Mohammed. He was thus far a religious
preacher and persuader; he became in his Medinian period a legislator
and warrior. He built there in 623 the first mosque, and married
<persfn>Ayesha</persfn>. In 624 the first battle for the faith took
place between Mohammed and the Meccans in the plain of Bedr, in which
the latter were defeated. At this time, also, <persfn>Mohammed</persfn>
began bitterly to inveigh against the Jews, who did not recognize his
claims to be the "greater prophet" promised by <persfn>Moses</persfn>.
He changed the attitude of prayer (kibla) from the direction of
Jerusalem to that of the Kaaba in <city>Mecca</city>, appointed Friday
as the day for public worship, and instituted the fast of Ramadan and
the tithe or poor-rate. The Jewish tribe of the Banu Kainuka, settled at
<city>Medina</city>, was driven out; while of another Jewish tribe, the
Banu Kuraiza, all the men, 700 in number, were massacred. In 625
Mohammed and his followers were defeated by the Meccans in the battle of
Ohud. The following years were filled out with expeditions. One tribe
after another submitted to <persfn>Mohammed</persfn>, until in 631
something like a definite Muslim empire was established. In 632 the
prophet made his last pilgrimage to <city>Mecca</city>, known as the
"farewell pilgrimage," or the pilgrimage of the "announcement" or of
"Islam." In the same year he died while planning an expedition against
the frontier of the Byzantine empire. <city>Mohammed</city> was a little
above the middle height, of a commanding figure, and is described as
being of a modest, tender, and generous disposition. His manner of life
was very simple and frugal. He mended his own clothes, and his common
diet was barley-bread and water. But he enjoyed perfumes and the charms
of women. His character appears composed of the strongest
inconsistencies. He could be tender, kind, and liberal, but on occasions
indulged in cruel and perfidious assassinations. With regard to his
prophetic claims, it is as difficult to assume that he was sincere
throughout, or self-deceived, as that he was throughout an impostor. In
his doctrines there is practically nothing original. The legends of the
Koran are chiefly drawn from the Old Testament and the rabbinical
literature, which <persfn>Mohammed</persfn> must have learned from a Jew
near <city>Mecca</city>, though he presents them as original revelations
by the angel <persfn>Gabriel</persfn>, See <er>Koran</er>.</bio><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Mohammedan</ent><br/
<hw>Mo*ham"med*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<ets>Mohammed</ets>, fr. Ar. <ets>muh<aacute/mmad</ets> praiseworthy,
highly praised.]</ety> <def>Of or pertaining to Mohammed, or to Islam,
the religion and institutions founded by Mohammed; in the latter sense,
synonymous with <altname>Islamic</altname>, the term preferred by
Moslems.</def> <altsp>[Written also <asp>Mahometan</asp>,
<asp>Mahomedan</asp>, <asp>Muhammadan</asp>, etc.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mohammedan</ent><br/
<hw>Mo*ham"med*an</hw>, <pos>n.</pos> <def>A follower of Mohammed, the
founder of Islam (also called Islamism or Mohammedanism); an adherent of
Islam; one who professes Islam; a Muslim; a Moslem; a Musselman; -- this
term is used mostly by non-Moslems, and some Moslems find it
offensive.</def> <altsp>[Written also <asp>Muhammadan</asp>,
<asp>Mahometan</asp>, <asp>Mahomedan</asp>, etc.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mohammedan calendar</ent><br/
<hw>Mo*ham"med*an cal"en*dar</hw>. <def>The Muslim calendar, a lunar
calendar reckoning from the year of the hegira (hejira), 622 <sc>a.
d.</sc> Thirty of its years constitute a cycle, of which the 2d, 5th,
7th, 10th, 13th, 16th, 18th, 21st, 24th, 26th, and 29th are leap years,
having 355 days; the others are common, having 354 days.</def> <note>By
the following tables any Mohammedan date may be changed into the
Christian date, or vice versa, for the years 1900-1935 <sc>a.
d.</sc><br/
<br/
<-- <ct> means "collocation type", just a font designation -->
<er>Months of the Mohammedan year</er>.<br/
<br/
<pre><tt>
 1 <ct>Muharram</ct> . . . .. 30
 2 <ct>Safar</ct> . . . . . . .. 29
 3 <ct>Rabia I</ct> . . . . . . 30
 4 <ct>Rabia II</ct> . . . .. 29
 5 <ct>Jumada I</ct> . . . .. 30
 6 <ct>Jumada II</ct> . . . . 29
 7 <ct>Rajab</ct> . . . . . . .. 30
 8 <ct>Shaban</ct> . . . . . . . 29
 9 <ct>Ramadan</ct> . . . . . . 30
10 <ct>Shawwal</ct> . . . . . . 29
11 <ct>Zu'lkadah</ct> . . . . 30
12 <ct>Zu'lhijjah</ct> . . . 29*
* in leap year, 30 days</tt></pre><br/
<br/
<pre><tt>
<sc>a. h.</sc> <sc>a. d.</sc>  <sc>a. h.</sc>   <sc>a. d.</sc><br/
--------------------------------------------------------------<br/
1317   begins May 12, 1899        1336*  begins  Oct.17, 1917<br/
1318          May  1, 1900        1337           Oct. 7, 1918<br/
1319*         Apr.20, 1901        1338*          Sept.26,1919<br/
1320          Apr.10, 1902        1339           Sept.15,1920<br/
1321+         Mar.30, 1903        1340           Sept.4, 1921<br/
1322*         Mar.18, 1904        1341*          Aug.24, 1922<br/
1323          Mar. 8, 1905        1342           Aug.14, 1923<br/
1324          Feb.25, 1906        1343           Aug. 2, 1924<br/
1325*         Feb.14, 1907        1344*          July 22,1925<br/
1326          Feb. 4, 1908        1345           July 12,1926<br/
1327*         Jan.23, 1909        1346*          July 1, 1927<br/
1328          Jan.13, 1910        1347           June 20,1928<br/
1329          Jan. 2, 1911        1348           June 9, 1929<br/
1330*         Dec.22, 1911        1349*          May 29, 1930<br/
1331          Dec.11, 1912        1350           May 19, 1931<br/
1332          Nov.30, 1913        1351++         May  7, 1932<br/
1333*         Nov.19, 1914        1352*          Apr.26, 1933<br/
1334          Nov. 9, 1915        1353           Apr.16, 1934<br/
1335          Oct.28, 1916        1354           Apr. 5, 1935<br/
-----------------------------------------------------------------<br/
* Leap year  + First year of the 45th cycle<br/
++ First year of the 46th cycle<br/
</tt></pre><br/
<br/
The following general rule for finding the date of commencement of any
Mohammedan year has a maximum error of a day: Multiply 970,224 by the
Mohammedan year, point off six decimal places, and add 621.5774. The
whole number will be the year <sc>a. d.</sc>, and the decimal multiplied
by 365 will give the day of the year.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note> The Mohammedan calendar is one of the most primitive. It is
strictly a Lunar calendar, the year consisting of twelve lunar months,
which retrograde through the seasons in about 321/2 years. To reconcile
the lunar cycle to a given number of complete days, a leap year is
introduced on the 2nd, 5th, 7th, 10th, 13th, 16th, 18th, 21st, 24th,
26th and 29th years of a thirty year cycle, making these years consist
of 355 days instead of 354. The names of the months and the number of
days are: 1, Muharram (30); 2, Saphar (29); 3, Rabia I (30); 4, Rabia II
(29); 5, Jomada I (30); 6, Jomada II (29); 7, Rajah (30); 8, Shaaban
(29); 9, Ramadan (30); 10, Shawaal (29); 11, Dulkasda (30); and 12,
Dulheggia (29 or 30). The years are calculated from July 16, 622 A.D.,
the day following the Hegira, the flight of Mohammed from Mecca to
Medina after an attempted assassination. The beginning of the 46th
cycle, with the first day of Muharram, in the year 1351, compares to May
7, 1932 of the Gregorian calendar; continuing: 1365 Dec. 6, 1945 1366
Nov. 25, 1946 1367 Nov. 15, 1947 1368 Nov. 3, 1948 1369 Oct. 24, 1949
1370 Oct. 13, 1950 1371 Oct. 2, 1951 1372 Sept. 21, 1952 1373 Sept. 10,
1953 1374 Aug. 30, 1954 To find the Gregorian equivalent to any
Mohammedan date multiply 970,224 by the Mohammedan year, point off six
decimal places and add 621.5774. The whole number will be the year A.D.,
and the decimal multiplied by 365 will be the day of the year. </note>
<au>https://web.archive.org/web/20040112151506/http://www.arsakeio.gr/universe/timeref1.htm</au><br/
[<source>PJC</source>]</p>

<p><ent>Mohammedan Era</ent><br/
<hw>Mohammedan Era</hw> <pos>prop. n.</pos> <def>The era in use in
Moslem countries. See <er>Mohammedan year</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mohammedism</ent><br/
<ent>Mohammedanism</ent><br/
<mhw>{ <hw>Mo*ham"med*an*ism</hw>, <hw>Mo*ham"med*ism</hw> }</mhw>
<pr>(?)</pr>, <pos>prop. n.</pos> <def>The religion, or doctrines and
precepts, of <persfn>Mohammed</persfn>, contained in the
<book>Koran</book>; Islamism; Islam. The term <altname>Islam</altname>
is preferred by most Moslems, and some find the term
<ex>Mohammedanism</ex> to be offensive, as they worship
<persfn>Allah</persfn>, not <persfn>Mohammed</persfn>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mohammedize</ent><br/
<ent>Mohammedanize</ent><br/
<mhw>{ <hw>Mo*ham"med*an*ize</hw>, <hw>Mo*ham"med*ize</hw> }</mhw>
<pr>(?)</pr>, <pos>prop. v. t.</pos> <def>To make conformable to the
principles, or customs and rites, of Islam.</def> <altsp>[Written also
<asp>Mahometanize</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mohammedan year</ent><br/
<hw>Mohammedan year</hw> <pos>prop. n.</pos> <def>The year used by
Muslims, consisting of twelve lunar months without intercalation, so
that they retrograde through all the seasons in about 32<frac12/ years.
The Mohammedan era begins with the year 622 <sc>a. d.</sc>, the first
day of the Mohammedan year 1332 being Nov. 30, 1913, according to the
Gregorian calendar.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mohawk</ent><br/
<hw>Mo"hawk</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <sn>1.</sn>
<fld>(Ethnol.)</fld> <def>One of a tribe of Indians who formed part of
the Five Nations. They formerly inhabited the valley of the Mohawk
River.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of certain ruffians who infested the streets of
London in the time of Addison, and took the name from the Mohawk
Indians.</def> <mark>[Slang]</mark> <rj><au>Spectator.
Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mohicans</ent><br/
<hw>Mo*hi"cans</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>; <sing>sing.
<singw>Mohican</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld>
<def>A tribe of Lenni-Lenape Indians who formerly inhabited Western
Connecticut and Eastern New York.</def> <altsp>[Written also
<asp>Mohegans</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moho</ent><br/
\'d8<hw>Mo"ho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name.]</ety>
<fld>(Zool.)</fld> <def>A gallinule (<spn>Notornis Mantelli</spn>)
formerly inhabiting New Zealand, but now supposed to be extinct. It was
incapable of flight. See <er>Notornis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moho</ent><br/
<hw>Mo"ho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Short for
<ets>Mohorovicic discontinuity</ets>, from <person>Andrija
<etsep>Mohorovi<ccar/i<cacute/</etsep></person>, a Yugoslavian
geologist.]</ety> <fld>(Geol.)</fld> <def>The boundary between the
earth's crust and the semiliquid mantle beneath. It varies in depth from
3 miles beneath the surface at certain points in the ocean to over 25
miles under certain parts of continents.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mohock</ent><br/
<hw>Mo"hock</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mohawk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moholi</ent><br/
\'d8<hw>Mo*ho"li</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Maholi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mohorovicic discontinuity</ent><br/
<hw>Mohorovicic discontinuity</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Geol.)</fld> <def>same as 2nd <er>Moho</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mohr</ent><br/
<hw>Mohr</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A West
African gazelle (<spn>Gazella mohr</spn>), having horns on which are
eleven or twelve very prominent rings. It is one of the species which
produce bezoar.</def> <altsp>[Written also
<asp>mhorr</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mohur</ent><br/
<hw>Mo"hur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind., fr. Per.
<ets>muhur</ets>, <ets>muhr</ets>, a gold coin, a seal, seal
ring.]</ety> <def>A British Indian gold coin, of the value of fifteen
silver rupees, or $7.21 (in 1913).</def> <rj><au>Malcom.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muharram</ent><br/
<ent>Mohurrum</ent><br/
<mhw>{ \'d8<hw>Mo*hur"rum</hw> <pr>(?)</pr>, \'d8<hw>Mu*har"ram</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[Ar. <ets>muharram</ets>,
prop., sacred, forbidden, n., the first month of the Mohammedan lunar
year.]</ety> <sn>1.</sn> <def>The first month of the Mohammedan
year.</def> <rj><au>Whitworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A festival of the Shiah sect of the Muslims held
during the first ten days of the month Mohurrum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moider</ent><br/
<hw>Moi"der</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To toil.</def>
<mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moidore</ent><br/
<hw>Moi"dore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg. <ets>moeda
d'ouro</ets>, lit., coin of gold. Cf. <er>Money</er>, and
<er>Aureate</er>.]</ety> <def>A gold coin of Portugal, valued at about
27s. sterling.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 936 --></p>

<p><ent>Moiety</ent><br/
<hw>Moi"e*ty</hw> <pr>(moi"<esl/*t<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Moieties</plw>
<pr>(moi"<esl/*t<icr/z)</pr>.</plu> <ety>[F. <ets>moiti<eacute/</ets>,
L. <ets>medietas</ets>, fr. <ets>medius</ets> middle, half. See
<er>Mid</er>, <pos>a.</pos>, and cf. <er>Mediate</er>,
<er>Mediety</er>.]</ety> <sn>1.</sn> <def>One of two equal parts; a
half; <as>as, a <ex>moiety</ex> of an estate, of goods, or of profits;
the <ex>moiety</ex> of a jury, or of a nation.</as></def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The more beautiful <qex>moiety</qex> of his majesty's subject.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An indefinite part; a small part.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moil</ent><br/
<hw>Moil</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Moiled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Moiling</conjf>.]</vmorph> <ety>[OE. <ets>moillen</ets> to wet,
OF. <ets>moillier</ets>, <ets>muillier</ets>, F. <ets>mouller</ets>, fr.
(assumed) LL. <ets>molliare</ets>, fr. L. <ets>mollis</ets> soft. See
<er>Mollify</er>.]</ety> <def>To daub; to make dirty; to soil; to
defile.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou . . . doest thy mind in dirty pleasures <qex>moil</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moil</ent><br/
<hw>Moil</hw>, <pos>v. i.</pos> <ety>[From <er>Moil</er> to daub; prob.
from the idea of struggling through the wet.]</ety> <def>To soil one's
self with severe labor; to work with painful effort; to labor; to toil;
to drudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Moil</qex> not too much under ground.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now he must <qex>moil</qex> and drudge for one he loathes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moil</ent><br/
<hw>Moil</hw>, <pos>n.</pos> <def>A spot; a defilement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>moil</qex> of death upon them.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moile</ent><br/
<hw>Moile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>mule</ets> a
slipper.]</ety> <def>A kind of high shoe anciently worn.</def>
<altsp>[Written also <asp>moyle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moineau</ent><br/
\'d8<hw>Moi"neau</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Fort.)</fld> <def>A small flat bastion, raised in the middle of an
overlong curtain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moira</ent><br/
\'d8<hw>Moi"ra</hw> <pr>(moi"r<adot/)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>Moi^ra</grk>.]</ety> <fld>(Greek Myth.)</fld> <def>The deity
who assigns to every man his lot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moire</ent><br/
\'d8<hw>Moire</hw> <pr>(mw<aum/r)</pr>, <pos>n.</pos> <ety>[F. Cf.
<er>Mohair</er>.]</ety> <sn>1.</sn> <def>Originally, a fine textile
fabric made of the hair of an Asiatic goat; afterwards, any textile
fabric to which a watered appearance is given in the process of
calendering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A watered, clouded, or frosted appearance produced
upon either textile fabrics or metallic surfaces;
moi`r<eacute/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moire</ent><br/
\'d8<hw>Moi`r<eacute/"</hw> <pr>(mw<aum/`r<amac/";
m<omac/"r<amac/)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A watered,
clouded, or frosted appearance on textile fabrics or metallic
surfaces.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Erroneously, moire, the fabric.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>A wavy pattern of lines produced by the
superposition of two patterns having closely spaced, often curved,
lines, so that the lines of the two patterns intersect at an acute
angle. When the superposing patterns are moved relative to the observer
or relative to each other, a shimmering effect is produced in which the
apparent pattern changes, often producing a pleasing artistic effect.
The effect may be seen, for example, when the superposed folds of a
sheer fabric, such as a window curtain, are observed with transmitted
light.</def><br/
<syn><b>Syn. --</b> moire pattern.</syn><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Printing)</fld> <def>An interference pattern
produced by the dots of a color printing process.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Moire antique</b></col>, <cd>a superior kind of thick
moire.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moire</ent><br/
\'d8<hw>Moi`r<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., p.p.
of <ets>moirer</ets> to water (silk, etc.). See <er>Moire</er>.]</ety>
<def>Watered; having a watered or clouded appearance; -- as of silk or
metals.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moire</ent><br/
<hw>Moi*r<eacute/"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Moir<eacute/ed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Moir<eacute/eing</conjf>
<pr>(?)</pr>.]</vmorph> Also <hw>Moire</hw>. <ety>[F.
<ets>moir<eacute/</ets>.]</ety> <def>To give a watered or clouded
appearance to (a surface).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moire metallique</ent><br/
\'d8<hw>Moi`r<eacute/" m<eacute/`tal`lique"</hw> <pr>(?)</pr>.
<ety>[F.]</ety> <def>A crystalline or frosted appearance produced by
some acids on tin plate; also, the tin plate thus treated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moist</ent><br/
<hw>Moist</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>moiste</ets>,
OF. <ets>moiste</ets>, F. <ets>moite</ets>, fr. L. <ets>muccidus</ets>,
for <ets>mucidus</ets>, moldy, musty. Cf. <er>Mucus</er>,
<er>Mucid</er>.]</ety> <sn>1.</sn> <def>Moderately wet; damp; humid; not
dry; <as>as, a <ex>moist</ex> atmosphere or air</as>.</def>
<ldquo/<xex>Moist</xex> eyes.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fresh, or new.</def> <mark>[Obs.]</mark>
<ldquo/Shoes full <xex>moist</xex> and new.<rdquo/ <ldquo/A draught of
<xex>moist</xex> and corny ale.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moist</ent><br/
<hw>Moist</hw>, <pos>v. t.</pos> <def>To moisten.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moisten</ent><br/
<hw>Mois"ten</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Moistened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Moistening</conjf>.]</vmorph> <sn>1.</sn> <def>To make
damp; to wet in a small degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A pipe a little <qex>moistened</qex> on the inside.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To soften by making moist; to make tender.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>moistened</qex> not his executioner's heart with any
pity.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moistener</ent><br/
<hw>Mois"ten*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, moistens.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moistful</ent><br/
<hw>Moist"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
moisture.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moistless</ent><br/
<hw>Moist"less</hw>, <pos>a.</pos> <def>Without moisture; dry.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moistness</ent><br/
<hw>Moist"ness</hw>, <pos>n.</pos> <def>The quality or state of being
moist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moisture</ent><br/
<hw>Mois"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>moistour</ets>, F. <ets>moiteur</ets>.]</ety> <sn>1.</sn> <def>A
moderate degree of wetness.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which moistens or makes damp or wet; exuding
fluid; liquid in small quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All my body's <qex>moisture</qex><br/
Scarce serves to quench my furnace-burning heat.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moistureless</ent><br/
<hw>Mois"ture*less</hw>, <pos>a.</pos> <def>Without moisture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moisty</ent><br/
<hw>Moist"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Moist.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moither</ent><br/
<hw>Moi"ther</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Etymol.
uncertain.]</ety> <def>To perplex; to confuse.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moither</ent><br/
<hw>Moi"ther</hw>, <pos>v. i.</pos> <def>To toil; to labor.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mojarra</ent><br/
<hw>Mo*jar"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety> <def>Any
of certain basslike marine fishes (mostly of tropical seas, and having a
deep, compressed body, protracile mouth, and large silvery scales)
constituting the family <fam>Gerridae</fam>, as <spn>Gerres
plumieri</spn>, found from Florida to Brazil and used as food. Also, any
of numerous other fishes of similar appearance but belonging to other
families.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mokadour</ent><br/
<hw>Mok"a*dour</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>mocador</ets> handkerchief.]</ety> <def>A handkerchief.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moke</ent><br/
<hw>Moke</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A stupid
person; a dolt.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A donkey.</def> <mark>[Cant]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A negro.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <fld>(Theat. Slang)</fld> <ety>[More fully <ets>musical
moke</ets>.]</ety> <def>A performer, as a minstrel, who plays on several
instruments.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moke</ent><br/
<hw>Moke</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mesh of a net, or of
anything resembling a net.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moky</ent><br/
<hw>Mo"ky</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. Icel.
<ets>m<oum/kkvi</ets> cloud, mist, <ets>m<oum/kkr</ets> a dense cloud,
W. <ets>mwg</ets> smoke, and E. <ets>muggy</ets>,
<ets>muck</ets>.]</ety> <def>Misty; dark; murky; muggy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mol</ent><br/
<hw>mol</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>A quantity of a
substance equal to the molecular weight of a substance expressed in
grams; a gram molecule; the basic unit of amount of substance adopted
under the System International d'Unites; <as>as, he added two
<ex>mols</ex> of dextrose to the medium</as>.</def><br/
<syn><b>Syn. --</b> gram molecule, mole.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mola</ent><br/
<hw>Mo"la</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Sunfish</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>molal</ent><br/
<hw>molal</hw> <pos>adj.</pos> <fld>(Chem.)</fld> <def>Being at a
concentration with the designated number of moles (of solute) per 1000
grams of solvent; <as>as, an 0.5 <ex>molal</ex> solution of glycerol in
water</as>. Compare <er>molar</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>molality</ent><br/
<hw>molality</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>A measure of
concentaration of substances in mixtures, 1 molal being the
concentration of a solution containing 1 mole of solute per 1000 grams
of solvent. Compare <er>molar</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>molar</ent><br/
<hw>mo"lar</hw> <pr>(m<omac/"l<etil/r)</pr>, <pos>a.</pos> <ety>[L.
<ets>moles</ets> mass.]</ety> <fld>(Mech.)</fld> <def>Of or pertaining
to a mass of matter; -- said of the properties or motions of masses, as
distinguished from those of molecules or atoms.</def><br/
[<source>PJC</source>]</p>

<p><ent>molar</ent><br/
<hw>mo"lar</hw> <pr>(m<omac/"l<etil/r <it>or</it> m<omac/"l<aum/r)</pr>,
<pos>a.</pos> <ety>[L. <ets>moles</ets> mass.]</ety> <fld>(Chem.)</fld>
<def>Being at a concentration having the designated number of moles (of
solute) per liter of solvent; <as>as, an 0.2 <ex>molar</ex> solution of
sodium chloride in water is close to isotonic</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Molar</ent><br/
<hw>Mo"lar</hw>, <pos>a.</pos> <ety>[L. <ets>molaris</ets>, fr.
<ets>mola</ets> mill, fr. <ets>molere</ets> to grind in a mill. See
<er>Mill</er> the machine.]</ety> <def>Having power to grind; grinding;
<as>as, the <ex>molar</ex> teeth</as>; also, of or pertaining to the
molar teeth.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molar</ent><br/
<hw>Mo"lar</hw>, <pos>n.</pos> <fld>(Anat.)</fld> <def>Any one of the
teeth back of the incisors and canines. The molars which replace the
deciduous or milk teeth are designated as <stype>premolars</stype>, and
those which are not preceded by deciduous teeth are sometimes called
<stype>true molars</stype>. See <er>Tooth</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molary</ent><br/
<hw>Mo"la*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as 2d
<er>Molar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molasse</ent><br/
<hw>Mo*lasse"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>molasse</ets>, prob. fr. <ets>mollasse</ets> flabby, flimsy, fr. L.
<ets>mollis</ets> soft.]</ety> <fld>(Geol.)</fld> <def>A soft Tertiary
sandstone; -- applied to a rock occurring in Switzerland. See
<xex>Chart</xex> of <er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molasses</ent><br/
<hw>Mo*las"ses</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<eacute/lasse</ets>, cf. Sp. <ets>melaza</ets>, Pg.
<ets>mela<cced/o</ets>, fr. L. <ets>mellaceus</ets> honeylike,
honey-sweet, <ets>mel</ets>, <ets>mellis</ets>, honey. See
<er>Mellifluous</er>, and cf. <er>Melasses</er>.]</ety> <def>The thick,
brown or dark colored, viscid, uncrystallizable sirup which drains from
sugar, in the process of manufacture; any thick, viscid, sweet sirup
made from vegetable juice or sap, as of the sorghum or maple. See
<er>Treacle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mold</ent><br/
<hw>Mold</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Mole</er> a
spot.]</ety> <def>A spot; a blemish; a mole.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw>}</mhw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[OE. <ets>molde</ets>, AS. <ets>molde</ets>; akin to D.
<ets>mul</ets>, G. <ets>mull</ets>, <ets>mulm</ets>, OHG.
<ets>molt</ets>, <ets>molta</ets>, Icel. <ets>mold</ets>, Dan.
<ets>muld</ets>, Sw. <ets>mull</ets>, Goth. <ets>mulda</ets>, and E.
<ets>meal</ets> flour. See <er>Meal</er>, and cf. <er>Mole</er> an
animal, <er>Mull</er>, <pos>v.</pos>]</ety> <altsp>[The prevalent
spelling is, perhaps, <asp>mould</asp>; but as the <it>u</it> has not
been inserted in the other words of this class, as <it>bold</it>,
<it>gold</it>, <it>old</it>, <it>cold</it>, etc., it seems desirable to
complete the analogy by dropping it from this word, thus spelling it as
Spenser, South, and many others did. The omission of the <it>u</it> is
now very common in America.]</altsp> <sn>1.</sn> <def>Crumbling, soft,
friable earth; esp., earth containing the remains or constituents of
organic matter, and suited to the growth of plants; soil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Earthy material; the matter of which anything is
formed; composing substance; material.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The etherial <qex>mold</qex>,<br/
Incapable of stain.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nature formed me of her softest <qex>mold</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw> }</mhw> <pr>(?)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Molded</conjf> or
<conjf>Moulded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Molding</conjf> or <conjf>Moulding</conjf>.]</vmorph> <def>To
cover with mold or soil.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw>, }</mhw> <pos>n.</pos> <ety>[From
the p. p. of OE. <ets>moulen</ets> to become moldy, to rot, prob. fr.
Icel. <ets>mygla</ets> to grow musty, <ets>mugga</ets> mugginess; cf.
Sw. <ets>m<oum/gla</ets> to grow moldy. See <er>Muggy</er>, and cf.
<er>Moldy</er>.]</ety> <fld>(Bot.)</fld> <def>A growth of minute fungi
of various kinds, esp. those of the great groups
<fam>Hyphomycetes</fam>, and <fam>Physomycetes</fam>, forming on damp or
decaying organic matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common blue mold of cheese, the brick-red cheese
mold, and the scarlet or orange strata which grow on tubers or roots
stored up for use, when commencing to decay, are familiar examples.
<rj><au>M. J. Berkley.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw>, }</mhw> <pos>v. t.</pos> <def>To
cause to become moldy; to cause mold to grow upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw>, }</mhw> <pos>v. i.</pos> <def>To
become moldy; to be covered or filled, in whole or in part, with a
mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw>, }</mhw> <pos>n.</pos> <ety>[OE.
<ets>molde</ets>, OF. <ets>mole</ets>, F. <ets>moule</ets>, fr. L.
<ets>modulus</ets>. See <er>Model</er>.]</ety> <altsp>[For spelling, see
2d <er>Mold</er>, above.]</altsp> <sn>1.</sn> <def>The matrix, or
cavity, in which anything is shaped, and from which it takes its form;
also, the body or mass containing the cavity; <as>as, a sand
<ex>mold</ex>; a jelly <ex>mold</ex>.</as></def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That on which, or in accordance with which, anything
is modeled or formed; anything which serves to regulate the size, form,
etc., as the pattern or templet used by a shipbuilder, carpenter, or
mason.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The glass of fashion and the <qex>mold</qex> of form.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Cast; form; shape; character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Crowned with an architrave of antique <qex>mold</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>A group of moldings; <as>as, the
arch <ex>mold</ex> of a porch or doorway; the pier <ex>mold</ex> of a
Gothic pier, meaning the whole profile, section, or combination of
parts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anat.)</fld> <def>A fontanel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Paper Making)</fld> <def>A frame with a wire cloth
bottom, on which the pump is drained to form a sheet, in making paper by
hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mould</ent><br/
<ent>Mold</ent><br/
<mhw>{ <hw>Mold</hw>, <hw>Mould</hw>, }</mhw> <pos>v. t.</pos> <ety>[Cf.
F. <ets>mouler</ets>, OF. <ets>moler</ets>, <ets>moller</ets>. See
<er>Mold</er> the matrix.]</ety> <sn>1.</sn> <def>To form into a
particular shape; to shape; to model; to fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He forgeth and <qex>moldeth</qex> metals.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Did I request thee, Maker, from my clay<br/
To <qex>mold</qex> me man?</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To ornament by molding or carving the material of;
<as>as, a <ex>molded</ex> window jamb</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To knead; <as>as, to <ex>mold</ex> dough or
bread</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Founding)</fld> <def>To form a mold of, as in sand,
in which a casting may be made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldable</ent><br/
<ent>Moldable</ent><br/
<mhw>{ <hw>Mold"a*ble</hw>, <hw>Mould"a*ble</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Capable of being molded or formed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldboard</ent><br/
<ent>Moldboard</ent><br/
<mhw>{ <hw>Mold"board`</hw>, <hw>Mould"board`</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>A curved plate of iron (originally of
wood) back of the share of a plow, which turns over the earth in
plowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Founding)</fld> <def>A follow board.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moulder</ent><br/
<ent>Molder</ent><br/
<mhw>{ <hw>Mold"er</hw>, <hw>Mould"er</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>One who, or that which, molds or forms into shape;
specifically <fld>(Founding)</fld>, one skilled in the art of making
molds for castings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moulder</ent><br/
<ent>Molder</ent><br/
<mhw>{ <hw>Mold"er</hw>, <hw>Mould"er</hw>, }</mhw> <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Moldered</conjf> <pr>(?)</pr> or
<conjf>Mouldered</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Moldering</conjf> or <conjf>Mouldering</conjf>.]</vmorph>
<ety>[From <er>Mold</er> fine soft earth: cf. Prov. G.
<ets>multern</ets>.]</ety> <def>To crumble into small particles; to turn
to dust by natural decay; to lose form, or waste away, by a gradual
separation of the component particles, without the presence of water; to
crumble away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>moldering</qex> of earth in frosts and sun.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When statues <qex>molder</qex>, and when arches fall.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If he had sat still, the enemy's army would have
<qex>moldered</qex> to nothing.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moulder</ent><br/
<ent>Molder</ent><br/
<mhw>{ <hw>Mold"er</hw>, <hw>Mould"er</hw>, }</mhw> <pos>v. t.</pos>
<def>To turn to dust; to cause to crumble; to cause to waste
away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Time's] gradual touch<br/
Has <qex>moldered</qex> into beauty many a tower.</q>
<rj><qau>Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldery</ent><br/
<ent>Moldery</ent><br/
<mhw>{ <hw>Mold"er*y</hw>, <hw>Mould"er*y</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Covered or filled with mold; consisting of, or
resembling, mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldiness</ent><br/
<ent>Moldiness</ent><br/
<mhw>{ <hw>Mold"i*ness</hw>, <hw>Mould"i*ness</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[From <er>Moldy</er>.]</ety> <def>The state of being
moldy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moulding</ent><br/
<ent>Molding</ent><br/
<mhw>{ <hw>Mold"ing</hw>, <hw>Mould"ing</hw>, }</mhw> <pos>n.</pos>
<sn>1.</sn> <def>The act or process of shaping in or on a mold, or of
making molds; the art or occupation of a molder.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything cast in a mold, or which appears to be so,
as grooved or ornamental bars of wood or metal, or sculptures.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> mold, mould, molding, modeling, clay
sculpture.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>A plane, or curved, narrow
surface, either sunk or projecting, used for decoration by means of the
lights and shades upon its surface. Moldings vary greatly in pattern,
and are generally used in groups, the different members of each group
projecting or retreating, one beyond another. See <er>Cable</er>,
<pos>n.</pos>, 3, and <cref>Crenelated molding</cref>, under
<er>Crenelate</er>, <pos>v. t.</pos></def> <wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Especially:</specif> <def>a decorative strip used
for ornamentation or finishing.</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> moolding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>5.</sn> <def>a preliminary sculpture in wax or clay from which a
finished work can be copied.</def> <wns>[wns=5]</wns><br/
<syn><b>Syn. --</b> modeling, moulding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moulding</ent><br/
<ent>Molding</ent><br/
<mhw>{ <hw>Mold"ing</hw>, <hw>Mould"ing</hw>, }</mhw> <pos>p. a.</pos>
<def>Used in making a mold or moldings; used in shaping anything
according to a pattern.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Molding board</b></col> <it>or</it>
<col><b>Moulding board</b></col></mcol>. <sd>(a)</sd> <cd>See
<cref>Follow board</cref>, under <er>Follow</er>, <pos>v. t.</pos></cd>
<sd>(b)</sd> <cd>A board on which bread or pastry is kneaded and
shaped.</cd> -- <mcol><col><b>Molding machine</b></col> <it>or</it>
<col><b>Moulding machine</b></col></mcol>. <sd>(a)</sd>
<fld>(Woodworking)</fld> <cd>A planing machine for making moldings</cd>.
(<sd>b</sd>) <fld>(Founding)</fld> <cd>A machine to assist in making
molds for castings.</cd> -- <mcol><col><b>Molding mill</b></col>
<it>or</it> <col><b>Moulding mill</b></col></mcol>, <cd>a mill for
shaping timber.</cd> -- <mcol><col><b>Molding sand</b></col> <it>or</it>
<col><b>Moulding sand</b></col></mcol> <fld>(Founding)</fld>, <cd>a kind
of sand containing clay, used in making molds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldwarp</ent><br/
<ent>Moldwarp</ent><br/
<mhw>{ <hw>Mold"warp</hw>, <hw>Mould"warp</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[OE. <ets>moldwerp</ets>: AS. <ets>molde</ets> soil +
<ets>weorpan</ets> to throw up; cf. OD. <ets>molworp</ets>, G.
<ets>maulwurf</ets>, Icel. <ets>moldvarpa</ets>, Dan.
<ets>muldvarp</ets>. See <er>Mold</er> soil, <er>Warp</er>, and cf.
<er>Mole</er> the animal.]</ety> <fld>(Zool.)</fld> <def>See
<er>Mole</er> the animal.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldy</ent><br/
<ent>Moldy</ent><br/
<mhw>{ <hw>Mold"y</hw>, <hw>Mould"y</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <amorph>[<pos>Compar.</pos> <adjf>Moldier</adjf>
<pr>(?)</pr> or <adjf>Mouldier</adjf>; <pos>superl.</pos>
<adjf>Moldiest</adjf> or <adjf>Mouldiest</adjf>.]</amorph> <ety>[From
<er>Mold</er> the growth of fungi.]</ety> <def>Overgrown with, or
containing, mold; smelling of mold; <as>as, <ex>moldy</ex> cheese or
bread</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mole</ent><br/
<hw>Mole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>m<amac/l</ets>;
akin to OHG. <ets>meil</ets>, Goth. <ets>mail</ets> Cf. <er>Mail</er> a
spot.]</ety> <sn>1.</sn> <def>A spot; a stain; a mark which discolors or
disfigures.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A spot, mark, or small permanent protuberance on the
human body; esp., a spot which is dark-colored, from which commonly
issue one or more hairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mole</ent><br/
<hw>Mole</hw>, <pos>n.</pos> <ety>[L. <ets>mola</ets>.]</ety> <def>A
mass of fleshy or other more or less solid matter generated in the
uterus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mole</ent><br/
<hw>Mole</hw>, <pos>n.</pos> <ety>[F. <ets>m<ocir/le</ets>, L.
<ets>moles</ets>. Cf. <er>Demolish</er>, <er>Emolument</er>,
<er>Molest</er>.]</ety> <def>A mound or massive work formed of masonry
or large stones, etc., laid in the sea, often extended either in a right
line or an arc of a circle before a port which it serves to defend from
the violence of the waves, thus protecting ships in a harbor; also,
sometimes, the harbor itself.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mole</ent><br/
<hw>Mole</hw>, <pos>n.</pos> <ety>[OE. <ets>molle</ets>, either
shortened fr. <ets>moldwerp</ets>, or from the root of E.
<ets>mold</ets> soil: cf. D. <ets>mol</ets>, OD. <ets>molworp</ets>. See
<er>Moldwarp</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>Any
insectivore of the family <fam>Talpidae</fam>. They have minute eyes and
ears, soft fur, and very large and strong fore feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common European mole, or moldwarp (<spn>Talpa
Europaea</spn>), is noted for its extensive burrows. The common American
mole, or shrew mole (<spn>Scalops aquaticus</spn>), and star-nosed mole
(<spn>Condylura cristata</spn>) have similar habits.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the Scriptures, the name is applied to two
unindentified animals, perhaps the chameleon and mole rat.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plow of peculiar construction, for forming
underground drains.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <mark>(fig.)</mark><def>A spy who lives for years an
apparently normal life (to establish a cover) before beginning his
spying activities.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Duck mole</b></col>. <cd>See under <er>Duck</er>.</cd> --
<col><b>Golden mole</b></col>. <cd>See <er>Chrysochlore</er>.</cd> --
<col><b>Mole cricket</b></col> <fld>(Zool.)</fld>, <cd>an orthopterous
insect of the genus <gen>Gryllotalpa</gen>, which excavates subterranean
galleries, and throws up mounds of earth resembling those of the mole.
It is said to do damage by injuring the roots of plants. The common
European species (<spn>Gryllotalpa vulgaris</spn>), and the American
(<spn>Gryllotalpa borealis</spn>), are the best known.</cd> --
<col><b>Mole rat</b></col> <fld>(Zool.)</fld>, <cd>any one of several
species of Old World rodents of the genera <gen>Spalax</gen>,
<gen>Georychus</gen>, and several allied genera. They are molelike in
appearance and habits, and their eyes are small or rudimentary.</cd> --
<col><b>Mole shrew</b></col> <fld>(Zool.)</fld>, <cd>any one of several
species of short-tailed American shrews of the genus <gen>Blarina</gen>,
esp. <spn>Blarina brevicauda</spn>.</cd> -- <col><b>Water
mole</b></col>, <cd>the duck mole.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mole</ent><br/
<hw>mole</hw> <pos>n.</pos> <def>A quantity of a substance equal to the
molecular weight of a substance expressed in grams; a gram molecule; the
basic unit of amount of substance adopted under the System International
d'Unites; <as>as, he added two <ex>moles</ex> of sodium chloride to the
medium</as>.</def><br/
<syn><b>Syn. --</b> gram molecule, mol.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mole</ent><br/
<hw>Mole</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Moled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Moling</conjf>.]</vmorph> <sn>1.</sn> <def>To form holes in, as a
mole; to burrow; to excavate; <as>as, to <ex>mole</ex> the
earth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To clear of molehills.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Pegge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molebut</ent><br/
<hw>Mole"but</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The sunfish (<gen>Orthagoriscus</gen>, or <gen>Mola</gen>).</def>
<altsp>[Written also <asp>molebat</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molecast</ent><br/
<hw>Mole"cast`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little elevation
of earth made by a mole; a molehill.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molech</ent><br/
<hw>Mo"lech</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[Heb.
<ets>molek</ets> king.]</ety> <fld>(Script.)</fld> <def>The fire god of
the Ammonites, to whom human sacrifices were offered; Moloch.</def>
<rj><au>Lev. xviii. 21.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molecular</ent><br/
<hw>Mo*lec"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mol<eacute/culare</ets>. See <er>Molecule</er>.]</ety> <fld>(Phys.
& Chem.)</fld> <def>Pertaining to, connected with, produced by, or
consisting of, molecules; <as>as, <ex>molecular</ex> forces;
<ex>molecular</ex> groups of atoms, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Molecular attraction</b></col> <fld>(Phys.)</fld>,
<cd>attraction acting between the molecules of bodies, and at insensible
distances.</cd> -- <col><b>Molecular weight</b></col>
<fld>(Chem.)</fld>, <cd>the weight of a molecule of any gas or vapor as
compared with the hydrogen atom having weight of 1 as a standard; the
sum of the atomic weights of the constituents of a molecule; <as>thus,
the <ex>molecular weight</ex> of water (<chform>H2O</chform>) is
18</as>. For more precise measurements, the weight of the carbon isotope
carbon-12 is used as the standard, that isotope having the value of
12.000. In this systen, now used almost universally, the hydrogen atom
has a weight of 1.0079.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>molecular formula</ent><br/
<hw>mo*lec"u*lar form"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>An expression representing the composition of
elements in a chemical substance, commonly consisting of a series of
letters and numbers comprising the atomic symbols of each element
present in a compound followed by the number of atoms of that element
present in one molecule of the substance. Thus the <ex>molecular
formula</ex> for common alcohol (ethyl alcohol) is
<chform>C2H6O</chform>, meaning that each molecule contains two carbon
atoms, six hydrogen atoms, and one oxygen atom. The <ex>molecular
formula</ex> may be written to provide some indication of the actual
structure of the molecule, in which case structural units may be written
separately. Thus, ethyl alcohol can also be written as
<chform>CH3.CH2.OH</chform> or <chform>CH3-CH2-OH</chform>, in which the
period or dash between functional groups indicates a single bond between
the principle atoms of each group. This formula shows that in ethyl
alcohol, the carbon of a methyl group (<chform>CH3-</chform>) is
attached to the carbon of a methylene group (<chform>-CH2-</chform>),
which is attached to the oxygen of a hydroxyl group
(<chform>-OH</chform>). A <contr>structural formula</contr> is a
graphical depiction of the relative positions of atoms in a molecule,
and may be very complicated.</def><br/
[<source>PJC</source>]</p>

<p><ent>Molecularity</ent><br/
<hw>Mo*lec`u*lar"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Phys. &
Chem.)</fld> <def>The state of consisting of molecules; the state or
quality of being molecular.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molecularly</ent><br/
<hw>Mo*lec"u*lar*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <fld>(Phys. &
Chem.)</fld> <def>With molecules; in the manner of molecules.</def>
<rj><au>W. R. Grove.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molecule</ent><br/
<hw>Mol"e*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. fr. L.
<ets>moles</ets> a mass: cf. F. <ets>mol<eacute/cule</ets>. See 3d
<er>Mole</er>.]</ety> <sn>1.</sn> <def>One of the very small invisible
particles of which all ordinary matter is supposed to consist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>The smallest part of any
substance which possesses the characteristic properties and qualities of
that substance, and which can exist alone in a free state.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>A group of atoms so united and
combined by chemical affinity that they form a complete, integrated
whole, being the smallest portion of any particular compound that can
exist in a free state; <as>as, a <ex>molecule</ex> of water consists of
two atoms of hydrogen and one of oxygen</as>. Cf.
<er>Atom</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mole-eyed</ent><br/
<hw>Mole"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having eyes like
those of the mole; having imperfect sight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molehill</ent><br/
<hw>Mole"hill`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little hillock of
earth thrown up by moles working under ground; hence, a very small hill,
or an insignificant obstacle or difficulty; <as>as, to make a mountain
out of a <ex>molehill</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Having leapt over such mountains, lie down before a
<qex>molehill</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 937 --></p>

<p><ent>molendinarious</ent><br/
<ent>mMolendinaceous</ent><br/
<mhw>{ <hw>mMo*len`di*na"ceous</hw>
<pr>(m<osl/*l<ecr/n`d<icr/*n<amac/"sh<ucr/s)</pr>,
<hw>mo*len`di*na"ri*ous</hw>
<pr>(m<osl/*l<ecr/n`d<icr/*n<amac/"r<icr/*<ucr/s)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>molendinarius</ets>, fr.
<ets>molendinum</ets> a mill, fr. <ets>molere</ets> to grind.]</ety>
<fld>(Bot.)</fld> <def>Resembling the sails of a windmill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moleskin</ent><br/
<hw>mole"skin`</hw> <pr>(m<omac/l"sk<icr/n)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Any fabric having a thick soft shag, like the fur of a
mole; esp., a kind of strong twilled fustian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A soft fabric having an adhesive backing, applied to
the skin at points susceptible to abrasion, as on the feet, to prevent
irritation or blistering during exercise, such as hiking.</def><br/
[<source>PJC</source>]</p>

<p><ent>Molest</ent><br/
<hw>Mo*lest"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Molested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Molesting</conjf>.]</vmorph> <ety>[F. <ets>molester</ets>, L.
<ets>molestare</ets>, fr. <ets>molestus</ets> troublesome, fr.
<ets>moles</ets> a heavy mass, load, burden. See 3d
<er>Mole</er>.]</ety> <def>To trouble; to disturb; to render uneasy; to
interfere with; to vex.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They have <qex>molested</qex> the church with needless
opposition.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To trouble; disturb; incommode; inconvenience;
annoy; vex; tease.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molest</ent><br/
<hw>Mo*lest"</hw>, <pos>n.</pos> <def>Molestation.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molestation</ent><br/
<hw>Mol`es*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>molestation</ets>.]</ety> <def>The act of molesting, or the state
of being molested; disturbance; annoyance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>molested</ent><br/
<hw>molested</hw> <pos>adj.</pos> <def>sexually abused.</def><br/
<syn><b>Syn. --</b> assaulted, raped, fondled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Molester</ent><br/
<hw>Mo*lest"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
molests.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molestful</ent><br/
<hw>Mo*lest"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Troublesome;
vexatious.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molesty</ent><br/
<ent>Molestie</ent><br/
<mhw>{ <hw>Mo*les"tie</hw>, <hw>Mo*les"ty</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[L. <ets>molestia</ets>.]</ety>
<def>Molestation.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molewarp</ent><br/
<hw>Mole"warp`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Moldwarp</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moliminous</ent><br/
<hw>Mo*lim"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>molimen</ets> a great exertion; <ets>moles</ets> a heavy
mass.]</ety> <def>Of great bulk or consequence; very important.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moline</ent><br/
<hw>Mo"line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>molina</ets>
mill, fr. <ets>molere</ets> to grind. See <er>Mill</er>.]</ety> <def>The
crossed iron that supports the upper millstone by resting on the
spindle; a millrind.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cross moline</b></col> <fld>(Her.)</fld>, <cd>a cross
each arm of which is divided at the end into two rounded branches or
divisions.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molinism</ent><br/
<hw>Mo"lin*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld>
<def>The doctrines of the <org>Molinists</org>, somewhat resembling the
tenets of the <org>Arminians</org>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molinist</ent><br/
<hw>Mo"lin*ist</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>A
follower of the opinions of <persfn>Molina</persfn>, a Spanish Jesuit
(in respect to grace); an opposer of the Jansenists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moll</ent><br/
\'d8<hw>Moll</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[G., fr. L.
<ets>mollis</ets> soft, tender, elegiac. Cf. <er>Molle</er>.]</ety>
<fld>(Mus.)</fld> <def>Minor; in the minor mode; <as>as, A
<ex>moll</ex>, that is, A minor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollah</ent><br/
\'d8<hw>Mol"lah</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>maul<amac/</ets>, commonly <ets>moll<amac/</ets>in Turkey.]</ety>
<sn>1.</sn> <def>One of the higher order of Turkish; also, a Turkish
title of respect for a religious and learned man.</def> <altsp>[Written
also <asp>mullah</asp> and <asp>moolah</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A title of respect used in Islamic countries for one
who is learned in Islamic law; a teacher or expounder of Islamic
law.</def><br/
[<source>PJC</source>]</p>

<p><ent>Molle</ent><br/
<hw>Mol"le</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Moll</er>.]</ety> <fld>(Mus.)</fld> <def>Lower by a semitone; flat;
<as>as, E <ex>molle</ex>, that is, E flat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollebart</ent><br/
<hw>Mol"le*bart</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An agricultural
implement used in Flanders, consisting of a kind of large shovel drawn
by a horse and guided by a man.</def> <altsp>[Written also
<asp>mollebaert</asp> and <asp>mouldebaert</asp>.]</altsp>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollemoke</ent><br/
<hw>Mol"le*moke`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sw.
<ets>mallemucke</ets> the stormy petrel.]</ety> <fld>(Zool.)</fld>
<def>Any one of several species of large pelagic petrels and fulmars, as
<spn>Fulmarus glacialis</spn>, of the North Atlantic, and several
species of <gen>Aestrelata</gen>, of the Southern Ocean. See
<er>Fulmar</er>.</def> <altsp>[Written also <asp>mollymawk</asp>,
<asp>malmock</asp>, <asp>mollemock</asp>, <asp>mallemocke</asp>,
etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollient</ent><br/
<hw>Mol"lient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>molliens</ets>, p. p. of <ets>mollire</ets> to soften, fr.
<ets>mollis</ets> soft.]</ety> <def>Serving to soften; assuaging;
emollient.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molliently</ent><br/
<hw>Mol"lient*ly</hw>, <pos>adv.</pos> <def>Assuagingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollifiable</ent><br/
<hw>Mol"li*fi`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being mollified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollification</ent><br/
<hw>Mol`li*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>mollificatio</ets>; cf. F. <ets>mollification</ets>.]</ety>
<def>The act of mollifying, or the state of being mollified; a
softening.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollifier</ent><br/
<hw>Mol"li*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, mollifies.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollify</ent><br/
<hw>Mol"li*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mollified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mollifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>mollifier</ets>, L. <ets>mollificare</ets>; <ets>mollis</ets> soft
+ <ets>-ficare</ets> (in comp.) to make. See <er>Enmollient</er>,
<er>Moil</er>, <pos>v. t.</pos>, and <er>-fy</er>.]</ety> <sn>1.</sn>
<def>To soften; to make tender; to reduce the hardness, harshness, or
asperity of; to qualify; <as>as, to <ex>mollify</ex> the
ground</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With sweet science <qex>mollified</qex> their stubborn hearts.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To assuage, as pain or irritation, to appease, as
excited feeling or passion; to pacify; to calm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollinet</ent><br/
<hw>Mol"li*net</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Moline</er>.]</ety> <def>A little mill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollipilose</ent><br/
<hw>Mol`li*pi*lose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mollis</ets> soft + <ets>pilosus</ets> hairy.]</ety>
<fld>(Zool.)</fld> <def>Having soft hairs; downy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollities</ent><br/
\'d8<hw>Mol*li"ti*es</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
softness.]</ety> <fld>(Med.)</fld> <def>Unnatural softness of any organ
or part.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollitude</ent><br/
<hw>Mol"li*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mollitudo</ets>, fr. <ets>mollis</ets> soft.]</ety> <def>Softness;
effeminacy; weakness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollusc</ent><br/
<hw>Mol"lusc</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Mollusk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollusca</ent><br/
\'d8<hw>Mol*lus"ca</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos> <ety>[NL.
See <er>Mollusk</er>.]</ety> <fld>(Zool.)</fld> <def>One of the grand
divisions of the animal kingdom, a phylum including the classes
<class>Cephalopoda</class>, <class>Gastropoda</class>,
<class>Pteropoda</class>, <class>Scaphopoda</class>, and
<class>Pelecyopoda</class> (syn. <class>Bivalvia</class>, formerly
called <class>Lamellibranchiata</class>, or <class>Conchifera</class>).
These animals have an unsegmented bilateral body, with most of the
organs and parts paired, but not repeated longitudinally. Most of them
develop a mantle, which incloses either a branchial or a pulmonary
cavity. They are generally more or less covered and protected by a
calcareous shell, which may be univalve, bivalve, or
multivalve.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ Formerly the Brachiopoda, Bryzoa, and Tunicata were
united with the Lamellibranchiata in an artificial group called
Acephala, which was also included under Mollusca. See
<er>Molluscoidea</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molluscan</ent><br/
<hw>Mol*lus"can</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to mollusks.</def> -- <def2><pos>n.</pos> <def>A
mollusk; one of the Mollusca.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molluscoid</ent><br/
<hw>Mol*lus"coid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mollusca</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Resembling the true mollusks; belonging to the Molluscoidea.</def>
-- <def2><pos>n.</pos> <def>One of the Molluscoidea.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molluscoidal</ent><br/
<hw>Mol`lus*coid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Molluscoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molluscoidea</ent><br/
\'d8<hw>Mol`lus*coi"de*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Mollusk</er>, and <er>-oid</er>.]</ety> <fld>(Zool.)</fld>
<def>A division of Invertebrata which includes the classes
<class>Brachiopoda</class> and <class>Bryozoa</class>; -- called also
<altname>Anthoid Mollusca</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Originally the Tunicata were included under
Molluscoidea, from which they are known to differ widely in structure
and embryology. Molluscoidea were formerly considered a subdivision of
Mollusca, but they are now known to have more relationship with Annelida
than with Mollusca.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molluscous</ent><br/
<hw>Mol*lus"cous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Molluscan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molluscum</ent><br/
\'d8<hw>Mol*lus"cum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Mollusk</er>.]</ety> <fld>(Med.)</fld> <def>A cutaneous disease
characterized by numerous tumors, of various forms, filled with a thick
matter; -- so called from the resemblance of the tumors to some
molluscous animals.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mollusk</ent><br/
<hw>Mol"lusk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mollusque</ets>, L. <ets>mollusca</ets> a kind of soft nut with a
thin shell, fr. <ets>molluscus</ets> soft, <ets>mollis</ets> soft. See
<er>Mollify</er>.]</ety> <fld>(Zool.)</fld> <def>One of the
<phylum>Mollusca</phylum>.</def> <altsp>[Written also
<asp>mollusc</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molly</ent><br/
<hw>Mol"ly</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same
as <er>Mollemoke</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molly</ent><br/
<hw>Mol"ly</hw>, <pos>n.</pos> <def>A pet or colloquial name for
<xex>Mary</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Molly cottontail</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Cottontail</er>.</cd> -- <col><b>Molly Maguire</b></col>
<pr>(m<adot/*gw<imac/r")</pr>; <plu><it>pl.</it> <er>Molly Maguires</er>
<pr>(-gw<imac/rz)</pr>.</plu> <sd>(a)</sd> <cd>A member of a secret
association formed among the tenantry in Ireland about 1843, principally
for the purpose of intimidating law officers and preventing the service
of legal writs. Its members disguised themselves in the dress of
women.</cd> <sd>(b)</sd> <cd>A member of a similar association of
Irishmen organized in the anthracite coal region of Pennsylvania, about
1854, for the purpose of intimidating employers and officers of the law,
and for avenging themselves by murder on persons obnoxious to them. The
society was broken up by criminal prosecutions in 1876.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mollycoddle</ent><br/
<hw>mollycoddle</hw> <pos>n.</pos> <def>a pampered darling; an
effeminate man; a milksop.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mollycoddle</ent><br/
<hw>mollycoddle</hw> <pos>v. t.</pos> <def>To pamper or
coddle.</def><br/
[<source>PJC</source>]</p>

<p><ent>Molly-mawk</ent><br/
<hw>Mol"ly-mawk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Mollemoke</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moloch</ent><br/
<hw>Mo"loch</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[Heb.
<ets>molek</ets> king.]</ety> <sn>1.</sn> <fld>(Script.)</fld> <def>The
fire god of the Ammonites in Canaan, to whom human sacrifices were
offered; Molech. Also applied figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A spiny Australian lizard
(<spn>Moloch horridus</spn>). The horns on the head and numerous spines
on the body give it a most formidable appearance.</def> <-- illustr. of
Moloch. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molokany</ent><br/
<ent>Molokane</ent><br/
<mhw>{ <hw>Mol`o*ka"ne</hw> <pr>(?)</pr>, <hw>Mol`o*ka"ny</hw> }</mhw>,
<pos>n. pl.</pos> <ety>[Russ. <ets>molokane</ets>.]</ety> <def>See
<er>Raskolnik</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Molosse</ent><br/
<hw>Mo*losse"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Molossus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molosses</ent><br/
<hw>Mo*los"ses</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Molasses.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molossine</ent><br/
<hw>Mo*los"sine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A bat of the genus <gen>Molossus</gen>, as the monk bat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molossus</ent><br/
\'d8<hw>Mo*los"sus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, prop., Molossian, belonging to the Molossians, a people in the
eastern part of Epirus.]</ety> <fld>(Gr. & Lat. Pros.)</fld> <def>A foot
of three long syllables.</def> <altsp>[Written also
<asp>molosse</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molotov</ent><br/
<hw>Molotov</hw> <pos>n.</pos> <def>a city in the European part of
Soviet Russia.</def><br/
<syn><b>Syn. --</b> Perm.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Molotov cocktail</ent><br/
<hw>Molotov cocktail</hw> <pos>n.</pos> <def>A home-made incendiary
device consisting of a bottle filled with gasoline, and a cloth wick.
The wick is lighted, and the bottle thrown at a target, such as a
vehicle, where it may shatter and spread intense flames over the
vehicle, destroying or damaging it.</def><br/
[<source>PJC</source>]</p>

<p><ent>Molt</ent><br/
<hw>Molt</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Melt</er>.</def> <rj><au>Chaucer.</au> <au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moult</ent><br/
<ent>Molt</ent><br/
<mhw>{ <hw>Molt</hw>, <hw>Moult</hw> }</mhw> <pr>(?)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Molted</conjf> or
<conjf>Moulted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Molting</conjf> or <conjf>Moulting</conjf>.]</vmorph> <ety>[OE.
<ets>mouten</ets>, L. <ets>mutare</ets>. See <er>Mew</er> to molt, and
cf. <er>Mute</er>, <pos>v. t.</pos>]</ety> <altsp>[The prevalent
spelling is, perhaps, <asp>moult</asp>; but as the <asp>u</asp> has not
been inserted in the otherwords of this class, <as>as, <ex>bolt</ex>,
<ex>colt</ex>, <ex>dolt</ex>, etc.</as>, it is desirable to complete the
analogy by the spelling <asp>molt</asp>.]</altsp> <def>To shed or cast
the hair, feathers, skin, horns, or the like, as an animal or a
bird.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moult</ent><br/
<ent>Molt</ent><br/
<mhw>{ <hw>Molt</hw>, <hw>Moult</hw>, }</mhw> <pos>v. t.</pos> <def>To
cast, as the hair, skin, feathers, or the like; to shed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moult</ent><br/
<ent>Molt</ent><br/
<mhw>{ <hw>Molt</hw>, <hw>Moult</hw>, }</mhw> <pos>n.</pos> <def>The act
or process of changing the feathers, hair, skin, etc.;
molting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moltable</ent><br/
<hw>Molt"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of assuming
a molten state; meltable; fusible.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molten</ent><br/
<hw>Mol"ten</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Melt</er>.]</ety> <sn>1.</sn> <def>Melted; being in a state of
fusion, esp. when the liquid state is produced by a high degree of heat;
<as>as, <ex>molten</ex> iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made by melting and casting the substance or metal
of which the thing is formed; <as>as, a <ex>molten</ex>
image</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>molting</ent><br/
<hw>molting</hw> <pos>n.</pos> <def>The act or process by which an
animal molts; especially, the periodic shedding of the cuticle in
arthropods or the outer skin in reptiles, or feathers in
birds.</def><br/
<syn><b>Syn. --</b> molt, moult, moulting, ecdysis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Molto</ent><br/
\'d8<hw>Mol"to</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Much; very; <as>as, <ex>molto</ex> adagio, very
slow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moly</ent><br/
<hw>Mo"ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/.]</ety>
<sn>1.</sn> <def>A fabulous herb of occult power, having a black root
and white blossoms, said by <persfn>Homer</persfn> to have been given by
<persfn>Hermes</persfn> to <persfn>Ulysses</persfn> to counteract the
spells of <persfn>Circe</persfn>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A kind of garlic (<spn>Allium
Moly</spn>) with large yellow flowers; -- called also <altname>golden
garlic</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdate</ent><br/
<hw>Mo*lyb"date</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of molybdic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdena</ent><br/
<hw>Mol`yb*de"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>molybdaena</ets> galena, Gr. <?/, fr. <?/ lead.]</ety>
<fld>(Min.)</fld> <def>See <er>Molybdenite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdenite</ent><br/
<hw>Mo*lyb"de*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>molybd<eacute/nite</ets>. See <er>Molybdena</er>.]</ety>
<fld>(Min.)</fld> <def>A mineral occurring in soft, lead-gray, foliated
masses or scales, resembling graphite; sulphide of molybdenum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdenous</ent><br/
<hw>Mo*lyb"de*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>See <er>Molybdous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdenum</ent><br/
<hw>Mol`yb*de"num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf. F.
<ets>molybd<egrave/ne</ets>. See <er>Molybdena</er>.]</ety>
<fld>(Chem.)</fld> <def>A rare element of the chromium group, occurring
in nature in the minerals molybdenite and wulfenite, and when reduced
obtained as a hard, silver-white, difficulty fusible metal. Symbol Mo.
Atomic number 42. Atomic weight 95.94.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Molybdic</ent><br/
<hw>Mo*lyb"dic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>molybdique</ets>. See <er>molybdena</er>.]</ety> <fld>(Chem.)</fld>
<def>Of, pertaining to, or containing, molybdenum; specif., designating
those compounds in which the element has a higher valence, as contrasted
with <contr>molybdous</contr> compounds; <as>as, <ex>molybdic</ex>
oxide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdite</ent><br/
<hw>Mo*lyb"dite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Molybdic ocher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Molybdous</ent><br/
<hw>Mo*lyb"dous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Molybdena</er>.]</ety> <def>Of, pertaining to, or containing,
molybdenum; specif., designating those compounds in which molybdenum has
a lower valence as contrasted with <contr>molybdic</contr>
compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mome</ent><br/
<hw>Mome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Mumm</er>,
<er>Momus</er>.]</ety> <def>A dull, silent person; a blockhead.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moment</ent><br/
<hw>Mo"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>moment</ets>,
L. <ets>momentum</ets>, for <ets>movimentum</ets> movement, motion,
moment, fr. <ets>movere</ets> to move. See <er>Move</er>, and cf.
<er>Momentum</er>, <er>Movement</er>.]</ety> <sn>1.</sn> <def>A minute
portion of time; a point of time; an instant; <as>as, at that very
<ex>moment</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In a <qex>moment</qex>, in the twinkling of an eye.</q> <rj><qau>1
Cor. xv. 52.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Impulsive power; force; momentum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>moments</qex> or quantities of motion in bodies.</q>
<rj><qau>Berkley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Touch, with lightest <qex>moment</qex> of impulse,<br/
His free will.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Importance, as in influence or effect; consequence;
weight or value; consideration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Matters of great <qex>moment</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is an abstruse speculation, but also of far less
<qex>moment</qex> and consequence of us than the others.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An essential element; a deciding point, fact, or
consideration; an essential or influential circumstance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>An infinitesimal change in a
varying quantity; an increment or decrement.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mech.)</fld> <def>Tendency, or measure of tendency,
to produce motion, esp. motion about a fixed point or axis.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moment of a couple</b></col> <fld>(Mech.)</fld>, <cd>the
product of either of its forces into the perpendicular distance between
them.</cd> -- <col><b>Moment of a force</b></col>. <fld>(Mech.)</fld>
<sd>(a)</sd> <mark>With respect to a point</mark>, <cd>the product of
the intensity of the force into the perpendicular distance from the
point to the line of direction of the force</cd>. <sd>(b)</sd>
<mark>With respect to a line</mark>, <cd>the product of that component
of the force which is perpendicular to the plane passing through the
line and the point of application of the force, into the shortest
distance between the line and this point</cd>. <sd>(c)</sd> <mark>With
respect to a plane that is parallel to the force</mark>, <cd>the product
of the force into the perpendicular distance of its point of application
from the plane.</cd> -- <col><b>Moment of inertia</b></col>, <cd>of a
rotating body, the sum of the mass of each particle of matter of the
body into the square of its distance from the axis of rotation; --
called also <altname>moment of rotation</altname> and <altname>moment of
the mass</altname>.</cd> -- <col><b>Statical moment</b></col>, <cd>the
product of a force into its leverage; the same as <altname>moment of a
force</altname> with respect to a point, line, etc.</cd> --
<col><b>Virtual moment</b></col>. <cd>See under
<er>Virtual</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Instant; twinkling; consequence; weight; force;
value; consideration; signification; avail.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momental</ent><br/
<hw>Mo*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>momental</ets>.]</ety> <mark>[Obs.]</mark> <sn>1.</sn> <def>Lasting
but a moment; brief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not one <qex>momental</qex> minute doth she swerve.</q>
<rj><qau>Breton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Important; momentous.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mech.)</fld> <def>Of or pertaining to moment or
momentum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momentally</ent><br/
<hw>Mo*men"tal*ly</hw>, <pos>adv.</pos> <def>For a moment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momentany</ent><br/
<ent>Momentaneous</ent><br/
<mhw>{ <hw>Mo`men*ta"ne*ous</hw> <pr>(?)</pr>, <hw>Mo"men*ta*ny</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>momentaneus</ets>: cf.
F. <ets>momentan<eacute/</ets>.]</ety> <def>Momentary.</def>
<mark>[Obs.]</mark> <au>Hooker.</au> <ldquo/<xex>Momentany</xex> as a
sound.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momentarily</ent><br/
<hw>Mo"men*ta*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>Every moment; from moment to moment.</def>
<rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a moment; in the immediate future.</def><br/
[<source>PJC</source>]</p>

<p><ent>Momentariness</ent><br/
<hw>Mo"men*ta*ri*ness</hw>, <pos>n.</pos> <def>The state or quality of
being momentary; shortness of duration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momentary</ent><br/
<hw>Mo"men*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>momentarius</ets>. See <er>Moment</er>.]</ety> <def>Done in a
moment; continuing only a moment; lasting a very short time; <as>as, a
<ex>momentary</ex> pang</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>momentary</qex> joy breeds months of pain.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momently</ent><br/
<hw>Mo"ment*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>For a
moment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a moment; every moment; momentarily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momentous</ent><br/
<hw>Mo*men"tous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>momentosus</ets> rapid, momentary.]</ety> <def>Of moment or
consequence; very important; weighty; <as>as, a <ex>momentous</ex>
decision; <ex>momentous</ex> affairs.</as></def> --
<wordforms><wf>Mo*men"tous*ly</wf>, <pos>adv.</pos> --
<wf>Mo*men"tous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>momentousness</ent><br/
<hw>mo*men"tous*ness</hw> <pos>n.</pos> <def>utmost
importance.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Momentum</ent><br/
<hw>Mo*men"tum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Momenta</plw> <pr>(#)</pr>, F. <plw>Momentums</plw>
<pr>(#)</pr>.</plu> <ety>[L. See <er>Moment</er>.]</ety> <sn>1.</sn>
<fld>(Mech.)</fld> <def>The quantity of motion in a moving body, being
always proportioned to the quantity of matter multiplied by the
velocity; impetus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Essential element, or constituent element.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall state the several <qex>momenta</qex> of the distinction in
separate propositions.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A property of an activity or course of events,
viewed as analogous to forward motion or to physical momentum (def. 1),
such that the activity is believed to be able to continue moving forward
without further application of force or effort; -- often used to
describe an increase in the acquisition of public support for a purpose;
<as>as, as, the petition drive gained <ex>momentum</ex> when it was
mentioned in the newspapers</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Momier</ent><br/
<hw>Mom"i*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>m<ocir/mier</ets>, fr. OF. <ets>momer</ets>, <ets>mommer</ets>, to
mumm, to mask one's self.]</ety> <def>A name given in contempt to strict
Calvinists in Switzerland, France, and some parts of Germany, in the
early part of the 19th century.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mommery</ent><br/
<hw>Mom"mer*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mummery</er>.</def> <rj><au>Rowe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momordica</ent><br/
<hw>Momordica</hw> <pos>prop. n.</pos> <def>A genus of Old World
tropical vine.</def><br/
<syn><b>Syn. --</b> genus <gen>Momordica</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Momos</ent><br/
<hw>Momos</hw> <pos>prop. n.</pos> <fld>(Gr. Myth.)</fld> <def>The god
of blame and mockery; Momus.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Momot</ent><br/
<hw>Mo"mot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Momot</ets> and
<ets>motmot</ets>, the native American name.]</ety> <fld>(Zool.)</fld>
<def>See <er>Motmot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Momotus</ent><br/
<hw>Momotus</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Momotidae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Momotus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Momus</ent><br/
\'d8<hw>Mo"mus</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[Gr. <?/
blame, ridicule, Momus.]</ety> <fld>(Gr. Myth.)</fld> <def>The god of
mockery and censure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mon</ent><br/
<hw>Mon</hw> <pr>(m<ocr/n)</pr>, <pos>n.</pos> <ety>[Jap., usually
translated as <ets>crest</ets>.]</ety> <fld>(Japan)</fld> <def>The badge
of a family, esp. of a family of the ancient feudal nobility. The most
frequent form of the mon is circular, and it commonly consists of
conventionalized forms from nature, flowers, birds, insects, the
lightnings, the waves of the sea, or of geometrical symbolic figures;
color is only a secondary character. It appears on lacquer and pottery,
and embroidered on, or woven in, fabrics. The imperial chrysanthemum,
the mon of the reigning family, is used as a national emblem. Formerly
the mon of the shoguns of the Tokugawa family was so used.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mon-</ent><br/
<hw>Mon-</hw> <pr>(?)</pr>. <def>Same as <er>Mono-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mona</ent><br/
\'d8<hw>Mo"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. Sp. & Pg.
<ets>mona</ets>, fem. of <ets>mono</ets> a monkey, ape.]</ety>
<fld>(Zool.)</fld> <def>A small, handsome, long-tailed West American
monkey (<spn>Cercopithecus mona</spn>). The body is dark olive, with a
spot of white on the haunches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monachal</ent><br/
<hw>Mon"a*chal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monachus</ets> a monk: cf. F. <ets>monacal</ets>. See
<er>Monk</er>.]</ety> <def>Of or pertaining to monks or a monastic life;
monastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monachism</ent><br/
<hw>Mon"a*chism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>monachisme</ets>.]</ety> <def>The system and influences of a
monastic life; monasticism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monacid</ent><br/
<hw>mon*ac"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mon-</ets> +
<ets>acid</ets>.]</ety> <fld>(Chem.)</fld> <def>Having one hydrogen atom
replaceable by an acidic atom or radical.</def><br/
<syn><b>Syn. --</b> monoacid, monoacidic, monacidic.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of neutralizing one equivalent of a
monobasic acid; -- said of bases, and of certain metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monacid</ent><br/
<hw>mon*ac"id</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>An acid having one replaceable hydrogen atom.</def><br/
<syn><b>Syn. --</b> monoacid.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Monad</ent><br/
<hw>Mon"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>monas</ets>,
<ets>-adis</ets>, a unit, Gr. <?/, <?/, fr. <grk>mo`nos</grk>
alone.]</ety> <sn>1.</sn> <def>An ultimate atom, or simple, unextended
point; something ultimate and indivisible.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Philos. of Leibnitz)</fld> <def>The elementary and
indestructible units which were conceived of as endowed with the power
to produce all the changes they undergo, and thus determine all physical
and spiritual phenomena.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>One of the smallest flagellate
Infusoria; esp., the species of the genus <gen>Monas</gen>, and allied
genera.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Biol.)</fld> <def>A simple, minute organism; a
primary cell, germ, or plastid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Chem.)</fld> <def>An atom or radical whose valence
is one, or which can combine with, be replaced by, or exchanged for, one
atom of hydrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monad deme</b></col> <fld>(Biol.)</fld>, <cd>in
tectology, a unit of the first order of individuality.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 938 --></p>

<p><ent>Monadaria</ent><br/
\'d8<hw>Mon`a*da"ri*a</hw>
<pr>(m<ocr/n`<adot/*d<amac/"r<icr/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Monad</er>.]</ety> <fld>(Zool.)</fld> <def>The
Infusoria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monadelphia</ent><br/
\'d8<hw>Mon`a*del"phi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <grk>mo`nos</grk> alone + <grk>'adelfo`s</grk> brother.]</ety>
<fld>(Bot.)</fld> <def>A Linnaean class of plants having the stamens
united into a tube, or ring, by the filaments, as in the Mallow
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monadelphous</ent><br/
<ent>Monadelphian</ent><br/
<mhw>{ <hw>Mon`a*del"phi*an</hw> <pr>(?)</pr>, <hw>Mon`a*del"phous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>monadelphie</ets>.]</ety> <fld>(Bot.)</fld> <def>Of or pertaining
to the Monadelphia; having the stamens united in one body by the
filaments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monadical</ent><br/
<ent>Monadic</ent><br/
<mhw>{ <hw>Mo*nad"ic</hw> <pr>(?)</pr>, <hw>Mo*nad"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of, pertaining to, or like, a
monad, in any of its senses. See <er>Monad</er>, <pos>n.</pos></def>
<rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monadiform</ent><br/
<hw>Mo*nad"i*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Monad</ets> + <ets>-form</ets>.]</ety> <fld>(Biol.)</fld>
<def>Having the form of a monad; resembling a monad in having one or
more filaments of vibratile protoplasm; <as>as, <ex>monadiform</ex>
young</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monadology</ent><br/
<hw>Mon`ad*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Monad</ets> + <ets>-logy</ets>.]</ety> <fld>(Philos.)</fld>
<def>The doctrine or theory of monads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monal</ent><br/
<hw>Mo*nal"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any
Asiatic pheasant of the genus <gen>Lophophorus</gen>, as the Impeyan
pheasant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monamide</ent><br/
<hw>Mon*am"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mon-</ets> +
<ets>amide</ets>.]</ety> <fld>(Chem.)</fld> <def>An amido compound with
only one amido group; a monoamide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monamine</ent><br/
<hw>Mon*am"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mon-</ets> +
<ets>amine</ets>.]</ety> <fld>(Chem.)</fld> <def>A basic compound
containing one amido group; a monoamine; <as>as, methyl amine is a
<ex>monamine</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monander</ent><br/
<hw>Mo*nan"der</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>One of the Monandria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monandria</ent><br/
\'d8<hw>Mo*nan"dri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <grk>mo`nos</grk> alone + <grk>'anh`r</grk>,
<grk>'andro`s</grk>, a man.]</ety> <fld>(Bot.)</fld> <def>A Linnaean
class of plants embracing those having but a single stamen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monandrian</ent><br/
<hw>Mo*nan"dri*an</hw> <pr>(?)</pr>, <pos>a.</pos>; <fld>(Bot.)</fld>
<def>Same as <er>Monandrous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monandric</ent><br/
<hw>Mo*nan"dric</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to monandry; practicing monandry as a system of marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monandrous</ent><br/
<hw>Mo*nan"drous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Of or pertaining to the monandria; having but one stamen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monandry</ent><br/
<hw>Mo*nan"dry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Monandria</er>.]</ety> <def>The possession by a woman of only one
husband at the same time; -- contrasted with
<xex>polyandry</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monanthous</ent><br/
<hw>Mo*nan"thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mon-</ets>
+ Gr. <grk>'a`nqos</grk> flower.]</ety> <fld>(Bot.)</fld> <def>Having
but one flower; one-flowered.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarch</ent><br/
<hw>Mon"arch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>monarque</ets>, L. <ets>monarcha</ets>, fr. Gr. <?/, <?/;
<grk>mo`nos</grk> alone + <?/ to be first, rule, govern. See
<er>Archi-</er>.]</ety> <sn>1.</sn> <def>A sole or supreme ruler; a
sovereign; the highest ruler; an emperor, king, queen, prince, or
chief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He who reigns<br/
<qex>Monarch</qex> in heaven, . . . upheld by old repute.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One superior to all others of the same kind; <as>as,
an oak is called the <ex>monarch</ex> of the forest</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A patron deity or presiding genius.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, thou, <qex>monarch</qex> of the vine,<br/
Plumpy Bacchus.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A very large red and black
butterfly (<spn>Danais Plexippus</spn>); -- called also
<altname>milkweed butterfly</altname> and <altname>monarch
butterfly</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarch</ent><br/
<hw>Mon"arch</hw>, <pos>a.</pos> <def>Superior to others; preeminent;
supreme; ruling.</def> <ldquo/<xex>Monarch</xex> savage.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchal</ent><br/
<hw>Mo*nar"chal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
monarch; suiting a monarch; sovereign; regal; imperial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Satan, whom now transcendent glory raised<br/
Above his fellows, with <qex>monarchal</qex> pride.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>monarch butterfly</ent><br/
<hw>mon"arch but"ter*fly</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
very large red and black butterfly (<spn>Danais Plexippus</spn>) having
striking orange-brown wings with black veins in a reticulated pattern;
-- called also <altname>milkweed butterfly</altname> and
<altname>monarch</altname>. Its larvae feed on the leaves of the
milkweed.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Monarchess</ent><br/
<hw>Mon"arch*ess</hw>, <pos>n.</pos> <def>A female monarch.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchial</ent><br/
<hw>Mo*nar"chi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Monarchic.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchian</ent><br/
<hw>Mo*nar"chi*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>One of a sect in the early Christian church which
rejected the doctrine of the Trinity; -- called also
<altname>patripassian</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchical</ent><br/
<ent>Monarchic</ent><br/
<mhw>{ <hw>Mo*nar"chic</hw> <pr>(?)</pr>, <hw>Mo*nar"chic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[F. <ets>monarchique</ets>, Gr.
<?/.]</ety> <def>Of or pertaining to a monarch, or to monarchy.</def>
<au>Burke.</au> -- <wordforms><wf>Mo*nar"chic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchism</ent><br/
<hw>Mon"arch*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles
of, or preference for, monarchy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchist</ent><br/
<hw>Mon"arch*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>monarchiste</ets>.]</ety> <def>An advocate of, or believer in,
monarchy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchize</ent><br/
<hw>Mon"arch*ize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Monarchized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Monarchizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
play the sovereign; to act the monarch.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchize</ent><br/
<hw>Mon"arch*ize</hw>, <pos>v. t.</pos> <def>To rule; to govern.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchizer</ent><br/
<hw>Mon"arch*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
monarchizes; also, a monarchist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarcho</ent><br/
<hw>Mo*nar"cho</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The nickname of a
crackbrained Italian who fancied himself an emperor.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monarchy</ent><br/
<hw>Mon"arch*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Monarchies</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>monarchie</ets>,
L. <ets>monarchia</ets>, Gr. <?/. See <er>Monarch</er>.]</ety>
<sn>1.</sn> <def>A state or government in which the supreme power is
lodged in the hands of a monarch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A system of government in which the chief ruler is a
monarch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In those days he had affected zeal for <qex>monarchy</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The territory ruled over by a monarch; a
kingdom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What scourage for perjury<br/
Can this dark <qex>monarchy</qex> afford false Clarence.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fifth monarchy</b></col>, <cd>a universal monarchy,
supposed to be the subject of prophecy in Daniel ii.; the four preceding
monarchies being Assyrian, Persian, Grecian, and Roman. See <cref>Fifth
Monarchy men</cref>, under <er>Fifth</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>monarda</ent><br/
<hw>monarda</hw> <pos>n.</pos> <def>Any of various aromatic herbs of the
genus <gen>Monarda</gen>.</def><br/
<syn><b>Syn. --</b> wild bergamot.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monas</ent><br/
\'d8<hw>Mo"nas</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Monad</er>.]</ety> <fld>(Zool.)</fld> <def>A genus of minute
flagellate Infusoria of which there are many species, both free and
attached. See <xex>Illust.</xex> under <er>Monad</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monasterial</ent><br/
<hw>Mon`as*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monasterials</ets>, fr. <ets>monasterium</ets>.]</ety> <def>Of or
pertaining to monastery, or to monastic life.</def> --
<wordforms><wf>Mon`as*te"ri*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monastery</ent><br/
<hw>Mon"as*te*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Monasteries</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>monasterium</ets>, Gr. <?/, fr. <?/ a solitary, a monk, fr. <?/ to
be alone, live in solitude, fr. <grk>mo`nos</grk> alone. Cf.
<er>Minister</er>.]</ety> <def>A house of religious retirement, or of
secusion from ordinary temporal concerns, especially for monks; -- more
rarely applied to such a house for females.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Convent; abbey; priory. See
<er>Cloister</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monastic</ent><br/
<hw>Mo*nas"tic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A monk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monastical</ent><br/
<ent>Monastic</ent><br/
<mhw>{ <hw>Mo*nas"tic</hw> <pr>(?)</pr>, <hw>Mo*nas"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ monk: cf. F.
<ets>monastique</ets>. See <er>Monastery</er>.]</ety> <sn>1.</sn>
<def>Of or pertaining to monasteries, or to their occupants, rules,
etc., <as>as, <ex>monastic</ex> institutions or rules</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Secluded from temporal concerns and devoted to
religion; recluse.</def> <ldquo/A life <xex>monastic</xex>.<rdquo/
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monastically</ent><br/
<hw>Mo*nas"tic*al*ly</hw>, <pos>adv.</pos> <def>In a monastic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monasticism</ent><br/
<hw>Mo*nas"ti*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The monastic
life, system, or condition.</def> <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monasticon</ent><br/
<hw>Mo*nas"ti*con</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Monastic</er>.]</ety> <def>A book giving an account of
monasteries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monatomic</ent><br/
<hw>Mon`a*tom"ic</hw> <pr>(?)</pr>, <pos>adv.</pos>
<ety>[<ets>Mon-</ets> + <ets>atomic</ets>.]</ety> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>Consisting of, or containing, one atom; <as>as, the
molecule of mercury is <ex>monatomic</ex></as>.</def> <sd>(b)</sd>
<def>Having the equivalence or replacing power of an atom of hydrogen;
univalent; <as>as, the methyl radical is
<ex>monatomic</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monaural</ent><br/
<hw>mon*au"ral</hw> <pr>(m<ocr/n*<ocir/r"<ait/l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Having or hearing with only one ear.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Same as <er>monophonic</er>{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monaxial</ent><br/
<hw>Mo*nax"i*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mon-</ets> +
<ets>axial</ets>.]</ety> <fld>(Biol.)</fld> <def>Having only one axis;
developing along a single line or plane; <as>as, <ex>monaxial</ex>
development</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monazite</ent><br/
<hw>Mon"a*zite</hw> <pr>(m<ocr/n"<adot/*z<imac/t)</pr>, <pos>n.</pos>
<ety>[From Gr. <grk>mona`zein</grk> to be solitary, in allusion to its
isolated crystals.]</ety> <fld>(Min.)</fld> <def>A mineral occurring
usually in small isolated crystals, -- a phosphate of the cerium
metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monday</ent><br/
<hw>Mon"day</hw> <pr>(m<ucr/n"d<asl/; 48)</pr>, <pos>n.</pos> <ety>[OE.
<ets>moneday</ets>, <ets>monenday</ets>, AS. <ets>m<omac/nandaeg</ets>,
i.e., day of the moon, day sacred to the moon; akin to D.
<ets>maandag</ets>, G. <ets>montag</ets>, OHG. <ets>m<amac/natag</ets>,
Icel. <ets>m<amac/nadagr</ets>, Dan. <ets>mandag</ets>, Sw.
<ets>m<aring/ndag</ets>. See <er>Moon</er>, and <er>Day</er>.]</ety>
<def>The second day of the week; the day following Sunday.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monday's Child</ent><br/
<hw>Mon"day's Child</hw> <pr>(m<ucr/n"d<amac/z ch<imac/ld`)</pr>,
<pos>n.</pos> <def>A child who is fair of face; -- a reference to a
nineteenth century poem. See below.</def><br/
[<source>PJC</source>]</p>

<p><q>Monday's child is fair of face,<br/
Tuesday's child is full of grace,<br/
Wednesday's child is full of woe,<br/
Thursday's child has far to go,<br/
Friday's child is loving and giving,<br/
Saturday's child works hard for a living,<br/
But the child who is born on the Sabbath day,<br/
Is lucky and happy and good and gay.</q><br/
[<source>PJC</source>]</p>

<p><ent>Monde</ent><br/
\'d8<hw>Monde</hw> <pr>(m<ocir/Nd)</pr>, <pos>n.</pos> <ety>[F. See
<er>Mundane</er>.]</ety> <def>The world; a globe as an ensign of
royalty.</def> <mark>[R.]</mark> <rj><au>A. Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Le beau monde</b></col> <ety>[F.]</ety>, <cd>fashionable
society. See <er>Beau monde</er>.</cd> -- <col><b>Demi monde</b></col>.
<cd>See <er>Demimonde</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mone</ent><br/
<hw>Mone</hw> <pr>(m<omac/n)</pr>, <pos>n.</pos> <def>The moon.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mone</ent><br/
<hw>Mone</hw>, <pos>n.</pos> <def>A moan.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monecious</ent><br/
<ent>Monecian</ent><br/
<mhw>{ <hw>Mo*ne"cian</hw> <pr>(?)</pr>, <hw>Mo*ne"cious</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Bot.)</fld> <def>See
<er>Monoecian</er>, and <er>Monoecious</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monembryony</ent><br/
<hw>Mon*em"bry*o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mono-</er>, and <er>Embryo</er>.]</ety> <fld>(Bot.)</fld> <def>The
condition of an ovule having but a single embryo.</def> --
<wordforms><wf>Mon*em`bry*on"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moner</ent><br/
<hw>Mo"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One
of the Monera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monera</ent><br/
\'d8<hw>Mo*ne"ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. Gr.
<grk>mo`nos</grk> single.]</ety> <fld>(Zool.)</fld> <def>The lowest
division of rhizopods, including those which resemble the amoebas, but
are destitute of a nucleus.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>One of the five kingdoms of
living organisms in the five-kingdom classification, consisting of
microscopic usually monocellular prokaryotic organisms that mostly
reproduce by asexual fission, sporulation, or budding; it includes the
bacteria and cyanophytes (blue-green algae), as well as certain
primitive pathogenic microbes, such as the Rickettsias.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moneral</ent><br/
<hw>Mo*ne"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the Monera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moneran</ent><br/
<hw>Mo*ne"ran</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Monera.</def> -- <def2><pos>n.</pos>
<def>One of the Monera.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moneron</ent><br/
\'d8<hw>Mo*ne"ron</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Monera</plw> <pr>(#)</pr>; E. <plw>Monerons</plw>
<pr>(#)</pr>.</plu> <ety>[NL.]</ety> <fld>(Zool.)</fld> <def>One of the
Monera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monerula</ent><br/
\'d8<hw>Mo*ner"u*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of
<ets>moner</ets>. See <er>Monera</er>.]</ety> <fld>(Biol.)</fld> <def>A
germ in that stage of development in which its form is simply that of a
non-nucleated mass of protoplasm. It precedes the one-celled germ. So
called from its likeness to a moner.</def>
<rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monesia</ent><br/
<hw>Mo*ne"sia</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Pharm.)</fld>
<def>The bark, or a vegetable extract brought in solid cakes from South
America and believed to be derived from the bark, of the tree
<spn>Chrysophyllum glycyphloeum</spn>. It is used as an alterative and
astringent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monesin</ent><br/
<hw>Mo*ne"sin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The acrid principle
of Monesia, sometimes used as a medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monest</ent><br/
<hw>Mo*nest"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Admonish</er>.]</ety> <def>To warn; to admonish; to advise.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif (2 Cor. v. 20).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>monestrous</ent><br/
<hw>mon*es"trous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having only one estrus period per breeding cycle or per year; -- of
certain mammals.</def><br/
[<source>PJC</source>]</p>

<p><ent>monetarism</ent><br/
<hw>mon"e*tar*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An economic
theory holding that the rate of growth of the money supply is the
priunciple cause of changes in inflation, economic growth, and
unemployment.</def><br/
[<source>PJC</source>]</p>

<p><ent>monetarist</ent><br/
<hw>mon"e*tar*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who adheres
to the theory of monetarism.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monetary</ent><br/
<hw>Mon"e*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monetarius</ets> belonging to a mint. See <er>Money</er>.]</ety>
<def>Of or pertaining to money, or consisting of money; pecuniary.</def>
<ldquo/The <xex>monetary</xex> relations of Europe.<rdquo/ <rj><au>E.
Everett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monetary unit</b></col>, <cd>the standard of a national
currency, as the dollar in the United States, the pound in England, the
peso in Mexico, the ruble in Russia, the franc in France, the mark in
Germany. Also, the standard of an international currency, such as the
euro used in the European union.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Moneth</ent><br/
<hw>Mon"eth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A month.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>monetisation</ent><br/
<hw>monetisation</hw> <pos>n.</pos> <def>monetization.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>monetization</ent><br/
<hw>mon`e*ti*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of converting into money, or of establishing something (e.g.
gold or silver) as the legal tender of a country; <as>as, the
<ex>monetization</ex> of silver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monetize</ent><br/
<hw>Mon"e*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To convert into
money; to adopt as current money; <as>as, to <ex>monetize</ex>
silver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Money</ent><br/
<hw>Mon"ey</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Moneys</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>moneie</ets>, OF.
<ets>moneie</ets>, F. <ets>monnaie</ets>, fr. L. <ets>moneta</ets>. See
<er>Mint</er> place where coin is made, <er>Mind</er>, and cf.
<er>Moidore</er>, <er>Monetary</er>.]</ety> <sn>1.</sn> <def>A piece of
metal, as gold, silver, copper, etc., coined, or stamped, and issued by
the sovereign authority as a medium of exchange in financial
transactions between citizens and with government; also, any number of
such pieces; coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To prevent such abuses, . . . it has been found necessary . . . to
affix a public stamp upon certain quantities of such particular metals,
as were in those countries commonly made use of to purchase goods. Hence
the origin of coined <qex>money</qex>, and of those public offices
called mints.</q> <rj><qau>A. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any written or stamped promise, certificate, or
order, as a government note, a bank note, a certificate of deposit,
etc., which is payable in standard coined money and is lawfully current
in lieu of it; in a comprehensive sense, any currency usually and
lawfully employed in buying and selling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any article used as a medium of payment in financial
transactions, such as checks drawn on checking accounts.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Economics)</fld> <def>Any form of wealth which
affects a person's propensity to spend, such as checking accounts or
time deposits in banks, credit accounts, letters of credit, etc. Various
aggregates of money in different forms are given different names, such
as <stype>M-1</stype>, the total sum of all currency in circulation plus
all money in demand deposit accounts (checking accounts).</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ Whatever, among barbarous nations, is used as a medium
of effecting exchanges of property, and in the terms of which values are
reckoned, as sheep, wampum, copper rings, quills of salt or of gold
dust, shovel blades, etc., is, in common language, called their
<xex>money</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In general, wealth; property; <as>as, he has much
<ex>money</ex> in land, or in stocks; to make, or lose,
<ex>money</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The love of <qex>money</qex> is a root of all kinds of evil.</q>
<rj><qau>1 Tim vi. 10 (Rev. Ver. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Money bill</b></col> <fld>(Legislation)</fld>, <cd>a bill
for raising revenue.</cd> -- <col><b>Money broker</b></col>, <cd>a
broker who deals in different kinds of money; one who buys and sells
bills of exchange; -- called also <altname>money changer</altname>.</cd>
-- <col><b>Money cowrie</b></col> <fld>(Zool.)</fld>, <cd>any one of
several species of <gen>Cypraea</gen> (esp. <spn>Cypraea moneta</spn>)
formerly much used as money by savage tribes. See <er>Cowrie</er>.</cd>
-- <col><b>Money of account</b></col>, <cd>a denomination of value used
in keeping accounts, for which there may, or may not, be an equivalent
coin; <it>e. g.</it>, the mill is a <xex>money of account</xex> in the
United States, but not a coin.</cd> -- <col><b>Money order</b></col>,
<sd>(a)</sd> <cd>an order for the payment of money; specifically, a
government order for the payment of money, issued at one post office as
payable at another; -- called also <altname>postal money
order</altname>.</cd> -- <sd>(b)</sd> <cd>a similar order issued by a
bank or other financial institution.</cd> -- <col><b>Money
scrivener</b></col>, <cd>a person who procures the loan of money to
others.</cd> <mark>[Eng.]</mark> -- <mcol><col><b>Money
spider</b></col>, <col><b>Money spinner</b></col></mcol>
<fld>(Zool.)</fld>, <cd>a small spider; -- so called as being popularly
supposed to indicate that the person upon whom it crawls will be
fortunate in money matters.</cd> -- <col><b>Money's worth</b></col>,
<cd>a fair or full equivalent for the money which is paid.</cd> --
<col><b>A piece of money</b></col>, <cd>a single coin.</cd> --
<col><b>Ready money</b></col>, <cd>money held ready for payment, or
actually paid, at the time of a transaction; cash.</cd> --
<col><b>plastic money</b></col>, <cd>credit cards, usually made out of
plastic; also called <altname>plastic</altname>; <as>as, put it on the
<ex>plastic</ex></as>.</cd> -- <col><b>To make money</b></col>, <cd>to
gain or acquire money or property; to make a profit in
dealings.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Money</ent><br/
<hw>Mon"ey</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To supply with
money.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moneyage</ent><br/
<hw>Mon"ey*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>monnayage</ets> coinage.]</ety> <sn>1.</sn> <def>A tax paid to the
first two Norman kings of England to prevent them from debashing the
coin.</def> <rj><au>Hume.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mintage; coinage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>moneybag</ent><br/
<hw>moneybag</hw> <pos>n.</pos> <def>a drawstring bag for holding
money.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moneyed</ent><br/
<hw>Mon"eyed</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>Supplied with money; having money; wealthy; <as>as,
<ex>moneyed</ex> men</as>.</def> <altsp>[Also spelled
<asp>monied</asp>.]</altsp> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Converted into money; coined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If exportation will not balance importation, away must your silver
go again, whether <qex>moneyed</qex> or not <qex>moneyed</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Consisting in, or composed of, money.</def>
<rj><au>A. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moneyer</ent><br/
<hw>Mon"ey*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Money</er>; cf. OF. <ets>monoier</ets>, F. <ets>monnoayeur</ets>, L.
<ets>monetarius</ets> a master of the mint. Cf.
<er>Monetary</er>.]</ety> <sn>1.</sn> <def>A person who deals in money;
banker or broker.</def> <mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An authorized coiner of money.</def> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Company of Moneyers</b></col>, <cd>the officials who
formerly coined the money of Great Britain, and who claimed certain
prescriptive rights and privileges.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>moneylender</ent><br/
<hw>moneylender</hw> <pos>n.</pos> <def>someone who lends money at
excessive rates of interest.</def><br/
<syn><b>Syn. --</b> usurer, loan shark, shark, money-lender.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moneyless</ent><br/
<hw>Mon"ey*less</hw>, <pos>a.</pos> <def>Destitute of money; penniless;
impecunious.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Money-maker</ent><br/
<hw>Mon"ey-mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who coins or prints money; also, a counterfeiter of money.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who accumulates money or wealth; specifically,
one who makes money-getting his governing motive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Money-making</ent><br/
<hw>Mon"ey-mak`ing</hw>, <pos>n.</pos> <def>The act or process of making
money; the acquisition and accumulation of wealth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Obstinacy in <qex>money-making</qex>.</q>
<rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Money-making</ent><br/
<hw>Mon"ey-mak`ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Affording
profitable returns; lucrative; <as>as, a <ex>money-making</ex>
business</as>. Opposite of <contr>unprofitable</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Successful in gaining money, and devoted to that
aim; <as>as, a <ex>money-making</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moneyman</ent><br/
<hw>moneyman</hw> <pos>n.</pos> <def>a person skilled in large scale
financial transactions.</def><br/
<syn><b>Syn. --</b> financier.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>money-spinner</ent><br/
<hw>money-spinner</hw> <pos>n.</pos> <def>a project that generates a
continuous flow of money.</def><br/
<syn><b>Syn. --</b> moneymaker, cash cow.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- ##??Money supply; --></p>

<p><ent>Moneywort</ent><br/
<hw>Mon"ey*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A trailing plant (<spn>Lysimachia Nummularia</spn>), with rounded
opposite leaves and solitary yellow flowers in their axils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongcorn</ent><br/
<hw>Mong"corn`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mangcorn</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monger</ent><br/
<hw>Mon"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mangere</ets>, fr. <ets>mangian</ets> to trade; akin to Icel.
<ets>manga</ets> to trade, <ets>mangari</ets> a trader, OHG.
<ets>mangari</ets>, <ets>mengari</ets>; cf. L. <ets>mango</ets> a dealer
in slaves.]</ety> <sn>1.</sn> <def>A trader; a dealer; -- now used
chiefly in composition; <as>as, fish<ex>monger</ex>,
iron<ex>monger</ex>, news<ex>monger</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small merchant vessel.</def> <mark>[Obs.]</mark>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monger</ent><br/
<hw>Mon"ger</hw>, <pos>v. t.</pos> <def>To deal in; to make merchandise
of; to traffic in; -- used chiefly of discreditable traffic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongol</ent><br/
<hw>Mon"gol</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the
Mongols.</def> -- <def2><pos>a.</pos> <def>Of or pertaining to Mongolia
or the Mongols.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongolian</ent><br/
<hw>Mon*go"li*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Mongolia or the Mongols.</def> -- <def2><pos>n.</pos> <def>One of the
Mongols.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongolic</ent><br/
<hw>Mon*gol"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Mongolian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongoloid</ent><br/
<hw>Mon"go*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mongol</ets>
+ <ets>-oid</ets>.]</ety> <def>Resembling a Mongol or the Mongols;
having race characteristics, such as color, hair, and features, like
those of the Mongols.</def> <rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of, related to, or affected with, <er>Down
syndrome</er>; -- not a technical term.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mongoloid</ent><br/
<hw>Mon"go*loid</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person affected
with <er>Down syndrome</er>; -- not a technical term.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mongolians</ent><br/
<ent>Mongols</ent><br/
<mhw>{ <hw>Mon"gols</hw> <pr>(?)</pr>, <hw>Mon*go"li*ans</hw>
<pr>(?)</pr> }</mhw>, <pos>n. pl.</pos> <fld>(Ethnol.)</fld> <def>One of
the great races of man, including the greater part of the inhabitants of
China, Japan, and the interior of Asia, with branches in Northern Europe
and other parts of the world. By some American Indians are considered a
branch of the Mongols. In a more restricted sense, the inhabitants of
Mongolia and adjacent countries, including the Burats and the
Kalmuks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongoos</ent><br/
<ent>Mongoose</ent><br/
<mhw>{ <hw>Mon"goose</hw>, <hw>Mon"goos</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos>; <plu>pl. <plw>Mongooses</plw> <pr>(#)</pr></plu>
<sn>1.</sn> <fld>(Zool.)</fld> <def>A species of ichneumon
(<spn>Herpestes griseus</spn>), native of India. Applied also to other
allied species, as the African banded mongoose (<spn>Crossarchus
fasciatus</spn>).</def> <altsp>[Written also <asp>mungoose</asp>,
<asp>mungoos</asp>, <asp>mungous</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Tamil <ets>manegos</ets>.]</ety> <def>A Madagascan
lemur (<spn>Lemur mongos</spn>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mongrel</ent><br/
<hw>Mon"grel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. shortened fr.
<ets>mongrel</ets>, and akin to AS. <ets>mengan</ets> to mix, and E.
<ets>mingle</ets>. See <er>Mingle</er>.]</ety> <def>The progeny
resulting from a cross between two breeds, as of domestic animals;
anything of mixed breed.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongrel</ent><br/
<hw>Mon"grel</hw>, <pos>a.</pos> <sn>1.</sn> <fld>(Zool.)</fld> <def>Not
of a pure breed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of mixed kinds; <as>as, <ex>mongrel</ex>
language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mongrelize</ent><br/
<hw>Mon"grel*ize</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To cause
to be mongrel; to cross breeds, so as to produce mongrels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>'Mongst</ent><br/
<hw>'Mongst</hw> <pr>(?)</pr>, <pos>prep.</pos> <def>See
<er>Amongst</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moniker</ent><br/
<ent>monicker</ent><br/
<mhw><hw>monicker</hw>, <hw>moniker</hw></mhw> <pos>n.</pos> <def>The
name of a person, especially an alias or a nickname.</def>
<mark>[slang]</mark> <br/
<syn><b>Syn. --</b> nickname, alias, sobriquet, cognomen.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Monied</ent><br/
<hw>Mon"ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Moneyed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monifier</ent><br/
<hw>Mo*nif"i*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>monile</ets> necklace + <ets>ferre</ets> to bear.]</ety>
<fld>(Paleon.)</fld> <def>A fossil fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moniliales</ent><br/
\'d8<hw>Mo*nil`i*a"les</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>monile</ets> necklace, -- because the conidia are produced
in chains.]</ety> <fld>(Bot.)</fld> <def>The largest of the three orders
into which the Fungi Imperfecti are divided, including various
forms.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>moniliasis</ent><br/
<hw>moniliasis</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>An infectious
disease caused by fungi of the genera
<causedby><gen>Monilia</gen></causedby> or
<causedby><gen>Candida</gen></causedby> especially
<causedby><spn>Candida albicans</spn></causedby>.</def><br/
<syn><b>Syn. --</b> candidiasis, monilia disease.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moniliform</ent><br/
<hw>Mo*nil"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monile</ets> necklace + <ets>-form</ets>: cf. F.
<ets>moniliforme</ets>.]</ety> <fld>(Biol.)</fld> <def>Joined or
constricted, at regular intervals, so as to resemble a string of beads;
<as>as, a <ex>moniliform</ex> root; a <ex>moniliform</ex> antenna</as>.
See <ex>Illust</ex>. of <er>Antenna</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moniment</ent><br/
<hw>Mon"i*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monimentum</ets>, <ets>monumentum</ets>. See
<er>Monument</er>.]</ety> <def>Something to preserve memory; a reminder;
a monument; hence, a mark; an image; a superscription; a record.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monish</ent><br/
<hw>Mon"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>monesten</ets>. See <er>Admonish</er>, <er>Monition</er>.]</ety>
<def>To admonish; to warn. See <er>Admonish</er>.</def>
<mark>[Archaic]</mark> <rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monisher</ent><br/
<hw>Mon"ish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who monishes;
an admonisher.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monishment</ent><br/
<hw>Mon"ish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Admonition.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 939 --></p>

<p><ent>Monism</ent><br/
<hw>Mon"ism</hw> <pr>(m<ocr/n"<icr/z'm <it>or</it>
m<omac/"n<icr/z'm)</pr>, <pos>n.</pos> <ety>[From Gr. <grk>mo`nos</grk>
single.]</ety> <sn>1.</sn> <fld>(Metaph.)</fld> <def>That doctrine which
refers all phenomena to a single ultimate constituent or agent; -- the
opposite of <contr>dualism</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The doctrine has been held in three generic forms:
matter and its phenomena have been explained as a modification of mind,
involving an idealistic <xex>monism</xex>; or mind has been explained by
and resolved into matter, giving a materialistic <xex>monism</xex>; or,
thirdly, matter, mind, and their phenomena have been held to be
manifestations or modifications of some one substance, like the
substance of Spinoza, or a supposed unknown something of some
evolutionists, which is capable of an objective and subjective
aspect.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>See <er>Monogenesis</er>,
1.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The doctrine that the universe is an organized
unitary being or total self-inclusive structure.</def></p>

<p><q><qex>Monism</qex> means that the whole of reality, i.e.,
everything that is, constitutes one inseparable and indivisible
entirety. <qex>Monism</qex> accordingly is a unitary conception of the
world. It always bears in mind that our words are abstracts representing
parts or features of the One and All, and not separate existences. Not
only are matter and mind, soul and body, abstracts, but also such
scientific terms as atoms and molecules, and also religious terms such
as God and world.</q> <rj><qau>Paul Carus.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monist</ent><br/
<hw>Mon"ist</hw>, <pos>n.</pos> <def>A believer in monism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monistic</ent><br/
<hw>Mo*nis"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining to,
or involving, monism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monition</ent><br/
<hw>Mo*ni"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>monitio</ets>, from <ets>monere</ets> to warn, bring to mind; akin
to E. <ets>mind</ets>. See <er>Mind</er>, and cf. <er>Admonish</er>,
<er>Money</er>, <er>Monster</er>.]</ety> <sn>1.</sn> <def>Instruction or
advice given by way of caution; an admonition; a warning; a
caution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sage <qex>monitions</qex> from his friends.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Information; indication; notice; advice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have no visible <qex>monition</qex> of . . . other periods,
such as we have of the day by successive light and darkness.</q>
<rj><qau>Holder.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Admiralty Practice)</fld> <def>A process in the
nature of a summons to appear and answer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eccl. Law)</fld> <def>An order monishing a party
complained against to obey under pain of the law.</def>
<rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitive</ent><br/
<hw>Mon"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Conveying
admonition; admonitory.</def> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitor</ent><br/
<hw>Mon"i*tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>monere</ets>. See <er>Monition</er>, and cf.
<er>Mentor</er>.]</ety> <sn>1.</sn> <def>One who admonishes; one who
warns of faults, informs of duty, or gives advice and instruction by way
of reproof or caution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You need not be a <qex>monitor</qex> to the king.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, specifically, a pupil selected to look to the
school in the absence of the instructor, to notice the absence or faults
of the scholars, or to instruct a division or class.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Any large Old World lizard of the
genus <gen>Varanus</gen>; esp., the Egyptian species (<spn>Varanus
Niloticus</spn>), which is useful because it devours the eggs and young
of the crocodile. It is sometimes five or six feet long.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[So called from the name given by <person>Captain
Ericson</person>, its designer, to the first ship of the kind.]</ety>
<def>An ironclad war vessel, very low in the water, and having one or
more heavily-armored revolving turrets, carrying heavy guns.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mach.)</fld> <def>A tool holder, as for a lathe,
shaped like a low turret, and capable of being revolved on a vertical
pivot so as to bring successively the several tools in holds into proper
position for cutting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A monitor nozzle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Monitor top</b></col>, <cd>the raised central portion, or
clearstory, of a car roof, having low windows along its
sides.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitorial</ent><br/
<hw>Mon`i*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of
or pertaining to a monitor or monitors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Done or performed by a monitor; <as>as,
<ex>monitorial</ex> work</as>; conducted or taught by monitors; <as>as,
a <ex>monitorial</ex> school; <ex>monitorial</ex>
instruction.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitorially</ent><br/
<hw>Mon`i*to"ri*al*ly</hw>, <pos>adv.</pos> <def>In a monitorial
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitor nozzle</ent><br/
<hw>Monitor nozzle</hw>. <def>A nozzle capable of turning completely
round in a horizontal plane and having a limited play in a vertical
plane, used in hydraulic mining, fire-extinguishing apparatus,
etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monitorship</ent><br/
<hw>Mon"i*tor*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The post or
office of a monitor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitory</ent><br/
<hw>Mon"i*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monitorius</ets>.]</ety> <def>Giving admonition; instructing by way
of caution; warning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Losses, miscarriages, and disappointments, are <qex>monitory</qex>
and instructive.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitory</ent><br/
<hw>Mon"i*to*ry</hw>, <pos>n.</pos> <def>Admonition; warning;
especially, a monition proceeding from an ecclesiastical court, but not
addressed to any one person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monitrix</ent><br/
<ent>Monitress</ent><br/
<mhw>{ <hw>Mon"i*tress</hw> <pr>(?)</pr>, <hw>Mon"i*trix</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>A female monitor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monk</ent><br/
<hw>Monk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>munuc</ets>,
<ets>munec</ets>, <ets>munc</ets>, L. <ets>monachus</ets>, Gr. <?/, fr.
<grk>mo`nos</grk> alone. Cf. <er>Monachism</er>.]</ety> <sn>1.</sn>
<def>A man who retires from the ordinary temporal concerns of the world,
and devotes himself to religion; one of a religious community of men
inhabiting a monastery, and bound by vows to a life of chastity,
obedience, and poverty.</def> <ldquo/A <xex>monk</xex> out of his
cloister.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Monks</qex> in some respects agree with regulars, as in the
substantial vows of religion; but in other respects <qex>monks</qex> and
regulars differ; for that regulars, vows excepted, are not tied up to so
strict a rule of life as <qex>monks</qex> are.</q>
<rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A blotch or spot of ink on a
printed page, caused by the ink not being properly distributed. It is
distinguished from a <xex>friar</xex>, or white spot caused by a
deficiency of ink.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A piece of tinder made of agaric, used in firing the
powder hose or train of a mine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A South American
monkey (<spn>Pithecia monachus</spn>); also applied to other species, as
<spn>Cebus xanthocephalus</spn>.</def> <sd>(b)</sd> <def>The European
bullfinch.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monk bat</b></col> <fld>(Zool.)</fld>, <cd>a South
American and West Indian bat (<spn>Molossus nasutus</spn>); -- so called
because the males live in communities by themselves.</cd> --
<col><b>Monk bird</b></col><fld>(Zool.)</fld>, <cd>the friar bird.</cd>
-- <col><b>Monk seal</b></col> <fld>(Zool.)</fld>, <cd>a species of seal
(<spn>Monachus albiventer</spn>) inhabiting the Black Sea, the
Mediterranean Sea, and the adjacent parts of the Atlantic.</cd> --
<col><b>Monk's rhubarb</b></col> <fld>(Bot.)</fld>, <cd>a kind of dock;
-- also called <altname>patience</altname> (<spn>Rumex
Patientia</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkery</ent><br/
<hw>Monk"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Monkeries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The life of
monks; monastic life; monastic usage or customs; -- now usually applied
by way of reproach.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Miters, and wretched dead mediaeval <qex>monkeries</qex>.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A collective body of monks.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Though he have a whole <qex>monkery</qex> to sing for him.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkey</ent><br/
<hw>Mon"key</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Monkeys</plw> <pr>(#)</pr>.</plu> <ety>[Cf. OIt.
<ets>monicchio</ets>, It. <ets>monnino</ets>, dim. of <ets>monna</ets>
an ape, also dame, mistress, contr. fr. <ets>madonna</ets>. See
<er>Madonna</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>In the most general sense, any one of the Quadrumana, including
apes, baboons, and lemurs.</def> <sd>(b)</sd> <def>Any species of
Quadrumana, except the lemurs.</def> <sd>(c)</sd> <def>Any one of
numerous species of Quadrumana (esp. such as have a long tail and
prehensile feet) exclusive of apes and baboons.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The monkeys are often divided into three groups:
(<stype>a</stype>) <stype>Catarrhines</stype>, or <fam>Simidae</fam>.
These have an oblong head, with the oblique flat nostrils near together.
Some have no tail, as the apes. All these are natives of the Old World.
(<stype>b</stype>) <stype>Platyrhines</stype>, or <fam>Cebidae</fam>.
These have a round head, with a broad nasal septum, so that the nostrils
are wide apart and directed downward. The tail is often prehensile, and
the thumb is short and not opposable. These are natives of the New
World. (<stype>c</stype>) <stype>Strepsorhines</stype>, or
<fam>Lemuroidea</fam>. These have a pointed head with curved nostrils.
They are natives of Southern Asia, Africa, and Madagascar.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A term of disapproval, ridicule, or contempt, as for
a mischievous child.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the <qex>monkey's</qex> own giving out; she is persuaded I
will marry her.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The weight or hammer of a pile driver, that is, a
very heavy mass of iron, which, being raised on high, falls on the head
of the pile, and drives it into the earth; the falling weight of a drop
hammer used in forging.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A small trading vessel of the sixteenth
century.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monkey boat</b></col>. <fld>(Naut.)</fld> <sd>(a)</sd>
<cd>A small boat used in docks</cd>. <sd>(b)</sd> <cd>A half-decked boat
used on the River Thames.</cd> -- <col><b>Monkey block</b></col>
<fld>(Naut.)</fld>, <cd>a small single block strapped with a
swivel.</cd> <au>R. H. Dana, Jr.</au> -- <col><b>Monkey flower</b></col>
<fld>(Bot.)</fld>, <cd>a plant of the genus <gen>Mimulus</gen>; -- so
called from the appearance of its gaping corolla.</cd> <au>Gray.</au> --
<col><b>Monkey gaff</b></col> <fld>(Naut.)</fld>, <cd>a light gaff
attached to the topmast for the better display of signals at sea.</cd>
-- <col><b>Monkey jacket</b></col>, <cd>a short closely fitting jacket,
worn by sailors.</cd> -- <col><b>Monkey rail</b></col>
<fld>(Naut.)</fld>, <cd>a second and lighter rail raised about six
inches above the quarter rail of a ship.</cd> -- <col><b>Monkey
shine</b></col>, <cd>monkey trick.</cd> <mark>[Slang, U.S.]</mark> --
<col><b>Monkey trick</b></col>, <cd>a mischievous prank.</cd>
<au>Saintsbury.</au> -- <col><b>Monkey wheel</b></col>. <cd>See
<cref>Gin block</cref>, under 5th <er>Gin</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkey</ent><br/
<hw>Mon"key</hw>, <pos>v. t. & i.</pos> <def>To act or treat as a monkey
does; to ape; to act in a grotesque or meddlesome manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To monkey with</b></col>, <col><b>To monkey around
with</b></col></mcol>, <cd>to handle in a meddlesome manner.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Monkey-bread</ent><br/
<hw>Mon"key-bread`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The fruit of the <spn>Adansonia digitata</spn>; also, the tree. See
<er>Adansonia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkey-cup</ent><br/
<hw>Mon"key-cup`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Nepenthes</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monkey pod</ent><br/
<ent>monkeypod</ent><br/
<mhw><hw>monkeypod</hw>, <hw>monkey pod</hw></mhw> <pos>n.</pos>
<def>large ornamental tropical American tree (<spn>Albizia saman</spn>)
with bipinnate leaves and globose clusters of flowers with crimson
stamens and sweet-pulp seed pods eaten by cattle.</def><br/
<syn><b>Syn. --</b> rain tree, saman, zaman, zamang, <spn>Albizia
saman</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monkey-pot</ent><br/
<hw>Mon"key-pot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The fruit of two South American trees (<spn>Lecythis Ollaria</spn>,
and <spn>Lecythis Zabucajo</spn>), which have for their fruit large,
pot-shaped, woody capsules containing delicious nuts, and opening almost
explosively by a circular lid at the top. Vases and pots are made of
this capsule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkey's puzzle</ent><br/
<hw>Mon"key's puz"zle</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>A lofty
coniferous Chilian tree (<spn>Araucaria araucana</spn>, formerly
<spn>Araucaria imbricata</spn>), the branches of which are so crowded
and intertwisted <ldquo/as to puzzle a monkey to climb.<rdquo/ It is
also called <altname>monkey puzzle</altname> and <altname>monkey puzzle
tree</altname>. The edible nuts are over an inch long, and are called
<xex>pi<ntil/on</xex> by the Chilians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkeytail</ent><br/
<hw>Mon"key*tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A short, round iron bar or lever used in naval gunnery.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>monkey wrench</ent><br/
<ent>monkeywrench</ent><br/
<mhw><hw>monkeywrench</hw>, <hw>monkey wrench</hw></mhw> <pos>n.</pos>
<def>A wrench or spanner which has one fixed and one adjustable
jaw.</def><br/
<syn><b>Syn. --</b> monkey wrench.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monkfish</ent><br/
<hw>Monk"fish</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The angel fish (<gen>Squatina</gen>).</def>
<sd>(b)</sd> <def>The angler (<gen>Lophius</gen>), esp. the goosefishes
<spn>Lophius Americanus</spn> in America and <spn>Lophius
piscatorius</spn> in Europe, used for food.</def> <au>[MW10]</au><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Monkflower</ent><br/
<hw>Monk"flow`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A name of certain curious orchids which bear three kinds of flowers
formerly referred to three genera, but now ascertained to be sexually
different forms of the same genus (<spn>Catasetum tridentatum</spn>,
etc.).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkhood</ent><br/
<hw>Monk"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Monk</ets> +
<ets>-hood</ets>.]</ety> <sn>1.</sn> <def>The character or condition of
a monk.</def> <rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Monks, regarded collectively.</def>
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monking</ent><br/
<hw>Monk"ing</hw>, <pos>a.</pos> <def>Monkish.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkish</ent><br/
<hw>Monk"ish</hw>, <pos>a.</pos> <def>Like a monk, or pertaining to
monks; monastic; <as>as, <ex>monkish</ex> manners; <ex>monkish</ex>
dress; <ex>monkish</ex> solitude.</as></def> --
<wordforms><wf>Monk"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkly</ent><br/
<hw>Monk"ly</hw>, <pos>a.</pos> <def>Like, or suitable to, a monk.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monkshood</ent><br/
<hw>Monks"hood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A plant of the genus <gen>Aconitum</gen>; aconite. See
<er>Aconite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monk's seam</ent><br/
<hw>Monk's" seam`</hw> <pr>(?)</pr>. <fld>(Naut.)</fld> <def>An extra
middle seam made at the junction of two breadths of canvas, ordinarily
joined by only two rows of stitches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mon-</ent><br/
<ent>Mono-</ent><br/
<mhw>{ <hw>Mon"o-</hw> <pr>(?)</pr>, <hw>Mon-</hw> <pr>(?)</pr> }</mhw>.
<ety>[Gr. <?/.]</ety> <def>A prefix signifying <sig>one</sig>,
<sig>single</sig>, <sig>alone</sig>; <as>as, <ex>mono</ex>carp,
<ex>mono</ex>poly</as>; <fld>(Chem.)</fld> indicating that a compound
contains <sig>one atom</sig>, <sig>one radical</sig>, or <sig>one
group</sig> of that to the name of which it is united; <as>as,
<ex>mon</ex>oxide, <ex>mono</ex>sulphide, <ex>mon</ex>atomic,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mono</ent><br/
\'d8<hw>Mo"no</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<fld>(Zool.)</fld> <def>The <altname>black howler</altname>
(<spn>Mycetes villosus</spn>), a monkey of Central America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monobasic</ent><br/
<hw>Mon`o*ba"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mono-</ets>
+ <ets>basic</ets>.]</ety> <fld>(Chem.)</fld> <def>Capable of being
neutralized by a univalent base or basic radical; having but one acid
hydrogen atom to be replaced; -- said of acids; <as>as, acetic, nitric,
and hydrochloric acids are <ex>monobasic</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monocarboxylic</ent><br/
<ent>monocarbonic</ent><br/
<mhw><hw>mon`o*car*bon"ic</hw>, <hw>mon`o*car*box*yl"ic</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mono-</ets> +
<ets>carbonic</ets>.]</ety> <fld>(Chem.)</fld> <def>Containing one
carboxyl group; <as>as, acetic acid is a <ex>monocarbonic</ex>
acid</as>. The more common term is <altname>monocarboxylic</altname>.
Contrasted with <contr>dicarboxylic</contr>,
<contr>tricarboxylic</contr>, etc.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Monocardian</ent><br/
<hw>Mon`o*car"di*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ heart.]</ety> <fld>(Zool.)</fld>
<def>Having a single heart, as fishes and amphibians.</def> --
<def2><pos>n.</pos> <def>An animal having a single
heart.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocarp</ent><br/
<hw>Mon"o*carp</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
monocarpic plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocarpellary</ent><br/
<hw>Mon`o*car"pel*la*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>carpellary</ets>.]</ety> <fld>(Bot.)</fld>
<def>Consisting of a single carpel, as the fruit of the pea, cherry, and
almond.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocarpous</ent><br/
<ent>Monocarpic</ent><br/
<mhw>{ <hw>Mon`o*car"pic</hw> <pr>(?)</pr>, <hw>Mon`o*car"pous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Mono-</ets> + Gr. <?/
fruit: cf. F. <ets>monocarpe</ets>.]</ety> <fld>(Bot.)</fld>
<def>Bearing fruit but once, and dying after fructification, as beans,
maize, mustard, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Annual and biennual herbs are monocarpic, so also some
plants of longer duration, as the century plant.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocephalous</ent><br/
<hw>Mon`o*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <grk>kefalh`</grk> head.]</ety>
<fld>(Bot.)</fld> <def>Having a solitary head; -- said of unbranched
composite plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoceros</ent><br/
\'d8<hw>Mo*noc"e*ros</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/; <grk>mo`nos</grk> alone, single + <grk>ke`ras</grk> horn.]</ety>
<sn>1.</sn> <def>A one-horned creature; a unicorn; a sea monster with
one horn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mighty <qex>monoceroses</qex> with immeasured tails.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>The Unicorn, a constellation
situated to the east Orion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monochlamydeous</ent><br/
<hw>Mon`o*chla*myd"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/, <?/, cloak: cf. F.
<ets>monochlamyd<eacute/</ets>.]</ety> <fld>(Bot.)</fld> <def>Having a
single floral envelope, that is, a calyx without a corolla, or,
possibly, in rare cases, a corolla without a calyx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monochord</ent><br/
<hw>Mon"o*chord</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monochordon</ets>, Gr. <?/, fr. <?/ with but one string; <?/ only,
single + <?/ string: cf. F. <ets>monocorde</ets>. See <er>Chord</er>,
and cf. <er>Mainchord</er>.]</ety> <fld>(Mus.)</fld> <def>An instrument
for experimenting upon the mathematical relations of musical sounds. It
consists of a single string stretched between two bridges, one or both
of which are movable, and which stand upon a graduated rule for the
purpose of readily changing and measuring the length of the part of the
string between them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monochromatic</ent><br/
<hw>Mon`o*chro*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>monochromatique</ets>. See <er>Monochrome</er>.]</ety>
<def>Consisting of one color, or presenting rays of light of one color
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monochromatic lamp</b></col> <fld>(Opt.)</fld>,<cd>a lamp
whose flame yields rays of some one homogenous light. It is of great
importance in optical experiments.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monochrome</ent><br/
<hw>Mon"o*chrome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ of one
color; <grk>mo`nos</grk> single + <?/ color: cf. F.
<ets>monochrome</ets>.]</ety> <def>A painting or drawing in a single
color; a picture made with a single color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monochromic</ent><br/
<hw>Mon`o*chro"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made, or done,
with a single color; <as>as, a <ex>monochromic</ex> picture</as>. Called
also, <altname>monochromatic</altname> and
<altname>monochrome</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Monochromy</ent><br/
<hw>Mon"o*chro`my</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
painting or drawing in monochrome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monochronic</ent><br/
<hw>Mon`o*chron"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ time.]</ety> <def>Existing at the same
time; contemporaneous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monociliated</ent><br/
<hw>Mon`o*cil"i*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>ciliated</ets>.]</ety> <fld>(Biol.)</fld>
<def>Having but one cilium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocle</ent><br/
<hw>Mon"o*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Monocular</er>.]</ety> <def>An eyeglass for one eye.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoclinal</ent><br/
<hw>Mon`o*cli"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Monoclinic</er>.]</ety> <fld>(Geol.)</fld> <def>Having one oblique
inclination; -- applied to strata that dip in only one direction from
the axis of elevation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocline</ent><br/
<hw>Mon"o*cline</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Geol.)</fld>
<def>A monoclinal fold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoclinic</ent><br/
<hw>Mon`o*clin"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ to incline.]</ety>
<fld>(Crystallog.)</fld> <def>Having one oblique intersection; -- said
of that system of crystallization in which the vertical axis is inclined
to one, but at right angles to the other, lateral axis. See
<er>Crystallization</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoclinous</ent><br/
<hw>Mo*noc"li*nous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ couch, fr. <?/ to lie down: cf. F.
<ets>monocline</ets>.]</ety> <fld>(Bot.)</fld> <def>Hermaphrodite, or
having both stamens and pistils in every flower.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocondyla</ent><br/
\'d8<hw>Mon`o*con"dy*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Mono-</er>, and <er>Condyle</er>.]</ety> <fld>(Zool.)</fld>
<def>A group of vertebrates, including the birds and reptiles, or those
that have only one occipital condyle; the Sauropsida.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocotyl</ent><br/
<hw>Mon"o*co*tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Any monocotyledonous plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocotyle</ent><br/
<hw>Mon"o*co*tyle</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>monocotyle</ets>.]</ety> <fld>(Bot.)</fld>
<def>Monocotyledonous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocotyledon</ent><br/
<hw>Mon`o*cot`y*le"don</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>cotyledon</ets>: cf. F.
<ets>monocotyl<eacute/done</ets>.]</ety> <fld>(Bot.)</fld> <def>A plant
with only one cotyledon, or seed lobe; a member of the
<class>Monocotyledonae</class>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The plural, <xex>monocotyledons</xex>, is used as the
name of a large class of plants (the <class>Monocotyledones</class>, or
<class>Monocotyledonae</class>), and is generally understood to be
equivalent to the term <xex>endogens</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocotyledones</ent><br/
<ent>Monocotyledonae</ent><br/
<mhw><hw>Monocotyledonae</hw>, <hw>Monocotyledones</hw></mhw> <pos>prop.
n.</pos> <def>A class of plants comprising seed plants that produce an
embryo with a single cotyledon and parallel-veined leaves: grasses;
lilies; palms; and orchids. It is divided into four subclasses or
superorders: Alismatidae; Arecidae; Commelinidae; and
Liliidae.</def><br/
<syn><b>Syn. --</b> class <class>Monocotyledones</class>,
<class>Monocotyledonae</class>, class <class>Monocotyledonae</class>,
<class>Liliopsida</class>, class <class>Liliopsida</class>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monocotyledonous</ent><br/
<hw>Mon`o*cot`y*le"don*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>monocotyl<eacute/don<eacute/</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having only one cotyledon, seed lobe, or seminal leaf.</def>
<rj><au>Lindley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocracy</ent><br/
<hw>Mo*noc"ra*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mono-</ets>
+ <ets>-cracy</ets>, as in <ets>democracy</ets>.]</ety> <def>Government
by a single person; undivided rule.</def> <rj><au>Sydney
Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocrat</ent><br/
<hw>Mon"o*crat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Gr. <?/ ruling
alone.]</ety> <def>One who governs alone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocrotic</ent><br/
<hw>Mon`o*crot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physiol.)</fld>
<def>Of, pertaining to, or showing, monocrotism; <as>as, a
<ex>monocrotic</ex> pulse; a pulse of the <ex>monocrotic</ex>
type.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocrotism</ent><br/
<hw>Mo*noc"ro*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mo`nos</grk> alone + <?/ a beating.]</ety> <fld>(Physiol.)</fld>
<def>That condition of the pulse in which the pulse curve or sphygmogram
shows but a single crest, the dicrotic elevation entirely
disappearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monocular</ent><br/
<hw>Mo*noc"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monoculus</ets>; Gr. <grk>mo`nos</grk> single + L.
<ets>oculus</ets> eye: cf. F. <ets>monoculaire</ets>.]</ety> <sn>1.</sn>
<def>Having only one eye; with one eye only; <as>as, <ex>monocular</ex>
vision</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Adapted to be used with only one eye at a time;
<as>as, a <ex>monocular</ex> microscope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 940 --></p>

<p><ent>monocule</ent><br/
<hw>mon"o*cule</hw> <pr>(m<ocr/n"<osl/*k<umac/l)</pr>, <pos>n.</pos>
<ety>[See <er>Monocular</er>.]</ety> <fld>(Zool.)</fld> <def>A small
crustacean with one median eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monoculous</ent><br/
<hw>mo*noc"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Monocular.</def>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>monocystic</ent><br/
<hw>mon`o*cys"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Mono-</er>, and <er>Cyst</er>.]</ety> <fld>(Zool.)</fld> <def>Of or
pertaining to a division (<fam>Monocystidea</fam>) of the protozoan
order <ord>Gregarinida</ord>, in which the body consists of one
sac.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodactylous</ent><br/
<hw>Mon`o*dac"tyl*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>monoda`ktylos</grk>; <grk>mo`nos</grk> single +
<grk>da`ktylos</grk> finger: cf. F. <ets>monodactyle</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having but one finger or claw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodelphian</ent><br/
<ent>Monodelph</ent><br/
<mhw>{ <hw>Mon"o*delph</hw> <pr>(?)</pr>, <hw>Mon`o*del"phi*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
Monodelphia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodelphia</ent><br/
\'d8<hw>Mon`o*del"phi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>mo`nos</grk> single + <grk>delfy`s</grk> the womb.]</ety>
<fld>(Zool.)</fld> <def>The group that includes all ordinary or
placental mammals; the Placentalia. See <er>Mammalia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodelphous</ent><br/
<ent>Monodelphic</ent><br/
<mhw>{ <hw>Mon`o*del"phic</hw> <pr>(?)</pr>, <hw>Mon`o*del"phous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Of or
pertaining to the Monodelphia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodical</ent><br/
<ent>Monodic</ent><br/
<mhw>{ <hw>Mo*nod"ic</hw> <pr>(?)</pr>, <hw>Mo*nod"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/.]</ety> <sn>1.</sn>
<def>Belonging to a monody.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>For one voice;
monophonic.</def> <sd>(b)</sd> <def>Homophonic; -- applied to music in
which the melody is confined to one part, instead of being shared by all
the parts as in the style called <contr>polyphonic</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodimetric</ent><br/
<hw>Mon`o*di*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>dimetric</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Dimetric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodist</ent><br/
<hw>Mon"o*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A writer of a
monody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodrame</ent><br/
<ent>Monodrama</ent><br/
<mhw>{ <hw>Mon"o*dra`ma</hw> <pr>(?)</pr>, <hw>Mon"o*drame</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[<ets>Mono-</ets> + Gr. <?/
drama.]</ety> <def>A drama acted, or intended to be acted, by a single
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodramatic</ent><br/
<hw>Mon`o*dra*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
a monodrama.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monody</ent><br/
<hw>Mon"o*dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Monodies</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>monodia</ets>, Gr.
<?/, fr. <?/ singing alone; <grk>mo`nos</grk> single + <?/ song: cf. F.
<ets>monodie</ets>. See <er>Ode</er>.]</ety> <def>A species of poem of a
mournful character, in which a single mourner expresses lamentation; a
song for one voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodynamic</ent><br/
<hw>Mon`o*dy*nam"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>dynamic</ets>.]</ety> <def>Possessing but
one capacity or power.</def> <ldquo/<xex>Monodynamic</xex> men.<rdquo/
<rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monodynamism</ent><br/
<hw>Mon`o*dy"na*mism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The theory
that the various forms of activity in nature are manifestations of the
same force.</def> <rj><au>G. H. Lewes.</au></rj> <note>A philosophical
form of the grand unified theory?</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Monoecia</ent><br/
\'d8<hw>Mo*noe"ci*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>mo`nos</grk> single + <?/ house.]</ety> <fld>(Bot.)</fld>
<def>A Linnaean class of plants, whose stamens and pistils are in
distinct flowers in the same plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoecian</ent><br/
<hw>Mo*noe"cian</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Of or pertaining to the Monoecia;
monoecious.</def> -- <def2><pos>n.</pos> <def>One of the
Monoecia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A monoecious animal, as certain
mollusks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoecious</ent><br/
<hw>Mo*noe"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Having the sexes united in one individual, as when male and female
flowers grow upon the same individual plant; hermaphrodite; -- opposed
to <ant>dioecious</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoecism</ent><br/
<hw>Mo*noe"cism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>The state or condition of being monoecious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogam</ent><br/
<hw>Mon"o*gam</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>One of the Monogamia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogamia</ent><br/
\'d8<hw>Mon`o*ga"mi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Monogamous</er>.]</ety> <fld>(Bot.)</fld> <def>A Linnaean order of
plants, having solitary flowers with united anthers, as in the genus
<gen>Lobelia</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogamic</ent><br/
<ent>Monogamian</ent><br/
<mhw>{ <hw>Mon`o*ga"mi*an</hw> <pr>(?)</pr>, <hw>Mon`o*gam"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See
<er>Monogamous</er>.]</ety> <sn>1.</sn> <def>Pertaining to, or
involving, monogamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Of or pertaining to the
<ord>Monogamia</ord>; having a simple flower with united
anthers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogamist</ent><br/
<hw>Mo*nog"a*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
practices or upholds monogamy.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogamous</ent><br/
<hw>Mo*nog"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monogamus</ets> having but one wife, Gr. <?/; <grk>mo`nos</grk>
single + <?/ marriage.]</ety> <sn>1.</sn> <def>Upholding, or practicing,
monogamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Same as
<er>Monogamian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Mating with but one of the
opposite sex; -- said of birds and mammals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monogamousness</ent><br/
<hw>monogamousness</hw> <pos>n.</pos> <def>The state of being
monogamous; having one wife at a time.</def><br/
<syn><b>Syn. --</b> monogamy, monogyny.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monogamy</ent><br/
<hw>Mo*nog"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monogamia</ets>, Gr. <?/: cf. F. <ets>monogamie</ets>.]</ety>
<sn>1.</sn> <def>Single marriage; marriage with but one person, husband
or wife, at the same time; -- opposed to <contr>polygamy</contr>. Also,
one marriage only during life; -- opposed to
<contr>deuterogamy</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>State of being paired with a
single mate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogastric</ent><br/
<hw>Mon`o*gas"tric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ belly.]</ety> <def>Having but a single
stomach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenesis</ent><br/
<hw>Mon`o*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>genesis</ets>.]</ety> <sn>1.</sn>
<def>Oneness of origin; esp. <fld>(Biol.)</fld>, development of all
beings in the universe from a single cell; -- opposed to
<contr>polygenesis</contr>. Called also <altname>monism</altname>.</def>
<rj><au>Dana.</au> <au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>That form of reproduction which
requires but one parent, as in reproduction by fission or in the
formation of buds, etc., which drop off and form new individuals;
asexual reproduction.</def> <rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>The direct development of an
embryo, without metamorphosis, into an organism similar to the parent
organism; -- opposed to <contr>metagenesis</contr>.</def> <rj><au>E. van
Beneden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenetic</ent><br/
<hw>Mon`o*ge*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Monogenesis</er>.]</ety> <sn>1.</sn> <fld>(Geol.)</fld> <def>One in
genesis; resulting from one process of formation; -- used of a mountain
range.</def> <rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Relating to, or involving,
monogenesis; <as>as, the <ex>monogenetic</ex> school of physiologists,
who admit but one cell as the source of all beings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenic</ent><br/
<hw>Mon`o*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Biol.)</fld> <def>Of or pertaining to monogenesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Producing only one kind of germs,
or young; developing only in one way.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenism</ent><br/
<hw>Mo*nog"e*nism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Anthropol.)</fld> <def>The theory or doctrine that the human races
have a common origin, or constitute a single species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenist</ent><br/
<hw>Mo*nog"e*nist</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Anthropol.)</fld> <def>One who maintains that the human races are
all of one species; -- opposed to <contr>polygenist</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenistic</ent><br/
<hw>Mon`o*ge*nis"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Monogenic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogenous</ent><br/
<hw>Mo*nog"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Biol.)</fld>
<def>Of or pertaining to monogenesis; <as>as, <ex>monogenous</ex>, or
asexual, reproduction</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogeny</ent><br/
<hw>Mo*nog"e*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Monogenesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anthropol.)</fld> <def>The doctrine that the
members of the human race have all a common origin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogoneutic</ent><br/
<hw>Mon`o*go*neu"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ offspring.]</ety> <fld>(Zool.)</fld>
<def>Having but one brood in a season.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogram</ent><br/
<hw>Mon"o*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monogramma</ets>; Gr. <grk>mo`nos</grk> single + <grk>gra`mma</grk>
letter, fr. <grk>gra`fein</grk> to write: cf. F. <ets>monogramme</ets>.
See <er>Graphic</er>.]</ety> <sn>1.</sn> <def>A character or cipher
composed of two or more letters interwoven or combined so as to
represent a name, or a part of it (usually the initials). Monograms are
often used on seals, ornamental pins, rings, buttons, and by painters,
engravers, etc., to distinguish their works.</def><br/
[<source>1913 Webster</source>]</p>

<p><illust>Monogram.</illust><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The monogram above, combining the letters of the name
<er>Karolvs</er>, was used by Charlemagne.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A picture in lines; a sketch.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An arbitrary sign for a word.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>monogram</ent><br/
<hw>mon"o*gram</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To inscribe or
ornament with a monogram.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monogrammal</ent><br/
<hw>Mon"o*gram`mal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Monogrammic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogrammatic</ent><br/
<hw>Mon`o*gram*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Monogrammic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogrammic</ent><br/
<hw>Mon`o*gram"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining
to, or resembling, a monogram.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogrammous</ent><br/
<hw>Mon"o*gram`mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Monogrammic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monograph</ent><br/
<hw>Mon"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mono-</ets>
+ <ets>-graph</ets>.]</ety> <def>A written account or description of a
single thing, or class of things; a special treatise on a particular
subject of limited range.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monographer</ent><br/
<hw>Mo*nog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A writer of a
monograph.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monographical</ent><br/
<ent>Monographic</ent><br/
<mhw>{ <hw>Mon`o*graph"ic</hw> <pr>(?)</pr>, <hw>Mon`o*graph"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>monographique</ets>.]</ety> <def>Of or pertaining to a monograph,
or to a monography; <as>as, a <ex>monographic</ex> writing; a
<ex>monographic</ex> picture.</as></def> --
<wordforms><wf>Mon`o*graph"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monographist</ent><br/
<hw>Mo*nog"ra*phist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who writes
a monograph.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monographous</ent><br/
<hw>Mo*nog"ra*phous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Monographic.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monography</ent><br/
<hw>Mo*nog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>-graphy</ets>: cf. F.
<ets>monographie</ets>.]</ety> <sn>1.</sn> <def>Representation by lines
without color; an outline drawing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A monograph.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogyn</ent><br/
<hw>Mon"o*gyn</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>One of the Monogynia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogynia</ent><br/
\'d8<hw>Mon`o*gyn"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>mo`nos</grk> single + <?/ woman, female.]</ety>
<fld>(Bot.)</fld> <def>A Linnaean order of plants, including those which
have only one style or stigma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogynian</ent><br/
<hw>Mon`o*gyn"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Pertaining to the <ord>Monogynia</ord>; monogynous.</def> --
<def2><pos>n.</pos> <def>One of the
<ord>Monogynia</ord>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogynous</ent><br/
<hw>Mo*nog"y*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>monogyne</ets>.]</ety> <fld>(Bot.)</fld> <def>Of or pertaining to
<ord>Monogynia</ord>; having only one style or stigma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monogyny</ent><br/
<hw>Mo*nog"y*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Monogynia</er>.]</ety> <sn>1.</sn> <def>Marriage with the one woman
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The state or condition of being
monogynous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monohemerous</ent><br/
<hw>Mon`o*hem"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ day.]</ety> <fld>(Med.)</fld>
<def>Lasting but one day.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoicous</ent><br/
<hw>Mo*noi"cous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Monoecious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monolatry</ent><br/
<hw>Mo*nol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mono-</ets>
+ Gr. <?/ worship.]</ety> <def>Worship of a single deity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monolingual</ent><br/
<hw>mon`o*lin"gual</hw> <pos>adj.</pos> <def>Using or knowing only one
language; <as>as, <ex>monolingual</ex> speakers; a <ex>monolingual</ex>
dictionary</as>. Opposite of <ant>multilingual</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monolith</ent><br/
<hw>Mon"o*lith</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>monolithe</ets>, L. <ets>monolithus</ets> consisting of a single
stone, Gr. <?/; <grk>mo`nos</grk> single + <grk>li`qos</grk>
stone.]</ety> <def>A single stone, especially one of large size, shaped
into a pillar, statue, or monument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monolithal</ent><br/
<hw>Mon"o*lith`al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Monolithic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monolithic</ent><br/
<hw>Mon`o*lith"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a monolith; consisting of a single stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monologist</ent><br/
<hw>Mo*nol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Monologue</er>.]</ety> <def>One who soliloquizes; esp., one who
monopolizes conversation in company.</def> <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monologue</ent><br/
<hw>Mon"o*logue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>monologue</ets>, Gr. <?/ speaking alone; <grk>mo`nos</grk> alone,
single, sole + <grk>lo`gos</grk> speech, discourse, <grk>le`gein</grk>
to speak. See <er>Legend</er>.]</ety> <sn>1.</sn> <def>A speech uttered
by a person alone; soliloquy; also, talk or discourse in company, in the
strain of a soliloquy; <as>as, an account in
<ex>monologue</ex></as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dramatic composition for a single
performer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monology</ent><br/
<hw>Mo*nol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/.]</ety>
<def>The habit of soliloquizing, or of monopolizing
conversation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was not by an insolent usurpation that Coleridge persisted in
<qex>monology</qex> through his whole life.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomachy</ent><br/
<ent>Monomachia</ent><br/
<mhw>{ \'d8<hw>Mon`o*ma"chi*a</hw> <pr>(?)</pr>, <hw>Mo*nom"a*chy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>monomachia</ets>, Gr.
<?/, fr. <?/ fighting in single combat; <grk>mo`nos</grk> single, alone
+ <?/ to fight.]</ety> <def>A duel; single combat.</def> <ldquo/The
duello or <xex>monomachia</xex>.<rdquo/ <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomachist</ent><br/
<hw>Mo*nom"a*chist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fights
in single combat; a duelist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomane</ent><br/
<hw>Mon"o*mane</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A monomaniac.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomania</ent><br/
<hw>Mon`o*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>mania</ets>.]</ety> <def>Derangement of
the mind in regard of a single subject only; also, such a concentration
of interest upon one particular subject or train of ideas to show mental
derangement.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Insanity; madness; alienation; aberration;
derangement; mania. See <er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomaniac</ent><br/
<hw>Mon`oma"ni*ac</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person
affected by monomania.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomaniacal</ent><br/
<ent>Monomaniac</ent><br/
<mhw>{ <hw>Mon`oma"ni*ac</hw> <pr>(?)</pr>, <hw>Mon`oma"ni*a*cal</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>monomaniaque</ets>.]</ety> <def>Affected with monomania, or partial
derangement of intellect; caused by, or resulting from, monomania;
<as>as, a <ex>monomaniacal</ex> delusion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monome</ent><br/
<hw>Mon"ome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Gr.
<grk>mo`nos</grk> single + <ets>-nome</ets> as in <ets>binome</ets>. See
<er>Binomial</er>.]</ety> <fld>(Math.)</fld> <def>A monomial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monomer</ent><br/
<hw>mon"o*mer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The basic conceptual building unit of a polymer; a molecule of low
molecular weight which may combine with other molecules to form a
molecule in a chain or branched form having high molecular weight;
<as>as, amino acids are the <ex>monomer</ex> units which are combined to
form proteins; vinylic plastics are formed from <ex>monomers</ex> having
a vinyl group</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>monomeric</ent><br/
<hw>mon`o*mer"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Not linked to other molecules of the same kind; having the property
of a monomer. Opposed to <ant>polymeric</ant>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monomerous</ent><br/
<hw>Mo*nom"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. single;
<grk>mo`nos</grk> alone + <?/ part.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>Composed of solitary parts, as a flower with one sepal, one petal,
one stamen, and one pistil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having but one joint; -- said of
the foot of certain insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monometallic</ent><br/
<hw>Mon`o*me*tal"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of
one metal; of or pertaining to monometallism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monometallism</ent><br/
<hw>Mon`o*met"al*lism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>metal</ets>.]</ety> <def>The legalized use
of one metal only, as gold, or silver, in the standard currency of a
country, or as a standard of money values. See
<er>Bimetallism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monometallist</ent><br/
<hw>Mon`o*met"al*list</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
believes in monometallism as opposed to bimetallism, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monometer</ent><br/
<hw>Mo*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ of one
meter; <grk>mo`nos</grk> single + <?/ measure.]</ety> <def>A rhythmic
series, consisting of a single meter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monometric</ent><br/
<hw>Mon`o*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>monom<eacute/trique</ets>.]</ety> <fld>(Crystallog.)</fld>
<def>Same as <er>Isometric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomial</ent><br/
<hw>Mo*no"mi*al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Monome</er>, <er>Binomial</er>.]</ety> <fld>(Alg.)</fld> <def>A
single algebraic expression; that is, an expression unconnected with any
other by the sign of addition, substraction, equality, or
inequality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomial</ent><br/
<hw>Mo*no"mi*al</hw>, <pos>a.</pos> <fld>(Alg.)</fld> <def>Consisting of
but a single term or expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomorphous</ent><br/
<ent>Monomorphic</ent><br/
<mhw>{ <hw>Mon`o*mor"phic</hw> <pr>(?)</pr>, <hw>Mon`o*mor"phous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Mono-</ets> + Gr.
<grk>morfh`</grk> form.]</ety> <fld>(Biol.)</fld> <def>Having but a
single form; retaining the same form throughout the various stages of
development; of the same or of an essentially similar type of structure;
-- opposed to <contr>dimorphic</contr>, <contr>trimorphic</contr>, and
<contr>polymorphic</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomphalus</ent><br/
\'d8<hw>Mo*nom"pha*lus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>mo`nos</grk> alone + <?/ the navel.]</ety> <def>A form of
double monster, in which two individuals are united by a common
umbilicus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomyaria</ent><br/
<ent>Monomya</ent><br/
<mhw>{ \'d8<hw>Mo*no"my*a</hw> <pr>(?)</pr>,
\'d8<hw>Mon`o*my*a"ri*a</hw> <pr>(?)</pr>, }</mhw> <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>mo`nos</grk> single + <?/, <?/, muscle.]</ety>
<fld>(Zool.)</fld> <def>An order of lamellibranchs having but one muscle
for closing the shell, as the oyster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monomyary</ent><br/
<ent>Monomyarian</ent><br/
<mhw>{ <hw>Mon`o*my"a*ri*an</hw> <pr>(?)</pr>, <hw>Mon`o*my"a*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Of or
pertaining to the <ord>Monomya</ord>.</def> -- <def2><pos>n.</pos>
<def>One of the <ord>Monomya</ord>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mononomial</ent><br/
<hw>Mon`o*no"mi*al</hw> <pr>(?)</pr>, <pos>n. & a.</pos>
<def>Monomyal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoousious</ent><br/
<ent>Monoousian</ent><br/
<mhw>{ <hw>Mon`o*ou"si*an</hw> <pr>(?)</pr>, <hw>Mon`o*ou"si*ous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Mono-</ets> + Gr. <?/
being, substance, essence.]</ety> <fld>(Theil.)</fld> <def>Having but
one and the same nature or essence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopathy</ent><br/
<hw>Mo*nop"a*thy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>mo`nos</grk> alone + <?/, <?/, to suffer.]</ety> <def>Suffering or
sensibility in a single organ or function.</def> --
<wordforms><wf>Mon`o*path"ic</wf>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopersonal</ent><br/
<hw>Mon`o*per"son*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>personal</ets>.]</ety> <def>Having but one
person, or form of existence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopetalous</ent><br/
<hw>Mon`o*pet"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>petal</ets>: cf. F.
<ets>monop<eacute/tale</ets>.]</ety> <fld>(Bot.)</fld> <def>Having only
one petal, or the corolla in one piece, or composed of petals cohering
so as to form a tube or bowl; gamopetalous.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The most recent authors restrict this form to flowers
having a solitary petal, as in species of <gen>Amorpha</gen>, and use
<contr>gamopetalous</contr> for a corolla of several petals combined
into one piece. See <xex>Illust.</xex> of
<er>Gamopetalous</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophanous</ent><br/
<hw>Mo*noph"a*nous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ to show.]</ety> <def>Having one and the
same appearance; having a mutual resemblance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophonic</ent><br/
<hw>Mon`o*phon"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ a voice.]</ety> <sn>1.</sn>
<fld>(Mus.)</fld> <def>Single-voiced; having but one part; <as>as, a
<ex>monophonic</ex> composition</as>; -- opposed to
<ant>polyphonic</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or relating to a system for recording and
reproducing sound, which has only one sound channel; also called
<altname>monaural</altname> or <altname>mono</altname>. It contrasts
with <contr>stereophonic</contr> (or <contr>stereo</contr>),
<contr>quadraphonic</contr>, or <contr>surround-sound</contr>, which
have two or more channels, and can thus reproduce the effect of the
sound coming from more than one direction.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monophthong</ent><br/
<hw>Mon"oph*thong</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ with
one sound; <grk>mo`nos</grk> alone + <?/ sound, voice.]</ety>
<sn>1.</sn> <def>A single uncompounded vowel sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A combination of two written vowels pronounced as
one; a digraph.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophthongal</ent><br/
<hw>Mon`oph*thon"gal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting
of, or pertaining to, a monophthong.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophyletic</ent><br/
<hw>Mon`o*phy*let"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ of
one tribe, fr. <grk>mo`nos</grk> single + <?/ clan.]</ety>
<fld>(Biol.)</fld> <def>Of or pertaining to a single family or stock, or
to development from a single common parent form; -- opposed to
<ant>polyphyletic</ant>; <as>as, <ex>monophyletic</ex>
origin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophyllous</ent><br/
<hw>Mo*noph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>mono`fyllos</grk>; <grk>mo`nos</grk> alone + <grk>fy`llon</grk>
leaf: cf. F. <ets>monophylle</ets>.]</ety> <fld>(Bot.)</fld>
<def>One-leaved; composed of a single leaf; <as>as, a
<ex>monophyllous</ex> involucre or calyx</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophyodont</ent><br/
<hw>Mon`o*phy"o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>mo`nos</grk> single (<grk>mo`nos</grk> alone + <?/ to produce) +
<grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, a tooth.]</ety>
<fld>(Anat.)</fld> <def>Having but one set of teeth; -- opposed to
<contr>diphyodont</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophysite</ent><br/
<hw>Mo*noph"y*site</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>mo`nos</grk> single + <?/ nature: cf. F.
<ets>monophysite</ets>.]</ety> <fld>(Eccl. Hist.)</fld> <def>One of a
sect, in the ancient church, who maintained that the human and divine in
Jesus Christ constituted but one composite nature. Also used
adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monophysitical</ent><br/
<hw>Mon`o*phy*sit"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to Monophysites, or their doctrines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoplast</ent><br/
<hw>Mon"o*plast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mono-</ets>
+ <ets>-plast</ets>.]</ety> <fld>(Biol.)</fld> <def>A monoplastic
element.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoplastic</ent><br/
<hw>Mon`o*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>-plastic</ets>.]</ety> <fld>(Biol.)</fld>
<def>That has one form, or retains its primary form, <as>as, a
<ex>monoplastic</ex> element</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoplegia</ent><br/
\'d8<hw>Mon`ople"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>mo`nos</grk> single + <?/ a stroke.]</ety> <fld>(Med.)</fld>
<def>Paralysis affecting a single limb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopneumona</ent><br/
\'d8<hw>Mon`op*neu"mo*na</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Mono-</er>, and <er>Pneumonia</er>.]</ety> <fld>(Zool.)</fld>
<def>A suborder of Dipnoi, including the Ceratodus.</def>
<altsp>[Written also <asp>monopneumonia</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopode</ent><br/
<hw>Mon"o*pode</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One of
a fabulous tribe or race of Ethiopians having but one leg and
foot.</def> <rj><au>Sir J. Mandeville.</au> <au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A monopodium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopodial</ent><br/
<hw>Mon`o*po"di*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having a monopodium or a single and continuous axis, as a birchen
twig or a cornstalk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopodium</ent><br/
\'d8<hw>Mon`o*po"di*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Monopodia</plw> <pr>(#)</pr>, E.
<plw>-ums</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Monopody</er>.]</ety> <fld>(Bot.)</fld> <def>A single and continuous
vegetable axis; -- opposed to <contr>sympodium</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopody</ent><br/
<hw>Mo*nop"o*dy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mono-</ets>
+ Gr. <grk>poy`s</grk>, <grk>podo`s</grk>, foot: cf. <?/, <?/,
one-footed.]</ety> <fld>(Pros.)</fld> <def>A measure of but a single
foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopoler</ent><br/
<hw>Mo*nop"o*ler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
monopolist.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 941 --></p>

<p><ent>Monopolist</ent><br/
<hw>Mo*nop"o*list</hw> <pr>(m<osl/*n<ocr/p"<osl/*l<icr/st)</pr>,
<pos>n.</pos> <def>One who monopolizes; one who has a monopoly; one who
favors monopoly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopolistic</ent><br/
<hw>Mo*nop`o*lis"tic</hw>
<pr>(m<osl/*n<ocr/p`<osl/*l<icr/s"t<icr/k)</pr>, <pos>a.</pos> <def>Of
or pertaining to a monopolist.</def> <rj><au>North Am.
Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopolite</ent><br/
<hw>Mo*nop"o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
monopolist.</def> <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopolize</ent><br/
<hw>Mo*nop"o*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Monopolized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Monopolizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From
<er>Monopoly</er>.]</ety> <def>To acquire a monopoly of; to have or get
the exclusive privilege or means of dealing in, or the exclusive
possession of; to engross the whole of; <as>as, to <ex>monopolize</ex>
the coffee trade; to <ex>monopolize</ex> land.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopolizer</ent><br/
<hw>Mo*nop"o*li`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
monopolizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopoly</ent><br/
<hw>Mo*nop"o*ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Monopolies</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>monopolium</ets>, Gr. <?/, <?/; <grk>mo`nos</grk> alone + <?/ to
sell.]</ety> <sn>1.</sn> <def>The exclusive power, or privilege of
selling a commodity; the exclusive power, right, or privilege of dealing
in some article, or of trading in some market; sole command of the
traffic in anything, however obtained; <as>as, the proprietor of a
patented article is given a <ex>monopoly</ex> of its sale for a limited
time; chartered trading companies have sometimes had a <ex>monopoly</ex>
of trade with remote regions; a combination of traders may get a
<ex>monopoly</ex> of a particular product.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Raleigh held a <qex>monopoly</qex> of cards, Essex a
<qex>monopoly</qex> of sweet wines.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exclusive possession; <as>as, a <ex>monopoly</ex> of
land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If I had a <qex>monopoly</qex> out, they would have part on
't.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The commodity or other material thing to which the
monopoly relates; <as>as, tobacco is a <ex>monopoly</ex> in
France</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopolylogue</ent><br/
<hw>Mon`o*pol"y*logue</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + Gr. <grk>poly`s</grk> many + <grk>lo`gos</grk>
speech.]</ety> <def>An exhibition in which an actor sustains many
characters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopsychism</ent><br/
<hw>Mon`o*psy"chism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ soul.]</ety> <def>The doctrine that
there is but one immortal soul or intellect with which all men are
endowed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monopteral</ent><br/
<hw>mo*nop"ter*al</hw> <pr>(m<osl/*n<ocr/p"t<etil/r*<ait/l)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>mono`pteros</grk> with a row of pillars
only; <grk>mo`nos</grk> alone, only + <grk>ptero`n</grk> feather, wing,
also, a row of pillars: cf. F. <ets>monopt<egrave/re</ets>.]</ety>
<fld>(Arch.)</fld> <def>Round and without a cella; consisting of a
single ring of columns supporting a roof; -- said esp. of a
temple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopteron</ent><br/
\'d8<hw>Mo*nop"ter*on</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Monoptera</plw> <pr>(#)</pr>.</plu> <ety>[NL. See
<er>Monopteral</er>.]</ety> <fld>(Arch.)</fld> <def>A circular temple
consisting of a roof supported on columns, without a cella.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoptote</ent><br/
<hw>Mon"op*tote</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monoptotum</ets>, Gr. <grk>mono`ptwtos</grk>; <grk>mo`nos</grk>
single + <?/ apt to fall, fallen, fr. <?/ to fall; cf. <?/ case.]</ety>
<fld>(Gram.)</fld> <sn>1.</sn> <def>A noun having only one case.</def>
<rj><au>Andrews.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A noun having only one ending for the oblique
cases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monopyrenous</ent><br/
<hw>Mon`o*py*re"nous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>pyrene</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having but a single stone or kernel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monorganic</ent><br/
<hw>Mon`or*gan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mon-</ets>
+ <ets>organic</ets>.]</ety> <fld>(Biol. & Med.)</fld> <def>Belonging
to, or affecting, a single organ, or set of organs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monorhina</ent><br/
\'d8<hw>Mon`o*rhi"na</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>mo`nos</grk> single + <?/, <?/, nose.]</ety> <fld>(Zool.)</fld>
<def>The Marsipobranchiata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monorhyme</ent><br/
<hw>Mon"o*rhyme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mono-</ets>
+ <ets>rhyme</ets>: cf. F. <ets>monorime</ets>.]</ety> <def>A
composition in verse, in which all the lines end with the same
rhyme.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-rid</ent><br/
<ent>Monosaccharide</ent><br/
<mhw>{ <hw>Mon`o*sac"cha*ride</hw> <pr>(?)</pr>, <pos>n.</pos> Also
<hw>-rid</hw> }</mhw>. <ety>[<ets>Mono-</ets> +
<ets>saccharide</ets>.]</ety> <fld>(Chem.)</fld> <def>A simple sugar;
any of a number of sugars (including the trioses, tetroses, pentoses,
hexoses, etc.), not decomposable into simpler sugars by hydrolysis.
Specif., as used by some, a hexose. The monosaccharides are all
open-chain compounds containing hydroxyl groups and either an aldehyde
group or a ketone group.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monosepalous</ent><br/
<hw>Mon`o*sep"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>sepal</ets>: cf. F.
<ets>monos<eacute/pale</ets>.]</ety> <fld>(Bot.)</fld> <def>Having only
one sepal, or the calyx in one piece or composed of the sepals united
into one piece; gamosepalous.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The most recent writers restrict this term to flowers
having a solarity sepal, and use <contr>gamosepalous</contr> for a calyx
formed by several sepals combined into one piece. Cf.
<er>Monopetalous</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>monosodium glutamate</ent><br/
<hw>monosodium glutamate</hw> <pos>n.</pos> <def>The monosodium salt of
the natural amino acid L-glutamine (<chform>C5H8NNaO4</chform>), used as
a food additive to enhance flavor; abbreviated <abbr>MSG</abbr>. It is
usually marketed as the monhydrate (<chform>C5H8NNaO4.H2O</chform>). It
is commmonly used in Chinese-American restaurants, and has been
identified as a main cause of <causes>Chinese restaurant
syndrome</causes>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monosperm</ent><br/
<hw>Mon"o*sperm</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A monospermous plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monospermous</ent><br/
<ent>Monospermal</ent><br/
<mhw>{ <hw>Mon`o*sper"mal</hw> <pr>(?)</pr>, <hw>Mon`o*sper"mous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Mono-</ets> + Gr.
<grk>spe`rma</grk> seed: cf. F. <ets>monosperme</ets>.]</ety>
<fld>(Bot.)</fld> <def>Having only one seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monospherical</ent><br/
<hw>Mon`o*spher"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>spherical</ets>.]</ety> <def>Consisting of
one sphere only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monostich</ent><br/
<hw>Mon"o*stich</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, from <?/
consisting of one verse; <grk>mo`nos</grk> single + <grk>sti`chos</grk>
line, verse.]</ety> <def>A composition consisting of one verse
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monostichous</ent><br/
<hw>Mo*nos"ti*chous</hw> <pr>(m<osl/*n<ocr/s"t<icr/*k<ucr/s)</pr>,
<pos>a.</pos> <ety>[See <er>Monostich</er>.]</ety> <fld>(Bot.)</fld>
<def>Arranged in a single row on one side of an axis, as the flowers in
grasses of the tribe <fam>Chloridae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monostrophe</ent><br/
<hw>Mo*nos"tro*phe</hw> <pr>(m<osl/*n<ocr/s"tr<osl/*f<esl/)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>mono`strofos</grk>
monostrophic.]</ety> <def>A metrical composition consisting of a single
strophe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monostrophic</ent><br/
<hw>Mon`o*stroph"ic</hw> <pr>(m<ocr/n`<osl/*str<ocr/f"<icr/k)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>monostrofiko`s</grk>; <grk>mo`nos</grk>
single + <grk>strofh`</grk> strophe.]</ety> <fld>(Pros.)</fld>
<def>Having one strophe only; not varied in measure; written in unvaried
measure.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosulphide</ent><br/
<hw>Mon`o*sul"phide</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>sulphide</ets>.]</ety> <fld>(Chem.)</fld>
<def>A sulphide containing one atom of sulphur, and analogous to a
monoxide; -- contrasted with a <ant>polysulphide</ant>; <as>as, galena
is a <ex>monosulphide</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosulphuret</ent><br/
<hw>Mon`o*sul"phu*ret</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>sulphuret</ets>.]</ety> <fld>(Chem.)</fld>
<def>See <er>Monosulphide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosyllabic</ent><br/
<hw>Mon`o*syl*lab"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>monosyllabique</ets>.]</ety> <def>Being a monosyllable, or composed
of monosyllables; <as>as, a <ex>monosyllabic</ex> word; a
<ex>monosyllabic</ex> language.</as></def> --
<wordforms><wf>Mon`o*syl*lab"ic*al*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosyllabism</ent><br/
<hw>Mon`o*syl"la*bism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
consisting of monosyllables, or having a monosyllabic form; frequent
occurrence of monosyllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosyllable</ent><br/
<hw>Mon"o*syl`la*ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monosyllabus</ets> of one syllable, Gr. <?/: cf. F.
<ets>monosyllabe</ets>. See <er>Mono-</er>, <er>Syllable</er>.]</ety>
<def>A word of one syllable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosyllabled</ent><br/
<hw>Mon"o*syl`la*bled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed into,
or consisting of, monosyllables.</def> <rj><au>Cleveland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monosymmetrical</ent><br/
<ent>Monosymmetric</ent><br/
<mhw>{ <hw>Mon`o*sym*met"ric</hw> <pr>(?)</pr>,
<hw>Mon`o*sym*met"ric*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Mono-</ets> + <ets>symmetric</ets>, <ets>-ical</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>Same as <er>Monoclinic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotessaron</ent><br/
<hw>Mon`o*tes"sa*ron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>mo`nos</grk> single + <?/ four.]</ety> <def>A single narrative
framed from the statements of the four evangelists; a gospel
harmony.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothalama</ent><br/
\'d8<hw>Mon`o*thal"a*ma</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>mo`nos</grk> single + <grk>qa`lamos</grk> a chamber.]</ety>
<fld>(Zool.)</fld> <def>A division of Foraminifera including those that
have only one chamber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothalaman</ent><br/
<hw>Mon`o*thal"a*man</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Monothalamous</er>.]</ety> <fld>(Zool.)</fld> <def>A foraminifer
having but one chamber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothalamous</ent><br/
<hw>Mon`o*thal"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <grk>qa`lamos</grk> chamber: cf. F.
<ets>monothalame</ets>.]</ety> <fld>(Zool.)</fld>
<def>One-chambered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothalmic</ent><br/
<hw>Mon`o*thal"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Monothalamous</er>.]</ety> <fld>(Bot.)</fld> <def>Formed from one
pistil; -- said of fruits.</def> <rj><au>R. Brown.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothecal</ent><br/
<hw>Mon`o*the"cal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Br. <?/ box.]</ety> <fld>(Bot.)</fld>
<def>Having a single loculament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotheism</ent><br/
<hw>Mon"o*the*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ god: cf. F.
<ets>monoth<eacute/isme</ets>.]</ety> <def>The doctrine or belief that
there is but one God.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotheist</ent><br/
<hw>Mon"o*the*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>monoth<eacute/iste</ets>.]</ety> <def>One who believes that there
is but one God.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotheistic</ent><br/
<hw>Mon`o*the*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to monotheism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothelitism</ent><br/
<ent>Monothelism</ent><br/
<mhw>{ <hw>Mo*noth"e*lism</hw> <pr>(?)</pr>, <hw>Mo*noth"e*li*tism</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf. F.
<ets>monoth<eacute/lisme</ets>, <ets>monoth<eacute/litisme</ets>.]</ety>
<def>The doctrine of the Monothelites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothelite</ent><br/
<hw>Mo*noth"e*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>mo`nos</grk> alone, only + <?/, <?/, to will, be willing: cf. F.
<ets>monoth<eacute/lite</ets>.]</ety> <fld>(Eccl. Hist.)</fld> <def>One
of an ancient sect who held that Christ had but one will as he had but
one nature. Cf. <er>Monophysite</er>.</def>
<rj><au>Gibbon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monothelitic</ent><br/
<hw>Mon`o*the*lit"ic</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to the <org>Monothelites</org>, or their doctrine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotocous</ent><br/
<hw>Mo*not"o*cous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ birth, offspring.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Bearing fruit but once; monocarpic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Uniparous; laying a single
egg.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotomous</ent><br/
<hw>Mo*not"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + Gr. <?/ cutting, fr. <?/ to cut.]</ety>
<fld>(Min.)</fld> <def>Having a distinct cleavage in a single direction
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotone</ent><br/
<hw>Mon"o*tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Monotonous</er>, <er>Monotony</er>.]</ety> <sn>1.</sn>
<fld>(Mus.)</fld> <def>A single unvaried tone or sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rhet.)</fld> <def>The utterance of successive
syllables, words, or sentences, on one unvaried key or line of
pitch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotonical</ent><br/
<ent>Monotonic</ent><br/
<mhw>{ <hw>Mon`o*ton"ic</hw> <pr>(?)</pr>, <hw>Mon`o*ton"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <sn>1.</sn> <def>Of, pertaining to,
or uttered in, a monotone; monotonous.</def>
<ldquo/<xex>Monotonical</xex> declamation.<rdquo/
<rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>Always increasing or always
decreasing, as the value of the independent variable increases; -- of a
function.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monotonist</ent><br/
<hw>Mo*not"o*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who talks in
the same strain or on the same subject until weariness is
produced.</def> <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotonous</ent><br/
<hw>Mo*not"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/;
<grk>mo`nos</grk> alone, single + <?/ tone. See <er>Tone</er>.]</ety>
<def>Uttered in one unvarying tone; continued with dull uniformity;
characterized by monotony; without change or variety; wearisome.</def>
-- <wordforms><wf>Mo*not"o*nous*ly</wf>, <pos>adv.</pos> --
<wf>Mo*not"o*nous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotony</ent><br/
<hw>Mo*not"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf. F.
<ets>monotonie</ets>. See <er>Monotonius</er>.]</ety> <sn>1.</sn> <def>A
frequent recurrence of the same tone or sound, producing a dull
uniformity; absence of variety, as in speaking or singing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any irksome sameness, or want of variety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At sea, everything that breaks the <qex>monotony</qex> of the
surrounding expanse attracts attention.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotremata</ent><br/
\'d8<hw>Mon`o*trem"a*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>mo`nos</grk> single + <?/ hole.]</ety> <fld>(Zool.)</fld>
<def>A subclass of Mammalia, having a cloaca in which the ducts of the
urinary, genital, and alimentary systems terminate, as in birds. The
female lays eggs like a bird. See <cref>Duck mole</cref>, under
<er>Duck</er>, and <er>Echidna</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotrematous</ent><br/
<hw>Mon`o*trem"a*tous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Monotremata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotreme</ent><br/
<hw>Mon"o*treme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>monotr<egrave/me</ets>.]</ety> <fld>(Zool.)</fld> <def>One of the
<subclass>Monotremata</subclass>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotriglyph</ent><br/
<hw>Mon`o*tri"glyph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mono-</ets> + <ets>triglyph</ets>: cf. F.
<ets>monotriglyphe</ets>.]</ety> <fld>(Arch.)</fld> <def>A kind of
intercolumniation in an entablature, in which only one triglyph and two
metopes are introduced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotropa</ent><br/
\'d8<hw>Mo*not"ro*pa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>mo`nos</grk> single + <?/ turn, from <?/ to turn.]</ety>
<fld>(Bot.)</fld> <def>A genus of parasitic or saprophytic plants
including the Indian pipe and pine sap. The name alludes to the dropping
end of the stem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotropaceae</ent><br/
<hw>Monotropaceae</hw> <pos>prop. n.</pos> <def>A natural family of
plants, used in some classifications for saprophytic herbs; it is
sometimes included in the family <fam>Pyrolaceae</fam>, and contains the
genera <gen>Monotropa</gen> and <gen>Sarcodes</gen>.</def><br/
<syn><b>Syn. --</b> family <fam>Monotropaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monotypic</ent><br/
<ent>Monotype</ent><br/
<mhw>{ <hw>Mon"o*type</hw> <pr>(?)</pr>, <hw>Mon`o*typ"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Mono-</ets> +
<ets>-type</ets>: cf. F. <ets>monotype</ets>.]</ety> <fld>(Biol.)</fld>
<def>Having but one type; containing but one representative; <as>as, a
<ex>monotypic</ex> genus, which contains but one species</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monotype</ent><br/
<hw>Mon"o*type</hw> <pr>(?)</pr>, <sn>1.</sn> <ety>[<ets>Mono-</ets> +
<ets>-type</ets>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>The only
representative of its group, as a single species constituting a
genus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A print (but one impression can be taken) made by
painting on metal and then transferring the painting to paper by
pressure; also, the process of making such prints.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>A kind of keyboard-operated typesetting and casting
machine that makes and sets separate characters.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monovalent</ent><br/
<hw>Mo*nov"a*lent</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mono-</ets> + L. <ets>valens</ets>, p. pr. See
<er>Valence</er>.]</ety> <fld>(Chem.)</fld> <def>Having a valence of
one; univalent. See <er>Univalent</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monovular</ent><br/
<hw>monovular</hw> <pos>adj.</pos> <fld>(Biol.)</fld> <def>derived from
a single egg or ovum; -- of twins; <as>as, identical twins are
<ex>monovular</ex></as>. Contrasted with <ant>fraternal</ant>.</def><br/
<syn><b>Syn. --</b> identical.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Monoxide</ent><br/
<hw>Mo*nox"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mon-</ets> +
<ets>oxide</ets>.]</ety> <fld>(Chem.)</fld> <def>An oxide containing one
atom of oxygen in each molecule; <as>as, barium
<ex>monoxide</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoxylon</ent><br/
\'d8<hw>Mo*nox"y*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <?/, fr. <?/ made from one piece of wood; <grk>mo`nos</grk> alone +
<?/ wood.]</ety> <def>A canoe or boat made from one piece of
timber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monoxylous</ent><br/
<hw>Mo*nox"y*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Monoxylon</er>.]</ety> <def>Made of one piece of wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monozoa</ent><br/
\'d8<hw>Mon`o*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., from
Gr. <grk>mo`nos</grk> single + <grk>zw^,on</grk> an animal.]</ety>
<fld>(Zool.)</fld> <def>A division of Radiolaria; -- called also
<altname>Monocyttaria</altname>.</def> --
<wordforms><wf>Mon`o*zo"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monroe doctrine</ent><br/
<hw>Mon*roe" doc"trine</hw>. <def>See under <er>Doctrine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monseigneur</ent><br/
\'d8<hw>Mon`sei`gneur"</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Messeigneurs</plw> <pr>(#)</pr>.</plu> <ety>[F.,
fr. <ets>mon</ets> my + <ets>seigneur</ets> lord, L. <ets>senior</ets>
older. See <er>Senior</er>, and cf. <er>Monsieur</er>.]</ety> <def>My
lord; -- a title in France of a person of high birth or rank; <as>as,
<ex>Monseigneur</ex> the Prince, or <ex>Monseigneur</ex> the
Archibishop</as>. It was given, specifically, to the dauphin, before the
Revolution of 1789. (Abbrev. <abbr>Mgr.</abbr>)</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monsel's salt</ent><br/
<hw>Mon"sel's salt`</hw> <pr>(?)</pr>. <fld>(Med.)</fld> <def>A basic
sulphate of iron; -- so named from <etsep>Monsel</etsep>, a
Frenchman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monsel's solution</ent><br/
<hw>Mon"sel's so*lu"tion</hw> <pr>(?)</pr>. <ety>[See <er>Monsel's
salt</er>.]</ety> <fld>(Med.)</fld> <def>An aqueous solution of Monsel's
salt, having valuable styptic properties.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monsieur</ent><br/
\'d8<hw>Mon*sieur"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Messieurs</plw> <pr>(#)</pr>.</plu> <ety>[F., fr. <ets>mon</ets> my
+ <ets>Sieur</ets>, abbrev. of <ets>seigneur</ets> lord. See
<er>Monseigneur</er>.]</ety> <sn>1.</sn> <def>The common title of
civility in France in speaking to, or of, a man; Mr. or Sir.</def>
<altsp>[Represented by the abbreviation <abbr>M.</abbr> or
<abbr>Mons.</abbr> in the singular, and by <plw><abbr>MM.</abbr></plw>
or <plw><abbr>Messrs.</abbr></plw> in the plural.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The oldest brother of the king of France.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A Frenchman.</def> <mark>[Contemptuous]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monsignore</ent><br/
\'d8<hw>Mon`si*gno"re</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Monsignors</plw> <pr>(#)</pr>.</plu> <ety>[It.,
my lord. Cf. <er>Monseigneur</er>.]</ety> <def>My lord; -- an
ecclesiastical dignity bestowed by the pope, entitling the bearer to
social and domestic rank at the papal court. (Abbrev.
<abbr>Mgr.</abbr>)</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>monsoon</ent><br/
<hw>mon*soon"</hw> <pr>(m<ocr/n*s<oomac/n")</pr>, <pos>n.</pos>
<ety>[Malay <ets>m<umac/sim</ets>, fr. Ar. <ets>mausim</ets> a time,
season: cf. F. <ets>monson</ets>, <ets>mousson</ets>, Sr.
<ets>monzon</ets>, Pg. <ets>mon<cced/<atil/o</ets>, It.
<ets>monsone</ets>.]</ety> <def>A wind blowing part of the year from one
direction, alternating with a wind from the opposite direction; -- a
term applied particularly to periodical winds of the Indian Ocean, which
blow from the southwest from the latter part of May to the middle of
September, and from the northeast from about the middle of October to
the middle of December.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A heavy rainfall in India associated with the
southwest monsoon{1}.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The season in which the monsoon{2} occurs.</def><br/
[<source>PJC</source>]</p>

<p><ent>Monster</ent><br/
<hw>Mon"ster</hw> <pr>(m<ocr/n*st<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>monstre</ets>, F. <ets>monstre</ets>, fr. L. <ets>monstrum</ets>,
orig., a divine omen, indicating misfortune; akin of
<ets>monstrare</ets> to show, point out, indicate, and <ets>monere</ets>
to warn. See <er>Monition</er>, and cf. <er>Demonstrate</er>,
<er>Muster</er>.]</ety> <sn>1.</sn> <def>Something of unnatural size,
shape, or quality; a prodigy; an enormity; a marvel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>monster</qex> or marvel.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically , an animal or plant departing greatly
from the usual type, as by having too many limbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any thing or person of unnatural or excessive
ugliness, deformity, wickedness, or cruelty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monster</ent><br/
<hw>Mon"ster</hw>, <pos>a.</pos> <sn>1.</sn> <def>Monstrous in
size.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Enormous or very powerful; <as>as, he drove a
<ex>monster</ex> Harley</as>.</def> <mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Monster</ent><br/
<hw>Mon"ster</hw>, <pos>v. t.</pos> <def>To make monstrous.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>monstera</ent><br/
<hw>monstera</hw> <pos>n.</pos> <sn>1.</sn> <def>any plant of the genus
<gen>Monstera</gen>; they are often grown as houseplants.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A tropical cylindrical pineconelike fruit with
pineapple-banana flavor.</def><br/
<syn><b>Syn. --</b> ceriman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>monstrance</ent><br/
<hw>mon"strance</hw> <pr>(m<ocr/n*str<ait/ns)</pr>, <pos>n.</pos>
<ety>[LL. <ets>monstrantia</ets>, fr. L. <ets>monstrare</ets> to show:
cf. OF. <ets>monstrance</ets>. See <er>Monster</er>.]</ety> <fld>(R. C.
Ch.)</fld> <def>A transparent pyx, in which the consecrated host is
exposed to view.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstration</ent><br/
<hw>Mon*stra"tion</hw> <pr>(m<ocr/n*str<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>monstratio</ets>.]</ety> <def>The act of
demonstrating; proof.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A certain <qex>monstration</qex>.</q>
<rj><qau>Grafton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstrosity</ent><br/
<hw>Mon*stros"i*ty</hw> <pr>(m<ocr/n*str<ocr/s"<icr/*t<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Monstrosities</plw>
<pr>(m<ocr/n*str<ocr/s"<icr/*t<icr/z)</pr>.</plu> <ety>[Cf. F.
<ets>monstruosit<eacute/</ets>. See <er>Monstrous</er>.]</ety> <def>The
state of being monstrous, or out of the common order of nature; that
which is monstrous; a monster.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>monstrosity</qex> never changes the name or affects the
immutability of a species.</q> <rj><qau>Adanson (Trans.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstrous</ent><br/
<hw>Mon"strous</hw> <pr>(m<ocr/n"str<ucr/s)</pr>, <pos>a.</pos>
<ety>[OE. <ets>monstruous</ets>, F. <ets>monstrueux</ets>, fr. L.
<ets>monstruosus</ets>, fr. <ets>monstrum</ets>. See
<er>Monster</er>.]</ety> <sn>1.</sn> <def>Marvelous; strange.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the qualities of a monster; deviating greatly
from the natural form or character; abnormal; <as>as, a
<ex>monstrous</ex> birth</as>.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He, therefore, that refuses to do good to them whom he is bound to
love . . . is unnatural and <qex>monstrous</qex> in his affections.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Extraordinary in a way to excite wonder, dislike,
apprehension, etc.; -- said of size, appearance, color, sound, etc.;
<as>as, a <ex>monstrous</ex> height; a <ex>monstrous</ex> ox; a
<ex>monstrous</ex> story.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Extraordinary on account of ugliness, viciousness,
or wickedness; hateful; horrible; dreadful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So bad a death argues a <qex>monstrous</qex> life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Abounding in monsters.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Where thou, perhaps, under the whelming tide<br/
Visitest the bottom of the <qex>monstrous</qex> world.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstrous</ent><br/
<hw>Mon"strous</hw>, <pos>adv.</pos> <def>Exceedingly; very; very
much.</def> <ldquo/A <xex>monstrous</xex> thick oil on the top.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And will be <qex>monstrous</qex> witty on the poor.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstrously</ent><br/
<hw>Mon"strous*ly</hw>, <pos>adv.</pos> <def>In a monstrous manner;
unnaturally; extraordinarily; <as>as, <ex>monstrously</ex>
wicked</as>.</def> <ldquo/Who with his wife is <xex>monstrously</xex> in
love.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstrousness</ent><br/
<hw>Mon"strous*ness</hw>, <pos>n.</pos> <def>The state or quality of
being monstrous, unusual, extraordinary.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstruosity</ent><br/
<hw>Mon`stru*os"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Monstrosity.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monstruous</ent><br/
<hw>Mon"stru*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Monstrous.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mont</ent><br/
\'d8<hw>Mont</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Mount</er>, <pos>n.</pos>]</ety> <def>Mountain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montaigne</ent><br/
<hw>Mon"taigne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mountain.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montanic</ent><br/
<hw>Mon*tan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>montanus</ets>, fr. <ets>mons</ets>, <ets>montis</ets>, mountain.
See <er>Mount</er>, <pos>n.</pos>]</ety> <def>Of or pertaining to
mountains; consisting of mountains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montanist</ent><br/
<hw>Mon"ta*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>A follower of <persfn>Mintanus</persfn>, a Phrygian
enthusiast of the second century, who claimed that the Holy Spirit, the
Paraclete, dwelt in him, and employed him as an instrument for purifying
and guiding men in the Christian life.</def> --
<wordforms><wf>Mon`ta*nis"tic</wf> <pr>(#)</pr>,
<wf>Mon`ta*nis"tic*al</wf> <pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montant</ent><br/
<hw>Mon"tant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.,prop., mounting,
fr. <ets>monter</ets> to mount, fr. L. <ets>mons</ets>,
<ets>montis</ets>, mountain. See <er>Mount</er>.]</ety> <sn>1.</sn>
<fld>(Fencing)</fld> <def>An upward thrust or blow.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>An upright piece in any
framework; a mullion or muntin; a stile.</def> <mark>[R.]</mark>
<see>See <er>Stile</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mont de piete</ent><br/
\'d8<hw>Mont" de pi`<eacute/`t<eacute/"</hw> <pr>(?)</pr>. <ety>[F., fr.
It. <ets>monte di piet<agrave/</ets> mount of piety.]</ety> <def>One of
certain public pawnbroking establishments which originated in Italy in
the 15th century, the object of which was to lend money at a low rate of
interest to poor people in need; -- called also <altname>mount of
piety</altname>. The institution has been adopted in other countries, as
in Spain and France. See <er>Lombard-house</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 942 --></p>

<p><ent>Monte</ent><br/
\'d8<hw>Mon"te</hw> <pr>(m<ocr/n"t<asl/)</pr>, <pos>n.</pos> <ety>[Sp.,
lit., mountain, hence, the stock of cards remaining after laying out a
certain number, fr. L. <ets>mons</ets>, <ets>montis</ets>,
mountain.]</ety> <def>A favorite gambling game among Spaniards, played
with dice or cards.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>three-card monte</b></col> <cd>a gambling game using
playing cards, in which a dealer shows a bettor three cards face up and
specifies one to be identified, and after the cards are turned face down
and moved around quickly, the bettor must identify which of the three
cards is the specified card. It is sometimes engaged in by dealers on
the streets of a city, with bets made by passers-by.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Monte</ent><br/
\'d8<hw>Mon"te</hw> <pr>(?)</pr>, <pos>n.</pos> <def>In Spanish America,
a wood; forest; timber land; esp., in parts of South America, a
comparatively wooden region.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monte-acid</ent><br/
<hw>Monte`-ac"id</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>monter</ets> to raise + <ets>acide</ets> acid.]</ety>
<fld>(Chem.)</fld> <def>An acid elevator, as a tube through which acid
is forced to some height in a sulphuric acid manufactory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monteith</ent><br/
<hw>Mon*teith"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Monteth</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monteith</ent><br/
<hw>Mon*teith"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of cotton
handkerchief having a uniform colored ground with a regular pattern of
white spots produced by discharging the color; -- so called from the
Glasgow manufactures.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monte-jus</ent><br/
\'d8<hw>Monte"-jus"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>monter</ets> to bring up + <ets>jus</ets> juice.]</ety> <def>An
apparatus for raising a liquid by pressure of air or steam in a
reservoir containing the liquid.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Montem</ent><br/
<hw>Mon"tem</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ad
montem</ets> to the hillock. See <er>Mount</er>, <pos>n.</pos>]</ety>
<def>A custom, formerly practiced by the scholars at Eton school,
England, of going every third year, on Whittuesday, to a hillock near
the Bath road, and exacting money from all passers-by, to support at the
university the senior scholar of the school.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montero</ent><br/
<hw>Mon*te"ro</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>montera</ets> a hunting cap, fr. <ets>montero</ets> a huntsman,
<ets>monte</ets> a mountain, forest, L. <ets>mons</ets>,
<ets>montis</ets>, mountain. See <er>Mount</er>, <pos>n.</pos>]</ety>
<def>An ancient kind of cap worn by horsemen or huntsmen.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montessori Method</ent><br/
<hw>Mon`tes*so"ri Meth"od</hw> <pr>(?)</pr>. <fld>(Pedagogy)</fld>
<def>A system of training and instruction, primarily for use with normal
children aged from three to six years, devised by <person>Dr. Maria
<etsep>Montessori</etsep></person> while teaching in the <ldquo/Houses
of Childhood<rdquo/ (schools in the poorest tenement districts of Rome,
Italy), and first fully described by her in 1909. The fundamental aim is
to create self-motivation for education, and the leading features are
freedom for physical activity (no stationary desks and chairs), informal
and individual instruction, the very early development of reading and
writing skills, and an extended sensory and motor training (with special
emphasis on vision, touch, perception of movement, and their
interconnections), mediated by a patented, standardized system of
<ldquo/didactic apparatus,<rdquo/ which is declared to be
<ldquo/auto-regulative.<rdquo/ Most of the chief features of the method
are borrowed from current methods used in many institutions for training
feeble-minded children, and dating back especially to the work of the
French-American physician <person>Edouard O. Seguin</person>
(1812-80).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Monteith</ent><br/
<ent>Monteth</ent><br/
<mhw>{ <hw>Mon*teth"</hw> <pr>(?)</pr>, <hw>Mon*teith"</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>A vessel in which glasses are washed; -- so
called from the name of the inventor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>New things produce new words, and thus <qex>Monteth</qex><br/
Has by one vessel saved his name from death.</q>
<rj><qau>King.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montgolfier</ent><br/
\'d8<hw>Mont`gol"fier</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A balloon
which ascends by the buoyancy of air heated by a fire; a fire balloon;
-- so called from two brothers, Stephen and <person>Joseph
<etsep>Montgolfier</etsep></person>, of France, who first constructed
and sent up a fire balloon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Month</ent><br/
<hw>Month</hw> <pr>(m<ucr/nth)</pr>, <pos>n.</pos> <ety>[OE.
<ets>month</ets>, <ets>moneth</ets>, AS. <ets>m<omac/n<edh/</ets>,
<ets>m<omac/na<edh/</ets>; akin to <ets>m<omac/na</ets> moon, and to D.
<ets>maand</ets> month, G. <ets>monat</ets>, OHG.
<ets>m<amac/n<omac/d</ets>, Icel. <ets>m<amac/nu<edh/r</ets>,
<ets>m<amac/na<edh/r</ets>, Goth. <ets>m<emac/n<omac/<thorn/s</ets>.
<root/272. See <er>Moon</er>.]</ety> <def>One of the twelve portions
into which the year is divided; the twelfth part of a year,
corresponding nearly to the length of a synodic revolution of the moon,
-- whence the name. In popular use, a period of four weeks is often
called a <ex>month</ex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the common law, a <xex>month</xex> is a lunar month,
or twenty-eight days, unless otherwise expressed. <au>Blackstone.</au>
In the United States the rule of the common law is generally changed,
and a <xex>month</xex> is declared to mean a calendar month.
<au>Cooley's Blackstone.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A month mind</b></col>. <sd>(a)</sd> <cd>A strong or
abnormal desire</cd>. <mark>[Obs.]</mark> <au>Shak.</au> <sd>(b)</sd>
<cd>A celebration made in remembrance of a deceased person a month after
death.</cd> <au>Strype.</au> -- <col><b>Calendar months</b></col>,
<cd>the months as adjusted in the common or Gregorian calendar; April,
June, September, and November, containing 30 days, and the rest 31,
except February, which, in common years, has 28, and in leap years
29.</cd> -- <col><b>Lunar month</b></col>, <cd>the period of one
revolution of the moon, particularly a synodical revolution; but several
kinds are distinguished, as the <stype>synodical month</stype>, or
period from one new moon to the next, in mean length 29 d. 12 h. 44 m.
2.87 s.; the <stype>nodical month</stype>, or time of revolution from
one node to the same again, in length 27 d. 5 h. 5 m. 36 s.; the
<stype>sidereal</stype>, or time of revolution from a star to the same
again, equal to 27 d. 7 h. 43 m. 11.5 s.; the
<stype>anomalistic</stype>, or time of revolution from perigee to
perigee again, in length 27 d. 13 h. 18 m. 37.4 s.; and the
<stype>tropical</stype>, or time of passing from any point of the
ecliptic to the same again, equal to 27 d. 7 h. 43 m. 4.7 s.</cd> --
<col><b>Solar month</b></col>, <cd>the time in which the sun passes
through one sign of the zodiac, in mean length 30 d. 10 h. 29 m. 4.1
s.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monthling</ent><br/
<hw>Month"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which is a
month old, or which lives for a month.</def> <mark>[R.]</mark>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monthly</ent><br/
<hw>Month"ly</hw>, <pos>a.</pos> <sn>1.</sn> <def>Continued a month, or
a performed in a month; <as>as, the <ex>monthly</ex> revolution of the
moon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Done, happening, payable, published, etc., once a
month, or every month; <as>as, a <ex>monthly</ex> visit;
<ex>monthly</ex> charges; a <ex>monthly</ex> installment; a
<ex>monthly</ex> magazine.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monthly nurse</b></col>, <cd>a nurse who serves for a
month or some short time, esp. one which attends women after
childbirth.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monthly</ent><br/
<hw>Month"ly</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Monthlies</plw>
<pr>(<?/)</pr>.</plu> <def>A publication which appears regularly once a
month.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monthly</ent><br/
<hw>Month"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>Once a month; in
every month; <as>as, the moon changes <ex>monthly</ex></as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>As if under the influence of the moon; in the manner
of a lunatic.</def> <mark>[Obs.]</mark> <rj><au>Middleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monticle</ent><br/
<hw>Mon"ti*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>monticulus</ets>, dim. of <ets>mons</ets>, <ets>montis</ets>,
mountain: cf. F. <ets>monticule</ets>. See <er>Mount</er>,
<pos>n.</pos>]</ety> <def>A little mount; a hillock; a small elevation
or prominence.</def> <altsp>[Written also
<asp>monticule</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monticulate</ent><br/
<hw>Mon*tic"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with
monticles or little elevations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monticule</ent><br/
<hw>Mon"ti*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Monticle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monticulous</ent><br/
<hw>Mon*tic"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Monticulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montiform</ent><br/
<hw>Mon"ti*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mons</ets>, <ets>montis</ets>, mountain + <ets>-form</ets>.]</ety>
<def>Resembling a mountain in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montigenous</ent><br/
<hw>Mon*tig"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>montigena</ets>; <ets>mons</ets>, <ets>montis</ets>, mountain + the
root of <ets>gignere</ets> to beget.]</ety> <def>Produced on a
mountain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montoir</ent><br/
\'d8<hw>Mon`toir"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>monter</ets> to mount. See <er>Montant</er>.]</ety> <def>A stone
used in mounting a horse; a horse block.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monton</ent><br/
<hw>Mon"ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<fld>(Mining)</fld> <def>A heap of ore; a mass undergoing the process of
amalgamation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montre</ent><br/
<hw>Mon"tre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., show, show case,
organ case.]</ety> <sn>1.</sn> <fld>(Organ Building)</fld> <def>A stop,
usually the open diapason, having its pipes <ldquo/shown<rdquo/ as part
of the organ case, or otherwise specially mounted.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A hole in the wall of a pottery kiln, by which the
state of the pieces within can be judged.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Montross</ent><br/
<hw>Mon*tross"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Matross</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Montrue</ent><br/
<hw>Mon"true</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>monter</ets> to mount. See <er>Montoir</er>.]</ety> <def>That on
which anything is mounted; a setting; hence, a saddle horse.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monument</ent><br/
<hw>Mon"u*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>monumentum</ets>, fr. <ets>monere</ets> to remind, admonish. See
<er>Monition</er>, and cf. <er>Moniment</er>.]</ety> <sn>1.</sn>
<def>Something which stands, or remains, to keep in remembrance what is
past; a memorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of ancient British art<br/
A pleasing <qex>monument</qex>.</q> <rj><qau>Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our bruised arms hung up for <qex>monuments</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A building, pillar, stone, or the like, erected to
preserve the remembrance of a person, event, action, etc.; <as>as, the
Washington <ex>monument</ex>; the Bunker Hill <ex>monument</ex></as>.
Also, a tomb, with memorial inscriptions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On your family's old <qex>monument</qex><br/
Hang mournful epitaphs, and do all rites<br/
That appertain unto a burial.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A stone or other permanent object, serving to
indicate a limit or to mark a boundary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A saying, deed, or example, worthy of
record.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Acts and <qex>Monuments</qex> of these latter and perilous
days.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Memorial; remembrance; tomb; cenotaph.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monumental</ent><br/
<hw>Mon`u*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>monumentalis</ets>: cf. F. <ets>monumental</ets>.]</ety>
<sn>1.</sn> <def>Of, pertaining to, or suitable for, a monument; <as>as,
a <ex>monumental</ex> inscription</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Serving as a monument; memorial; preserving
memory.</def> <ldquo/Of pine, or <xex>monumental</xex> oak.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A work outlasting <qex>monumental</qex> brass.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of lasting significance; <as>as, a
<ex>monumental</ex> work of literature; a <ex>monumental</ex>
accomplishment</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Exceptionally large in quantity, quality, or degree;
<as>as, a <ex>monumental</ex> amount of work to be done</as></def><br/
[<source>PJC</source>]</p>

<p><ent>Monumentally</ent><br/
<hw>Mon`u*men"tal*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>By way of
memorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>By means of monuments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Monureid</ent><br/
<hw>Mon*u"re*id</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mon-</ets> +
<ets>ureid</ets>.]</ety> <fld>(Chem.)</fld> <def>Any one of a series of
complex nitrogenous substances regarded as derived from one molecule of
urea; <as>as, alloxan is a <ex>monureid</ex></as>.</def> <altsp>[Written
also <asp>monureide</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moo</ent><br/
<hw>Moo</hw> <pr>(m<omac/)</pr>, <pos>a., adv., & n.</pos> <def>See
<er>Mo</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moo</ent><br/
<hw>Moo</hw> <pr>(m<oomac/)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mooed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mooing</conjf>.]</vmorph> <ety>[Of imitative
origin.]</ety> <def>To make the noise of a cow; to low; -- a child's
word.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moo</ent><br/
<hw>Moo</hw>, <pos>n.</pos> <def>The lowing of a cow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mooch</ent><br/
<hw>mooch</hw> <pos>v. t.</pos> <sn>1.</sn> <def>to ask for and get
free; to borrow without intending to repay; to sponge; -- usually with
objects of small value; <as>as, he <ex>mooched</ex> a few cigarettes
from me</as>.</def><br/
<syn><b>Syn. --</b> bum, cadge, grub, sponge.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>To beg for.</def><br/
[<source>PJC</source>]</p>

<p><ent>moo-cow</ent><br/
<hw>moo-cow</hw> <pos>n.</pos> <def>a cow{1}; -- a child's word. See 1st
<er>cow</er>{1}, <pos>n.</pos></def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mood</ent><br/
<hw>Mood</hw> <pr>(m<oomac/d)</pr>, <pos>n.</pos> <ety>[The same word as
<ets>mode</ets>, perh. influenced by <ets>mood</ets> temper. See
<er>Mode</er>.]</ety> <sn>1.</sn> <def>Manner; style; mode; logical
form; musical style; manner of action or being. See <er>Mode</er> which
is the preferable form).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>Manner of conceiving and
expressing action or being, as positive, possible, conditional,
hypothetical, obligatory, imperitive, etc., without regard to other
accidents, such as time, person, number, etc.; <as>as, the indicative
<ex>mood</ex>; the imperitive <ex>mood</ex>; the infinitive
<ex>mood</ex>; the subjunctive <ex>mood</ex>. Same as
<er>Mode</er>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mood</ent><br/
<hw>Mood</hw>, <pos>n.</pos> <ety>[OE. <ets>mood</ets>, <ets>mod</ets>,
AS. <ets>m<omac/d</ets>mind, feeling, heart, courage; akin to OS. &
OFries. <ets>m<omac/d</ets>, D. <ets>moed</ets>, OHG. <ets>muot</ets>,
G. <ets>muth</ets>, <ets>mut</ets>, courage, Dan. & Sw. <ets>mod</ets>,
Icel. <ets>m<omac/<edh/r</ets> wrath, Goth. <ets>m<omac/ds</ets>.]</ety>
<def>Temper of mind; temporary state of the mind in regard to passion or
feeling; humor; <as>as, a melancholy <ex>mood</ex>; a suppliant
<ex>mood</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till at the last aslaked was his <qex>mood</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fortune is merry,<br/
And in this <qex>mood</qex> will give us anything.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The desperate recklessness of her <qex>mood</qex>.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooder</ent><br/
<hw>Moo"der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mother.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moodily</ent><br/
<hw>Mood"i*ly</hw> <pr>(m<oomac/d"<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a moody manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moodiness</ent><br/
<hw>Mood"i*ness</hw>, <pos>n.</pos> <def>The quality or state of being
moody; specifically, liability to strange or violent moods.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moodir</ent><br/
\'d8<hw>Moo"dir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>mud<imac/r</ets>.]</ety> <def>The governor of a province in Egypt,
etc.</def> <altsp>[Written also <asp>mudir</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moodish</ent><br/
<hw>Mood"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Moody.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moodishly</ent><br/
<hw>Mood"ish*ly</hw>, <pos>adv.</pos> <def>Moodily.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moody</ent><br/
<hw>Mood"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Moodier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Moodiest</adjf>.]</amorph> <ety>[AS. <ets>m<omac/dig</ets>
courageous.]</ety> <sn>1.</sn> <def>Subject to varying moods, especially
to states of mind which are unamiable or depressed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Out of humor; peevish; angry; fretful; also,
abstracted and pensive; sad; gloomy; melancholy.</def> <ldquo/Every
peevish, <xex>moody</xex> malcontent.<rdquo/ <rj><au>Rowe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Arouse thee from thy <qex>moody</qex> dream!</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Gloomy; pensive; sad; fretful;
capricious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moollah</ent><br/
<ent>Moolah</ent><br/
<mhw>{ <hw>Moo"lah</hw> <pr>(?)</pr>, <hw>Mool"lah</hw> }</mhw>,
<pos>n.</pos> <def>See <er>Mollah</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moolley</ent><br/
<hw>Mool"ley</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mulley</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moolah</ent><br/
<ent>moola</ent><br/
<mhw><hw>moo"la</hw>, <hw>moo"lah</hw></mhw>
<pr>(m<oomac/"l<adot/)</pr>, <pos>n.</pos> <def>money.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Moon</ent><br/
<hw>Moon</hw> <pr>(m<oomac/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mone</ets>, AS. <ets>m<omac/na</ets>; akin to D. <ets>maan</ets>,
OS. & OHG. <ets>m<amac/no</ets>, G. <ets>mond</ets>, Icel.
<ets>m<amac/ni</ets>, Dan. <ets>maane</ets>, Sw. <ets>m<aring/ne</ets>,
Goth. <ets>m<emac/na</ets>, Lith. <ets>men<uring/</ets>, L.
<ets>mensis</ets> month, Gr. <grk>mh`nh</grk> moon, <grk>mh`n</grk>
month, Skr. <ets>m<amac/s</ets> moon, month; prob. from a root meaning
to measure (cf. Skr. <ets>m<amac/</ets> to measure), from its serving to
measure the time. <root/271. Cf. <er>Mete</er> to measure,
<er>Menses</er>, <er>Monday</er>, <er>Month</er>.]</ety> <sn>1.</sn>
<def>The celestial orb which revolves round the earth; the satellite of
the earth; a secondary planet, whose light, borrowed from the sun, is
reflected to the earth, and serves to dispel the darkness of night. The
diameter of the moon is 2,160 miles, its mean distance from the earth is
240,000 miles, and its mass is one eightieth that of the earth. See
<cref>Lunar month</cref>, under <er>Month</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The crescent <qex>moon</qex>, the diadem of night.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A secondary planet, or satellite, revolving about
any member of the solar system; <as>as, the <ex>moons</ex> of Jupiter or
Saturn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The time occupied by the moon in making one
revolution in her orbit; a month; <as>as, it's been many <ex>moons</ex>
since I last visited Washington</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Fort.)</fld> <def>A crescentlike outwork. See
<er>Half-moon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The deliberately exposed naked buttocks.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Moon blindness</b></col>. <sd>(a)</sd> <fld>(Far.)</fld>
<cd>A kind of ophthalmia liable to recur at intervals of three or four
weeks</cd>. <sd>(b)</sd> <fld>(Med.)</fld> <cd>Hemeralopia.</cd> --
<col><b>Moon dial</b></col>, <cd>a dial used to indicate time by
moonlight.</cd> -- <col><b>Moon face</b></col>, <cd>a round face like a
full moon.</cd> -- <col><b>Moon madness</b></col>, <cd>lunacy.</cd>
<mark>[Poetic]</mark> -- <col><b>Moon month</b></col>, <cd>a lunar
month.</cd> -- <col><b>Moon trefoil</b></col> <fld>(Bot.)</fld>, <cd>a
shrubby species of medic (<spn>Medicago arborea</spn>). See
<er>Medic</er>.</cd> -- <col><b>Moon year</b></col>, <cd>a lunar year,
consisting of lunar months, being sometimes twelve and sometimes
thirteen.</cd> -- <col><b>blue moon</b></col>, <cd>see <er>blue
moon</er> in the vocabulary.</cd> -- <col><b>many moons</b></col>, <cd>a
long time.</cd> </cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moon</ent><br/
<hw>Moon</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mooned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mooning</conjf>.]</vmorph> <sn>1.</sn> <def>To expose to the rays
of the moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If they have it to be exceeding white indeed, they seethe it yet
once more, after it hath been thus sunned and <qex>mooned</qex>.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To expose one's naked buttocks to (a person); -- a
vulgar sign of contempt or disrespect, sometimes done as a
prank.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moon</ent><br/
<hw>Moon</hw>, <pos>v. i.</pos> <def>To act if moonstruck; to wander or
gaze about in an abstracted manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Elsley was <qex>mooning</qex> down the river by himself.</q>
<rj><qau>C. Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonbeam</ent><br/
<hw>Moon"beam`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ray of light from
the moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonblind</ent><br/
<hw>Moon"blind`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dim-sighted;
purblind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonblink</ent><br/
<hw>Moon"blink`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A temporary
blindness, or impairment of sight, said to be caused by sleeping in the
moonlight; -- sometimes called <altname>nyctalopia</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooncalf</ent><br/
<hw>Moon"calf`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
monster; a false conception; a mass of fleshy matter, generated in the
uterus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dolt; a stupid fellow.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moon-culminating</ent><br/
<hw>Moon"-cul"mi*na`ting</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Culminating, or coming to the meredian, at or about the same time
with the moon; -- said of a star or stars, esp. of certain stars
selected beforehand, and named in an ephemeris (as the Nautical
Almanac), as suitable to be observed in connection with the moon at
culmination, for determining terrestrial longitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooned</ent><br/
<hw>Mooned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or resembling the
moon; symbolized by the moon.</def> <ldquo/Sharpening in
<xex>mooned</xex> horns.<rdquo/ <ldquo/<xex>Mooned</xex>
Ashtaroth.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooner</ent><br/
<hw>Moon"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who abstractedly
wanders or gazes about, as if moonstruck.</def> <mark>[R.]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonery</ent><br/
<hw>Moon"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Conduct of one who
moons.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonet</ent><br/
<hw>Moon"et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little moon.</def>
<mark>[R.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moon-eye</ent><br/
<hw>Moon"-eye`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A eye
affected by the moon; also, a disease in the eye of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any species of
American fresh-water fishes of the genus <gen>Hyodon</gen>, esp.
<spn>Hyodon tergisus</spn> of the Great Lakes and adjacent waters.</def>
<sd>(b)</sd> <def>The cisco.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moon-eyed</ent><br/
<hw>Moon"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having eyes
affected by the moon; moonblind; dim-eyed; purblind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moon-faced</ent><br/
<hw>Moon"-faced`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a round,
full face.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonfish</ent><br/
<hw>Moon"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>An American marine fish (<spn>Vomer setipennis</spn>);
-- called also <altname>bluntnosed shiner</altname>,
<altname>horsefish</altname>, and <altname>sunfish</altname>.</def>
<sd>(b)</sd> <def>A broad, thin, silvery marine fish (<spn>Selene
vomer</spn>); -- called also <altname>lookdown</altname>, and
<altname>silver moonfish</altname>.</def> <sd>(c)</sd> <def>The mola.
See <er>Sunfish</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonflower</ent><br/
<hw>Moon"flow`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The oxeye daisy; -- called also <altname>moon
daisy</altname>.</def> <sd>(b)</sd> <def>A kind of morning glory
(<spn>Ipomoea Bona-nox</spn>) with large white flowers opening at
night.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moong</ent><br/
<hw>Moong</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Same
as <er>Mung</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonglade</ent><br/
<hw>Moon"glade`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The bright
reflection of the moon's light on an expanse of water.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>moonie</ent><br/
<hw>moo"nie</hw> <pr>(m<oomac/"n<emac/)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The European goldcrest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonie</ent><br/
<hw>Moo"nie</hw> <pr>(m<oomac/"n<emac/)</pr>, <pos>prop. n.</pos>
<ety>[from <person>Sun Myun <etsep>Moon</etsep></person>, Korean
evangelist and founder.]</ety> <def>A member of the <org>Unification
Church</org>, founded by <person>Sun Myun
<etsep>Moon</etsep></person>.</def> <mark>[informal &
contemptuous.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Moonish</ent><br/
<hw>Moon"ish</hw> <pr>(m<oomac/n"<icr/sh)</pr>, <pos>a.</pos> <def>Like
the moon; variable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Being but a <qex>moonish</qex> youth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonless</ent><br/
<hw>Moon"less</hw>, <pos>a.</pos> <def>Being without a moon or
moonlight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonlight</ent><br/
<hw>Moon`light`</hw> <pr>(m<oomac/n"l<imac/t`)</pr>, <pos>n.</pos>
<def>The light of the moon.</def> -- <def2><pos>a.</pos> <def>Occurring
during or by moonlight; characterized by moonlight.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonlight</ent><br/
<hw>Moon"light`</hw> <pr>(m<oomac/n"l<imac/t`)</pr>, <pos>v. i.</pos>
<def>To work at a second job in addition to one's main occupation; --
often done at night, hence the word.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moonlighter</ent><br/
<hw>Moon"light`er</hw> <pr>(m<oomac/n"l<imac/t`<etil/r)</pr>,
<pos>n.</pos> <def>One who follows an occupation or pastime by
moonlight;</def> as: <sd>(a)</sd> <def>A moonshiner.</def> <sd>(b)</sd>
<def>In Ireland, one of a band that engaged in agrarian outrages by
night.</def> <sd>(c)</sd> <def>A serenader by moonlight.</def>
<mark>[Local, U. S.]</mark> <sd>(d)</sd> <def>One who works at a second
job in addition to his main occupation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moonling</ent><br/
<hw>Moon"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A simpleton; a
lunatic.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonlit</ent><br/
<hw>Moon"lit`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Illumined by the
moon.</def> <ldquo/The <xex>moonlit</xex> sea.<rdquo/ <au>Moore.</au>
<ldquo/<xex>Moonlit</xex> dells.<rdquo/ <au>Lowell.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonraker</ent><br/
<hw>Moon"rak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>Same as <er>Moonsail</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonrise</ent><br/
<hw>Moon"rise`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The rising of the
moon above the horizon; also, the time of its rising.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moon-round</ent><br/
<hw>moon-round</hw> <pos>adj.</pos> <def>resembling the moon in
shape.</def><br/
<syn><b>Syn. --</b> moonlike.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moonsail</ent><br/
<hw>Moon"sail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A sail sometimes carried in light winds, above a skysail.</def>
<rj><au>R. H. Dana, Jr.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonseed</ent><br/
<hw>Moon"seed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
climbing plant of the genus <gen>Menispermum</gen>; -- so called from
the crescentlike form of the seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonset</ent><br/
<hw>Moon"set`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The descent of the
moon below the horizon; also, the time when the moon sets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonshee</ent><br/
\'d8<hw>Moon"shee</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>munish<imac/</ets>, fr. Ar. <ets>munish<imac/</ets> a writer,
author, secretary, tutor.]</ety> <def>A Muslim professor or teacher of
language.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonshine</ent><br/
<hw>Moon"shine`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
light of the moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, show without substance or reality.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A month.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A preparation of eggs for food.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Liquor smuggled or illicitly distilled, especially
liquor distilled illegally in rural parts of the southern U. S.</def>
<mark>[Dial. Eng., & Colloq. or Slang, U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moonshine</ent><br/
<hw>Moon"shine`</hw>, <pos>a.</pos> <def>Moonlight.</def>
<mark>[R.]</mark> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Empty; trivial; idle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>Designating, or pertaining to, illicit liquor;
<as>as, <ex>moonshine</ex> whisky</as>.</def> <mark>[Dial. Eng., &
Colloq. or Slang, U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moonshiner</ent><br/
<hw>Moon"shin`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person engaged
in illicit distilling; -- so called because the work is largely done at
night.</def> <mark>[Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonshining</ent><br/
<hw>Moon"shin`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Illicit
distilling.</def> <mark>[Slang or Colloq., U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moonshiny</ent><br/
<hw>Moon"shin`y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Moonlight.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I went to see them in a <qex>moonshiny</qex> night.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moon shot</ent><br/
<hw>Moon" shot`</hw> <pr>(m<oomac/n" sh<ocr/t)</pr>, <pos>n.</pos>
<def>The action or event of sending a spacecraft to the moon; -- used of
manned or unmanned missions.</def><br/
[<source>PJC</source>]</p>

<p><ent>moon-splashed</ent><br/
<hw>moon-splashed</hw> <pos>adj.</pos> <def>splashed or covered patchily
with moonlight; <as>as, the <ex>moon-splashed</ex> world</as>.</def><br/
<syn><b>Syn. --</b> moon splashed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Moonstone</ent><br/
<hw>Moon"stone`</hw> <pr>(m<oomac/n"st<omac/n`)</pr>, <pos>n.</pos>
<fld>(Min.)</fld> <def>A nearly pellucid variety of feldspar, showing
pearly or opaline reflections from within. It is used as a gem. The best
specimens come from Ceylon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonstricken</ent><br/
<hw>Moon"strick`en</hw> <pr>(m<oomac/n"str<icr/k`'n)</pr>, <pos>a.</pos>
<def>See <er>Moonstruck</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moonstruck</ent><br/
<hw>Moon"struck`</hw> <pr>(m<oomac/n"str<ucr/k`)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Mentally affected or deranged by the supposed influence
of the moon; lunatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Produced by the supposed influence of the
moon.</def> <ldquo/<xex>Moonstruck</xex> madness.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Made sick by the supposed influence of the moon, as
a human being; made unsuitable for food, as fishes, by such supposed
influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moonwalk</ent><br/
<hw>moonwalk</hw> <pos>n.</pos> <sn>1.</sn> <def>a kind of dance step in
which the dancer seems to be sliding backward on the spot; <as>as,
<person>Michael Jackson</person> perfected the <ex>moonwalk</ex> in the
1980s</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>an exploratory walk by an astronaut on the surface
of Earth's moon.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moonwort</ent><br/
<hw>Moon"wort`</hw> <pr>(m<oomac/n"w<ucir/rt`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>The herb lunary or honesty. See
<er>Honesty</er>.</def> <sd>(b)</sd> <def>Any fern of the genus
<gen>Botrychium</gen>, esp. <spn>Botrychium Lunaria</spn>; -- so named
from the crescent-shaped segments of its frond.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moony</ent><br/
<hw>Moon"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to the moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soft and pale as the <qex>moony</qex> beam.</q> <rj><qau>J. R.
Drake.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Furnished with a moon; bearing a crescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But soon the miscreant <qex>moony</qex> host<br/
Before the victor cross shall fly.</q> <rj><qau>Fenton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Silly; weakly sentimental.</def>
<mark>[Colloq.]</mark> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moony</ent><br/
<hw>Moon"y</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A follower of the
<person>Rev. Sun Myun <etsep>Moon</etsep></person>; a member of the
<membof>Unification Church</membof>; -- often considered
disparaging.</def> <altsp>[Also spelled <asp>Moonie</asp>.]</altsp><br/
[<source>PJC</source>]</p>

<p><ent>Moor</ent><br/
<hw>Moor</hw> <pr>(m<oomac/r)</pr>, <pos>n.</pos> <ety>[F.
<ets>More</ets>, <ets>Maure</ets>, L. <ets>Maurus</ets> a Moor, a
Mauritanian, an inhabitant of Mauritania, Gr. <grk>May^ros</grk>; cf.
<grk>may^ros</grk> black, dark. Cf. <er>Morris</er> a dance,
<er>Morocco</er>.]</ety> <sn>1.</sn> <def>One of a mixed race inhabiting
Morocco, Algeria, Tunis, and Tripoli, chiefly along the coast and in
towns.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hist.)</fld> <def>Any individual of the swarthy
races of Africa or Asia which have adopted the Muslim religion.</def>
<ldquo/In Spanish history the terms <xex>Moors</xex>, Saracens, and
Arabs are synonymous.<rdquo/ <rj><au>Internat. Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moor</ent><br/
<hw>Moor</hw>, <pos>n.</pos> <ety>[OE. <ets>mor</ets>, AS.
<ets>m<omac/r</ets> moor, morass; akin to D. <ets>moer</ets> moor, G.
<ets>moor</ets>, and prob. to Goth. <ets>marei</ets> sea, E.
<ets>mere</ets>. See <er>Mere</er> a lake.]</ety> <sn>1.</sn> <def>An
extensive waste covered with patches of heath, and having a poor, light
soil, but sometimes marshy, and abounding in peat; a heath.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In her girlish age she kept sheep on the <qex>moor</qex>.</q>
<rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A game preserve consisting of moorland.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moor buzzard</b></col> <fld>(Zool.)</fld>, <cd>the marsh
harrier.</cd> <mark>[Prov. Eng.]</mark> -- <col><b>Moor coal</b></col>
<fld>(Geol.)</fld>, <cd>a friable variety of lignite.</cd> --
<col><b>Moor cock</b></col> <fld>(Zool.)</fld>, <cd>the male of the
<er>moor fowl</er> or red grouse of Europe.</cd> -- <col><b>Moor
coot</b></col>. <fld>(Zool.)</fld> <cd>See <er>Gallinule</er>.</cd> --
<col><b>Moor game</b></col>. <fld>(Zool.)</fld> <cd>Same as <er>Moor
fowl</er>.</cd> -- <col><b>Moor grass</b></col> <fld>(Bot.)</fld>, <cd>a
tufted perennial grass (<spn>Sesleria caerulea</spn>), found in mountain
pastures of Europe.</cd> -- <col><b>Moor hawk</b></col>
<fld>(Zool.)</fld>, <cd>the marsh harrier.</cd> -- <col><b>Moor
hen</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The female of the
<er>moor fowl</er>.</cd> <sd>(b)</sd> <cd>A gallinule, esp. the European
species. See <er>Gallinule</er>.</cd> <sd>(c)</sd> <cd>An Australian
rail (<spn>Tribonyx ventralis</spn>).</cd> -- <col><b>Moor
monkey</b></col> <fld>(Zool.)</fld>, <cd>the black macaque of Borneo
(<spn>Macacus maurus</spn>).</cd> -- <col><b>Moor titling</b></col>
<fld>(Zool.)</fld>, <cd>the European stonechat (<spn>Pratinocola
rubicola</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 943 --></p>

<p><ent>Moor</ent><br/
<hw>Moor</hw> <pr>(m<oomac/r)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Moored</conjf> <pr>(m<oomac/rd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Mooring</conjf>.]</vmorph> <ety>[Prob. fr. D.
<ets>marren</ets> to tie, fasten, or moor a ship. See
<er>Mar</er>.]</ety> <sn>1.</sn> <fld>(Naut.)</fld> <def>To fix or
secure, as a vessel, in a particular place by casting anchor, or by
fastening with cables or chains; <as>as, the vessel was <ex>moored</ex>
in the stream; they <ex>moored</ex> the boat to the
wharf.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To secure, or fix firmly.</def>
<rj><au>Brougham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moor</ent><br/
<hw>Moor</hw>, <pos>v. i.</pos> <def>To cast anchor; to become
fast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On oozy ground his galleys <qex>moor</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorage</ent><br/
<hw>Moor"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place for
mooring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorball</ent><br/
<hw>Moor"ball`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
fresh-water alga (<spn>Cladophora Aegagropila</spn>) which forms a
globular mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorband</ent><br/
<hw>Moor"band`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Moorpan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooress</ent><br/
<hw>Moor"ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female Moor; a
Moorish woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moor fowl</ent><br/
<ent>moorfowl</ent><br/
<mhw><hw>moorfowl</hw>, <hw>moor fowl</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <sn>1.</sn> <def>A reddish-brown grouse (<spn>Lagopus
Scoticus</spn>) of upland moors of Great Britain; the European
ptarmigan, or <altname>red grouse</altname>, also called the
<altname>moorgame</altname>.</def><br/
<syn><b>Syn. --</b> red grouse, moorbird, moorgame, <spn>Lagopus
scoticus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The European heath grouse. See under
<er>Heath</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moorgame</ent><br/
<hw>moorgame</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>The
<er>moorfowl</er>.</def><br/
<syn><b>Syn. --</b> red grouse, , moorbird, <spn>Lagopus
scoticus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>moorhen</ent><br/
<hw>moorhen</hw> <pos>n.</pos> <fld>(Zool.)</fld> <sn>1.</sn> <def>A
black gallinule (<spn>Gallinula chloropus</spn>) that inhabits ponds and
lakes.</def><br/
<syn><b>Syn. --</b> <spn>Gallinula chloropus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The female of the <er>moor fowl</er>; the
<altname>moor hen</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mooring</ent><br/
<hw>Moor"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of confining a
ship to a particular place, by means of anchors or fastenings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which serves to confine a ship to a place, as
anchors, cables, bridles, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The place or condition of a ship
thus confined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the tossed bark in <qex>moorings</qex> swings.</q>
<rj><qau>Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mooring block</b></col> <fld>(Naut.)</fld>, <cd>a heavy
block of cast iron sometimes used as an anchor for mooring
vessels.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorish</ent><br/
<hw>Moor"ish</hw>, <pos>a.</pos> <ety>[From 2d <er>Moor</er>.]</ety>
<def>Having the characteristics of a moor or heath.</def>
<ldquo/<xex>Moorish</xex> fens.<rdquo/ <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorish</ent><br/
<hw>Moor"ish</hw>, <pos>a.</pos> <ety>[See 1st <er>Moor</er>, and cf.
<er>Morris</er>, <er>Moresque</er>.]</ety> <def>Of or pertaining to
Morocco or the Moors; in the style of the Moors.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moorish architecture</b></col>, <cd>the style developed
by the Moors in the later Middle Ages, esp. in Spain, in which the arch
had the form of a horseshoe, and the ornamentation admitted no
representation of animal life. It has many points of resemblance to the
Arabian and Persian styles, but should be distinguished from them. See
<xex>Illust.</xex> under <er>Moresque</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorland</ent><br/
<hw>Moor"land</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>m<omac/rland</ets>.]</ety> <def>Land consisting of a moor or
moors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorpan</ent><br/
<hw>Moor"pan`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <ets>Hard
pan</ets>, under <er>Hard</er>.]</ety> <def>A clayey layer or pan
underlying some moors, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moorstone</ent><br/
<hw>Moor"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A species of
English granite, used as a building stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooruk</ent><br/
\'d8<hw>Moo"ruk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native
name.]</ety> <fld>(Zool.)</fld> <def>A species of cassowary
(<spn>Casuarius Bennetti</spn>) found in New Britain, and noted for its
agility in running and leaping. It is smaller and has stouter legs than
the common cassowary. Its crest is bilobed; the neck and breast are
black; the back, rufous mixed with black; and the naked skin of the
neck, blue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moory</ent><br/
<hw>Moor"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
moors; marshy; fenny; boggy; moorish.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As when thick mists arise from <qex>moory</qex> vales.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moory</ent><br/
<hw>Moor"y</hw>, <pos>n.</pos> <def>A kind of blue cloth made in
India.</def> <rj><au>Balfour (Cyc of India).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>moose</ent><br/
<hw>moose</hw> <pr>(m<oomac/s)</pr>, <pos>n.</pos> <ety>[A native name;
Knisteneaux <ets>mouswah</ets>; Algonquin <ets>monse</ets>.
<ets>Mackenzie</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A large
cervine mammal (<spn>Alces alces</spn> syn. <spn>Alces machlis</spn>,
syn <spn>Alces Americanus</spn>), native of the Northern United States
and Canada. The adult male is about as large as a horse, and has very
large, palmate antlers. It closely resembles the European elk, and by
many Zoologists is considered the same species. See
<er>Elk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A member of the Progressive Party; a Bull
Moose.</def> <mark>[Obsolescent. Cant, from the early
1900's.]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <mark>[capitalized]</mark> <def>A member of the fraternal
organization named <membof>Loyal Order of Moose</membof>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Moose bird</b></col> <fld>(Zool.)</fld>, <cd>the Canada
jayor whisky jack. See <er>Whisky jack</er>.</cd> -- <col><b>Moose
deer</b></col>. <cd>Same as <er>Moose</er>.</cd> -- <col><b>Moose
yard</b></col> <fld>(Zool.)</fld>, <cd>a locality where moose, in
winter, herd together in a forest to feed and for mutual
protection.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moosewood</ent><br/
<hw>Moose"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The striped maple (<spn>Acer
Pennsylvanicum</spn>).</def> <sd>(b)</sd> <def>Leatherwood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moot</ent><br/
<hw>moot</hw> <pr>(m<omac/t)</pr>, <pos>v.</pos> <def>See 1st
<er>Mot</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>moot</ent><br/
<hw>moot</hw> <pr>(m<oomac/t)</pr>, <pos>n.</pos>
<fld>(Shipbuilding)</fld> <def>A ring for gauging wooden pins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moot</ent><br/
<hw>Moot</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mooted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mooting</conjf>.]</vmorph> <ety>[OE. <ets>moten</ets>,
<ets>motien</ets>, AS. <ets>m<omac/tan</ets> to meet or assemble for
conversation, to discuss, dispute, fr. <ets>m<omac/t</ets>,
<ets>gem<omac/t</ets>, a meeting, an assembly; akin to Icel.
<ets>m<omac/t</ets>, MHG. <ets>muoz</ets>. Cf. <er>Meet</er> to come
together.]</ety> <sn>1.</sn> <def>To argue for and against; to debate;
to discuss; to propose for discussion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A problem which hardly has been mentioned, much less
<qex>mooted</qex>, in this country.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically: To discuss by way of exercise; to
argue for practice; to propound and discuss in a mock court.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>First a case is appointed to be <qex>mooted</qex> by certain young
men, containing some doubtful controversy.</q> <rj><qau>Sir T.
Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render inconsequential, as having no effect on
the practical outcome; to render academic; <as>as, the ruling that the
law was invalid <ex>mooted</ex> the question of whether he actually
violated it</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moot</ent><br/
<hw>Moot</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To argue or plead in a
supposed case.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a difference between <qex>mooting</qex> and pleading;
between fencing and fighting.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moot</ent><br/
<hw>Moot</hw>, <pos>n.</pos> <ety>[AS. <ets>m<omac/t</ets>,
<ets>gem<omac/t</ets>, a meeting; -- usually in comp.]</ety>
<altsp>[Written also <asp>mote</asp>.]</altsp> <sn>1.</sn> <def>A
meeting for discussion and deliberation; esp., a meeting of the people
of a village or district, in Anglo-Saxon times, for the discussion and
settlement of matters of common interest; -- usually in composition;
<as>as, folk-<ex>moot</ex></as>.</def> <rj><au>J. R.
Green.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[From <er>Moot</er>, <pos>v.</pos>]</ety> <def>A
discussion or debate; especially, a discussion of fictitious causes by
way of practice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pleading used in courts and chancery called
<qex>moots</qex>.</q> <rj><qau>Sir T. Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moot case</b></col>, <cd>a case or question to be mooted;
a disputable case; an unsettled question.</cd> <au>Dryden.</au> --
<col><b>Moot court</b></col>, <cd>a mock court, such as is held by
students of law for practicing the conduct of law cases.</cd> --
<col><b>Moot point</b></col>, <cd>a point or question to be debated; a
doubtful question.</cd> -- <col><b>to make moot</b></col> <pos>v.
t.</pos> <cd>to render moot{2}; to moot{3}.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Moot</ent><br/
<hw>Moot</hw>, <pos>a.</pos> <sn>1.</sn> <def>Subject, or open, to
argument or discussion; undecided; debatable; mooted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of purely theoretical or academic interest; having
no practical consequence; <as>as, the team won in spite of the bad call,
and whether the ruling was correct is a <ex>moot</ex>
question</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mootable</ent><br/
<hw>Moot"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
mooted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mooter</ent><br/
<hw>Moot"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A disputer of a mooted
case.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moot-house</ent><br/
<ent>Moot-hall</ent><br/
<mhw>{ <hw>Moot"-hall`</hw> <pr>(?)</pr>, <hw>Moot"-house`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[AS.
<ets>m<omac/th<?/s</ets>.]</ety> <def>A hall for public meetings; a hall
of judgment.</def> <mark>[Obs.]</mark> <ldquo/The <xex>moot-hall</xex>
of Herod.<rdquo/ <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moot-hill</ent><br/
<hw>Moot"-hill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(O. Eng.
Law)</fld> <def>A hill of meeting or council; an elevated place in the
open air where public assemblies or courts were held by the Saxons; --
called, in Scotland, <altname>mute-hill</altname>.</def> <rj><au>J. R.
Green.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mootman</ent><br/
<hw>Moot"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mootmen</plw> <pr>(<?/)</pr>.</plu> <fld>(O. Eng. Law)</fld>
<def>One who argued moot cases in the inns of court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mop</ent><br/
<hw>Mop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Mope</er>.]</ety>
<def>A made-up face; a grimace.</def> <ldquo/What <xex>mops</xex> and
mowes it makes!<rdquo/ <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mop</ent><br/
<hw>Mop</hw>, <pos>v. i.</pos> <def>To make a wry mouth.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mop</ent><br/
<hw>Mop</hw>, <pos>n.</pos> <ety>[CF. W. <ets>mop</ets>,
<ets>mopa</ets>, Ir. <ets>moipal</ets>, Gael. <ets>moibeal</ets>,
<ets>moibean</ets>; or OF. <ets>mappe</ets> a napkin (see <er>Map</er>,
<er>Napkin</er>).]</ety> <sn>1.</sn> <def>An implement for washing
floors, or the like, made of a piece of cloth, or a collection of
thrums, or coarse yarn, fastened to a handle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fair where servants are hired.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The young of any animal; also, a young girl; a
moppet.</def> <mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mop head</b></col>. <sd>(a)</sd> <cd>The end of a mop, to
which the thrums or rags are fastened</cd>. <sd>(b)</sd> <cd>A clamp for
holding the thrums or rags of a mop.</cd> <mark>[U.S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mop</ent><br/
<hw>Mop</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mopped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mopping</conjf>.]</vmorph> <def>To rub or wipe with a mop, or as
with a mop; <as>as, to <ex>mop</ex> a floor; to <ex>mop</ex> one's face
with a handkerchief.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mopboard</ent><br/
<hw>Mop"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Carp.)</fld>
<def>A narrow board nailed against the wall of a room next to the floor;
skirting board; baseboard. See <er>Baseboard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mope</ent><br/
<hw>Mope</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Moped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Moping</conjf>.]</vmorph> <ety>[Cf. D. <ets>moppen</ets> to pout,
Prov. G. <ets>muffen</ets> to sulk.]</ety> <def>To be dull and
spiritless; to spend time doing little; <as>as, to <ex>mope</ex> around
the house</as>.</def> <ldquo/<xex>Moping</xex> melancholy.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sickly part of one true sense<br/
Could not so <qex>mope</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mope</ent><br/
<hw>Mope</hw>, <pos>v. t.</pos> <def>To make spiritless and
stupid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mope</ent><br/
<hw>Mope</hw>, <pos>n.</pos> <def>A dull, spiritless person.</def>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mope-eyed</ent><br/
<hw>Mope"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shortsighted;
purblind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mopeful</ent><br/
<hw>Mope"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mopish.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mop-headed</ent><br/
<hw>mop-headed</hw> <pos>adj.</pos> <def>having a bushy top without a
leader; -- of trees; <as>as, <ex>mop-headed</ex> cabbage
palms</as>.</def><br/
<syn><b>Syn. --</b> mopheaded.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mopish</ent><br/
<hw>Mop"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dull; spiritless;
dejected.</def> -- <wordforms><wf>Mop"ish*ly</wf>, <pos>adv.</pos> --
<wf>Mop"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moplah</ent><br/
<hw>Mop"lah</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Malayalam
<ets>m<amac/pplia</ets>.]</ety> <def>One of a class of Muslims in
Malabar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moppet</ent><br/
<hw>Mop"pet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From 3d
<er>Mop</er>.]</ety> <sn>1.</sn> <def>A rag baby; a puppet made of
cloth; hence, also, in fondness, a little girl, or a woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A long-haired pet dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mopsy</ent><br/
<ent>Mopsey</ent><br/
<mhw>{ <hw>Mop"sey</hw>, <hw>Mop"sy</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>A moppet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slatternly, untidy woman.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mopsical</ent><br/
<hw>Mop"si*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shortsighted;
mope-eyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mopstick</ent><br/
<hw>Mop"stick`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The long handle of
a mop.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mopus</ent><br/
<hw>mo"pus</hw> <pr>(m<omac/"p<ucr/s)</pr>, <pos>n.</pos> <def>A mope; a
drone.</def> <mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moquette</ent><br/
\'d8<hw>Mo*quette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A kind of carpet having a short velvety pile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mora</ent><br/
\'d8<hw>Mor"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety> <def>A
game of guessing the number of fingers extended in a quick movement of
the hand, -- much played by Italians of the lower classes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mora</ent><br/
<hw>Mo"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
leguminous tree of Guiana and Trinidad (<spn>Dimorphandra
excelsa</spn>); also, its timber, used in shipbuilding and making
furniture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mora</ent><br/
\'d8<hw>Mo"ra</hw>, <pos>n.</pos> <ety>[L.]</ety> <fld>(Rom. & Civil
Law)</fld> <def>Delay; esp., culpable delay; postponement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moraine</ent><br/
<hw>Mo*raine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Cf. Prov. G.
<ets>mur</ets> stones broken off, It. <ets>mora</ets> a heap of stones,
hillock, G. <ets>m<uum/rbe</ets> soft, broken up, OHG.
<ets>muruwi</ets>, AS. <ets>mearu</ets> tender, Gr. <?/ to cause to
wither, Skr. <ets>ml<amac/</ets> to relax.]</ety> <fld>(Geol.)</fld>
<def>An accumulation of earth and stones carried forward and deposited
by a glacier.</def> <rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ If the moraine is at the extremity of the glacier it is
a <xex>terminal moraine</xex>; if at the side, a <xex>lateral
moraine</xex>; if parallel to the side on the central portion of the
glacier, a <xex>medial moraine</xex>. See <xex>Illust.</xex> of
<er>Glacier</er>. In the last case it is formed by the union of the
lateral moraines of the branches of the glacier. A <xex>ground
moraine</xex> is one beneath the mass of ice.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morainic</ent><br/
<hw>Mo*rain"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
a moranie.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moral</ent><br/
<hw>Mor"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. It.
<ets>moralis</ets>, fr. <ets>mos</ets>, <ets>moris</ets>, manner,
custom, habit, way of life, conduct.]</ety> <sn>1.</sn> <def>Relating to
duty or obligation; pertaining to those intentions and actions of which
right and wrong, virtue and vice, are predicated, or to the rules by
which such intentions and actions ought to be directed; relating to the
practice, manners, or conduct of men as social beings in relation to
each other, as respects right and wrong, so far as they are properly
subject to rules.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Keep at the least within the compass of <qex>moral</qex> actions,
which have in them vice or virtue.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mankind is broken loose from <qex>moral</qex> bands.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She had wandered without rule or guidance in a <qex>moral</qex>
wilderness.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conformed to accepted rules of right; acting in
conformity with such rules; virtuous; just; <as>as, a <ex>moral</ex>
man</as>. Used sometimes in distinction from <xex>religious</xex>;
<as>as, a <ex>moral</ex> rather than a religious life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The wiser and more <qex>moral</qex> part of mankind.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Capable of right and wrong action or of being
governed by a sense of right; subject to the law of duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>moral</qex> agent is a being capable of those actions that
have a <qex>moral</qex> quality, and which can properly be denominated
good or evil in a <qex>moral</qex> sense.</q> <rj><qau>J.
Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Acting upon or through one's moral nature or sense
of right, or suited to act in such a manner; <as>as, a <ex>moral</ex>
arguments; <ex>moral</ex> considerations</as>. Sometimes opposed to
<contr>material</contr> and <contr>physical</contr>; <as>as,
<ex>moral</ex> pressure or support</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Supported by reason or probability; practically
sufficient; -- opposed to <contr>legal</contr> or
<contr>demonstrable</contr>; <as>as, a <ex>moral</ex> evidence; a
<ex>moral</ex> certainty.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Serving to teach or convey a moral; <as>as, a
<ex>moral</ex> lesson; <ex>moral</ex> tales.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moral agent</b></col>, <cd>a being who is capable of
acting with reference to right and wrong.</cd> -- <col><b>Moral
certainty</b></col>, <cd>a very high degree or probability, although not
demonstrable as a certainty; a probability of so high a degree that it
can be confidently acted upon in the affairs of life; <as>as, there is a
<ex>moral certainty</ex> of his guilt</as>.</cd> -- <col><b>Moral
insanity</b></col>, <cd>insanity, so called, of the moral system;
badness alleged to be irresponsible.</cd> -- <col><b>Moral
philosophy</b></col>, <cd>the science of duty; the science which treats
of the nature and condition of man as a moral being, of the duties which
result from his moral relations, and the reasons on which they are
founded.</cd> -- <col><b>Moral play</b></col>, <cd>an allegorical play;
a morality.</cd> <mark>[Obs.]</mark> -- <col><b>Moral sense</b></col>,
<cd>the power of moral judgment and feeling; the capacity to perceive
what is right or wrong in moral conduct, and to approve or disapprove,
independently of education or the knowledge of any positive rule or
law.</cd> -- <col><b>Moral theology</b></col>, <cd>theology applied to
morals; practical theology; casuistry.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moral</ent><br/
<hw>Mor"al</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
doctrine or practice of the duties of life; manner of living as regards
right and wrong; conduct; behavior; -- usually in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Corrupt in their <qex>morals</qex> as vice could make them.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The inner meaning or significance of a fable, a
narrative, an occurrence, an experience, etc.; the practical lesson
which anything is designed or fitted to teach; the doctrine meant to be
inculcated by a fiction; a maxim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus may we gather honey from the weed,<br/
And make a <qex>moral</qex> of the devil himself.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To point a <qex>moral</qex>, or adorn a tale.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We protest against the principle that the world of pure comedy is
one into which no <qex>moral</qex> enters.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A morality play. See <er>Morality</er>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moral</ent><br/
<hw>Mor"al</hw>, <pos>v. i.</pos> <def>To moralize.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morale</ent><br/
\'d8<hw>Mo`rale"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Moral</er>, <pos>a.</pos>]</ety> <def>The moral condition, or the
condition in other respects, so far as it is affected by, or dependent
upon, moral considerations, such as zeal, spirit, hope, and confidence;
mental state, as of a body of men, an army, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moraler</ent><br/
<hw>Mor"al*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A moralizer.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moralism</ent><br/
<hw>Mor"al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A maxim or saying
embodying a moral truth.</def> <rj><au>Farrar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>moralise</ent><br/
<hw>moralise</hw> <pos>v.</pos> <def>moralize.</def> <mark>[Chiefly
Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moralist</ent><br/
<hw>Mor"al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>moraliste</ets>.]</ety> <sn>1.</sn> <def>One who moralizes; one who
teaches or animadverts upon the duties of life; a writer of essays
intended to correct vice and inculcate moral duties.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who practices moral duties; a person who lives
in conformity with moral rules; one of correct deportment and dealings
with his fellow-creatures; -- sometimes used in contradistinction to one
whose life is controlled by religious motives.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The love (in the <qex>moralist</qex> of virtue, but in the
Christian) of God himself.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>moralistic</ent><br/
<hw>moralistic</hw> <pos>adj.</pos> <sn>1.</sn> <def>narrowly and
conventionally moral; -- of people.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>disposed to moralize{2}; -- of people.</def><br/
<syn><b>Syn. --</b> moralizing.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Morality</ent><br/
<hw>Mo*ral"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Moralities</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>moralitas</ets>:
cf. F. <ets>moralit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The relation
of conformity or nonconformity to the moral standard or rule; quality of
an intention, a character, an action, a principle, or a sentiment, when
tried by the standard of right.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>morality</qex> of an action is founded in the freedom of
that principle, by virtue of which it is in the agent's power, having
all things ready and requisite to the performance of an action, either
to perform or not perform it.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of an action which renders it good; the
conformity of an act to the accepted standard of right.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of <qex>moralitee</qex> he was the flower.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am bold to think that <qex>morality</qex> is capable of
demonstration.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The doctrines or rules of moral duties, or the
duties of men in their social character; ethics.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The end of <qex>morality</qex> is to procure the affections to
obey reason, and not to invade it.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The system of <qex>morality</qex> to be gathered out of . . .
ancient sages falls very short of that delivered in the gospel.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The practice of the moral duties; rectitude of life;
conformity to the standard of right; virtue; <as>as, we often admire the
politeness of men whose <ex>morality</ex> we question</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A kind of allegorical play, so termed because it
consisted of discourses in praise of morality between actors
representing such characters as Charity, Faith, Death, Vice, etc. Such
plays were occasionally exhibited as late as the reign of <person>Henry
VIII.</person></def> <rj><au>Strutt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Intent; meaning; moral.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Taketh the <qex>morality</qex> thereof, good men.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moralization</ent><br/
<hw>Mor`al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>moralisation</ets>.]</ety> <sn>1.</sn> <def>The act of moralizing;
moral reflections or discourse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Explanation in a moral sense.</def> <rj><au>T.
Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 944 --></p>

<p><ent>Moralize</ent><br/
<hw>Mor"al*ize</hw> <pr>(m<ocr/r"<ait/l*<imac/z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Moralized</conjf>
<pr>(m<ocr/r"<ait/l*<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Moralizing</conjf>
<pr>(m<ocr/r"<ait/l*<imac/*z<icr/ng)</pr>.]</vmorph> <ety>[Cf. F.
<ets>moraliser</ets>.]</ety> <sn>1.</sn> <def>To apply to a moral
purpose; to explain in a moral sense; to draw a moral from.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This fable is <qex>moralized</qex> in a common proverb.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Did he not <qex>moralize</qex> this spectacle?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with moral lessons, teachings, or
examples; to lend a moral to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While chastening thoughts of sweetest use, bestowed<br/
By Wisdom, <qex>moralize</qex> his pensive road.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render moral; to correct the morals of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It had a large share in <qex>moralizing</qex> the poor white
people of the country.</q> <rj><qau>D. Ramsay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give a moral quality to; to affect the moral
quality of, either for better or worse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Good and bad stars <qex>moralize</qex> not our actions.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moralize</ent><br/
<hw>Mor"al*ize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
make moral reflections; to regard acts and events as involving a
moral.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to lecture to a person in a manner asserting moral
principles.</def><br/
<syn><b>Syn. --</b> sermonize, preachify, moralise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moralizer</ent><br/
<hw>Mor"al*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
moralizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morally</ent><br/
<hw>Mor"al*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a moral or
ethical sense; according to the rules of morality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By good, good <qex>morally</qex> so called, <ldquo/bonum
honestum<rdquo/ ought chiefly to be understood.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>According to moral rules; virtuously.</def>
<ldquo/To live <xex>morally</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In moral qualities; in disposition and character;
<as>as, one who physically and <ex>morally</ex> endures
hardships</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In a manner calculated to serve as the basis of
action; according to the usual course of things and human judgment;
according to reason and probability.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is <qex>morally</qex> impossible for an hypocrite to keep
himself long upon his guard.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>morals</ent><br/
<hw>morals</hw> <pos>n.</pos> <def>motivation based on ideas of right
and wrong.</def><br/
<syn><b>Syn. --</b> ethical motive, ethics, morality.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Morass</ent><br/
<hw>Mo*rass"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>marras</ets>, <ets>mareis</ets> (perh. through D.
<ets>moeras</ets>), fr. F. <ets>marais</ets>, prob. from L.
<ets>mare</ets> sea, in LL., any body of water; but perh. influenced by
some German word. See <er>Mere</er> a lake, and cf.
<er>Marsh</er>.]</ety> <def>A tract of soft, wet ground; a marsh; a
fen.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Morass ore</b></col>. <fld>(Min.)</fld> <cd>See <cref>Bog
ore</cref>, under <er>Bog</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>morassy</ent><br/
<hw>mo*rass"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Marshy; fenny.</def>
<mark>[R.]</mark> <rj><au>Pennant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morate</ent><br/
<hw>Mo"rate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
salt of moric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moration</ent><br/
<hw>Mo*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>moratio</ets>.]</ety> <def>A delaying tarrying; delay.</def>
<mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moratorium</ent><br/
\'d8<hw>Mor`a*to"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Moratory</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld> <def>A period
during which an obligor has a legal right to delay meeting an
obligation, esp. such a period granted, as to a bank, by a moratory
law.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>a suspension of an activity.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>an officially authorized period of delay or waiting;
<as>as, a <ex>moratorium</ex> on putting a law into
effect</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moratory</ent><br/
<hw>Mor"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>moratorius</ets> delaying, fr. <ets>morari</ets> to delay.]</ety>
<def>Of or pertaining to delay; esp., designating a law passed, as in a
time of financial panic, to postpone or delay for a period the time at
which notes, bills of exchange, and other obligations, shall mature or
become due.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moravian</ent><br/
<hw>Mo*ra"vi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Moravia, or to the United Brethren. See <er>Moravian</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moravian</ent><br/
<hw>Mo*ra"vi*an</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One of
a religious sect called the <membof>United Brethren</membof> (an
offshoot of the Hussites in Bohemia), which formed a separate church of
Moravia, a northern district of Austria, about the middle of the 15th
century. After being nearly extirpated by persecution, the society,
under the name of <membof>The Renewed Church of the United
Brethren</membof>, was reestablished in 1722-35 on the estates of
<person>Count Zinzendorf</person> in Saxony. Called also
<altname>Herrnhuter</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moravianism</ent><br/
<hw>Mo*ra"vi*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The religious
system of the Moravians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moray</ent><br/
<hw>Mor"ay</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
muraena.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbid</ent><br/
<hw>Mor"bid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>morbidus</ets>, fr. <ets>morbus</ets> disease; prob. akin to
<ets>mori</ets> to die: cf. F. <ets>morbide</ets>, It.
<ets>morbido</ets>. See <er>Mortal</er>.]</ety> <sn>1.</sn> <def>Not
sound and healthful; induced by a diseased or abnormal condition;
diseased; sickly; <as>as, a <ex>morbid</ex> condition; a <ex>morbid</ex>
constitution; a <ex>morbid</ex> state of the juices of a
plant.</as></def> <ldquo/Her sick and <xex>morbid</xex> heart.<rdquo/
<rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to disease or diseased parts;
<as>as, <ex>morbid</ex> anatomy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Indicating an unhealthy mental attitude or
disposition; especially, abnormally gloomy, to an extent not justified
by the situation; preoccupied with death, disease, or fear of death;
<as>as, a <ex>morbid</ex> interest in details of a
disaster</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Gruesome; <as>as, a <ex>morbid</ex>
topic</as>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Diseased; sickly; sick.</syn> <usage> --
<er>Morbid</er>, <er>Diseased</er>. <xex>Morbid</xex> is sometimes used
interchangeably with <xex>diseased</xex>, but is commonly applied, in a
somewhat technical sense, to cases of a prolonged nature; <as>as, a
<ex>morbid</ex> condition of the nervous system</as>; a
<xex>morbid</xex> sensibility, etc.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbidezza</ent><br/
\'d8<hw>Mor`bi*dez"za</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.,
softness, delicacy. See <er>Morbid</er>.]</ety> <sn>1.</sn> <fld>(Fine
Arts)</fld> <def>Delicacy or softness in the representation of
flesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A term used as a direction in
execution, signifying, with extreme delicacy.</def>
<rj><au>Ludden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbidity</ent><br/
<hw>Mor*bid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
quality or state of being morbid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Morbid quality; disease; sickness.</def> <rj><au>C.
Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Amount of disease; rate of sickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbidly</ent><br/
<hw>Mor"bid*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a morbid
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbidness</ent><br/
<hw>Mor"bid*ness</hw>, <pos>n.</pos> <def>The quality or state of being
morbid; morbidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbifical</ent><br/
<ent>Morbific</ent><br/
<mhw>{ <hw>Mor*bif"ic</hw> <pr>(?)</pr>, <hw>Mor*bif"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>morbus</ets> disease +
<ets>-ficare</ets> (in comp.) to make: cf. F. <ets>morbifique</ets>. See
<er>-fy</er>.]</ety> <def>Causing disease; generating a sickly state;
<as>as, a <ex>morbific</ex> matter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbillous</ent><br/
<hw>Mor*bil"lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>morbilli</ets> measles, dim. of L. <ets>morbus</ets> disease: cf.
F. <ets>morbilleux</ets>.]</ety> <def>Pertaining to the measles;
partaking of the nature of measels, or resembling the eruptions of that
disease; measly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbose</ent><br/
<hw>Mor*bose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>morbosus</ets>, fr. <ets>morbus</ets> disease.]</ety>
<def>Proceeding from disease; morbid; unhealthy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Morbose</qex> tumors and excrescences of plants.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morbosity</ent><br/
<hw>Mor*bos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>morbositas</ets>.]</ety> <def>A diseased state;
unhealthiness.</def> <mark>[R.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morceau</ent><br/
\'d8<hw>Mor`ceau"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A bit; a morsel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordacious</ent><br/
<hw>Mor*da"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mordax</ets>, <ets>-acis</ets>, fr. <ets>mordere</ets>,
<ets>morsum</ets>, to bite. See <er>Morsel</er>.]</ety> <def>Biting;
given to biting; hence, figuratively, sarcastic; severe; scathing.</def>
-- <wordforms><wf>Mor*da"cious*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordacity</ent><br/
<hw>Mor*dac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mordacitas</ets>: cf. F. <ets>mordacit<eacute/</ets>. See
<er>Mordacious</er>.]</ety> <def>The quality of being mordacious; biting
severity, or sarcastic quality.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordant</ent><br/
<hw>Mor"dant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., p. pr. of
<ets>mordere</ets> to bite; L. <ets>mordere</ets>. See
<er>Morsel</er>.]</ety> <sn>1.</sn> <def>Biting; caustic; sarcastic;
keen; severe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Dyeing & Calico Printing)</fld> <def>Serving to fix
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordant</ent><br/
<hw>Mor"dant</hw>, <pos>n.</pos> <ety>[F., originally, biting.]</ety>
<sn>1.</sn> <def>Any corroding substance used in etching.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Dyeing & Calico Printing)</fld> <def>Any substance,
as alum or copperas, which, having a twofold attraction for organic
fibers and coloring matter, serves as a bond of union, and thus gives
fixity to, or <xex>bites in</xex>, the dyes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gilding)</fld> <def>Any sticky matter by which the
gold leaf is made to adhere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordant</ent><br/
<hw>Mor"dant</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mordanted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mordanting</conjf>.]</vmorph> <def>To subject to the action of,
or imbue with, a mordant; <as>as, to <ex>mordant</ex> goods for
dyeing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordantly</ent><br/
<hw>Mor"dant*ly</hw>, <pos>adv.</pos> <def>In the manner of a
mordant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordente</ent><br/
\'d8<hw>Mor*den"te</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>An embellishment resembling a trill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordicancy</ent><br/
<hw>Mor"di*can*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A biting
quality; corrosiveness.</def> <mark>[R.]</mark>
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordicant</ent><br/
<hw>Mor"di*cant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mordicans</ets>, p. pr. of <ets>mordicare</ets> to bite, fr.
<ets>mordere</ets>: cf. F. <ets>mordicant</ets>.]</ety> <def>Biting;
acrid; <as>as, the <ex>mordicant</ex> quality of a body</as>.</def>
<mark>[R.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordication</ent><br/
<hw>Mor`di*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mordicatio</ets>.]</ety> <def>The act of biting or corroding;
corrosion.</def> <mark>[R.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mordicative</ent><br/
<hw>Mor"di*ca*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mordicativus</ets>.]</ety> <def>Biting; corrosive.</def>
<mark>[R.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>More</ent><br/
<hw>More</hw> <pr>(m<omac/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>m<omac/r</ets>. See <er>Moor</er> a waste.]</ety> <def>A
hill.</def> <mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>More</ent><br/
<hw>More</hw>, <pos>n.</pos> <ety>[AS. <ets>more</ets>, <ets>moru</ets>;
akin to G. <ets>m<oum/hre</ets> carrot, OHG. <ets>moraha</ets>,
<ets>morha</ets>.]</ety> <def>A root.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>More</ent><br/
<hw>More</hw>, <pos>a., compar.</pos> <amorph>[<it>Positive
wanting</it>; <pos>superl.</pos> <adjf>Most</adjf>
<pr>(m<omac/st)</pr>.]</amorph> <ety>[OE. <ets>more</ets>,
<ets>mare</ets>, and (orig. neut. and adv.) <ets>mo</ets>,
<ets>ma</ets>, AS. <ets>m<amac/ra</ets>, and (as neut. and adv.)
<ets>m<amac/</ets>; akin to D. <ets>meer</ets>, OS. <ets>m<emac/r</ets>,
G. <ets>mehr</ets>, OHG. <ets>m<emac/ro</ets>, <ets>m<emac/r</ets>,
Icel. <ets>meiri</ets>, <ets>meirr</ets>, Dan. <ets>meere</ets>,
<ets>meer</ets>, Sw. <ets>mera</ets>, <ets>mer</ets>, Goth.
<ets>maiza</ets>, a., <ets>mais</ets>, adv., and perh. to L.
<ets>major</ets> greater, compar. of <ets>magnus</ets> great, and
<ets>magis</ets>, adv., more. <root/103. Cf. <er>Most</er>,
<er>uch</er>, <er>Major</er>.]</ety> <sn>1.</sn> <def>Greater; superior;
increased;</def> <specif>as:</specif> <sd>(a)</sd> <def>Greater in
quality, amount, degree, quality, and the like; with the
singular.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He gat <qex>more</qex> money.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If we procure not to ourselves <qex>more</qex> woe.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>More</xex>, in this sense, was formerly used in
connection with some other qualifying word, -- <xex>a</xex>,
<xex>the</xex>, <xex>this</xex>, <xex>their</xex>, etc., -- which now
requires the substitution of <xex>greater</xex>, <xex>further</xex>, or
the like, for <xex>more</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Whilst sisters nine, which dwell on Parnasse height,<br/
Do make them music for their <qex>more</qex> delight.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>more</qex> part knew not wherefore they were come
together.</q> <rj><qau>Acts xix. 32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wrong not that wrong with a <qex>more</qex> contempt.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Greater in number; exceeding in numbers; -- with
the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The people of the children of Israel are <qex>more</qex> and
mightier than we.</q> <rj><qau>Ex. i. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Additional; other; <as>as, he wept because there
were no <ex>more</ex> worlds to conquer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With open arms received one poet <qex>more</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>More</ent><br/
<hw>More</hw>, <pos>n.</pos> <sn>1.</sn> <def>A greater quantity,
amount, or number; that which exceeds or surpasses in any way what it is
compared with.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the children of Israel did so, and gathered, some
<qex>more</qex>, some less.</q> <rj><qau>Ex. xvi. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is in addition; something other and
further; an additional or greater amount.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They that would have <qex>more</qex> and <qex>more</qex> can never
have enough.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O! That pang where <qex>more</qex> than madness lies.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Any more</b></col>. <sd>(a)</sd> <cd>Anything or
something additional or further; <as>as, I do not need <ex>any
more</ex></as>.</cd> <sd>(b)</sd> <mark>Adverbially:</mark> <cd>Further;
beyond a certain time; <as>as, do not think <ex>any more</ex> about
it</as>.</cd> -- <col><b>No more</b></col>, <cd>not anything more;
nothing in addition.</cd> -- <col><b>The more and less</b></col>,
<cd>the high and low.</cd> <mark>[Obs.]</mark> <au>Shak.</au> <ldquo/All
cried, both <xex>less and more</xex>.<rdquo/ <au>Chaucer.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>More</ent><br/
<hw>More</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a greater quantity;
in or to a greater extent or degree.</def> <sd>(a)</sd> <def>With a verb
or participle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Admiring <qex>more</qex><br/
The riches of Heaven's pavement.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>With an adjective or adverb (instead of the suffix
<xex>-er</xex>) to form the comparative degree; <as>as, <ex>more</ex>
durable; <ex>more</ex> active; <ex>more</ex> sweetly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Happy here, and <qex>more</qex> happy hereafter.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ Double comparatives were common among writers of the
Elizabeth period, and for some time later; as, <xex>more</xex> brighter;
<xex>more</xex> dearer.<br/
[<source>1913 Webster</source>]</p>

<p><q>The duke of Milan<br/
And his <qex>more</qex> braver daughter.</q> <rj><qau>Shak.</qau></rj>
<br/
[<source>1913 Webster</source>]</p></note>

<p><sn>2.</sn> <def>In addition; further; besides; again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet once <qex>more</qex>, O ye laurels, and once
<qex>more</qex>,<br/
Ye myrtles brown, with ivy never sere,<br/
I come to pluck your berries harsh and crude.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>More and more</b></col>, <cd>with continual
increase.</cd> <ldquo/Amon trespassed <xex>more and more</xex>.<rdquo/
<au>2 Chron. xxxiii. 23.</au> -- <col><b>The more</b></col>, <cd>to a
greater degree; by an added quantity; for a reason already
specified.</cd> -- <col><b>The more -- the more</b></col>, <cd>by how
much more -- by so much more.</cd> <ldquo/<xex>The more</xex> he praised
it in himself, <xex>the more</xex> he seems to suspect that in very deed
it was not in him.<rdquo/ <au>Milton.</au> -- <col><b>To be no
more</b></col>, <cd>to have ceased to be; <as>as, Cassius <ex>is no
more</ex>; Troy <ex>is no more</ex></as>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Those oracles which set the world in flames,<br/
Nor ceased to burn till kingdoms were <qex>no more</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>More</ent><br/
<hw>More</hw>, <pos>v. t.</pos> <def>To make more; to increase.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>moreen</ent><br/
<hw>mo*reen"</hw> <pr>(m<osl/*r<emac/n")</pr>, <pos>n.</pos> <ety>[Cf.
<er>Mohair</er>.]</ety> <def>A thick woolen fabric, watered or with
embossed figures; -- used in upholstery, for curtains, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>morel</ent><br/
<hw>mor"el</hw> <pr>(m<ocr/r"<ecr/l)</pr>, <pos>n.</pos> <ety>[See
<er>moril</er>.]</ety> <fld>(Bot.)</fld> <def>An edible fungus
(<spn>Morchella esculenta</spn>), the upper part of which is covered
with a reticulated and pitted hymenium. It is used as food, and for
flavoring sauces.</def> <altsp>[Written also
<asp>moril</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>morel</ent><br/
<hw>mor"el</hw>, <pos>n.</pos> <ety>[See <er>morelle</er>.]</ety>
<fld>(Bot.)</fld> <sn>1.</sn> <def>Nightshade; -- so called from its
blackish purple berries.</def> <altsp>[Written also
<asp>morelle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of cherry. See <er>Morello</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Great morel</b></col>, <cd>the deadly nightshade.</cd> --
<col><b>Petty morel</b></col>, <cd>the black nightshade. See
<er>Nightshade</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>moreland</ent><br/
<hw>more"land</hw> <pr>(m<ocr/r"l<acr/nd)</pr>, <pos>n.</pos>
<def>Moorland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morelle</ent><br/
<hw>Mo*relle"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., orig. fem. of
<ets>moreau</ets> black, OF. <ets>morel</ets>, fr. LL.
<ets>morellus</ets>. Cf. <er>Morello</er>, <er>Murrey</er>.]</ety>
<fld>(Bot.)</fld> <def>Nightshade. See 2d <er>Morel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morello</ent><br/
<hw>Mo*rel"lo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>morello</ets> blackish, OF. <ets>morel</ets>. Cf.
<er>Morelle</er>.]</ety> <fld>(Bot.)</fld> <def>A kind of nearly black
cherry with dark red flesh and juice, -- used chiefly for
preserving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morendo</ent><br/
\'d8<hw>Mo*ren"do</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Dying; a gradual decrescendo at the end of a
strain or cadence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moreness</ent><br/
<hw>More"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Greatness.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moreover</ent><br/
<hw>More*o"ver</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[<ets>More</ets>
+ <ets>over</ets>.]</ety> <def>Beyond what has been said; further;
besides; in addition; furthermore; also; likewise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Moreover</qex>, he hath left you all his walks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Besides</er>, <er>Moreover</er>.</syn>
<usage> Of the two words, <xex>moreover</xex> is the stronger and is
properly used in solemn discourse, or when what is added is important to
be considered. See <er>Besides</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morepork</ent><br/
<hw>More"pork`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So named from its
cry.]</ety> <fld>(Zool.)</fld> <def>The Australian crested goatsucker
(<spn>Aegotheles Novae-Hollandiae</spn>). Also applied to other allied
birds, as <spn>Podargus Cuveiri</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mores</ent><br/
\'d8<hw>Mo"res</hw> <pr>(m<omac/"r<emac/z)</pr>, <pos>n. pl.</pos>;
<sing><it>sing.</it> <singw>Mos</singw> <pr>(m<omac/s)</pr></sing>.
<ety>[L.]</ety> <def>Customs; habits; esp., moral customs conformity to
which is more or less obligatory; customary law.</def> <mark>[singular
is rarely used]</mark> <br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Moresk</ent><br/
<hw>Mo*resk"</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>Moresque.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moresque</ent><br/
<hw>Mo*resque"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. It.
<ets>moresco</ets>, or Sp. <ets>morisco</ets>. See
<er>Morris</er>.]</ety> <def>Of or pertaining to, or in the manner or
style of, the Moors; Moorish.</def> -- <def2><pos>n.</pos> <def>The
Moresque style of architecture or decoration. See <cref>Moorish
architecture</cref>, under <er>Moorish</er>.</def></def2>
<altsp>[Written also <asp>mauresque</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morgan</ent><br/
<hw>Mor"gan</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One
of a celebrated breed of small compact American saddle and trotting
horses; -- so called from the name of the stud (Justin Morgan) from
which the breed originated in Vermont.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Morgan</ent><br/
<hw>Morgan</hw> <pos>prop. n.</pos> <def><person>John Pierpont
Morgan</person>, a noted American financier and philanthropist;
1837-1913.</def><br/
<syn><b>Syn. --</b> <person>J. P. Morgan</person>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Morganatic</ent><br/
<hw>Mor`ga*nat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>matrimonium ad morganaticam</ets>, fr. <ets>morganatica</ets> a
morning gift, a kind of dowry paid on the morning before or after the
marriage, fr. OHG. <ets>morgan</ets> morning, in <ets>morgangeba</ets>
morning gift, G. <ets>morgengabe</ets>. See <er>Morn</er>.]</ety>
<def>Pertaining to, in the manner of, or designating, a kind of
marriage, called also <altname>left-handed marriage</altname>, between a
man of superior rank and a woman of inferior, in which it is stipulated
that neither the latter nor her children shall enjoy the rank or inherit
the possessions of her husband.</def> <au>Brande & C.</au> --
<wordforms><wf>Mor`ga*nat"ic*al*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morgay</ent><br/
<hw>Mor"gay</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W. <ets>morgi</ets>
dogfish, shark; <ets>mor</ets> sea + <ets>ci</ets> dog.]</ety>
<fld>(Zool.)</fld> <def>The European small-spotted dogfish, or
houndfish. See the Note under <er>Houndfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morglay</ent><br/
<hw>Mor"glay</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Claymore</er>.]</ety> <def>A sword.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morgue</ent><br/
<hw>Morgue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <sn>1.</sn>
<def>A place where the bodies of dead persons are kept, until they are
identified, or claimed by their friends; a deadhouse.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Newspapers)</fld> <def>A room containing reference
files of older material in a newspaper office; also, the material
contained in such a room.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moria</ent><br/
\'d8<hw>Mo"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
folly.]</ety> <def>Idiocy; imbecility; fatuity; foolishness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morian</ent><br/
<hw>Mo"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Ethnol.)</fld>
<def>A Moor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In vain the Turks and <qex>Morians</qex> armed be.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moribund</ent><br/
<hw>Mor"i*bund</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>moribundus</ets>, from <ets>moriri</ets> to die. See
<er>Mortal</er>.]</ety> <def>In a dying state; dying; at the point of
death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The patient was comatose and <qex>moribund</qex>.</q>
<rj><qau>Copland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moribund</ent><br/
<hw>Mor"i*bund</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dying
person.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moric</ent><br/
<hw>Mo"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
derived from, fustic (see <er>Morin</er>); <as>as, <ex>moric</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morice</ent><br/
<hw>Mor"ice</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Morisco</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morigerate</ent><br/
<hw>Mo*rig"er*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>morigeratus</ets>, p. p. of <ets>morigerari</ets> to comply with.
See <er>Morigerous</er>.]</ety> <def>Obedient.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morigeration</ent><br/
<hw>Mo*rig`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>morigeratio</ets>.]</ety> <def>Obsequiousness; obedience.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morigerous</ent><br/
<hw>Mo*rig"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>morigerus</ets>; <ets>mos</ets>, <ets>moris</ets>, custom, manner +
<ets>gerere</ets> to bear, conduct.]</ety> <def>Obedient;
obsequious.</def> <mark>[Obs.]</mark> <rj><au>Brathwait.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moril</ent><br/
<hw>Mor"il</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>morille</ets>;
cf. OHG. <ets>morhila</ets>, G. <ets>morchel</ets>, OHG.
<ets>morha</ets> carrot. See <er>More</er> a root.]</ety>
<fld>(Bot.)</fld> <def>An edible fungus. Same as 1st
<er>Morel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morin</ent><br/
<hw>Mo"rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
yellow crystalline substance (<chform>C15H10O7</chform>) of acid
properties extracted from <prodby>fustic</prodby> (<spn>Chlorophora
tinctoria</spn> syn. <spn>Maclura tinctoria</spn>, formerly called
<altname>Morus tinctoria</altname>); -- called also <altname>moric
acid</altname> and <altname>natural yellow 8</altname>. It is used as a
dye for wool, giving a color from lemon yellow through olive to olive
brown, depending on the metal with which it is mordanted.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Morinda</ent><br/
<hw>Mo*rin"da</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus of rubiaceous trees and shrubs, mostly East Indian, many species
of which yield valuable red and yellow dyes. The wood is hard and
beautiful, and used for gunstocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>morindin</ent><br/
<hw>mo*rin"din</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A yellow dyestuff (<chform>C27H30O14</chform>) extracted from the
root bark of an East Indian plant (<spn>Morinda citrifolia</spn>) or
from the bark of <spn>Coprosma australis</spn>. The substance is also
found in the fruit of the <spn>Morinda citrifolia</spn>, called
<prodby>noni</prodby>, which is touted by some merchants to have a
stimulatory effect on the immune system. It is a disaccharide derivative
of anthracenedione.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Morinel</ent><br/
<hw>Mor"i*nel`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>morinelle</ets>.]</ety> <fld>(Zool.)</fld> <def>The
dotterel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moringa</ent><br/
<hw>Mo*rin"ga</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[Malayam
<ets>murunggi</ets>.]</ety> <fld>(Bot.)</fld> <def>A genus of trees of
Southern India and Northern Africa. One species (<spn>Moringa
pterygosperma</spn>) is the horse-radish tree, and its seeds, as well as
those of <spn>Moringa aptera</spn>, are known in commerce as
<prod>ben</prod> or <prod>ben nuts</prod>, and yield the oil called
<prod>oil of ben</prod>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moringic</ent><br/
<hw>Mo*rin"gic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Designating an organic acid obtained from oil of ben. See
<er>Moringa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morintannic</ent><br/
<hw>Mo`rin*tan"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>Morus</ets> fustic + E. <ets>tannic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, a variety of
tannic acid extracted from fustic (<spn>Chlorophora tinctoria</spn>,
formerly <spn>Maclura tinctoria</spn> and <spn>Morus tinctoria</spn>) as
a yellow crystalline substance; -- called also
<altname>maclurin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morion</ent><br/
<hw>Mo"ri*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>morion</ets>, Sp. <ets>morrion</ets>; cf. Sp. <ets>morra</ets> the
upper part of the head, <ets>morro</ets> anything that is round.]</ety>
<def>A kind of open helmet, without visor or beaver, and somewhat
resembling a hat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A battered <qex>morion</qex> on his brow.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morion</ent><br/
<hw>Mo"ri*on</hw>, <pos>n.</pos> <ety>[G.]</ety> <fld>(Min.)</fld>
<def>A dark variety of smoky quartz.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morioplasty</ent><br/
<hw>Mo"ri*o*plas`ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ piece
(dim. of <?/ a part + <ets>-plasty</ets>.]</ety> <fld>(Surg.)</fld>
<def>The restoration of lost parts of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 945 --></p>

<p><ent>Morisco</ent><br/
<hw>Mo*ris"co</hw> <pr>(m<osl/*r<icr/s"k<osl/)</pr>, <pos>a.</pos>
<ety>[Sp. See <er>Morris</er> the dance.]</ety> <def>Moresque.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morisco</ent><br/
<hw>Mo*ris"co</hw>, <pos>n.</pos> <ety>[Sp. <ets>morisco</ets>
Moorish.]</ety> <def>A thing of Moorish origin;</def> as: <sd>(a)</sd>
<def>The Moorish language.</def> <sd>(b)</sd> <def>A Moorish dance, now
called <altname>morris dance</altname>.</def> <au>Marston</au>.
<sd>(c)</sd> <def>One who dances the Moorish dance.</def> <au>Shak</au>.
<sd>(d)</sd> <def>Moresque decoration or architecture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morisk</ent><br/
<hw>Mo"risk</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Morisco</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morkin</ent><br/
<hw>Mor"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Akin to Sw.
<ets>murken</ets> putrefied, Icel. <ets>morkinn</ets> putrid.]</ety>
<def>A beast that has died of disease or by mischance.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morland</ent><br/
<hw>Mor"land</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Moorland.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morling</ent><br/
<hw>Mor"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mort</ets> dead, L. <ets>mortuus</ets>, fr. <ets>moriri</ets> to
die.]</ety> <def>Mortling.</def> <mark>[Eng.]</mark>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormal</ent><br/
<hw>Mor"mal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mort-mai</ets> a deadly evil. <ets>Nares</ets>.]</ety> <def>A bad
sore; a gangrene; a cancer.</def> <mark>[Obs.]</mark> <altsp>[Written
also <asp>morrimal</asp> and <asp>mortmal</asp>.]</altsp>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormo</ent><br/
<hw>Mor"mo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>mormw`</grk>
a hideous she-monster, a bugbear.]</ety> <def>A bugbear; false
terror.</def> <mark>[Obs.]</mark> <rj><au>Jonhson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormon</ent><br/
\'d8<hw>Mor"mon</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL., fr.
Gr. <grk>mormw`n</grk> monster, bugbear.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A genus of sea birds, having a large, thick bill; the
puffin.</def> <sd>(b)</sd> <def>The mandrill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormon</ent><br/
<hw>Mor"mon</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Eccl.)</fld>
<def>One of a Christian denomination (<membof>The Church of Jesus Christ
of Latter-day Saints</membof>) in the United States, followers of
<person>Joseph Smith</person>, who professed to have found an addition
to the Bible, engraved on golden plates, called the <col><it>Book of
Mormon</it></col>, first published in 1830. The Mormons believe in
polygamy, and their hierarchy of apostles, etc., has control of civil
and religious matters.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ The Mormons call their religious organization
<membof>The Church of Jesus Christ of Latter-day Saints</membof>. Its
head claims to receive revelations of God's will, and to have certain
supernatural powers. The church headquarters are in <city>Salt Lake
City</city>, Utah. They form a substantial fraction of the population of
Utah, and at the end of the 20th centrury their numbers were increasing
due to active proselytization.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mormon</ent><br/
<hw>Mor"mon</hw>, <pos>n.</pos> <fld>(Eccl.)</fld> <def>A member of a
sect, called the <membof>Reorganized Church of Jesus of Latterday
Saints</membof>, which has always rejected polygamy. It was organized in
1852, and is represented in about forty States and Territories of the
United States.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mormon</ent><br/
<hw>Mor"mon</hw>, <pos>a.</pos> <def>Of or pertaining to the Mormons;
<as>as, the <ex>Mormon</ex> religion; <ex>Mormon</ex>
practices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormondom</ent><br/
<hw>Mor"mon*dom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The country
inhabited by the Mormons; the Mormon people.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormonism</ent><br/
<hw>Mor"mon*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The doctrine,
system, and practices of the Mormons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mormonite</ent><br/
<hw>Mor"mon*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Mormon.</def> --
<def2><pos>a.</pos> <def>Mormon.</def> <ldquo/<xex>Mormonite</xex>
religion.<rdquo/</def2> <rj><au>F. W. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morn</ent><br/
<hw>Morn</hw> <pr>(m<ocir/rn)</pr>, <pos>n.</pos> <ety>[OE.
<ets>morwen</ets>, <ets>morgen</ets>, AS. <ets>morgen</ets>; akin to D.
<ets>morgen</ets>, OS. <ets>morgan</ets>, G. <ets>morgen</ets>, Icel.
<ets>morginn</ets>, <ets>morgunn</ets>, Sw. <ets>morgon</ets>, Dan.
<ets>morgen</ets>, Goth. <ets>ma<uacute/rgins</ets>. Cf.
<er>Morrow</er>, <er>Morning</er>.]</ety> <def>The first part of the
day; the morning; -- used chiefly in poetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From <qex>morn</qex><br/
To noon he fell, from noon to dewy eve.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morne</ent><br/
<hw>Mor"ne</hw> <pr>(m<ocir/r"n<eit/)</pr>, <pos>a.</pos> <def>Of or
pertaining to the morn; morning.</def> <mark>[Obs.]</mark> <ldquo/White
as <xex>morne</xex> milk.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morne</ent><br/
\'d8<hw>Morne</hw> <pr>(m<ocir/rn)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>morne</ets> sad, sorrowful. See <er>Mourn</er>.]</ety> <def>A ring
fitted upon the head of a lance to prevent wounding an adversary in
tilting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morne</ent><br/
\'d8<hw>Mor`n<eacute/"</hw> <pr>(m<ocir/r`n<asl/")</pr>, <pos>a.</pos>
<ety>[F., fr. <ets>morne</ets> a morne.]</ety> <fld>(Her.)</fld>
<def>Without teeth, tongue, or claws; -- said of a lion represented
heraldically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morning</ent><br/
<hw>Morn"ing</hw> <pr>(m<ocir/rn"<icr/ng)</pr>, <pos>n.</pos> <ety>[OE.
<ets>morning</ets>, <ets>morwening</ets>. See <er>Morn</er>.]</ety>
<sn>1.</sn> <def>The first or early part of the day, variously
understood as the earliest hours of light, the time near sunrise; the
time from midnight to noon, from rising to noon, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The first or early part; <as>as, the
<ex>morning</ex> of life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The goddess Aurora.</def> <mark>[Poetic]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morning</ent><br/
<hw>Morn"ing</hw>, <pos>a.</pos> <def>Pertaining to the first part or
early part of the day; being in the early part of the day; <as>as,
<ex>morning</ex> dew; <ex>morning</ex> light; <ex>morning</ex>
service.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>She looks as clear<br/
As <qex>morning</qex> roses newly washed with dew.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Morning gown</b></col>, <cd>a gown worn in the morning
before one is dressed for the day.</cd> -- <col><b>Morning
gun</b></col>, <cd>a gun fired at the first stroke of reveille at
military posts.</cd> -- <col><b>Morning sickness</b></col>
<fld>(Med.)</fld>, <cd>nausea and vomiting, usually occurring in the
morning; -- a common sign of pregnancy.</cd> -- <col><b>Morning
star</b></col>. <sd>(a)</sd> <cd>Any one of the planets (Venus, Jupiter,
Mars, or Saturn) when it precedes the sun in rising, esp. Venus. Cf.
<cref>Evening star</cref>, <er>Evening</er>.</cd> <sd>(b)</sd>
<cd>Satan. See <er>Lucifer</er>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Since he miscalled the <qex>morning star</qex>,<br/
Nor man nor fiend hath fallen so far.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <cd>A weapon consisting of a heavy ball set with spikes,
either attached to a staff or suspended from one by a chain.</cd> --
<col><b>Morning watch</b></col> <fld>(Naut.)</fld>, <cd>the watch
between four <sc>a. m.</sc> and eight <sc>a. m.</sc>.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Morning-glory</ent><br/
<ent>Morning glory</ent><br/
<hw>Morn"ing-glo`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A climbing plant (<spn>Ipomoea purpurea</spn>) having handsome,
funnel-shaped flowers, usually red, pink, purple, white, or variegated,
sometimes pale blue. See <er>Dextrorsal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morningtide</ent><br/
<hw>Morn"ing*tide`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Morning
time.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mornward</ent><br/
<hw>Morn"ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Towards the
morn.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>mornward</qex> now the starry hands move on.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moro</ent><br/
<hw>Mo"ro</hw> <pr>(m<omac/"r<osl/)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>mora</ets> mulberry, L. <ets>morum</ets>.]</ety> <fld>(Med.)</fld>
<def>A small abscess or tumor having a resemblance to a mulberry.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moro</ent><br/
<hw>Mo"ro</hw> <pr>(m<omac/"r<osl/)</pr>, <pos>prop. n.</pos>;
<plu><it>pl.</it> <plw>Moros</plw> <pr>(m<omac/"r<osl/s)</pr></plu>.
<ety>[Sp., moor. See <er>moor</er>, <pos>n.</pos> and
<er>Moros</er>.]</ety> <sn>1.</sn> <fld>(Ethnol.)</fld> <def>A member of
any of the <er>Moros</er>, a group one of various tribes of the southern
Phillippine Islands, mostly Malays adhering to Islam.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Linguistics)</fld> <def>Any of the languages of the
Moro people, of the Austronesian language family.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moroccan</ent><br/
<hw>Mo*roc"can</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Morocco, or its inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morocco</ent><br/
<hw>Mo*roc"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named from
<ets>Morocco</ets>, the country. Cf. <er>Morris</er> the dance.]</ety>
<def>A fine kind of leather, prepared commonly from goatskin (though an
inferior kind is made of sheepskin), and tanned with sumac and dyed of
various colors; -- said to have been first made by the Moors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morology</ent><br/
<hw>Mo*rol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mwrologi`a</grk> foolish talk, <grk>mw^ros</grk> foolish +
<grk>lo`gos</grk> discourse.]</ety> <def>Foolish talk; nonsense;
folly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moron</ent><br/
<hw>Mo"ron</hw> <pr>(m<omac/"r<ocr/n)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mw^ros</grk> foolish, stupid.]</ety> <sn>1.</sn>
<fld>(Pedagogy)</fld> <def>A mentally retarded person whose intellectual
development proceeds normally up to about the eighth year of age and is
then arrested so that there is little or no further development; an
adult having the mental development of an 8-to-12-year old. A
<ex>moron</ex> is considered capable of doing routine work under
supervision.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Hence, a very stupid person.</def> <mark>[informal,
derogatory]</mark> <br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>mo*ron"ic</wf> <pos>adj.</pos> --
<wf>mo*ron"ic*al*ly</wf> <pos>adv.</pos> -- <wf>mo"ron*ism</wf>
<pos>n.</pos> -- <wf>mo*ron"i*ty</wf> <pos>n.</pos></wordforms></p>

<p><ent>Moron</ent><br/
<hw>Mo*ron"</hw> <pr>(m<osl/*r<omac/n")</pr>, <pos>n.</pos>;
<plu><it>Sp. pl.</it> <plw>Morones</plw> <pr>(#)</pr></plu>.
<ety>[Sp.]</ety> <def>An inferior olive size having a woody pulp and a
large clingstone pit, growing in the mountainous and high-valley
districts around the city of <etsep>Moron</etsep>, in Spain.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Morone</ent><br/
<hw>Mo*rone"</hw> <pr>(m<osl/*r<omac/n")</pr>, <pos>n.</pos>
<def>Maroon; the color of an unripe black mulberry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moronic</ent><br/
<hw>moronic</hw> <pos>adj.</pos> <def>having a mental age of between
eight and twelve years; also used as a derogatory term.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moros</ent><br/
<hw>Mo"ros</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing><it>sing.</it>
<singw>Moro</singw> <pr>(<?/)</pr></sing>. <ety>[Sp., pl. of
<ets>Moro</ets> Moor.]</ety> <fld>(Ethnol.)</fld> <def>The Muslim tribes
of the southern Philippine Islands, said to have formerly migrated from
Borneo. Some of them are warlike and addicted to piracy.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Morosaurus</ent><br/
\'d8<hw>Mo`ro*sau"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>mw^ros</grk> stupid + <grk>sau^ros</grk> lizard.]</ety>
<fld>(Paleon.)</fld> <def>An extinct genus of large herbivorous
dinosaurs, found in Jurassic strata in America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morose</ent><br/
<hw>Mo*rose"</hw> <pr>(m<osl/*r<omac/s")</pr>, <pos>a.</pos> <ety>[L.
<ets>morosus</ets>, prop., excessively addicted to any particular way or
habit, fr. <ets>mos</ets>, <ets>moris</ets>, manner, habit, way of life:
cf. F. <ets>morose</ets>.]</ety> <sn>1.</sn> <def>Of a sour temper;
sullen and austere; ill-humored; severe.</def> <ldquo/A
<xex>morose</xex> and affected taciturnity.<rdquo/ <rj><au>I.
Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lascivious; brooding over evil thoughts.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Sullen; gruff; severe; austere; gloomy; crabbed;
crusty; churlish; surly; ill-humored.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morosely</ent><br/
<hw>Mo*rose"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Sourly; with
sullen austerity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moroseness</ent><br/
<hw>Mo*rose"ness</hw>, <pos>n.</pos> <def>Sourness of temper;
sulenness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Learn good humor, never to oppose without just reason; abate some
degrees of pride and <qex>moroseness</qex>.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Moroseness</xex> is not precisely
<xex>peevishness</xex> or <xex>fretfulness</xex>, though often
accompanied with it. It denotes more of silence and severity, or
ill-humor, than the irritability or irritation which characterizes
<xex>peevishness</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morosis</ent><br/
\'d8<hw>Mo*ro"sis</hw> <pr>(m<osl/*r<omac/"s<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>mw`rwsis</grk>, fr. <grk>mw^ros</grk> silly,
foolish.]</ety> <fld>(Med.)</fld> <def>Idiocy; fatuity;
stupidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morosity</ent><br/
<hw>Mo*ros"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>morositas</ets>: cf. F. <ets>morosit<eacute/</ets>.]</ety>
<def>Moroseness.</def> <mark>[R.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morosoph</ent><br/
<hw>Mo"ro*soph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>mwro`s</grk> foolish + <grk>sofo`s</grk> wise. See also
<er>sophomore</er>.]</ety> <def>A philosophical or learned fool.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morosous</ent><br/
<hw>Mo*ro"sous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Morose.</def>
<mark>[Obs.]</mark> <rj><au>Sheldon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moroxite</ent><br/
<hw>Mo*rox"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Gr. <?/, <?/,
a sort of pipe clay.]</ety> <fld>(Min.)</fld> <def>A variety of apatite
of a greenish blue color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moroxylate</ent><br/
<hw>Mo*rox"y*late</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A morate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moroxylic</ent><br/
<hw>Mor`ox*yl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>morus</ets> a mulberry tree + Gr. <?/ wood.]</ety>
<fld>(Chem.)</fld> <def>Of, pertaining to, or derived from, the
mulberry; moric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphean</ent><br/
<hw>Mor"phe*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or relating to
<persfn>Morpheus</persfn>, to dreams, or to sleep.</def>
<rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>morph</ent><br/
<hw>morph</hw> <pr>(m<ocir/rf)</pr>, <pos>n.</pos>
<fld>(Linguistics)</fld> <def>A sequence of phonemes, often a word
fragment, which constitutes the minimum unit of meaning or syntax within
a given word. A morph may be one of several variants of a morpheme,
depending for its individal form on the context in which it occurs. Thus
the <ex>morphs</ex> <examp>-s</examp> and <examp>-es</examp> are
variants of the morpheme by which the plural form of an English noun is
expressed.</def><br/
[<source>PJC</source>]</p>

<p><ent>morph</ent><br/
<hw>morph</hw> <pr>(m<ocir/rf)</pr>, <pos>v. i. & t.</pos> <def>To
transform smoothly in imperceptible steps from one image to another, on
a computer screen.</def><br/
[<source>PJC</source>]</p>

<p><ent>morpheme</ent><br/
<hw>mor"pheme</hw> <pr>(m<ocir/r"f<emac/m)</pr>, <pos>n.</pos>
<fld>(Linguistics)</fld> <def>The smallest unit of meaning of a
language, which cannot be divided into smaller parts carrying meaning;
it is usually smaller than a single wordform, such as the
<examp>-ed</examp> morpheme of verbs in the past tense or the
<examp>-s</examp> morpheme of nouns in the plural form.</def><br/
[<source>PJC</source>]</p>

<p><ent>morphemic</ent><br/
<hw>mor*phem"ic</hw> <pr>(m<ocir/r*f<emac/m"<icr/k)</pr>, <pos>a.</pos>
<fld>(Linguistics)</fld> <def>Of or pertaining to a morpheme.</def><br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>mor*phem"ic*al*ly</wf>,
<pos>adv.</pos></wordforms></p>

<p><ent>morphemics</ent><br/
<hw>mor*phem"ics</hw> <pr>(m<ocir/r*f<emac/m"<icr/ks)</pr>,
<pos>n.</pos> <fld>(Linguistics)</fld> <def>The study of the types and
functions of morphemes; morphology{4}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Morpheus</ent><br/
<hw>Mor"pheus</hw> <pr>(m<ocir/r"f<umac/s <it>or</it>
m<ocir/r"f<esl/*<ucr/s)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>Morfey`s</grk> prop., the fashioner or molder, because of the
shapes he calls up before the sleeper, fr. <grk>morfh`</grk> form,
shape.]</ety> <fld>(Class. Myth.)</fld> <def>The god of
dreams.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphew</ent><br/
<hw>Mor"phew</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>morphe<eacute/</ets>, LL. <ets>morphea</ets>; cf. It.
<ets>morfea</ets>.]</ety> <def>A scurfy eruption.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphew</ent><br/
<hw>Mor"phew</hw>, <pos>v. t.</pos> <def>To cover with a morphew.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphia</ent><br/
<hw>Mor"phi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Chem.)</fld> <def>Morphine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphine</ent><br/
<hw>Mor"phine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Morpheus: cf.
F. <ets>morphine</ets>.]</ety> <fld>(Chem.)</fld> <def>A bitter white
crystalline alkaloid found in opium, possessing strong narcotic
properties, and much used as an anodyne; -- called also
<altname>morphia</altname>, and <altname>morphina</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>morphing</ent><br/
<hw>morph"ing</hw> <pr>(m<ocir/rf"<icr/ng)</pr>, <pos>n.</pos>
<fld>(Computers)</fld> <def>The smooth transformation of one shape or
image into another, displayed on the computer screen as a series of
images that appear to be continuous, as if in a movie.</def><br/
[<source>PJC</source>]</p>

<p><ent>morphinism</ent><br/
<hw>mor"phin*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>A morbid condition produced by the excessive or prolonged use of
morphine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>morpho</ent><br/
\'d8<hw>mor"pho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/,
an epithet of Venus.]</ety> <fld>(Zool.)</fld> <def>Any one of numerous
species of large, handsome, tropical American butterflies, of the genus
<gen>Morpho</gen>. They are noted for the very brilliant metallic luster
and bright colors (often blue) of the upper surface of the wings. The
lower surface is usually brown or gray, with eyelike spots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>morphogenesis</ent><br/
<hw>mor`pho*gen"e*sis</hw> <fld>(Biol.)</fld> <def>The development of
the tissues and organs of an organism; the formation of structural
features of an organism.</def><br/
[<source>PJC</source>]</p>

<p><ent>morphogenetic</ent><br/
<hw>mor`pho*ge*net"ic</hw> <fld>(Biol.)</fld> <def>Of or pertaining to
morphogenesis; concerned with the process of development of the normal
features of an organism.</def><br/
[<source>PJC</source>]</p>

<p><ent>Morphogeny</ent><br/
<hw>Mor*phog"e*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>form</ets>
+ root of <grk>gi`gnesqai</grk> to be born.]</ety> <fld>(Biol.)</fld>
<def>History of the evolution of forms; that part of ontogeny that deals
with the germ history of forms; -- distinguished from
<contr>physiogeny</contr>.</def> <rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphological</ent><br/
<ent>Morphologic</ent><br/
<mhw>{ <hw>Mor`pho*log"ic</hw> <pr>(?)</pr>, <hw>Mor`pho*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>morphologique</ets>.]</ety> <fld>(Biol.)</fld> <def>Of, pertaining
to, or according to, the principles of morphology.</def> --
<wordforms><wf>Mor`pho*log"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphologist</ent><br/
<hw>Mor*phol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>One who is versed in the science of morphology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphology</ent><br/
<hw>Mor*phol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>morfh`</grk> form + <ets>-logy</ets>: cf. F.
<ets>morphologie</ets>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>That
branch of biology which deals with the structure of animals and plants,
treating of the forms of organs and describing their varieties,
homologies, and metamorphoses. See <er>Tectology</er>, and
<er>Promorphology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The form and structure of an
organism.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Linguistics)</fld> <def>The branch of linguistics
which studies the patterns by which words are formed from other words,
including inflection, compounding, and derivation.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Specifically:</specif> <def>The study of the
patterns of inflection of words or word classes in any given language;
the study of the patterns in which morphemes combine to form words, and
the rules for combination; morphemics; <as>as, the <ex>morphology</ex>
of Spanish verbs</as>; also, the inflection patterns
themselves.</def><br/
[<source>PJC</source>]</p>

<p><ent>Morphon</ent><br/
<hw>Mor"phon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, p. pr. of
<?/ to form.]</ety> <fld>(Biol.)</fld> <def>A morphological individual,
characterized by definiteness of form, in distinction from
<contr>bion</contr>, a physiological individual. See
<er>Tectology</er>.</def> <rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Of morphons there are six orders or categories: 1.
<stype>Plastids</stype> or elementary organisms. 2.
<stype>Organs</stype>, homoplastic or heteroplastic. 3.
<stype>Antimeres</stype> (opposite or symmetrical or homotypic parts).
4. <stype>Metameres</stype> (successive or homodynamous parts). 5.
<stype>Personae</stype> (shoots or buds of plants, individuals in the
narrowest sense among the higher animals). 6. <stype>Corms</stype>
(stocks or colonies). For orders 2, 3, and 4 the term <xex>idorgan</xex>
has been recently substituted. See <er>Idorgan</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphonomy</ent><br/
<hw>Mor*phon"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>morfh`</grk> form + <?/ a law.]</ety> <fld>(Biol.)</fld> <def>The
laws of organic formation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphophyly</ent><br/
<hw>Mor"pho*phy`ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>morfh`</grk> form + <?/ a clan.]</ety> <fld>(Biol.)</fld> <def>The
tribal history of forms; that part of phylogeny which treats of the
tribal history of forms, in distinction from the tribal history of
functions.</def> <rj><au>Haeckel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphosis</ent><br/
\'d8<hw>Mor*pho"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>mo`rfwsis</grk> form, fr. <grk>morfh`</grk> form.]</ety>
<fld>(Biol.)</fld> <def>The order or mode of development of an organ or
part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morphotic</ent><br/
<hw>Mor*phot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ fit for
forming.]</ety> <fld>(Physiol.)</fld> <def>Connected with, or becoming
an integral part of, a living unit or of the morphological framework;
<as>as, <ex>morphotic</ex>, or tissue, proteids</as>.</def>
<rj><au>Foster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-morphous</ent><br/
<hw>-mor"phous</hw> <pr>(?)</pr>. <ety>[Gr. <grk>morfh`</grk>
form.]</ety> <def>A combining form denoting <sig>form</sig>,
<sig>shape</sig>; <as>as, iso<ex>morphous</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morpion</ent><br/
<hw>Mor"pi*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>mordre</ets> to bite + L. <ets>pedis</ets> louse.]</ety>
<fld>(Zool.)</fld> <def>A louse.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morrice</ent><br/
<hw>Mor"rice</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as 1st
<er>Morris</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morrice</ent><br/
<hw>Mor"rice</hw>, <pos>a.</pos> <def>Dancing the morrice;
dancing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In shoals and bands, a <qex>morrice</qex> train.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morricer</ent><br/
<hw>Mor"ri*cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A morris
dancer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morrimal</ent><br/
<hw>Mor"ri*mal</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>See
<er>Mormal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morris</ent><br/
<hw>Mor"ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>morisco</ets> Moorish, fr. <ets>Moro</ets> a Moor: cf. F.
<ets>moresque</ets>, It. <ets>moresca</ets>.]</ety> <sn>1.</sn> <def>A
Moorish dance, usually performed by a single dancer, who accompanies the
dance with castanets.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dance formerly common in England, often performed
in pagenats, processions, and May games. The dancers, grotesquely
dressed and ornamented, took the parts of Robin Hood, Maidmarian, and
other fictitious characters.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An old game played with counters, or men, which are
placed at the angles of a figure drawn on a board or on the ground;
also, the board or ground on which the game is played.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The nine-men's <qex>morris</qex> is filled up with mud.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The figure consists of three concentric squares, with
lines from the angles of the outer one to those of the inner, and from
the middle of each side of the outer square to that of the inner. The
game is played by two persons with nine or twelve pieces each (hence
called <xex>nine-men's morris</xex> or <xex>twelve-men's morris</xex>).
The pieces are placed alternately, and each player endeavors to prevent
his opponent from making a straight row of three. Should either succeed
in making a row, he may take up one of his opponent's pieces, and he who
takes off all of his opponent's pieces wins the game.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morris</ent><br/
<hw>Mor"ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from its
discoverer.]</ety> <fld>(Zool.)</fld> <def>A marine fish having a very
slender, flat, transparent body. It is now generally believed to be the
young of the conger eel or some allied fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morris-chair</ent><br/
<hw>Mor"ris-chair`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr. the
proper name <ets>Morris</ets>.]</ety> <def>A kind of easy-chair with a
back which may be lowered or raised.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Morris-pike</ent><br/
<hw>Mor"ris-pike`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Moorish
pike.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morro</ent><br/
\'d8<hw>Mor"ro</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., any spherical
object.]</ety> <def>A round hill or point of land; hence, <col><b>Morro
castle</b></col>, a castle on a hill.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Morrot</ent><br/
<hw>Mor"rot</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Marrot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morrow</ent><br/
<hw>Mor"row</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>morwe</ets>,
<ets>morwen</ets>, AS. <ets>morgen</ets>. See <er>Morn</er>.]</ety>
<sn>1.</sn> <def>Morning.</def> <mark>[Obs.]</mark> <ldquo/White as
<xex>morrow's</xex> milk.<rdquo/ <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We loved he by the <qex>morwe</qex> a sop in wine.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The next following day; the day subsequent to any
day specified or understood.</def> <rj><au>Lev. vii. 16.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Till this stormy night is gone,<br/
And the eternal <qex>morrow</qex> dawn.</q>
<rj><qau>Crashaw.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The day following the present; to-morrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Good morrow</b></col>, <cd>good morning; -- a form of
salutation.</cd> -- <col><b>To morrow</b></col>. <cd>See
<er>To-morrow</er> in the Vocabulary.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morse</ent><br/
<hw>Morse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>morse</ets>,
Russ. <ets>morj'</ets>; perh. akin to E. <ets>mere</ets> lake; cf. Russ.
<ets>more</ets> sea.]</ety> <fld>(Zool.)</fld> <def>The walrus. See
<er>Walrus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morse</ent><br/
<hw>Morse</hw>, <pos>n.</pos> <ety>[L. <ets>morsus</ets> a biting, a
clasp, fr. <ets>mordere</ets> to bite.]</ety> <def>A clasp for fastening
garments in front.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morse alphabet</ent><br/
<hw>Morse" al"pha*bet</hw> <pr>(?)</pr>. <def>same as <er>Morse
code</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morse code</ent><br/
<hw>Morse" code"</hw> <pr>(?)</pr>. <fld>(Teleg.)</fld> <def>a
telegraphic code, in which dots, dashes, and spaces represent letters,
numbers, and other elements of text. The original code was invented by
<person>Samuel B. <etsep>Morse</etsep></person>. The code now mostly
used is the <stype>International Morse code</stype>, also referred to
simply as the <ex>Morse code</ex>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<note><p>The present International Morse Code is given in the table
below. There are no spaces in the <stype>International Morse
Code</stype>.<br/
<br/
<pre><tt><er>Alphabet</er><br/
----------------------------------------------------------<br/
A .-          H ....       O ---          V ...-<br/
B -...        I ..         P .--.         W .--<br/
C _._.        J .---       Q --.-         X -..-<br/
D -..         K -.-        R .-.          Y -.--<br/
E .           L .-..       S ...          Z --..<br/
F ..-.        M --         T -<br/
G --.         N -.         U ..-<br/
<br/
<er>Numerals</er><br/
<br/
1 .----       4 ....-          7 --...<br/
2 ..---       5 .....          8 ---..<br/
3 ...--       6 -....          9 ----.<br/
0 -----
<br/
<er>Punctuation</er><br/
<br/
 . (Period)            .-.-.-    , (Comma)             --..--<br/
 ? (Question Mark)     ..--..    ; (Semicolon)         -.-.-.
 : (Colon)             ---...    ' (apostrophe)        .----.
 - (hyphen)            -....-    / (forward slash)     -..-.
 ( (left parenthesis)  -.--.     ) (right parenthesis) -.--.-
----------------------------------------------------------------<br/
</tt></pre></p>

<p>The Alphabetic code which was originally in use in North America is
given in the table below. In length, or duration, one dash is
theoretically equal to three dots; the space between the elements of a
letter is equal to one dot; the interval in spaced letters, as O . ., is
equal to three dots. There are no spaces in any letter composed wholly
or in part of dashes.</p>

<p><pre><tt><er>Alphabet</er><br/
<br/
A .-          H ....       O . .          V ...-<br/
B - . . .     I ..         P .....        W .--<br/
C .. .        J -.-.       Q ..-.         X .-..<br/
D -..         K -.-        R . ..         Y .. ..<br/
E .           L <mdash/    S ...          Z ... .<br/
F .-.         M --         T --           & . ...<br/
G --.         N -.         U ..-<br/
<br/
<er>Numerals</er><br/
<br/
1 .--.        4 . . . .-          7 --..<br/
2 ..-..       5 ---               8 - . . . .<br/
3 . . . -.    6 . . . . . .       9 -..-<br/
0 ----     Period ..--..   Comma .-.-<br/
</tt></pre></p>

<p>The Morse code was used chiefly with the electric telegraph, but is
also employed in signalling with flags, lights, etc.<br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>
</note>

<p><ent>Morsel</ent><br/
<hw>Mor"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>morsel</ets>, F. <ets>morceau</ets>, LL. <ets>morsellus</ets>, a
dim. fr. L. <ets>morsus</ets> a biting, bite, fr. <ets>mordere</ets> to
bite; prob. akin to E. <ets>smart</ets>. See <er>Smart</er>, and cf.
<er>Morceau</er>, <er>Mordant</er>, <er>Muse</er>, <pos>v.</pos>,
<er>Muzzle</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>A little bite or
bit of food.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every <qex>morsel</qex> to a satisfied hunger is only a new labor
to a tired digestion.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small quantity; a little piece; a
fragment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morsing horn</ent><br/
<hw>Mor"sing horn`</hw> <pr>(?)</pr>. <def>A horn or flask for holding
powder, as for priming.</def> <mark>[Scot.]</mark> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morsitation</ent><br/
<hw>Mor`si*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
biting or gnawing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morsure</ent><br/
<hw>Mor"sure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>mordere</ets>, <ets>morsum</ets>, to bite.]</ety> <def>The act of
biting.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mort</ent><br/
<hw>Mort</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>margt</ets>, neut. of <ets>margr</ets> many.]</ety> <def>A great
quantity or number.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There was a <qex>mort</qex> of merrymaking.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mort</ent><br/
<hw>Mort</hw>, <pos>n.</pos> <ety>[Etym. uncert.]</ety> <def>A woman; a
female.</def> <mark>[Cant, archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Male gypsies all, not a <qex>mort</qex> among them.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mort</ent><br/
<hw>Mort</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety>
<fld>(Zool.)</fld> <def>A salmon in its third year.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mort</ent><br/
<hw>Mort</hw>, <pos>n.</pos> <ety>[F., death, fr. L. <ets>mors</ets>,
<ets>mortis</ets>.]</ety> <sn>1.</sn> <def>Death; esp., the death of
game in the chase.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A note or series of notes sounded on a horn at the
death of game.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sportsman then sounded a treble <qex>mort</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The skin of a sheep or lamb that has died of
disease.</def> <mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mort cloth</b></col>, <cd>the pall spread over a coffin;
black cloth indicative or mourning; funeral hangings.</cd>
<au>Carlyle.</au> -- <col><b>Mort stone</b></col>, <cd>a large stone by
the wayside on which the bearers rest a coffin.</cd> <mark>[Eng.]</mark>
<au>H. Taylor.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mort</ent><br/
<hw>Mort</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>mort</ets>
dummy, lit., dead.]</ety> <def>A variety of dummy whist for three
players; also, the exposed or dummy hand in this game.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mortal</ent><br/
<hw>Mor"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>mortel</ets>,
L. <ets>mortalis</ets>, from <ets>mors</ets>, <ets>mortis</ets>, death,
fr. <ets>moriri</ets> 8die; akin to E. <ets>murder</ets>. See
<er>Murder</er>, and cf. <er>Filemot</er>, <er>Mere</er> a lake,
<er>Mortgage</er>.]</ety> <sn>1.</sn> <def>Subject to death; destined to
die; <as>as, man is <ex>mortal</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destructive to life; causing or occasioning death;
terminating life; exposing to or deserving death; deadly; <as>as, a
<ex>mortal</ex> wound; a <ex>mortal</ex> sin.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fatally vulnerable; vital.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Last of all, against himself he turns his sword, but missing the
<qex>mortal</qex> place, with his poniard finishes the work.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of or pertaining to the time of death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Safe in the hand of one disposing Power,<br/
Or in the natal or the <qex>mortal</qex> hour.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Affecting as if with power to kill;
deathly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The nymph grew pale, and in a <qex>mortal</qex> fright.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Human; belonging to man, who is mortal; <as>as,
<ex>mortal</ex> wit or knowledge; <ex>mortal</ex> power</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The voice of God<br/
To <qex>mortal</qex> ear is dreadful.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Very painful or tedious; wearisome; <as>as, a sermon
lasting two <ex>mortal</ex> hours</as>.</def> <mark>[Colloq.]</mark>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Mortal foe</b></col>, <col><b>Mortal
enemy</b></col></mcol>, <cd>an inveterate, desperate, or implacable
enemy; a foe bent on one's destruction.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortal</ent><br/
<hw>Mor"tal</hw>, <pos>n.</pos> <def>A being subject to death; a human
being; man.</def> <ldquo/Warn poor <xex>mortals</xex> left
behind.<rdquo/ <rj><au>Tickell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortality</ent><br/
<hw>Mor*tal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mortalitas</ets>: cf. F. <ets>mortalit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The condition or quality of being mortal; subjection to
death or to the necessity of dying.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When I saw her die,<br/
I then did think on your <qex>mortality</qex>.</q>
<rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 946 --></p>

<p><sn>2.</sn> <def>Human life; the life of a mortal being.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From this instant<br/
There 's nothing serious in <qex>mortality</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Those who are, or that which is, mortal; the human
race; humanity; human nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Take these tears, <qex>mortality's</qex> relief.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Death; destruction.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The whole sum or number of deaths in a given time or
a given community; also, the proportion of deaths to population, or to a
specific number of the population; death rate; <as>as, a time of great,
or low, <ex>mortality</ex>; the <ex>mortality</ex> among the settlers
was alarming.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bill of mortality</b></col>. <cd>See under
<er>Bill</er>.</cd> -- <col><b>Law of mortality</b></col>, <cd>a
mathematical relation between the numbers living at different ages, so
that from a given large number of persons alive at one age, it can be
computed what number are likely to survive a given number of years.</cd>
-- <col><b>Table of mortality</b></col>, <cd>a table exhibiting the
average relative number of persons who survive, or who have died, at the
end of each year of life, out of a given number supposed to have been
born at the same time.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortalize</ent><br/
<hw>Mor"tal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mortalized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mortalizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To make
mortal.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortally</ent><br/
<hw>Mor"tal*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a mortal
manner; so as to cause death; <as>as, <ex>mortally</ex>
wounded</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In the manner of a mortal or of mortal
beings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was <qex>mortally</qex> brought forth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In an extreme degree; to the point of dying or
causing death; desperately; <as>as, <ex>mortally</ex>
jealous</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adrian <qex>mortally</qex> envied poets, painters, and artificers,
in works wherein he had a vein to excel.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortalness</ent><br/
<hw>Mor"tal*ness</hw>, <pos>n.</pos> <def>Quality of being mortal;
mortality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortar</ent><br/
<hw>Mor"tar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>morter</ets>, AS. <ets>mort<emac/re</ets>, L. <ets>mortarium</ets>:
cf. F. <ets>mortier</ets> mortar. Cf. sense 2 (below), also 2d
<er>Mortar</er>, <er>Martel</er>, <er>Morter</er>.]</ety> <sn>1.</sn>
<def>A strong vessel, commonly in form of an inverted bell, in which
substances are pounded or rubbed with a pestle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F. <ets>mortier</ets>, fr. L. <ets>mortarium</ets>
mortar (for trituarating).]</ety> <fld>(Mil.)</fld> <def>A short piece
of ordnance, used for throwing bombs, carcasses, shells, etc., at high
angles of elevation, as 45<deg/, and even higher; -- so named from its
resemblance in shape to the utensil above described.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mortar bed</b></col> <fld>(Mil.)</fld>, <cd>a framework
of wood and iron, suitably hollowed out to receive the breech and
trunnions of a mortar.</cd> -- <mcol><col><b>Mortar boat</b></col>
<it>or</it> <col><b>Mortar vessel</b></col></mcol> <fld>(Naut.)</fld>,
<cd>a boat strongly built and adapted to carrying a mortar or mortars
for bombarding; a bomb ketch.</cd> -- <col><b>Mortar piece</b></col>,
<cd>a mortar.</cd> <mark>[Obs.]</mark> <au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortar</ent><br/
<hw>Mor"tar</hw>, <pos>n.</pos> <ety>[OE. <ets>mortier</ets>, F.
<ets>mortier</ets>, L. <ets>mortarium</ets> mortar, a large basin or
trough in which mortar is made, a mortar (in sense 1, above). See 1st
<er>Mortar</er>.]</ety> <fld>(Arch.)</fld> <def>A building material made
by mixing lime, cement, or plaster of Paris, with sand, water, and
sometimes other materials; -- used in masonry for joining stones,
bricks, etc., also for plastering, and in other ways.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mortar bed</b></col>, <cd>a shallow box or receptacle in
which mortar is mixed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortar</ent><br/
<hw>Mor"tar</hw>, <pos>v. t.</pos> <def>To plaster or make fast with
mortar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortar</ent><br/
<hw>Mor"tar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mortier</ets>. See <er>Mortar</er> a vessel.]</ety> <def>A chamber
lamp or light.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mortar board</ent><br/
<ent>mortarboard</ent><br/
<mhw><hw>mortarboard</hw>, <hw>mortar board</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>A small square board with a handle beneath, for holding
mortar; a hawk; used by masons to hold or carry mortar.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An academic cap topped by broad, projecting, stiff
and flat square top, with a tassel attached to the top and hanging down.
It was once worn by students in some colleges, but is now worn usually
only at graduation ceremonies.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Mortgage</ent><br/
<hw>Mort"gage</hw> <pr>(m<ocir/r"g<asl/j; 48)</pr>, <pos>n.</pos>
<ety>[F. <ets>mort-gage</ets>; <ets>mort</ets> dead (L.
<ets>mortuus</ets>) + <ets>gage</ets> pledge. See <er>Mortal</er>, and
<er>Gage</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld> <def>A conveyance of
property, upon condition, as security for the payment of a debt or the
preformance of a duty, and to become void upon payment or performance
according to the stipulated terms; also, the written instrument by which
the conveyance is made.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It was called a <xex>mortgage</xex> (or <xex>dead
pledge</xex>) because, whatever profit it might yield, it did not
thereby redeem itself, but became lost or <xex>dead</xex> to the
mortgager upon breach of the condition. But in equity a <xex>right of
redemption</xex> is an inseparable incident of a mortgage until the
mortgager is debarred by his own laches, or by judicial decree.</note>
<rj><au>Cowell.</au> <au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>State of being pledged; <as>as, lands given in
<ex>mortgage</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chattel mortgage</b></col>. <cd>See under
<er>Chattel</er>.</cd> -- <col><b>To foreclose a mortgage</b></col>.
<cd>See under <er>Foreclose</er>.</cd> -- <col><b>Mortgage
deed</b></col> <fld>(Law)</fld>, <cd>a deed given by way of
mortgage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortgage</ent><br/
<hw>Mort"gage</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mortgaged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mortgaging</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<fld>(Law)</fld> <def>To grant or convey, as property, for the security
of a debt, or other engagement, upon a condition that if the debt or
engagement shall be discharged according to the contract, the conveyance
shall be void, otherwise to become absolute, subject, however, to the
right of redemption.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: To pledge, either literally or figuratively;
to make subject to a claim or obligation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mortgaging</qex> their lives to covetise.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I myself an <qex>mortgaged</qex> to thy will.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mortgaged</ent><br/
<hw>mortgaged</hw> <pos>adj.</pos> <def>burdened with legal or financial
obligations; <as>as, His house was <ex>mortgaged</ex> to the
hilt</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mortgagee</ent><br/
<hw>Mort`ga*gee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>The person to whom property is mortgaged, or to whom a mortgage is
made or given.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortgagor</ent><br/
<ent>Mortgageor</ent><br/
<mhw>{ <hw>Mort"gage*or</hw>, <hw>Mort"ga*gor</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Law)</fld> <def>One who gives a mortgage.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The letter <xex>e</xex> is required analogically after
the second <xex>g</xex> in order to soften it; but the spelling
<xex>mortgagor</xex> is in fact the prevailing form. When the word is
contradistinguished from <xex>mortgagee</xex> it is accented on the last
syllable <pr>(-j<ocir/r")</pr>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortgager</ent><br/
<hw>Mort"ga*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who gives a mortgage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortiferous</ent><br/
<hw>Mor"tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mortifier</ets>; <ets>mors</ets>, <ets>mortis</ets>, death +
<ets>ferre</ets> to bring: cf. F. <ets>mortif<egrave/re</ets>.]</ety>
<def>Bringing or producing death; deadly; destructive; <as>as, a
<ex>mortiferous</ex> herb</as>.</def> <rj><au>Gov. of
Tongue.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortification</ent><br/
<hw>Mor`ti*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>mortificatio</ets> a killing. See <er>Mortify</er>.]</ety>
<sn>1.</sn> <def>The act of mortifying, or the condition of being
mortified</def>; especially: <sd>(a)</sd> <fld>(Med.)</fld> <def>The
death of one part of an animal body, while the rest continues to live;
loss of vitality in some part of a living animal; gangrene.</def>
<au>Dunglison.</au> <sd>(b)</sd> <fld>(Alchem. & Old Chem.)</fld>
<def>Destruction of active qualities; neutralization.</def>
<mark>[Obs.]</mark> <au>Bacon.</au> <sd>(c)</sd> <def>Subjection of the
passions and appetites, by penance, abstinence, or painful severities
inflicted on the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mortification</qex> of our lusts has something in it that
is troublesome, yet nothing that is unreasonable.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deep humiliation or shame, from a loss of pride;
painful embarassment, usually arising from exposure of a mistake;
chagrin; vexation.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>That which mortifies; the cause of humiliation,
chagrin, or vexation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is one of the vexatious <qex>mortifications</qex> of a studious
man to have his thoughts discovered by a tedious visit.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Scots Law)</fld> <def>A gift to some charitable or
religious institution; -- nearly synonymous with
<altname>mortmain</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Chagrin; vexation; shame. See
<er>Chagrin</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortified</ent><br/
<hw>Mor"ti*fied</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Mortify</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mortified</ent><br/
<hw>mor"ti*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deeply embarrased;
painfully humiliated.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mortifiedness</ent><br/
<hw>Mor"ti*fied*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being mortified; humiliation; subjection of the passions.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortifier</ent><br/
<hw>Mor"ti*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, mortifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortify</ent><br/
<hw>Mor"ti*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mortified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mortifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>mortifien</ets>, F. <ets>mortifier</ets>, fr. L.
<ets>mortificare</ets>; L. <ets>mors</ets>, <ets>mortis</ets>, death +
<ets>-ficare</ets> (in comp.) to make. See <er>Mortal</er>, and
<er>-fy</er>.]</ety> <sn>1.</sn> <def>To destroy the organic texture and
vital functions of; to produce gangrene in.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To destroy the active powers or essential qualities
of; to change by chemical action.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Quicksilver is <qex>mortified</qex> with turpentine.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>mortified</qex> pearls in vinegar.</q>
<rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deaden by religious or other discipline, as the
carnal affections, bodily appetites, or worldly desires; to bring into
subjection; to abase; to humble; <as>as, to <ex>mortify</ex> the
flesh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With fasting <qex>mortified</qex>, worn out with tears.</q>
<rj><qau>Harte.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mortify</qex> thy learned lust.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mortify</qex>, therefore, your members which are upon the
earth.</q> <rj><qau>Col. iii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To affect with vexation, chagrin; to
depress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The news of the fatal battle of Worcester, which exceedingly
<qex>mortified</qex> our expectations.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How often is the ambitious man <qex>mortified</qex> with the very
praises he receives, if they do not rise so high as he thinks they
ought!</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To humiliate deeply, especially by injuring the
pride of; to embarrass painfully; to humble; <as>as, the team was
<ex>mortified</ex> to lose by 45 to 0</as>.</def><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Mortify</ent><br/
<hw>Mor"ti*fy</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To lose vitality
and organic structure, as flesh of a living body; to gangrene.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To practice penance from religious motives; to
deaden desires by religious discipline.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This makes him . . . give alms of all that he hath, watch, fast,
and <qex>mortify</qex>.</q> <rj><qau>Law.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be subdued; to decay, as appetites, desires,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortifying</ent><br/
<hw>Mor"ti*fy`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Tending to mortify; affected by, or having symptoms of,
mortification; <as>as, a <ex>mortifying</ex> wound; <ex>mortifying</ex>
flesh.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subduing the appetites, desires, etc.; <as>as,
<ex>mortifying</ex> penances</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tending to humble or abase; humiliating; <as>as, a
<ex>mortifying</ex> repulse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortifyingly</ent><br/
<hw>Mor"ti*fy`ing*ly</hw>, <pos>adv.</pos> <def>In a mortifying
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortise</ent><br/
<hw>Mor"tise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mortaise</ets>; cf. Sp. <ets>mortaja</ets>, Ar. <ets>murtazz</ets>
fixed, or W. <ets>mortais</ets>, Ir. <ets>mortis</ets>,
<ets>moirtis</ets>, Gael. <ets>moirteis</ets>.]</ety> <def>A cavity cut
into a piece of timber, or other material, to receive something (as the
end of another piece) made to fit it, and called a
<inv>tenon</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mortise and tenon</b></col> <fld>(Carp.)</fld>, <cd>made
with a mortise and tenon; joined or united by means of a mortise and
tenon; -- used adjectively.</cd> -- <col><b>Mortise joint</b></col>,
<cd>a joint made by a mortise and tenon.</cd> -- <col><b>Mortise
lock</b></col>. <cd>See under <er>Lock</er>.</cd> -- <col><b>Mortise
wheel</b></col>, <cd>a cast-iron wheel, with wooden clogs inserted in
mortises on its face or edge; -- also called <altname>mortise
gear</altname>, and <altname>core gear</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortise</ent><br/
<hw>Mor"tise</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mortised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mortising</conjf>.]</vmorph> <sn>1.</sn> <def>To cut or make a
mortise in.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To join or fasten by a tenon and mortise; <as>as, to
<ex>mortise</ex> a beam into a post, or a joist into a
girder</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortling</ent><br/
<hw>Mort"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Morling</er>.]</ety> <sn>1.</sn> <def>An animal, as a sheep, dead of
disease or privation; a morling.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wool plucked from a dead sheep; morling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortmain</ent><br/
<hw>Mort"main`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mort</ets>, <ets>morte</ets>, dead + <ets>main</ets> hand; F.
<ets>main-morte</ets>. See <er>Mortal</er>, and <er>Manual</er>.]</ety>
<fld>(Law)</fld> <def>Possession of lands or tenements in, or conveyance
to, dead hands, or hands that cannot alienate.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term was originally applied to conveyance of land
made to ecclesiastical bodies; afterward to conveyance made to
<xex>any</xex> corporate body.</note> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortmal</ent><br/
<hw>Mort"mal</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mormal</er>.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortpay</ent><br/
<hw>Mort"pay`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>mort</ets>
dead + E. <ets>pay</ets>.]</ety> <def>Dead pay; the crime of taking pay
for the service of dead soldiers, or for services not actually rendered
by soldiers.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortrew</ent><br/
<ent>Mortress</ent><br/
<mhw>{ <hw>Mor"tress</hw> <pr>(?)</pr>, <hw>Mor"trew</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[See <er>Mortar</er>.]</ety> <def>A dish of
meats and other ingredients, cooked together; an ollapodrida.</def>
<rj><au>Chaucer.</au> <au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mortuary</ent><br/
<hw>Mor"tu*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mortuaries</plw> <pr>(#)</pr>.</plu> <ety>[LL.
<ets>mortuarium</ets>. See <er>Mortuary</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>A sort of ecclesiastical heriot, a customary gift
claimed by, and due to, the minister of a parish on the death of a
parishioner. It seems to have been originally a voluntary bequest or
donation, intended to make amends for any failure in the payment of
tithes of which the deceased had been guilty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A burial place; a place for the dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place for the reception of the dead before burial;
a deadhouse; a morgue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A <er>funeral home</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mortuary</ent><br/
<hw>Mor"tu*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mortuarius</ets>, fr. <ets>mortuus</ets> dead: cf. F.
<ets>mortuaire</ets>. See <er>Mortal</er>.]</ety> <def>Of or pertaining
to the dead; <as>as, <ex>mortuary</ex> monuments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mortuary urn</b></col>, <cd>an urn for holding the ashes
of a dead person after cremation.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morula</ent><br/
\'d8<hw>Mor"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Morulae</plw> <pr>(#)</pr>.</plu> <ety>[NL., dim. of L.
<ets>morum</ets> a mulberry.]</ety> <fld>(Biol.)</fld> <def>The sphere
or globular mass of cells (<parts>blastomeres</parts>), formed by the
clevage of the ovum or egg in the first stages of its development; --
called also <altname>mulberry mass</altname>, <altname>segmentation
sphere</altname>, and <altname>blastosphere</altname>. See
<er>Segmentation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morulation</ent><br/
<hw>Mor`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>The process of cleavage, or segmentation, of the ovum, by which a
morula is formed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morus</ent><br/
\'d8<hw>Mo"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., mulberry tree.
See <er>Mulberry</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of trees,
some species of which produce edible fruit; the mulberry. See
<er>Mulberry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <col><b>Morus alba</b></col> is the white mulberry, a
native of India or China, the leaves of which are extensively used for
feeding silkworms, for which it furnishes the chief food. --
<col><b>Morus multicaulis</b></col>, the many-stemmed or Chinese
mulberry, is only a form of white mulberry, preferred on account of its
more abundant leaves. -- <col><b>Morus nigra</b></col>, the black
mulberry, produces a dark-colored fruit, of an agreeable
flavor.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morwe</ent><br/
<hw>Mor"we</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Morrow</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Morwening</ent><br/
<hw>Mor"wen*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Morning.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mos</ent><br/
<hw>Mos</hw> <pr>(?)</pr>, <pos>n.</pos>, <def><pos>sing.</pos> of
<er>Mores</er>.</def> <mark>[Rare]</mark> <br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Mosaic</ent><br/
<hw>Mo*sa"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mosa<ium/que</ets>; cf. Pr. <ets>mozaic</ets>, <ets>musec</ets>,
Sp. & Pg. <ets>mosaico</ets>, It. <ets>mosaico</ets>,
<ets>musaico</ets>, LGr. <?/, <?/, L. <ets>musivum</ets>; all fr. Gr.
<?/ belonging to the Muses. See <er>Muse</er> the goddess.]</ety>
<sn>1.</sn> <fld>(Fine Arts)</fld> <def>A surface decoration made by
inlaying in patterns small pieces of variously colored glass, stone, or
other material; -- called also <altname>mosaic work</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A picture or design made in mosaic; an article
decorated in mosaic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something resembling a mosaic{1}; something made up
of different pieces, fitted together by design to form a unified
composition.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>aerial mosaic</b></col> <cd>An aerial photograph of a
large area, made by carefully fitting together aerial photographs of
smaller areas so that the edges match in location, and the whole
provides a continuous image of the larger area. Called also
<col><b>mosaic map</b></col> and <altname>photomosaic</altname>.</cd> --
<col><b>mosaic virus</b></col> <cd>A type of plant virus that causes
green and yellow mottling of leaves of a plant. A much-studied type is
the <stype>tobacco mosaic virus</stype>, affecting the tobacco
plant.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Mosaic</ent><br/
<hw>Mo*sa"ic</hw>, <pos>a.</pos> <def>Of or pertaining to the style of
work called mosaic; formed by uniting pieces of different colors;
variegated; tessellated; also, composed of various materials or
ingredients.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A very beautiful <qex>mosaic</qex> pavement.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Florentine mosaic</b></col>. <cd>See under
<er>Florentine</er>.</cd> -- <col><b>Mosaic gold</b></col>. <sd>(a)</sd>
<cd>See <er>Ormolu</er>.</cd> <sd>(b)</sd> <cd>Stannic sulphide,
<chform>SnS2</chform>, obtained as a yellow scaly crystalline powder,
and used as a pigment in bronzing and gilding wood and metal work. It
was called by the alchemists <altname>aurum musivum</altname>, or
<altname>aurum mosaicum</altname>. Called also <altname>bronze
powder</altname>.</cd> -- <col><b>Mosaic work</b></col>. <cd>See
<er>Mosaic</er>, <pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosaic</ent><br/
<hw>Mo*sa"ic</hw>, <pos>prop. a.</pos> <ety>[From
<etsep>Moses</etsep>.]</ety> <def>Of or pertaining to
<persfn>Moses</persfn>, the leader of the <grp>Israelites</grp>, or
established through his agency; <as>as, the <ex>Mosaic</ex> law, rites,
or institutions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosaical</ent><br/
<hw>Mo*sa"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mosaic (in either
sense).</def> <ldquo/A <xex>mosaical</xex> floor.<rdquo/ <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosaically</ent><br/
<hw>Mo*sa"ic*al*ly</hw>, <pos>adv.</pos> <def>In the manner of a
mosaic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosaism</ent><br/
<hw>Mo"sa*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Attachment to the
system or doctrines of Moses; that which is peculiar to the Mosaic
system or doctrines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosasaurian</ent><br/
<ent>Mosasaur</ent><br/
<mhw>{ <hw>Mos"a*saur</hw> <pr>(?)</pr>, <hw>Mos`a*sau"ri*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Paleon.)</fld> <def>One of an
extinct order of reptiles, including <gen>Mosasaurus</gen> and allied
genera. See <er>Mosasauria</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosasauria</ent><br/
\'d8<hw>Mos`a*sau"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Mosasaurus</er>.]</ety> <fld>(Paleon.)</fld> <def>An order of
large, extinct, marine reptiles, found in the Cretaceous rocks,
especially in America. They were serpentlike in form and in having
loosely articulated and dilatable jaws, with large recurved teeth, but
they had paddlelike feet. Some of them were over fifty feet long. They
are, essentially, fossil sea serpents with paddles. Called also
<altname>Pythonomarpha</altname>, and
<altname>Mosasauria</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosasaurus</ent><br/
\'d8<hw>Mos`a*sau"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>Mosa</ets> the River Meuse (on which Meastricht is situated) + Gr.
<?/ a lizard.]</ety> <fld>(Paleon.)</fld> <def>A genus of extinct marine
reptiles allied to the lizards, but having the body much elongated, and
the limbs in the form of paddles. The first known species, nearly fifty
feet in length, was discovered in Cretaceous beds near
<city>Maestricht</city>, in the Netherlands.</def> <altsp>[Written also
<asp>Mososaurus</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moschatel</ent><br/
<hw>Mos"cha*tel`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ musk:
cf. F. <ets>moscatelline</ets>. See <er>Muscadel</er>,
<er>Musk</er>.]</ety> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Adoxa</gen> (<spn>Adoxa moschatellina</spn>), the flowers of which
are pale green, and have a faint musky smell. It is found in woods in
all parts of Europe, and is called also <altname>hollow root</altname>
and <altname>musk crowfoot</altname>.</def>
<rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moschine</ent><br/
<hw>Mos"chine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
<gen>Moschus</gen>, a genus including the musk deer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosel</ent><br/
<hw>Mos"el</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Muzzle</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moselle</ent><br/
<hw>Mo*selle"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A light wine,
usually white, produced in the vicinity of the river Moselle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moses</ent><br/
<hw>Mo"ses</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A large flatboat, used
in the West Indies for taking freight from shore to ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosey</ent><br/
<hw>Mo"sey</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Perh. fr.
<er>Vamose</er>.]</ety> <def>To go, or move (in a certain manner); --
usually with <ptcl>out</ptcl>, <ptcl>off</ptcl>, <ptcl>along</ptcl>,
etc.</def> <mark>[Colloq.]</mark> <rj><au>E. N. Wescott.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mosk</ent><br/
<hw>Mosk</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mosque</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moslem</ent><br/
<hw>Mos"lem</hw> <pr>(m<ocr/z"l<ecr/m)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Moslems</plw> <pr>(m<ocr/z"l<ecr/mz)</pr>,
<xex>or collectively</xex> <plw>Moslem</plw>.</plu> <ety>[Ar.
<ets>muslim</ets> a true believer in the Muslim faith, fr.
<ets>salama</ets> to submit to God, to resign one's self to the divine
will. Cf. <er>Islam</er>, <er>Mussulman</er>.]</ety> <def>An adherent of
Islam; a Mussulman; an orthodox Muslim.</def> <altsp>[Written also
<asp>muslim</asp>.]</altsp> <ldquo/Heaps of slaughtered
<xex>Moslem</xex>.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They piled the ground with <qex>Moslem</qex> slain.</q>
<rj><qau>Halleck.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 947 --></p>

<p><ent>Moslem</ent><br/
<hw>Mos"lem</hw> <pr>(m<ocr/z"l<ecr/m)</pr>, <pos>a.</pos> <def>Of or
pertaining to the Muslims; Islamic; <as>as, <ex>Moslem</ex> lands; the
<ex>Moslem</ex> faith.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moslings</ent><br/
<hw>Mos"lings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Thin shreds of
leather shaved off in dressing skins.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mososaurus</ent><br/
\'d8<hw>Mos`o*sau"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Paleon.)</fld> <def>Same as <er>Mosasaurus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosque</ent><br/
<hw>Mosque</hw> <pr>(m<ocr/sk)</pr>, <pos>n.</pos> <ety>[F.
<ets>mosqu<eacute/e</ets>, Sp. <ets>mezquita</ets>, Ar.
<ets>masjid</ets>, from <ets>sajada</ets> to bend, adore.]</ety> <def>A
Muslim church or place of religious worship.</def> <altsp>[Written also
<asp>mosk</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosquito</ent><br/
<hw>Mos*qui"to</hw> <pr>(m<ocr/s*k<emac/*t<osl/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mosquitoes</plw>
<pr>(m<ocr/s*k<emac/*t<omac/z)</pr>.</plu> <ety>[Sp.
<ets>mosquito</ets>, fr. <ets>mosca</ets>fly, L. <ets>musca</ets>. Cf.
<er>Musket</er>.]</ety> <fld>(Zool.)</fld> <def>Any one of various
species of gnats of the genus <gen>Culex</gen> and allied genera. The
females have a proboscis containing, within the sheathlike labium, six
fine, sharp, needlelike organs with which they puncture the skin of man
and animals to suck the blood. These bites, when numerous, cause, in
many persons, considerable irritation and swelling, with some pain. The
larvae and pupae, called <stage>wigglers</stage>, are aquatic.</def>
<altsp>[Written also <asp>musquito</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Mosquito bar</b></col>, <col><b>Mosquito
net</b></col></mcol>, <cd>a net or curtain for excluding mosquitoes, --
used for beds and windows.</cd> -- <col><b>Mosquito fleet</b></col>,
<cd>a fleet of small vessels.</cd> -- <col><b>Mosquito hawk</b></col>
<fld>(Zool.)</fld>, <cd>a dragon fly; -- so called because it captures
and feeds upon mosquitoes.</cd> -- <col><b>Mosquito netting</b></col>,
<cd>a loosely-woven gauzelike fabric for making mosquito
bars.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mosquitofish</ent><br/
<hw>mosquitofish</hw> <pos>n.</pos> <def>A silvery topminnow
(<spn>Gambusia affinis</spn>) with rows of black spots of tropical North
America and West Indies; important in mosquito control.</def><br/
<syn><b>Syn. --</b> <spn>Gambusia affinis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moss</ent><br/
<hw>Moss</hw> <pr>(m<ocr/s; 115)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mos</ets>; akin to AS. <ets>me<oacute/s</ets>, D. <ets>mos</ets>,
G. <ets>moos</ets>, OHG. <ets>mos</ets>, <ets>mios</ets>, Icel.
<ets>mosi</ets>, Dan. <ets>mos</ets>, Sw. <ets>mossa</ets>, Russ.
<ets>mokh'</ets>, L. <ets>muscus</ets>. Cf. <er>Muscoid</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A cryptogamous plant of a cellular
structure, with distinct stem and simple leaves. The fruit is a small
capsule usually opening by an apical lid, and so discharging the spores.
There are many species, collectively termed <xex>Musci</xex>, growing on
the earth, on rocks, and trunks of trees, etc., and a few in running
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <xex>moss</xex> is also popularly applied to
many other small cryptogamic plants, particularly <xex>lichens</xex>,
species of which are called <xex>tree moss</xex>, <xex>rock moss</xex>,
<xex>coral moss</xex>, etc. <xex>Fir moss</xex> and <xex>club moss</xex>
are of the genus <gen>Lycopodium</gen>. See <cref>Club moss</cref>,
under <er>Club</er>, and <er>Lycopodium</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bog; a morass; a place containing peat; <as>as,
the <ex>mosses</ex> of the Scottish border</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Moss</xex> is used with participles in the
composition of words which need no special explanation; as,
<xex>moss</xex>-capped, <xex>moss</xex>-clad, <xex>moss</xex>-covered,
<xex>moss</xex>-grown, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Black moss</b></col>. <cd>See under <er>Black</er>, and
<er>Tillandsia</er>.</cd> -- <col><b>Bog moss</b></col>. <cd>See
<er>Sphagnum</er>.</cd> -- <col><b>Feather moss</b></col>, <cd>any moss
branched in a feathery manner, esp. several species of the genus
<gen>Hypnum</gen>.</cd> -- <mcol><col><b>Florida moss</b></col>,
<col><b>Long moss</b></col>, <it>or</it> <col><b>Spanish
moss</b></col></mcol>. <cd>See <er>Tillandsia</er>.</cd> --
<col><b>Iceland moss</b></col>, <cd>a lichen. See <er>Iceland
Moss</er>.</cd> -- <col><b>Irish moss</b></col>, <cd>a seaweed. See
<er>Carrageen</er>.</cd> -- <col><b>Moss agate</b></col>
<fld>(Min.)</fld>, <cd>a variety of agate, containing brown, black, or
green mosslike or dendritic markings, due in part to oxide of manganese.
Called also <altname>Mocha stone</altname>.</cd> -- <col><b>Moss
animal</b></col> <fld>(Zool.)</fld>, <cd>a bryozoan.</cd> --
<col><b>Moss berry</b></col> <fld>(Bot.)</fld>, <cd>the small cranberry
(<spn>Vaccinium Oxycoccus</spn>).</cd> -- <col><b>Moss campion</b></col>
<fld>(Bot.)</fld>, <cd>a kind of mosslike catchfly (<spn>Silene
acaulis</spn>), with mostly purplish flowers, found on the highest
mountains of Europe and America, and within the Arctic circle.</cd> --
<col><b>Moss land</b></col>, <cd>land produced accumulation of aquatic
plants, forming peat bogs of more or less consistency, as the water is
grained off or retained in its pores.</cd> -- <col><b>Moss
pink</b></col> <fld>(Bot.)</fld>, <cd>a plant of the genus
<gen>Phlox</gen> (<spn>Phlox subulata</spn>), growing in patches on dry
rocky hills in the Middle United States, and often cultivated for its
handsome flowers.</cd> <au>Gray.</au> -- <col><b>Moss rose</b></col>
<fld>(Bot.)</fld>, <cd>a variety of rose having a mosslike growth on the
stalk and calyx. It is said to be derived from the Provence rose.</cd>
-- <col><b>Moss rush</b></col> <fld>(Bot.)</fld>, <cd>a rush of the
genus <gen>Juncus</gen> (<spn>Juncus squarrosus</spn>).</cd> --
<col><b>Scale moss</b></col>. <cd>See <er>Hepatica</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moss</ent><br/
<hw>Moss</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mossed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mossing</conjf>.]</vmorph> <def>To cover or overgrow with
moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An oak whose boughs were <qex>mossed</qex> with age.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mossback</ent><br/
<hw>Moss"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A veteran partisan;
one who is so conservative in opinion that he may be likened to a stone
or old tree covered with moss.</def> <mark>[Political Slang,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mossbunker</ent><br/
<ent>Mossbanker</ent><br/
<mhw>{ <hw>Moss"bank`er</hw> <pr>(?)</pr>, <hw>Moss"bunk`er</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>The
menhaded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mossgrown</ent><br/
<ent>moss-grown</ent><br/
<mhw><hw>moss"-grown`</hw>, <hw>moss"grown`</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Overgrown with moss; mossy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mossiness</ent><br/
<hw>Moss"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
mossy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mosstrooper</ent><br/
<hw>Moss"troop`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Moss</ets>
+ <ets>trooper</ets>.]</ety> <def>One of a class of marauders or bandits
that formerly infested the border country between England and Scotland;
-- so called in allusion to the <xex>mossy</xex> or boggy character of
much of the border country.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mossy</ent><br/
<hw>Moss"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Mossier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Mossiest</adjf>.]</amorph> <sn>1.</sn> <def>Overgrown with moss;
abounding with or edged with moss; <as>as, <ex>mossy</ex> trees;
<ex>mossy</ex> streams.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Old trees are more <qex>mossy</qex> far than young.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling moss; <as>as, <ex>mossy</ex>
green</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Most</ent><br/
<hw>Most</hw> <pr>(m<omac/st)</pr>, <pos>a.</pos>, <pos>superl.</pos> of
<er>More</er>. <ety>[OE. <ets>most</ets>, <ets>mast</ets>,
<ets>mest</ets>, AS. <ets>m<aemac/st</ets>; akin to D. <ets>meest</ets>,
OS. <ets>m<emac/st</ets>, G. <ets>meist</ets>, Icel. <ets>mestr</ets>,
Goth. <ets>maists</ets>; a superl. corresponding to E. <ets>more</ets>.
<root/103. See <er>More</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>Consisting of the greatest number or quantity; greater in number or
quantity than all the rest; nearly all.</def> <ldquo/<xex>Most</xex> men
will proclaim every one his own goodness.<rdquo/ <rj><au>Prov. xx.
6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The cities wherein <qex>most</qex> of his mighty works were
done.</q> <rj><qau>Matt. xi. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Greatest in degree; <as>as, he has the <ex>most</ex>
need of it</as>.</def> <ldquo/In the <xex>moste</xex> pride.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Highest in rank; greatest.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Most</xex> is used as a noun, the words
<xex>part</xex>, <xex>portion</xex>, <xex>quantity</xex>, etc., being
omitted, and has the following meanings: <b>1.</b> The greatest value,
number, or part; preponderating portion; highest or chief part.
<b>2.</b> The utmost; greatest possible amount, degree, or result;
especially in the phrases <xex>to make the most of</xex>, <xex>at the
most</xex>, <xex>at most</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>A quarter of a year or some months <qex>at the most</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A covetous man <qex>makes the most of</qex> what he has.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>For the most part</b></col>, <cd>in reference to the
larger part of a thing, or to the majority of the persons, instances, or
things referred to; as, human beings, <xex>for the most part</xex>, are
superstitious; the view, <xex>for the most part</xex>, was
pleasing.</cd> -- <col><b>Most an end</b></col>, <cd>generally. See
<cref>An end</cref>, under <er>End</er>, <pos>n.</pos></cd>
<mark>[Obs.]</mark> <ldquo/She sleeps <xex>most an end</xex>.<rdquo/
<rj><au>Massinger.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Most</ent><br/
<hw>Most</hw>, <pos>adv.</pos> <ety>[AS. <ets>m<aemac/st</ets>. See
<er>Most</er>, <pos>a.</pos>]</ety> <def>In the greatest or highest
degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those nearest to this king, and <qex>most</qex> his favorites,
were courtiers and prelates.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Placed before an adjective or adverb, <xex>most</xex> is
used to form the superlative degree, being equivalent to the termination
<xex>-est</xex>; as, <xex>most</xex> vile, <xex>most</xex> wicked;
<xex>most</xex> illustrious; <xex>most</xex> rapidly. Formerly, and
until after the Elizabethan period of our literature, the use of the
double superlative was common. See <er>More</er>,
<pos>adv.</pos></note><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>most unkindest</qex> cut of all.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>most straitest</qex> sect of our religion.</q>
<rj><qau>Acts xxvi. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mostahiba</ent><br/
<hw>Mos`ta*hi"ba</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mustaiba</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moste</ent><br/
<hw>Mos"te</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Mote</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Most-favored-nation clause</ent><br/
<hw>Most-favored-nation clause</hw> <fld>(Diplomacy)</fld>, <def>A
clause, often inserted in treaties, by which each of the contracting
nations binds itself to grant to the other in certain stipulated matters
the same terms as are then, or may be thereafter, granted to the nation
which receives from it the most favorable terms in respect of those
matters. It is used most frequently in treaties regarding the terms of
trade between countries, as regarding tariffs and non-tariff barriers to
trade.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><q>There was a <ldquo/<qex>most-favored-nation</qex><rdquo/
<qex>clause</qex> with provisions for the good treatment of strangers
entering the Republic.</q> <rj><qau>James Bryce.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>Steam navigation was secured by the Japanese as far as Chungking,
and under the <qex>most-favored-nation clause</qex> the right accrued to
us.</q> <rj><qau>A. R. Colquhoun.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mostick</ent><br/
<ent>Mostic</ent><br/
<mhw>{ <hw>Mos"tic</hw>, <hw>Mos"tick</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[See <er>Maul-stick</er>.]</ety> <def>A painter's
maul-stick.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mostly</ent><br/
<hw>Most"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>For the greatest
part; for the most part; chiefly; in the main.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mostra</ent><br/
\'d8<hw>Mos"tra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>See <er>Direct</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mostwhat</ent><br/
<hw>Most"what`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>For the most
part.</def> <mark>[Obs.]</mark> <ldquo/All the rest do
<xex>mostwhat</xex> far amiss.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mot</ent><br/
<hw>Mot</hw> <pr>(m<omac/t)</pr>, <pos>v.</pos> <vmorph>[<pos>Sing.
pres. ind.</pos> <conjf>Mot</conjf>, <conjf>Mote</conjf>,
<conjf>Moot</conjf> <pr>(m<omac/t)</pr>, <pos>pl.</pos>
<conjf>Mot</conjf>, <conjf>Mote</conjf>, <conjf>Moote</conjf>,
<pos>pres. subj.</pos> <conjf>Mote</conjf>; <pos>imp.</pos>
<conjf>Moste</conjf>.]</vmorph> <ety>[See <er>Must</er>,
<pos>v.</pos>]</ety> <mark>[Obs.]</mark> <def>May; must;
might.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>moot</qex> as well say one word as another</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The wordes <qex>mote</qex> be cousin to the deed.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men <qex>moot</qex> [i.e., one only] give silver to the poore
freres.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>So mote it be</b></col>, <cd>so be it; amen; -- a phrase
in some rituals, as that of the Freemasons.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mot</ent><br/
<hw>Mot</hw> <pr>(m<ocr/t; m<osl/, def. 2)</pr>, <pos>n.</pos> <ety>[F.
See <er>Motto</er>.]</ety> <sn>1.</sn> <def>A word; hence, a motto; a
device.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tarquin's eye may read the <qex>mot</qex> afar.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A pithy or witty saying; a witticism.</def> <mark>[A
Gallicism]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Here and there turns up a . . . savage <qex>mot</qex>.</q>
<rj><qau>N. Brit. Rev.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A note or brief strain on a bugle.</def> <rj><au>Sir
W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motacil</ent><br/
<hw>Mot"a*cil</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>motacille</ets>.]</ety> <fld>(Zool.)</fld> <def>Any singing bird of
the genus <gen>Motacilla</gen>; a wagtail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motation</ent><br/
<hw>Mo*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>motare</ets>, <ets>motatum</ets>, to keep moving.]</ety> <def>The
act of moving; motion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mote</ent><br/
<hw>Mote</hw> <pr>(?)</pr>, <pos>v.</pos> <def>See 1st
<er>Mot</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mote</ent><br/
<hw>Mote</hw>, <pos>n.</pos> <ety>[See <er>Moot</er>, a meeting.]</ety>
<mark>[Obs., except in a few combinations or phrases.]</mark>
<sn>1.</sn> <def>A meeting of persons for discussion; <as>as, a
ward<ex>mote</ex> in the city of London</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A body of persons who meet for discussion, esp.
about the management of affairs; <as>as, a
folk<ex>mote</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place of meeting for discussion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mote bell</b></col>, <cd>the bell rung to summon to a
<ex>mote</ex>.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mote</ent><br/
<hw>Mote</hw>, <pos>n.</pos> <def>The flourish sounded on a horn by a
huntsman. See <er>Mot</er>, <pos>n.</pos>, 3, and <er>Mort</er>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mote</ent><br/
<hw>Mote</hw>, <pos>n.</pos> <ety>[OE. <ets>mot</ets>, AS.
<ets>mot</ets>.]</ety> <def>A small particle, as of floating dust;
anything proverbially small; a speck.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The little <qex>motes</qex> in the sun do ever stir, though there
be no wind.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We are <qex>motes</qex> in the midst of generations.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moted</ent><br/
<hw>Mot"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Filled with motes, or
fine floating dust; <as>as, the air</as>.</def> <ldquo/<xex>Moted</xex>
sunbeams.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motet</ent><br/
<hw>Mo*tet"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., a dim. of
<ets>mot</ets> word; cf. It. <ets>mottetto</ets>, dim. of
<ets>motto</ets> word, device. See <er>Mot</er>, <er>Motto</er>.]</ety>
<fld>(Mus.)</fld> <def>A composition adapted to sacred words in the
elaborate polyphonic church style; an anthem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moth</ent><br/
<hw>Moth</hw> <pr>(m<ocr/th)</pr>, <pos>n.</pos> <def>A mote.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moth</ent><br/
<hw>Moth</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Moths</plw>
<pr>(m<ocr/thz)</pr>.</plu> <ety>[OE. <ets>mothe</ets>, AS.
<ets>mo<edh/<edh/e</ets>; akin to D. <ets>mot</ets>, G.
<ets>motte</ets>, Icel. <ets>motti</ets>, and prob. to E. <ets>mad</ets>
an earthworm. Cf. <er>Mad</er>, <pos>n.</pos>, <er>Mawk</er>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>Any nocturnal lepidopterous insect,
or any not included among the butterflies; <as>as, the luna
<ex>moth</ex>; Io <ex>moth</ex>; hawk <ex>moth</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any lepidopterous insect that
feeds upon garments, grain, etc.; <as>as, the clothes <ex>moth</ex>;
grain <ex>moth</ex>; bee <ex>moth</ex></as>. See these terms under
<er>Clothes</er>, <er>Grain</er>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Any one of various other insects
that destroy woolen and fur goods, etc., esp. the larvae of several
species of beetles of the genera <gen>Dermestes</gen> and
<gen>Anthrenus</gen>. Carpet moths are often the larvae of
<gen>Anthrenus</gen>. See <cref>Carpet beetle</cref>, under
<er>Carpet</er>, <er>Dermestes</er>, <er>Anthrenus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Anything which gradually and silently eats,
consumes, or wastes any other thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moth blight</b></col> <fld>(Zool.)</fld>, <cd>any plant
louse of the genus <gen>Aleurodes</gen>, and related genera. They are
injurious to various plants.</cd> -- <col><b>Moth gnat</b></col>
<fld>(Zool.)</fld>, <cd>a dipterous insect of the genus
<gen>Bychoda</gen>, having fringed wings.</cd> -- <col><b>Moth
hunter</b></col> <fld>(Zool.)</fld>, <cd>the goatsucker.</cd> --
<col><b>Moth miller</b></col> <fld>(Zool.)</fld>, <cd>a clothes moth.
See <er>Miller</er>, 3, <sd>(a)</sd>.</cd> -- <col><b>Moth
mullein</b></col> <fld>(Bot.)</fld>, <cd>a common herb of the genus
<gen>Verbascum</gen> (<spn>Verbascum Blattaria</spn>), having large
wheel-shaped yellow or whitish flowers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mothball</ent><br/
<hw>moth"ball`</hw> <pos>n.</pos> <def>A small sphere of camphor or
naphthalene used to keep moths away from stored clothing.</def><br/
<syn><b>Syn. --</b> camphor ball.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mothball</ent><br/
<hw>moth"ball`</hw> <pos>v. t.</pos> <def>To put into long-term storage;
<as>as, to <ex>mothball</ex> the battleships not needed after the
war</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moth-eat</ent><br/
<hw>Moth"-eat`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To eat or prey
upon, as a moth eats a garment.</def> <mark>[Rarely used except in the
form <it>moth-eaten</it>, p. p. or a.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Ruin and neglect have so <qex>moth-eaten</qex> her.</q>
<rj><qau>Sir T. Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moth-eaten</ent><br/
<hw>Moth"-eat`en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>having holes due
to eating by moths or moth larvae; -- of cloth or clothing.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mothen</ent><br/
<hw>Moth"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of moths.</def>
<mark>[Obs.]</mark> <rj><au>Fulke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother</ent><br/
<hw>Moth"er</hw> <pr>(m<ucr/<th/"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>moder</ets>, AS. <ets>m<omac/dor</ets>; akin to D.
<ets>moeder</ets>, OS. <ets>m<omac/dar</ets>, G. <ets>mutter</ets>, OHG.
<ets>muotar</ets>, Icel. <ets>m<omac/<edh/ir</ets>, Dan. & Sw.
<ets>moder</ets>, OSlav. <ets>mati</ets>, Russ. <ets>mate</ets>, Ir. &
Gael. <ets>mathair</ets>, L. <ets>mater</ets>, Gr. <grk>mh`thr</grk>,
Skr. <ets>m<amac/t<rsdot/</ets>; cf. Skr. <ets>m<amac/</ets> to measure.
<root/268. Cf. <er>Material</er>, <er>Matrix</er>, <er>Metropolis</er>,
<er>Father</er>.]</ety> <sn>1.</sn> <def>A female parent; especially,
one of the human race; a woman who has borne a child.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which has produced or nurtured anything; source
of birth or origin; generatrix.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Alas! poor country! . . . it can not<br/
Be called our <qex>mother</qex>, but our grave.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I behold . . . the solitary majesty of Crete, <qex>mother</qex> of
a religion, it is said, that lived two thousand years.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An old woman or matron.</def>
<mark>[Familiar]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The female superior or head of a religious house, as
an abbess, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hysterical passion; hysteria.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mother Carey's chicken</b></col> <fld>(Zool.)</fld>,
<cd>any one of several species of small petrels, as the stormy petrel
(<spn>Procellaria pelagica</spn>), and Leach's petrel (<spn>Oceanodroma
leucorhoa</spn>), both of the Atlantic, and <spn>Oceanodroma
furcata</spn> of the North Pacific.</cd> -- <col><b>Mother Carey's
goose</b></col> <fld>(Zool.)</fld>, <cd>the giant fulmar of the Pacific.
See <er>Fulmar</er>.</cd> -- <col><b>Mother's mark</b></col>
<fld>(Med.)</fld>, <cd>a congenital mark upon the body; a birthmark; a
naevus.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother</ent><br/
<hw>Moth"er</hw>, <pos>a.</pos> <def>Received by birth or from
ancestors; native, natural; <as>as, <ex>mother</ex> language</as>; also
acting the part, or having the place of a mother; producing others;
originating.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the <qex>mother</qex> falsehood from which all idolatry is
derived.</q> <rj><qau>T. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mother cell</b></col> <fld>(Biol.)</fld>, <cd>a cell
which, by endogenous divisions, gives rise to other cells (daughter
cells); a parent cell.</cd> -- <col><b>Mother church</b></col>, <cd>the
original church; a church from which other churches have sprung; <as>as,
the <ex>mother church</ex> of a diocese</as>.</cd> -- <col><b>Mother
country</b></col>, <cd>the country of one's parents or ancestors; the
country from which the people of a colony derive their origin.</cd> --
<col><b>Mother liquor</b></col> <fld>(Chem.)</fld>, <cd>the impure or
complex residual solution which remains after the salts readily or
regularly crystallizing have been removed.</cd> -- <col><b>Mother
queen</b></col>, <cd>the mother of a reigning sovereign; a queen
mother.</cd> -- <col><b>Mother tongue</b></col>. <sd>(a)</sd> <cd>A
language from which another language has had its origin</cd>.
<sd>(b)</sd> <cd>The language of one's native land; native tongue.</cd>
-- <col><b>Mother water</b></col>. <cd>See <cref>Mother liquor</cref>
(above).</cd> -- <col><b>Mother wit</b></col>, <cd>natural or native wit
or intelligence.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother</ent><br/
<hw>Moth"er</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mothered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mothering</conjf>.]</vmorph> <def>To adopt as a son or daughter;
to perform the duties of a mother to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The queen, to have put lady Elizabeth besides the crown, would
have <qex>mothered</qex> another body's child.</q>
<rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother</ent><br/
<hw>Moth"er</hw>, <pos>n.</pos> <ety>[Akin to D. <ets>modder</ets> mud,
G. <ets>moder</ets> mold, mud, Dan. <ets>mudder</ets> mud, and to E.
<ets>mud</ets>. See <er>Mud</er>.]</ety> <def>A film or membrane which
is developed on the surface of fermented alcoholic liquids, such as
vinegar, wine, etc., and acts as a means of conveying the oxygen of the
air to the alcohol and other combustible principles of the liquid, thus
leading to their oxidation.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The film is composed of a mass of rapidly developing
microorganisms of the genus <gen>Mycoderma</gen>, and in the
<cref>mother of vinegar</cref> the microorganisms (<spn>Mycoderma
aceti</spn>) composing the film are the active agents in the Conversion
of the alcohol into vinegar. When thickened by growth, the film may
settle to the bottom of the fluid. See <cref>Acetous
fermentation</cref>, under <er>Fermentation</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother</ent><br/
<hw>Moth"er</hw>, <pos>v. i.</pos> <def>To become like, or full of,
mother, or thick matter, as vinegar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mother</ent><br/
<hw>moth"er</hw> <pr>(m<ucr/<th/"<etil/r)</pr>, <pos>n.</pos>
<ety>[Shortened from <ets>motherfucker</ets> as a euphemism.]</ety>
<sn>1.</sn> <def>Same as <er>motherfucker</er>.</def> <mark>[Vulgar
slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A person or thing with some exceptional quality, as
great size or power; <as>as, a grizzly stuck his nose in my tent and I
grabbed my pistol and shot the <ex>mother</ex></as>.</def>
<mark>[Slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>motherboard</ent><br/
<hw>moth"er*board`</hw> <pos>n.</pos> <fld>(Electronics)</fld> <def>The
board containing the main circuits of an electronic device, especially
computers. The term is used primarily in microcomputer literature, where
it designates the board containing the main <part>expansion bus</part>,
and usually also the <part>cpu</part>. On motherboards designed with an
expansion bus, often all of the circuits not contained on an expansion
card are on the <ex>motherboard</ex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mothered</ent><br/
<hw>Moth"ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Thick, like mother;
viscid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They oint their naked limbs with <qex>mothered</qex> oil.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>motherfucker</ent><br/
<hw>moth"er*fuck`er</hw> <pos>n.</pos> <sn>1.</sn> <def>A person who is
deemed to be worthless or despicable; -- obscene and highly
offensive.</def> <mark>[vulgar slang]</mark><br/
<syn><b>Syn. --</b> rotter, rat, skunk, stinker, bum, crumb, lowlife,
scum bag, cocksucker, mother.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Any object viewed as annoying or frustrating; --
usually used as an expression of anger.</def> <mark>[vulgar
slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Mother Goose</ent><br/
<hw>Mother Goose</hw> <pos>n.</pos> <def>The supposed author of a book
of nursery rhymes first published as <ldquo/Mother Goose's
Melodies,<rdquo/ and usually called simply <ldquo/Mother Goose.<rdquo/
The first English edition is said to have been printed in 1719 in
London. The actual persons who composed the rhymes is unknown, and
earlier similar rhymes in French are a likely source for some of them.
<ex>Mother Goose</ex> is also used as the title of a book of Mother
Goose rhymes.</def><br/
[<source>PJC</source>]</p>

<p><ent>Motherhood</ent><br/
<hw>Moth"er*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being a mother; the character or office of a mother.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mothering</ent><br/
<hw>Moth"er*ing</hw>, <pos>n.</pos> <def>A rural custom in England, of
visiting one's parents on Midlent Sunday, -- supposed to have been
originally visiting the mother church to make offerings at the high
altar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother-in-law</ent><br/
<hw>Moth"er-in-law`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The mother of
one's husband or wife.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motherland</ent><br/
<hw>Moth"er*land`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The country of
one's ancestors; -- same as <altname>fatherland</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motherless</ent><br/
<hw>Moth"er*less</hw>, <pos>a.</pos> <ety>[AS.
<ets>m<omac/dorle<aacute/s</ets>.]</ety> <def>Destitute of a mother;
having lost a mother; <as>as, <ex>motherless</ex>
children</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>motherlike</ent><br/
<hw>motherlike</hw> <pos>adj.</pos> <def>suggestive of or acting like a
mother; motherly; maternal.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motherliness</ent><br/
<hw>Moth"er*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being motherly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motherly</ent><br/
<hw>Moth"er*ly</hw>, <pos>a.</pos> <ety>[AS.
<ets>m<omac/dorlic</ets>.]</ety> <def>Of or pertaining to a mother;
like, or suitable for, a mother; tender; maternal; <as>as,
<ex>motherly</ex> authority, love, or care</as>.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Maternal; paternal.</syn> <usage> --
<er>Motherly</er>, <er>Maternal</er>. <xex>Motherly</xex>, being
Anglo-Saxon, is the most familiar word of the two when both have the
same meaning. Besides this, <xex>maternal</xex> is confined to the
feelings of a mother toward her <xex>own</xex> children, whereas
<xex>motherly</xex> has a secondary sense, denoting a care
<xex>like</xex> that of a mother for her offspring. There is, perhaps, a
growing tendency thus to separate the two, confining <xex>motherly</xex>
to the latter signification. <ldquo/They termed her the great mother,
for her <xex>motherly</xex> care in cherishing her brethren whilst
young.<rdquo/ <au>Sir W. Raleigh.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motherly</ent><br/
<hw>Moth"er*ly</hw>, <pos>adv.</pos> <def>In a manner of a
mother.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother-naked</ent><br/
<hw>Moth"er-na`ked</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Naked as when
born; completely naked.</def><br/
<syn><b>Syn. --</b> naked as the day one was born, in one's birthday
suit.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother-of-pearl</ent><br/
<hw>Moth"er-of-pearl`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The hard, iridescent, pearly internal layer of
several kinds of shells, esp. of pearl oysters, river mussels, and the
abalone shells; nacre. See <er>Pearl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mother-of-thousands</ent><br/
<hw>mother-of-thousands</hw> <pos>n.</pos> <def>An East Asiatic
saxifrage (<spn>Saxifraga stolonifera</spn>) with racemes of small
red-and-white flowers; spreads by numerous creeping stolons; called also
<altname>strawberry geranium</altname> and <altname>strawberry
saxifrage</altname>.</def><br/
<syn><b>Syn. --</b> strawberry geranium, strawberry saxifrage,
<spn>Saxifraga stolonifera</spn>, Saxifraga sarmentosam.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mother-of-thyme</ent><br/
<hw>Moth"er-of-thyme`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An aromatic plant (<spn>Thymus Serphyllum</spn>); -- called also
<altname>wild thyme</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mother's Day</ent><br/
<hw>Moth"er's Day</hw>. <def>A day appointed for the honor and uplift of
motherhood by the loving remembrance of each person of his mother
through the performance of some act of kindness, visit, tribute, or
letter. The founder of the day is <person>Anna Jarvis</person>, of
<city>Philadelphia</city>, who designated the second Sunday in May, or
for schools the second Friday, as the time, and a white carnation as the
badge.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motherwort</ent><br/
<hw>Moth"er*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A labiate herb (<spn>Leonurus Cardiaca</spn>), of a
bitter taste, used popularly in medicine; lion's tail.</def>
<sd>(b)</sd> <def>The mugwort. See <er>Mugwort</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 948 --></p>

<p><ent>Mothery</ent><br/
<hw>Moth"er*y</hw> <pr>(m<ucr/<th/"<etil/r*<ycr/)</pr>, <pos>a.</pos>
<def>Consisting of, containing, or resembling, mother (in
vinegar).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mothy</ent><br/
<hw>Moth"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Infested with moths;
moth-eaten.</def> <ldquo/An old <xex>mothy</xex> saddle.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motif</ent><br/
<hw>Mo"tif</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Motive.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In literature and the fine arts, a salient feature
or element of a composition or work; esp., the theme, or central or
dominant feature;</def> <specif>specif.</specif> <fld>(Music)</fld>,
<def>a motive{3}. See also <er>leitmotif</er>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><q>This <qex>motif</qex>, of old things lost, is a favorite one for
the serious ballade.</q> <rj><qau>R. M. Alden.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The design . . . is . . . based on the peacock -- a
<qex>motif</qex> favored by decorative artists of all ages.</q>
<rj><qau>R. D. Benn.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Dressmaking)</fld> <def>A decorative
appliqu<eacute/ design or figure, as of lace or velvet, used in
trimming; also, a repeated design.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Motific</ent><br/
<hw>Mo*tif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>motus</ets>
motion (fr. <ets>movere</ets> to move) + <ets>facere</ets> to
make.]</ety> <def>Producing motion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motile</ent><br/
<hw>Mo"tile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Motive</er>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld> <def>Exhibiting,
or capable of, spontaneous movement; <as>as, <ex>motile</ex> bacteria,
<ex>motile</ex> protozoa, <ex>motile</ex> cilia, <ex>motile</ex> spores,
etc.</as></def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Producing motion; <as>as, <ex>motile</ex>
powers</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motile</ent><br/
<hw>Mo"tile</hw>, <pos>n.</pos> <fld>(Psychol.)</fld> <def>A person
whose prevailing mental imagery takes the form of inner feelings of
action, such as incipient pronunciation of words, muscular innervations,
etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motility</ent><br/
<hw>Mo*til"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>motilit<eacute/</ets>.]</ety> <fld>(Physiol.)</fld> <def>Capability
of motion; contractility.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motion</ent><br/
<hw>Mo"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>motio</ets>, fr. <ets>movere</ets>, <ets>motum</ets>, to move. See
<er>Move</er>.]</ety> <sn>1.</sn> <def>The act, process, or state of
changing place or position; movement; the passing of a body from one
place or position to another, whether voluntary or involuntary; --
opposed to <contr>rest</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Speaking or mute, all comeliness and grace<br/
attends thee, and each word, each <qex>motion</qex>, forms.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Power of, or capacity for, motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Devoid of sense and <qex>motion</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Direction of movement; course; tendency; <as>as, the
<ex>motion</ex> of the planets is from west to east</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In our proper <qex>motion</qex> we ascend.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Change in the relative position of the parts of
anything; action of a machine with respect to the relative movement of
its parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the great wheel to which the clock owes its
<qex>motion</qex>.</q> <rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Movement of the mind, desires, or passions; mental
act, or impulse to any action; internal activity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let a good man obey every good <qex>motion</qex> rising in his
heart, knowing that every such <qex>motion</qex> proceeds from God.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A proposal or suggestion looking to action or
progress; esp., a formal proposal made in a deliberative assembly;
<as>as, a <ex>motion</ex> to adjourn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yes, I agree, and thank you for your <qex>motion</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Law)</fld> <def>An application made to a court or
judge orally in open court. Its object is to obtain an order or rule
directing some act to be done in favor of the applicant.</def>
<rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mus.)</fld> <def>Change of pitch in successive
sounds, whether in the same part or in groups of parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The independent <qex>motions</qex> of different parts sounding
together constitute counterpoint.</q> <rj><qau>Grove.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Conjunct motion</xex> is that by single degrees of
the scale. <xex>Contrary motion</xex> is that when parts move in
opposite directions. <xex>Disjunct motion</xex> is motion by skips.
<xex>Oblique motion</xex> is that when one part is stationary while
another moves. <xex>Similar</xex> or <xex>direct motion</xex> is that
when parts move in the same direction.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A puppet show or puppet.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>motion</qex>'s this? the model of Nineveh?</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Motion, in mechanics, may be simple or compound.
<col><b>Simple motions</b></col> are: (<stype>a</stype>) <xex>straight
translation</xex>, which, if of indefinite duration, must be
reciprocating. (<stype>b</stype>) <xex>Simple rotation</xex>, which may
be either continuous or reciprocating, and when reciprocating is called
<xex>oscillating</xex>. (<stype>c</stype>) <xex>Helical</xex>, which, if
of indefinite duration, must be reciprocating. <col><b>Compound
motion</b></col> consists of combinations of any of the simple
motions.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Center of motion</b></col>, <col><b>Harmonic
motion</b></col></mcol>, <cd>etc. See under <er>Center</er>,
<er>Harmonic</er>, etc.</cd> -- <col><b>Motion block</b></col>
<fld>(Steam Engine)</fld>, <cd>a crosshead.</cd> -- <col><b>Perpetual
motion</b></col> <fld>(Mech.)</fld>, <cd>an incessant motion conceived
to be attainable by a machine supplying its own motive forces
independently of any action from without. According to the law of
conservation of energy, such perpetual motion is impossible, and no
device has yet been built that is capable of perpetual
motion.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Movement</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motion</ent><br/
<hw>Mo"tion</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Motioned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Motioning</conjf>.]</vmorph> <sn>1.</sn> <def>To make a
significant movement or gesture, as with the hand; <as>as, to
<ex>motion</ex> to one to take a seat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make proposal; to offer plans.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motion</ent><br/
<hw>Mo"tion</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To direct or invite
by a motion, as of the hand or head; <as>as, to <ex>motion</ex> one to a
seat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To propose; to move.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I want friends to <qex>motion</qex> such a matter.</q>
<rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>motional</ent><br/
<hw>motional</hw> <pos>adj.</pos> <def>of or pertaining to
motion.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motioner</ent><br/
<hw>Mo"tion*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes a
motion; a mover.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motionist</ent><br/
<hw>Mo"tion*ist</hw>, <pos>n.</pos> <def>A mover.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motionless</ent><br/
<hw>Mo"tion*less</hw>, <pos>a.</pos> <def>Without motion; being at
rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motion picture</ent><br/
<hw>Mo"tion pic"ture</hw>. <sn>1.</sn> <def>A series of pictures on a
strip of film, taken at regular intervals in rapid succession (now
usually 24 frames per second for ordinary work) by a special camera,
intended to capture the image of objects in motion.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>the display of the images captured on a <er>motion
picture</er>{1}, presented to the eye in very rapid succession by
projection from a special apparatus (a <usedby><er>movie
projector</er></usedby>), with shows some or all of the objects in the
picture represented in changing positions, producing, by persistence of
vision, the optical effect of a continuous picture in which the objects
appear to move as they did in the original scene.</def><br/
<syn><b>Syn. --</b> movie, moving picture, flick.</syn>
[<source>Webster 1913 Suppl.</source>  <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>The conceptual or informational content of a
<er>motion picture</er>{1}; the actions or events represented in a
<er>motion picture</er>{1}; the story line of a movie.</def> <ldquo/One
of the great punch lines in <xex>motion picture</xex> history is
<lsquo/Round up the usual suspects.' from <lsquo/Casablanca'.<rdquo/
[<source>PJC</source>]</p>

<p><ent>Motivate</ent><br/
<hw>Mo"ti*vate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>-vated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>-vating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From
<er>Motive</er>, <pos>n.</pos>]</ety> <def>To provide with a motive; to
move; impel; induce; incite.</def> -- <wordforms><wf>Mo`ti*va"tion</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms> <rj><au>William
James.</au></rj><br/
<syn><b>Syn. --</b> move, prompt, incite, induce impel, drive.</syn><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>motivated</ent><br/
<hw>motivated</hw> <pos>adj.</pos> <def>Having a strong motive; -- of
people. Opposite of <ant>unmotivated</ant>.</def> [Narrower terms:
<stype>driven, impelled</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motivative</ent><br/
<ent>motivating</ent><br/
<mhw><hw>motivating</hw> <hw>motivative</hw></mhw> <pos>adj.</pos>
<def>causing motion or impelling to action; providing a motive{2};
<as>as, <ex>motivating</ex> arguments</as>.</def><br/
<syn><b>Syn. --</b> motive(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>It may well be that ethical language has primarily a
<qex>motivative</qex> function</q> <qau>Arthur Pap</qau></p>

<p><ent>motivation</ent><br/
<hw>motivation</hw> <pos>n.</pos> <sn>1.</sn> <def>The act or process of
motivating.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The mental process that arouses an organism to
action; <as>as, a large part of a teacher's job is to give students the
<ex>motivation</ex> to learn on their own</as>.</def><br/
<syn><b>Syn. --</b> motive, need.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>The goal or mental image of a goal that creates a
motivation{2}; <as>as, the image of a peaceful world is a powerful
<ex>motivation</ex> for only a rare few individuals</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Motive</ent><br/
<hw>Mo"tive</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>motif</ets>,
LL. <ets>motivum</ets>, from <ets>motivus</ets> moving, fr. L.
<ets>movere</ets>, <ets>motum</ets>, to move. See <er>Move</er>.]</ety>
<sn>1.</sn> <def>That which moves; a mover.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which incites to action; anything prompting or
exciting to choise, or moving the will; cause; reason; inducement;
object; motivation{2}.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>motive</qex>, I mean the whole of that which
<qex>moves</qex>, excites, or invites the mind to volition, whether that
be one thing singly, or many things conjunctively.</q> <rj><qau>J.
Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>The theme or subject; a leading
phrase or passage which is reproduced and varied through the course of a
comor a movement; a short figure, or melodic germ, out of which a whole
movement is develpoed. See also <cref>Leading motive</cref>, under
<er>Leading</er>.</def> <altsp>[Written also
<asp>motivo</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Fine Arts)</fld> <def>That which produces
conception, invention, or creation in the mind of the artist in
undertaking his subject; the guiding or controlling idea manifested in a
work of art, or any part of one.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Incentive; incitement; inducement; reason; spur;
stimulus; cause.</syn> <usage> -- <er>Motive</er>, <er>Inducement</er>,
<er>Reason</er>. <xex>Motive</xex> is the word originally used in
speaking of that which determines the choice. We call it an
<xex>inducement</xex> when it is attractive in its nature. We call it a
<xex>reason</xex> when it is more immediately addressed to the intellect
in the form of argument.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motive</ent><br/
<hw>Mo"tive</hw>, <pos>a.</pos> <def>Causing motion; having power to
move, or tending to move; <as>as, a <ex>motive</ex> argument;
<ex>motive</ex> power</as>.</def> <ldquo/<xex>Motive</xex>
faculty.<rdquo/ <rj><au>Bp. Wilkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Motive power</b></col> <fld>(Mach.)</fld>, <cd>a natural
agent, as water, steam, wind, electricity, etc., used to impart motion
to machinery; a motor; a mover.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motive</ent><br/
<hw>Mo"tive</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To prompt or incite
by a motive or motives; to move.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motiveless</ent><br/
<hw>Mo"tive*less</hw>, <pos>a.</pos> <def>Destitute of a motive; not
incited by a motive.</def> -- <wordforms><wf>Mo"tive*less*ness</wf>,
<pos>n.</pos></wordforms> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motivity</ent><br/
<hw>Mo*tiv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Motive</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>The power of
moving or producing motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of being influenced by motives.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motivo</ent><br/
\'d8<hw>Mo*ti"vo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Motive</er>, <pos>n.</pos>]</ety> <def>See <er>Motive</er>,
<pos>n.</pos>, 3, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motley</ent><br/
<hw>Mot"ley</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>mottelee</ets>, <ets>motle</ets>; cf. OF. <ets>mattel<eacute/</ets>
clotted, curdled, OF, ciel <ets>mattonn<eacute/</ets> a mottled sky,
<ets>mate</ets>, <ets>maton</ets>, curdled milk, Prov. G.
<ets>matte</ets> curd. Cf. <er>Mottle</er>.]</ety> <sn>1.</sn>
<def>Variegated in color; consisting of different colors; dappled;
party-colored; <as>as, a <ex>motley</ex> coat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wearing motley or party-colored clothing. See
<er>Motley</er>, <pos>n.</pos>, 1.</def> <ldquo/A <xex>motley</xex>
fool.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Composed of different or various parts;
heterogeneously made or mixed up; discordantly composite; <as>as,
<ex>motley</ex> style</as>.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motley</ent><br/
<hw>Mot"ley</hw>, <pos>n.</pos> <sn>1.</sn> <def>A combination of
distinct colors; esp., the party-colored cloth, or clothing, worn by the
professional fool.</def> <au>Chaucer.</au> <ldquo/<xex>Motley</xex> 's
the only wear.<rdquo/ <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, a jester, a fool.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Man of motley</b></col>, <cd>a fool.</cd>
</cs><mark>[Obs.]</mark> <au>Beau. & Fl.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>motley collection</ent><br/
<hw>mot"ley col*lec"tion</hw>, <pos>n.</pos> <def>A collection of
objects of various kinds; a hodgepodge; a medley; a confused mixture; an
omnium gatherum.</def><br/
[<source>PJC</source>]</p>

<p><ent>Motley-minded</ent><br/
<hw>Mot"ley-mind`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a mind
of a jester; foolish.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motmot</ent><br/
<hw>Mot"mot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Momot</er>.]</ety> <fld>(Zool.)</fld> <def>Any one of several
species of long-tailed, passerine birds of the genus <gen>Momotus</gen>,
having a strong serrated beak. In most of the species the two long
middle tail feathers are racket-shaped at the tip, when mature. The bird
itself is said by some writers to trim them into this shape. They feed
on insects, reptiles, and fruit, and are found from Mexico to Brazil.
The name is derived from its note.</def> <altsp>[Written also
<asp>momot</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moto</ent><br/
\'d8<hw>Mo"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Movement; manner of movement; particularly,
movement with increased rapidity; -- used especially in the phrase
<xex>con moto</xex>, directing to a somewhat quicker movement; <as>as,
<ex>andante con moto</ex>, a little more rapidly than <ex>andante</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motograph</ent><br/
<hw>Mo"to*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>movere</ets>, <ets>motum</ets>, to move + <ets>-graph</ets>.]</ety>
<fld>(Elec.)</fld> <def>A device utilized in the making of a
loud-speaking telephone, depending on the fact that the friction between
a metallic point and a moving cylinder of moistened chalk, or a moving
slip of paper, on which it rests is diminished by the passage of a
current between the point and the moving surface.</def>
<mark>[obsolescent]</mark> -- <wordforms><wf>Mo`to*graph"ic</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moton</ent><br/
<hw>Mo"ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Anc. Armor)</fld> <def>A small plate covering
the armpit in armor of the 14th century and later.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motor</ent><br/
<hw>Mo"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>movere</ets>, <ets>motum</ets>, to move.]</ety> <sn>1.</sn>
<def>One who, or that which, imparts motion; a source of mechanical
power.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A prime mover; a machine by means
of which a source of power, as steam, moving water, electricity, etc.,
is made available for doing mechanical work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A motor car; an automobile.</def> <mark>[archiac
Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motorial</ent><br/
<ent>Motory</ent><br/
<ent>Motor</ent><br/
<mhw>{ <hw>Mo"tor</hw> <pr>(?)</pr>, <hw>Mo"to*ry</hw> <pr>(?)</pr>,
<hw>Mo*to"ri*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>motorius</ets> that has motion. See <er>Motor</er>,
<pos>n.</pos>]</ety> <def>Causing or setting up motion; pertaining to
organs of motion; -- applied especially in physiology to those nerves or
nerve fibers which only convey impressions from a nerve center to
muscles, thereby causing motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>motorboat</ent><br/
<hw>motorboat</hw> <pos>n.</pos> <def>a boat propelled by an
internal-combustion engine driving propellers immersed in the
water.</def><br/
<syn><b>Syn. --</b> powerboat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motorbus</ent><br/
<hw>motorbus</hw> <pos>n.</pos> <def>a road vehicle carrying many
passengers; used for public transport; an omnibus.</def><br/
<syn><b>Syn. --</b> bus, autobus, coach, charabanc, double-decker,
jitney, motorcoach, omnibus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motorcade</ent><br/
<hw>motorcade</hw> <pos>n.</pos> <def>a procession of people traveling
in motor cars.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motorcar</ent><br/
<ent>Motor car</ent><br/
<mhw>{ <hw>Motor car</hw>, <it>or</it> <hw>Mo"tor*car`</hw> }</mhw>,
<pos>n.</pos> <sn>1.</sn> <def>An automobile, locomobile, or locomotive
designed to run and be steered on a street or roadway; esp., an
automobile specially designed for passengers and propelled by an
internal combustion engine.</def><br/
<syn><b>Syn. --</b> car, auto, automobile, machine.</syn><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Elec. Railroads)</fld> <def>Any car containing
motors for propulsion.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motorbike</ent><br/
<hw>Mo"tor*bike`</hw>, <pos>n.</pos> <sn>1.</sn> <def>a light
two-wheeled vehicle containing a motor for propulsion. It is lighter in
construction and has a lower speed than a <er>motorcycle</er>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>a small motorcycle
with a low frame and small weels and elevated handlebars.</def><br/
<syn><b>Syn. --</b> minibike.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <def>a bicyle with a motor
attached for propulsion.</def><br/
[<source>PJC</source>]</p>

<p><ent>motorcoach</ent><br/
<hw>motorcoach</hw> <pos>n.</pos> <def>a <er>motorbus</er>.</def><br/
<syn><b>Syn. --</b> bus, autobus, coach, charabanc, double-decker,
jitney, motorbus, omnibus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motor cycle</ent><br/
<ent>motorcycle</ent><br/
<mhw>{ <hw>mo"tor*cy`cle</hw>, <it>or</it> <hw>mo"tor cy`cle</hw>
}</mhw>, <pos>n.</pos> <def>A two-wheeled vehicle having a motor
attached so as to be self-propelled. In common usage, a
<ex>motorcycle</ex> is of heavier construction with larger wheels, a
more powerful motor, and a higher maximum speed than a
<er>motorbike</er>.</def> <note>A motorcycle may have a small appended
compartment called a <part>sidecar</part>, supported by a third wheel,
which can carry a passenger.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note>In Great Britain as of 1913 the term <xex>motor cycle</xex> was
treated by statute (<au>3 Ed VII. c. 36</au>) as limited to motor cars
(self-propelled vehicles) designed to travel on not more than three
wheels, and weighing unladen (that is, without water, fuel, or
accumulators necessary for propulsion) not more than three hundred
weight (336 lbs.).</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>motorcycle</ent><br/
<hw>motorcycle</hw> <pos>v. i.</pos> <def>to ride a
motorcycle.</def><br/
<syn><b>Syn. --</b> cycle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motorcycling</ent><br/
<hw>motorcycling</hw> <pos>n.</pos> <def>The process of riding a
motocycle.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>travel on a motorcycle.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motorcyclist</ent><br/
<hw>mo"tor*cyc`list</hw>, <pos>n.</pos> <def>A person who rides a
motorcycle.</def><br/
<syn><b>Syn. --</b> biker, cyclist.</syn><br/
[<source>PJC</source>]</p>

<p><ent>motor-driven</ent><br/
<hw>mo`tor-driv`en</hw>, <pos>a.</pos> <fld>(Mach.)</fld> <def>Driven or
actuated by a motor, esp. by an individual electric motor. An electric
motor forms an integral part of many machine tools in numerous modern
machine shops.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>motored</ent><br/
<hw>motored</hw> <pos>adj.</pos> <def>equipped with a motor or motors;
motorized. Opposite of <ant>unmotorized</ant>.</def> [Narrower terms:
<stype>bimotored</stype>; <stype>trimotored </stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motor generator</ent><br/
<hw>Motor generator</hw>. <def>The combination consisting of a generator
and a driving motor mechanically connected, usually on a common bedplate
and with the two shafts directly coupled or combined into a single
shaft.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motoring</ent><br/
<hw>Mo"tor*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the act or
recreation of riding in or driving a motor car or automobile.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Motoring</ent><br/
<hw>Mo"tor*ing</hw>, <pos>a.</pos> <def>Pertaining to motor cars or
automobiles, or to the technology of such; addicted to riding in or
driving automobiles; <as>as, <ex>motoring</ex> parlance; my
<ex>motoring</ex> friend</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>motorisation</ent><br/
<hw>motorisation</hw> <pos>n.</pos> <def>motorization.</def>
<mark>[Chiefly Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motorise</ent><br/
<hw>Mo"tor*ise</hw> <pr>(m<omac/"t<etil/r*<imac/z)</pr>, <pos>v.
t.</pos> <def>same as <er>motorize</er>.</def> <mark>[Brit.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>motorization</ent><br/
<hw>motorization</hw> <pos>n.</pos> <def>the act of motorizing (equiping
with motors or with motor vehicles).</def><br/
<syn><b>Syn. --</b> motorisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motorize</ent><br/
<hw>Mo"tor*ize</hw> <pr>(m<omac/"t<etil/r*<imac/z)</pr>, <pos>v.
t.</pos> <ety>[<ets>Motor</ets> + <ets>-ize</ets>.]</ety> <sn>1.</sn>
<def>To substitute motor-driven vehicles, or automobiles, for the horses
and horse-drawn vehicles of (a fire department, city, etc.).</def>
<mark>[archaic]</mark> -- <wordforms><wf>Mo`tor*i*za"tion</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>to equip (a piece of machinery) with a
motor.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>to provide with automobiles or other motor vehicles;
<as>as, a <ex>motorized</ex> army division</as>.</def><br/
<syn><b>Syn. --</b> mechanize.</syn><br/
[<source>PJC</source>]</p>

<p><ent>motorized</ent><br/
<hw>motorized</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>motored</er>; <as>as, a <ex>motorized</ex> wheelchair</as>. Opposite
of <ant>unmotorized</ant>.</def> [Narrower terms: <stype>bimotored
</stype>; <stype>trimotored </stype>]<br/
<syn><b>Syn. --</b> motored.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Equipped with vehicles to permit rapid movement from
place to place.</def><br/
<syn><b>Syn. --</b> mechanized.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>motorless</ent><br/
<hw>motorless</hw> <pos>adj.</pos> <def>having no motor. Opposite of
<ant>motorized</ant>.</def><br/
<syn><b>Syn. --</b> unmotorized.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Motorman</ent><br/
<hw>Mo"tor*man</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A man
who controls a motor.</def> <mark>[archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>an operator of a motor vehicle, especially of a
streetcar or subway train.</def> <br/
[<source>PJC</source>]</p>

<p><ent>Motormouth</ent><br/
<hw>Mo"tor*mouth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a person who
talks excessively.</def> <mark>[derogatory]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Motorpathic</ent><br/
<hw>Mo`tor*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to motorpathy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motorpathy</ent><br/
<hw>Mo*tor"pa*thy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>motor</ets> a mover + Gr. <?/, <?/, to suffer.]</ety>
<fld>(Med.)</fld> <def>same as <er>Kinesiatrics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motte</ent><br/
<hw>Motte</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>motte</ets>
a clod, clump, or hillock.]</ety> <def>A clump of trees in a
prairie.</def> <mark>[Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mottle</ent><br/
<hw>Mot"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mottled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mottling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From
<er>Mottled</er>.]</ety> <def>To mark with spots of different color, or
shades of color, as if stained; to spot; to maculate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mottle</ent><br/
<hw>Mot"tle</hw>, <pos>n.</pos> <def>A mottled appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mottled</ent><br/
<hw>Mot"tled</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Motley</er>.]</ety> <def>Marked with spots of different colors;
variegated; spotted; <as>as, <ex>mottled</ex> wood</as>.</def>
<ldquo/The <xex>mottled</xex> meadows.<rdquo/
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mottling</ent><br/
<hw>mottling</hw> <pos>n.</pos> <sn>1.</sn> <def>the act of coloring
with areas of different shades.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A mottled pattern.</def><br/
[<source>PJC</source>]</p>

<p><ent>Motto</ent><br/
<hw>Mot"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mottoes</plw> <pr>(#)</pr>.</plu> <ety>[It. <ets>motto</ets> a
word, a saying, L. <ets>muttum</ets> a mutter, a grunt, cf.
<ets>muttire</ets>, <ets>mutire</ets>, to mutter, mumble; prob. of
imitative origin. Cf. <er>Mot</er> a word.]</ety> <sn>1.</sn>
<fld>(Her.)</fld> <def>A sentence, phrase, or word, forming part of an
heraldic achievment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sentence, phrase, or word, prefixed to an essay,
discourse, chapter, canto, or the like, suggestive of its subject
matter; a short, suggestive expression of a guiding principle; a
maxim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was the <qex>motto</qex> of a bishop eminent for his piety and
good works, . . . <ldquo/Serve God, and be cheerful.<rdquo/</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mottoed</ent><br/
<hw>Mot"toed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bearing or having a
motto; <as>as, a <ex>mottoed</ex> coat or device</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Motty</ent><br/
<hw>Mot"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of, or consisting
of, motes.</def> <altsp>[Written also <asp>mottie</asp>.]</altsp>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>motty</qex> dust reek raised by the workmen.</q>
<rj><qau>H. Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouchoir</ent><br/
\'d8<hw>Mou`choir"</hw> <pr>(m<oomac/`shw<aum/r")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A handkerchief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouezzin</ent><br/
<hw>Mou*ez"zin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>See
<er>Muezzin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouflon</ent><br/
<hw>Mouf"lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mouflon</ets>.]</ety> <fld>(Zool.)</fld> <def>A wild sheep
(<spn>Ovis musimon</spn>), inhabiting the mountains of Sardinia,
Corsica, etc. Its horns are very large, with a triangular base and
rounded angles. It is supposed by some to be the original of the
domestic sheep. Called also <altname>musimon</altname> or
<altname>musmon</altname>.</def> <altsp>[Written also
<asp>moufflon</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mought</ent><br/
<hw>Mought</hw> <pr>(mout)</pr>, <mark>obs.</mark> <pos>imp.</pos>
<mord>of <er>May</er>.</mord> <def>Might.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouillation</ent><br/
\'d8<hw>Mouil*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mouill<eacute/</er>.]</ety> <fld>(Phon.)</fld> <def>The act of
uttering the sound of a mouill<eacute/ letter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouille</ent><br/
\'d8<hw>Mouil`l<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.,
lit., wet.]</ety> <fld>(Phon.)</fld> <def>Applied to certain consonants
having a <ldquo/liquid<rdquo/ or softened sound; <it>e. g.</it>, in
French, <it>l</it> or <it>ll</it> and <it>gn</it> (like the <it>lli</it>
in <xex>million</xex> and <it>ni</it> in <xex>minion</xex>); in Italian,
<it>gl</it> and <it>gn</it>; in Spanish, <it>ll</it> and
<it><ntil/</it>; in Portuguese, <it>lh</it> and <it>nh.</it></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouldy</ent><br/
<ent>Moulder</ent><br/
<ent>Mould</ent><br/
<mhw>{ <hw>Mould</hw> <pr>(m<omac/lt)</pr>, <hw>Mould"er</hw>
<pr>(m<omac/ld"<etil/r)</pr>, <hw>Mould"y</hw>
<pr>(m<omac/ld"<ycr/)</pr>, etc. }</mhw> <def>See <er>Mold</er>,
<er>Molder</er>, <er>Moldy</er>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moulding</ent><br/
<hw>moulding</hw> <pos>n.</pos> <sn>1.</sn> <def>a sculpture produced by
molding.</def><br/
<syn><b>Syn. --</b> mold, mould, molding, modeling, clay
sculpture.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a decorative recessed or relieved surface.</def><br/
<syn><b>Syn. --</b> molding, border.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a decorative strip used for ornamentation or
finishing.</def><br/
<syn><b>Syn. --</b> molding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>a preliminary sculpture in wax or clay from which a
finished work can be copied.</def><br/
<syn><b>Syn. --</b> modeling, molding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moule</ent><br/
<hw>Moule</hw> <pr>(m<omac/l)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>moulen</ets>. See <er>Mold</er>.]</ety> <def>To contract mold; to
grow moldy; to mold.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us not <qex>moulen</qex> thus in idleness.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moulinet</ent><br/
<ent>Mouline</ent><br/
<mhw>{ <hw>Mou*line"</hw> <pr>(?)</pr>, <hw>Mou"li*net</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[F. <ets>moulinet</ets>, orig.,
a little mill, dim. of <ets>moulin</ets> mill. See <er>Mill</er>.]</ety>
<sn>1.</sn> <def>The drum upon which the rope is wound in a capstan,
crane, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A machine formerly used for bending a crossbow by
winding it up.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In sword and saber exercises, a circular swing of
the weapon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moult</ent><br/
<hw>Moult</hw> <pr>(m<omac/lt)</pr>, <pos>v. & n.</pos> <def>See
<er>Molt</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moulten</ent><br/
<hw>Moult"en</hw> <pr>(m<omac/lt'n)</pr>, <pos>a.</pos> <def>Having
molted.</def> <mark>[Obs.]</mark> <ldquo/A <xex>moulten</xex>
raven.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moun</ent><br/
<hw>Moun</hw> <pr>(moun)</pr>, <pos>v.</pos>, <def><pos>pl.</pos> of
<er>Mow</er>, may.</def> <mark>[Obs.]</mark>
<rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mounch</ent><br/
<hw>Mounch</hw> <pr>(mounch)</pr>, <pos>v. t.</pos> <def>To munch.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mound</ent><br/
<hw>Mound</hw> <pr>(mound)</pr>, <pos>n.</pos> <ety>[F. <ets>monde</ets>
the world, L. <ets>mundus</ets>. See <er>Mundane</er>.]</ety> <def>A
ball or globe forming part of the regalia of an emperor or other
sovereign. It is encircled with bands, enriched with precious stones,
and surmounted with a cross; -- called also
<altname>globe</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mound</ent><br/
<hw>Mound</hw>, <pos>n.</pos> <ety>[OE. <ets>mound</ets>,
<ets>mund</ets>, protection, AS. <ets>mund</ets> protection, hand; akin
to OHG. <ets>munt</ets>, Icel. <ets>mund</ets> hand, and prob. to L.
<ets>manus</ets>. See <er>Manual</er>.]</ety> <def>An artificial hill or
elevation of earth; a raised bank; an embarkment thrown up for defense;
a bulwark; a rampart; also, a natural elevation appearing as if thrown
up artificially; a regular and isolated hill, hillock, or
knoll.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To thrid the thickets or to leap the <qex>mounds</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mound bird</b></col>. <fld>(Zool.)</fld> <cd>See
<er>moundbird</er> in the vocabulary.</cd> -- <col><b>Mound
builders</b></col> <fld>(Ethnol.)</fld>, <cd>the tribe, or tribes, of
North American aborigines who built, in former times, extensive mounds
of earth, esp. in the valleys of the Mississippi and Ohio Rivers.
Formerly they were supposed to have preceded the Indians, but later
investigations go to show that they were, in general, identical with the
tribes that occupied the country when discovered by Europeans.</cd> --
<col><b>Mound maker</b></col> <fld>(Zool.)</fld>, <cd>any one of the
<er>megapodes</er>. See also <er>moundbird</er> in the vocabulary.</cd>
-- <col><b>Shell mound</b></col>, <cd>a mound of refuse shells,
collected by aborigines who subsisted largely on shellfish. See
<er>Midden</er>, and <er>Kitchen middens</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mound</ent><br/
<hw>Mound</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mounded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mounding</conjf>.]</vmorph> <def>To fortify or inclose with a
mound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mound bird</ent><br/
<ent>moundbird</ent><br/
<mhw><hw>moundbird</hw>, <hw>mound bird</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any of several large-footed short-winged birds
of Australasia, which build mounds of decaying vegetation to incubate
eggs. Called also <altname>mound builder</altname>, <altname>mound
maker</altname>, <altname>megapode</altname>, <altname>brush
turkey</altname>, and <altname>scrub fowl</altname>.</def><br/
<syn><b>Syn. --</b> megapode, mound builder, scrub fowl, brush
turkey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mount</ent><br/
<hw>Mount</hw> <pr>(mount)</pr>, <pos>n.</pos> <ety>[OE.
<ets>munt</ets>, <ets>mont</ets>, <ets>mount</ets>, AS. <ets>munt</ets>,
fr. L. <ets>mons</ets>, <ets>montis</ets>; cf. L. <ets>minae</ets>
protections, E. <ets>eminent</ets>, <ets>menace</ets>: cf. F.
<ets>mont</ets>. Cf. <er>Mount</er>, <pos>v.</pos>, <er>Mountain</er>,
<er>Mont</er>, <er>Monte</er>, <er>Montem</er>.]</ety> <sn>1.</sn>
<def>A mass of earth, or earth and rock, rising considerably above the
common surface of the surrounding land; a mountain; a high hill; -- used
always instead of <xex>mountain</xex>, when put before a proper name;
<as>as, <ex>Mount</ex> Washington</as>; otherwise, chiefly in
poetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bulwark for offense or defense; a mound.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Hew ye down trees, and cast a <qex>mount</qex> against
Jerusalem.</q> <rj><qau>Jer. vi. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[See <er>Mont de pi<eacute/t<eacute/</er>.]</ety>
<def>A bank; a fund.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Palmistry)</fld> <def>Any one of seven fleshy
prominences in the palm of the hand which are taken as significant of
the influence of <ldquo/planets,<rdquo/ and called the <xex>mounts</xex>
of Jupiter, Mars, Mercury, the Moon, Saturn, the Sun or Apollo, and
Venus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Mount of piety</b></col>. <cd>See <er>Mont de
pi<eacute/t<eacute/</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mount</ent><br/
<hw>Mount</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mounted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mounting</conjf>.]</vmorph> <ety>[OE. <ets>mounten</ets>,
<ets>monten</ets>, F. <ets>monter</ets>, fr. L. <ets>mons</ets>,
<ets>montis</ets>, mountain. See <er>Mount</er>, <pos>n.</pos>
(above).]</ety> <sn>1.</sn> <def>To rise on high; to go up; to be
upraised or uplifted; to tower aloft; to ascend; -- often with
<xex>up</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though Babylon should <qex>mount</qex> up to heaven.</q>
<rj><qau>Jer. li. 53.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The fire of trees and houses <qex>mounts</qex> on high.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To get up on anything, as a platform or scaffold;
especially, to seat one's self on a horse for riding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To attain in value; to amount.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bring then these blessings to a strict account,<br/
Make fair deductions, see to what they <qex>mount</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mount</ent><br/
<hw>Mount</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To get upon; to
ascend; to climb; <as>as, to <ex>mount</ex> the pulpit and deliver a
sermon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall we <qex>mount</qex> again the rural throne?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place one's self on, as a horse or other animal,
or anything that one sits upon; to bestride.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to mount; to put on horseback; to furnish
with animals for riding; to furnish with horses.</def> <ldquo/To
<xex>mount</xex> the Trojan troop.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence: To put upon anything that sustains and fits
for use, as a gun on a carriage, a map or picture on cloth or paper; to
prepare for being worn or otherwise used, as a diamond by setting, or a
sword blade by adding the hilt, scabbard, etc.; <as>as, to
<ex>mount</ex> a picture or diploma in a frame</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To raise aloft; to lift on high.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What power is it which <qex>mounts</qex> my love so high?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A fort or ship is said to <xex>mount</xex> cannon, when
it has them arranged for use in or about it.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To mount guard</b></col> <fld>(Mil.)</fld>, <cd>to go on
guard; to march on guard; to do duty as a guard.</cd> -- <col><b>To
mount a play</b></col>, <cd>to prepare and arrange the scenery,
furniture, etc., used in the play.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mount</ent><br/
<hw>Mount</hw>, <pos>n.</pos> <ety>[From <er>Mount</er>,
<pos>v.</pos>]</ety> <def>That upon which a person or thing is
mounted</def>, <specif>especially:</specif> <sd>(a)</sd> <def>A
horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She had so good a seat and hand, she might be trusted with any
<qex>mount</qex>.</q> <rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>The cardboard or cloth on which a drawing,
photograph, or the like is mounted; a mounting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountable</ent><br/
<hw>Mount"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
mounted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountain</ent><br/
<hw>Moun"tain</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>mountaine</ets>, <ets>montaine</ets>, F. <ets>montagne</ets>, LL.
<ets>montanea</ets>, <ets>montania</ets>, fr. L. <ets>mons</ets>,
<ets>montis</ets>, a mountain; cf. <ets>montanus</ets> belonging to a
mountain. See 1st <er>Mount</er>.]</ety> <sn>1.</sn> <def>A large mass
of earth and rock, rising above the common level of the earth or
adjacent land; earth and rock forming an isolated peak or a ridge; an
eminence higher than a hill; a mount.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>A range, chain, or group of such
elevations; <as>as, the White <ex>Mountains</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mountainlike mass; something of great bulk; a
large quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I should have been a <qex>mountain</qex> of mummy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Mountain</b></col> (<au>La montagne</au>)
<fld>(French Hist.)</fld>, <cd>a popular name given in 1793 to a party
of extreme Jacobins in the National Convention, who occupied the highest
rows of seats.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 949 --></p>

<p><ent>Mountain</ent><br/
<hw>Moun"tain</hw> <pr>(moun"t<icr/n)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Of or pertaining to a mountain or mountains; growing or living on a
mountain; found on or peculiar to mountains; among mountains; <as>as, a
<ex>mountain</ex> torrent; <ex>mountain</ex> pines; <ex>mountain</ex>
goats; <ex>mountain</ex> air; <ex>mountain</ex> howitzer.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like a mountain; mountainous; vast; very
great.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The high, the <qex>mountain</qex> majesty of worth.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mountain antelope</b></col> <fld>(Zool.)</fld>, <cd>the
goral.</cd> -- <col><b>Mountain ash</b></col> <fld>(Bot.)</fld>, <cd>an
ornamental tree, the <spn>Pyrus Americana</spn> (or <spn>Sorbus
Americana</spn>), producing beautiful bunches of red berries. Its leaves
are pinnate, and its flowers white, growing in fragrant clusters. The
European species is the <spn>Pyrus aucuparia</spn>, or rowan tree.</cd>
-- <col><b>Mountain barometer</b></col>, <cd>a portable barometer,
adapted for safe transportation, used in measuring the heights of
mountains.</cd> -- <col><b>Mountain beaver</b></col> <fld>(Zool.)</fld>,
<cd>the sewellel.</cd> -- <col><b>Mountain blue</b></col>
<fld>(Min.)</fld>, <cd>blue carbonate of copper; azurite.</cd> --
<col><b>Mountain cat</b></col> <fld>(Zool.)</fld>, <cd>the catamount.
See <er>Catamount</er>.</cd> -- <col><b>Mountain chain</b></col>, <cd>a
series of contiguous mountain ranges, generally in parallel or
consecutive lines or curves.</cd> -- <col><b>Mountain cock</b></col>
<fld>(Zool.)</fld>, <cd>capercailzie. See <er>Capercailzie</er>.</cd> --
<col><b>Mountain cork</b></col> <fld>(Min.)</fld>, <cd>a variety of
asbestus, resembling cork in its texture.</cd> -- <col><b>Mountain
crystal</b></col>. <cd>See under <er>Crystal</er>.</cd> --
<col><b>Mountain damson</b></col> <fld>(Bot.)</fld>, <cd>a large tree of
the genus <gen>Simaruba</gen> (<spn>Simaruba amarga</spn>) growing in
the West Indies, which affords a bitter tonic and astringent, sometimes
used in medicine.</cd> -- <col><b>Mountain dew</b></col>, <cd>Scotch
whisky, so called because often illicitly distilled among the
mountains.</cd> <mark>[Humorous]</mark> -- <col><b>Mountain
ebony</b></col> <fld>(Bot.)</fld>, <cd>a small leguminous tree
(<spn>Bauhinia variegata</spn>) of the East and West Indies; -- so
called because of its dark wood. The bark is used medicinally and in
tanning.</cd> -- <col><b>Mountain flax</b></col> <fld>(Min.)</fld>,
<cd>a variety of asbestus, having very fine fibers; amianthus. See
<er>Amianthus</er>.</cd> -- <col><b>Mountain fringe</b></col>
<fld>(Bot.)</fld>, <cd>climbing fumitory. See under
<er>Fumitory</er>.</cd> -- <col><b>Mountain goat</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Mazama</er>.</cd> -- <col><b>Mountain
green</b></col>. <fld>(Min.)</fld> <sd>(a)</sd> <cd>Green malachite, or
carbonate of copper</cd>. <sd>(b)</sd> <cd>See <cref>Green earth</cref>,
under <er>Green</er>, <pos>a.</pos></cd> -- <col><b>Mountain
holly</b></col> <fld>(Bot.)</fld>, <cd>a branching shrub
(<spn>Nemopanthes Canadensis</spn>), having smooth oblong leaves and red
berries. It is found in the Northern United States.</cd> --
<col><b>Mountain laurel</b></col> <fld>(Bot.)</fld>, <cd>an American
shrub (<spn>Kalmia latifolia</spn>) with glossy evergreen leaves and
showy clusters of rose-colored or white flowers. The foliage is
poisonous. Called also <altname>American laurel</altname>, <altname>ivy
bush</altname>, and <altname>calico bush</altname>. See
<er>Kalmia</er>.</cd> -- <col><b>Mountain leather</b></col>
<fld>(Min.)</fld>, <cd>a variety of asbestus, resembling leather in its
texture.</cd> -- <col><b>Mountain licorice</b></col> <fld>(Bot.)</fld>,
<cd>a plant of the genus <gen>Trifolium</gen> (<spn>Trifolium
Alpinum</spn>).</cd> -- <col><b>Mountain limestone</b></col>
<fld>(Geol.)</fld>, <cd>a series of marine limestone strata below the
coal measures, and above the old red standstone of Great Britain. See
<xex>Chart</xex> of <er>Geology</er>.</cd> -- <col><b>Mountain
linnet</b></col> <fld>(Zool.)</fld>, <cd>the twite.</cd> --
<col><b>Mountain magpie</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>The yaffle, or green woodpecker</cd>. <sd>(b)</sd> <cd>The European
gray shrike.</cd> -- <col><b>Mountain mahogany</b></col>
<fld>(Bot.)</fld> <cd>See under <er>Mahogany</er>.</cd> --
<col><b>Mountain meal</b></col> <fld>(Min.)</fld>, <cd>a light powdery
variety of calcite, occurring as an efflorescence.</cd> --
<col><b>Mountain milk</b></col> <fld>(Min.)</fld>, <cd>a soft spongy
variety of carbonate of lime.</cd> -- <col><b>Mountain mint</b></col>.
<fld>(Bot.)</fld> <cd>See <er>Mint</er>.</cd> -- <col><b>Mountain
ousel</b></col> <fld>(Zool.)</fld>, <cd>the ring ousel; -- called also
<altname>mountain thrush</altname> and <altname>mountain
colley</altname>. See <er>Ousel</er>.</cd> -- <mcol><col><b>Mountain
pride</b></col>, <it>or</it> <col><b>Mountain green</b></col></mcol>
<fld>(Bot.)</fld>, <cd>a tree of Jamaica (<spn>Spathelia simplex</spn>),
which has an unbranched palmlike stem, and a terminal cluster of large,
pinnate leaves.</cd> -- <col><b>Mountain quail</b></col>
<fld>(Zool.)</fld>, <cd>the plumed partridge (<spn>Oreortyx
pictus</spn>) of California. It has two long, slender, plumelike
feathers on the head. The throat and sides are chestnut; the belly is
brown with transverse bars of black and white; the neck and breast are
dark gray.</cd> -- <col><b>Mountain range</b></col>, <cd>a series of
mountains closely related in position and direction.</cd> --
<col><b>Mountain rice</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd> <cd>An
upland variety of rice, grown without irrigation, in some parts of Asia,
Europe, and the United States</cd>. <sd>(b)</sd> <cd>An American genus
of grasses (<gen>Oryzopsis</gen>).</cd> -- <col><b>Mountain
rose</b></col> <fld>(Bot.)</fld>, <cd>a species of rose with solitary
flowers, growing in the mountains of Europe (<spn>Rosa
alpina</spn>).</cd> -- <col><b>Mountain soap</b></col>
<fld>(Min.)</fld>, <cd>a soft earthy mineral, of a brownish color, used
in crayon painting; saxonite.</cd> -- <col><b>Mountain sorrel</b></col>
<fld>(Bot.)</fld>, <cd>a low perennial plant (<spn>Oxyria digyna</spn>
with rounded kidney-form leaves, and small greenish flowers, found in
the White Mountains of New Hampshire, and in high northern
latitudes.</cd> <au>Gray.</au> -- <col><b>Mountain sparrow</b></col>
<fld>(Zool.)</fld>, <cd>the European tree sparrow.</cd> --
<col><b>Mountain spinach</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Orach</er>.</cd> -- <col><b>Mountain tobacco</b></col>
<fld>(Bot.)</fld>, <cd>a composite plant (<spn>Arnica montana</spn>) of
Europe; called also <altname>leopard's bane</altname>.</cd> --
<col><b>Mountain witch</b></col> <fld>(Zool.)</fld>, <cd>a ground pigeon
of Jamaica, of the genus <gen>Geotrygon</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountaineer</ent><br/
<hw>Moun`tain*eer"</hw> <pr>(moun`t<icr/n*<emac/r")</pr>, <pos>n.</pos>
<ety>[OF. <ets>montanier</ets>, LL. <ets>montanarius</ets>. See
<er>Mountain</er>.]</ety> <sn>1.</sn> <def>An inhabitant of a mountain;
one who lives among mountains.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rude, fierce person.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No savage fierce, bandit, or <qex>mountaineer</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person who climbs mountains for sport.</def><br/
[<source>PJC</source>]</p>

<p><ent>mountaineer</ent><br/
<hw>moun`tain*eer"</hw>, <pos>v. i.</pos> <def>To live or act as a
mountaineer; to climb mountains.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You can't go <qex>mountaineering</qex> in a flat country.</q>
<rj><qau>H. James.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mountaineering</ent><br/
<hw>moun`tain*eer"ing</hw> <pr>(moun`t<icr/n*<emac/r"<icr/ng)</pr>,
<pos>n.</pos> <def>Climbing mountains as a sport.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mountainer</ent><br/
<hw>Moun"tain*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
mountaineer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountainet</ent><br/
<hw>Moun"tain*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small
mountain.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountainous</ent><br/
<hw>Moun"tain*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>montagneux</ets>, L. <ets>montaniosus</ets>.]</ety> <sn>1.</sn>
<def>Full of, or containing, mountains; <as>as, the <ex>mountainous</ex>
country of the Swiss</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inhabiting mountains.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Large as, or resembling, a mountain; huge; of great
bulk; <as>as, a <ex>mountainous</ex> heap</as>.</def>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountainousness</ent><br/
<hw>Moun"tain*ous*ness</hw>, <pos>n.</pos> <def>The state or quality of
being mountainous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountance</ent><br/
<hw>Mount"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>montance</ets>.]</ety> <def>Amount; sum; quantity; extent.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountain specter</ent><br/
<hw>Moun"tain spec"ter</hw>. <def>An optical phenomenon sometimes seen
on the summit of mountains (as on the Brocken) when the observer is
between the sun and a mass of cloud. The figures of the observer and
surrounding objects are seen projected on the cloud, greatly enlarged
and often encircled by rainbow colors.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mountain State</ent><br/
<hw>Moun"tain State</hw>. <def>Montana; -- a nickname.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mountant</ent><br/
<hw>Mount"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>montant</ets>, p. pr. of <ets>monter</ets>. See <er>Mount</er>, and
cf. <er>Montant</er>.]</ety> <def>Raised; high.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountebank</ent><br/
<hw>Mount"e*bank</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>montimbanco</ets>, <ets>montambanco</ets>; <ets>montare</ets> to
mount + <ets>in</ets> in, upon + <ets>banco</ets> bench. See
<er>Mount</er>, and 4th <er>Bank</er>.]</ety> <sn>1.</sn> <def>One who
mounts a bench or stage in the market or other public place, boasts of
his skill in curing diseases, and vends medicines which he pretends are
infallible remedies; a quack doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such is the weakness and easy credulity of men, that a
<qex>mountebank</qex> . . . is preferred before an able physician.</q>
<rj><qau>Whitlock.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any boastful or false pretender; a charlatan; a
quack.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing so impossible in nature but <qex>mountebanks</qex> will
undertake.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountebank</ent><br/
<hw>Mount"e*bank</hw>, <pos>v. t.</pos> <def>To cheat by boasting and
false pretenses; to gull.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountebank</ent><br/
<hw>Mount"e*bank</hw>, <pos>v. i.</pos> <def>To play the
mountebank.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountebankery</ent><br/
<hw>Mount"e*bank`er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
practices of a mountebank; quackery; boastful and vain
pretenses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountebankish</ent><br/
<hw>Mount"e*bank`ish</hw>, <pos>a.</pos> <def>Like a mountebank or his
quackery.</def> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountebankism</ent><br/
<hw>Mount"e*bank*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The practices
of a mountebank; mountebankery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mounted</ent><br/
<hw>Mount"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Seated or serving on
horseback or similarly; <as>as, <ex>mounted</ex> police;
<ex>mounted</ex> infantry.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Placed on a suitable support, or fixed in a setting;
<as>as, a <ex>mounted</ex> gun; a <ex>mounted</ex> map; a
<ex>mounted</ex> gem.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountenaunce</ent><br/
<hw>Mount"e*naunce</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Mountance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mounter</ent><br/
<hw>Mount"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
mounts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An animal mounted; a monture.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mounting</ent><br/
<hw>Mount"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one that
mounts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That by which anything is prepared for use, or set
off to advantage; equipment; embellishment; setting; <as>as, the
<ex>mounting</ex> of a sword or diamond</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Aeronautics)</fld> <def>same as
<er>Carriage</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mountingly</ent><br/
<hw>Mount"ing*ly</hw>, <pos>adv.</pos> <def>In an ascending
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mountlet</ent><br/
<hw>Mount"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small or low
mountain.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mounty</ent><br/
<hw>Mount"y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mont<eacute/e</ets>, fr. <ets>monter</ets>. See <er>Mount</er>,
<pos>v.</pos>]</ety> <def>The rise of a hawk after prey.</def>
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourn</ent><br/
<hw>Mourn</hw> <pr>(m<omac/rn)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Mourned</conjf> <pr>(m<omac/rnd)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Mourning</conjf>.]</vmorph> <ety>[AS.
<ets>murnan</ets>; akin to OS. <ets>mornian</ets>, OHG.
<ets>mornen</ets>, Goth. <ets>ma<uacute/rnan</ets>.]</ety> <sn>1.</sn>
<def>To express or to feel grief or sorrow; to grieve; to be sorrowful;
to lament; to be in a state of grief or sadness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Abraham came to <qex>mourn</qex> for Sarah, and to weep for
her.</q> <rj><qau>Gen. xxiii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wear the customary garb of a mourner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>mourn</qex> in black; why <qex>mourn</qex> we not in
blood?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Grieve for an hour, perhaps, then <qex>mourn</qex> a year.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourn</ent><br/
<hw>Mourn</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To grieve for; to
lament; to deplore; to bemoan; to bewail.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As if he <qex>mourned</qex> his rival's ill success.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And looking over the hills, I <qex>mourn</qex><br/
The darling who shall not return.</q> <rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter in a mournful manner or voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lovelorn nightingale<br/
Nightly to thee her sad song <qex>mourneth</qex> well.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Deplore</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourne</ent><br/
<hw>Mourne</hw> <pr>(m<omac/rn)</pr>, <pos>n.</pos> <ety>[See 2d
<er>Morne</er>.]</ety> <def>The armed or feruled end of a staff; in a
sheephook, the end of the staff to which the hook is attached.</def>
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourner</ent><br/
<hw>Mourn"er</hw> <pr>(m<omac/rn"<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who mourns or is grieved at any misfortune, as the
death of a friend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>mourners</qex> were two hosts, his friends and foes.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who attends a funeral as a hired
mourner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mourners</qex> were provided to attend the funeral.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mournful</ent><br/
<hw>Mourn"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of sorrow;
expressing, or intended to express, sorrow; mourning; grieving; sad;
also, causing sorrow; saddening; grievous; <as>as, a <ex>mournful</ex>
person; <ex>mournful</ex> looks, tones, loss.</as></def> --
<wordforms><wf>Mourn"ful*ly</wf>, <pos>adv.</pos> --
<wf>Mourn"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Sorrowful; lugubrious; sad; doleful; heavy;
afflictive; grievous; calamitous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourning</ent><br/
<hw>Mourn"ing</hw>, <pos>n.</pos> <ety>[AS. <ets>murnung</ets>.]</ety>
<sn>1.</sn> <def>The act of sorrowing or expressing grief; lamentation;
sorrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Garb, drapery, or emblems indicative of grief, esp.
clothing or a badge of somber black.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The houses to their tops with black were spread,<br/
And ev'n the pavements were with <qex>mourning</qex> hid.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deep mourning</b></col>. <cd>See under
<er>Deep</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourning</ent><br/
<hw>Mourn"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Grieving; sorrowing;
lamenting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Employed to express sorrow or grief; worn or used as
appropriate to the condition of one bereaved or sorrowing; <as>as,
<ex>mourning</ex> garments; a <ex>mourning</ex> ring; a
<ex>mourning</ex> pin, and the like.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mourning bride</b></col> <fld>(Bot.)</fld>, <cd>a garden
flower (<spn>Scabiosa atropurpurea</spn>) with dark purple or crimson
flowers in flattened heads.</cd> -- <col><b>Mourning dove</b></col>
<fld>(Zool.)</fld>, <cd>a wild dove (<spn>Zenaidura macroura</spn>)
found throughout the United States; -- so named from its plaintive note.
Called also <altname>Carolina dove</altname>. See <xex>Illust.</xex>
under <er>Dove</er>.</cd> -- <col><b>Mourning warbler</b></col>
<fld>(Zool.)</fld>, <cd>an American ground warbler (<spn>Geothlypis
Philadelphia</spn>). The male has the head, neck, and chest, deep
ash-gray, mixed with black on the throat and chest; other lower parts
are pure yellow.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mourningly</ent><br/
<hw>Mourn"ing*ly</hw>, <pos>adv.</pos> <def>In a mourning
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mournival</ent><br/
<hw>Mour"ni*val</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Murnival</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouse</ent><br/
<hw>Mouse</hw> <pr>(mous)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mice</plw> <pr>(m<imac/s)</pr>.</plu> <ety>[OE. <ets>mous</ets>,
<ets>mus</ets>, AS. <ets>m<umac/s</ets>, pl. <ets>m<ymac/s</ets>; akin
to D. <ets>muis</ets>, G. <ets>maus</ets>, OHG. & Icel.
<ets>m<umac/s</ets>, Dan. <ets>muus</ets>, Sw. <ets>mus</ets>, Russ.
<ets>muishe</ets>, L. <ets>mus</ets>, Gr. <grk>my^s</grk>, Skr.
<ets>m<umac/sh</ets> mouse, <ets>mush</ets> to steal. <root/277. Cf.
<er>Muscle</er>, <er>Musk</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>Any one of numerous species of small rodents belonging to the genus
<gen>Mus</gen> and various related genera of the family
<fam>Muridae</fam>. The common house mouse (<spn>Mus musculus</spn>) is
found in nearly all countries. The American <stype>white-footed
mouse</stype>, or <stype>deer mouse</stype> (<spn>Peromyscus
leucopus</spn>, formerly <spn>Hesperomys leucopus</spn>) sometimes lives
in houses. See <er>Dormouse</er>, <cref>Meadow mouse</cref>, under
<er>Meadow</er>, and <cref>Harvest mouse</cref>, under
<er>Harvest</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A knob made on a
rope with spun yarn or parceling to prevent a running eye from
slipping.</def> <sd>(b)</sd> <def>Same as 2d <er>Mousing</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A familiar term of endearment.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A dark-colored swelling caused by a blow.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A match used in firing guns or blasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Field mouse</b></col>, <col><b>Flying
mouse</b></col></mcol>, etc. <cd>See under <er>Field</er>,
<er>Flying</er>, etc.</cd> -- <col><b>Mouse bird</b></col>
<fld>(Zool.)</fld>, <cd>a coly.</cd> -- <col><b>Mouse deer</b></col>
<fld>(Zool.)</fld>, <cd>a chevrotain, as the kanchil.</cd> --
<col><b>Mouse galago</b></col> <fld>(Zool.)</fld>, <cd>a very small West
American galago (<spn>Galago murinus</spn>). In color and size it
resembles a mouse. It has a bushy tail like that of a squirrel.</cd> --
<col><b>Mouse hawk</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A hawk
that devours mice</cd>. <sd>(b)</sd> <cd>The hawk owl; -- called also
<altname>mouse owl</altname>.</cd> -- <col><b>Mouse lemur</b></col>
<fld>(Zool.)</fld>, <cd>any one of several species of very small lemurs
of the genus <gen>Chirogaleus</gen>, found in Madagascar.</cd> --
<col><b>Mouse piece</b></col> <fld>(Cookery)</fld>, <cd>the piece of
beef cut from the part next below the round or from the lower part of
the latter; -- called also <altname>mouse
buttock</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouse</ent><br/
<hw>Mouse</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Moused</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mousing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To watch
for and catch mice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To watch for or pursue anything in a sly manner; to
pry about, on the lookout for something.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouse</ent><br/
<hw>Mouse</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To tear, as a cat
devours a mouse.</def> <mark>[Obs.]</mark> <ldquo/[Death]
<xex>mousing</xex> the flesh of men.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To furnish with a mouse; to
secure by means of a mousing. See <er>Mouse</er>, <pos>n.</pos>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouse-ear</ent><br/
<hw>Mouse"-ear`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The forget-me-not (<spn>Myosotis palustris</spn>) and
other species of the same genus.</def> <sd>(b)</sd> <def>A European
species of hawkweed (<spn>Hieracium Pilosella</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mouse-ear chickweed</b></col>, <cd>a name of two common
species of chickweed (<spn>Cerastium vulgarium</spn>, and <spn>Cerastium
viscosum</spn>).</cd> -- <col><b>Mouse-ear cress</b></col>, <cd>a low
cruciferous herb (<spn>Sisymbrium Thaliana</spn>). All these are low
herbs with soft, oval, or obovate leaves, whence the name.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousefish</ent><br/
<hw>Mouse"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Frogfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousehole</ent><br/
<hw>Mouse"hole`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hole made by a
mouse, for passage or abode, as in a wall; hence, a very small hole like
that gnawed by a mouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mousekin</ent><br/
<hw>mouse"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little
mouse.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mouseketeer</ent><br/
<hw>mouse"ke*teer`</hw> <pr>(mous"k<ecr/*t<emac/r`)</pr>, <pos>n.</pos>
<def>One of a group of children appearing on the television program
<membof>The Mickey Mouse Club</membof> in the 1950's.</def> <mark>[U.
S.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Mouser</ent><br/
<hw>Mous"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A cat that
catches mice; <as>as, a good <ex>mouser</ex> is better than a dozen
mousetraps</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>One who pries about on the lookout for
something.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousetail</ent><br/
<hw>Mouse"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A genus of ranunculaceous plants (<gen>Myosurus</gen>), in which
the prolonged receptacle is covered with imbricating achenes, and so
resembles the tail of a mouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mouse trap</ent><br/
<ent>mousetrap</ent><br/
<mhw><hw>mouse"trap`</hw>, <hw>mouse" trap`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>Any device that catches, and usually kills, mice.
They are of various designs, the most common being a stiff loop of wire
mounted on a small wooden platform base and attached to a strong spring,
which holds the loop firmly against the base. To activate the trap, the
loop is pulled through a 180<deg/ arc against the tension of the spring
and held against the base by a delicate metal catch, which can keep the
loop from moving, though in a state of high tension. The metal catch is
moved when a mouse tries to take a piece of bait attached to it,
releasing the loop which forcefully moves though an arc, usually killing
the mouse. A larger version of the same device is used as a <contr>rat
trap</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousie</ent><br/
<hw>Mous"ie</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Diminutive for
<er>Mouse</er>.</def> <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousing</ent><br/
<hw>Mous"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Impertinently
inquisitive; prying; meddlesome.</def> <ldquo/<xex>Mousing</xex>
saints.<rdquo/ <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousing</ent><br/
<hw>Mous"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of hunting
mice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A turn or lashing of spun yarn or
small stuff, or a metallic clasp or fastening, uniting the point and
shank of a hook to prevent its unhooking or straighening out.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A ratchet movement in a loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mousing hook</b></col>, <cd>a hook with an attachment
which prevents its unhooking.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousle</ent><br/
<hw>Mou"sle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To sport with
roughly; to rumple.</def> <altsp>[Written also
<asp>mouzle</asp>.]</altsp> <mark>[Obs.]</mark>
<rj><au>Wycherley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousquetaire</ent><br/
\'d8<hw>Mous`que*taire"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>A musketeer, esp. one of the French royal musketeers of
the 17th and 18th centuries, conspicuous both for their daring and their
fine dress.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A mosquetaire cuff or glove, or other article of
dress fancied to resemble those worn by the French
mosquetaires.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mousquetaire cuff</ent><br/
<hw>Mousquetaire cuff</hw>. <def>A deep flaring cuff.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mousquetaire glove</ent><br/
<hw>Mousquetaire glove</hw>. <def>A woman's glove with a long, loosely
fitting wrist.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mousse</ent><br/
<hw>Mousse</hw> <pr>(m<oomac/s)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <fld>(Cookery)</fld> <def>A frozen dessert of a frothy
texture, made of sweetened and flavored whipped cream, sometimes with
the addition of egg yolks and gelatin. Mousse differs from ice cream in
being beaten before -- not during -- the freezing process.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Any of a variety of foods whipped to a light
texture; <as>as, a salmon <ex>mousse</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A foam containing special chemicals, used for
styling hair.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mousseline</ent><br/
\'d8<hw>Mousse`line"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Muslin.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mousseline de laine</b></col> <pr>(<?/)</pr>. <ety>[F.,
muslin of wool.]</ety> <cd>Muslin delaine. See under
<er>Muslin</er>.</cd> -- <col><b>Mousseline glass</b></col>, <cd>a kind
of thin blown glassware, such as wineglasses, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mousseline de soie</ent><br/
\'d8<hw>Mousse`line de soie"</hw> <pr>(?)</pr>. <ety>[F.]</ety> <def>A
soft thin silk fabric with a weave like that of muslin.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Moustache</ent><br/
<hw>Mous`tache"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Mustache.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>moustachio</ent><br/
<hw>moustachio</hw> <pos>n.</pos> <def>A large bushy
moustache.</def><br/
<syn><b>Syn. --</b> mustachio, handle-bars.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mousy</ent><br/
<hw>Mous"y</hw> <pr>(mouz"<ycr/)</pr>, <pos>a.</pos> <def>Infested with
mice; smelling of mice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moutan</ent><br/
<hw>Mou"tan</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The
Chinese tree peony (<spn>Paeonia Mountan</spn>), a shrub with large
flowers of various colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouth</ent><br/
<hw>Mouth</hw> <pr>(mouth)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mouths</plw> <pr>(mou<th/z)</pr>.</plu> <ety>[OE. <ets>mouth</ets>,
<ets>mu<thorn/</ets>, AS. <ets>m<umac/<edh/</ets>; akin to D.
<ets>mond</ets>, OS. <ets>m<umac/<edh/</ets>, G. <ets>mund</ets>, Icel.
<ets>mu<edh/r</ets>, <ets>munnr</ets>, Sw. <ets>mun</ets>, Dan.
<ets>mund</ets>, Goth. <ets>mun<thorn/s</ets>, and possibly L.
<ets>mentum</ets> chin; or cf. D. <ets>muil</ets> mouth, muzzle, G.
<ets>maul</ets>, OHG. <ets>m<umac/la</ets>, Icel. <ets>m<umac/li</ets>,
and Skr. <ets>mukha</ets> mouth.]</ety> <sn>1.</sn> <def>The opening
through which an animal receives food; the aperture between the jaws or
between the lips; also, the cavity, containing the
<contains>tongue</contains> and <contains>teeth</contains>, between the
lips and the pharynx; the buccal cavity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>An opening affording
entrance or exit; orifice; aperture;</def> as: <sd>(a)</sd> <def>The
opening of a vessel by which it is filled or emptied, charged or
discharged; <as>as, the <ex>mouth</ex> of a jar or pitcher; the
<ex>mouth</ex> of the lacteal vessels, etc.</as></def> <sd>(b)</sd>
<def>The opening or entrance of any cavity, as a cave, pit, well, or
den.</def> <sd>(c)</sd> <def>The opening of a piece of ordnance, through
which it is discharged.</def> <sd>(d)</sd> <def>The opening through
which the waters of a river or any stream are discharged.</def>
<sd>(e)</sd> <def>The entrance into a harbor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Saddlery)</fld> <def>The crosspiece of a bridle
bit, which enters the mouth of an animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A principal speaker; one who utters the common
opinion; a mouthpiece.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every coffeehouse has some particular statesman belonging to it,
who is the <qex>mouth</qex> of the street where he lives.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Cry; voice.</def> <mark>[Obs.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Speech; language; testimony.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That in the <qex>mouth</qex> of two or three witnesses every word
may be established.</q> <rj><qau>Matt. xviii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A wry face; a grimace; a mow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Counterfeit sad looks,<br/
Make <qex>mouths</qex> upon me when I turn my back.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Down at the mouth</b></col> <it>or</it>
<col><b>Down in the mouth</b></col></mcol>, <cd>chapfallen; of dejected
countenance; depressed; discouraged.</cd> <mark>[Obs. or Colloq.]</mark>
-- <col><b>Mouth friend</b></col>, <cd>one who professes friendship
insincerely.</cd> <au>Shak.</au> -- <col><b>Mouth glass</b></col>, <cd>a
small mirror for inspecting the mouth or teeth.</cd> -- <col><b>Mouth
honor</b></col>, <cd>honor given in words, but not felt.</cd>
<au>Shak.</au> -- <col><b>Mouth organ</b></col>. <fld>(Mus.)</fld>
<sd>(a)</sd> <cd>Pan's pipes</cd>. See <er>Pandean</er>. <sd>(b)</sd>
<cd>An harmonicon.</cd> -- <col><b>Mouth pipe</b></col>, <cd>an organ
pipe with a lip or plate to cut the escaping air and make a sound.</cd>
-- <col><b>To stop the mouth</b></col>, <cd>to silence or be silent; to
put to shame; to confound.</cd> -- <col><b>To put one's foot in one's
mouth</b></col>, <cd>to say something which causes one
embarrassment.</cd> -- <col><b>To run off at the mouth</b></col>, <cd>to
speak excessively.</cd> -- <col><b>To talk out of both sides of one's
mouth</b></col>, <cd>to say things which are
contradictory.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q><qex>The mouth</qex> of them that speak lies shall be
<qex>stopped</qex>.</q> <rj><qau>Ps. lxiii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose <qex>mouths</qex> must be <qex>stopped</qex>.</q>
<rj><qau>Titus i. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 950 --></p>

<p><ent>Mouth</ent><br/
<hw>Mouth</hw> <pr>(mou<th/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mouthed</conjf> <pr>(mou<th/d)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Mouthing</conjf>.]</vmorph> <sn>1.</sn> <def>To take
into the mouth; to seize or grind with the mouth or teeth; to chew; to
devour.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter with a voice affectedly big or swelling; to
speak in a strained or unnaturally sonorous manner; <as>as,
<ex>mouthing</ex> platitudes</as>.</def> <ldquo/<xex>Mouthing</xex> big
phrases.<rdquo/ <rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mouthing</qex> out his hollow oes and aes.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To form or cleanse with the mouth; to lick, as a
bear her cub.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make mouths at.</def> <mark>[R.]</mark>
<rj><au>R. Blair.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouth</ent><br/
<hw>Mouth</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To speak with a full,
round, or loud, affected voice; to vociferate; to rant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll bellow out for Rome, and for my country,<br/
And <qex>mouth</qex> at Caesar, till I shake the senate.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put mouth to mouth; to kiss.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make grimaces, esp. in ridicule or
contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Well I know, when I am gone,<br/
How she <qex>mouths</qex> behind my back.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouthed</ent><br/
<hw>Mouthed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Furnished
with a mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a mouth of a particular kind; using the
mouth, speech, or voice in a particular way; -- used only in
composition; <as>as, wide-<ex>mouthed</ex>; hard-<ex>mouthed</ex>;
foul-<ex>mouthed</ex>; mealy-<ex>mouthed</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouther</ent><br/
<hw>Mouth"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who mouths; an
affected speaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouth-footed</ent><br/
<hw>Mouth"-foot`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having the basal joints of the legs converted into jaws.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouthful</ent><br/
<hw>Mouth"ful</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mouthfuls</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>As much as
is usually put into the mouth at one time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, a small quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A statement that has a profound truth in it; <as>as,
you said a <ex>mouthful</ex>!</as></def> <mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Mouthless</ent><br/
<hw>Mouth"less</hw>, <pos>a.</pos> <ety>[AS.
<ets>m<umac/<edh/le<aacute/s</ets>.]</ety> <def>Destitute of a
mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouth-made</ent><br/
<hw>Mouth"-made`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Spoken without
sincerity; not heartfelt.</def> <ldquo/<xex>Mouth-made</xex>
vows.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mouthpiece</ent><br/
<hw>Mouth"piece`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
part of a musical or other instrument to which the mouth is applied in
using it; <as>as, the <ex>mouthpiece</ex> of a bugle, or of a tobacco
pipe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An appendage to an inlet or outlet opening of a pipe
or vessel, to direct or facilitate the inflow or outflow of a
fluid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who delivers the opinion of others or of
another; a spokesman; <as>as, the <ex>mouthpiece</ex> of his
party</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Egmont was imprudent enough to make himself the
<qex>mouthpiece</qex> of their remonstrance.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <def>A person's lawyer.</def>
<mark>[slang]</mark> <note>This is a term that was used sometimes in old
movies. When a tough bad guy was arrested he might say <ldquo/I ain't
sayin' nothin' without my <ex>mouthpiece</ex>!<rdquo/</note><br/
[<source>PJC</source>]</p>

<p><ent>mouthwash</ent><br/
<hw>mouthwash</hw> <pos>n.</pos> <def>a medicated solution used for
gargling and rinsing the mouth.</def><br/
<syn><b>Syn. --</b> gargle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mouton</ent><br/
<hw>mouton</hw> <pos>n.</pos> <def>meat from a mature sheep.</def><br/
<syn><b>Syn. --</b> mutton.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Movability</ent><br/
<hw>Mov`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Movableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movable</ent><br/
<hw>Mov"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>movable</ets>. See <er>Move</er>.]</ety> <sn>1.</sn> <def>Capable
of being moved, lifted, carried, drawn, turned, or conveyed, or in any
way made to change place or posture; susceptible of motion; not fixed or
stationary; <as>as, a <ex>movable</ex> steam engine</as>.</def>
<altsp>[Also spelled <asp>moveable</asp>.]</altsp><br/
<syn><b>Syn. --</b> transferable, transferrable,
transportable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Changing from one time to another; <as>as,
<ex>movable</ex> feasts, <it>i. e.</it>, church festivals, the date of
which varies from year to year</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Movable letter</b></col> <fld>(Heb. Gram.)</fld>, <cd>a
letter that is pronounced, as opposed to one that is quiescent.</cd> --
<col><b>Movable feast</b></col> <fld>(Ecclesiastical)</fld>, <cd>a holy
day that changes date, depending on the lunar cycle. An example of such
a day is <stype>Easter</stype>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Movable</ent><br/
<hw>Mov"a*ble</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Movables</plw>
<pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>An article of wares or goods; a
commodity; a piece of property not fixed, or not a part of real estate;
generally, in the plural, goods; wares; furniture.</def> <altsp>[Also
spelled <asp>moveable</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Furnished with the most rich and princely <qex>movables</qex>.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rom. Law)</fld> <def>Property not attached to the
soil.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is not convertible with <xex>personal
property</xex>, since rents and similar incidents of the soil which are
personal property by our law are immovables by the Roman law.</note>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movableness</ent><br/
<hw>Mov"a*ble*ness</hw>, <pos>n.</pos> <def>The quality or state of
being movable; mobility; susceptibility of motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movably</ent><br/
<hw>Mov"a*bly</hw>, <pos>adv.</pos> <def>In a movable manner or
condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Move</ent><br/
<hw>Move</hw> <pr>(m<oomac/v)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Moved</conjf> <pr>(m<oomac/vd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Moving</conjf>.]</vmorph> <ety>[OE.
<ets>moven</ets>, OF. <ets>moveir</ets>, F. <ets>mouvoir</ets>, L.
<ets>movere</ets>; cf. Gr. <grk>'amei`bein</grk> to change, exchange, go
in or out, quit, Skr. <ets>m<imac/v</ets>, p. p. <ets>m<umac/ta</ets>,
to move, push. Cf. <er>Emotion</er>, <er>Mew</er> to molt, <er>Mob</er>,
<er>Mutable</er>, <er>Mutiny</er>.]</ety> <sn>1.</sn> <def>To cause to
change place or posture in any manner; to set in motion; to carry,
convey, draw, or push from one place to another; to impel; to stir;
<as>as, the wind <ex>moves</ex> a vessel; the horse <ex>moves</ex> a
carriage.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chess, Checkers, etc.)</fld> <def>To transfer (a
piece or man) from one space or position to another on a playing board,
according to the rules of the game; <as>as, to <ex>move</ex> a
king</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To excite to action by the presentation of motives;
to rouse by representation, persuasion, or appeal; to
influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Minds desirous of revenge were not <qex>moved</qex> with gold.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No female arts his mind could <qex>move</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To arouse the feelings or passions of; especially,
to excite to tenderness or compassion; to touch pathetically; to excite,
as an emotion.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When he saw the multitudes, he was <qex>moved</qex> with
compassion on them.</q> <rj><qau>Matt. ix. 36.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[The use of images] in orations and poetry is to <qex>move</qex>
pity or terror.</q> <rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To propose; to recommend; specifically, to propose
formally for consideration and determination, in a deliberative
assembly; to submit, as a resolution to be adopted; <as>as, to
<ex>move</ex> to adjourn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me but <qex>move</qex> one question to your daughter.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They are to be blamed alike who <qex>move</qex> and who decline
war upon particular respects.</q> <rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To apply to, as for aid.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To stir; agitate; trouble; affect; persuade;
influence; actuate; impel; rouse; prompt; instigate; incite; induce;
incline; propose; offer.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Move</ent><br/
<hw>Move</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To change place or
posture; to stir; to go, in any manner, from one place or position to
another; <as>as, a ship <ex>moves</ex> rapidly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The foundations also of the hills <qex>moved</qex> and were
shaken, because he was wroth.</q> <rj><qau>Ps. xviii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On the green bank I sat and listened long, . . . <br/
Nor till her lay was ended could I <qex>move</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act; to take action; to stir; to begin to act;
<as>as, to <ex>move</ex> in a matter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To change residence; to remove, as from one house,
town, or state, to another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chess, Checkers, etc.)</fld> <def>To change the
place of a piece in accordance with the rules of the game.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Move</ent><br/
<hw>Move</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of
moving; a movement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chess, Checkers, etc.)</fld> <def>The act of moving
one of the pieces, from one position to another, in the progress of the
game; also, the opportunity or obligation to so move a piece; one's
turn; <as>as, you can only borrow from the bank in Monopoly when it's
your <ex>move</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>An act for the attainment of an object; a step in
the execution of a plan or purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To make a move</b></col>. <sd>(a)</sd> <cd>To take some
action toward a goal, usually one involving interaction with other
people.</cd> <sd>(b)</sd> <cd>To move a piece, as in a game.</cd> --
<col><b>To be on the move</b></col>, <cd>to bustle or stir about.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>moveable</ent><br/
<hw>moveable</hw> <pos>adj.</pos> <def>movable.</def><br/
<syn><b>Syn. --</b> , transferable, transferrable,
transportable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>moved</ent><br/
<hw>moved</hw> <pos>pred. adj.</pos> <def>affected emotionally. Opposite
of <ant>unmoved</ant>.</def> <see>Also See <er>affected</er>,
<er>emotional</er>.</see> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Moveless</ent><br/
<hw>Move`less</hw>, <pos>a.</pos> <def>Motionless; fixed.</def>
<ldquo/<xex>Moveless</xex> as a tower.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movement</ent><br/
<hw>Move"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mouvement</ets>. See <er>Move</er>, and cf. <er>Moment</er>.]</ety>
<sn>1.</sn> <def>The act of moving in space; change of place or posture;
motion; <as>as, the <ex>movement</ex> of an army in marching or
maneuvering; the <ex>movement</ex> of a wheel or a
machine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Manner or style of moving; <as>as, a slow, or quick,
or sudden, <ex>movement</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Transference, by any means, from one situation to
another; a change of situation; progress toward a goal; advancement;
<as>as, after months of fruitless discussion there was finally some
<ex>movement</ex> toward an agreement</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <def>Motion of the mind or feelings; emotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>The rhythmical
progression, pace, and tempo of a piece.</def> <ldquo/Any change of time
is a change of <xex>movement</xex>.<rdquo/ <au>Busby.</au> <sd>(b)</sd>
<def>One of the several strains or pieces, each complete in itself, with
its own time and rhythm, which make up a larger work; <as>as, the
several <ex>movements</ex> of a suite or a symphony</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mech.)</fld> <def>A system of mechanism for
transmitting motion of a definite character, or for transforming motion;
as, the wheelwork of a watch; <as>as, a seventeen jewel
<ex>movement</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A more or less organized effort by many people to
achieve some goal, especially a social or artistic goal; <as>as, the
women's liberation <ex>movement</ex>; the progressive <ex>movement</ex>
in architecture</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Febrile movement</b></col> <fld>(Med.)</fld>, <cd>an
elevation of the body temperature; a fever.</cd> -- <col><b>Movement
cure</b></col>. <fld>(Med.)</fld> <cd>See <er>Kinesiatrics</er>.</cd> --
<col><b>Movement of the bowels</b></col>, <cd>an evacuation or stool; a
passage or discharge.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Motion.</syn> <usage> -- <er>Movement</er>,
<er>Motion</er>. <xex>Motion</xex> expresses a general idea of not being
at rest; <xex>movement</xex> is oftener used to express a definite,
regulated motion, esp. a progress.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movent</ent><br/
<hw>Mo"vent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>movens</ets>,
p. pr. of <ets>movere</ets>. See <er>Move</er>.]</ety>
<def>Moving.</def> <mark>[R.]</mark> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movent</ent><br/
<hw>Mo"vent</hw>, <pos>n.</pos> <def>That which moves anything.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mover</ent><br/
<hw>Mov"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A person or
thing that moves, stirs, or changes place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person or thing that imparts motion, or causes
change of place; a motor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who, or that which, excites, instigates, or
causes movement, change, etc.; <as>as, <ex>movers</ex> of
sedition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These most poisonous compounds,<br/
Which are the <qex>movers</qex> of a languishing death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A proposer; one who offers a proposition, or
recommends anything for consideration or adoption; <as>as, the
<ex>mover</ex> of a resolution in a legislative body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movie</ent><br/
<hw>Mov"ie</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A motion
picture.</def><br/
<syn><b>Syn. --</b> film, picture, moving picture, motion picture,
picture show, flick.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A motion picture show; the event of showing a motion
picture. In the <pluf>pl.</pluf>, the event of showing a motion picture
at a movie theater; <as>as, to go to the <ex>movies</ex>; to spend an
evening at the <ex>movies</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The motion picture industry or
medium, generally.</def><br/
[<source>PJC</source>]</p>

<p><ent>Moving</ent><br/
<hw>Mov"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Changing place or
posture; causing motion or action; <as>as, a <ex>moving</ex> car, or
power</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exciting movement of the mind or feelings; adapted
to move the sympathies, passions, or affections; touching; pathetic;
<as>as, a <ex>moving</ex> appeal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I sang an old <qex>moving</qex> story.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moving force</b></col> <fld>(Mech.)</fld>, <cd>a force
that accelerates, retards, or deflects the motion of a body.</cd> --
<col><b>Moving plant</b></col> <fld>(Bot.)</fld>, <cd>a leguminous plant
(<spn>Desmodium gyrans</spn>); -- so called because its leaflets have a
distinct automatic motion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moving</ent><br/
<hw>Mov"ing</hw>, <pos>n.</pos> <def>The act of changing place or
posture; esp., the act of changing one's dwelling place or place of
business.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moving day</b></col>, <cd>a day when one moves; esp., a
day when a large number of tenants change their dwelling
place.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movingly</ent><br/
<hw>Mov"ing*ly</hw>, <pos>adv.</pos> <def>In a moving manner.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Movingness</ent><br/
<hw>Mov"ing*ness</hw>, <pos>n.</pos> <def>The power of moving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moving picture</ent><br/
<hw>Moving picture</hw>. <def>same as <er>motion picture</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>moe</asp> and <asp>mowe</asp>.]</altsp> <ety>[F. <ets>moue</ets>
pouting, a wry face; cf. OD. <ets>mouwe</ets> the protruded lip.]</ety>
<def>A wry face.</def> <ldquo/Make <xex>mows</xex> at him.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw>, <pos>v. i.</pos> <def>To make mouths.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nodding, becking, and <qex>mowing</qex>.</q>
<rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as
<er>Mew</er>, a gull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw>, <pos>v.</pos> <vmorph>[<pos>pres. sing.</pos>
<conjf>Mow</conjf>, <pos>pl.</pos> <conjf>Mowe</conjf>,
<conjf>Mowen</conjf>, <conjf>Moun</conjf>.]</vmorph> <ety>[AS.
<ets>magan</ets>. See <er>May</er>, <pos>v.</pos>]</ety> <def>May;
can.</def> <ldquo/Thou <xex>mow</xex> now escapen.<rdquo/
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our walles <qex>mowe</qex> not make hem resistence.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw> <pr>(m<omac/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Mowed</conjf> <pr>(m<omac/d)</pr>;
<pos>p. p.</pos> <conjf>Mowed</conjf> or <conjf>Mown</conjf>
<pr>(m<omac/n)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mowing</conjf>.]</vmorph> <ety>[OE. <ets>mowen</ets>,
<ets>mawen</ets>, AS. <ets>m<amac/wan</ets>; akin to D.
<ets>maaijen</ets>, G. <ets>m<aum/hen</ets>, OHG. <ets>m<amac/jan</ets>,
Dan. <ets>meie</ets>, L. <ets>metere</ets> to reap, mow, Gr.
<grk>'ama^n</grk>. Cf. <er>Math</er>, <er>Mead</er> a meadow,
<er>Meadow</er>.]</ety> <sn>1.</sn> <def>To cut down, as grass, with a
scythe or machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut the grass from; <as>as, to <ex>mow</ex> a
meadow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cut down; to cause to fall in rows or masses, as
in mowing grass; -- with <xex>down</xex>; <as>as, a discharge of
grapeshot <ex>mows</ex> down whole ranks of men</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw>, <pos>v. i.</pos> <def>To cut grass, etc., with a scythe,
or with a machine; to cut grass for hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw> <pr>(mou)</pr>, <pos>n.</pos> <ety>[OE. <ets>mowe</ets>,
AS. <ets>m<umac/ga</ets>.]</ety> <sn>1.</sn> <def>A heap or mass of hay
or of sheaves of grain stowed in a barn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place in a barn where hay or grain in the sheaf
is stowed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mow</ent><br/
<hw>Mow</hw> <pr>(mou)</pr>, <pos>v. t.</pos> <def>To lay, as hay or
sheaves of grain, in a heap or mass in a barn; to pile and stow
away.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mowburn</ent><br/
<hw>Mow"burn`</hw> <pr>(mou"b<ucir/rn`)</pr>, <pos>v. i.</pos> <def>To
heat and ferment in the mow, as hay when housed too green.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mowe</ent><br/
<hw>Mowe</hw> <pr>(mou)</pr>, <pos>v.</pos> <def>See 4th
<er>Mow</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mowe</ent><br/
<hw>Mowe</hw>, <pos>n. & v.</pos> <def>See 1st & 2d <er>Mow</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mower</ent><br/
<hw>Mow"er</hw> <pr>(m<omac/"<etil/r)</pr>, <pos>n.</pos> <def>One who,
or that which, mows; a mowing machine; <as>as, a lawn
<ex>mower</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mowing</ent><br/
<hw>Mow"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who, or
the operation of that which, mows.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Land from which grass is cut; meadow land.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mowing machine</b></col>, <cd>an agricultural machine
armed with knives or blades for cutting standing grass, etc. It may be
drawn by a horse or horses, or propelled by a powered
engine.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mown</ent><br/
<hw>Mown</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <def>Cut down by
mowing, as grass; deprived of grass by mowing; <as>as, a <ex>mown</ex>
field</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mowyer</ent><br/
<hw>Mow"yer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mower.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moxa</ent><br/
<hw>Mox"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A corruption of Japan.
<ets>mogusa</ets> (pronounced <ets>mongsa</ets>), an escharotic made
from the plant <ets>yomigi</ets>: cf. F. <ets>moxa</ets>.]</ety>
<sn>1.</sn> <fld>(Med.)</fld> <def>A soft woolly mass prepared from the
young leaves of <spn>Artemisia Chinensis</spn>, and used as a cautery by
burning it on the skin; hence, any substance used in a like manner, as
cotton impregnated with niter, amadou.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A plant from which this substance
is obtained, esp. <spn>Artemisia Chinensis</spn>, and <spn>Artemisia
moxa</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moxie</ent><br/
<hw>Mox"ie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[fr. Moxie, a trade
name for a beverage.]</ety> <sn>1.</sn> <def>energy; pep.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>courage, determination.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Know-how, expertise.</def>
<rj><au>MW10.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moya</ent><br/
\'d8<hw>Moy"a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Mud poured out from
volcanoes during eruptions; -- so called in South America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moyle</ent><br/
<hw>Moyle</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See <er>Moil</er>,
and <er>Moile</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mozarabic</ent><br/
<ent>Mozarab</ent><br/
<mhw>{ <hw>Moz"a*rab</hw> <pr>(?)</pr>, <hw>Moz`a*rab"ic</hw>
<pr>(?)</pr> }</mhw>. <def>Same as <er>Muzarab</er>,
<er>Muzarabic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mozzetta</ent><br/
<ent>Mozetta</ent><br/
<mhw>{ <hw>Mo*zet"ta</hw> <pr>(?)</pr>, <hw>Moz*zet"ta</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[It. <ets>mozzetta</ets>: cf.
F. <ets>mosette</ets>. Cf. <er>Amice</er> a hood or cape.]</ety>
<fld>(Eccl.)</fld> <def>A cape, with a small hood; -- worn by the pope
and other dignitaries of the Roman Catholic Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mr.</ent><br/
<hw>Mr.</hw>. <pr>(<?/)</pr>. <def>The customary abbreviation of
<sig>Mister</sig> in writing and printing. See <er>Master</er>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mrs.</ent><br/
<hw>Mrs.</hw> <pr>(<?/)</pr>. <def>The customary abbreviation of
<sig>Mistress</sig> or <sig>Missess</sig> when used as a title of
courtesy, in writing and printing; <as>as, <ex>Mrs.</ex> Clinton is
commonly called by her full name, <person>Hillary Rodham
Clinton</person></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>msasa</ent><br/
<hw>msasa</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>Amall shrubby
African tree (<spn>Brachystegia speciformis</spn>) having compound
leaves and racemes of small fragrant green flowers.</def><br/
<syn><b>Syn. --</b> <spn>Brachystegia speciformis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>MSB</ent><br/
<hw>MSB</hw> <pos>n.</pos> <def>See <er>mutual savings bank</er>.</def>
<mark>[abbr.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>MSG</ent><br/
<hw>MSG</hw> <pos>n.</pos> <def>See <er>monosodium
glutamate</er>.</def><br/
<syn><b>Syn. --</b> monosodium glutamate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>MST</ent><br/
<hw>MST</hw> <pos>n.</pos> <def>Mountain Standard Time, the time of the
105th meridian, used in the mountain states of the U.S.</def>
<mark>[abbr.]</mark> <br/
<syn><b>Syn. --</b> Mountain Time, Mountain Standard Time.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>MT</ent><br/
<hw>MT</hw> <pos>n.</pos> <def>A <altname>metric ton</altname>, a unit
of weight equivalent to 1000 kilograms.</def> <mark>[abbr.]</mark> <br/
<syn><b>Syn. --</b> metric ton, tonne, t.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mu</ent><br/
<hw>mu</hw> <pos>n.</pos> <pr>(m<umac/)</pr> <def>The 12th letter of the
Greek alphabet (<mu/, <MU/).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mu'adhdhin</ent><br/
<hw>mu'adhdhin</hw> <pos>n.</pos> <def>Same as
<er>muezzin</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>muazzin</ent><br/
<hw>muazzin</hw> <pos>n.</pos> <def>Same as <er>muezzin</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mucamide</ent><br/
<hw>Mu*cam"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Muc</ets>ic +
<ets>amide</ets>.]</ety> <fld>(Chem.)</fld> <def>The acid amide of mucic
acid, obtained as a white crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucate</ent><br/
<hw>Mu"cate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
salt of mucic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muce</ent><br/
<hw>Muce</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Muse</er>, and
<er>Muset</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucedin</ent><br/
<hw>Mu*ce"din</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Mucus</er>.]</ety> <fld>(Bot. Chem.)</fld> <def>A yellowish white,
amorphous, nitrogenous substance found in wheat, rye, etc., and
resembling gluten; -- formerly called also
<altname>mucin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Much</ent><br/
<hw>Much</hw> <pr>(m<ucr/ch)</pr>, <pos>a.</pos> <amorph>[<pos>Compar. &
superl.</pos> wanting, but supplied by <adjf>More</adjf>
<pr>(m<omac/r)</pr>, and <adjf>Most</adjf> <pr>(m<omac/st)</pr>, from
another root.]</amorph> <ety>[OE. <ets>moche</ets>, <ets>muche</ets>,
<ets>miche</ets>, prob. the same as <ets>mochel</ets>,
<ets>muchel</ets>, <ets>michel</ets>, <ets>mikel</ets>, fr. AS.
<ets>micel</ets>, <ets>mycel</ets>; cf. Gr. <grk>me`gas</grk>, fem.
<grk>mega`lh</grk>, great, and Icel. <ets>mj<oum/k</ets>, adv., much.
<root/103. See <er>Mickle</er>.]</ety> <sn>1.</sn> <def>Great in
quantity; long in duration; <as>as, <ex>much</ex> rain has fallen;
<ex>much</ex> time.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt carry <qex>much</qex> seed out into the field, and
shalt gather but little in.</q> <rj><qau>Deut. xxviii.
38.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Many in number.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Edom came out against him with <qex>much</qex> people.</q>
<rj><qau>Num. xx. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>High in rank or position.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Much</ent><br/
<hw>Much</hw>, <pos>n.</pos> <sn>1.</sn> <def>A great quantity; a great
deal; also, an indefinite quantity; <as>as, you have as <ex>much</ex> as
I</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that gathered <qex>much</qex> had nothing over.</q>
<rj><qau>Ex. xvi. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Much</xex>in this sense can be regarded as an
adjective qualifying a word unexpressed, and may, therefore, be modified
by <xex>as</xex>, <xex>so</xex>, <xex>too</xex>,
<xex>very</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A thing uncommon, wonderful, or noticeable;
something considerable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And [he] thought not <qex>much</qex> to clothe his enemies.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To make much of</b></col>, <cd>to treat as something of
especial value or worth.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Much</ent><br/
<hw>Much</hw>, <pos>adv.</pos> <ety>[Cf. Icel. <ets>mj<oum/k</ets>. See
<er>Much</er>, <pos>a.</pos>]</ety> <def>To a great degree or extent;
greatly; abundantly; far; nearly.</def> <ldquo/<xex>Much</xex> suffering
heroes.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou art <qex>much</qex> mightier than we.</q> <rj><qau>Gen. xxvi.
16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Excellent speech becometh not a fool, <qex>much</qex> less do
lying lips a prince.</q> <rj><qau>Prov. xvii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Henceforth I fly not death, nor would prolong<br/
Life <qex>much</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All left the world <qex>much</qex> as they found it.</q>
<rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muchel</ent><br/
<hw>Much"el</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<root/103. See
<er>Mickle</er>.]</ety> <def>Much.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muchness</ent><br/
<hw>Much"ness</hw>, <pos>n.</pos> <def>Greatness; extent.</def>
<mark>[Obs. or Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The quantity and <qex>muchness</qex> of time which it
filcheth.</q> <rj><qau>W. Whately.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Much of a muchness</b></col>, <cd>much the same.</cd>
<mark>[Colloq.]</mark> <ldquo/Men's men; gentle or simple, they're
<xex>much of a muchness</xex>.<rdquo/ <rj><au>G.
Eliot.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muchwhat</ent><br/
<hw>Much"what`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Nearly; almost;
much.</def> <mark>[Obs.]</mark> <ldquo/<xex>Muchwhat</xex> after the
same manner.<rdquo/ <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucic</ent><br/
<hw>Mu"cic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>mucus</ets>
mucus: cf. F. <ets>mucique</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, gums and micilaginous substances;
specif., denoting an acid obtained by the oxidation of gums, dulcite,
etc., as a white crystalline substance isomeric with saccharic
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucid</ent><br/
<hw>Mu"cid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>mucidus</ets>,
fr. L. <ets>mucus</ets> mucus. See <er>Mucus</er>, and cf.
<er>Moist</er>.]</ety> <def>Musty; moldy; slimy; mucous.</def> --
<wordforms><wf>Mu"cid*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucific</ent><br/
<hw>Mu*cif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mucus</ets> +
L. <ets>-ficare</ets> (in comp.) to make. See <er>-fy</er>.]</ety>
<sn>1.</sn> <fld>(Med.)</fld> <def>Inducing or stimulating the secretion
of mucus; blennogenous.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>Secreting mucus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muciform</ent><br/
<hw>Mu"ci*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mucus</ets> +
<ets>-form</ets>.]</ety> <fld>(Physiol.)</fld> <def>Resembling mucus;
having the character or appearance of mucus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucigen</ent><br/
<hw>Mu"ci*gen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Muc</ets>in +
<ets>-gen</ets>.]</ety> <fld>(Physiol.)</fld> <def>A substance which is
formed in mucous epithelial cells, and gives rise to mucin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucigenous</ent><br/
<hw>Mu*cig"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physiol.)</fld>
<def>Connected with the formation of mucin; resembling mucin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mucigenous</qex> basis is manufactured at the expense of
the ordinary protoplasm of the cell.</q> <rj><qau>Foster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucilage</ent><br/
<hw>Mu"ci*lage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from L.
<ets>mucilago</ets> a musty juice, fr. <ets>mucus</ets> mucus, slime.
See <er>Mucus</er>.]</ety> <sn>1.</sn> <fld>(Bot. Chem.)</fld> <def>A
gummy or gelatinous substance produced in certain plants by the action
of water on the cell wall, as in the seeds of quinces, of flax,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An aqueous solution of gum, or of substances allied
to it; a glue; a liquid adhesive; <as>as, medicinal <ex>mucilage</ex>;
<ex>mucilage</ex> for fastening envelopes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucilaginous</ent><br/
<hw>Mu`ci*lag"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>mucilagineux</ets>. See <er>Mucilage</er>.]</ety> <sn>1.</sn>
<def>Partaking of the nature of, or resembling, mucilage; moist, soft,
and viscid; slimy; ropy; <as>as, a <ex>mucilaginous</ex>
liquid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of, pertaining to, or secreting, mucilage; <as>as,
the <ex>mucilaginous</ex> glands</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Soluble in water, but not in alcohol; yielding
mucilage; <as>as, <ex>mucilaginous</ex> gums or plants</as>.</def> --
<wordforms><wf>Mu`ci*lag"i*nous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 951 --></p>

<p><ent>Mucin</ent><br/
<hw>Mu"cin</hw> <pr>(m<umac/"s<icr/n)</pr>, <pos>n.</pos> <ety>[From
<er>Mucus</er>.]</ety> <sn>1.</sn> <fld>(Bot. Chem.)</fld> <def>See
<er>Mucedin</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol. Chem.)</fld> <def>Any of a class of high
molecular weight glycoproteins which are contained in mucus, and give to
the latter secretion its peculiar ropy character. They are found in all
the secretions from mucous glands, and also between the fibers of
connective tissue, as in tendons. They form viscous solutions and serve
to provide lubrication for movement within body cavities, and some
protection of surfaces. See <xex>Illust.</xex> of
<er>Demilune</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mucinogen</ent><br/
<hw>Mu*cin"o*gen</hw> <pr>(m<usl/*s<icr/n"<osl/*j<ecr/n)</pr>,
<pos>n.</pos> <ety>[<ets>Mucin</ets> + <ets>-gen</ets>.]</ety>
<fld>(Physiol.)</fld> <def>Same as <er>Mucigen</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muciparous</ent><br/
<hw>Mu*cip"a*rous</hw> <pr>(m<usl/*s<icr/"p<adot/*r<ucr/s)</pr>,
<pos>a.</pos> <ety>[<ets>Mucus</ets> + L. <ets>parere</ets> to
produce.]</ety> <fld>(Physiol.)</fld> <def>Secreting, or producing,
mucus or mucin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucivore</ent><br/
<hw>Mu"ci*vore</hw> <pr>(m<umac/"s<icr/*v<omac/r)</pr>, <pos>n.</pos>
<ety>[L. <ets>mucus</ets> slime, mucus + <ets>vorare</ets> to
devour.]</ety> <fld>(Zool.)</fld> <def>An insect which feeds on mucus,
or the sap of plants, as certain Diptera, of the tribe
<fam>Mucivora</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muck</ent><br/
<hw>Muck</hw> <pr>(m<ucr/k)</pr>, <pos>adv.</pos> <def>Abbreviation of
<xex>Amuck</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To run a muck</b></col>. <cd>See
<er>Amuck</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muck</ent><br/
<hw>Muck</hw>, <pos>n.</pos> <ety>[Icel. <ets>myki</ets>; akin to D.
<ets>m<oum/g</ets>. Cf. <er>Midden</er>.]</ety> <sn>1.</sn> <def>Dung in
a moist state; manure.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vegetable mold mixed with earth, as found in low,
damp places and swamps.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything filthy or vile.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Money; -- in contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fatal <qex>muck</qex> we quarreled for.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mining)</fld> <def>The unwanted material,
especially rock or soil, that must be excavated in order to reach the
valuable ore; also, the unwanted material after being excavated or
crushed by blasting, or after being removed to a waste pile. In the
latter sense, also called a <er>muck pile</er>.</def><br/
[<source>RDH</source>]</p>

<p><cs><col><b>Muck bar</b></col>, <cd>bar iron which has been through
the rolls only once.</cd> -- <col><b>Muck iron</b></col>, <cd>crude
puddled iron ready for the squeezer or rollers.</cd> <au>Knight.</au>
<col>muck pile</col> <cd>see <er>muck pile</er> in the
vocabulary.</cd></cs><br/
[<source>1913 Webster</source> <source>+RH</source>]</p>

<p><ent>muck</ent><br/
<hw>muck</hw>, <pos>a.</pos> <def>Like muck; mucky; also, used in
collecting or distributing muck; <as>as, a <ex>muck</ex>
fork</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>muck</ent><br/
<hw>muck</hw>, <pos>v. t.</pos> <def>To manure with muck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>muck</ent><br/
<hw>muck</hw>, <pos>v. i. & t.</pos> <def>To excavate and remove
muck{5}. Often used with <ptcl>out</ptcl>, <as>as, to <ex>muck</ex> out
a round</as>.</def><br/
[<source>RDH</source>]</p>

<p><q> . . . <company>Inco</company> is still much more advanced than
other mining companies. He says that the LKAB mine in
<country>Sweden</country> is the closest rival. He predicts that, by
2008, <company>Inco</company> can reach a new productivity plateau,
doubling the current mining productivity from 3,350 tonnes to 6,350
tonnes per person per year. Another aim is to triple the mine cycle rate
(the time to drill, blast and <qex>muck</qex> a round) from one cycle to
three complete cycles per 24 hours.</q>
<qau>https://web.archive.org/web/20010728040054/http://www.canadianminingjournal.com/issues/apr00/page10.asp</qau><br/
[<source>PJC</source>]</p>


<p><ent>Muckender</ent><br/
<hw>Muck"en*der</hw> <pr>(m<ucr/k"<ecr/n*d<etil/r)</pr>, <pos>n.</pos>
<ety>[Sp. <ets>mocador</ets>. Cf. <er>Mokadour</er>.]</ety> <def>A
handkerchief.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>muckinder</asp>, <asp>muckiter</asp>,
<asp>mockadour</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucker</ent><br/
<hw>Muck"er</hw> <pr>(m<ucr/k"<etil/r)</pr>, <pos>n.</pos> <def>A term
of reproach for a low or vulgar labor person.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>mucker</ent><br/
<hw>muck"er</hw> <pr>(m<ucr/k"<etil/r)</pr>, <pos>n.</pos>
<fld>(Construction)</fld> <def>An excavating machine designed to remove
particulate material from within a confined area, as in a tunnel or
mine.</def><br/
[<source>RDH</source>]</p>

<p><ent>Mucker</ent><br/
<hw>Muck"er</hw>, <pos>v. t.</pos> <def>To scrape together, as money, by
mean labor or shifts.</def> <mark>[Obs.]</mark>
<rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muckerer</ent><br/
<hw>Muck"er*er</hw> <pr>(m<ucr/k"<etil/r*<etil/r)</pr>, <pos>n.</pos>
<def>A miser; a niggard.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muckiness</ent><br/
<hw>Muck"i*ness</hw> <pr>(m<ucr/k"<esl/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The quality of being mucky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muckle</ent><br/
<hw>Muc"kle</hw> <pr>(m<ucr/k"k'l)</pr>, <pos>a.</pos> <ety>[See
<er>Mickle</er>.]</ety> <def>Much.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muckmidden</ent><br/
<hw>Muck"mid`den</hw> <pr>(m<ucr/k"m<icr/d`d'n)</pr>, <pos>n.</pos>
<def>A dunghill.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>muck pile</ent><br/
<hw>muck" pile`</hw> <pr>(m<ucr/k" p<imac/l`)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Construction)</fld> <def>The broken material at the
face of a tunnel being bored, after being crushed by blasting.</def><br/
[<source>RDH</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>Muck{5} that has been placed in
a spoil area.</def><br/
[<source>RDH</source>]</p>

<p><ent>Muck rake</ent><br/
<hw>Muck" rake`</hw>. <def>A rake for scraping up muck or dung. See
<er>Muckrake</er>, <pos>v. i.</pos>, below.</def> <mark>[obs.]</mark>
<br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>muckrake</ent><br/
<hw>muck"rake`</hw> <pr>(m<ucr/k"r<amac/k`)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>-raked</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>-raking</conjf>
<pr>(?)</pr>.]</vmorph> <def>To seek for, expose, or charge, especially
habitually, corruption, real or alleged, on the part of public men and
corporations.</def> <note>On April 14, 1906, President Roosevelt
delivered a speech on <ldquo/The Man with the Muck Rake,<rdquo/ in which
he deprecated sweeping and unjust charges of corruption against public
men and corporations. The phrase was taken up by the press, and the verb
to <er>muckrake</er>, in the above sense, and the noun
<it>muckraker</it>, to designate one so engaged, were speedily coined
and obtained wide currency. The original allusion was to a character in
Bunyan's <ldquo/Pilgrim's Progress<rdquo/ so intent on raking up muck
that he could not see a celestial crown held above him.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>muckraker</ent><br/
<hw>muck"rak`er</hw> <pr>(m<ucr/k"r<amac/k`<etil/r)</pr>, <pos>n.</pos>
<def>A person who habitually muckrakes.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mucksy</ent><br/
<hw>Muck"sy</hw> <pr>(m<ucr/k"s<ycr/)</pr>, <pos>a.</pos> <def>Somewhat
mucky; soft, sticky, and dirty; muxy.</def> <mark>[Prov. Eng.]</mark>
<rj><au>R. D. Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muckworm</ent><br/
<hw>Muck"worm`</hw> <pr>(m<ucr/k"w<ucir/rm`)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Zool.)</fld> <def>A larva or grub that lives in muck
or manure; -- applied to the larvae of the tumbledung and allied
beetles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who scrapes together money by mean labor and
devices; a miser.</def> <ldquo/Misers are <xex>muckworms</xex>.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucky</ent><br/
<hw>Muck"y</hw> <pr>(m<ucr/k"<ycr/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Filthy with muck; miry; <as>as, a <ex>mucky</ex> road</as>.</def>
<ldquo/<xex>Mucky</xex> filth.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vile, in a moral sense; sordid.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mucky</qex> money and false felicity.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucocele</ent><br/
<hw>Mu"co*cele</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Mucus</ets> +
Gr. <grk>kh`lh</grk> tumor.]</ety> <fld>(Med.)</fld> <def>An enlargement
or protrusion of the mucous membrane of the lachrymal passages, or
dropsy of the lachrymal sac, dependent upon catarrhal inflammation of
the latter.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucoid</ent><br/
<hw>Mu"coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mucus</ets> +
<ets>-oid</ets>.]</ety> <def>Resembling mucus.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mucoid degeneration</b></col>, <cd>a form of degeneration
in which the tissues are transformed into a semisolid substance
resembling mucus.</cd> <rj><au>Quain.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucoid</ent><br/
<hw>Mu"coid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Muc</ets>in +
<ets>-oid</ets>.]</ety> <fld>(Physiol. Chem.)</fld> <def>One of a class
of mucinlike substances yielding on decomposition a reducing
carbohydrate together with some form of proteinaceous matter.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muconate</ent><br/
<hw>Mu"co*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of muconic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muconic</ent><br/
<hw>Mu*con"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mu</ets>cic +
ita<ets>conic</ets>.]</ety> <fld>(Chem.)</fld> <def>Of, pertaining to,
or designating, an organic acid (<chform>C6H6O4</chform>,
<chname>2-4-hexadienedoic acid</chname>), obtained indirectly from mucic
acid, and somewhat resembling itaconic acid. Various other means of
synthesis have been reported.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mucopurulent</ent><br/
<hw>Mu`co*pu"ru*lent</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mucus</ets> + <ets>purulent</ets>.]</ety> <fld>(Med.)</fld>
<def>Having the character or appearance of both mucus and pus.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucor</ent><br/
\'d8<hw>Mu"cor</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., fr.
<ets>mucere</ets> to be moldy or musty.]</ety> <fld>(Bot.)</fld> <def>A
genus of minute fungi. The plants consist of slender threads with
terminal globular sporangia; mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucorales</ent><br/
<hw>Mucorales</hw> <pos>prop. n.</pos> <def>An order of mostly
saprophytic fungi.</def><br/
<syn><b>Syn. --</b> order <ord>Mucorales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mucosa</ent><br/
<hw>mucosa</hw> <pos>n.</pos> <def>The mucus-secreting membrane lining
all body cavities or passages that communicate with the exterior; called
also <altname>mucous membrane</altname>.</def><br/
<syn><b>Syn. --</b> mucous membrane.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mucosity</ent><br/
<hw>Mu*cos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being mucous or slimy; mucousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucous</ent><br/
<hw>Mu"cous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mucosus</ets>, fr. <ets>mucus</ets> mucus.]</ety> <sn>1.</sn>
<def>Of, pertaining to, or resembling, mucus; slimy, ropy, or stringy,
and lubricous; <as>as, a <ex>mucous</ex> substance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Secreting a slimy or mucigenous substance; <as>as,
the <ex>mucous</ex> membrane</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mucous membrane</b></col>. <fld>(Anat.)</fld> <cd>See
under <er>Membrane</er>.</cd> -- <col><b>Mucous patches</b></col>
<fld>(Med.)</fld>, <cd>elevated patches found in the mucous membranes of
the mouth and anus, usually due to syphilis.</cd> -- <col><b>Mucous
tissue</b></col> <fld>(Anat.)</fld>, <cd>a form of connective tissue in
an early stage of development, found in the umbilical cord and in the
embryo, and also in certain tumors called
<partof>myxomata</partof>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucousness</ent><br/
<hw>Mu"cous*ness</hw>, <pos>n.</pos> <def>The quality or state of being
mucous; sliminess.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucro</ent><br/
\'d8<hw>Mu"cro</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Bot. & Zool.)</fld> <def>A minute abrupt point, as of a leaf; any
small, sharp point or process, terminating a larger part or
organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucronated</ent><br/
<ent>Mucronate</ent><br/
<mhw>{ <hw>Mu"cro*nate</hw> <pr>(?)</pr>, <hw>Mu"cro*na`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>mucronatus</ets>, fr.
<ets>mucro</ets> a sharp point: cf. F. <ets>mucron<eacute/</ets>.]</ety>
<def>Ending abruptly in a sharp point; abruptly tipped with a short and
sharp point; <as>as, a <ex>mucronate</ex> leaf</as>.</def> --
<wordforms><wf>Mu"cro*nate*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucronulate</ent><br/
<hw>Mu*cron"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having, or
tipped with, a small point or points.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muculent</ent><br/
<hw>Mu"cu*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>muculentus</ets>, fr. <ets>mucus</ets>.]</ety> <def>Slimy; moist,
and moderately viscous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucus</ent><br/
<hw>Mu"cus</hw> <pr>(m<umac/"k<ucr/s)</pr>, <pos>n.</pos> <ety>[L.
<ets>mucus</ets>, <ets>muccus</ets>; cf. <ets>mucere</ets> to be moldy
or musty, Gr. <grk>my`xa</grk> mucus, and Skr. <ets>muc</ets> to
release. Cf. <er>Match</er> for striking fire, <er>Moist</er>,
<er>Mucilage</er>.]</ety> <sn>1.</sn> <fld>(Physiol.)</fld> <def>A
viscid fluid secreted by mucous membranes, which it serves to moisten
and protect. It covers the lining membranes of all the cavities which
open externally, such as those of the mouth, nose, lungs, intestinal
canal, urinary passages, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>Any other animal fluid of a
viscid quality, as the synovial fluid, which lubricates the cavities of
the joints; -- improperly so used.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A gelatinous or slimy substance
found in certain algae and other plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mucusin</ent><br/
<hw>Mu"cus*in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.
Chem.)</fld> <def>Mucin.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mud</ent><br/
<hw>Mud</hw> <pr>(m<ucr/d)</pr>, <pos>n.</pos> <ety>[Akin to LG.
<ets>mudde</ets>, D. <ets>modder</ets>, G. <ets>moder</ets> mold, OSw.
<ets>modd</ets> mud, Sw. <ets>modder</ets> mother, Dan.
<ets>mudder</ets> mud. Cf. <er>Mother</er> a scum on liquors.]</ety>
<def>Earth and water mixed so as to be soft and adhesive.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mud bass</b></col> <fld>(Zool.)</fld>, <cd>a fresh-water
fish (<spn>Acantharchum pomotis</spn> or <spn>Acantharchus
pomotis</spn>) of the Eastern United States. It produces a deep grunting
note.</cd> -- <col><b>Mud bath</b></col>, <cd>an immersion of the body,
or some part of it, in mud charged with medicinal agents, as a remedy
for disease.</cd> -- <col><b>Mud boat</b></col>, <cd>a large flatboat
used in dredging.</cd> -- <col><b>Mud cat</b></col>. <cd>See <er>mud
cat</er> in the vocabulary.</cd> -- <col><b>Mud crab</b></col>
<fld>(Zool.)</fld>, <cd>any one of several American marine crabs of the
genus <gen>Panopeus</gen>.</cd> -- <col><b>Mud dab</b></col>
<fld>(Zool.)</fld>, <cd>the winter flounder. See <er>Flounder</er>, and
<er>Dab</er>.</cd> -- <col><b>Mud dauber</b></col> <fld>(Zool.)</fld>,
<cd>a mud wasp; the <er>mud-dauber</er>.</cd> -- <col><b>Mud
devil</b></col> <fld>(Zool.)</fld>, <cd>the fellbender.</cd> --
<col><b>Mud drum</b></col> <fld>(Steam Boilers)</fld>, <cd>a drum
beneath a boiler, into which sediment and mud in the water can settle
for removal.</cd> -- <col><b>Mud eel</b></col> <fld>(Zool.)</fld>, <cd>a
long, slender, aquatic amphibian (<spn>Siren lacertina</spn>), found in
the Southern United States. It has persistent external gills and only
the anterior pair of legs. See <er>Siren</er>.</cd> -- <col><b>Mud
frog</b></col> <fld>(Zool.)</fld>, <cd>a European frog (<spn>Pelobates
fuscus</spn>).</cd> -- <col><b>Mud hen</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The American coot (<spn>Fulica Americana</spn>)</cd>.
<sd>(b)</sd> <cd>The clapper rail.</cd> -- <col><b>Mud lark</b></col>,
<cd>a person who cleans sewers, or delves in mud.</cd>
<mark>[Slang]</mark> -- <col><b>Mud minnow</b></col> <fld>(Zool.)</fld>,
<cd>any small American fresh-water fish of the genus <gen>Umbra</gen>,
as <spn>Umbra limi</spn>. The genus is allied to the pickerels.</cd> --
<col><b>Mud plug</b></col>, <cd>a plug for stopping the mudhole of a
boiler.</cd> -- <col><b>Mud puppy</b></col> <fld>(Zool.)</fld>, <cd>the
menobranchus.</cd> -- <col><b>Mud scow</b></col>, <cd>a heavy scow, used
in dredging; a mud boat.</cd> <mark>[U.S.]</mark> -- <mcol><col><b>Mud
turtle</b></col>, <col><b>Mud tortoise</b></col></mcol>
<fld>(Zool.)</fld>, <cd>any one of numerous species of fresh-water
tortoises of the United States.</cd> -- <col><b>Mud wasp</b></col>
<fld>(Zool.)</fld>, <cd>any one of numerous species of hymenopterous
insects belonging to <gen>Pepaeus</gen>, and allied genera, which
construct groups of mud cells, attached, side by side, to stones or to
the woodwork of buildings, etc. The female places an egg in each cell,
together with spiders or other insects, paralyzed by a sting, to serve
as food for the larva. Called also <altname>mud
dauber</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mud</ent><br/
<hw>Mud</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To bury in mud.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make muddy or turbid.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudar</ent><br/
\'d8<hw>Mu"dar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>mad<amac/r</ets>.]</ety> <fld>(Bot.)</fld> <def>Either one of two
asclepiadaceous shrubs (<spn>Calotropis gigantea</spn>, and
<spn>Calotropis procera</spn>), which furnish a strong and valuable
fiber. The acrid milky juice is used medicinally.</def> <altsp>[Also
spelled <asp>madar</asp> and <asp>muddar</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudarin</ent><br/
<hw>Mu"da*rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
brown, amorphous, bitter substance having a strong emetic action,
extracted from the root of the mudar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mud cat</ent><br/
<ent>mudcat</ent><br/
<mhw><hw>mudcat</hw>, <hw>mud cat</hw></mhw> <pos>n.</pos> <def>A large
catfish (<spn>Pylodictus olivaris</spn>, formerly <spn>Leptops
olivaris</spn>) of the central U. S. having a flattened head and
projecting jaw.</def><br/
<syn><b>Syn. --</b> flathead catfish, goujon, shovelnose catfish,
spoonbill catfish, <spn>Pylodictus olivaris</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mud dauber</ent><br/
<ent>mud-dauber</ent><br/
<mhw><hw>mud"-daub`er</hw>, <hw>mud" daub`er</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>A wasp of the family <fam>Sphegidae</fam>
(<fam>Sphecidae</fam>) which builds a nest of mud and stores insects and
spiders in it; a digger-wasp.</def><br/
[<source>PJC</source>]</p>

<p><ent>mud crab</ent><br/
<ent>mud-crab</ent><br/
<mhw><hw>mud"-crab`</hw>, <hw>mud" crab`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>A crab of the genus <gen>Panop<oe/us</gen> (also
written <gen>Panopeus</gen>).</def><br/
[<source>PJC</source>]</p>

<p><ent>Muddily</ent><br/
<hw>Mud"di*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a muddy manner;
turbidly; without mixture; cloudily; obscurely; confusedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudder</ent><br/
<hw>Mud"der</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>a
racehorse that exhibits a better than usual performance when the
racetrack is wet or muddy.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>An athlete who performs better than his/her average
under muddy conditions.</def><br/
[<source>PJC</source>]</p>

<p><ent>Muddiness</ent><br/
<hw>Mud"di*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The condition or
quality of being muddy; turbidness; foulness caused by mud, dirt, or
sediment; <as>as, the <ex>muddiness</ex> of a stream</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Obscurity or confusion, as in treatment of a
subject; intellectual dullness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddle</ent><br/
<hw>Mud"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Muddled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Muddling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From
<er>Mud</er>.]</ety> <sn>1.</sn> <def>To make turbid, or muddy, as
water.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He did ill to <qex>muddle</qex> the water.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cloud or stupefy; to render stupid with liquor;
to intoxicate partially.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Epicurus seems to have had brains so <qex>muddled</qex> and
confounded, that he scarce ever kept in the right way.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Often drunk, always <qex>muddled</qex>.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To waste or misuse, as one does who is stupid or
intoxicated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>muddle</qex> it [money] away without method or object,
and without having anything to show for it.</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To mix confusedly; to confuse; to make a mess of;
<as>as, to <ex>muddle</ex> matters</as>; also, to perplex; to
mystify.</def> <rj><au>F. W. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddle</ent><br/
<hw>Mud"dle</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To dabble in
mud.</def> <mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To think and act in a confused, aimless
way.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddle</ent><br/
<hw>Mud"dle</hw>, <pos>n.</pos> <def>A state of being turbid or
confused; hence, intellectual cloudiness or dullness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We both grub on in a <qex>muddle</qex>.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddlehead</ent><br/
<hw>Mud"dle*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stupid person;
a blunderer.</def> <mark>[Colloq.]</mark> <au>C. Reade.</au> --
<wordforms><wf>Mud"dle-head`ed</wf>, <pos>a.</pos>
<mark>[Colloq.]</mark> <au>Dickens.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddler</ent><br/
<hw>Mud"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, muddles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddy</ent><br/
<hw>Mud"dy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Muddier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Muddiest</adjf>.]</amorph> <sn>1.</sn> <def>Abounding in mud;
besmeared or dashed with mud; <as>as, a <ex>muddy</ex> road or path;
<ex>muddy</ex> boots.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Turbid with mud; <as>as, <ex>muddy</ex>
water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Consisting of mud or earth; gross; impure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>muddy</qex> vesture of decay.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Confused, as if turbid with mud; cloudy in mind;
dull; stupid; also, immethodical; incoherent; vague.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cold hearts and <qex>muddy</qex> understandings.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Dost think I am so <qex>muddy</qex>, so unsettled.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not clear or bright.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddy</ent><br/
<hw>Mud"dy</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Muddied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Muddying</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To soil
with mud; to dirty; to render turbid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>(Fig.)</mark>: <def>To cloud; to make dull or
heavy; to confuse.</def> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddy-headed</ent><br/
<hw>Mud"dy-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dull;
stupid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muddy-mettled</ent><br/
<hw>Mud"dy-met`tled</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dull-spirited.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudfish</ent><br/
<hw>Mud"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The European loach.</def> <sd>(b)</sd> <def>The bowfin
(<spn>Amia calva</spn>).</def> <sd>(c)</sd> <def>The South American
lipedosiren, and the allied African species (<spn>Protopterus
annectens</spn>). See <er>Lipedosiren</er>.</def> <sd>(d)</sd> <def>The
mud minnow, a fish of the genus <gen>Umbra</gen> or family
<fam>Umbridae</fam>.</def> <sd>(e)</sd> <cd>any fish which lives in
muddy waters, such as the <er>mummichog</er>, a killifish.</cd><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mudhole</ent><br/
<hw>Mud"hole`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A hole,
or hollow place, containing mud, as in a road.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Steam Boilers)</fld> <def>A hole near the bottom,
through which the sediment is withdrawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudir</ent><br/
<hw>Mu"dir</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Moodir</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudsill</ent><br/
<hw>Mud"sill`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
lowest sill of a structure, usually embedded in the soil; the lowest
timber of a house; also, that sill or timber of a bridge which is laid
at the bottom of the water. See <er>Sill</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: A person of the lowest stratum of society; --
a term of opprobrium or contempt.</def> <mark>[Southern U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mudsucker</ent><br/
<hw>Mud"suck`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A woodcock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudwall</ent><br/
<hw>Mud"wall`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European bee-eater. See <er>Bee-eater</er>.</def>
<altsp>[Written also <asp>modwall</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mudwort</ent><br/
<hw>Mud"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
small herbaceous plant growing on muddy shores (<spn>Limosella
aquatica</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mue</ent><br/
<hw>Mue</hw> <pr>(m<umac/)</pr>, <pos>v. i.</pos> <def>To mew; to
molt.</def> <mark>[Obs.]</mark> <rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>muesli</ent><br/
<hw>mues"li</hw> <pr>(m<umac/s"l<esl/ <it>or</it> m<umac/z"l<esl/)</pr>
<pos>n.</pos> <def>A mixture of untoasted dry cereals, nuts, and fruits,
eaten mostly as a breakfast cereal; -- of Swiss origin.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>muezzin</ent><br/
<hw>mu*ez"zin</hw> <pr>(m<usl/*<ecr/z"z<icr/n)</pr>, <pos>n.</pos>
<ety>[Ar.]</ety> <def>A Muslim crier of the hour of prayer; the Moslem
official of a mosque who summons the faithful to prayer from a minaret
five times a day.</def> <altsp>[Written also <asp>mouezzin</asp>,
<asp>mueddin</asp>, <asp>muazzin</asp>, <asp>mu'adhdhin</asp>, and
<asp>muwazzin</asp>.]</altsp><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Muff</ent><br/
<hw>Muff</hw> <pr>(m<ucr/f)</pr>, <pos>n.</pos> <ety>[Cf. LG.
<ets>muff</ets>, D. <ets>mof</ets>, G., Dan., & Sw. <ets>muff</ets>, F.
<ets>moufle</ets> mitten, LL. <ets>muffula</ets>, MHG. <ets>mouwe</ets>
sleeve, D. <ets>mouw</ets>, and E. <ets>muffle</ets>, v.]</ety>
<sn>1.</sn> <def>A soft cover of cylindrical form, usually of fur, worn
by women to shield the hands from cold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A short hollow cylinder
surrounding an object, as a pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Glass Manuf.)</fld> <def>A blown cylinder of glass
which is afterward flattened out to make a sheet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[Perhaps a different word; cf. Prov. E.
<ets>maffle</ets> to slammer.]</ety> <def>A stupid fellow; a
poor-spirited person.</def> <mark>[Colloq.]</mark> <ldquo/A
<xex>muff</xex> of a curate.<rdquo/ <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[See 4.]</ety> <fld>(Baseball)</fld> <def>A failure
to hold a ball when once in the hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Zool.)</fld> <def>The whitethroat.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muff</ent><br/
<hw>Muff</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Muffed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Muffing</conjf>.]</vmorph> <def>To handle awkwardly; to fumble;
to fail to hold, as a ball, in catching it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffetee</ent><br/
<hw>Muf`fe*tee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small muff worn
over the wrist.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffin</ent><br/
<hw>Muf"fin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Muff</er>.]</ety> <def>A light, spongy, cylindrical cake, used for
breakfast and tea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffineer</ent><br/
<hw>Muf`fin*eer"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dish for
keeping muffins hot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffish</ent><br/
<hw>Muff"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Muff</er>, 4
& 5.]</ety> <def>Stupid; awkward.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffle</ent><br/
<hw>Muf"fle</hw> <pr>(m<ucr/f"f'l)</pr>, <pos>n.</pos> <def>The bare end
of the nose between the nostrils; -- used esp. of ruminants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffle</ent><br/
<hw>Muf"fle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Muffled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Muffling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>moufle</ets> a mitten, LL. <ets>muffula</ets>, OD.
<ets>moffel</ets> a muff. See <er>Muff</er>.]</ety> <sn>1.</sn> <def>To
wrap up in something that conceals or protects; to wrap, as the face and
neck, in thick and disguising folds; hence, to conceal or cover the face
of; to envelop; to inclose; -- often with <xex>up</xex>.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The face lies <qex>muffled</qex> up within the garment.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>muffled</qex> with a cloud his mournful eyes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Muffled</qex> up in darkness and superstition.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To prevent seeing, or hearing, or speaking, by wraps
bound about the head; to blindfold; to deafen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To wrap or fit with something that dulls or deadens
the sound of; <as>as, to <ex>muffle</ex> the strings of a drum, or that
part of an oar which rests in the rowlock; to <ex>muffle</ex> the
exhaust of a motor vehicle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffle</ent><br/
<hw>Muf"fle</hw>, <pos>v. i.</pos> <ety>[Cf. F. <ets>maffle</ets>,
<ets>mumble</ets>, D. <ets>moffelen</ets>.]</ety> <def>To speak
indistinctly, or without clear articulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muffle</ent><br/
<hw>Muf"fle</hw>, <pos>n.</pos> <ety>[F. <ets>moufle</ets>, prop., a
mitten, from the resemblance in shape. See <er>Muffle</er>, <pos>v.
t.</pos>, <er>Muff</er>.]</ety> <sn>1.</sn> <def>Anything with which
another thing, as an oar or drum, is muffled; also, a boxing glove; a
muff.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal.)</fld> <def>An earthenware compartment or
oven, often shaped like a half cylinder, used in furnaces to protect
objects heated from the direct action of the fire, as in scorification
of ores, cupellation of ore buttons, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Ceramics)</fld> <def>A small oven for baking and
fixing the colors of painted or printed pottery, without exposing the
pottery to the flames of the furnace or kiln.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A pulley block containing several sheaves.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>muffled</ent><br/
<hw>muffled</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>muted</er>; <as>as, <ex>muffled</ex> drums; the <ex>muffled</ex>
noises of the street</as>.</def><br/
<syn><b>Syn. --</b> dull, muted, softened.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Wrapped up especially for protection or secrecy;
<as>as, children <ex>muffled</ex> almost to the eyebrows</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muffler</ent><br/
<hw>Muf"fler</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Anything
used in muffling; esp., a scarf for protecting the head and neck in cold
weather; a tippet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fortune is painted blind, with a <qex>muffler</qex> above her
eyes.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A cushion for terminating or
softening a note made by a stringed instrument with a
keyboard.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of mitten or boxing glove, esp. when
stuffed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who muffles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mach.)</fld> <def>Any of various devices to deaden
the noise of escaping gases or vapors, as a tube filled with
obstructions, through which the exhaust gases of an internal-combustion
engine, as on an automobile, are passed (called also
<altname>silencer</altname>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muflon</ent><br/
<hw>Muf"lon</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Mouflon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mufti</ent><br/
<hw>Muf"ti</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Muftis</plw> <pr>(#)</pr>.</plu> <ety>[Ar. <ets>mufti</ets>.]</ety>
<sn>1.</sn> <def>An official expounder of Muslim law.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of the chief legal advisers to the Sultan of the
Ottoman Empire.</def><br/
[<source>PJC</source>]</p>

<p><ent>mufti</ent><br/
<hw>muf"ti</hw>, <pos>n.</pos> <def>Ordinary civilian dress when worn by
persons who serve in a uniformed service, such as the military or
police. It originally was used in reference to British naval or military
officers, and originated with the British service in India.</def>
<mark>[Colloq. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mug</ent><br/
<hw>Mug</hw> <pr>(m<ucr/g)</pr>, <pos>n.</pos> <ety>[Cf. Ir.
<ets>mugam</ets> a mug, <ets>mucog</ets> a cup.]</ety> <sn>1.</sn>
<def>A kind of ceramic or metal drinking cup, with a handle, -- usually
cylindrical and without a lip.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The face or mouth; <as>as, I don't want to see your
ugly <ex>mug</ex> again</as>; -- often used contemptuously.</def>
<mark>[Slang]</mark> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>mug</ent><br/
<hw>mug</hw> <pr>(m<ucr/g)</pr>, <pos>v. t.</pos> <def>To take property
from (a person) in a public place by threatening or committing violence
on the person who is robbed; to rob, especially to rob by use of a
weapon such as a knife or gun.</def> <note>To rob a person or a business
indoors is not usually referred to as to <ex>mug</ex>, but to
<contr>stick up</contr> or <contr>hold up</contr>.</note><br/
<syn><b>Syn. --</b> rob, stick up</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>mugful</ent><br/
<hw>mugful</hw> <pos>n.</pos> <def>the quantity that can be held in a
mug.</def><br/
<syn><b>Syn. --</b> mug.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muggard</ent><br/
<hw>Mug"gard</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. G.
<ets>mucker</ets> a sulky person, <ets>muckish</ets> sullen, peevish,
<ets>mucken</ets> to mutter, grumble.]</ety> <def>Sullen;
displeased.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muggur</ent><br/
<ent>Muggar</ent><br/
<ent>Mugger</ent><br/
<mhw>{ <hw>Mug"ger</hw> <pr>(?)</pr>, <pos>n.</pos> Also
<hw>Mug"gar</hw>, <hw>Mug"gur</hw> }</mhw>. <ety>[Hind.
<ets>magar</ets>, fr. Skr. <ets>makara</ets> sea monster.]</ety>
<def>The common crocodile (<spn>Crocodilus palustris</spn>) of India,
the East Indies, etc. It becomes twelve feet or more long.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mugger</ent><br/
<hw>mugger</hw> <pos>n.</pos> <def>A thief who takes property by
threatening (or performing) violence on the person who is robbed; a
person who commits a mugging; one who mugs. See <er>mug</er>, <pos>v.
t.</pos></def><br/
<syn><b>Syn. --</b> robber</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Mugget</ent><br/
<hw>Mug"get</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The small entrails of
a calf or a hog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugginess</ent><br/
<hw>Mug"gi*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition or
quality of being muggy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugging</ent><br/
<hw>Mug"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<pos>p. pr. & vb.
n.</pos> from <er>mug</er>, <pos>v.</pos>]</ety> <def>A robbery; a
taking of property by threatening (or performing) violence on the person
who is robbed. See <er>mug</er>, <pos>v.</pos></def><br/
<syn><b>Syn. --</b> robbery, holdup, stickup</syn><br/
[<source>PJC</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Muggins</ent><br/
<hw>Mug"gins</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etym.
unknown.]</ety> <sn>1.</sn> <def>A game of dominoes in which the object
is to make the sum of the two ends of the line some multiple of
five.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A game at cards which depends upon building in suits
or matching exposed cards, the object being to get rid of one's
cards.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muggins</ent><br/
<hw>Mug"gins</hw>, <pos>v. t.</pos> <def>In certain games, to score
against, or take an advantage over (an opponent), as for an error,
announcing the act by saying <ldquo/muggins.<rdquo/</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muggish</ent><br/
<hw>Mug"gish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Muggy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muggletonian</ent><br/
<hw>Mug`gle*to"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>One of an extinct sect, named after <person>Ludovic
<etsep>Muggleton</etsep></person>, an English journeyman tailor, who
(about 1657) claimed to be inspired.</def> <rj><au>Eadie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muggy</ent><br/
<hw>Mug"gy</hw> <pr>(m<ucr/g"g<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Muggier</adjf>
<pr>(m<ucr/g"g<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Muggiest</adjf>.]</amorph> <ety>[Cf. Icel. <ets>mugga</ets> mist,
mugginess. Cf. 4th <er>Mold</er>.]</ety> <sn>1.</sn> <def>Moist; damp;
moldy; <as>as, <ex>muggy</ex> straw</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Warm, damp, and windless; uncomfortably hot and
humid; sultry; <as>as, <ex>muggy</ex> air, weather</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 952 --></p>

<p><ent>Mughouse</ent><br/
<hw>Mug"house`</hw> <pr>(m<ucr/g"hous`)</pr>, <pos>n.</pos> <def>An
alehouse; a pothouse.</def> <rj><au>Tickel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugiency</ent><br/
<hw>Mu"gi*en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bellowing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugient</ent><br/
<hw>Mu"gi*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mugiens</ets>, p. pr. of <ets>mugire</ets> to bellow.]</ety>
<def>Lowing; bellowing.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugil</ent><br/
\'d8<hw>Mu"gil</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., a sort
of fish.]</ety> <fld>(Zool.)</fld> <def>A genus of fishes including the
gray mullets. See <er>Mullet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugilidae</ent><br/
<hw>Mugilidae</hw> <pos>prop. n.</pos> <def>A natural family of fish
including the gray mullets.</def><br/
<syn><b>Syn. --</b> family <fam>Mugilidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mugiloidea</ent><br/
<hw>Mugiloidea</hw> <pos>prop. n.</pos> <def>A suborder of fishes
distinguished by abdominal pelvic fins, including the families
<fam>Mugilidae</fam>; <fam>Atherinidae</fam>; and
<fam>Sphyraenidae</fam>.</def><br/
<syn><b>Syn. --</b> suborder <subord>Mugiloidea</subord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mugiloid</ent><br/
<hw>Mu"gi*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or pertaining to the genus <gen>Mugil</gen>, or family
<fam>Mugilidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugweed</ent><br/
<hw>Mug"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
slender European weed (<spn>Galium Cruciata</spn>); -- called also
<altname>crossweed</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mugwort</ent><br/
<hw>Mug"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mucgwyrt</ets>. Cf. <er>Midge</er>.]</ety> <fld>(Bot.)</fld> <def>A
somewhat aromatic composite weed (<spn>Artemisia vulgaris</spn>), at one
time used medicinally; -- called also
<altname>motherwort</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mugwump</ent><br/
<hw>mug"wump`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Algonquin
<ets>mugquomp</ets> a chief.]</ety> <sn>1.</sn> <def>A bolter from the
Republican party in the national election of 1884; an Independent.</def>
<mark>[Political Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who is undecided about an issue, especially
a political one; a person who takes a neutral stance on an issue; a
fence-sitter.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mugwumpism</ent><br/
<ent>Mugwumpery</ent><br/
<mhw>{ <hw>Mug"wump`er*y</hw> <pr>(?)</pr>, <hw>Mug"wump*ism</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The acts and views of the
mugwumps.</def> <mark>[Political Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muhammedan</ent><br/
<ent>Muhammadan</ent><br/
<mhw>{ <hw>Mu*ham"mad*an</hw> <pr>(?)</pr>, <hw>Mu*ham"med*an</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Islamic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muhammedan</ent><br/
<ent>Muhammadan</ent><br/
<mhw>{ <hw>Mu*ham"mad*an</hw> <pr>(?)</pr>, <hw>Mu*ham"med*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>A Muslim.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muhammadanism</ent><br/
<hw>Mu*ham"mad*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Mohammedanism; Islam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muharram</ent><br/
<hw>Muharram</hw> <pos>n.</pos> <def>The first month of the Islamic
calendar.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>muishond</ent><br/
<hw>muishond</hw> <pos>n.</pos> <def>A southern African
weasel.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mujik</ent><br/
<hw>mujik</hw> <pos>n.</pos> <def>A Russian peasant (especially prior to
1917).</def><br/
<syn><b>Syn. --</b> muzhik, moujik, muzjik.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mulada</ent><br/
\'d8<hw>Mu*la"da</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A moor.</def>
<mark>[Scot.]</mark> <rj><au>Lockhart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulada</ent><br/
\'d8<hw>Mu*la"da</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. Amer., fr.
Sp. <ets>mulo</ets>, <ets>mula</ets>, a mule.]</ety> <def>A drove of
mules.</def> <mark>[Southwest. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulatto</ent><br/
<hw>Mu*lat"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mulattoes</plw> <pr>(#)</pr>.</plu> <ety>[Sp. & Pg.
<ets>mulato</ets>, masc., <ets>mulata</ets>, fem., of a mixed breed, fr.
<ets>mulo</ets> mule, L. <ets>mulus</ets>. See <er>Mule</er>.]</ety>
<def>The offspring of a negress by a white man, or of a white woman by a
negro, -- usually of a brownish yellow complexion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulattress</ent><br/
<hw>Mu*lat"tress</hw>, <pos>n.</pos> <def>A female mulatto.</def>
<rj><au>G. W. Gable.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulberry</ent><br/
<hw>Mul"ber*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mulberries</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>moolbery</ets>,
<ets>murberie</ets>, AS. <ets>murberie</ets>, where the first part is
fr. L. <ets>morum</ets> mulberry; cf. Gr. <?/, <?/. Cf. <er>Murrey</er>,
<er>Sycamore</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>The berry
or fruit of any tree of the genus <gen>Morus</gen>; also, the tree
itself. See <er>Morus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dark pure color, like the hue of a black
mulberry.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mulberry mass</b></col>. <fld>(Biol.)</fld> <cd>See
<er>Morula</er>.</cd> -- <col><b>Paper mulberry</b></col>, <cd>a tree
(<spn>Broussonetia papyrifera</spn>), related to the true mulberry, used
in Polynesia for making tapa cloth by macerating and pounding the inner
bark, and in China and Japan for the manufacture of paper. It is seen as
a shade tree in America.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulberry-faced</ent><br/
<hw>Mul"ber*ry-faced`</hw> <pr>(-f<amac/st`)</pr>, <pos>a.</pos>
<def>Having a face of a mulberry color, or blotched as if with mulberry
stains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulch</ent><br/
<hw>Mulch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <ets>mull</ets>
dirt, also Prov. G. <ets>mulsch</ets>, <ets>molsch</ets>, rotten, soft,
mellow, as fruit.]</ety> <def>Half-rotten straw, or any similar light,
porous, organic substance strewn on the ground, as over the roots of
plants, to protect from heat, drought, etc., and to hinder weed growth
and preserve moisture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulch</ent><br/
<hw>Mulch</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mulched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mulching</conjf>.]</vmorph> <def>To cover or dress with
mulch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulct</ent><br/
<hw>Mulct</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>mulcta</ets>,
<ets>multa</ets>.]</ety> <sn>1.</sn> <def>A fine or penalty, esp. a
pecuniary punishment or penalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A blemish or defect.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Amercement; forfeit; forfeiture;
penalty.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulct</ent><br/
<hw>Mulct</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mulcted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Mulcting</conjf>.]</vmorph> <ety>[L. <ets>mulctare</ets>,
<ets>multare</ets>.]</ety> <sn>1.</sn> <def>To punish for an offense or
misdemeanor by imposing a fine or forfeiture, esp. a pecuniary fine; to
fine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to deprive of; to withhold by way of
punishment or discipline.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulctuary</ent><br/
<ent>Mulctary</ent><br/
<mhw>{ <hw>Mulc"ta*ry</hw> <pr>(?)</pr>, <hw>Mulc"tu*a*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Imposing a pecuniary penalty;
consisting of, or paid as, a fine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fines, or some known <qex>mulctuary</qex> punishments.</q>
<rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mule</ent><br/
<hw>Mule</hw> <pr>(m<umac/l)</pr>, <pos>n.</pos> <ety>[F., a she-mule,
L. <ets>mula</ets>, fem. of <ets>mulus</ets>; cf. Gr.
<grk>my`klos</grk>, <grk>mychlo`s</grk>. Cf. AS. <ets>m<umac/l</ets>,
fr. L. <ets>mulus</ets>. Cf. <er>Mulatto</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A hybrid animal; specifically, one generated
between an ass and a mare. Sometimes the term is applied to the
offspring of a horse and a she-ass, but that hybrid is more properly
termed a <contr>hinny</contr>. See <er>Hinny</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Mules are much used as draught animals. They are hardy,
and proverbial for stubbornness.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A plant or vegetable produced by
impregnating the pistil of one species with the pollen or fecundating
dust of another; -- called also <altname>hybrid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A very stubborn person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A machine, used in factories, for spinning cotton,
wool, etc., into yarn or thread and winding it into cops; -- called also
<altname>jenny</altname> and <altname>mule-jenny</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A slipper that has no fitting around the
heel.</def><br/
<syn><b>Syn. --</b> mules, scuff, scuffs.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Mule armadillo</b></col> <fld>(Zool.)</fld>, <cd>a
long-eared armadillo <fld>(Tatusia hybrida)</fld>, native of Buenos
Ayres; -- called also <altname>mulita</altname>. See <xex>Illust.</xex>
under <er>Armadillo</er>.</cd> -- <col><b>Mule deer</b></col>
<fld>(Zool.)</fld>, <cd>a large deer (<spn>Cervus macrotis</spn> syn.
<spn>Cariacus macrotis</spn>) of the Western United States. The name
refers to its long ears.</cd> -- <col><b>Mule pulley</b></col>
<fld>(Mach.)</fld>, <cd>an idle pulley for guiding a belt which
transmits motion between shafts that are not parallel.</cd> --
<col><b>Mule twist</b></col>, <cd>cotton yarn in cops, as spun on a
mule; -- in distinction from yarn spun on a throstle
frame.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mule-jenny</ent><br/
<hw>Mule"-jen`ny</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mule</er>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mule killer</ent><br/
<hw>Mule killer</hw>. <def>Any of several arthropods erroneously
supposed to kill live stock, in the southern United States, by stinging
or by being swallowed;</def> as: <sd>(a)</sd> <def>A whip
scorpion.</def> <mark>[Florida]</mark> <sd>(b)</sd> <def>A walking-stick
insect.</def> <mark>[Texas]</mark> <sd>(c)</sd> <def>A mantis.</def>
<sd>(d)</sd> <def>A wheel bug.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muleteer</ent><br/
<hw>Mu`le*teer"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>muletier</ets>, fr. <ets>mulet</ets> a mule, dim. fr. L.
<ets>mulus</ets>.]</ety> <def>One who drives mules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulewort</ent><br/
<hw>Mule"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
fern of the genus <gen>Hemionitis</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muley</ent><br/
<hw>Mu"ley</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Sawmills)</fld> <def>A
stiff, long saw, guided at the ends but not stretched in a
gate.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Muley axle</b></col> <fld>(Railroad)</fld>, <cd>a car
axle without collars at the outer ends of the journals.</cd>
<rj><au>Forney.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muley</ent><br/
<hw>Mul"ey</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mulley</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muliebrity</ent><br/
<hw>Mu`li*eb"ri*ty</hw> <pr>(m<umac/`l<icr/*<ecr/b"r<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>muliebritas</ets>, fr. <ets>muliebris</ets>
belonging to a woman, fr. <ets>mulier</ets> a woman.]</ety> <sn>1.</sn>
<def>The state of being a woman or of possessing full womanly powers;
womanhood; -- correlate of <contr>virility</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Effeminancy;
softness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulier</ent><br/
\'d8<hw>Mu"li*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
woman.]</ety> <sn>1.</sn> <def>A woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>Lawful issue born in
wedlock, in distinction from an elder brother born of the same parents
before their marriage; a lawful son.</def> <sd>(b)</sd> <fld>(Civ.
Law)</fld> <def>A woman; a wife; a mother.</def> <rj><au>Blount.</au>
<au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulierly</ent><br/
<hw>Mu"li*er*ly</hw>, <pos>adv.</pos> <def>In the manner or condition of
a mulier; in wedlock; legitimately.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulierose</ent><br/
<hw>Mu"li*er*ose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mulierosus</ets>.]</ety> <def>Fond of woman.</def>
<mark>[R.]</mark> <rj><au>Charles Reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulierosity</ent><br/
<hw>Mu`li*er*os"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mulierositas</ets>.]</ety> <def>A fondness for women.</def>
<mark>[R.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulierty</ent><br/
<hw>Mu"li*er*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>Condition of being a mulier; position of one born in lawful
wedlock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulish</ent><br/
<hw>Mul"ish</hw> <pr>(m<umac/l"<icr/sh)</pr>, <pos>a.</pos> <def>Like a
mule; sullen; stubborn.</def> -- <wordforms><wf>Mul"ish*ly</wf>,
<pos>adv.</pos> -- <wf>Mul"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw> <pr>(m<ucr/l)</pr>, <pos>n.</pos> <ety>[Perh. contr. fr.
<ets>mossul</ets>. See <er>Muslin</er>.]</ety> <def>A thin, soft kind of
muslin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw>, <pos>n.</pos> <ety>[Icel. <ets>m<umac/li</ets> a snout,
muzzle, projecting crag; or cf. Ir. & Gael. <ets>meall</ets> a heap of
earth, a mound, a hill or eminence, W. <ets>moel</ets>. Cf.
<er>Mouth</er>.]</ety> <sn>1.</sn> <def>A promontory; <as>as, the
<ex>Mull</ex> of Cantyre</as>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A snuffbox made of the small end of a
horn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw>, <pos>n.</pos> <ety>[Prob. akin to <ets>mold</ets>.
<root/108. See <er>Mold</er>.]</ety> <def>Dirt; rubbish.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw>, <pos>v. t.</pos> <ety>[OE. <ets>mullen</ets>. See 2d
<er>Muller</er>.]</ety> <def>To powder; to pulverize.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw>, <pos>v. i.</pos> <def>To work (over) mentally; to
cogitate; to ruminate; -- usually with <ptcl>over</ptcl>; <as>as, to
<ex>mull</ex> over a thought or a problem</as>.</def> <mark>[Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw>, <pos>n.</pos> <def>An inferior kind of madder prepared
from the smaller roots or the peelings and refuse of the
larger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mull</ent><br/
<hw>Mull</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mulled</conjf> <pr>(m<ucr/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mulling</conjf>.]</vmorph> <ety>[From <ets>mulled</ets>, for
<ets>mold</ets>, taken as a p. p.; OE. <ets>mold</ets>-ale funeral ale
or banquet. See <er>Mold</er> soil.]</ety> <sn>1.</sn> <def>To heat,
sweeten, and enrich with spices; <as>as, to <ex>mull</ex>
wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>New cider, <qex>mulled</qex> with ginger warm.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dispirit or deaden; to dull or blunt.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullah</ent><br/
<ent>Mulla</ent><br/
<mhw><hw>Mul"la</hw>, <hw>Mul"lah</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<def>Same as <er>Mollah</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullagatawny</ent><br/
<hw>Mul`la*ga*taw"ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Tamil
<ets>milagu-tann<imac/r</ets> pepper water.]</ety> <def>An East Indian
curry soup.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullah</ent><br/
<hw>Mul"lah</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mollah</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullar</ent><br/
<hw>Mul"lar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A die, cut in
intaglio, for stamping an ornament in relief, as upon metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullein</ent><br/
<hw>Mul"lein</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>moleyn</ets>, AS. <ets>molegn</ets>.]</ety> <fld>(Bot.)</fld>
<def>Any plant of the genus <gen>Verbascum</gen>. They are tall herbs
having coarse leaves, and large flowers in dense spikes. The common
species, with densely woolly leaves, is <spn>Verbascum
Thapsus</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moth mullein</b></col>. <cd>See under <er>Moth</er>.</cd>
-- <col><b>Mullein foxglove</b></col>, <cd>an American herb
(<spn>Seymeria macrophylla</spn>) with coarse leaves and yellow tubular
flowers with a spreading border.</cd> -- <col><b>Petty
mullein</b></col>, <cd>the cowslip.</cd> <au>Dr. Prior.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullen</ent><br/
<hw>Mul"len</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<er>Mullein</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muller</ent><br/
<hw>Mull"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, mulls.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vessel in which wine, etc., is mulled over a
fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muller</ent><br/
<hw>Mull"er</hw>, <pos>n.</pos> <ety>[OE. <ets>mullen</ets> to
pulverize, bruise; cf. Icel. <ets>mylja</ets>; prob. akin to E.
<ets>mold</ets> soil. See <er>Mold</er> soil, and cf. <er>Mull</er>
dirt.]</ety> <def>A stone or thick lump of glass, or kind of pestle,
flat at the bottom, used for grinding pigments or drugs, etc., upon a
slab of similar material.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muellerian</ent><br/
<ent>Mullerian</ent><br/
<hw>M<uum/l*le"ri*an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <fld>(Anat.,
Med.)</fld> <def>Of, pertaining to, or discovered by, <person>Johannes
<etsep>M<uum/ller</etsep></person>; <as>as, Mullerian duct; Muellerian
tumor; M<uum/llerian capsule</as>.</def><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><cs><col><b>M<uum/llerian ducts</b></col> <fld>(Anat.)</fld>, <cd>a
pair of embryonic ducts which give rise to the genital passages in the
female, but disappear in the male.</cd> -- <col><b>M<uum/llerian
fibers</b></col> <fld>(Anat.)</fld>, <cd>the sustentacular or
connective-tissue fibers which form the framework of the
retina.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullet</ent><br/
<hw>Mul"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>molet</ets>,
<ets>mulet</ets>, F. <ets>mulet</ets>, fr. L. <ets>mullus</ets>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>Any one of numerous fishes of the
genus Mugil; -- called also <altname>gray mullets</altname>. They are
found on the coasts of both continents, and are highly esteemed as food.
Among the most valuable species are <styp><spn>Mugil capito</spn></styp>
of Europe, and <styp><spn>Mugil cephalus</spn></styp> which occurs both
on the European and American coasts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any species of the genus
<gen>Mullus</gen>, or family <fam>Mullidae</fam>; called also
<altname>red mullet</altname>, and <altname>surmullet</altname>, esp.
the plain surmullet (<spn>Mullus barbatus</spn>), and the striped
surmullet (<spn>Mullus surmulletus</spn>) of Southern Europe. The former
is the mullet of the Romans. It is noted for the brilliancy of its
colors. See <er>Surmullet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>French mullet</b></col>. <cd>See <er>Ladyfish</er>
<sd>(a)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullet</ent><br/
<hw>Mul"let</hw>, <pos>n.</pos> <ety>[F. <ets>molette</ets>.]</ety>
<fld>(Her.)</fld> <def>A star, usually five pointed and pierced; -- when
used as a difference it indicates the third son.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullet</ent><br/
<hw>Mul"let</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>molet</ets> a sort of
pinchers.]</ety> <def>Small pinchers for curling the hair.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moolley</ent><br/
<ent>Mulley</ent><br/
<mhw>{ <hw>Mul"ley</hw> <pr>(?)</pr>, <hw>Mool"ley</hw> }</mhw>,
<pos>n.</pos> <ety>[CF. Gael. <ets>maolag</ets> a hornless cow,
<ets>maol</ets> bald, hornless, blunt.]</ety> <sn>1.</sn> <def>A mulley
or polled animal.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cow.</def> <mark>[Prov. Eng.; U.S., a child's
word.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Leave milking and dry up old <qex>mulley</qex>, thy cow.</q>
<rj><qau>Tusser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Moolley</ent><br/
<ent>Mulley</ent><br/
<mhw>{ <hw>Mul"ley</hw> <pr>(?)</pr>, <hw>Mool"ley</hw> }</mhw>,
<pos>a.</pos> <def>Destitute of horns, although belonging to a species
of animals most of which have horns; hornless; polled; <as>as,
<ex>mulley</ex> cattle; a <ex>mulley</ex> (or <ex>moolley</ex>)
cow.</as></def> <mark>[U. S.]</mark> <altsp>[Written also
<asp>muley</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>mulligan stew</ent><br/
<ent>mulligan</ent><br/
<mhw><hw>mulligan</hw>, <hw>mulligan stew</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>A stew made typically of meat, vegetables, and any
conveniently available ingredients; also, an Irish version of
burgoo.</def><br/
<syn><b>Syn. --</b> Irish burgoo.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Golf)</fld> <def>In informal and friendly games of
golf, a permission to take another stroke without counting the previous
stroke against the score, when a stroke was poorly played; a free
stroke; <as>as, to take a <ex>mulligan</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mulligatawny</ent><br/
<hw>Mul`li*ga*taw"ny</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mullagatawny</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulligrubs</ent><br/
<hw>Mul"li*grubs</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Prov. E.
<ets>mull</ets> to squeeze, pull about, <ets>mulling</ets> numb or
dull.]</ety> <sn>1.</sn> <def>A griping of the intestines; colic.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose dog lies sick of the <qex>mulligrubs</qex>?</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, sullenness; the sulks.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullingong</ent><br/
<hw>Mul"lin*gong</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <cref>Duck mole</cref>, under <er>Duck</er>.</def>
<altsp>[Written also <asp>mollingong</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullion</ent><br/
<hw>Mul"lion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A corruption of
<ets>munnion</ets>, F. <ets>moignon</ets> stump of an amputated limb,
stump, OF. <ets>moing</ets> mutilated; cf. Armor. <ets>mo<ntil/</ets>,
<ets>mou<ntil/</ets>, <ets>mank</ets>, <ets>monk</ets>, and also L.
<ets>mancus</ets> maimed.]</ety> <fld>(Arch.)</fld> <sd>(a)</sd> <def>A
slender bar or pier which forms the division between the lights of
windows, screens, etc.</def> <sd>(b)</sd> <def>An upright member of a
framing. See <er>Stile</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullion</ent><br/
<hw>Mul"lion</hw>, <pos>v. t.</pos> <def>To furnish with mullions; to
divide by mullions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mullock</ent><br/
<hw>Mul"lock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Mull</er>
dirt: cf. Scot. <ets>mulloch</ets>, <ets>mulock</ets>, crumb.
<root/108.]</ety> <def>Rubbish; refuse; dirt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All this <qex>mullok</qex> [was] in a sieve ythrowe.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulloid</ent><br/
<hw>Mul"loid</hw> <pr>(m<ucr/l"loid)</pr>, <pos>a.</pos> <ety>[NL.
<ets>Mullus</ets>, generic name (fr. L. <ets>mullus</ets> surmullet) +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or pertaining to
the genus <gen>Mullus</gen>, which includes the surmullet, or red
mullet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mull over</ent><br/
<hw>mull over</hw>, <pos>v. t.</pos> <def>To think about; to consider;
to ruminate about; <as>as, <ex>mull</ex> it <ex>over</ex> and decide in
the morning</as>.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulmul</ent><br/
<hw>Mul"mul</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fine, soft muslin;
mull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mulse</ent><br/
<hw>Mulse</hw> <pr>(m<ucr/ls)</pr>, <pos>n.</pos> <ety>[L.
<ets>mulsum</ets> (sc. <ets>vinum</ets>), fr. <ets>mulsus</ets> mixed
with honey, honey-sweet, p. p. of <ets>mulcere</ets> to sweeten,
soften.]</ety> <def>Wine boiled and mingled with honey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mult-</ent><br/
<hw>Mult-</hw>. <def>See <er>Multi-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multangular</ent><br/
<hw>Mul*tan"gu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multangulus</ets>; <ets>multus</ets> much, many +
<ets>angulus</ets> angle: cf. F. <ets>multangulaire</ets>.]</ety>
<def>Having many angles.</def> -- <wordforms><wf>Mul*tan"gu*lar*ly</wf>,
<pos>adv.</pos> -- <wf>Mul*tan"gu*lar*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multanimous</ent><br/
<hw>Mul*tan"i*mous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mult-</ets> + L. <ets>animus</ets> mind.]</ety>
<def>Many-minded; many-sided.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>multanimous</qex> nature of the poet.</q> <rj><qau>J. R.
Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multarticulate</ent><br/
<hw>Mul`tar*tic"u*late</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mult-</ets> + <ets>articulate</ets>.]</ety> <def>Having many
articulations or joints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multeity</ent><br/
<hw>Mul*te"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>multus</ets> much, many.]</ety> <def>Multiplicity.</def>
<mark>[R.]</mark> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mult-</ent><br/
<ent>Multi-</ent><br/
<mhw>{ <hw>Mul"ti-</hw> <pr>(?)</pr>, <hw>Mult-</hw> <pr>(?)</pr>
}</mhw>. <ety>[L. <ets>multus</ets> much.]</ety> <def>A prefix
signifying <sig>much</sig> or <sig>many</sig>; <sig>several</sig>;
<sig>more than one</sig>; <as>as, <ex>multi</ex>axial,
<ex>mult</ex>ocular</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiaxial</ent><br/
<hw>Mul`ti*ax"i*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>axial</ets>.]</ety> <fld>(Biol.)</fld>
<def>Having more than one axis; developing in more than a single line or
plain; -- opposed to <ant>monoaxial</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicapsular</ent><br/
<hw>Mul`ti*cap"su*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>capsular</ets>: cf. F.
<ets>multicapsulaire</ets>.]</ety> <fld>(Bot.)</fld> <def>Having many,
or several, capsules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicarinate</ent><br/
<hw>Mul`ti*car"i*nate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>carinate</ets>.]</ety> <fld>(Zool.)</fld>
<def>Many-keeled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicavous</ent><br/
<hw>Mul`ti*ca"vous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multicavus</ets>; <ets>multus</ets> much, many + <ets>cavum</ets>,
<ets>cavus</ets>, a cavity, hole, fr. <ets>cavus</ets> hollow.]</ety>
<def>Having many cavities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicellular</ent><br/
<hw>Mul`ti*cel"lu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting
of, or having, many cells or more than one cell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicentral</ent><br/
<hw>Mul`ti*cen"tral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>central</ets>.]</ety> <def>Having many,
or several, centers; <as>as, a <ex>multicentral</ex>
cell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Multicentral development</b></col> <fld>(Biol.)</fld>,
<cd>growth, or development, from several centers. According as the
insubordination to a single center is more or less pronounced, the
resultant organism will be more or less irregular in form and may even
become discontinuous.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicipital</ent><br/
<hw>Mul`ti*cip"i*tal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + L. <ets>caput</ets> head.]</ety>
<fld>(Bot.)</fld> <def>Having many heads or many stems from one crown or
root.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicolor</ent><br/
<hw>Mul"ti*col`or</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Multi-</er>, and <er>Color</er>.]</ety> <def>Having many, or
several, colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicostate</ent><br/
<hw>Mul`ti*cos"tate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>costate</ets>.]</ety> <def>Having
numerous ribs, or costae, as the leaf of a plant, or as certain shells
and corals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicuspid</ent><br/
<hw>Mul`ti*cus"pid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<ets>Multi-</ets>, and <ets>Cuspid</ets>.]</ety> <def>Multicuspidate; --
said of teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multicuspidate</ent><br/
<hw>Mul`ti*cus"pi*date</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>cuspidate</ets>.]</ety> <def>Having many
cusps or points.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multidentate</ent><br/
<hw>Mul`ti*den"tate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>dentate</ets>.]</ety> <def>Having many
teeth, or toothlike processes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multidigitate</ent><br/
<hw>Mul`ti*dig"i*tate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>digitate</ets>.]</ety> <def>Having many
fingers, or fingerlike processes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifaced</ent><br/
<hw>Mul"ti*faced`</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>face</ets>.]</ety> <def>Having many
faces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifarious</ent><br/
<hw>Mul`ti*fa"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multifarius</ets>; <ets>multus</ets> much, many. Cf.
<er>Bifarious</er>.]</ety> <sn>1.</sn> <def>Having multiplicity; having
great diversity or variety; of various kinds; diversified; made up of
many differing parts; manifold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a <qex>multifarious</qex> artifice in the structure of
the meanest animal.</q> <rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having parts, as leaves, arranged
in many vertical rows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifariously</ent><br/
<hw>Mul`ti*fa"ri*ous*ly</hw>, <pos>adv.</pos> <def>With great
multiplicity and diversity; with variety of modes and
relations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifariousness</ent><br/
<hw>Mul`ti*fa"ri*ous*ness</hw>, <pos>n.</pos> <sn>1.</sn>
<def>Multiplied diversity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The fault of improperly uniting in
one bill distinct and independent matters, and thereby confounding
them.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiferous</ent><br/
<hw>Mul*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multifer</ets>; <ets>multus</ets> much, many + <ets>ferre</ets> to
bear.]</ety> <def>Bearing or producing much or many.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifid</ent><br/
<hw>Mul"ti*fid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multifidus</ets>; <ets>multus</ets> much, many + <ets>findere</ets>
to split: cf. F. <ets>multifide</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having many segments; cleft into several parts by linear sinuses;
<as>as, a <ex>multifid</ex> leaf or corolla</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiflorous</ent><br/
<hw>Mul`ti*flo"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multiflorus</ets>; <ets>multus</ets> much, many + <ets>flos</ets>,
<ets>floris</ets>, flower: cf. F. <ets>multiflore</ets>.]</ety>
<fld>(Bot.)</fld> <def>Having many flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 953 --></p>

<p><ent>Multiflue</ent><br/
<hw>Mul"ti*flue</hw> <pr>(m<ucr/l"t<icr/*fl<umac/)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>flue</ets>.]</ety> <def>Having many
flues; <as>as, a <ex>multiflue</ex> boiler</as>. See
<er>Boiler</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifoil</ent><br/
<hw>Mul"ti*foil</hw> <pr>(m<ucr/l"t<icr/*foil)</pr>, <pos>n.</pos>
<ety>[<ets>Multi-</ets> + <ets>foil</ets>.]</ety> <fld>(Arch.)</fld>
<def>An ornamental foliation consisting of more than five divisions or
foils.</def> <mark>[R.]</mark> <see>See <er>Foil</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifoil</ent><br/
<hw>Mul"ti*foil</hw>, <pos>a.</pos> <def>Having more than five divisions
or foils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multifold</ent><br/
<hw>Mul"ti*fold</hw> <pr>(m<ucr/l"t<icr/*f<omac/ld)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>fold</ets>.]</ety> <def>Many times
doubled; manifold; numerous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiform</ent><br/
<hw>Mul"ti*form</hw> <pr>(m<ucr/l"t<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[L. <ets>multiformis</ets>; <ets>multus</ets> much, many +
<ets>forma</ets> shape: cf. F. <ets>multiforme</ets>.]</ety> <def>Having
many forms, shapes, or appearances.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A plastic and <qex>multiform</qex> unit.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiformity</ent><br/
<hw>Mul`ti*form"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>multiformitas</ets>.]</ety> <def>The quality of being multiform;
diversity of forms; variety of appearances in the same thing.</def>
<rj><au>Purchas.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiformous</ent><br/
<hw>Mul`ti*form"ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Multiform.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multigenerous</ent><br/
<hw>Mul`ti*gen"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multigenerus</ets>; <ets>multus</ets> + <ets>genus</ets>,
<ets>generis</ets>, kind.]</ety> <def>Having many kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multigranulate</ent><br/
<hw>Mul`ti*gran"u*late</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>granulate</ets>.]</ety> <def>Having, or
consisting of, many grains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multigraph</ent><br/
<hw>Mul"ti*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Multi-</ets> + <ets>-graph</ets>.]</ety> <def>A combined
rotary type-setting and printing machine for office use. The type is
transferred semi-automatically by means of keys from a type-supply drum
to a printing drum. The printing may be done by means of an inked ribbon
to print <ldquo/typewritten<rdquo/ letters, or directly from inked type
or a stereotype plate, as in a printing press.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Multijugate</ent><br/
<hw>Mul*tij"u*gate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having many
pairs of leaflets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multijugous</ent><br/
<hw>Mul*tij"u*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multijugus</ets>; <ets>multus</ets> + <ets>jugum</ets> yoke.]</ety>
<sn>1.</sn> <def>Consisting of many parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Same as
<er>Multijugate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multilateral</ent><br/
<hw>Mul`ti*lat"er*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>lateral</ets>.]</ety> <def>Having many
sides; many-sided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multilineal</ent><br/
<hw>Mul`ti*lin"e*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>lineal</ets>.]</ety> <def>Having many
lines.</def> <rj><au>Steevens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multilobar</ent><br/
<hw>Mul`ti*lo"bar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>lobar</ets>.]</ety> <def>Consisting of,
or having, many lobes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multilocular</ent><br/
<hw>Mul`ti*loc"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>locular</ets>: cf. F.
<ets>multiloculaire</ets>.]</ety> <def>Having many or several cells or
compartments; <as>as, a <ex>multilocular</ex> shell or
capsule</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiloquence</ent><br/
<hw>Mul*til"o*quence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality of
being multiloquent; use of many words; talkativeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiloquous</ent><br/
<ent>Multiloquent</ent><br/
<mhw>{ <hw>Mul*til"o*quent</hw> <pr>(?)</pr>, <hw>Mul*til"o*quous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>multiloquus</ets>;
<ets>multus</ets> much, many + <ets>loqui</ets> to speak.]</ety>
<def>Speaking much; very talkative; loquacious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiloquy</ent><br/
<hw>Mul*til"o*quy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>multiloquium</ets>.]</ety> <def>Excess of words or talk.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multinodate</ent><br/
<hw>Mul`ti*no"date</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>nodate</ets>.]</ety> <def>Having many
knots or nodes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multinodous</ent><br/
<hw>Mul`ti*no"dous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multinodus</ets>.]</ety> <def>Same as
<er>Multinodate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multinomial</ent><br/
<hw>Mul`ti*no"mi*al</hw> <pr>(?)</pr>, <pos>n. & a.</pos>
<ety>[<ets>Multi-</ets> + <ets>-nomial</ets>, as in binomial. See
<er>Binomial</er>.]</ety> <fld>(Alg.)</fld> <def>Same as
<er>Polynomial</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multinominous</ent><br/
<ent>Multinominal</ent><br/
<mhw>{ <hw>Mul`ti*nom"i*nal</hw> <pr>(?)</pr>,
<hw>Mul`ti*nom"i*nous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>multinominis</ets>; <ets>multus</ets> many + <ets>nomen
nominis</ets> name.]</ety> <def>Having many names or terms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>multinominal</ent><br/
<hw>mul`ti*nom"i*nal</hw> <pos>n.</pos> <fld>(Math.)</fld>
<def>Polynomial.</def> <mark>[R.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Multinuclear</ent><br/
<hw>Mul`ti*nu"cle*ar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>nuclear</ets>.]</ety> <fld>(Biol.)</fld>
<def>Containing many nuclei; <as>as, <ex>multinuclear</ex>
cells</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multinucleated</ent><br/
<ent>Multinucleate</ent><br/
<mhw>{ <hw>Mul`ti*nu"cle*ate</hw> <pr>(?)</pr>,
<hw>Mul`ti*nu"cle*a`ted</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Biol.)</fld> <def>Multinuclear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiparous</ent><br/
<hw>Mul*tip"a*rous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + L. <ets>parere</ets> to produce: cf. F.
<ets>multipare</ets>.]</ety> <def>Producing many, or more than one, at a
birth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multipartite</ent><br/
<hw>Mul*tip"ar*tite</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multipartitus multus</ets> much, many <ets>partitus</ets> divided,
p. p.: cf. F. <ets>multipartite</ets>. See <er>Partite</er>.]</ety>
<def>Divided into many parts; having several parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiped</ent><br/
<hw>Mul"ti*ped</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>multipes</ets>, <ets>multipeda</ets>; <ets>multus</ets> much, many
+ <ets>pes</ets>, <ets>pedis</ets>, foot: cf. F.
<ets>multip<egrave/de</ets>.]</ety> <fld>(Zool.)</fld> <def>An insect
having many feet, as a myriapod.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiped</ent><br/
<hw>Mul"ti*ped</hw>, <pos>a.</pos> <def>Having many feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiphase</ent><br/
<hw>Mul"ti*phase</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>phase</ets>.]</ety> <def>Having many
phases;</def> <specif>specif.</specif> <fld>(Elec.)</fld>,
<def>pertaining to, or designating, a generator producing, or any system
conveying or utilizing, two or more waves of pressure, or electromotive
force, not in phase with each other; polyphase.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Multiplane</ent><br/
<hw>Mul"ti*plane</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having several or
many planes or plane surfaces; <as>as, a <ex>multiplane</ex>
kite</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Multiplane</ent><br/
<hw>Mul"ti*plane</hw>, <pos>n.</pos> <ety>[<ets>Multi-</ets> +
<ets>plane</ets>.]</ety> <fld>(Aeronautics)</fld> <def>An airplane with
three or more superposed main wings, such as a
<stype>triplane</stype>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Multiple</ent><br/
<hw>Mul"ti*ple</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>multiple</ets>, and E. <ets>quadruple</ets>, and
<ets>multiply</ets>.]</ety> <def>Containing more than once, or more than
one; consisting of more than one; manifold; repeated many times; having
several, or many, parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Law of multiple proportion</b></col> <fld>(Chem.)</fld>,
<cd>the generalization that when the same elements unite in more than
one proportion, forming two or more different compounds, the higher
proportions of the elements in such compounds are simple multiples of
the lowest proportion, or the proportions are connected by some simple
common factor; thus, iron and oxygen unite in the proportions
<chform>FeO</chform>, <chform>Fe2O3</chform>, <chform>Fe3O4</chform>, in
which compounds, considering the oxygen, 3 and 4 are simple multiplies
of 1. Called also the <altname>Law of Dalton</altname> or
<altname>Dalton's Law</altname>, from its discoverer.</cd> --
<col><b>Multiple algebra</b></col>, <cd>a branch of advanced mathematics
that treats of operations upon units compounded of two or more unlike
units.</cd> -- <col><b>Multiple conjugation</b></col>
<fld>(Biol.)</fld>, <cd>a coalescence of many cells (as where an
indefinite number of amoeboid cells flow together into a single mass)
from which conjugation proper and even fertilization may have been
evolved.</cd> -- <col><b>Multiple fruits</b></col>. <fld>(Bot.)</fld>
<cd>See <cref>Collective fruit</cref>, under <er>Collective</er>.</cd>
-- <col><b>Multiple star</b></col> <fld>(Astron.)</fld>, <cd>several
stars in close proximity, which appear to form a single
system.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiple</ent><br/
<hw>Mul"ti*ple</hw>, <pos>n.</pos> <fld>(Math.)</fld> <def>A quantity
containing another quantity an integral number of times without a
remainder.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <col><b>common multiple</b></col> of two or more
numbers contains each of them a number of times exactly; thus, 24 is a
<ex>common multiple</ex> of 3 and 4. The <col><b>least common
multiple</b></col> is the smallest number that will do this; thus, 12 is
the <ex>least common multiple</ex> of 3 and 4 (abbreviated
<abbr>LCM</abbr>).</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplex</ent><br/
<hw>Mul"ti*plex</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multiplex</ets>, <ets>-plicis</ets>. See <er>Multiply</er>.]</ety>
<def>Manifold; multiple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multipliable</ent><br/
<hw>Mul"ti*pli`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>multipliable</ets>.]</ety> <def>Capable of being multiplied.</def>
-- <wordforms><wf>Mul"ti*pli`a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicable</ent><br/
<hw>Mul"ti*pli*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multiplicabilis</ets>.]</ety> <def>Capable of being multiplied;
multipliable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicand</ent><br/
<hw>Mul"ti*pli*cand`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>multiplicandus</ets> to be multiplied: cf. F.
<ets>multiplicande</ets>.]</ety> <fld>(Math.)</fld> <def>The number
which is to be multiplied by another number called the
<corr>multiplier</corr>. See Note under
<er>Multiplication</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicate</ent><br/
<hw>Mul"ti*pli*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multiplicatus</ets>, p. p. of <ets>multiplicare</ets>. See
<er>Multiply</er>.]</ety> <def>Consisting of many, or of more than one;
multiple; multifold.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Multiplicate flower</b></col> <fld>(Bot.)</fld>, <cd>a
flower that is double, or has an unusual number of petals in consequence
of the abnormal multiplication of the parts of the floral
whorls.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplication</ent><br/
<hw>Mul`ti*pli*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>multiplicatio</ets>: cf. F. <ets>multiplication</ets>. See
<er>Multiply</er>.]</ety> <sn>1.</sn> <def>The act or process of
multiplying, or of increasing in number; the state of being multiplied;
<as>as, the <ex>multiplication</ex> of the human species by natural
generation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The increase and <qex>multiplication</qex> of the world.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>The process of repeating, or
adding to itself, any given number or quantity a certain number of
times; commonly, the process of ascertaining by a briefer computation
the result of such repeated additions; also, the rule by which the
operation is performed; -- the reverse of <inv>division</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word <xex>multiplication</xex> is sometimes used in
mathematics, particularly in multiple algebra, to denote any
distributive operation expressed by one symbol upon any quantity or any
thing expressed by another symbol. Corresponding extensions of meaning
are given to the words <xex>multiply</xex>, <xex>multiplier</xex>,
<xex>multiplicand</xex>, and <xex>product</xex>. Thus, since
<mathex><phi/(<it>x + y</it>) = <phi/<it>x</it> +
<phi/<it>y</it></mathex> (see under <er>Distributive</er>), where
<phi/(<it>x + y</it>), <phi/<it>x</it>, and <phi/<it>y</it> indicate the
results of any distributive operation represented by the symbol <phi/
upon <it>x + y</it>, <it>x</it>, and <it>y</it>, severally, then because
of many very useful analogies <phi/(<it>x + y</it>) is called the
<xex>product</xex> of <phi/ and <it>x + y</it>, and the operation
indicated by <phi/ is called <xex>multiplication</xex>. Cf.
<er>Facient</er>, <pos>n.</pos>, 2.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>An increase above the normal
number of parts, especially of petals; augmentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The art of increasing gold or silver by magic, --
attributed formerly to the alchemists.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Multiplication table</b></col>, <cd>a table giving the
product of a set of numbers multiplied in some regular way; commonly, a
table giving the products of the first ten or twelve numbers multiplied
successively by 1, 2, 3, etc., up to 10 or 12. Called also a
<altname>times table</altname>, used by students in elementary school
prior to memorization of the table.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicative</ent><br/
<hw>Mul"ti*pli*ca*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>multiplicatif</ets>.]</ety> <def>Tending to multiply; having the
power to multiply, or incease numbers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicatively</ent><br/
<hw>Mul"ti*pli*ca*tive*ly</hw>, <pos>adv.</pos> <def>So as to
multiply.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicator</ent><br/
<hw>Mul"ti*pli*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>multiplicateur</ets>. Cf. <er>Multiplier</er>.]</ety> <def>The
number by which another number is multiplied; a multiplier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicious</ent><br/
<hw>Mul`ti*pli"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Multiplex</er>.]</ety> <def>Manifold.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplicity</ent><br/
<hw>Mul`ti*plic"ity</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>multiplicit<eacute/</ets>.]</ety> <def>The quality of being
multiple, manifold, or various; a state of being many; a multitude;
<as>as, a <ex>multiplicity</ex> of thoughts or objects</as>.</def>
<ldquo/A <xex>multiplicity</xex> of goods.<rdquo/
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiplier</ent><br/
<hw>Mul"ti*pli`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>multiplier</ets>. Cf. <er>Multiplicator</er>.]</ety> <sn>1.</sn>
<def>One who, or that which, multiplies or increases number.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>The number by which another
number (the <corr>multiplicand</corr>) is multiplied. See the Note under
<er>Multiplication</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physics)</fld> <def>An instrument for multiplying
or increasing by repetition or accumulation the intensity of a force or
action, as heat or electricity. It is particularly used to render such a
force or action appreciable or measurable when feeble. See
<er>Thermomultiplier</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiply</ent><br/
<hw>Mul"ti*ply</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Multiplied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Multiplying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>multiplier</ets>, L. <ets>multiplicare</ets>, fr.
<ets>multiplex</ets> manifold. See <er>Multitude</er>,
<er>Complex</er>.]</ety> <sn>1.</sn> <def>To increase in number; to make
more numerous; to add quantity to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Impunity will <qex>multiply</qex> motives to disobedience.</q>
<rj><qau>Ames.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>To add (any given number or
quantity) to itself a certain number of times; to find the product of by
multiplication; <as>thus 7 <ex>multiplied</ex> by 8 produces the number
56; to <ex>multiply</ex> two numbers</as>. See the Note under
<er>Multiplication</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To increase (the amount of gold or silver) by the
arts of alchemy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Multiplying gear</b></col> <fld>(Mach.)</fld>, <cd>gear
for increasing speed.</cd> -- <col><b>Multiplying lens</b></col>.
<fld>(Opt.)</fld> <cd>See under <er>Lens</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiply</ent><br/
<hw>Mul"ti*ply</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become greater
in number; to become numerous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When men began to <qex>multiply</qex> on the face of the earth,
and daughters were born unto them.</q> <rj><qau>Gen. vi.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To increase in extent and influence; to
spread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The word of God grew and <qex>multiplied</qex>.</q> <rj><qau>Acts
xii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To increase amount of gold or silver by the arts of
alchemy.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multipolar</ent><br/
<hw>Mul`ti*po"lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>polar</ets>.]</ety> <sn>1.</sn>
<def>Having many poles; in <fld>Anat.</fld>, designating specif. a nerve
cell which has several dendrites.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>Having, or pertaining to, many
poles, as a field magnet or armature of a dynamo, or a dynamo having
such a field magnet or (sometimes) armature.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Multipotent</ent><br/
<hw>Mul*tip"o*tent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multipotens</ets>; <ets>multus</ets> much + <ets>potens</ets>
powerful. See <er>Potent</er>.]</ety> <def>Having manifold power, or
power to do many things.</def> <ldquo/Jove
<xex>multipotent</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multipresence</ent><br/
<hw>Mul`ti*pres"ence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
power of being multipresent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>multipresence</qex> of Christ's body.</q> <rj><qau>Bp.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multipresent</ent><br/
<hw>Mul`ti*pres"ent</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>present</ets>, a.]</ety> <def>Being, or
having the power to be, present in two or more places at once.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiradiate</ent><br/
<hw>Mul`ti*ra"di*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>radiate</ets>.]</ety> <def>Having many
rays.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiramified</ent><br/
<hw>Mul`ti*ram"i*fied</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + p. p. of <ets>ramify</ets>.]</ety>
<def>Divided into many branches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiramose</ent><br/
<hw>Mul`ti*ra*mose"</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>ramose</ets>.]</ety> <def>Having many
branches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiscious</ent><br/
<hw>Mul*tis"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multiscius</ets>; <ets>multus</ets> much + <ets>scius</ets>
knowing, fr. <ets>scire</ets> to know.]</ety> <def>Having much or varied
knowledge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multisect</ent><br/
<hw>Mul"ti*sect</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Multi-</ets>
+ L. <ets>sectus</ets>, p. p. of <ets>secare</ets> to cut.]</ety>
<fld>(Zool.)</fld> <def>Divided into many similar segments; -- said of
an insect or myriapod.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiseptate</ent><br/
<hw>Mul`ti*sep"tate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>septate</ets>.]</ety> <fld>(Bot.)</fld>
<def>Divided into many chambers by partitions, as the pith of the
pokeweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiserial</ent><br/
<hw>Mul`ti*se"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>serial</ets>.]</ety> <fld>(Bot.)</fld>
<def>Arranged in many rows, or series, as the scales of a pine cone, or
the leaves of the houseleek.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multisiliquous</ent><br/
<hw>Mul`ti*sil"i*quous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>siliquious</ets>.]</ety>
<fld>(Bot.)</fld> <def>Having many pods or seed vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multisonous</ent><br/
<hw>Mul*tis"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>multisonus</ets>; <ets>multus</ets> much, many + <ets>sonus</ets>
sound.]</ety> <def>Having many sounds, or sounding much.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multispiral</ent><br/
<hw>Mul`ti*spi"ral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>spiral</ets>.]</ety> <fld>(Zool.)</fld>
<def>Having numerous spiral coils round a center or nucleus; -- said of
the opercula of certain shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multistriate</ent><br/
<hw>Mul`ti*stri"ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>striate</ets>.]</ety> <def>Having many
streaks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multisulcate</ent><br/
<hw>Mul`ti*sul"cate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>sulcate</ets>.]</ety> <def>Having many
furrows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multisyllable</ent><br/
<hw>Mul"ti*syl`la*ble</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Multi-</ets> + <ets>syllable</ets>.]</ety> <def>A word of
many syllables; a polysyllable.</def> <mark>[R.]</mark> --
<wordforms><wf>Mul`ti*syl*lab"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multititular</ent><br/
<hw>Mul`ti*tit"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>titular</ets>.]</ety> <def>Having many
titles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multitubular</ent><br/
<hw>Mul`ti*tu"bu*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>tubular</ets>.]</ety> <def>Having many
tubes; <as>as, a <ex>multitubular</ex> boiler</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multitude</ent><br/
<hw>Mul"ti*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>multitude</ets>, L. <ets>multitudo</ets>, <ets>multitudinis</ets>,
fr. <ets>multus</ets> much, many; of unknown origin.]</ety> <sn>1.</sn>
<def>A great number of persons collected together; a numerous collection
of persons; a crowd; an assembly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But when he saw the <qex>multitudes</qex>, he was moved with
compassion on them.</q> <rj><qau>Matt. ix. 36.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A great number of persons or things, regarded
collectively; <as>as, the book will be read by a <ex>multitude</ex> of
people; the <ex>multitude</ex> of stars; a <ex>multitude</ex> of
cares.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a fault in a <qex>multitude</qex> of preachers, that they
utterly neglect method in their harangues.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>multitude</qex> of flowers<br/
As countless as the stars on high.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being many; numerousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They came as grasshoppers for <qex>multitude</qex>.</q>
<rj><qau>Judg. vi. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The multitude</b></col>, <cd>the populace; the mass of
men.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Throng; crowd; assembly; assemblage; commonalty;
swarm; populace; vulgar. See <er>Throng</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multitudinary</ent><br/
<hw>Mul`ti*tu"di*na*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Multitudinous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multitudinous</ent><br/
<hw>Mul`ti*tu"di*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Consisting of a multitude; manifold in number or condition; <as>as,
<ex>multitudinous</ex> waves</as>.</def> <ldquo/The
<xex>multitudinous</xex> seas.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A renewed jingling of <qex>multitudinous</qex> chains.</q>
<rj><qau>G. Kennan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to a multitude.</def> <ldquo/The
<xex>multitudinous</xex> tongue.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mul`ti*tu"di*nous*ly</wf>, <pos>adv.</pos> --
<wf>Mul`ti*tu"di*nous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multivagous</ent><br/
<ent>Multivagant</ent><br/
<mhw>{ <hw>Mul*tiv"a*gant</hw> <pr>(?)</pr>, <hw>Mul*tiv"a*gous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>multivagus</ets>;
<ets>multus</ets> much + <ets>vagus</ets> wandering; cf.
<ets>vagans</ets>, p. pr. of <ets>vagari</ets>. See
<er>Vagary</er>.]</ety> <def>Wandering much.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multivalence</ent><br/
<hw>Mul*tiv"a*lence</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Quality, state, or degree, of a multivalent element, atom, or
radical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multivalent</ent><br/
<hw>Mul*tiv"a*lent</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + L. <ets>valens</ets>, p. pr. See
<er>Valence</er>.]</ety> <sn>1.</sn> <fld>(Chem.)</fld> <sd>(a)</sd>
<def>Having a valence greater than one, as silicon.</def> <sd>(b)</sd>
<def>Having more than one degree of valence, as sulphur.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Immunology)</fld> <def>Having multiple
antigen-binding sites; -- of antibody molecules.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Immunology)</fld> <def>Containing several types of
antibody, to protect against more than one disease; polyvalent; -- of
vaccines.</def><br/
[<source>PJC</source>]</p>

<p><ent>Multivalve</ent><br/
<hw>Mul"ti*valve</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>multivalve</ets>.]</ety> <fld>(Zool.)</fld> <def>Any mollusk which
has a shell composed of more than two pieces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multivalvular</ent><br/
<ent>Multivalve</ent><br/
<mhw>{ <hw>Mul"ti*valve</hw> <pr>(?)</pr>, <hw>Mul`ti*val"vu*lar</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[<ets>Multi-</ets> +
<ets>valve</ets>, <ets>valvular</ets>: cf. F.
<ets>multivalve</ets>.]</ety> <sn>1.</sn> <def>Having many
valves.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Many-valved; having more than two
valves; -- said of certain shells, as the chitons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multiversant</ent><br/
<hw>Mul*tiv"er*sant</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + L. <ets>versans</ets>, p. pr. See
<er>Versant</er>.]</ety> <def>Turning into many shapes; assuming many
forms; protean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multivious</ent><br/
<hw>Mul*tiv"i*ous</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[L.
<ets>multivius</ets>; <ets>multus</ets> many + <ets>via</ets>
way.]</ety> <def>Having many ways or roads; by many ways.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multivocal</ent><br/
<hw>Mul*tiv"o*cal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>vocal</ets>.]</ety> <def>Signifying many
different things; of manifold meaning; equivocal.</def> <ldquo/An
ambiguous <xex>multivocal</xex> word.<rdquo/
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <def2><pos>n.</pos> <def>A multivocal word.</def>
<mark>[R.]</mark> <au>Fitzed. Hall.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multocular</ent><br/
<hw>Mul*toc"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + L. <ets>oculus</ets> eye.]</ety> <def>Having
many eyes, or more than two.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multum</ent><br/
<hw>Mul"tum</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An extract of quassia
licorice, fraudulently used by brewers in order to economize malt and
hops.</def> <rj><au>Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hard multum</b></col>, <cd>a preparation made from
<spn>Cocculus Indicus</spn>, etc., used to impart an intoxicating
quality to beer.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multungulate</ent><br/
<hw>Mul*tun"gu*late</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Multi-</ets> + <ets>ungulate</ets>.]</ety> <def>Having many
hoofs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Multure</ent><br/
<hw>Mul"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>multure</ets>, <ets>moulture</ets>, F. <ets>mouture</ets>, fr. L.
<ets>molitura</ets> a grinding, <ets>molere</ets> to grind. See
<er>Mill</er> the machine.]</ety> <sn>1.</sn> <fld>(Scots Law)</fld>
<def>The toll for grinding grain.</def> <rj><au>Erskine.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grist or grinding; the grain ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mum</ent><br/
<hw>Mum</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Of imitative origin. Cf.
<er>Mumble</er>.]</ety> <def>Silent; not speaking; <as>as, to keep
<ex>mum</ex></as>.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The citizens are <qex>mum</qex>, and speak not a word.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>mum's the word</b></col> <cd>keep this a secret; don't
tell anybody.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Mum</ent><br/
<hw>Mum</hw>, <pos>interj.</pos> <def>Be silent! Hush!</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mum</qex>, then, and no more.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mum</ent><br/
<hw>Mum</hw>, <pos>n.</pos> <def>Silence.</def> <mark>[R.]</mark>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mum</ent><br/
<hw>Mum</hw>, <pos>n.</pos> <ety>[G. <ets>mummere</ets>, fr. Christian
<ets>Mumme</ets>, who first brewed it in 1492.]</ety> <def>A sort of
strong beer, originally made in Brunswick, Germany.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The clamorous crowd is hushed with mugs of <qex>mum</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumble</ent><br/
<hw>Mum"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mumbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mumbling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>momelen</ets>; cf. D. <ets>mompelen</ets>, <ets>mommelen</ets>, G.
<ets>mummelen</ets>, Sw. <ets>mumla</ets>, Dan. <ets>mumle</ets>. Cf.
<er>Mum</er>, <pos>a.</pos>, <er>Mumm</er>, <er>Mump</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>To speak with the lips partly
closed, so as to render the sounds inarticulate and imperfect; to utter
words in a grumbling indistinct manner, indicating discontent or
displeasure; to mutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Peace, you <qex>mumbling</qex> fool.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A wrinkled hag, with age grown double,<br/
Picking dry sticks, and <qex>mumbling</qex> to herself.</q>
<rj><qau>Otway.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To chew something gently with closed lips.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 954 --></p>

<p><ent>Mumble</ent><br/
<hw>Mum"ble</hw> <pr>(m<ucr/m"b'l)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To utter with a low, inarticulate voice.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To chew or bite gently, as one without
teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gums unarmed, to <qex>mumble</qex> meat in vain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To suppress, or utter imperfectly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumblety peg</ent><br/
<ent>Mumbledy peg</ent><br/
<mhw><hw>Mum"ble*dy peg`</hw>, <hw>Mum"ble*ty peg`</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <def>A game played with a pocketknife, the
object of which is to throw the knife in any of a vairety of ways (such
as over the back), or from various positions, and have it stick in the
ground or another surface. Also called <altname>mumble-the-peg</altname>
and <altname>mumble peg</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mumblenews</ent><br/
<hw>Mum"ble*news`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
talebearer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumbler</ent><br/
<hw>Mum"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mumbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumbling</ent><br/
<hw>Mum"bling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Low; indistinct;
inarticulate.</def> -- <wordforms><wf>Mum"bling*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumbo Jumbo</ent><br/
<hw>Mum"bo Jum"bo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. fr. the
native name of an African god.]</ety> <sn>1.</sn> <def>Among the
Mandingos of the western Sudan, a bugbear by means of which the women
are terrified and disciplined by societies of the men, one of whom
assumes a masquerade for the purpose; hence, loosely, any Negro idol,
fetish, or bugaboo.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The miserable <qex>Mumbo Jumbo</qex> they paraded.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An object of superstitious homage and fear.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Incomprehensible or senseless language, usually
intended to avoid answering plainly, confuse a listener, or obscure an
issue.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Language so arcane or obscure as to be
unintelligible to the listener.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mum-chance</ent><br/
<hw>Mum"-chance`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
game of hazard played with cards in silence.</def> <mark>[Obs. or Prov.
Eng.]</mark> <rj><au>Decker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A silent, stupid person.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mum-chance</ent><br/
<hw>Mum"-chance`</hw>, <pos>a.</pos> <def>Silent and idle.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Boys can't sit <qex>mum-chance</qex> always.</q> <rj><qau>J. H.
Ewing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mu meson</ent><br/
<ent>mu-meson</ent><br/
<mhw><hw>mu-meson</hw>, <hw>mu meson</hw></mhw> <pos>n.</pos>
<fld>(Physics)</fld> <def>an elementary particle with a negative charge
and a half-life of 2 microseconds; the muon. It is a <isa>lepton</isa>,
not a true meson, and decays to an electron and neutrino and
antineutrino.</def><br/
<syn><b>Syn. --</b> muon, negative muon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mumm</ent><br/
<hw>Mumm</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Mummed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mumming</conjf>.]</vmorph> <ety>[D. <ets>mimmen</ets> to mask,
<ets>mom</ets> a mask; akin to G. <ets>mumme</ets> disguise; prob. of
imitative origin, and akin to E. <ets>mum</ets>, <ets>mumble</ets>, in
allusion to the indistinctness of speech occasioned by talking from
behind a mask. Cf. <er>Mumble</er>, <er>Mummery</er>.]</ety> <def>To
sport or make diversion in a mask or disguise; to mask.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>mumming</qex> and with masking all around.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummer</ent><br/
<hw>Mumm"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>mommeur</ets>. See <er>Mumm</er>, and cf. <er>Momier</er>.]</ety>
<def>One who mumms, or makes diversion in disguise; a masker; a
buffon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jugglers and dancers, antics, <qex>mummers</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummery</ent><br/
<hw>Mum"mer*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mummeries</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>momerie</ets>, of
Dutch or German origin. See <er>Mumm</er>.]</ety> <sn>1.</sn>
<def>Masking; frolic in disguise; buffoonery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mummery</qex> of foreign strollers.</q>
<rj><qau>Fenton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Farcical show; hypocritical disguise and parade or
ceremonies.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummichog</ent><br/
<hw>Mum"mi*chog</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Amer. Indian
name.]</ety> <fld>(Zool.)</fld> <def>Any one of several species of small
American cyprinodont fishes of the genus <gen>Fundulus</gen>, and of
allied genera; the killifishes; -- called also
<altname>minnow</altname>.</def> <altsp>[Written also
<asp>mummychog</asp>, <asp>mummachog</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummification</ent><br/
<hw>Mum`mi*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mummify</er>.]</ety> <def>The act of making a mummy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummified</ent><br/
<hw>Mum"mi*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Converted into a
mummy or a mummylike substance; having the appearance of a mummy;
withered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummiform</ent><br/
<hw>Mum"mi*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mummy</ets>
+ <ets>-form</ets>.]</ety> <def>Having some resemblance to a mummy; --
in Zoology, said of the pupae of certain insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummify</ent><br/
<hw>Mum"mi*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mummified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mummifying</conjf> <pr>(?)</pr>.]</vmorph>
<ety>[<ets>Mummy</ets> + <ets>-fy</ets>: cf. F.
<ets>momifier</ets>.]</ety> <def>To embalm and dry as a mummy; to make
into, or like, a mummy.</def> <rj><au>Hall (1646).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mummify</ent><br/
<hw>mum"mi*fy</hw> <pos>v. i.</pos> <def>To turn into a mummy-like
corpse; to dry up with unusually little decomposition; -- said of dead
animals; <as>as, A <ex>mummified</ex> body was found in the
attic</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mummy</ent><br/
<hw>Mum"my</hw> <pr>(m<ucr/m"m<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mummies</plw> <pr>(m<ucr/m"m<icr/z)</pr>.</plu>
<ety>[F. <ets>momie</ets>; cf. Sp. & Pg. <ets>momia</ets>, It.
<ets>mummia</ets>; all fr. Per. <ets>m<umac/miy<amac/</ets>, fr.
<ets>m<umac/m</ets> wax.]</ety> <sn>1.</sn> <def>A dead body embalmed
and dried after the manner of the ancient Egyptians; also, a body
preserved, by any means, in a dry state, from the process of
putrefaction.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dried flesh of a mummy.</def> <mark>[Obs.]</mark>
<rj><au>Sir. J. Hill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A gummy liquor that exudes from embalmed flesh when
heated; -- formerly supposed to have magical and medicinal
properties.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au> <au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A brown color obtained from bitumen. See <cref>Mummy
brown</cref> (below).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Gardening)</fld> <def>A sort of wax used in
grafting, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>One whose affections and energies are
withered.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mummy brown</b></col>, <cd>a brown color, nearly
intermediate in tint between burnt umber and raw umber. A pigment of
this color is prepared from bitumen, etc., obtained from Egyptian
tombs.</cd> -- <col><b>Mummy wheat</b></col> <fld>(Bot.)</fld>,
<cd>wheat found in the ancient mummy cases of Egypt. No botanist now
believes that genuine mummy wheat has been made to germinate in modern
times.</cd> -- <col><b>To beat to a mummy</b></col>, <cd>to beat to a
senseless mass; to beat soundly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummy</ent><br/
<hw>Mum"my</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mummied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mummying</conjf>.]</vmorph> <def>To embalm; to mummify.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mummychog</ent><br/
<hw>Mum"my*chog</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Mummichog</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mump</ent><br/
<hw>Mump</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Akin to
<ets>mumble</ets>; cf. D. <ets>mompen</ets> to cheat; perh. orig., to
whine like a beggar, D. <ets>mompelen</ets> to mumble. See
<er>Mumble</er>, <er>Mum</er>, and cf. <er>Mumps</er>.]</ety>
<sn>1.</sn> <def>To move the lips with the mouth closed; to mumble, as
in sulkiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>mumps</qex>, and lovers, and hangs the lip.</q>
<rj><qau>Taylor, 1630.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To talk imperfectly, brokenly, or feebly; to chatter
unintelligibly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cheat; to deceive; to play the beggar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And then when <qex>mumping</qex> with a sore leg, . . . canting
and whining.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be sullen or sulky.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mump</ent><br/
<hw>Mump</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mumped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mumping</conjf>.]</vmorph> <sn>1.</sn> <def>To utter imperfectly,
brokenly, or feebly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Old men who <qex>mump</qex> their passion.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To work over with the mouth; to mumble; <as>as, to
<ex>mump</ex> food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of (something) by cheating; to impose
upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumper</ent><br/
<hw>Mump"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A beggar; a begging
impostor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Deceived by the tales of a Lincoln's Inn <qex>mumper</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumpish</ent><br/
<hw>Mump"ish</hw>, <pos>a.</pos> <def>Sullen, sulky.</def> --
<wordforms><wf>Mump"ish*ly</wf>, <pos>adv.</pos> --
<wf>Mump"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mumps</ent><br/
<hw>Mumps</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. E.
<ets>mump</ets> to be sulky. Cf. <er>Mump</er>, <er>Mumble</er>, and
<er>Mum</er>.]</ety> <sn>1.</sn> <pluf>pl.</pluf> <def>Sullenness;
silent displeasure; the sulks.</def> <rj><au>Skinner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Prob. so called from the patient's
appearance.]</ety> <fld>(Med.)</fld> <def>A specific infectious febrile
disorder characterized by a nonsuppurative inflammation of the parotid
glands, and sometimes causing inflammation of the testes or ovaries;
also called <altname>epidemic parotitis</altname> or <altname>infectious
parotitis</altname>. It is caused by infection with a
<causes>paramyxovirus</causes>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mun</ent><br/
<hw>Mun</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mouth</er>.]</ety> <def>The mouth.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One a penny, two a penny, hot cross buns,<br/
Butter them and sugar them and put them in your <qex>muns</qex>.</q>
<rj><qau>Old Rhyme.</qau> <qau>Halliwell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munch</ent><br/
<hw>Munch</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Munched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Munching</conjf>.]</vmorph> <ety>[Prob. akin to
<ets>mumble</ets>: cf. also F. <ets>manger</ets> to eat (cf.
<er>Mange</er>), and <ets>m<acir/cher</ets> to cher (cf.
<er>Masticate</er>). See <er>Mumble</er>.]</ety> <def>To chew with a
grinding, crunching sound, as a beast chews provender; to chew
deliberately or in large mouthfuls.</def> <altsp>[Formerly written also
<asp>maunch</asp> and <asp>mounch</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>I could <qex>munch</qex> your good dry oats.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munchausenism</ent><br/
<hw>Mun*chau"sen*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called in
allusion to <person>Baron <ets>Munchausen's</ets></person> extravagant
tales of travel.]</ety> <def>An extravagant fiction embodying an account
of some marvelous exploit or adventure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muncher</ent><br/
<hw>Munch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
munches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mund</ent><br/
<hw>Mund</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mun</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundane</ent><br/
<hw>Mun"dane</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mundanus</ets>, fr. <ets>mundus</ets> the world, an implement,
toilet adornments, or dress; cf. <ets>mundus</ets>, a., clean, neat,
Skr. <ets>ma<nsdot/<dsdot/</ets> to adorn, dress,
<ets>ma<nsdot/<dsdot/a</ets> adornment. Cf. <er>Monde</er>,
<er>Mound</er> in heraldry.]</ety> <sn>1.</sn> <def>Of or pertaining to
the world; worldly, as contrasted with <contr>heavenly</contr>; earthly;
terrestrial; <as>as, the <ex>mundane</ex> sphere; <ex>mundane</ex>
concerns</as>.</def> -- <wordforms><wf>Mun"dane*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The defilement of <qex>mundane</qex> passions.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Commonplace; ordinary; banal.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mundanity</ent><br/
<hw>Mun*dan"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Worldliness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundation</ent><br/
<hw>Mun*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mundatio</ets>, fr. <ets>mundare</ets> to make clean.]</ety>
<def>The act of cleansing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundatory</ent><br/
<hw>Mun"da*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mundatorius</ets>.]</ety> <def>Cleansing; having power to
cleanse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundic</ent><br/
<hw>Mun"dic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Iron pyrites, or
arsenical pyrites; -- so called by the Cornish miners.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundificant</ent><br/
<hw>Mun*dif"i*cant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mundificans</ets>, p. pr. of <ets>mundificare</ets> to make clean,
fr. <ets>mundus</ets> clean + <ets>-ficare</ets> (in comp.) to make. See
<er>-fy</er>.]</ety> <def>Serving to cleanse and heal.</def> --
<def2><pos>n.</pos> <def>A mundificant ointment or
plaster.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundification</ent><br/
<hw>Mun`di*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
operation of cleansing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundificative</ent><br/
<hw>Mun*dif"i*ca*tive</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Cleansing.</def> -- <def2><pos>n.</pos> <def>A detergent medicine
or preparation.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundify</ent><br/
<hw>Mun"di*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>mondifier</ets>, L. <ets>mundificare</ets>. See
<er>Mundificant</er>.]</ety> <def>To cleanse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundil</ent><br/
<hw>Mun"dil</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A turban ornamented
with an imitation of gold or silver embroidery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundivagant</ent><br/
<hw>Mun*div"a*gant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mundus</ets> the world + <ets>vagans</ets> wandering, p. pr. of
<ets>vagari</ets>. See <er>Vagary</er>.]</ety> <def>Wandering over the
world.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mundungus</ent><br/
<hw>Mun*dun"gus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>mondongo</ets> paunch, tripe, black pudding.]</ety> <def>A stinking
tobacco.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munerary</ent><br/
<hw>Mu"ner*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>munerarius</ets>, from <ets>munus</ets> a gift.]</ety> <def>Having
the nature of a gift.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munerate</ent><br/
<hw>Mu"ner*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>muneratus</ets>, p. p. of <ets>munerare</ets> to give, bestow, fr.
<ets>munus</ets> a gift.]</ety> <def>To remunerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muneration</ent><br/
<hw>Mu`ner*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>muneratio</ets>.]</ety> <def>Remuneration.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mung</ent><br/
<hw>Mung</hw> <pr>(m<ucr/ng)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>m<umac/ng</ets>.]</ety> <fld>(Bot.)</fld> <def>Green gram, a kind
of legume (pulse) (<spn>Vigna radiata</spn> syn. <spn>Phaseolus
aureus</spn>, syn. <spn>Phaseolus Mungo</spn>), grown for food in
British India; called also <altname>gram</altname>, <altname>mung
bean</altname>, <altname>Chinese mung bean</altname>, and
<altname>green-seeded mung bean</altname>. It is an erect, bushy annual
producing edible green or yellow seeds, and edible pods and young
sprouts.</def> <rj><au>Balfour (Cyc. of India).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mung bean</ent><br/
<hw>Mung" bean`</hw> <pr>(m<ucr/ng" b<emac/n`)</pr>, <pos>n.</pos>
<def>The <er>mung</er> (<spn>Vigna radiata</spn>).</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The bean produced by the <er>mung</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Munga</ent><br/
<hw>Mun"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<cref>Bonnet monkey</cref>, under <er>Bonnet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mungcorn</ent><br/
<hw>Mung"corn`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Mangcorn</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mungo</ent><br/
<hw>Mun"go</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A material of short
fiber and inferior quality obtained by deviling woolen rags or the
remnants of woolen goods, specif. those of felted, milled, or hard-spun
woolen cloth, as distinguished from <contr>shoddy</contr>, or the
deviled product of loose-textured woolen goods or worsted, -- a
distinction often disregarded.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ <xex>Mungo</xex> properly signifies the disintegrated
rags of woolen cloth, as distinguished from those of worsted, which form
<contr>shoddy</contr>. The distinction is very commonly
disregarded.</note> <rj><au>Beck (Draper's Dict.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mungoos</ent><br/
<ent>Mungoose</ent><br/
<mhw>{ <hw>Mun"goose</hw>, <hw>Mun"goos</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>See <er>Mongoose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mungrel</ent><br/
<hw>Mun"grel</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>See
<er>Mongrel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Municipal</ent><br/
<hw>Mu*nic"i*pal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>municipalis</ets>, fr. <ets>municipium</ets> a town, particularly
in Italy, which possessed the right of Roman citizenship, but was
governed by its own laws, a free town, fr. <ets>municeps</ets> an
inhabitant of a free town, a free citizen; <ets>munia</ets> official
duties, functions + <ets>capere</ets> to take: cf. F.
<ets>municipal</ets>. Cf. <er>Immunity</er>, and
<er>Capacoius</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to a city
or a corporation having the right of administering local government;
<as>as, <ex>municipal</ex> rights; <ex>municipal</ex>
officers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to a state, kingdom, or
nation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Municipal</qex> law is properly defined to be a rule of civil
conduct prescribed by the supreme power in a state.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Municipalism</ent><br/
<hw>Mu*nic"i*pal*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Municipal
condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Municipality</ent><br/
<hw>Mu*nic`i*pal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Municipalities</plw> <pr>(#)</pr>.</plu>
<ety>[Cf. F. <ets>municipalit<eacute/</ets>.]</ety> <def>A municipal
district; a borough, city, or incorporated town or village.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Municipalize</ent><br/
<hw>Mu*nic"i*pal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<ety>[<ets>Municipal</ets> + <ets>-ize</ets>.]</ety> <def>To bring under
municipal oversight or control; <as>as, a <ex>municipalized</ex>
industry</as>.</def></p>

<p><q>London people are now determined to centralize and to
<qex>municipalize</qex> such services.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Municipally</ent><br/
<hw>Mu*nic"i*pal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
municipal relation or condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munific</ent><br/
<hw>Mu*nif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Munificent</er>.]</ety> <def>Munificent; liberal.</def> <mark>[Obs.
or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munificate</ent><br/
<hw>Mu*nif"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>munificatus</ets>, p. p. of <ets>munificare</ets> to present with a
thing, fr. <ets>munificus</ets>. See <er>Munificent</er>.]</ety> <def>To
enrich.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munificence</ent><br/
<hw>Mu*nif"i*cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>munire</ets> to fortify.]</ety> <def>Means of defense;
fortification.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munificence</ent><br/
<hw>Mu*nif"i*cence</hw>, <pos>n.</pos> <ety>[L. <ets>munificentia</ets>:
cf. F. <ets>munificence</ets>.]</ety> <def>The quality or state of being
munificent; a giving or bestowing with extraordinary liberality;
generous bounty; lavish generosity.</def><br/
<syn><b>Syn.</b> -- Benevolence; beneficence; liberality; generosity;
bounty; bounteousness. See <er>Benevolence</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>The virtues of liberality and <qex>munificence</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munificent</ent><br/
<hw>Mu*nif"i*cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>munificus</ets>; <ets>munus</ets> service, gift +
<ets>-ficare</ets> (in comp.) to make. Cf. <er>Immunity</er>,
<er>-fy</er>.]</ety> <def>Very liberal in giving or bestowing; lavish;
<as>as, a <ex>munificent</ex> benefactor</as>.</def> --
<wordforms><wf>Mu*nif"i*cent*ly</wf>, <pos>adv.</pos></wordforms><br/
<syn><b>Syn.</b> -- Bounteous; bountiful; liberal; generous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munify</ent><br/
<hw>Mu"ni*fy</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[See
<er>Munificate</er>.]</ety> <def>To prepare for defense; to
fortify.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muniment</ent><br/
<hw>Mu"ni*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>munimentum</ets>, fr. <ets>munire</ets> to fortify. See
<er>Munition</er>.]</ety> <sn>1.</sn> <def>The act of supporting or
defending.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which supports or defends; stronghold; place or
means of defense; munition; assistance.</def> <ldquo/Other
<xex>muniments</xex> and petty helps.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A record; the evidences or writings
whereby a man is enabled to defend the title to his estate; title deeds
and papers.</def> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Muniment room</b></col> <it>or</it>
<col><b>Muniment house</b></col></mcol>, <cd>that room in a cathedral,
castle, or other public building, which is used for keeping the records,
charters, seals, deeds, and the like.</cd> <au>Gwilt.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munite</ent><br/
<hw>Mu*nite"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>munitus</ets>, p. p. of <ets>munire</ets> to wall, fortify.]</ety>
<def>To fortify; to strengthen.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munition</ent><br/
<hw>Mu*ni"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., munition of
war, L. <ets>munitio</ets> a fortifying, fortification, fr.
<ets>munire</ets> to fortify, defend with a wall; cf. <ets>moenia</ets>
walls, <ets>murus</ets> (for <ets>moirus</ets>) a wall, and Skr.
<ets>mi</ets> to fix, make firm. Cf. <er>Ammunition</er>.]</ety>
<sn>1.</sn> <def>Fortification; stronghold.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His place of defense shall be the <qex>munitions</qex> of
rocks.</q> <rj><qau>Is. xxxiii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Whatever materials are used in war for defense or
for annoying an enemy; ammunition; also, stores and provisions; military
stores of all kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bodies of men, <qex>munition</qex>, and money, may justly be
called the sinews of war.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munity</ent><br/
<hw>Mu"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Immunity</er>.]</ety> <def>Freedom; security; immunity.</def>
<mark>[Obs.]</mark> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>munja</ent><br/
<ent>munj</ent><br/
<mhw><hw>munj</hw>, <hw>munja</hw></mhw> <pos>n.</pos> <def>A tough
Asiatic grass (<spn>Saccharum bengalense</spn> syn. <spn>Saccharum
munja</spn>) whose culms are used for ropes and baskets.</def><br/
<syn><b>Syn. --</b> munj, <spn>Saccharum bengalense</spn>,
<spn>Saccharum munja</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Munjeet</ent><br/
<hw>Mun*jeet"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>maj<imac/<tsdot/h</ets> a drug used for dyeing red.]</ety> <def>See
<cref>Indian madder</cref>, under <er>Madder</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munjistin</ent><br/
<hw>Mun"jis*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>An orange-red coloring substance resembling alizarin, found in the
root of an East Indian species of madder (<spn>Rubia
munjista</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munnion</ent><br/
<hw>Mun"nion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mullion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Munting</ent><br/
<ent>Muntin</ent><br/
<mhw>{ <hw>Mun"tin</hw> <pr>(?)</pr>, <hw>Mun"ting</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[CF. <er>Montant</er>.]</ety>
<fld>(Arch.)</fld> <def>Same as <er>Mullion</er>; -- especially used in
joiner's work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muntjac</ent><br/
<hw>Munt"jac</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of several species of small Asiatic deer of the genus
<gen>Cervulus</gen>, esp. <spn>Cervulus muntjac</spn>, which occurs both
in India and on the East Indian Islands.</def> <altsp>[Written also
<asp>muntjak</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muntz metal</ent><br/
<hw>Muntz" met`al</hw> <pr>(?)</pr>. <def>See under
<er>Metal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muraena</ent><br/
\'d8<hw>Mu*rae"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <fld>(Zool.)</fld> <def>A genus of large eels of the family
<fam>Muraenidae</fam>. They differ from the common eel in lacking
pectoral fins and in having the dorsal and anal fins continuous. The
murry (<spn>Muraena Helenae</spn>) of Southern Europe was the muraena of
the Romans. It is highly valued as a food fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murenoid</ent><br/
<ent>Muraenoid</ent><br/
<mhw>{ <hw>Mu*rae"noid</hw>, <hw>Mu*re"noid</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <ety>[NL. <ets>Muraena</ets>, the generic name +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or pertaining to
the genus <gen>Muraena</gen>, or family <fam>Muraenidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murage</ent><br/
<hw>Mu"rage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>murer</ets> to wall, fr. <ets>mur</ets> wall, L. <ets>murus</ets>.
See <er>Mure</er> a wall.]</ety> <def>A tax or toll paid for building or
repairing the walls of a fortified town.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mural</ent><br/
<hw>Mu"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>muralis</ets>, fr. <ets>murus</ets> wall. See <er>Mure</er> a
wall.]</ety> <sn>1.</sn> <def>Of or pertaining to a wall; being on, or
in, a wall; growing on, or against, a wall; <as>as, a <ex>mural</ex>
quadrant</as>.</def> <ldquo/<xex>Mural</xex> breach.<rdquo/
<au>Milton.</au> <ldquo/<xex>Mural</xex> fruit.<rdquo/
<au>Evelyn.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling a wall; perpendicular or steep; <as>as, a
<ex>mural</ex> precipice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mural circle</b></col> <fld>(Astron.)</fld>, <cd>a
graduated circle, in the plane of the meridian, attached permanently to
a perpendicular wall; -- used for measuring arcs of the meridian. See
<er>Circle</er>, <pos>n.</pos>, 3.</cd> -- <col><b>Mural crown</b></col>
<fld>(Rom. Antiq.)</fld>, <cd>a golden crown, or circle of gold indented
so as to resemble a battlement, bestowed on him who first mounted the
wall of a besieged place, and there lodged a standard.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murder</ent><br/
<hw>Mur"der</hw> <pr>(m<ucir/r"d<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>morder</ets>, <ets>morther</ets>, AS. <ets>mor<edh/or</ets>, fr.
<ets>mor<edh/</ets> murder; akin to D. <ets>moord</ets>, OS.
<ets>mor<edh/</ets>, G., Dan., & Sw. <ets>mord</ets>, Icel.
<ets>mor<edh/</ets>, Goth. <ets>ma<uacute/r<thorn/r</ets>, OSlav.
<ets>mr<emac/ti</ets> to die, Lith. <ets>mirti</ets>, W. <ets>marw</ets>
dead, L. <ets>mors</ets>, <ets>mortis</ets>, death, <ets>mori</ets>,
<ets>moriri</ets>, to die, Gr. <grk>broto`s</grk> (for
<grk>mroto`s</grk>) mortal, <grk>'a`mbrotos</grk> immortal, Skr.
<ets>m<rsdot/</ets> to die, <ets>m<rsdot/ta</ets> death. <root/105. Cf.
<er>Amaranth</er>, <er>Ambrosia</er>, <er>Mortal</er>.]</ety> <def>The
offense of killing a human being with malice prepense or aforethought,
express or implied; intentional and unlawful homicide.</def>
<ldquo/<xex>Mordre</xex> will out.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The killing of their children had, in the account of God, the
guilt of <qex>murder</qex>, as the offering them to idols had the guilt
of idolatry.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Slaughter grows <qex>murder</qex> when it goes too far.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Murder in the second degree</xex>, in most
jurisdictions, is a malicious homicide committed without a specific
intention to take life.</note> <rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murder</ent><br/
<hw>Mur"der</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Murdered</conjf> <pr>(m<ucir/r"d<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Murdering</conjf>.]</vmorph> <ety>[OE.
<ets>mortheren</ets>, <ets>murtheren</ets>, AS. <ets>myr<edh/rian</ets>;
akin to OHG. <ets>murdiren</ets>, Goth.
<ets>ma<uacute/r<thorn/rjan</ets>. See <er>Murder</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To kill with premediated malice;
to kill (a human being) willfully, deliberately, and unlawfully. See
<er>Murder</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To destroy; to put an end to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Canst thou] <qex>murder</qex> thy breath in middle of a word?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To mutilate, spoil, or deform, as if with malice or
cruelty; to mangle; <as>as, to <ex>murder</ex> the king's
English</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To kill; assassinate; slay. See
<er>Kill</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>murdered</ent><br/
<hw>murdered</hw> <pos>adj.</pos> <def>killed unlawfully; <as>as, the
<ex>murdered</ex> woman</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 955 --></p>

<p><ent>Murderer</ent><br/
<hw>Mur"der*er</hw> <pr>(m<ucir/r"d<etil/r*<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One guilty of murder; a person who, in possession of
his reason, unlawfully kills a human being with premeditated
malice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small cannon, formerly used for clearing a ship's
decks of boarders; -- called also <altname>murdering
piece</altname>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murderess</ent><br/
<hw>Mur"der*ess</hw>, <pos>n.</pos> <def>A woman who commits
murder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murderment</ent><br/
<hw>Mur"der*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Murder.</def>
<mark>[Obs.]</mark> <rj><au>Farfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murderous</ent><br/
<hw>Mur"der*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to murder; characterized by, or causing, murder or bloodshed; having the
purpose or quality of murder; bloody; sanguinary; <as>as, the
<ex>murderous</ex> king; <ex>murderous</ex> rapine; <ex>murderous</ex>
intent; a <ex>murderous</ex> assault.</as></def>
<ldquo/<xex>Murderous</xex> coward.<rdquo/ <au>Shak.</au> --
<wordforms><wf>Mur"der*ous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Bloody; sanguinary; bloodguilty; bloodthirsty;
fell; savage; cruel.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murdress</ent><br/
<hw>Mur"dress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A battlement in
ancient fortifications with interstices for firing through.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mure</ent><br/
<hw>Mure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>murus</ets>; or
F. <ets>mur</ets>, fr. L. <ets>murus</ets>. Cf.
<er>Munition</er>.]</ety> <def>A wall.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mure</ent><br/
<hw>Mure</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mured</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F. <ets>murer</ets>,
L. <ets>murare</ets>. See <er>Mure</er>, <pos>n.</pos>]</ety> <def>To
inclose in walls; to wall; to immure; to shut up.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The five kings are <qex>mured</qex> in a cave.</q> <rj><qau>John.
x. (Heading).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murenger</ent><br/
<hw>Mu"ren*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who had charge
of the wall of a town, or its repairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murex</ent><br/
\'d8<hw>Mu"rex</hw> <pr>(?)</pr>, <pos>prop. n.</pos>; <plu><it>pl.</it>
<plw>Murices</plw> <pr>(#)</pr>.</plu> <ety>[L., the purple fish.]</ety>
<fld>(Zool.)</fld> <def>A genus of marine gastropods, having rough, and
frequently spinose, shells, which are often highly colored inside; the
rock shells. They abound in tropical seas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murexan</ent><br/
<hw>Mu*rex"an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Murexide</er>.]</ety> <fld>(Chem.)</fld> <def>A complex nitrogenous
substance obtained from murexide, alloxantin, and other ureids, as a
white, or yellowish, crystalline which turns red on exposure to the air;
-- called also <altname>uramil</altname>,
<altname>dialuramide</altname>, and formerly <altname>purpuric
acid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murexide</ent><br/
<hw>Mu*rex"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>murex</ets> the purple fish, purple.]</ety> <fld>(Chem.)</fld>
<def>A crystalline nitrogenous substance (<chform>C8H8N6O6</chform>,
<chname>5-5'-nitrilodibarbituric acid monoammonium salt</chname>) having
a splendid dichroism, being green by reflected light and garnet-red by
transmitted light. It was formerly used in dyeing calico, and was
obtained in a large quantities from guano. It is now synthesized from
alloxan. Formerly called also <altname>ammonium
purpurate</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Murexoin</ent><br/
<hw>Mu*rex"o*<ium/n</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A complex nitrogenous compound obtained as a scarlet crystalline
substance, and regarded as related to murexide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muriate</ent><br/
<hw>Mu"ri*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Muriatic</er>.]</ety> <fld>(Chem.)</fld> <def>A salt of muriatic
hydrochloric acid; a chloride; <as>as, <ex>muriate</ex> of
ammonia</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term, as also the word <xex>muriatic</xex>, was
formerly applied to the chlorides before their true composition was
understood, and while they were erroneously supposed to be compounds of
an acid with an oxide. <xex>Muriate</xex> and <xex>muriatic</xex> are
still occasionally used as commercial terms, but are obsolete in
scientific language.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muriated</ent><br/
<hw>Mu"ri*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Put in
brine.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Combined or impregnated with
muriatic or hydrochloric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Photog.)</fld> <def>Prepared with chloride of
silver through the agency of common salt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muriatic</ent><br/
<hw>Mu`ri*at"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>muriaticus</ets> pickled, from <ets>muria</ets> brine: cf. F.
<ets>muriatique</ets>.]</ety> <fld>(Chem.)</fld> <def>Of, pertaining to,
or obtained from, sea salt, or from chlorine, one of the constituents of
sea salt; hydrochloric.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Muriatic acid</b></col>, <cd>hydrochloric acid,
<chform>HCl</chform>; -- formerly called also <altname>marine
acid</altname>, and <altname>spirit of salt</altname>. See
<er>hydrochloric</er>, and the Note under
<er>Muriate</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muriatiferous</ent><br/
<hw>Mu`ri*a*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Muriat</ets>ic + <ets>-ferous</ets>.]</ety> <fld>(Old
Chem.)</fld> <def>Producing muriatic substances or salt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muricated</ent><br/
<ent>Muricate</ent><br/
<mhw>{ <hw>Mu"ri*cate</hw> <pr>(?)</pr>, <hw>Mu"ri*ca`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>muricatus</ets>, fr.
<ets>murex</ets> a pointed rock or stone.]</ety> <def>Formed with sharp
points; full of sharp points or of pickles; covered, or roughened, as a
surface, with sharp points or excrescences.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muricoid</ent><br/
<hw>Mu"ri*coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mur</ets>ex +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like, or pertaining to,
the genus Murex, or family <fam>Muricidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muriculate</ent><br/
<hw>Mu*ric"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Minutely
muricate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muride</ent><br/
<hw>Mu"ride</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>muria</ets>
brine.]</ety> <fld>(Old Chem.)</fld> <def>Bromine; -- formerly so called
from its being obtained from sea water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muriform</ent><br/
<hw>Mu"ri*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>murus</ets> a wall + <ets>-form</ets>.]</ety> <fld>(Bot.)</fld>
<def>Resembling courses of bricks or stones in squareness and regular
arrangement; <as>as, a <ex>muriform</ex> variety of cellular
tissue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murine</ent><br/
<hw>Mu"rine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>murinus</ets>, from <ets>mus</ets>, <ets>muris</ets>, mouse: cf. F.
<ets>murin</ets>.]</ety> <fld>(Zool.)</fld> <def>Pertaining to a family
of rodents (<fam>Muridae</fam>), of which the mouse is the
type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murine</ent><br/
<hw>Mu"rine</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of a tribe
of rodents, of which the mouse is the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muringer</ent><br/
<hw>Mu"rin*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Murenger</er>.</def> <rj><au>Jacob.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murk</ent><br/
<hw>Murk</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Murky</er>.]</ety> <def>Dark; murky.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He can not see through the mantle <qex>murk</qex>.</q> <rj><qau>J.
R. Drake.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murk</ent><br/
<hw>Murk</hw>, <pos>n.</pos> <def>Darkness; mirk.</def>
<mark>[Archaic]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murk</ent><br/
<hw>Murk</hw>, <pos>n.</pos> <def>The refuse of fruit, after the juice
has been expressed; marc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murkily</ent><br/
<hw>Murk"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Darkly;
gloomily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murkiness</ent><br/
<hw>Murk"i*ness</hw>, <pos>n.</pos> <def>The state of being
murky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murky</ent><br/
<hw>Murk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Murkier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Murkiest</adjf>.]</amorph> <ety>[OE. <ets>mirke</ets>,
<ets>merke</ets>, AS. <ets>myrce</ets>, <ets>mirce</ets>; akin to Icel.
<ets>myrkr</ets>, Dan. & Sw. <ets>m<oum/rk</ets>.]</ety> <sn>1.</sn>
<def>Dark; gloomy.</def> <ldquo/The <xex>murkiest</xex> den.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>murky</qex> deep lowering o'er our heads.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Obscured by haze or mist; clouded; turbid; <as>as,
poor visibility in the <ex>murky</ex> water</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Murlins</ent><br/
<hw>Mur"lins</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
seaweed. See <er>Baddrelocks</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmur</ent><br/
<hw>Mur"mur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>murmure</ets>: cf. L. <ets>murmur</ets>. CF. <er>Murmur</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>A low, confused, and indistinct
sound, like that of running water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A complaint half suppressed, or uttered in a low,
muttering voice.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some discontents there are, some idle <qex>murmurs</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmur</ent><br/
<hw>Mur"mur</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Murmured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Murmuring</conjf>.]</vmorph> <ety>[F. <ets>murmurer</ets>, L.
<ets>murmurare</ets>, <ets>murmurari</ets>, fr. <ets>murmur</ets>
murmur; cf. Gr. <?/ to roar and boil, said of water, Skr.
<ets>marmara</ets> a rustling sound; prob. of imitative origin.]</ety>
<sn>1.</sn> <def>To make a low continued noise, like the hum of bees, a
stream of water, distant waves, or the wind in a forest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>murmured</qex> as doth a swarm of bees.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter complaints in a low, half-articulated
voice; to feel or express dissatisfaction or discontent; to grumble; --
often with <xex>at</xex> or <xex>against</xex>.</def> <ldquo/His
disciples <xex>murmured</xex> at it.<rdquo/ <rj><au>John vi.
61.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And all the children of Israel <qex>murmured</qex> against Moses
and against Aaron.</q> <rj><qau>Num. xiv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither <qex>murmur</qex> ye, as some of them also
<qex>murmured</qex>.</q> <rj><qau>1 Cor. x. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmur</ent><br/
<hw>Mur"mur</hw>, <pos>v. t.</pos> <def>To utter or give forth in low or
indistinct words or sounds; <as>as, to <ex>murmur</ex> tales</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The people <qex>murmured</qex> such things concerning him.</q>
<rj><qau>John vii. 32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmuration</ent><br/
<hw>Mur`mur*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>murmuratio</ets>.]</ety> <def>The act of murmuring; a murmur.</def>
<mark>[Obs.]</mark> <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmurer</ent><br/
<hw>Mur"mur*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
murmurs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmuring</ent><br/
<hw>Mur"mur*ing</hw>, <pos>a. & n.</pos> <def>Uttering murmurs; making
low sounds; complaining.</def> -- <wordforms><wf>Mur"mur*ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murmurous</ent><br/
<hw>Mur"mur*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>murmuriosus</ets>, OF. <ets>murmuros</ets>.]</ety> <def>Attended
with murmurs; exciting murmurs or complaint; murmuring.</def>
<mark>[Archaic or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The lime, a summer home of <qex>murmurous</qex> wings.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murnival</ent><br/
<hw>Mur"ni*val</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. fr. F.
<ets>mornifle</ets> a game at cards.]</ety> <def>In the game of gleek,
four cards of the same value, as four aces or four kings; hence, four of
anything.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>mournival</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murphy</ent><br/
<hw>Mur"phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A potato.</def>
<mark>[Humorous]</mark> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murr</ent><br/
<hw>Murr</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. abbrev. from
<ets>murrain</ets>.]</ety> <def>A catarrh.</def> <mark>[Obs.]</mark>
<rj><au>Gascoigne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrain</ent><br/
<hw>Mur"rain</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>moreine</ets>, OF. <ets>morine</ets>, fr. OF. <ets>morir</ets>,
<ets>murir</ets>, 8die, L. <ets>mori</ets>, <ets>moriri</ets>.]</ety>
<fld>(Far.)</fld> <def>An infectious and fatal disease among
cattle.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A murrain on you</b></col>, <cd>may you be afflicted with
a pestilent disease.</cd> <au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrain</ent><br/
<hw>Mur"rain</hw>, <pos>a.</pos> <def>Having, or afflicted with,
murrain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrayin</ent><br/
<hw>Mur"ray*in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A glucoside found in the flowers of a plant (<spn>Murraya
exotica</spn>) of South Asia, and extracted as a white amorphous
slightly bitter substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murre</ent><br/
<hw>Murre</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any
one of several species of sea birds of the genus <gen>Uria</gen>, or
<gen>Catarractes</gen>; a guillemot.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The murres are allied to the auks, and are abundant on
the northern coasts of Europe and America. They often breed in large
communities on the projecting ledges of precipituous cliffs, laying one
or two large eggs on the bare rocks.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrelet</ent><br/
<hw>Murre"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Murre</ets> +
<ets>-let</ets>.]</ety> <fld>(Zool.)</fld> <def>One of several species
of sea birds of the genera <gen>Synthliboramphus</gen> and
<gen>Brachyramphus</gen>, inhabiting the North Pacific. They are closely
related to the murres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrey</ent><br/
<hw>Mur"rey</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mor<eacute/e</ets> a dark red color, <ets>mor</ets> blackish brown,
fr. L. <ets>morum</ets> mulberry, blackberry, or fr. <ets>Maurus</ets> a
Moor. Cf. <er>Mulberry</er>, <er>Moor</er>, <er>Morelle</er>.]</ety>
<def>A dark red color.</def> -- <def2><pos>a.</pos> <def>Of a dark red
color.</def></def2> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrhine</ent><br/
<hw>Mur"rhine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>murrhinus</ets>, fr. <ets>murrha</ets>: cf. F.
<ets>murrhin</ets>.]</ety> <def>Made of the stone or material called by
the Romans <xex>murrha</xex>; -- applied to certain costly vases of
great beauty and delicacy used by the luxurious in Rome as wine cups;
<as>as, <ex>murrhine</ex> vases, cups, vessels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Murrhine glass</b></col>, <cd>glassware made in imitation
of murrhine vases and cups.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrion</ent><br/
<hw>Mur"ri*on</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Murrain</er>.]</ety> <def>Infected with or killed by murrain.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murrion</ent><br/
<hw>Mur"ri*on</hw>, <pos>n.</pos> <def>A morion. See
<er>Morion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murry</ent><br/
<hw>Mur"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Muraena</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murth</ent><br/
<hw>Murth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>Plenty; abundance.</def> <mark>[Obs. or Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murther</ent><br/
<hw>Mur"ther</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>Murder,
<pos>n.</pos> & <pos>v.</pos></def> <mark>[Obs. or Prov.]</mark>
<ldquo/The treason of the <xex>murthering</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murtherer</ent><br/
<hw>Mur"ther*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A murderer.</def>
<mark>[Obs. or Prov.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Murza</ent><br/
<hw>Mur"za</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the hereditary
nobility among the Tatars, esp. one of the second class.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word must not be confounded with the Persian
<xex>Mirza</xex>, though perhaps of the same origin.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mus</ent><br/
\'d8<hw>Mus</hw> <pr>(?)</pr>, <pos>prop. n.</pos>; <plu><it>pl.</it>
<plw>Mures</plw> <pr>(#)</pr>.</plu> <ety>[L., a mouse.]</ety>
<fld>(Zool.)</fld> <def>A genus of small rodents, including the common
mouse and rat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musa</ent><br/
\'d8<hw>Mu"sa</hw> <pr>(?)</pr>, <pos>prop. n.</pos>; <plu><it>pl.</it>
<plw>Musae</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Ar. <ets>mauz</ets>,
<ets>mauza</ets>, banana.]</ety> <fld>(Bot.)</fld> <def>A genus of
perennial, herbaceous, endogenous plants of great size, including the
banana (<spn>Musa sapientum</spn>), the plantain (<spn>Musa
paradisiaca</spn> of Linnaeus, but probably not a distinct species), the
Abyssinian (<spn>Musa Ensete</spn>), the Philippine Island (<spn>Musa
textilis</spn>, which yields Manila hemp), and about eighteen other
species. See <xex>Illust.</xex> of <er>Banana</er> and
<er>Plantain</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musaceae</ent><br/
<hw>Musaceae</hw> <pos>prop. n.</pos> <def>A natural family of treelike
tropical Asian herbs including the banana tree.</def><br/
<syn><b>Syn. --</b> family <fam>Musaceae</fam>, banana family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Musaceous</ent><br/
<hw>Mu*sa"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining to,
or resembling, plants of the genus <gen>Musa</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musal</ent><br/
<hw>Mus"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to the
Muses, or to Poetry.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musales</ent><br/
<hw>Musales</hw> <pos>prop. n.</pos> <def>An order of tropical
plants.</def><br/
<syn><b>Syn. --</b> order <ord>Musales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Musang</ent><br/
<hw>Mu*sang"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
small animal of Java (<spn>Paradoxirus fasciatus</spn>), allied to the
civets. It swallows, but does not digest, large quantities of ripe
coffee berries, thus serving to disseminate the coffee plant; hence it
is called also <altname>coffee rat</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musar</ent><br/
<hw>Mu"sar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An itinerant player on
the musette, an instrument formerly common in Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musard</ent><br/
<hw>Mu"sard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>muser</ets> to loiter, trifle. See <er>Muse</er>, <pos>v.
i.</pos>]</ety> <def>A dreamer; an absent-minded person.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musca</ent><br/
\'d8<hw>Mus"ca</hw> <pr>(?)</pr>, <pos>prop. n.</pos>; <plu><it>pl.</it>
<plw>Muscae</plw> <pr>(#)</pr>.</plu> <ety>[L., a fly.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>A genus of dipterous insects,
including the common house fly, and numerous allied species.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly, a large part of the Diptera were included
under the genus <gen>Musca</gen>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>A small constellation situated
between the Southern Cross and the Pole.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Muscae volitantes</b></col> <pr>(<?/)</pr>. <ety>[L.,
flying flies.]</ety> <fld>(Med.)</fld> <cd>Specks or filaments
apparently seen moving or gliding about in the field of vision. Their
appearance is often a symptom of disease of the eye, or of disorder of
the nervous system.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>muscadelle</ent><br/
<ent>Muscadel</ent><br/
<mhw><hw>Mus"ca*del`</hw>, <hw>mus"ca*delle</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[It. <ets>moscadello</ets>, <ets>moscatello</ets>,
LL. <ets>muscatellum</ets> or <ets>muscadellum</ets> (sc.
<ets>vinum</ets>), fr. <ets>muscatellus</ets> nutmeglike, dim. of
<ets>muscatus</ets> smelling like musk, <ets>muscatum</ets> and
<ets>muscata</ets> (sc. <ets>nux</ets>) nutmeg: cf. F.
<ets>muscadelle</ets>, fr. Italian. See <er>Musk</er> and cf.
<er>Moschatel</er>, <er>Muscardin</er>, <er>Muscat</er>,
<er>Nutmeg</er>.]</ety> <def>See <er>Muscatel</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Quaffed off the <qex>muscadel</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscadet</ent><br/
<hw>Muscadet</hw> <pos>n.</pos> <sn>1.</sn> <def>A white grape grown
esp. in the Loire Valley in France.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A dry white wine from the Loire Valley in
France.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muscadine</ent><br/
<hw>Mus"ca*dine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Muscadel</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A name
given to several very different kinds of grapes, but in America used
chiefly for the scuppernong, or southern fox grape, which is said to be
the parent stock of the Catawba. See <er>Grapevine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A fragrant and delicious
pear.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>See <er>Muscardin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Northern muscadine</b></col> <fld>(Bot.)</fld>, <cd>a
derivative of the northern fox grape, and scarcely an improvement upon
it.</cd> -- <col><b>Royal muscadine</b></col> <fld>(Bot.)</fld>, <cd>a
European grape of great value. Its berries are large, round, and of a
pale amber color. Called also <altname>golden
chasselas</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscales</ent><br/
\'d8<hw>Mus*ca"les</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
L. <ets>muscus</ets> moss.]</ety> <fld>(Bot.)</fld> <def>An old name for
mosses in the widest sense, including the true mosses and also hepaticae
and sphagna.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscallonge</ent><br/
<hw>Mus"cal*longe</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Muskellunge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscardin</ent><br/
<hw>Mus"car*din</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>muscadin</ets> a musk-scented lozenge, fr. <ets>muscade</ets>
nutmeg, fr. L. <ets>muscus</ets> musk. See <er>Muscadel</er>.]</ety>
<fld>(Zool.)</fld> <def>The common European dormouse; -- so named from
its odor.</def> <altsp>[Written also <asp>muscadine</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscardine</ent><br/
<hw>Mus`car*dine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A disease which is very destructive to silkworms, and which
sometimes extends to other insects. It is attended by the development of
a fungus (provisionally called <spn>Botrytis bassiana</spn>). Also, the
fungus itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscariform</ent><br/
<hw>Mus*car"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>muscarium</ets> fly brush + <ets>-form</ets>.]</ety> <def>Having
the form of a brush.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscarin</ent><br/
<hw>Mus*ca"rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.
Chem.)</fld> <def>A solid crystalline substance,
<chform>C5H13NO2</chform>, found in the toadstool (<spn>Agaricus
muscarius</spn>), and in putrid fish. It is a typical ptomaine, and a
violent poison.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscat</ent><br/
<hw>Mus"cat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Muscadel</er>.]</ety> <fld>(Bot.)</fld> <def>A name given to several
varieties of Old World grapes, differing in color, size, etc., but all
having a somewhat musky flavor. The muscat of Alexandria is a large oval
grape of a pale amber color.</def> <altsp>[Written also
<asp>muskat</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscatel</ent><br/
<hw>Mus"ca*tel`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining to,
or designating, or derived from, a muscat grapes or similar grapes;
<as>as, <ex>muscatel</ex> grapes; <ex>muscatel</ex> wine,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscatel</ent><br/
<hw>Mus"ca*tel`</hw>, <pos>n.</pos> <sn>1.</sn> <def>A common name for
several varieties of rich sweet wine, made in Italy, Spain, and
France.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Finest raisins, dried on the vine;
<ldquo/sun raisins.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><altsp>[Variously written <asp>moscatel</asp>, <asp>muscadel</asp>,
etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muschelkalk</ent><br/
\'d8<hw>Musch"el*kalk`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., from
<ets>muschel</ets> shell + <ets>kalk</ets> limestone.]</ety>
<fld>(Geol.)</fld> <def>A kind of shell limestone, whose strata form the
middle one of the three divisions of the Triassic formation in Germany.
See <xex>Chart</xex>, under <er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musci</ent><br/
\'d8<hw>Mus"ci</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>muscus</ets> moss.]</ety> <fld>(Bot.)</fld> <def>An order or
subclass of cryptogamous plants; the mosses. See <er>Moss</er>, and
<er>Cryptogamia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscicapidae</ent><br/
<hw>Muscicapidae</hw> <pos>prop. n.</pos> <def>A natural family of Old
World (true) flycatchers.</def><br/
<syn><b>Syn. --</b> family <fam>Muscicapidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muscicapine</ent><br/
<hw>Mus*cic"a*pine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>musca</ets> a fly + <ets>capere</ets> to catch.]</ety>
<fld>(Zool.)</fld> <def>Of or pertaining to the <fam>Muscicapidae</fam>,
a family of birds that includes the true flycatchers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscid</ent><br/
<hw>Mus"cid</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Any fly of the genus
Musca, or family <fam>Muscidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscidae</ent><br/
<hw>Muscidae</hw> <pos>prop. n.</pos> <def>A natural family of
two-winged flies esp. the housefly.</def><br/
<syn><b>Syn. --</b> family <fam>Muscidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Musciform</ent><br/
<hw>Mus"ci*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Musca</ets>
+ <ets>-form</ets>.]</ety> <fld>(Zool.)</fld> <def>Having the form or
structure of flies of the genus <gen>Musca</gen>, or family
<fam>Muscidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musciform</ent><br/
<hw>Mus"ci*form</hw>, <pos>a.</pos> <ety>[<ets>Muscus</ets> +
<ets>-form</ets>.]</ety> <fld>(Bot.)</fld> <def>Having the appearance or
form of a moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscivora-forficata</ent><br/
<hw>Muscivora-forficata</hw> <pos>n.</pos> <def>A gray flycatcher of
Southwestern U. S. and Mexico and Central America having a long forked
tail and white breast and salmon and scarlet markings; the scissortailed
flycatcher.</def><br/
<syn><b>Syn. --</b> scissortail, scissortailed flycatcher.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muscle</ent><br/
<hw>Mus"cle</hw> <pr>(m<ucr/s"'l)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>musculus</ets> a muscle, a little mouse, dim. of <ets>mus</ets> a
mouse. See <er>Mouse</er>, and cf. sense 3 (below).]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <sd>(a)</sd> <def>An organ which, by its contraction,
produces motion.</def> See <xex>Illust.</xex> of Muscles of the Human
Body, in Appendix. <sd>(b)</sd> <def>The contractile tissue of which
muscles are largely made up.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Muscles are of two kinds, <xex>striated</xex> and
<xex>nonstriated</xex>. The striated muscles, which, in most of the
higher animals, constitute the principal part of the flesh, exclusive of
the fat, are mostly under the control of the will, or
<xex>voluntary</xex>, and are made up of great numbers of elongated
fibres bound together into bundles and inclosed in a sheath of
connective tissue, the <part>perimysium</part>. Each fiber is inclosed
in a delicate membrane (the <part>sarcolemma</part>), is made up of
alternate segments of lighter and darker material which give it a
transversely striated appearance, and contains, scattered through its
substance, protoplasmic nuclei, the so-called <parts>muscle
corpuscles</parts>.</note><br/
[<source>1913 Webster</source>]</p>

<p> The nonstriated muscles are <xex>involuntary</xex>. They constitute
a large part of the walls of the alimentary canal, blood vessels,
uterus, and bladder, and are found also in the iris, skin, etc. They are
made up of greatly elongated cells, usually grouped in bundles or
sheets.<br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Muscular strength or development; <as>as, to show
one's <ex>muscle</ex> by lifting a heavy weight</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[AS. <ets>muscle</ets>, L. <ets>musculus</ets> a
muscle, mussel. See above.]</ety> <fld>(Zool.)</fld> <def>See
<er>Mussel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An essential part of something; <as>as, budget cuts
have gone beyond the fat and are cutting into the <ex>muscle</ex> of the
government</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>Bodyguards or other persons hired to provide
protection or commit violence; <as>as, he doesn't go out without his
<ex>muscle</ex> along</as>.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><cs><col><b>Muscle curve</b></col> <fld>(Physiol.)</fld>,
<cd>contraction curve of a muscle; a myogram; the curve inscribed, upon
a prepared surface, by means of a myograph when acted upon by a
contracting muscle. The character of the curve represents the extent of
the contraction.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>muscle</ent><br/
<hw>mus"cle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
compel by threat of force; <as>as, they <ex>muscled</ex> the shopkeeper
into paying protection money</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To moved by human force; <as>as, to <ex>muscle</ex>
the piano onto the truck</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>musclebuilder</ent><br/
<hw>musclebuilder</hw> <pos>n.</pos> <def>someone who does special
exercises to develop the musculature; a bodybuilder.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>musclebuilding</ent><br/
<hw>musclebuilding</hw> <pos>n.</pos> <def>exercise that builds muscles
through tension; bodybuilding.</def><br/
<syn><b>Syn. --</b> bodybuilding, anaerobic exercise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 956 --></p>

<p><ent>Muscled</ent><br/
<hw>Mus"cled</hw> <pr>(m<ucr/s"l'd)</pr>, <pos>a.</pos> <def>Furnished
with muscles; having muscles; <as>as, things well
<ex>muscled</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>muscleman</ent><br/
<hw>muscleman</hw> <pos>n.</pos> <def>a bully employed by a
gangster.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muscle reading</ent><br/
<hw>Mus"cle read`ing</hw>. <def>The art of making discriminations
between objects of choice, of discovering the whereabouts of hidden
objects, etc., by inference from the involuntary movements of one whose
hand the reader holds or with whom he is otherwise in muscular
contact.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muscling</ent><br/
<hw>Mus"cling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Fine Arts)</fld>
<def>Exhibition or representation of the muscles.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A good piece, the painters say, must have good
<qex>muscling</qex>, as well as coloring and drapery.</q>
<rj><qau>Shaftesbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscogees</ent><br/
<hw>Mus*co"gees</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Muskogees</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscoid</ent><br/
<hw>Mus"coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Muscus</ets> +
<ets>-oid</ets>: cf. F. <ets>muscoide</ets>.]</ety> <fld>(Bot.)</fld>
<def>Mosslike; resembling moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscoid</ent><br/
<hw>Mus"coid</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A term formerly
applied to any mosslike flowerless plant, with a distinct stem, and
often with leaves, but without any vascular system.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscoidea</ent><br/
<hw>Muscoidea</hw> <pos>prop. n.</pos> <def>A superfamily of two-winged
flies esp. the families: <fam>Muscidae</fam>;
<fam>Gasterophilidae</fam>; <fam>Calliphoridae</fam>; and
<fam>Tachinidae</fam>.</def><br/
<syn><b>Syn. --</b> superfamily <fam>Muscoidea</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muscology</ent><br/
<hw>Mus*col"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Muscus</ets> + <ets>-logy</ets>.]</ety>
<def>Bryology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscosity</ent><br/
<hw>Mus*cos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>muscosus</ets> mossy, fr. <ets>muscus</ets> moss.]</ety>
<def>Mossiness.</def> <rj><au>Jonhson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscovado</ent><br/
<hw>Mus`co*va"do</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Corrupted fr.
Sp. <ets>mascabado</ets>; cf. Pg. <ets>mascavado</ets>, F.
<ets>moscouade</ets>, n., formerly also <ets>mascovade</ets>, It.
<ets>mascavato</ets>.]</ety> <def>Pertaining to, or of the nature of,
unrefined or raw sugar, obtained from the juice of the sugar cane by
evaporating and draining off the molasses. Muscovado sugar contains
impurities which render it dark colored and moist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscovado</ent><br/
<hw>Mus`co*va"do</hw>, <pos>n.</pos> <def>Unrefined or raw
sugar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscovite</ent><br/
<hw>Mus"co*vite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Muscovy
glass</er>.]</ety> <sn>1.</sn> <def>A native or inhabitant of Muscovy or
ancient Russia; hence, a Russian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inhabitant of Moscow.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Min.)</fld> <def>Common potash mica, essentially
<chform>KAl3Si3O10(OH)2</chform>. It is used as an electrical insulator.
See <er>Mica</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscovy duck</ent><br/
<hw>Mus"co*vy duck`</hw> <pr>(?)</pr>. <ety>[A corruption of
<ets>musk</ets> duck.]</ety> <fld>(Zool.)</fld> <def>A duck
(<spn>Cairina moschata</spn>), larger than the common duck, often raised
in poultry yards. Called also <altname>musk duck</altname>. It is native
of tropical America, from Mexico to Southern Brazil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscovy glass</ent><br/
<hw>Mus"co*vy glass`</hw> <pr>(?)</pr>. <ety>[From <ets>Muscovy</ets>,
the old name of Russia: cf. F. verre de <ets>Moscovie</ets>.]</ety>
<def>Mica; muscovite. See <er>Mica</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscular</ent><br/
<hw>Mus"cu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>musculaire</ets>. See <er>Muscle</er>.]</ety> <sn>1.</sn> <def>Of
or pertaining to a muscle, or to a system of muscles; consisting of, or
constituting, a muscle or muscles; <as>as, <ex>muscular</ex>
fiber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Great <qex>muscular</qex> strength, accompanied by much
awkwardness.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Performed by, or dependent on, a muscle or the
muscles.</def> <ldquo/The <xex>muscular</xex> motion.<rdquo/
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Well furnished with muscles; having well-developed
muscles; brawny; hence, strong; powerful; vigorous; <as>as, a
<ex>muscular</ex> body or arm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Muscular Christian</b></col>, <cd>one who believes in a
part of religious duty to maintain a healthful and vigorous physical
state.</cd> <au>T. Hughes.</au> -- <col><b>Muscular
Christianity</b></col>. <sd>(a)</sd> <cd>The practice and opinion of
those Christians who believe that it is a part of religious duty to
maintain a vigorous condition of the body, and who therefore approve of
athletic sports and exercises as conductive to good health, good morals,
and right feelings in religious matters.</cd> <au>T. Hughes.</au>
<sd>(b)</sd> <cd>An active, robust, and cheerful Christian life, as
opposed to a meditative and gloomy one.</cd> <au>C. Kingsley.</au> --
<col><b>Muscular excitability</b></col> <fld>(Physiol.)</fld>, <cd>that
property in virtue of which a muscle shortens, when it is stimulated;
irritability; contractility.</cd> -- <col><b>Muscular sense</b></col>
<fld>(Physiol.)</fld>, <cd>muscular sensibility; the sense by which we
obtain knowledge of the condition of our muscles and to what extent they
are contracted, also of the position of the various parts of our bodies
and the resistance offering by external objects.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscularity</ent><br/
<hw>Mus`cu*lar"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being muscular.</def> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscularize</ent><br/
<hw>Mus"cu*lar*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
muscular.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscularly</ent><br/
<hw>Mus"cu*lar*ly</hw>, <pos>adv.</pos> <def>In a muscular
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculation</ent><br/
<hw>Mus`cu*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>Musculature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculature</ent><br/
<hw>Mus"cu*la*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>musculature</ets>.]</ety> <fld>(Anat.)</fld> <def>The muscular
system of an animal, or of any of its parts; musculation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muscule</ent><br/
<hw>Mus"cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>musculus</ets>: cf. F. <ets>muscule</ets>.]</ety> <fld>(Mil.)</fld>
<def>A long movable shed used by besiegers in ancient times in attacking
the walls of a fortified town.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculin</ent><br/
<hw>Mus"cu*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>musculus</ets> a muscle.]</ety> <fld>(Physiol. Chem.)</fld>
<def>See <er>Syntonin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculocutaneous</ent><br/
<hw>Mus`cu*lo*cu*ta"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>musculus</ets> + E. <ets>cutaneous</ets>.]</ety> <fld>(Anat.)</fld>
<def>Pertaining both to muscles and skin; <as>as, the
<ex>musculocutaneous</ex> nerve</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculophrenic</ent><br/
<hw>Mus`cu*lo*phren"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>musculus</ets> muscle + E. <ets>phrenic</ets>.]</ety>
<fld>(Anat.)</fld> <def>Pertaining to the muscles and the diaphragm;
<as>as, the <ex>musculophrenic</ex> artery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculosity</ent><br/
<hw>Mus`cu*los"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being musculous; muscularity.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculospiral</ent><br/
<hw>Mus`cu*lo*spi"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>musculus</ets> muscle + E. <ets>spiral</ets>.]</ety>
<fld>(Anat.)</fld> <def>Of or pertaining to the muscles, and taking a
spiral course; -- applied esp. to a large nerve of the arm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musculous</ent><br/
<hw>Mus"cu*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>musculosus</ets>: cf. F. <ets>musculeux</ets>.]</ety>
<def>Muscular.</def> <mark>[Obs.]</mark> <rj><au>Jonhson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muse</ent><br/
<hw>Muse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From F.
<ets>musse</ets>. See <er>Muset</er>.]</ety> <def>A gap or hole in a
hedge, hence, wall, or the like, through which a wild animal is
accustomed to pass; a muset.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Find a hare without a <qex>muse</qex>.</q> <rj><qau>Old
Prov.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muse</ent><br/
<hw>Muse</hw>, <pos>n.</pos> <ety>[F. <ets>Muse</ets>, L.
<ets>Musa</ets>, Gr. <?/. Cf. <er>Mosaic</er>, <pos>n.</pos>,
<er>Music</er>.]</ety> <sn>1.</sn> <fld>(Class. Myth.)</fld> <def>One of
the nine goddesses, daughters of Zeus and Mnemosyne, who presided over
song and the different kinds of poetry, and also the arts and sciences;
-- often used in the plural. At one time certain other goddesses were
considered as muses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Granville commands; your aid, O Muses, bring:<br/
What <qex>Muse</qex> for Granville can refuse to sing?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The names of the Muses and the arts they presided over
were: <examp>Calliope</examp> (Epic poetry), <examp>Clio</examp>
(History), <examp>Erato</examp> (Lyric poetry), <examp>Euterpe</examp>
(music), <examp>Melpomene</examp> (Tragedy), <examp>Polymnia</examp> or
<examp>Polyhymnia</examp> (religious music), <examp>Terpsichore</examp>
(dance), <examp>Thalia</examp> (comedy), and <examp>Urania</examp>
(astronomy).</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A particular power and practice of poetry; the
inspirational genius of a poet.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A poet; a bard.</def> <mark>[R.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muse</ent><br/
<hw>Muse</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mused</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Musing</conjf>.]</vmorph> <ety>[F. <ets>muser</ets> to loiter or
trifle, orig., to stand with open mouth, fr. LL. <ets>musus</ets>,
<ets>morsus</ets>, muzzle, snout, fr. L. <ets>morsus</ets> a biting,
bite, fr. <ets>mordere</ets> to bite. See <er>Morsel</er>, and cf.
<er>Amuse</er>, <er>Muzzle</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>To think closely; to study in silence; to meditate.</def>
<ldquo/Thereon <xex>mused</xex> he.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>mused</qex> upon some dangerous plot.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be absent in mind; to be so occupied in study or
contemplation as not to observe passing scenes or things present; to be
in a brown study.</def> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To wonder.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au> <au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To consider; meditate; ruminate. See
<er>Ponder</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muse</ent><br/
<hw>Muse</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To think on; to
meditate on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, then, expressive Silence, <qex>muse</qex> his praise.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wonder at.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muse</ent><br/
<hw>Muse</hw>, <pos>n.</pos> <sn>1.</sn> <def>Contemplation which
abstracts the mind from passing scenes; absorbing thought; hence,
absence of mind; a brown study.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wonder, or admiration.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Museful</ent><br/
<hw>Muse"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Meditative;
thoughtfully silent.</def> <ldquo/<xex>Museful</xex> mopings.<rdquo/
<au>Dryden.</au> -- <wordforms><wf>Muse"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Museless</ent><br/
<hw>Muse"less</hw>, <pos>a.</pos> <def>Unregardful of the Muses;
disregarding the power of poetry; unpoetical.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muser</ent><br/
<hw>Mus"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
muses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muset</ent><br/
<hw>Mu"set</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>mussette</ets>, dim. of <ets>musse</ets>, <ets>muce</ets>, a hiding
place, fr. F. <ets>musser</ets>, OF. <ets>mucier</ets>,
<ets>muchier</ets>, to conceal, hide. Cf. <er>Micher</er>.]</ety> <def>A
small hole or gap through which a wild animal passes; a muse.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musette</ent><br/
<hw>Mu*sette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., dim. of OF.
<ets>muse</ets>.]</ety> <sn>1.</sn> <def>A small bagpipe formerly in
use, having a soft and sweet tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An air adapted to this instrument; also, a kind of
rustic dance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Museum</ent><br/
<hw>Mu*se"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a temple of the
Muses, hence, a place of study, fr. Gr. <?/, fr. <?/ a Muse.]</ety>
<def>A repository or a collection of natural, scientific, or literary
curiosities, or of works of art.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Museum beetle</b></col>, <col><b>Museum
pest</b></col></mcol>. <fld>(Zool.)</fld> <cd>See
<er>Anthrenus</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mush</ent><br/
<hw>Mush</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Gael.
<ets>mus</ets>, <ets>muss</ets>, pap, porridge, any thick preparation of
fruit, OHG. <ets>muos</ets>; akin to AS. & OS. <ets>m<omac/s</ets> food,
and prob, to E. <ets>meat</ets>. See <er>Meat</er>.]</ety> <def>Meal
(esp. Indian meal) boiled in water; hasty pudding; supawn.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mush</ent><br/
<hw>Mush</hw>, <pos>v. t.</pos> <ety>[Cf. F. <ets>moucheter</ets> to cut
with small cuts.]</ety> <def>To notch, cut, or indent, as cloth, with a
stamp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mush</ent><br/
<hw>Mush</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. short for
<ets>mush on</ets>, a corrupt of E. <ets>marchons</ets>, the cry of the
voyageurs and coureurs de bois to their dogs.]</ety> <def>A march on
foot, esp. across the snow with dogs; <as>as, he had a long
<ex>mush</ex> before him</as>; -- also used attributively.</def>
<mark>[Colloq., Alaska & Northwestern U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mush</ent><br/
<hw>Mush</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mushed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mushing</conjf>.]</vmorph> <def>To travel on foot, esp. across
the snow with dogs.</def> -- <def2><pos>v. t. </pos> <def>To cause to
travel or journey.</def> <mark>[Rare]</mark> <mark>[Colloq., Alaska &
Northwestern U. S.]</mark></def2><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mushroom</ent><br/
<hw>Mush"room</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>muscheron</ets>, OF. <ets>mouscheron</ets>, F.
<ets>mousseron</ets>; perhaps fr. <ets>mousse</ets> moss, of German
origin. See <er>Moss</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>An edible fungus (<spn>Agaricus campestris</spn>),
having a white stalk which bears a convex or oven flattish expanded
portion called the <part>pileus</part>. This is whitish and silky or
somewhat scaly above, and bears on the under side radiating gills which
are at first flesh-colored, but gradually become brown. The plant grows
in rich pastures and is proverbial for rapidity of growth and shortness
of duration. It has a pleasant smell, and is largely used as food. It is
also cultivated from spawn.</def> <sd>(b)</sd> <def>Any large fungus
developing a visible fruiting body with a stem and cap, usu. of the
basidiomycetes;</def> <specif>especially</specif> <def>one of the genus
<gen>Agaricus</gen>; a toadstool. Several species are edible; but many
are very poisonous. The term <ex>mushroom</ex> is used most often for
edible varieties, the poisonous ones being termed
<contr>toadstools</contr> or other names. But this distinction is often
ignored.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>One who rises suddenly from a low condition in life;
an upstart.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mushroom</ent><br/
<hw>Mush"room</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
mushrooms; <as>as, <ex>mushroom</ex> catchup</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling mushrooms in rapidity of growth and
shortness of duration; short-lived; ephemerial; <as>as,
<ex>mushroom</ex> cities</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mushroom anchor</b></col>, <cd>an anchor shaped like a
mushroom, capable of grasping the ground in whatever way it falls.</cd>
-- <col><b>Mushroom coral</b></col> <fld>(Zool.)</fld>, <cd>any coral of
the genus <gen>Fungia</gen>. See <er>Fungia</er>.</cd> --
<col><b>Mushroom spawn</b></col> <fld>(Bot.)</fld>, <cd>the mycelium, or
primary filamentous growth, of the mushroom; also, cakes of earth and
manure containing this growth, which are used for propagation of the
mushroom.</cd> -- <col><b>mushroom cloud</b></col>, <cd>a cloud of smoke
rising and then spreading laterally to take on the shape of a mushroom
-- caused by large fires or explosions, esp. nuclear
explosions.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>mushroom</ent><br/
<hw>mush"room</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>to
grow or expand rapidly.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>to grow so much and so rapidly as to change
qualitatively; used with <ptcl>into</ptcl>; <as>as, a minor border
skirmish <ex>mushroomed into</ex> a full-blown war</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mushroom-headed</ent><br/
<hw>Mush"room-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having a cylindrical body with a convex head of larger diameter;
having a head like that of a mushroom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mushy</ent><br/
<hw>Mush"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Soft like mush;
figuratively, good-naturedly weak and effusive; weakly
sentimental.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She 's not <qex>mushy</qex>, but her heart is tender.</q>
<rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Music</ent><br/
<hw>Mu"sic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>musique</ets>,
fr. L. <ets>musica</ets>, Gr. <?/ (sc. <?/), any art over which the
Muses presided, especially music, lyric poetry set and sung to music,
fr. <?/ belonging to Muses or fine arts, fr. <?/ Muse.]</ety>
<sn>1.</sn> <def>The science and the art of tones, or musical sounds,
<it>i. e.</it>, sounds of higher or lower pitch, begotten of uniform and
synchronous vibrations, as of a string at various degrees of tension;
the science of harmonical tones which treats of the principles of
harmony, or the properties, dependences, and relations of tones to each
other; the art of combining tones in a manner to please the
ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Not all <xex>sounds</xex> are <xex>tones</xex>. Sounds
may be unmusical and yet please the ear. <xex>Music</xex> deals with
<xex>tones</xex>, and with no other sounds. See
<er>Tone</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <def>Melody; a rhythmical and otherwise
agreeable succession of tones.</def> <sd>(b)</sd> <def>Harmony; an
accordant combination of simultaneous tones.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The written and printed notation of a musical
composition; the score.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Love of music; capacity of enjoying music.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The man that hath no <qex>music</qex> in himself<br/
Nor is not moved with concord of sweet sounds,<br/
Is fit for treasons, stratagems, and spoils.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>A more or less musical sound made
by many of the lower animals. See <er>Stridulation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Magic music</b></col>, <cd>a game in which a person is
guided in finding a hidden article, or in doing a specific act required,
by music which is made more loud or rapid as he approaches success, and
slower as he recedes. It is similar to the game of <er>hot and
cold</er>, but using music as the clue.</cd> <au>Tennyson.</au> --
<col><b>Music box</b></col>. <cd>See <cref>Musical box</cref>, under
<er>Musical</er>.</cd> -- <col><b>Music hall</b></col>, <cd>a place for
public musical entertainments.</cd> -- <col><b>Music loft</b></col>,
<cd>a gallery for musicians, as in a dancing room or a church.</cd> --
<col><b>Music of the spheres</b></col>, <cd>the harmony supposed to be
produced by the accordant movement of the celestial spheres.</cd> --
<col><b>Music paper</b></col>, <cd>paper ruled with the musical staff,
for the use of composers and copyists.</cd> -- <col><b>Music
pen</b></col>, <cd>a pen for ruling at one time the five lines of the
musical staff.</cd> -- <col><b>Music shell</b></col> <fld>(Zool.)</fld>,
<cd>a handsomely colored marine gastropod shell (<spn>Voluta
musica</spn>) found in the East Indies; -- so called because the color
markings often resemble printed music. Sometimes applied to other shells
similarly marked.</cd> -- <col><b>To face the music</b></col>, <cd>to
meet any disagreeable necessity, such as a reprimand for an error or
misdeed, without flinching.</cd> <mark>[Colloq. or
Slang]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musical</ent><br/
<hw>Mu"sic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>musical</ets>.]</ety> <def>Of or pertaining to music; having the
qualities of music; or the power of producing music; devoted to music;
melodious; harmonious; <as>as, <ex>musical</ex> proportion; a
<ex>musical</ex> voice; <ex>musical</ex> instruments; a <ex>musical</ex>
sentence; <ex>musical</ex> persons.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Musical box</b></col>, <it>or</it> <col><b>Music
box</b></col></mcol>, <cd>a box or case containing apparatus moved by
clockwork so as to play certain tunes automatically. The apparatus may
be driven by a wind-up spring mechanism or by batteries.</cd> --
<col><b>Musical fish</b></col> <fld>(Zool.)</fld>, <cd>any fish which
utters sounds under water, as the drumfish, grunt, gizzard shad,
etc.</cd> -- <col><b>Musical glasses</b></col>, <cd>glass goblets or
bowls so tuned and arranged that when struck, or rubbed, they produce
musical notes. Cf. <er>Harmonica</er>, 1.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musical</ent><br/
<hw>Mu"sic*al</hw>, <pos>n.</pos> <sn>1.</sn> <def>Music.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To fetch home May with their <qex>musical</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A social entertainment of which music is the leading
feature; a musical party.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A drama in which music and song are prominent
features; a musical drama or musical play; <as>as, Oklahoma! was a
breakthrough in the form and popularity of the
<ex>musical</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Musicale</ent><br/
\'d8<hw>Mu`si`cale"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Cf.
<ets>Soir<eacute/e musicale</ets>.]</ety> <def>A social musical
party.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musically</ent><br/
<hw>Mu"sic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a musical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musicalness</ent><br/
<hw>Mu"sic*al*ness</hw>, <pos>n.</pos> <def>The quality of being
musical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Music drama</ent><br/
<hw>Mu"sic dra`ma</hw>. <def>An opera in which the text and action are
not interrupted by set arias, duets, etc., the music being determined
throughout by dramatic appropriateness; musical drama of this character,
in general. It involves the use of a kind of melodious declamation, the
development of leitmotif, great orchestral elaboration, and a fusion of
poetry, music, action, and scene into an organic whole. The term is
applied esp. to the later works of Wagner: <ldquo/Tristan und
Isolde,<rdquo/ <ldquo/Die Meistersinger,<rdquo/ <ldquo/Rheingold,<rdquo/
<ldquo/Walk<uum/re,<rdquo/ <ldquo/Siegfried,<rdquo/
<ldquo/G<oum/tterd<aum/mmerung,<rdquo/ and
<ldquo/Parsifal.<rdquo/</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Music hall</ent><br/
<hw>Music hall</hw>. <def>A place for public musical entertainments;
specif. (<mark>Eng.</mark>), esp. a public hall for vaudeville
performances, in which smoking and drinking are usually allowed in the
auditorium.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Musician</ent><br/
<hw>Mu*si"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>musicien</ets>.]</ety> <def>One skilled in the art or science of
music; esp., a skilled singer, or performer on a musical
instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musicomania</ent><br/
<hw>Mu`si*co*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Music</ets> + <ets>mania</ets>: cf. F.
<ets>musicomanie</ets>.]</ety> <fld>(Med.)</fld> <def>A kind of
monomania in which the passion for music becomes so strong as to derange
the intellectual faculties.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musimon</ent><br/
<hw>Mus"i*mon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Musmon</er>.]</ety> <fld>(Zool.)</fld> <def>See
<er>Mouflon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>musing</ent><br/
<hw>musing</hw> <pos>adj.</pos> <def>Thinking long and
intensely.</def><br/
<syn><b>Syn. --</b> brooding, broody, contemplative, meditative,
pensive, pondering, reflective, ruminative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Musingly</ent><br/
<hw>Mus"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a musing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musit</ent><br/
<hw>Mu"sit</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Muset</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musk</ent><br/
<hw>Musk</hw> <pr>(m<ucr/sk)</pr>, <pos>n.</pos> <ety>[F.
<ets>musc</ets>, L. <ets>muscus</ets>, Per. <ets>musk</ets>, fr. Skr.
<ets>mushka</ets> testicle, orig., a little mouse. See <er>Mouse</er>,
and cd. <er>Abelmosk</er>, <er>Muscadel</er>, <er>Muscovy duck</er>,
<er>Nutmeg</er>.]</ety> <sn>1.</sn> <def>A substance of a reddish brown
color, and when fresh of the consistency of honey, obtained from a bag
being behind the navel of the male musk deer. It has a slightly bitter
taste, but is specially remarkable for its powerful and enduring odor.
It is used in medicine as a stimulant antispasmodic. The term is also
applied to secretions of various other animals, having a similar
odor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The musk deer. See <cref>Musk
deer</cref> (below).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The perfume emitted by musk, or any perfume somewhat
similar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The musk plant
(<spn>Mimulus moschatus</spn>).</def> <sd>(b)</sd> <def>A plant of the
genus <gen>Erodium</gen> (<spn>Erodium moschatum</spn>); -- called also
<altname>musky heron's-bill</altname>.</def> <sd>(c)</sd> <def>A plant
of the genus <gen>Muscari</gen>; grape hyacinth.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Musk beaver</b></col> <fld>(Zool.)</fld>, <cd>muskrat
(1).</cd> -- <col><b>Musk beetle</b></col> <fld>(Zool.)</fld>, <cd>a
European longicorn beetle (<spn>Aromia moschata</spn>), having an
agreeable odor resembling that of attar of roses.</cd> -- <col><b>Musk
cat</b></col>. <cd>See <er>Bondar</er>.</cd> -- <col><b>Musk
cattle</b></col> <fld>(Zool.)</fld>, <cd>musk oxen. See <cref>Musk
ox</cref> (below).</cd> -- <col><b>Musk deer</b></col>
<fld>(Zool.)</fld>, <cd>a small hornless deer (<spn>Moschus
moschiferus</spn>), which inhabits the elevated parts of Central Asia.
The upper canine teeth of the male are developed into sharp tusks,
curved downward. The male has scent bags on the belly, from which the
musk of commerce is derived. The deer is yellow or red-brown above,
whitish below. The pygmy musk deer are chevrotains, as the kanchil and
napu.</cd> -- <col><b>Musk duck</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The Muscovy duck</cd>. <sd>(b)</sd> <cd>An Australian
duck (<spn>Biziura lobata</spn>).</cd> -- <col><b>Musk
lorikeet</b></col> <fld>(Zool.)</fld>, <cd>the Pacific lorikeet
(<spn>Glossopsitta australis</spn>) of Australia.</cd> -- <col><b>Musk
mallow</b></col> <fld>(Bot.)</fld>, <cd>a name of two malvaceous
plants</cd>: <sd>(a)</sd> <cd>A species of mallow (<spn>Malva
moschata</spn>), the foliage of which has a faint musky smell</cd>.
<sd>(b)</sd> <cd>An Asiatic shrub. See <er>Abelmosk</er>.</cd> --
<col><b>Musk orchis</b></col> <fld>(Bot.)</fld>, <cd>a European plant of
the Orchis family (<spn>Herminium Minorchis</spn>); -- so called from
its peculiar scent.</cd> -- <col><b>Musk ox</b></col>
<fld>(Zool.)</fld>, <cd>an Arctic hollow-horned ruminant (<spn>Ovibos
moschatus</spn>), now existing only in America, but found fossil in
Europe and Asia. It is covered with a thick coat of fine yellowish wool,
and with long dark hair, which is abundant and shaggy on the neck and
shoulders. The full-grown male weighs over four hundred pounds.</cd> --
<col><b>Musk parakeet</b></col>. <fld>(Zool.)</fld> <cd>Same as
<cref>Musk lorikeet</cref> (above).</cd> -- <col><b>Musk pear</b></col>
<fld>(Bot.)</fld>, <cd>a fragrant kind of pear much resembling the
Seckel pear.</cd> -- <col><b>Musk plant</b></col> <fld>(Bot.)</fld>,
<cd>the <spn>Mimulus moschatus</spn>, a plant found in Western North
America, often cultivated, and having a strong musky odor.</cd> --
<col><b>Musk root</b></col> <fld>(Bot.)</fld>, <cd>the name of several
roots with a strong odor, as that of the nard (<spn>Nardostachys
Jatamansi</spn>) and of a species of <gen>Angelica</gen>.</cd> --
<col><b>Musk rose</b></col> <fld>(Bot.)</fld>, <cd>a species of rose
(<spn>Rosa moschata</spn>), having peculiarly fragrant white
blossoms.</cd> -- <col><b>Musk seed</b></col> <fld>(Bot.)</fld>, <cd>the
seed of a plant of the Mallow family (<spn>Hibiscus moschatus</spn>),
used in perfumery and in flavoring. See <er>Abelmosk</er>.</cd> --
<col><b>Musk sheep</b></col> <fld>(Zool.)</fld>, <cd>the musk ox.</cd>
-- <col><b>Musk shrew</b></col> <fld>(Zool.)</fld>, <cd>a shrew
(<spn>Sorex murinus</spn>), found in India. It has a powerful odor of
musk. Called also <altname>sondeli</altname>, and
<altname>mondjourou</altname>.</cd> -- <col><b>Musk thistle</b></col>
<fld>(Bot.)</fld>, <cd>a species of thistle (<spn>Carduus nutans</spn>),
having fine large flowers, and leaves smelling strongly of musk.</cd> --
<mcol><col><b>Musk tortoise</b></col>, <col><b>Musk
turtle</b></col></mcol> <fld>(Zool.)</fld>, <cd>a small American
fresh-water tortoise (<spn>Armochelys odorata</spn> syn. <spn>Ozotheca
odorata</spn>), which has a distinct odor of musk; -- called also
<altname>stinkpot</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 957 --></p>

<p><ent>Musk</ent><br/
<hw>Musk</hw> <pr>(m<ucr/sk)</pr>, <pos>v. t.</pos> <def>To perfume with
musk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskadel</ent><br/
<hw>Mus"ka*del`</hw> <pr>(m<ucr/s"k<adot/*d<ecr/l`)</pr>, <pos>n.</pos>
<def>See <er>Muscadel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskat</ent><br/
<hw>Mus"kat</hw> <pr>(m<ucr/s"k<acr/t)</pr>, <pos>n.</pos> <def>See
<er>Muscat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskellunge</ent><br/
<hw>Mus"kel*lunge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the Amer.
Indian name.]</ety> <fld>(Zool.)</fld> <def>A large American pike
(<spn>Esox masquinongy</spn> formerly <spn>Esox nobilior</spn>) found in
the Great Lakes, and other Northern lakes, and in the St. Lawrence
River. It is valued as a food fish.</def> <altsp>[Written also
<asp>maskallonge</asp>, <asp>maskalonge</asp>, <asp>maskinonge</asp>,
<asp>muskallonge</asp>, <asp>muskellonge</asp>, and
<asp>muskelunjeh</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musket</ent><br/
<hw>Mus"ket</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mousquet</ets>, It. <ets>moschetto</ets>, formerly, a kind of hawk;
cf. OF. <ets>mousket</ets>, <ets>moschet</ets>, a kind of hawk falcon,
F. <ets>mouchet</ets>, prop., a little fly (the hawk prob. being named
from its size), fr. L. <ets>musca</ets> a fly. Cf.
<er>Mosquito</er>.]</ety> <altsp>[Sometimes written also
<asp>musquet</asp>.]</altsp> <sn>1.</sn> <fld>(Zool.)</fld> <def>The
male of the sparrow hawk.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A species of firearm formerly carried by the
infantry of an army. It was originally fired by means of a match, or
matchlock, for which several mechanical appliances (including the
flintlock, and finally the percussion lock) were successively
substituted. This arm has been completely superseded by the rifle, and
is now only of historical interest.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Musketeer</ent><br/
<hw>Mus`ket*eer"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mousquetaire</ets>; cf. It. <ets>moschettiere</ets>.]</ety> <def>A
soldier armed with a musket.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musketo</ent><br/
<hw>Mus*ke"to</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mosquito</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musketoon</ent><br/
<hw>Mus`ket*oon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mousqueton</ets>; cf. It. <ets>moschettone</ets>.]</ety>
<sn>1.</sn> <def>A short musket.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is armed with such a musket.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musketry</ent><br/
<hw>Mus"ket*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mousqueterie</ets>; cf. It. <ets>moschetteria</ets>.]</ety>
<sn>1.</sn> <def>Muskets, collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fire of muskets.</def>
<rj><au>Motley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskiness</ent><br/
<hw>Musk"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being musky; the scent of musk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskmelon</ent><br/
<hw>Musk"mel`on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Musk</ets> +
<ets>melon</ets>.]</ety> <fld>(Bot.)</fld> <def>The fruit of a
cucurbitaceous plant (<spn>Cucumis Melo</spn>) of the gourd family,
having a peculiar aromatic flavor, and cultivated in many varieties, the
principal sorts being the cantaloupe, of oval form and yellowish flesh,
and the smaller nutmeg melon with greenish flesh. See <xex>Illust.</xex>
of <er>Melon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskogees</ent><br/
<hw>Mus*ko"gees</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Muskogee</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld>
<def>A powerful tribe of North American Indians that formerly occupied
the region of Georgia, Florida, and Alabama. They constituted a large
part of the Creek confederacy.</def> <altsp>[Written also
<asp>Muscogees</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskrat</ent><br/
<hw>Musk"rat`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A North American aquatic fur-bearing rodent
(<spn>Ondatra zibethica</spn> formerly <spn>Fiber zibethicus</spn>). It
resembles a rat in color and having a long scaly tail, but the tail is
compressed, the hind feet are webbed, and the ears are concealed in the
fur. It has scent glands which secrete a substance having a strong odor
of musk. Called also <altname>musquash</altname>, <altname>musk
beaver</altname>, <altname>ondatra</altname>, and sometimes
<altname>water rat</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The musk shrew.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The desman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muskwood</ent><br/
<hw>Musk"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from its
fragrance.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The wood of a West
Indian tree of the Mahogany family (<spn>Moschoxylum
Swartzii</spn>).</def> <sd>(b)</sd> <def>The wood of an Australian tree
(<spn>Eurybia argophylla</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musky</ent><br/
<hw>Musk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having an odor of musk,
or somewhat the like.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>musky</ent><br/
<hw>musk"y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
<er>muskellunge</er>.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Muslim</ent><br/
<hw>Mus"lim</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>See
<er>Moslem</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muslin</ent><br/
<hw>Mus"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mousseline</ets>; cf. It. <ets>mussolino</ets>, <ets>mussolo</ets>,
Sp. <ets>muselina</ets>; all from <ets>Mussoul</ets> a city of
Mesopotamia, Ar. <ets>Mausil</ets>, Syr. <ets>Mauzol</ets>,
<ets>Muzol</ets>, <ets>Mosul</ets>, where it was first manufactured. Cf.
<er>Mull</er> a kind of cloth.]</ety> <def>A thin cotton, white, dyed,
or printed. The name is also applied to coarser and heavier cotton
goods; <as>as, shirting and sheeting <ex>muslins</ex></as>. In sheeting,
<ex>muslin</ex> is not as finely woven as
<contr>percale</contr>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Muslin cambric</b></col>. <cd>See <er>Cambric</er>.</cd>
-- <col><b>Muslin delaine</b></col>, <cd>a light woolen fabric for
women's dresses. See <er>Delaine</er>.</cd> <altsp>[Written also
<asp>mousseline de laine</asp>.]</altsp></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muslinet</ent><br/
<hw>Mus`lin*et"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mousselinette</ets>.]</ety> <def>A sort of coarse or light cotton
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musmon</ent><br/
<hw>Mus"mon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>musmo</ets>,
<ets>musimo</ets>, a Sardinian animal; cf. Gr.
<grk>moy`smwn</grk>.]</ety> <fld>(Zool.)</fld> <def>See
<er>Mouflon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musomania</ent><br/
<hw>Mu`so*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Musicomania</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musquash</ent><br/
<hw>Mus"quash</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[American Indian
name.]</ety> <fld>(Zool.)</fld> <def>See <er>Muskrat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Musquash root</b></col> <fld>(Bot.)</fld>, <cd>an
umbelliferous plant (<spn>Cicuta maculata</spn>), having a poisonous
root. See <er>Water hemlock</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musquaw</ent><br/
\'d8<hw>Mus"quaw</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[American Indian
name.]</ety> <fld>(Zool.)</fld> <def>The American black bear. See
<er>Bear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musquet</ent><br/
<hw>Mus"quet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Musket</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musquito</ent><br/
<hw>Mus*qui"to</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Mosquito</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musrol</ent><br/
<ent>Musrole</ent><br/
<mhw>{ <hw>Mus"role</hw>, <hw>Mus"rol</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>muserolle</ets>, fr. <ets>muserau</ets> a
muzzle, OF. <ets>musel</ets>. See <er>Muzzle</er>.]</ety> <def>The nose
band of a horse's bridle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muss</ent><br/
<hw>Muss</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>mousche</ets> a fly, also, the play called <ets>muss</ets>, fr. L.
<ets>musca</ets> a fly.]</ety> <def>A scramble, as when small objects
are thrown down, to be taken by those who can seize them; a confused
struggle.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muss</ent><br/
<hw>Muss</hw>, <pos>n.</pos> <def>A state of confusion or disorder; --
prob. variant of <xex>mess</xex>, but influenced by <xex>muss</xex>, a
scramble.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muss</ent><br/
<hw>Muss</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mussed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mussing</conjf>.]</vmorph> <def>To disarrange, as clothing; to
rumple; -- often used with <ptcl>up</ptcl>; <as>as, the wind
<ex>mussed</ex> up my hair</as>.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muss</ent><br/
<hw>Muss</hw>, <pos>n.</pos> <ety>[Cf. OE. <ets>mus</ets> a mouse. See
<er>Mouse</er>.]</ety> <def>A term of endearment.</def>
<mark>[Obs.]</mark> <see>See <er>Mouse</er>.</see> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussel</ent><br/
<hw>Mus"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Muscle</er>,
3.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>Any one of many species of
marine bivalve shells of the genus <gen>Mytilus</gen>, and related
genera, of the family <fam>Mytidae</fam>. The common mussel
(<spn>Mytilus edulis</spn>; see <xex>Illust.</xex> under
<er>Byssus</er>), and the larger, or horse, mussel (<spn>Modiola
modiolus</spn>), inhabiting the shores both of Europe and America, are
edible. The former is extensively used as food in Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any one of numerous species of
<gen>Unio</gen>, and related fresh-water genera; -- called also
<altname>river mussel</altname>. See <er>Naiad</er>, and
<er>Unio</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mussel digger</b></col> <fld>(Zool.)</fld>, <cd>the
grayback whale. See <cref>Gray whale</cref>, under
<er>Gray</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussitation</ent><br/
<hw>Mus`si*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mussitatio</ets> suppression of the voice, fr. <ets>mussitare</ets>
to be silent, to murmur.]</ety> <def>A speaking in a low tone;
mumbling.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussite</ent><br/
<hw>Mus"site</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A
variety of pyroxene, from the Mussa Alp in Piedmont; diopside.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussulman</ent><br/
<hw>Mus"sul*man</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mussulmans</plw> <pr>(#)</pr>.</plu> <ety>[Ar.
<ets>muslim<imac/n</ets>, pl. of <ets>muslim</ets>: cf. F. & Sp.
<ets>musulman</ets>. See <er>Moslem</er>.]</ety> <def>A Muslim; a
Moslem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussulmanic</ent><br/
<hw>Mus`sul*man"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining
to, or like, the Muslims (Mussulmans), or their customs:
Islamic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussulmanish</ent><br/
<hw>Mus"sul*man*ish</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Islamic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussulmanism</ent><br/
<hw>Mus"sul*man*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Islam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussulmanly</ent><br/
<hw>Mus"sul*man*ly</hw>, <pos>adv.</pos> <def>In the manner of
Moslems.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mussy</ent><br/
<hw>Muss"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From 2d
<er>Muss</er>.]</ety> <def>Disarranged; rumpled.</def> <mark>[Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Must</ent><br/
<hw>Must</hw> <pr>(m<ucr/st)</pr>, <pos>v. i. <or/ auxiliary</pos>.
<ety>[OE. <ets>moste</ets>, a pret. generally meaning, could, was free
to, pres. <ets>mot</ets>, <ets>moot</ets>, AS. <ets>m<omac/ste</ets>,
pret. <ets>m<omac/t</ets>, pres.; akin to D. <ets>moetan</ets> to be
obliged, OS. <ets>m<omac/tan</ets> to be free, to be obliged, OHG.
<ets>muozan</ets>, G. <ets>m<uum/ssen</ets> to be obliged, Sw.
<ets>m<aring/ste</ets> must, Goth. <ets>gam<omac/tan</ets> to have
place, have room, to able; of unknown origin.]</ety> <sn>1.</sn> <def>To
be obliged; to be necessitated; -- expressing either physical or moral
necessity; <as>as, a man <ex>must</ex> eat for nourishment; we
<ex>must</ex> submit to the laws.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be morally required; to be necessary or essential
to a certain quality, character, end, or result; <as>as, he
<ex>must</ex> reconsider the matter; he <ex>must</ex> have been
insane.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Likewise <qex>must</qex> the deacons be grave.</q> <rj><qau>1 Tim.
iii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Morover, he [a bishop] <qex>must</qex> have a good report of them
which are without.</q> <rj><qau>1 Tim. iii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The principal verb, if easily supplied by the mind, was
formerly often omitted when <xex>must</xex> was used; <as>as, I
<ex>must</ex> away</as>. <ldquo/I <xex>must</xex> to Coventry.<rdquo/
<au>Shak.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Must</ent><br/
<hw>Must</hw>, <pos>n.</pos> <ety>[AS. <ets>must</ets>, fr. L.
<ets>mustum</ets> (sc. <ets>vinum</ets>), from <ets>mustus</ets> young,
new, fresh. Cf. <er>Mustard</er>.]</ety> <sn>1.</sn> <def>The expressed
juice of the grape, or other fruit, before fermentation.</def>
<ldquo/These men ben full of <xex>must</xex>.<rdquo/ <rj><au>Wyclif
(Acts ii. 13.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No fermenting <qex>must</qex> fills . . . the deep vats.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. <er>Musty</er>.]</ety>
<def>Mustiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Must</ent><br/
<hw>Must</hw>, <pos>v. t. & i.</pos> <def>To make musty; to become
musty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>musth</ent><br/
<ent>must</ent><br/
<mhw><hw>must</hw>, <hw>musth</hw></mhw> <pr>(m<ucr/st)</pr>,
<pos>a.</pos> <ety>[Hind. <ets>mast</ets> intoxicated, ruttish, fr. Skr.
<ets>matta</ets>, p.p. of <ets>mad</ets> to rejoice, intoxicate.]</ety>
<fld>(Zool.)</fld> <def>Being in a condition of dangerous frenzy,
usually connected with sexual excitement; -- said of adult male
elephants which become so at irregular intervals, typicaly due to
increased testosterone levels.</def> -- <def2><pos>n.</pos> <sd>(a)</sd>
<def>The condition of frenzy.</def> <sd>(b)</sd> <def>An elephant in
must.</def></def2><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Mustac</ent><br/
<hw>Mus"tac</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>moustac</ets>.]</ety> <fld>(Zool.)</fld> <def>A small tufted
monkey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustache</ent><br/
<hw>Mus*tache"</hw> <pr>(m<ucr/s*t<adot/sh"; 277)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mustaches</plw> <pr>(<?/)</pr>.</plu>
<altsp>[Written also <asp>moustache</asp>.]</altsp> <ety>[F.
<ets>moustache</ets>, It. <ets>mostaccio</ets> visage,
<ets>mostacchio</ets> mustache, fr. Gr. <grk>my`stax</grk> upper lip and
the beard upon it; cf. <grk>ma`stax</grk> mouth: cf. Sp.
<ets>mostacho</ets>.]</ety> <sn>1.</sn> <def>That part of the beard
which grows on the upper lip; hair left growing above the
mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A West African monkey
(<spn>Cercopithecus cephus</spn>). It has yellow whiskers, and a
triangular blue mark on the nose.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Any conspicuous stripe of color
on the side of the head, beneath the eye of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A stain or discoloration on the upper lip of a
person; <as>as, wearing a milk <ex>mustache</ex></as>.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Mustachio</ent><br/
<hw>Mus*ta"chio</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mustachios</plw> <pr>(<?/)</pr>.</plu> <def>A mustache.</def>
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mustachioed</ent><br/
<hw>mus*ta"chioed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
mustache or mustachios.</def><br/
<syn><b>Syn. --</b> mustached.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustahfiz</ent><br/
<hw>Mus`tah"fiz`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk. & Ar.
<ets>musta<hsdot/fi<zsdot/</ets> who trusts to another's keeping, a
soldier of a garrison.]</ety> <def>See <er>Army organization</er>,
above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mustaiba</ent><br/
<hw>Mus`ta*i"ba</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A close-grained,
heavy wood of a brownish color, brought from Brazil, and used in
turning, for making the handles of tools, and the like.</def>
<altsp>[Written also <asp>mostahiba</asp>.]</altsp>
<rj><au>MaElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustang</ent><br/
<hw>Mus"tang</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>muste<ntil/o</ets> belonging to the graziers, strayed, wild.]</ety>
<fld>(Zool.)</fld> <def>The half-wild horse of the plains in Mexico,
California, etc. It is small, hardy, and easily sustained.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mustard grape</b></col> <fld>(Bot.)</fld>, <cd>a species
of grape (<spn>Vitis candicans</spn>), native in Arkansas and Texas. The
berries are small, light-colored, with an acid skin and a sweet
pulp.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustard</ent><br/
<hw>Mus"tard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>moustarde</ets>, F. <ets>moutarde</ets>, fr. L. <ets>mustum</ets>
must, -- mustard was prepared for use by being mixed with
<ets>must</ets>. See <er>Must</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>The name of several cruciferous plants of the
genus <gen>Brassica</gen> (formerly <gen>Sinapis</gen>), as <stype>white
mustard</stype> (<spn>Brassica alba</spn>), <stype>black mustard</stype>
(<spn>Brassica Nigra</spn>), <stype>wild mustard</stype> or
<stype>charlock</stype> (<spn>Brassica Sinapistrum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are also many herbs of the same family which are
called <ex>mustard</ex>, and have more or less of the flavor of the true
mustard; as, bowyer's mustard (<spn>Lepidium ruderale</spn>); hedge
mustard (<spn>Sisymbrium officinale</spn>); Mithridate mustard
(<spn>Thlaspi arvense</spn>); tower mustard (<spn>Arabis
perfoliata</spn>); treacle mustard (<spn>Erysimum
cheiranthoides</spn>).</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A powder or a paste made from the seeds of black or
white mustard, used as a condiment and a rubefacient. Taken internally
it is stimulant and diuretic, and in large doses is emetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mustard oil</b></col> <fld>(Chem.)</fld>, <cd>a substance
obtained from mustard, as a transparent, volatile and intensely pungent
oil. The name is also extended to a number of analogous compounds
produced either naturally or artificially.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustee</ent><br/
<hw>Mus*tee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mestee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustela</ent><br/
<hw>Mustela</hw> <pos>prop. n.</pos> <def>The type genus of the family
<fam>Mustelidae:</fam> minks and weasels.</def><br/
<syn><b>Syn. --</b> genus <gen>Mustela</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mustelid</ent><br/
<hw>mustelid</hw> <pos>n.</pos> <def>A member of the
<fam>Mustelidae</fam>, fissiped fur-bearing carnivorous
mammals.</def><br/
<syn><b>Syn. --</b> musteline mammal, musteline.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mustelidae</ent><br/
<hw>Mustelidae</hw> <pos>prop. n.</pos> <def>A natural family of
fissiped fur-bearing carnivorous mammals including the weasels;
polecats; ferrets; minks; fishers; otters; badgers; skunks; wolverines;
and martens.</def><br/
<syn><b>Syn. --</b> family <fam>Mustelidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Musteline</ent><br/
<hw>Mus"te*line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mustelinus</ets>, fr. <ets>mustela</ets> weasel.]</ety>
<fld>(Zool.)</fld> <def>Like or pertaining to the family
<fam>Mustelidae</fam>, or the weasels and martens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustelus</ent><br/
<hw>Mustelus</hw> <pos>prop. n.</pos> <def>A genus of sharks including
certain of the smooth dogfishes.</def><br/
<syn><b>Syn. --</b> genus Mustelus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muster</ent><br/
<hw>Mus"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>moustre</ets>, OF. <ets>mostre</ets>, <ets>moustre</ets>, F.
<ets>montre</ets>, LL. <ets>monstra</ets>. See <er>Muster</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Something shown for imitation; a
pattern.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A show; a display.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An assembling or review of troops, as for parade,
verification of numbers, inspection, exercise, or introduction into
service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hurried <qex>muster</qex> of the soldiers of liberty.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>See how in warlike <qex>muster</qex> they appear,<br/
In rhombs, and wedges, and half-moons, and wings.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The sum total of an army when assembled for review
and inspection; the whole number of effective men in an army.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the <qex>muster</qex> was thirty thousands of men.</q>
<rj><qau>Wyclif.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye publish the <qex>musters</qex> of your own bands, and proclaim
them to amount of thousands.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Any assemblage or display; a gathering.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of the temporal grandees of the realm, mentof their wives and
daughters, the <qex>muster</qex> was great and splendid.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Muster book</b></col>, <cd>a book in which military
forces are registered.</cd> -- <col><b>Muster file</b></col>, <cd>a
muster roll.</cd> -- <col><b>Muster master</b></col> <fld>(Mil.)</fld>,
<cd>one who takes an account of troops, and of their equipment; a
mustering officer; an inspector.</cd> <mark>[Eng.]</mark> --
<col><b>Muster roll</b></col> <fld>(Mil.)</fld>, <cd>a list or register
of all the men in a company, troop, or regiment, present or accounted
for on the day of muster.</cd> -- <col><b>To pass muster</b></col>,
<cd>to pass through a muster or inspection without
censure.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Such excuses will not <qex>pass muster</qex> with God.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muster</ent><br/
<hw>Mus"ter</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mustered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mustering</conjf>.]</vmorph> <ety>[OE. <ets>mustren</ets>, prop.,
to show, OF. <ets>mostrer</ets>, <ets>mustrer</ets>,
<ets>moustrer</ets>, <ets>monstrer</ets>, F. <ets>montrer</ets>, fr. L.
<ets>monstrare</ets> to show. See <er>Monster</er>.]</ety> <sn>1.</sn>
<def>To collect and display; to assemble, as troops for parade,
inspection, exercise, or the like.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: To summon together; to enroll in service; to
get together.</def> <ldquo/Mustering <xex>all its force</xex>.<rdquo/
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All the gay feathers he could <qex>muster</qex>.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To muster troops into service</b></col>
<fld>(Mil.)</fld>, <cd>to inspect and enter troops on the muster roll of
the army.</cd> -- <col><b>To muster troops out of service</b></col>
<fld>(Mil.)</fld>, <cd>to register them for final payment and
discharge.</cd> -- <col><b>To muster up</b></col>, <cd>to gather up; to
succeed in obtaining; to obtain with some effort or
difficulty.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>One of those who can <qex>muster up</qex> sufficient sprightliness
to engage in a game of forfeits.</q> <rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muster</ent><br/
<hw>Mus"ter</hw>, <pos>v. i.</pos> <def>To be gathered together for
parade, inspection, exercise, or the like; to come together as parts of
a force or body; <as>as, his supporters <ex>mustered</ex> in
force</as>.</def> <ldquo/The <xex>mustering</xex> squadron.<rdquo/
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustily</ent><br/
<hw>Mus"ti*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>In a musty
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mustiness</ent><br/
<hw>Mus"ti*ness</hw>, <pos>n.</pos> <def>The quality or state of being
musty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Musty</ent><br/
<hw>Mus"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Mustier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Mustiest</adjf>.]</amorph> <ety>[From L. <ets>mustum</ets> must;
or perh. fr. E. <ets>moist</ets>. Cf. <er>Must</er>, <pos>n.</pos>,
<er>Moist</er>.]</ety> <sn>1.</sn> <def>Having the rank, pungent,
offensive odor and taste which substances of organic origin acquire
during warm, moist weather; foul or sour and fetid; moldy; <as>as,
<ex>musty</ex> corn; <ex>musty</ex> books.</as></def>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Spoiled by age; rank; stale.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The proverb is somewhat <qex>musty</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Dull; heavy; spiritless.</def> <ldquo/That he may
not grow <xex>musty</xex> and unfit for conversation.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutability</ent><br/
<hw>Mu`ta*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mutabilitas</ets>: cf. F. <ets>mutabilit<eacute/</ets>.]</ety>
<def>The quality of being mutable, or subject to change or alteration,
either in form, state, or essential character; susceptibility of change;
changeableness; inconstancy; variation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Plato confessed that the heavens and the frame of the world are
corporeal, and therefore subject to <qex>mutability</qex>.</q>
<rj><qau>Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutable</ent><br/
<hw>Mu"ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mutabilis</ets>, fr. <ets>mutare</ets> to change. See
<er>Move</er>.]</ety> <sn>1.</sn> <def>Capable of alteration; subject to
change; changeable in form, qualities, or nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Things of the most accidental and <qex>mutable</qex> nature.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Changeable; inconstant; unsettled; unstable;
fickle.</def> <ldquo/Most <xex>mutable</xex> wishes.<rdquo/
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Changeable; alterable; unstable; unsteady;
unsettled; wavering; inconstant; variable; fickle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutableness</ent><br/
<hw>Mu"ta*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
mutable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutably</ent><br/
<hw>Mu"ta*bly</hw>, <pos>adv.</pos> <def>Changeably.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutacism</ent><br/
<hw>Mu"ta*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Mytacism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutage</ent><br/
<hw>Mu"tage</hw> <pr>(m<umac/"t<asl/j)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A process for checking the fermentation of the must
of grapes.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 958 --></p>

<p><ent>mutagen</ent><br/
<hw>mu"ta*gen</hw> <pr>(m<umac/"t<adot/*j<ecr/n)</pr>, <pos>n.</pos>
<def>A chemical compound or other external influence (such as ionizing
radiation) which causes mutations{3}.</def><br/
[<source>PJC</source>]</p>

<p><ent>mutagenesis</ent><br/
<hw>mu`ta*gen"e*sis</hw>
<pr>(m<umac/`t<adot/*j<ecr/n"<esl/*s<icr/s)</pr>, <pos>n.</pos> <def>the
causing of a mutation or the occurrence of a mutation{3}.</def><br/
[<source>PJC</source>]</p>

<p><ent>mutagenicity</ent><br/
<hw>mu`ta*gen*i"ci*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the degree
or measure of the ability to cause mutation{3}; -- said of
mutagens.</def><br/
[<source>PJC</source>]</p>

<p><ent>mutandum</ent><br/
\'d8<hw>mu*tan"dum</hw> <pr>(m<usl/*t<acr/n"d<ucr/m)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Mutanda</plw>
<pr>(m<usl/*t<acr/n"d<adot/)</pr>.</plu> <ety>[L., fr. <ets>mutare</ets>
to change.]</ety> <def>A thing which is to be changed; something which
must be altered; -- used chiefly in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mutation</ent><br/
<hw>mu*ta"tion</hw> <pr>(m<usl/*t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>mutatio</ets>, fr. <ets>mutare</ets> to change: cf. F.
<ets>mutation</ets>. See <er>Mutable</er>.]</ety> <def>Change;
alteration, either in form or qualities.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vicissitude or <qex>mutations</qex> in the superior globe are
no fit matter for this present argument.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Gradual definitely tending
variation, such as may be observed in a group of organisms in the
fossils of successive geological levels.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <sd>(a)</sd> <def>As now employed
(first by <person>de Vries</person>), a cellular process resulting in a
sudden inheritable variation (the offspring differing from its parents
in some well-marked character or characters) as distinguished from a
gradual variation in which the new characters become fully developed
only in the course of many generations. The occurrence of mutations, the
selection of strains carrying mutations permitting enhanced survival
under prevailing conditions, and the mechanism of hereditary of the
characters so appearing, are well-established facts; whether and to what
extent the mutation process has played the most important part in the
evolution of the existing species and other groups of organisms is an
unresolved question.</def> <sd>(b)</sd> <def>The result of the above
process; a suddenly produced variation.</def> <note>Mutations can occur
by a change in the fundamental coding sequence of the hereditary
material, which in most organisms is DNA, but in some viruses is RNA. It
can also occur by rearrangement of an organism's chromosomes. Specific
mutations due to a change in DNA sequence have been recognized as
causing certain specific hereditary diseases. Certain processes which
produce variation in the genotype of an organism, such as sexual mixing
of chromosomes in offspring, or artificially induced recombination or
introduction of novel genetic material into an organism, are not
referred to as <ex>mutation</ex>.</note><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <fld>(Biol.)</fld> <def>a variant strain of an organism
in which the hereditary variant property is caused by a
mutation{3}.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mutative</ent><br/
<hw>mutative</hw> <pos>adj.</pos> <def>Of or pertaining to or marked by
genetic mutation{3}.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mutch</ent><br/
<hw>Mutch</hw> <pr>(much)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>mutse</ets> a cap, G. <ets>m<uum/tze</ets>. Cf. <er>Amice</er> a
cape.]</ety> <def>The close linen or muslin cap of an old woman.</def>
<mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutchkin</ent><br/
<hw>Mutch"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A liquid measure
equal to four gills, or an imperial pint.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mute</ent><br/
<hw>Mute</hw> <pr>(m<umac/t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>mutare</ets> to change. See <er>Molt</er>.]</ety> <def>To cast off;
to molt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have I <qex>muted</qex> all my feathers?</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mute</ent><br/
<hw>Mute</hw>, <pos>v. t. & i.</pos> <ety>[F. <ets>mutir</ets>,
<ets><eacute/meutir</ets>, OF. <ets>esmeltir</ets>, fr. OD.
<ets>smelten</ets>, prop., to melt. See <er>Smelt</er>.]</ety> <def>To
eject the contents of the bowels; -- said of birds.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mute</ent><br/
<hw>Mute</hw>, <pos>n.</pos> <def>The dung of birds.</def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mute</ent><br/
<hw>Mute</hw>, <pos>a.</pos> <ety>[L. <ets>mutus</ets>; cf. Gr.
<grk>my`ein</grk> to shut, Skr. <ets>m<umac/ta</ets> bound,
<ets>m<umac/ka</ets> dumb: cf. OE. <ets>muet</ets>, fr. F.
<ets>muet</ets>, a dim. of OF. <ets>mu</ets>, L.
<ets>mutus</ets>.]</ety> <sn>1.</sn> <def>Not speaking; uttering no
sound; silent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the heavenly choir stood <qex>mute</qex>,<br/
And silence was in heaven.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In law a prisoner is said to stand <xex>mute</xex>,
when, upon being arranged, he makes no answer, or does not plead
directly, or will not put himself on trial.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Incapable of speaking; dumb.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not uttered; unpronounced; silent; also, produced by
complete closure of the mouth organs which interrupt the passage of
breath; -- said of certain letters. See 5th <er>Mute</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not giving a ringing sound when struck; -- said of a
metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mute swan</b></col> <fld>(Zool.)</fld>, <cd>a European
wild white swan (<spn>Cygnus olor</spn> syn. <spn>Cygnus gibbus</spn>),
which produces no loud notes, in distinction from the <contr>Trumpeter
swan</contr>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<usage>
<p><syn><b>Syn.</b> -- Silent; dumb; speechless.</syn> --
<er>Mute</er>, <er>Silent</er>, <er>Dumb</er>. One is
<xex>silent</xex> who <xex>does</xex> not speak; one is <xex>dumb</xex>
who <xex>can</xex> not, for want of the proper organs; <as>as, a
<ex>dumb</ex> beast, etc.</as>; and hence, figuratively, we speak of a
person as struck <xex>dumb</xex> with astonishment, etc. One is
<xex>mute</xex> who is <xex>held back</xex> from speaking by some
special cause; <as>as, he was <ex>mute</ex> through fear; <ex>mute</ex>
astonishment, etc.</as> Such is the case with most of those who never
speak from childhood; they are not ordinarily <xex>dumb</xex>, but
<xex>mute</xex> because they are deaf, and therefore never learn to
talk; and hence their more appropriate name is
<xex>deaf-mutes</xex>.<br/
[<source>1913 Webster</source>]</p>

<p><q>They spake not a word;<br/
But, like <qex>dumb</qex> statues, or breathing stones,<br/
Gazed each on other.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All sat <qex>mute</qex>,<br/
Pondering the danger with deep thoughts.</q> <rj><qau>Milton.</qau></rj>
<br/
[<source>1913 Webster</source>]</p>
</usage>

<p><ent>Mute</ent><br/
<hw>Mute</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who does not speak,
whether from physical inability, unwillingness, or other cause.</def>
<specif>Specifically:</specif> <sd>(a)</sd> <def>One who, from deafness,
either congenital or from early life, is unable to use articulate
language; a deaf-mute.</def> <sd>(b)</sd> <def>A person employed by
undertakers at a funeral.</def> <sd>(c)</sd> <def>A person whose part in
a play does not require him to speak.</def> <sd>(d)</sd> <def>Among the
Turks, an officer or attendant who is selected for his place because he
can not speak.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phon.)</fld> <def>A letter which represents no
sound; a silent letter; also, a close articulation; an element of speech
formed by a position of the mouth organs which stops the passage of the
breath; <as>as, <stype>p</stype>, <stype>b</stype>, <stype>d</stype>,
<stype>k</stype>, <stype>t</stype></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A little utensil made of brass,
ivory, or other material, so formed that it can be fixed in an erect
position on the bridge of a violin, or similar instrument, in order to
deaden or soften the tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>muted</ent><br/
<hw>muted</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as <er>quiet</er>;
<as>as, the <ex>muted</ex> atmosphere of a church</as>. Opposite of
<ant>noisy</ant>.</def><br/
<syn><b>Syn. --</b> hushed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>softened; rendered less loud or harsh; -- of sounds
and instruments which produce sounds; <as>as, <ex>muted</ex>
trumpets</as>.</def><br/
<syn><b>Syn. --</b> dull, muffled, softened.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mute-hill</ent><br/
<hw>Mute"-hill`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Moot-hill</er>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutely</ent><br/
<hw>Mute"ly</hw>, <pos>adv.</pos> <def>Without uttering words or sounds;
in a mute manner; silently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muteness</ent><br/
<hw>Mute"ness</hw>, <pos>n.</pos> <def>The quality or state of being
mute; speechlessness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutessarif</ent><br/
<hw>Mu*tes`sa*rif"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk. & Ar.
<ets>mute<cced/arif</ets> freely disposing of anything, master.]</ety>
<def>In Turkey prior to the revolution, an administrative authority of
any of certain sanjaks. They were appointed directly by the
Sultan.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mutessarifat</ent><br/
<hw>Mu*tes`sa*ri*fat"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk. & Ar.
<ets>mute<cced/arifah</ets> office of a mutessarif.]</ety> <def>In
Turkey, a sanjak whose head is a mutessarif.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Muticous</ent><br/
<ent>Mutic</ent><br/
<mhw>{ <hw>Mu"tic</hw> <pr>(?)</pr>, <hw>Mu"ti*cous</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>muticus</ets>, for
<ets>mutilus</ets>. See <er>Mutilate</er>.]</ety> <fld>(Bot. &
Zool.)</fld> <def>Without a point or pointed process; blunt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutilate</ent><br/
<hw>Mu"ti*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mutilatus</ets>, p. p. of <ets>mutilare</ets> to mutilate, fr.
<ets>mutilus</ets> maimed; cf. Gr. <?/, <?/. Cf. <er>Mutton</er>.]</ety>
<sn>1.</sn> <def>Deprived of, or having lost, an important part;
mutilated.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having finlike appendages or
flukes instead of legs, as a cetacean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutilate</ent><br/
<hw>Mu"ti*late</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A cetacean,
or a sirenian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutilate</ent><br/
<hw>Mu"ti*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mutilated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mutilating</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To cut off or remove a limb or essential part of; to maim; to
cripple; to disfigure; to hack; <as>as, to <ex>mutilate</ex> the body, a
statue, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To destroy or remove a material part of, so as to
render imperfect; <as>as, to <ex>mutilate</ex> the orations of
Cicero</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Among the <qex>mutilated</qex> poets of antiquity, there is none
whose fragments are so beautiful as those of Sappho.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Mutilated gear</b></col>, <col><b>Mutilated
wheel</b></col></mcol> <fld>(Mach.)</fld>, <cd>a gear wheel from a
portion of whose periphery the cogs are omitted. It is used for giving
intermittent movements.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>mutilated</ent><br/
<hw>mutilated</hw> <pos>adj.</pos> <sn>1.</sn> <def>badly injured,
perhaps with amputation or permanent disfigurement; <as>as,
<ex>mutilated</ex> victims of the rocket attack</as>.</def><br/
<syn><b>Syn. --</b> maimed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>damaged, often deliberately; -- of compositions;
<as>as, a <ex>mutilated</ex> text</as>. Opposite of <ant>undamaged</ant>
or <ant>intact</ant>.</def><br/
<syn><b>Syn. --</b> mangled, mutilated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mutilation</ent><br/
<hw>Mu`ti*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mutilatio</ets>: cf. F. <ets>mutilation</ets>.]</ety> <def>The act
of mutilating, or the state of being mutilated; deprivation of a limb or
of an essential part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutilator</ent><br/
<hw>Mu"ti*la"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mutilateur</ets>.]</ety> <def>One who mutilates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutilous</ent><br/
<hw>Mu"ti*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>mutilus</ets>. See <er>Mutilate</er>.]</ety> <def>Mutilated;
defective; imperfect.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutine</ent><br/
<hw>Mu"tine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>mutin</ets>.]</ety> <def>A mutineer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutine</ent><br/
<hw>Mu"tine</hw>, <pos>v. i.</pos> <ety>[F. <ets>mutiner</ets>.]</ety>
<def>To mutiny.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutineer</ent><br/
<hw>Mu"ti*neer`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mutiny</er>.]</ety> <def>One guilty of mutiny.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muting</ent><br/
<hw>Mut"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dung of
birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutinous</ent><br/
<hw>Mu"ti*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Mutiny</er>.]</ety> <def>Disposed to mutiny; in a state of mutiny;
characterized by mutiny; seditious; insubordinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The city was becoming <qex>mutinous</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Mu"ti*nous*ly</wf>, <pos>adv.</pos> --
<wf>Mu"ti*nous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutiny</ent><br/
<hw>Mu"ti*ny</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mutinies</plw> <pr>(#)</pr>.</plu> <ety>[From <ets>mutine</ets> to
mutiny, fr. F. <ets>se mutiner</ets>, fr. F. <ets>mutin</ets> stubborn,
mutinous, fr. OF. <ets>meute</ets> riot, LL. <ets>movita</ets>, fr.
<ets>movitus</ets>, for L. <ets>motus</ets>, p. p. of <ets>movere</ets>
to move. See <er>Move</er>.]</ety> <sn>1.</sn> <def>Insurrection against
constituted authority, particularly military or naval authority;
concerted revolt against the rules of discipline or the lawful commands
of a superior officer; hence, generally, forcible resistance to rightful
authority; insubordination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In every <qex>mutiny</qex> against the discipline of the college,
he was the ringleader.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Violent commotion; tumult; strife.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To raise a <qex>mutiny</qex> betwixt yourselves.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mutiny act</b></col> <fld>(Law)</fld>, <cd>an English
statute reenacted annually to punish mutiny and desertion.</cd>
<rj><au>Wharton.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Insurrection</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutiny</ent><br/
<hw>Mu"ti*ny</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Mutinied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Mutinying</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To
rise against, or refuse to obey, lawful authority in military or naval
service; to excite, or to be guilty of, mutiny or mutinous conduct; to
revolt against one's superior officer, or any rightful
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall into strife; to quarrel.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutism</ent><br/
<hw>Mut"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition, state,
or habit of being mute, or without speech.</def> <rj><au>Max
M<uum/ller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutoscope</ent><br/
<hw>Mu"to*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mutare</ets> to change + <ets>-scope</ets>.]</ety> <def>A simple
form of moving-picture machine in which the series of views, exhibiting
the successive phases of a scene, are printed on paper and mounted
around the periphery of a wheel. The rotation of the wheel brings them
rapidly into sight, one after another, and the blended effect gives a
semblance of motion.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mutt</ent><br/
<hw>mutt</hw> <pos>n.</pos> <def>An dog that is of inferior quality or
of mixed breed.</def><br/
<syn><b>Syn. --</b> cur, mongrel.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mutter</ent><br/
<hw>Mut"ter</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Muttered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Muttering</conjf>.]</vmorph> <ety>[Prob. of imitative
origin; cf. L. <ets>muttire</ets>, <ets>mutire</ets>.]</ety> <sn>1.</sn>
<def>To utter words indistinctly or with a low voice and lips partly
closed; esp., to utter indistinct complaints or angry expressions; to
grumble; to growl.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wizards that peep, and that <qex>mutter</qex>.</q> <rj><qau>Is.
viii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Meantime your filthy foreigner will stare,<br/
And <qex>mutter</qex> to himself.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sound with a low, rumbling noise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thick lightnings flash, the <qex>muttering</qex> thunder
rolls.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutter</ent><br/
<hw>Mut"ter</hw>, <pos>v. t.</pos> <def>To utter with imperfect
articulations, or with a low voice; <as>as, to <ex>mutter</ex>
threats</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutter</ent><br/
<hw>Mut"ter</hw>, <pos>n.</pos> <def>Repressed or obscure
utterance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutterer</ent><br/
<hw>Mut"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mutters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutteringly</ent><br/
<hw>Mut"ter*ing*ly</hw>, <pos>adv.</pos> <def>With a low voice and
indistinct articulation; in a muttering manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutton</ent><br/
<hw>Mut"ton</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>motoun</ets>, OF. <ets>moton</ets>, <ets>molton</ets>, a sheep,
wether, F. <ets>mouton</ets>, LL. <ets>multo</ets>, by transposition of
<it>l</it> fr. L. <ets>mutilus</ets> mutilated. See
<er>Mutilate</er>.]</ety> <sn>1.</sn> <def>A sheep.</def>
<mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not so much ground as will feed a <qex>mutton</qex>.</q>
<rj><qau>Sir H. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Muttons</qex>, beeves, and porkers are good old words for the
living quadrupeds.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The flesh of a sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fat of roasted <qex>mutton</qex> or beef.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A loose woman; a prostitute.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Mutton bird</b></col> <fld>(Zool.)</fld>, <cd>the
Australian short-tailed petrel (<spn>Nectris brevicaudus</spn>).</cd> --
<col><b>Mutton chop</b></col>, <cd>a rib of mutton for broiling, with
the end of the bone at the smaller part chopped off.</cd> --
<col><b>Mutton fish</b></col> <fld>(Zool.)</fld>, <cd>the American
eelpout. See <er>Eelpout</er>.</cd> -- <col><b>Mutton fist</b></col>,
<cd>a big brawny fist or hand.</cd> <mark>[Colloq.]</mark>
<au>Dryden.</au> -- <col><b>Mutton monger</b></col>, <cd>a pimp.</cd>
<mark>[Low & Obs.]</mark> <au>Chapman.</au> -- <col><b>To return to
one's muttons</b></col>. <ety>[A translation of a phrase from a farce by
<person>De Brueys</person>, <ets>revenons <agrave/ nos moutons</ets> let
us return to our sheep.]</ety> <cd>To return to one's topic, subject of
discussion, etc.</cd> <mark>[Humorous]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I willingly <qex>return to my muttons</qex>.</q> <rj><qau>H. R.
Haweis.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>muttonfish</ent><br/
<hw>muttonfish</hw> <pos>n.</pos> <def>A fish (<spn>Lutjanus
analis</spn>) similar to and often marketed as <ldquo/red
snapper<rdquo/.</def><br/
<syn><b>Syn. --</b> mutton snapper, <spn>Lutjanus
analis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>muttonhead</ent><br/
<hw>muttonhead</hw> <pos>n.</pos> <def>A stupid or foolish person; a
dolt; a numbskull; a blockhead; -- disparaging and offensive. These
words are used to express a low opinion of someone's intelligence.</def>
<mark>[disparaging]</mark> <br/
<syn><b>Syn. --</b> dunce, dunderhead, numskull, blockhead, bonehead,
lunkhead, hammerhead, knucklehead, loggerhead, shithead,
fuckhead.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muttony</ent><br/
<hw>Mut"ton*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like mutton; having
a flavor of mutton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutual</ent><br/
<hw>Mu"tu*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>mutuel</ets>, L. <ets>mutuus</ets>, orig., exchanged, borrowed,
lent; akin to <ets>mutare</ets> to change. See <er>Mutable</er>.]</ety>
<sn>1.</sn> <def>Reciprocally acting or related; reciprocally receiving
and giving; reciprocally given and received; reciprocal; interchanged;
<as>as, a <ex>mutual</ex> love, advantage, assistance, aversion,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Conspiracy and <qex>mutual</qex> promise.</q> <rj><qau>Sir T.
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Happy in our <qex>mutual</qex> help,<br/
And <qex>mutual</qex> love.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A certain shyness on such subjects, which was <qex>mutual</qex>
between the sisters.</q> <rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Possessed, experienced, or done by two or more
persons or things at the same time; common; joint; <as>as,
<ex>mutual</ex> happiness; a <ex>mutual</ex> effort.</as></def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A vast accession of misery and woe from the <qex>mutual</qex>
weeping, and wailing, and gnashing of teeth.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ This use of <xex>mutual</xex> as synonymous with
<xex>common</xex> is inconsistent with the idea of interchange, or
reciprocal relation, which properly belongs to it; but the word has been
so used by many writers of high authority. The present tendency is
toward a careful discrimination.<br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Mutual</qex>, as Johnson will tell us, means something
reciprocal, a giving and taking. How could people have <qex>mutual</qex>
ancestors?</q> <rj><qau>P. Harrison.</qau></rj><br/
[<source>1913 Webster</source>]</p></note>

<p><cs><col><b>Mutual insurance</b></col>, <cd>agreement among a number
of persons to insure each other against loss, as by fire, death, or
accident.</cd> -- <col><b>Mutual insurance company</b></col>, <cd>one
which does a business of insurance on the mutual principle, the policy
holders sharing losses and profits <xex>pro rata</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reciprocal; interchanged; common.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutualism</ent><br/
<hw>Mu"tu*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Ethics)</fld>
<def>The doctrine of mutual dependence as the condition of individual
and social welfare.</def> <rj><au>F. Harrison.</au> <au>H. Spencer.</au>
<au>Mallock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mutualist</ent><br/
<hw>mutualist</hw> <pos>adj.</pos> <def>One practising or advocating the
doctrine of mutualism.</def><br/
<syn><b>Syn. --</b> interdependent, mutually beneficial.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mutuality</ent><br/
<hw>Mu`tu*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mutualit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The quality of
correlation; reciprocation; interchange; interaction;
interdependence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Reciprocity of consideration.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutually</ent><br/
<hw>Mu"tu*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a mutual
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mutual savings bank</ent><br/
<hw>mutual savings bank</hw> <pos>n.</pos> <def>a state-chartered
savings bank owned by its depositors and managed by a board of trustees.
Abbreviated <altname>MSB</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mutuary</ent><br/
<hw>Mu"tu*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mutuarius</ets> mutual.See <er>Mutuation</er>.]</ety>
<fld>(Law)</fld> <def>One who borrows personal chattels which are to be
consumed by him, and which he is to return or repay in kind.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutuation</ent><br/
<hw>Mu`tu*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mutuatio</ets>, fr. <ets>mutuare</ets>, <ets>mutuari</ets>, to
borrow, fr. <ets>mutuus</ets>. See <er>Mutual</er>.]</ety> <def>The act
of borrowing or exchanging.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mutule</ent><br/
<hw>Mu"tule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>mutulus</ets>.]</ety> <fld>(Arch.)</fld> <def>A projecting block
worked under the corona of the Doric corice, in the same situation as
the modillion of the Corinthian and Composite orders. See
<xex>Illust.</xex> of <er>Gutta</er>.</def> <rj><au>Oxf.
Gloss.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mux</ent><br/
<hw>Mux</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Mixen</er>.]</ety> <def>Dirt; filth; muck.</def> <mark>[Prov.
Eng.]</mark> <rj><au>ose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mux</ent><br/
<hw>Mux</hw>, <pos>v. t.</pos> <def>To mix in an untidy and offensive
way; to make a mess of.</def> <mark>[Prov. Eng.; Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muxy</ent><br/
<hw>Mux"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Soft; sticky, and
dirty.</def> <mark>[Prov. Eng.]</mark> <see>See
<er>Mucky</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzarab</ent><br/
<hw>Muz"a*rab</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>mozarabe</ets>, fr. Ar. <ets>mosta'rib</ets>, a name applied to
strange tribes living among the Arabs.]</ety> <fld>(Eccl. Hist.)</fld>
<def>One of a denomination of Christians formerly living under the
government of the Moors in Spain, and having a liturgy and ritual of
their own.</def> <altsp>[Written also <asp>Mozarab</asp>,
<asp>Mostarab</asp>.]</altsp> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzarabic</ent><br/
<hw>Muz`a*rab"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Muzarabs; <as>as, the <ex>Muzarabic</ex> liturgy</as>.</def>
<altsp>[Written also <asp>Mozarabic</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>muzjik</ent><br/
<hw>muzjik</hw> <pos>n.</pos> <def>A Russian peasant (especially prior
to 1917).</def><br/
<syn><b>Syn. --</b> muzhik, moujik, mujik.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Muzziness</ent><br/
<hw>Muz"zi*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being muzzy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzzle</ent><br/
<hw>Muz"zle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>mosel</ets>,
OF. <ets>musel</ets>, F. <ets>museau</ets> muzzle or snout, LL.
<ets>musellus</ets>, fr. <ets>musus</ets>, <ets>morsus</ets>. See
<er>Muse</er>, <pos>v. i.</pos>, and cf. <er>Morsel</er>.]</ety>
<sn>1.</sn> <def>The projecting mouth and nose of a quadruped, as of a
horse; a snout.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mouth of a thing; the end for entrance or
discharge; <as>as, the <ex>muzzle</ex> of a gun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fastening or covering (as a band or cage) for the
mouth of an animal, to prevent eating or vicious biting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With golden <qex>muzzles</qex> all their mouths were bound</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Muzzle sight</b></col>. <fld>(Gun.)</fld> <cd>See
<er>Dispart</er>, <pos>n.</pos>, 2.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzzle</ent><br/
<hw>Muz"zle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Muzzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Muzzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>museler</ets>.]</ety> <sn>1.</sn> <def>To bind the mouth of; to
fasten the mouth of, so as to prevent biting or eating; hence,
figuratively, to bind; to sheathe; to restrain from speech or action;
<as>as, the dictator <ex>muzzled</ex> all the newspapers</as>.</def>
<ldquo/My dagger <xex>muzzled</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt not <qex>muzzle</qex> the ox when he treadeth out the
corn.</q> <rj><qau>Deut. xxv. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fondle with the closed mouth.</def>
<mark>[Obs.]</mark> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzzle</ent><br/
<hw>Muz"zle</hw>, <pos>v. i.</pos> <def>To bring the mouth or muzzle
near.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bear <qex>muzzles</qex> and smells to him.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzzle-loader</ent><br/
<hw>Muz"zle-load`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A firearm
which receives its charge through the muzzle, as distinguished from one
which is loaded at the breech.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzzle-loading</ent><br/
<hw>Muz"zle-load`ing</hw>, <pos>a.</pos> <def>Receiving its charge
through the muzzle; <as>as, a <ex>muzzle-loading</ex>
rifle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Muzzy</ent><br/
<hw>Muz"zy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>muse</ets>.]</ety> <def>Absent-minded; dazed; muddled;
stupid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole company stared at me with a whimsical, <qex>muzzy</qex>
look, like men whose senses were a little obfuscated by beer rather than
wine.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>MVP</ent><br/
<hw>MVP</hw> <pos>n.</pos> <mark>(acron.)</mark> <def>most valuable
player; the player judged to be the most important to the sport, also
the name of the award given to that player.</def>
<mark>[abbreviation]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mx</ent><br/
<hw>Mx</hw> <pos>prop. n.</pos> <def>The symbol for the
<sig>maxwell</sig>, a cgs unit of magnetic flux.</def><br/
<syn><b>Syn. --</b> maxwell.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>My</ent><br/
<hw>My</hw> <pr>(m<imac/)</pr>, <pos>a. & poss. pron.</pos> <ety>[OE.
<ets>mi</ets>, fr. <ets>min</ets>. See <er>Mine</er>, and cf., for loss
of <it>n</it>, <er>A</er>, <pos>a.</pos>, <er>An</er>,
<pos>a.</pos>]</ety> <def>Of or belonging to me; -- used always
attributively; <as>as, <ex>my</ex> body; <ex>my</ex> book</as>; --
<xex>mine</xex> is used in the predicate; <as>as, the book is
<ex>mine</ex></as>. See <er>Mine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mya</ent><br/
\'d8<hw>My"a</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L.
<ets>mya</ets> a kind of mussel.]</ety> <fld>(Zool.)</fld> <def>A genus
of bivalve mollusks, including the common long, or soft-shelled,
clam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myaceae</ent><br/
<hw>Myaceae</hw> <pos>prop. n.</pos> <def>An order of clams.</def><br/
<syn><b>Syn. --</b> order <ord>Myaceae</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myacidae</ent><br/
<hw>Myacidae</hw> <pos>prop. n.</pos> <def>A natural family of
soft-shell clams.</def><br/
<syn><b>Syn. --</b> family <fam>Myacidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myadestes</ent><br/
<hw>Myadestes</hw> <pos>prop. n.</pos> <def>A genus of birds including
the solitaires, thrushes noted for their beautiful songs.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myalgia</ent><br/
\'d8<hw>My*al"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ muscle + <?/ pain.]</ety> <fld>(Med.)</fld> <def>Pain in the
muscles; muscular rheumatism or neuralgia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myall wood</ent><br/
<hw>My*all" wood`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>A durable,
fragrant, and dark-colored Australian wood, used by the natives for
spears. It is obtained from the small tree <spn>Acacia
homolophylla</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myaria</ent><br/
\'d8<hw>My*a"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>A division of bivalve mollusks of which the
common clam (<gen>Mya</gen>) is the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycelium</ent><br/
\'d8<hw>My*ce"li*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>my`khs</grk> a mushroom.]</ety> <fld>(Bot.)</fld> <def>The white
threads or filamentous growth from which a mushroom or fungus is
developed; the so-called mushroom spawn.</def> --
<wordforms><wf>My*ce"li*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myceloid</ent><br/
<hw>Myc"e*loid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Mycel</ets>ium + <ets>-oid</ets>.]</ety> <fld>(Bot.)</fld>
<def>Resembling mycelium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycetes</ent><br/
\'d8<hw>My*ce"tes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>mykhth`s</grk> a bellower, fr. <grk>myka^sqai</grk> to
bellow.]</ety> <fld>(Zool.)</fld> <def>A genus of South American
monkeys, including the howlers. See <er>Howler</er>, 2, and
<xex>Illust.</xex></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycetoid</ent><br/
<hw>Myc"e*toid</hw> <pr>(?)</pr>, <ety>[Gr. <grk>my`khs</grk>,
<grk>my`khtos</grk>, a fungus + <ets>-oid</ets>.]</ety>
<fld>(Bot.)</fld> <def>Resembling a fungus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycetozoa</ent><br/
\'d8<hw>My*ce`to*zo"a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.;
Gr. <grk>my`khs</grk>, <grk>my`khtos</grk>, fungus + <?/ pl. of
<grk>zw^,on</grk> an animal.]</ety> <fld>(Zool.)</fld> <def>The
Myxomycetes; -- so called by those who regard them as a class of
animals.</def> -- <wordforms><wf>My*ce`to*zo"an</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>mycobacteria</ent><br/
<hw>mycobacteria</hw> <pos>n. pl.</pos> <def>A group of rod-shaped
bacteria, some saprophytic or causing diseases.</def><br/
<syn><b>Syn. --</b> mycobacterium.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mycobacterium</ent><br/
<hw>mycobacterium</hw> <pos>n.</pos>; <plu><it>pl.</it>
<plw>mycobacteria</plw> <pr>(#)</pr>.</plu> <def>Any of various
rod-shaped bacteria, some saprophytic or causing diseases.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mycoderma</ent><br/
\'d8<hw>my`co*der"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>my`khs</grk> a fungus + <grk>de`rma</grk> skin.]</ety>
<sn>1.</sn> <fld>(Biol.)</fld> <def>One of the forms in which bacteria
group themselves; a more or less thick layer of motionless but living
bacteria, formed by the bacteria uniting on the surface of the fluid in
which they are developed. This production differs from the zoogloea
stage of bacteria by not having the intermediary mucous
substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>(Capitalized)</mark> <def>A genus of microorganisms
of which the acetic ferment (<spn>Mycoderma aceti</spn>), which converts
alcoholic fluids into vinegar, is a representative. Cf.
<er>Mother</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycological</ent><br/
<ent>Mycologic</ent><br/
<mhw>{ <hw>My`co*log"ic</hw> <pr>(?)</pr>, <hw>My`co*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or relating to mycology, or
the fungi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycologist</ent><br/
<hw>My*col"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
versed in, or who studies, mycology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycology</ent><br/
<hw>My*col"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>my`khs</grk> fungus + <ets>-logy</ets>.]</ety> <def>That branch of
botanical science which relates to the mushrooms and other
fungi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycomelic</ent><br/
<hw>My`co*mel"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. (spurious)
<grk>my^kos</grk> mucus (L. <ets>mucus</ets>) + <grk>me`li</grk>
honey.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or designating, a
complex nitrogenous acid of the alloxan group, obtained as a
honey-yellow powder. Its solutions have a gelatinous
consistency.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycoprotein</ent><br/
<hw>My`co*pro"te*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
(spurious) <grk>my^kos</grk> mucus (L. <ets>mucus</ets>) + E.
<ets>protein</ets>.]</ety> <fld>(Biol.)</fld> <def>The protoplasmic
matter of which bacteria are composed.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycose</ent><br/
<hw>My"cose</hw> <pr>(m<imac/"k<omac/s)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>my`khs</grk> a mushroom.]</ety> <fld>(Chem.)</fld> <def>A variety
of sugar, isomeric with sucrose and obtained from certain lichens and
fungi. Called also <altname>trehalose</altname>.</def> <altsp>[Written
also <asp>mykose</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 959 --></p>

<p><ent>Mycothrix</ent><br/
\'d8<hw>Myc"o*thrix</hw> <pr>(m<imac/k"<osl/*thr<icr/ks)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. (spurious) <grk>my`khs</grk> mucus (L.
<ets>mucus</ets>) + <grk>qri`x</grk>, <grk>tricho`s</grk>, hair.]</ety>
<fld>(Biol.)</fld> <def>The chain of micrococci formed by the division
of the micrococci in multiplication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mycteria</ent><br/
<hw>Mycteria</hw> <pos>prop. n.</pos> <def>A genus of birds including
certain of the wood ibises, including the endangered <spn>Mycteria
americana</spn>; it is sometimes assigned to a subfamily
<subfam>Mycteriinae</subfam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Mycteria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mydaleine</ent><br/
<hw>My*da"le*ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>myda^n</grk> to be clammy (from decay).]</ety> <fld>(Physiol.
Chem.)</fld> <def>A toxic alkaloid (ptomaine) obtained from putrid flesh
and from herring brines. As a poison it is said to execute profuse
diarrhoea, vomiting, and intestinal inflammation.</def>
<rj><au>Brieger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mydatoxin</ent><br/
<hw>Myd`a*tox"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>myda^n</grk> to be clammy (from decay) + <ets>tox</ets>ic +
<ets>in</ets>.]</ety> <fld>(Physiol. Chem.)</fld> <def>A poisonous amido
acid, <chform>C6H13NO2</chform>, separated by Brieger from decaying
horseflesh. In physiological action, it is similar to curare.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mydaus</ent><br/
\'d8<hw>Myd"a*us</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>myda^n</grk> to be clammy or damp.]</ety> <fld>(Zool.)</fld>
<def>The teledu.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mydriasis</ent><br/
\'d8<hw>My*dri"a*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <fld>(Physiol. & Med.)</fld> <def>A long-continued or
excessive dilatation of the pupil of the eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mydriatic</ent><br/
<hw>Myd`ri*at"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
dilatation of the pupil.</def> -- <def2><pos>n.</pos> <def>A mydriatic
medicine or agent, as belladonna.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myelencephala</ent><br/
\'d8<hw>My`e*len*ceph"a*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Myelencephalon</er>.]</ety> <fld>(Zool.)</fld>
<def>Same as <er>Vertebrata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myelencephalic</ent><br/
<hw>My`e*len`ce*phal"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to the myelencephalon;
cerebro-spinal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myelencephalon</ent><br/
\'d8<hw>My`e*len*ceph"a*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
from Gr. <grk>myelo`s</grk> marrow + E. <ets>encephalon</ets>.]</ety>
<fld>(Anat.)</fld> <sd>(a)</sd> <def>The brain and spinal cord; the
cerebro-spinal axis. Sometimes abbreviated to
<altname>myelencephal</altname>.</def> <sd>(b)</sd> <def>The
metencephalon.</def> <rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myelencephalous</ent><br/
<hw>My`e*len*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Myelencephala.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myeline</ent><br/
<ent>myelin</ent><br/
<mhw><hw>my"e*lin</hw>, <hw>my"e*line</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>myelo`s</grk> marrow.]</ety> <fld>(Physiol.
Chem.)</fld> <sd>(a)</sd> <def>A soft white substance constituting the
medullary sheaths of nerve fibers, and composed mainly of cholesterin,
lecithin, cerebrin, protein, and some fat.</def> <sd>(b)</sd> <def>One
of a group of phosphorized principles occurring in nerve tissue, both in
the brain and nerve fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myelinic</ent><br/
<hw>myelinic</hw> <pos>adj.</pos> <def>Of or pertaining to
myelin.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myelitis</ent><br/
\'d8<hw>My`e*li"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<grk>myelo`s</grk> marrow + <ets>-itis</ets>.]</ety> <fld>(Med.)</fld>
<sn>1.</sn> <def>Inflammation of the spinal marrow or its
membranes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Inflammation of bone marrow.</def><br/
[<source>PJC</source>]</p>

<p><ent>Myelocoele</ent><br/
<hw>My"e*lo*coele`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>myelo`s</grk> marrow + <grk>koi^los</grk> hollow.]</ety>
<fld>(Anat.)</fld> <def>The central canal of the spinal cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myelofibrosis</ent><br/
<hw>myelofibrosis</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>Fibrosis of
the bone marrow.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myelogenic</ent><br/
<hw>My`e*lo*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>myelo`s</grk> marrow + the root of <grk>gi`gnesqai</grk> to be
born.]</ety> <fld>(Physiol.)</fld> <def>Derived from, or pertaining to,
the bone marrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myeloid</ent><br/
<hw>My"e*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>myelo`s</grk> marrow + <ets>-oid</ets>.]</ety> <def>Resembling
marrow in appearance or consistency; <as>as, a <ex>myeloid</ex>
tumor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myeloidin</ent><br/
<hw>My`e*loid"in</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Myelin</ets> + <ets>-oid</ets> + <ets>-in</ets>.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A substance, present in the protoplasm
of the retinal epithelium cells, and resembling, if not identical with,
the substance (<xex>myelin</xex>) forming the medullary sheaths of nerve
fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myelon</ent><br/
\'d8<hw>My"e*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>myelo`s</grk> marrow.]</ety> <fld>(Anat.)</fld> <def>The spinal
cord. (Sometimes abbrev. to <abbr>myel.</abbr>)</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myelonal</ent><br/
<hw>My"e*lo`nal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the myelon; <as>as, the <ex>myelonal</ex>, or
spinal, nerves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myeloneura</ent><br/
\'d8<hw>My`e*lo*neu"ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>myelo`s</grk> + <grk>ney^ron</grk> a nerve.]</ety>
<fld>(Zool.)</fld> <def>The Vertebrata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myeloplax</ent><br/
\'d8<hw>My*el"o*plax</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
E. <plw>Myeloplaxes</plw> <pr>(#)</pr>, L. <plw>Myeloplaces</plw>
<pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <grk>myelo`s</grk> marrow + <?/
anything flat and broad.]</ety> <fld>(Anat.)</fld> <def>One of the huge
multinucleated cells found in the marrow of bone and occasionally in
other parts; a giant cell. See <er>Osteoclast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mygale</ent><br/
\'d8<hw>Myg"a*le</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., a
field mouse, Gr. <?/.]</ety> <fld>(Zool.)</fld> <def>A genus of very
large hairy spiders of the family <fam>Ctenizidae</fam>, having four
lungs and only four spinnerets. They do not spin webs, but usually
construct tubes in the earth, which are often furnished with a trapdoor.
The South American bird spider (<spn>Mygale avicularia</spn>), and the
crab spider, or matoutou (<spn>Mygale cancerides</spn>) are among the
largest species. They are also called <altname>trapdoor
spiders</altname>. Some of the species are erroneously called
<xex>tarantulas</xex>, as the Texas tarantula (<spn>Mygale
Hentzii</spn>).</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Mykiss</ent><br/
<hw>My"kiss</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Russ.
<ets>muikize</ets>, prob. fr. a native name.]</ety> <fld>(Zool.)</fld>
<def>A salmon (<spn>Salmo mykiss</spn>, syn. <spn>Salmo
purpuratus</spn>) marked with black spots and a red throat, found in
most of the rivers from Alaska to the Colorado River, and in Siberia; --
called also <altname>black-spotted trout</altname>, <altname>cutthroat
trout</altname>, and <altname>redthroat trout</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Mylitta</ent><br/
<hw>Mylitta</hw> <pos>prop. n.</pos> <fld>(Babylonian and Assyrian
Mythology)</fld> <def>The goddess of love and fertility and war; also
called <altname>Ishtar</altname>; the counterpart of
<persfn>Ashtoreth</persfn> and <persfn>Astarte</persfn>.</def><br/
<syn><b>Syn. --</b> Ishtar.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mylodon</ent><br/
<hw>Myl"o*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a mill +
<grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, a tooth.]</ety>
<fld>(Paleon.)</fld> <def>An extinct genus of large slothlike American
edentates, allied to Megatherium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mylodontidae</ent><br/
<hw>Mylodontidae</hw> <pos>n.</pos> <def>A natural family of extinct
South American edentates.</def><br/
<syn><b>Syn. --</b> family <fam>Mylodontidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mylohyoid</ent><br/
<hw>My`lo*hy"oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ the
molar teeth + E. <ets>hyoid</ets>.]</ety> <fld>(Anat.)</fld>
<def>Pertaining to, or in the region of, the lower jaw and the hyoid
apparatus; <as>as, the <ex>mylohyoid</ex> nerve</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mynah</ent><br/
<ent>myna</ent><br/
<mhw><hw>my"na</hw>, <hw>my"nah</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[See <er>Mino bird</er>.]</ety> <fld>(Zool.)</fld> <def>Any one of
numerous species of Asiatic starlings of the genera
<gen>Acridotheres</gen>, <gen>Sturnopastor</gen>, <gen>Sturnia</gen>,
<gen>Gracula</gen>, and allied genera. In habits they resemble the
European starlings, and like them are often caged and taught to talk.
See <cref>Hill myna</cref>, under <er>Hill</er>, and <er>Mino
bird</er>.</def> <altsp>[Spelt also <asp>mynah</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mynchen</ent><br/
<hw>Myn"chen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>mynecen</ets>, fr. <ets>munec</ets> monk. See <er>Monk</er>.]</ety>
<def>A nun.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mynchery</ent><br/
<hw>Myn"cher*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A nunnery; -- a
term still applied to the ruins of certain nunneries in
England.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mynheer</ent><br/
<hw>Myn*heer"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>mijnheer</ets>.]</ety> <def>The Dutch equivalent of <sig>Mr.</sig>
or <sig>Sir</sig>; hence, a Dutchman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myo-</ent><br/
<hw>my"o-</hw> <pr>(?)</pr>. <def>A combining form of Gr. <?/, <?/, a
<xex>muscle</xex>; <as>as, <ex>myo</ex>graph,
<ex>myo</ex>chrome</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myocardial</ent><br/
<hw>myocardial</hw> <pos>adj.</pos> <def>Of or pertaining to the
myocardium.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>myocarditis</ent><br/
\'d8<hw>my`o*car*di"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. see
<er>myocardium</er>.]</ety> <fld>(Med.)</fld> <def>Inflammation of the
myocardium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myocardium</ent><br/
\'d8<hw>My`o*car"di*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/, <?/, muscle + <?/ heart.]</ety> <fld>(Anat.)</fld> <def>The
main substance of the muscular wall of the heart inclosed between the
epicardium and endocardium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myochrome</ent><br/
<hw>My"o*chrome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
Gr. <?/ color.]</ety> <fld>(Physiol.)</fld> <def>A colored albuminous
substance in the serum from red-colored muscles. It is identical with
hemoglobin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myocomma</ent><br/
\'d8<hw>My`o*com"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
L. <plw>Myocommata</plw> <pr>(#)</pr>, E. <plw>Myocommas</plw>
<pr>(#)</pr>.</plu> <ety>[NL. See <er>Myo-</er>, and
<er>Comma</er>.]</ety> <fld>(Anat.)</fld> <def>A myotome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myodynamics</ent><br/
<hw>My`o*dy*nam"ics</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Myo-</ets> + <ets>dynamics</ets>.]</ety>
<fld>(Physiol.)</fld> <def>The department of physiology which deals with
the principles of muscular contraction; the exercise of muscular force
or contraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myodynamiometer</ent><br/
<hw>My`o*dy*na`mi*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
myodynamometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myodynamometer</ent><br/
<hw>My`o*dy`na*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Myo-</ets> + E. <ets>dynamometer</ets>.]</ety>
<fld>(Physiol.)</fld> <def>An instrument for measuring the muscular
strength of man or of other animals; a dynamometer.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myoepithelial</ent><br/
<hw>My`o*ep`i*the"li*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Myo-</ets> + <ets>epithelial</ets>.]</ety> <sn>1.</sn>
<fld>(Biol.)</fld> <def>Derived from epithelial cells and destined to
become a part of the muscular system; -- applied to structural elements
in certain embryonic forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having the characteristics of
both muscle and epithelium; <as>as, the <ex>myoepithelial</ex> cells of
the hydra</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myogalid</ent><br/
<hw>My*og"a*lid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
Gr. <?/ a weasel.]</ety> <fld>(Zool.)</fld> <def>One of the
<fam>Myogalodae</fam>, a family of Insectivora, including the desman,
and allied species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myogram</ent><br/
<hw>My"o*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
<ets>-gram</ets>.]</ety> <fld>(Physiol.)</fld> <def>See <cref>Muscle
curve</cref>, under <er>Muscle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myograph</ent><br/
<hw>My"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
<ets>-graph</ets>.]</ety> <fld>(Physiol.)</fld> <def>An instrument for
determining and recording the different phases, as the intensity,
velocity, etc., of a muscular contraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myographical</ent><br/
<ent>Myographic</ent><br/
<mhw>{ <hw>My`o*graph"ic</hw> <pr>(?)</pr>, <hw>My`o*graph"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to
myography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myography</ent><br/
<hw>My*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>myographie</ets>.]</ety> <def>The description of muscles, including
the study of muscular contraction by the aid of registering apparatus,
as by some form of myograph; myology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myohaematin</ent><br/
<hw>My`o*haem"a*tin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Myo-</ets> + <ets>haematin</ets>.]</ety>
<fld>(Physiol.)</fld> <def>A red-colored respiratory pigment found
associated with hemoglobin in the muscle tissue of a large number of
animals, both vertebrate and invertebrate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myoid</ent><br/
<hw>My"oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Myo-</ets> +
<ets>-oid</ets>.]</ety> <def>Composed of, or resembling, muscular
fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myolemma</ent><br/
\'d8<hw>My`o*lem"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, <?/, a muscle + <?/ skin.]</ety> <fld>(Anat.)</fld>
<def>Sarcolemma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myolin</ent><br/
<hw>My"o*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/,
muscle.]</ety> <fld>(Physiol.)</fld> <def>The essential material of
muscle fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myological</ent><br/
<ent>Myologic</ent><br/
<mhw>{ <hw>My`o*log"ic</hw> <pr>(?)</pr>, <hw>My`o*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to
myology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myologist</ent><br/
<hw>My*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled in
myology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myology</ent><br/
<hw>My*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
<ets>-logy</ets>: cf. F. <ets>myologie</ets>.]</ety> <def>That part of
anatomy which treats of muscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myoma</ent><br/
\'d8<hw>My*o"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Myo-</er>, and <er>-oma</er>.]</ety> <fld>(Med.)</fld> <def>A tumor
consisting of muscular tissue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myomancy</ent><br/
<hw>My"o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>my^s</grk> mouse + <ets>-mancy</ets>.]</ety> <def>Divination by the
movements of mice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myomorph</ent><br/
<hw>My"o*morph</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the
Myomorpha.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myomorpha</ent><br/
\'d8<hw>My`o*mor"pha</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>my^s</grk>, <grk>myo`s</grk>, a mouse + <grk>morfh`</grk>
form.]</ety> <fld>(Zool.)</fld> <def>An extensive group of rodents which
includes the rats, mice, jerboas, and many allied forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopathia</ent><br/
\'d8<hw>My`o*pa*thi"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/, <?/, a muscle + <?/, <?/, to suffer.]</ety> <fld>(Med.)</fld>
<def>Any affection of the muscles or muscular system.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopathic</ent><br/
<hw>My`o*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Of or pertaining to myopathia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopathy</ent><br/
<hw>My*op"a*thy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Myopathia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myope</ent><br/
<hw>My"ope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Gr. <?/, <?/;
<?/ to close, shut the eyes + <?/, <?/, the eye.]</ety> <def>A person
having myopia; a myops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myophan</ent><br/
<hw>My"o*phan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
Gr. <?/ to show.]</ety> <fld>(Zool.)</fld> <def>A contractile striated
layer found in the bodies and stems of certain Infusoria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopia</ent><br/
<hw>My*o"pi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Myope</er>.]</ety> <fld>(Med.)</fld> <def>Nearsightedness;
shortsightedness; a condition of the eye in which the rays from distant
object are brought to a focus before they reach the retina, and hence
form an indistinct image; while the rays from very near objects are
normally converged so as to produce a distinct image. It is corrected by
the use of a concave lens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopic</ent><br/
<hw>My*op"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
affected with, or characterized by, myopia; nearsighted.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Myopic astigmatism</b></col>, <cd>a condition in which
the eye is affected with myopia in one meridian only.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myops</ent><br/
\'d8<hw>My"ops</hw> <pr>(m<imac/"<ocr/ps)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <def>See <er>Myope</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopsis</ent><br/
\'d8<hw>My*op"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ fly + <?/ sight.]</ety> <fld>(Med.)</fld> <def>The appearance of
<cref>muscae volitantes</cref>. See <cref>Muscae volitantes</cref>,
under <er>Musca</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myopy</ent><br/
<hw>My"o*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>myopie</ets>.]</ety> <fld>(Med.)</fld> <def>Myopia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myosin</ent><br/
<hw>My"o*sin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>my^s</grk>,
<grk>myo`s</grk> a muscle.]</ety> <fld>(Physiol. Chem.)</fld> <def>A
protein present in muscle, serving as the principle contractile protein
in muscle contraction.</def> <note>It was earlier considered as being
formed in the process of coagulation which takes place in <er>rigor
mortis</er>. See <cref>Muscle plasma</cref>, under
<er>Plasma</er>.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ Myosin belongs to the group of globulins. It is
insoluble in water, but soluble in dilute solution of salt, and is
especially characterized by being completely precipitated by saturation
of its solutions with salt.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myosis</ent><br/
\'d8<hw>My*o"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
to close the eyes or lips.]</ety> <fld>(Med.)</fld> <def>Long-continued
contraction of the pupil of the eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myositic</ent><br/
<hw>My`o*sit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Myotic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myositis</ent><br/
\'d8<hw>My`o*si"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, <?/, muscle + <ets>-itis</ets>.]</ety> <fld>(Med.)</fld>
<def>Inflammation of the muscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myosotis</ent><br/
\'d8<hw>My`o*so"tis</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.;
Gr. <?/, lit., mouse ear.]</ety> <fld>(Bot.)</fld> <def>A genus of
plants. See <er>Mouse-ear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myotic</ent><br/
<hw>My*ot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Myosis</er>.]</ety> <fld>(Med.)</fld> <def>Producing myosis, or
contraction of the pupil of the eye, as opium, calabar bean, etc.</def>
-- <def2><pos>n.</pos> <def>A myotic agent.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myotome</ent><br/
<hw>My"o*tome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Myotomy</er>.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd> <def>A muscular
segment; one of the zones into which the muscles of the trunk,
especially in fishes, are divided; a myocomma.</def> <sd>(b)</sd>
<def>One of the embryonic muscular segments arising from the
protovertebrae; also, one of the protovertebrae themselves.</def>
<sd>(c)</sd> <def>The muscular system of one metamere of an
articulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myotomic</ent><br/
<hw>My`o*tom"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to a myotome or myotomes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myotomy</ent><br/
<hw>My*ot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myo-</ets> +
Gr. <?/ to cut: cf. F. <ets>myotomie</ets>.]</ety> <def>The dissection,
or that part of anatomy which treats of the dissection, of
muscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrcia</ent><br/
\'d8<hw>Myr"ci*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Bot.)</fld> <def>A large genus of tropical American trees and
shrubs, nearly related to the true myrtles (<gen>Myrtus</gen>), from
which they differ in having very few seeds in each berry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myria-</ent><br/
<hw>Myr"i*a-</hw> <pr>(?)</pr>. <ety>[Gr. <?/ a myriad. See
<er>Myriad</er>.]</ety> <def>A prefix, esp. in the metric system,
indicating <sig>ten thousand</sig>, <sig>ten thousand times</sig>;
<as>as, <ex>myria</ex>meter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriacanthous</ent><br/
<hw>Myr`i*a*can"thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
numberless + <grk>'a`kanqa</grk> a spine.]</ety> <fld>(Zool.)</fld>
<def>Having numerous spines, as certain fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriad</ent><br/
<hw>Myr"i*ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/, fr.
<?/ numberless, pl. <?/ ten thousand: cf. F. <ets>myriade</ets>.]</ety>
<sn>1.</sn> <def>The number of ten thousand; ten thousand persons or
things.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An immense number; a very great many; an
indefinitely large number.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriad</ent><br/
<hw>Myr"i*ad</hw>, <pos>a.</pos> <def>Consisting of a very great, but
indefinite, number; <as>as, <ex>myriad</ex> stars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriagramme</ent><br/
<ent>Myriagram</ent><br/
<mhw>{ <hw>Myr"i*a*gram</hw>, <hw>Myr"i*a*gramme</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>myriagramme</ets>. See
<er>Myria-</er>, and 3d <er>Gram</er>.]</ety> <def>A metric weight,
consisting of ten thousand grams or ten kilograms. It is equal to 22.046
lbs. avoirdupois.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrialitre</ent><br/
<ent>Myrialiter</ent><br/
<mhw>{ <hw>Myr"i*a*li`ter</hw>, <hw>Myr"i*a*li`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>myrialitre</ets>. See
<er>Myria-</er>, and <er>Liter</er>.]</ety> <def>A metric measure of
capacity, containing ten thousand liters. It is equal to 2641.7 wine
gallons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriametre</ent><br/
<ent>Myriameter</ent><br/
<mhw>{ <hw>Myr"i*a*me`ter</hw>, <hw>Myr"i*a*me`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>myriam<egrave/tre</ets>. See
<er>Myria-</er>, and <er>Meter</er>.]</ety> <def>A metric measure of
length, containing ten thousand meters. It is equal to 6.2137
miles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriapod</ent><br/
<hw>Myr"i*a*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>myriapode</ets>.]</ety> <fld>(Zool.)</fld> <def>One of the
<class>Myriapoda</class>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriapoda</ent><br/
\'d8<hw>Myr`i*ap"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ numberless + <ets>-poda</ets>.]</ety> <fld>(Zool.)</fld>
<def>A class, or subclass, of arthropods, related to the hexapod
insects, from which they differ in having the body made up of numerous
similar segments, nearly all of which bear true jointed legs. They have
one pair of antennae, three pairs of mouth organs, and numerous
tracheae, similar to those of true insects. The larvae, when first
hatched, often have but three pairs of legs. See <er>Centiped</er>,
<er>Galleyworm</er>, <er>Milliped</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The existing Myriapoda are divided into three orders:
<ord>Chilopoda</ord>, <ord>Chilognatha</ord> or <ord>Diplopoda</ord>,
and <ord>Pauropoda</ord> (see these words in the Vocabulary). Large
fossil species (very different from any living forms) are found in the
Carboniferous formation.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriarch</ent><br/
<hw>Myr"i*arch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, <?/; <?/
ten thousand + <?/ chief.]</ety> <def>A captain or commander of ten
thousand men.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriare</ent><br/
<hw>Myr"i*are</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Myria-</er>, and 2d <er>Are</er>.]</ety> <def>A measure of surface
in the metric system containing ten thousand ares, or one million square
meters. It is equal to about 247.1 acres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrica</ent><br/
\'d8<hw>My*ri"ca</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., fr.
Gr. <?/ tamarisk.]</ety> <fld>(Bot.)</fld> <def>A widely dispersed genus
of shrubs and trees, usually with aromatic foliage. It includes the
bayberry or wax myrtle, the sweet gale, and the North American sweet
fern, so called.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myricin</ent><br/
<hw>Myr"i*cin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>myricine</ets>. Prob. so called from a fancied resemblance to the
wax of the bayberry (<gen>Myrica</gen>).]</ety> <fld>(Chem.)</fld>
<def>A silky, crystalline, waxy substance, forming the less soluble part
of beeswax, and regarded as a palmitate of a higher alcohol of the
paraffin series; -- called also <altname>myricyl
alcohol</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myricyl</ent><br/
<hw>Myr"i*cyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Myric</ets>in
+ <ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A hypothetical radical
regarded as the essential residue of myricin; -- called also
<altname>melissyl</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriological</ent><br/
<hw>Myr`i*o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
relating to a myriologue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriologist</ent><br/
<hw>Myr`i*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
composes or sings a myriologue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriologue</ent><br/
<hw>Myr"i*o*logue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>myriologue</ets>, <ets>myriologie</ets>, NGr. <?/, <?/, fr. Gr.
<grk>Moi^ra</grk> the goddess of fate or death + <grk>lo`gos</grk>
speech, discourse.]</ety> <def>An extemporaneous funeral song, composed
and sung by a woman on the death of a friend.</def> <mark>[Modern
Greece]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriophyllous</ent><br/
<hw>Myr`i*oph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
numberless + <grk>fy`llon</grk> leaf.]</ety> <fld>(Bot.)</fld>
<def>Having an indefinitely great or countless number of
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriopoda</ent><br/
\'d8<hw>Myr`i*op"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Myriapoda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myriorama</ent><br/
<hw>Myr`i*o*ra"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
numberless + <?/ a sight, fr. <?/ to see.]</ety> <def>A picture made up
of several smaller pictures, drawn upon separate pieces in such a manner
as to admit of combination in many different ways, thus producing a
great variety of scenes or landscapes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrioscope</ent><br/
<hw>Myr"i*o*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
numberless + <ets>-scope</ets>.]</ety> <def>A form of
kaleidoscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 960 --></p>

<p><ent>Myristate</ent><br/
<hw>My*ris"tate</hw> <pr>(m<icr/*r<icr/s"t<asl/t)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A salt of myristic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myristic</ent><br/
<hw>My*ris"tic</hw> <pr>(m<icr/*r<icr/s"t<icr/k)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Pertaining to, or derived from, the nutmeg
(<gen>Myristica</gen>). Specifically, designating an acid
(<chform>C14H28O2</chform>) found in nutmeg oil and otoba fat, and
extracted as a white crystalline waxy substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myristin</ent><br/
<hw>My*ris"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The myristate of glycerin, -- found as a vegetable fat in nutmeg
butter, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myristone</ent><br/
<hw>My*ris"tone</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Myrist</ets>ic + <ets>-one</ets>.]</ety> <fld>(Chem.)</fld>
<def>The ketone of myristic acid, obtained as a white crystalline
substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrmecophaga</ent><br/
<hw>Myrmecophaga</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld> <def>The
type genus of the <fam>Myrmecophagidae</fam>; the South American ant
bear.</def><br/
<syn><b>Syn. --</b> genus <gen>Myrmecophaga</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrmecophagidae</ent><br/
<hw>Myrmecophagidae</hw> <pos>prop. n.</pos> <fld>(Zool.)</fld> <def>A
natural family of New World anteaters.</def><br/
<syn><b>Syn. --</b> family <fam>Myrmecophagidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>myrmecophagous</ent><br/
<hw>myrmecophagous</hw> <pos>adj.</pos> <fld>(Biol.)</fld> <def>feeding
on ants but usually not living with them.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>myrmecophile</ent><br/
<hw>myrmecophile</hw> <pos>n.</pos> <fld>(Biol.)</fld> <def>An organism
such as an insect that habitually shares the nest of a species of
ant.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>myrmecophilous</ent><br/
<hw>myrmecophilous</hw> <pos>adj.</pos> <fld>(Biol.)</fld>
<def>Associated with, or benefitted by ants through sharing their
nest.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrmecophyte</ent><br/
<hw>Myr"me*co*phyte`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>my`rmhx</grk>, <grk>my`rmhkos</grk>, ant + <grk>fyto`n</grk>
plant.]</ety> <fld>(Bot.)</fld> <def>A plant that affords shelter and
food to certain species of ants which live in symbiotic relations with
it. Special adaptations for this purpose exist; thus, <spn>Acacia
spadicigera</spn> has large hollows thorns, and species of
<gen>Cecropia</gen> have stem cavities.</def> --
<wordforms><wf>Myr`me*co*phyt"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>myrmecophytic</ent><br/
<hw>myrmecophytic</hw> <pos>adj.</pos> <def>Of or pertaining to a
myrmecophyte.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrmeleon</ent><br/
<hw>Myrmeleon</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Myrmeleontidae</fam>, including the antlions.</def><br/
<syn><b>Syn. --</b> genus Myrmeleon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrmeleontidae</ent><br/
<hw>Myrmeleontidae</hw> <pos>prop. n.</pos> <def>A natural family of the
order <ord>Neuroptera</ord>, including the antlions.</def><br/
<syn><b>Syn. --</b> family <fam>Myrmeleontidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrmicine</ent><br/
<hw>Myr"mi*cine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to <gen>Myrmica</gen>, a genus of ants including
the small house ant (<spn>Myrmica molesta</spn>), and many
others.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrmidon</ent><br/
<hw>Myr"mi*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Myrmidones</ets>, Gr. <grk>Myrmido`nes</grk>, pl.]</ety>
<sn>1.</sn> <def>One of a fierce tribe or troop who accompanied
<persfn>Achilles</persfn>, their king, to the Trojan war.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A soldier or a subordinate civil officer who
executes cruel orders of a superior without protest or pity; --
sometimes applied to bailiffs, constables, etc.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With unabated ardor the vindictive man of law and his
<qex>myrmidons</qex> pressed forward.</q> <rj><qau>W. H.
Ainsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrmidonian</ent><br/
<hw>Myr`mi*do"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of,
or like, myrmidons.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrmotherine</ent><br/
<hw>Myr`mo*the"rine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>my`rmhx</grk> an ant + <grk>qhra^n</grk> to hunt.]</ety>
<fld>(Zool.)</fld> <def>Feeding upon ants; -- said of certain
birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrobolan</ent><br/
<ent>Myrobalan</ent><br/
<mhw>{ <hw>My*rob"a*lan</hw> <pr>(?)</pr>, <hw>My*rob"o*lan</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>myrobalanum</ets> the
fruit of a palm tree from which a balsam was made, Gr.
<grk>myroba`lanos</grk>; <grk>my`ron</grk> any sweet juice distilling
from plants, any prepared unguent or sweet oil + <grk>ba`lanos</grk> an
acorn or any similar fruit: cf. F. <ets>myrobolan</ets>.]</ety> <def>A
dried astringent fruit much resembling a prune. It contains tannin, and
was formerly used in medicine, but is now chiefly used in tanning and
dyeing. Myrobolans are produced by various species of
<gen>Terminalia</gen> of the East Indies, and of <gen>Spondias</gen> of
South America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myronic</ent><br/
<hw>My*ron"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>my`ron</grk> a sweet-smelling unguent.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or obtained from, mustard; -- used specifically to
designate a glucoside called <xex>myronic acid</xex>, found in mustard
seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myropolist</ent><br/
<hw>My*rop"o*list</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>myropw`lhs</grk>; <grk>my`ron</grk> unguent + <grk>pwlei^n</grk> to
sell.]</ety> <def>One who sells unguents or perfumery.</def>
<mark>[Obs.]</mark> <rj><au>Jonhson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrosin</ent><br/
<hw>Myr"o*sin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>An enzyme, resembling diastase, found in mustard seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myroxylon</ent><br/
\'d8<hw>My*rox"y*lon</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.,
fr. Gr. <grk>my`ron</grk> a sweet juice distilling from a plant +
<grk>xy`lon</grk> wood.]</ety> <fld>(Bot.)</fld> <def>A genus of
leguminous trees of tropical America, the different species of which
yield balsamic products, among which are balsam of Peru, and balsam of
Tolu. The species were formerly referred to
<gen>Myrospermum</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrrh</ent><br/
<hw>Myrrh</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>mirre</ets>,
OF. <ets>mirre</ets>, F. <ets>myrrhe</ets>, L. <ets>myrrha</ets>,
<ets>murra</ets>, Gr. <?/; cf. Ar. <ets>murr</ets> bitter, also myrrh,
Heb. <ets>mar</ets> bitter.]</ety> <def>A gum resin, usually of a
yellowish brown or amber color, of an aromatic odor, and a bitter,
slightly pungent taste. It is valued for its odor and for its medicinal
properties. It exudes from the bark of a shrub of Abyssinia and Arabia,
the <spn>Commiphora Myrrha</spn> (syn. <spn>Balsamodendron Myrrha</spn>)
of the family <fam>Burseraceae</fam>, or from the <spn>Commiphora
abyssinica</spn>. The myrrh of the Bible is supposed to have been partly
the gum above named, and partly the exudation of species of
<gen>Cistus</gen>, or rockrose.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>False myrrh</b></col>. <cd>See the Note under
<er>Bdellium</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrrhic</ent><br/
<hw>Myr"rhic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining to, or
obtained from, myrrh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrrhine</ent><br/
<hw>Myr"rhine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Murrhine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrtaceae</ent><br/
<hw>Myrtaceae</hw> <pos>prop. n.</pos> <def>A natural family of trees
and shrubs yielding fragrant oils, including the myrtles, eucalyptus,
clove, allspice, and guava; the <altname>myrtle
family</altname>.</def><br/
<syn><b>Syn. --</b> family <fam>Myrtaceae</fam>, myrtle
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrtaceous</ent><br/
<hw>Myr*ta"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>myrtaceus</ets>.]</ety> <fld>(Bot.)</fld> <def>Of, pertaining to,
or resembling, a large and important natural family of trees and shrubs
(<fam>Myrtaceae</fam> of the order <ord>Myrtales</ord>), of which the
myrtle (<gen>Myrtus</gen>) is the type. It includes the genera
<gen>Eucalyptus</gen>, <gen>Pimenta</gen>, <gen>Lechythis</gen>, and
about seventy more.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrtales</ent><br/
<hw>Myrtales</hw> <pos>prop. n.</pos> <def>A natural order of trees and
shrubs including the myrtle family, Myrtaceae; Combretaceae;
Elaeagnaceae; Haloragidaceae; Melastomaceae; Lecythidaceae; Lythraceae;
Rhizophoraceae; Onagraceae; Lecythidaceae; and Punicaceae.</def><br/
<syn><b>Syn. --</b> order <ord>Myrtales</ord>, <ord>Thymelaeales</ord>,
order Thymelaeales.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrtiform</ent><br/
<hw>Myr"ti*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>myrtus</ets> myrtle + <ets>-form</ets>: cf. F.
<ets>myrtiforme</ets>.]</ety> <def>Resembling myrtle or myrtle berries;
having the form of a myrtle leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrtillocactus</ent><br/
<hw>Myrtillocactus</hw> <pos>prop. n.</pos> <def>A small genus of
arborescent cacti of Mexico and Central America.</def><br/
<syn><b>Syn. --</b> genus <gen>Myrtillocactus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myrtle</ent><br/
<hw>Myr"tle</hw> <pr>(m<etil/r"t'l)</pr>, <pos>n.</pos> <ety>[F.
<ets>myrtil</ets> bilberry, prop., a little myrtle, from
<ets>myrte</ets> myrtle, L. <ets>myrtus</ets>, <ets>murtus</ets>, Gr.
<grk>my`rtos</grk>; cf. Per. <ets>m<umac/rd</ets>.]</ety>
<fld>(Bot.)</fld> <def>A species of the genus <gen>Myrtus</gen>,
especially <spn>Myrtus communis</spn>. The common myrtle has a shrubby,
upright stem, eight or ten feet high. Its branches form a close, full
head, thickly covered with ovate or lanceolate evergreen leaves. It has
solitary axillary white or rosy flowers, followed by black
several-seeded berries. The ancients considered it sacred to Venus. The
flowers, leaves, and berries are used variously in perfumery and as a
condiment, and the beautifully mottled wood is used in
turning.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also popularly but wrongly applied in
America to two creeping plants, the blue-flowered periwinkle and the
yellow-flowered moneywort. In the West Indies several myrtaceous shrubs
are called <ex>myrtle</ex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bog myrtle</b></col>, <cd>the sweet gale.</cd> --
<col><b>Crape myrtle</b></col>. <cd>See under <er>Crape</er>.</cd> --
<col><b>Myrtle warbler</b></col> <fld>(Zool.)</fld>, <cd>a North
American wood warbler (<spn>Dendroica coronata</spn>); -- called also
<altname>myrtle bird</altname>, <altname>yellow-rumped
warbler</altname>, and <altname>yellow-crowned warbler</altname>.</cd>
-- <col><b>Myrtle wax</b></col>. <fld>(Bot.)</fld> <cd>See
<cref>Bayberry tallow</cref>, under <er>Bayberry</er>.</cd> --
<col><b>Sand myrtle</b></col>, <cd>a low, branching evergreen shrub
(<spn>Leiophyllum buxifolium</spn>), growing in New Jersey and
southward.</cd> -- <col><b>Wax myrtle</b></col> <cd>(<spn>Myrica
cerifera</spn>). See <er>Bayberry</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myrtus</ent><br/
<hw>Myrtus</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Myrtaceae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Myrtus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myself</ent><br/
<hw>My*self"</hw> <pr>(?)</pr>, <pos>pron.</pos>; <plu><it>pl.</it>
<plw>Ourselves</plw> <pr>(<?/)</pr>.</plu> <def>I or me in person; --
used for emphasis, my own self or person; as I <xex>myself</xex> will do
it; I have done it <xex>myself</xex>; -- used also instead of
<xex>me</xex>, as the object of the first person of a reflexive verb,
without emphasis; <as>as, I will defend <ex>myself</ex></as>.</def><-- a
reflexive pron. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myselven</ent><br/
<hw>My*selv"en</hw> <pr>(?)</pr>, <pos>pron.</pos> <def>Myself.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysidacea</ent><br/
<hw>Mysidacea</hw> <pos>prop. n.</pos> <def>An order of crustaceans
including the opossum shrimp.</def><br/
<syn><b>Syn. --</b> order <ord>Mysidacea</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mysidae</ent><br/
<hw>Mysidae</hw> <pos>prop. n.</pos> <def>A natural family of small
shrimplike crustaceans.</def><br/
<syn><b>Syn. --</b> family <fam>Mysidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mysis</ent><br/
\'d8<hw>My"sis</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL., fr. Gr.
<?/ a closing of the lips or eyes.]</ety> <fld>(Zool.)</fld> <def>A
genus of small schizopod shrimps found both in fresh and salt water; the
opossum shrimps. One species inhabits the Great Lakes of North America,
and is largely eaten by the whitefish. The marine species form part of
the food of right whales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystacal</ent><br/
<hw>Mys"ta*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>my`stax</grk> mustache.]</ety> <fld>(Zool.)</fld> <def>Of or
pertaining to the upper lip, or mustache.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystagogical</ent><br/
<ent>Mystagogic</ent><br/
<mhw>{ <hw>Mys`ta*gog"ic</hw> <pr>(?)</pr>, <hw>Mys`ta*gog"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to
interpretation of mysteries or to mystagogue; of the nature of
mystagogy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystagogue</ent><br/
<hw>Mys"ta*gogue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mystagogus</ets>, Gr. <?/; <?/ one initiated in mysteries + <?/
leading, n., a leader, fr. <?/ to lead: cf. F. <ets>mystagogue</ets>.
See 1st <er>Mystery</er>.]</ety> <sn>1.</sn> <def>One who interprets
mysteries, especially of a religious kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who keeps and shows church relics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystagogy</ent><br/
<hw>Mys"ta*go`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The doctrines,
principles, or practice of a mystagogue; interpretation of
mysteries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysterial</ent><br/
<hw>Mys*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mysterious.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysteriarch</ent><br/
<hw>Mys*te"ri*arch</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>mysteriarches</ets>, Gr. <?/; <?/ mystery + <?/ chief.]</ety>
<def>One presiding over mysteries.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysterious</ent><br/
<hw>Mys*te"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>myst<egrave/rieux</ets>. See 1st <er>Mystery</er>.]</ety> <def>Of
or pertaining to mystery; containing a mystery; difficult or impossible
to understand; inexplicable; obscure; not revealed or explained;
enigmatical; incomprehensible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God at last<br/
To Satan, first in sin, his doom applied,<br/
Thought in <qex>mysterious</qex> terms.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Obscure; secret; occult; dark; mystic;
cabalistic; enigmatical; unintelligible; inexplicable;
incomprehensible.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysteriously</ent><br/
<hw>Mys*te"ri*ous*ly</hw>, <pos>adv.</pos> <def>In a mysterious
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysteriousness</ent><br/
<hw>Mys*te"ri*ous*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state or
quality of being mysterious.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something mysterious; a mystery.</def>
<mark>[R.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysterize</ent><br/
<hw>Mys"ter*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mysterized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mysterizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To make
mysterious; to make a mystery of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystery</ent><br/
<hw>Mys"ter*y</hw> <pr>(m<icr/s"t<etil/r*<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Mysteries</plw>
<pr>(m<icr/s"t<etil/r*<icr/z)</pr>.</plu> <ety>[L. <ets>mysterium</ets>,
Gr. <grk>mysth`rion</grk>, fr. <grk>my`sths</grk> one initiated in
mysteries; cf. <grk>myei^n</grk> to initiate into the mysteries, fr.
<grk>my`ein</grk> to shut the eyes. Cf. <er>Mute</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>A profound secret; something
wholly unknown, or something kept cautiously concealed, and therefore
exciting curiosity or wonder; something which has not been or can not be
explained; hence, specifically, that which is beyond human
comprehension.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We speak the wisdom of God in a <qex>mystery</qex>.</q> <rj><qau>1
Cor. ii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If God should please to reveal unto us this great
<qex>mystery</qex> of the Trinity, or some other <qex>mysteries</qex> in
our holy religion, we should not be able to understand them, unless he
would bestow on us some new faculties of the mind.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of secret religious celebration, to which
none were admitted except those who had been initiated by certain
preparatory ceremonies; -- usually plural; <as>as, the Eleusinian
<ex>mysteries</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The consecrated elements in the
eucharist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Anything artfully made difficult; an
enigma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystery</ent><br/
<hw>Mys"ter*y</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mysteries</plw>.</plu> <ety>[OE. <ets>mistere</ets>, OF.
<ets>mestier</ets>, F. <ets>m<eacute/tier</ets>, L.
<ets>ministerium</ets>. See <er>Ministry</er>.]</ety> <sn>1.</sn> <def>A
trade; a handicraft; hence, any business with which one is usually
occupied.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fie upon him, he will discredit our <qex>mystery</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And that which is the noblest <qex>mystery</qex><br/
Brings to reproach and common infamy.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dramatic representation of a Scriptural subject,
often some event in the life of Christ; a dramatic composition of this
character; <as>as, the Chester <ex>Mysteries</ex>, consisting of dramas
acted by various craft associations in that city in the early part of
the 14th century</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/<qex>Mystery</qex> plays,<rdquo/ so called because acted by
craftsmen.</q> <rj><qau>Skeat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystical</ent><br/
<ent>Mystic</ent><br/
<mhw>{ <hw>Mys"tic</hw> <pr>(?)</pr>, <hw>Mys"tic*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>mysticus</ets>, Gr. <?/ belonging to
secret rites, from <?/ one initiated: cf. F. <ets>mystique</ets>. See
1st <er>Mystery</er>, <er>Misty</er>.]</ety> <sn>1.</sn> <def>Remote
from or beyond human comprehension; baffling human understanding;
unknowable; obscure; mysterious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven's numerous hierarchy span<br/
The <qex>mystic</qex> gulf from God to man.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God hath revealed a way <qex>mystical</qex> and supernatural.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Importing or implying mysticism; involving some
secret meaning; allegorical; emblematical; <as>as, a <ex>mystic</ex>
dance; <ex>mystic</ex> Babylon.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus, then, did the spirit of unity and meekness inspire every
joint and sinew of the <qex>mystical</qex> body.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>employing mysticism; <as>as, <ex>mystical</ex>
intuition; <ex>mystical</ex> explanations</as>; -- contrasted to
<contr>logical</contr>, <contr>rational</contr>,
<contr>analytical</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>Mys"tic*al*ly</wf>, <pos>adv.</pos> --
<wf>Mys"tic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystic</ent><br/
<hw>Mys"tic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One given to
mysticism; one who holds mystical views, interpretations, etc.;
especially, in ecclesiastical history, one who professed mysticism. See
<er>Mysticism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysticete</ent><br/
<hw>Mys"ti*cete</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>my`stax</grk> the upper lip, also, the mustache + <grk>kh^tos</grk>
a whale.]</ety> <fld>(Zool.)</fld> <def>Any right whale, or whalebone
whale. See <er>Cetacea</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mysticeti</ent><br/
<hw>Mysticeti</hw> <pos>prop. n.</pos> <def>A suborder including baleen
whales: right whales; rorquals; blue whales; and humpbacks.</def><br/
<syn><b>Syn. --</b> suborder <subord>Mysticeti</subord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mysticism</ent><br/
<hw>Mys"ti*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mysticisme</ets>.]</ety> <sn>1.</sn> <def>Obscurity of
doctrine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl. Hist.)</fld> <def>The doctrine of the
Mystics, who professed a pure, sublime, and wholly disinterested
devotion, and maintained that they had direct intercourse with the
divine Spirit, and aquired a knowledge of God and of spiritual things
unattainable by the natural intellect, and such as can not be analyzed
or explained.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Philos.)</fld> <def>The doctrine that the ultimate
elements or principles of knowledge or belief are gained by an act or
process akin to feeling or faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystification</ent><br/
<hw>Mys`ti*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mystification</ets>.]</ety> <def>The act of mystifying, or the
state of being mystied; also, something designed to, or that does,
mystify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The reply of Pope seems very much as though he had been playing
off a <qex>mystification</qex> on his Grace.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystificator</ent><br/
<hw>Mys"ti*fi*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
mystifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mystify</ent><br/
<hw>Mys"ti*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Mystified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Mystifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>mystifier</ets>, fr. Gr. <?/ + L. <ets>-ficare</ets> (in comp.) to
make. See 1st <er>Mystery</er>, and <er>-fy</er>.]</ety> <sn>1.</sn>
<def>To involve in mystery; to make obscure or difficult to understand;
<as>as, to <ex>mystify</ex> a passage of Scripture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perplex the mind of; to puzzle; to impose upon
the credulity of; to baffle; <as>as, to <ex>mystify</ex> an
opponent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He took undue advantage of his credulity and <qex>mystified</qex>
him exceedingly.</q> <rj><qau>Ld. Campbell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>mystique</ent><br/
<hw>mystique</hw> <pos>n.</pos> <sn>1.</sn> <def>An aura of reverence or
mystery stemming from feelings of high value or interest or meaning
surrounding a person or thing; <as>as, the Kennedy
<ex>mystique</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The aura of mystery surrounding the esoteric
knowledge and skills required in certain occupations, or the power of
those possessing those skills; <as>as, the <ex>mystique</ex> of the
astrophysicists</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Mytacism</ent><br/
<hw>My"ta*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/. Cf.
<er>Metacism</er>.]</ety> <def>Too frequent use of the letter
<it>m</it>, or of the sound represented by it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myth</ent><br/
<hw>Myth</hw> <pr>(m<icr/th)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>mythe</asp>.]</altsp> <ety>[Gr. <grk>my^qos</grk> myth, fable,
tale, talk, speech: cf. F. <ets>mythe</ets>.]</ety> <sn>1.</sn> <def>A
story of great but unknown age which originally embodied a belief
regarding some fact or phenomenon of experience, and in which often the
forces of nature and of the soul are personified; an ancient legend of a
god, a hero, the origin of a race, etc.; a wonder story of prehistoric
origin; a popular fable which is, or has been, received as
historical.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person or thing existing only in imagination, or
whose actual existence is not verifiable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As for Mrs. Primmins's bones, they had been <qex>myths</qex> these
twenty years.</q> <rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Myth history</b></col>, <cd>history made of, or mixed
with, myths.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythe</ent><br/
<hw>Mythe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Myth</er>.</def>
<rj><au>Grote.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythical</ent><br/
<ent>Mythic</ent><br/
<mhw>{ <hw>Myth"ic</hw> <pr>(?)</pr>, <hw>Myth"ic*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>mythicus</ets>, Gr. <?/. See
<er>Myth</er>.]</ety> <def>Of or relating to myths; described in a myth;
of the nature of a myth; fabulous; imaginary; fanciful;
mythological.</def> -- <wordforms><wf>Myth"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mythic</qex> turf where danced the nymphs.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hengist and Horsa, Vortigern and Rowena, Arthur and Mordred, are
<qex>mythical</qex> persons, whose very existence may be questioned.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythographer</ent><br/
<hw>My*thog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>myqogra`fos</grk>; <grk>my^qos</grk> + <grk>gra`fein</grk> to
write.]</ety> <def>A composer of fables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythologer</ent><br/
<hw>My*thol"o*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
mythologist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythologian</ent><br/
<hw>Myth`o*lo"gi*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
mythologist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythological</ent><br/
<ent>Mythologic</ent><br/
<mhw>{ <hw>Myth`o*log"ic</hw> <pr>(?)</pr>, <hw>Myth`o*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>mythologicus</ets>:
cf. F. <ets>mytholigique</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining
to mythology or to myths; <as>as, <ex>mythological</ex>
creatures</as>.</def> -- <wordforms><wf>Myth`o*log"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>based on or told of in traditional stories; lacking
factual basis or historical validity; mythical; fabulous.</def><br/
<syn><b>Syn. --</b> fabulous, mythic, mythical.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>mythologisation</ent><br/
<hw>mythologisation</hw> <pos>n.</pos> <def>mythologization.</def>
<mark>[Chiefly Brit.]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mythologist</ent><br/
<hw>My*thol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>mythologiste</ets>.]</ety> <def>One versed in, or who writes on,
mythology or myths.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>mythologization</ent><br/
<hw>mythologization</hw> <pos>n.</pos> <def>The construction of a myth;
the restatement of a message as a myth.</def><br/
<syn><b>Syn. --</b> mythologisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Mythologize</ent><br/
<hw>My*thol"o*gize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. F.
<ets>mythologiser</ets>.]</ety> <sn>1.</sn> <def>To relate, classify,
and explain, or attempt to explain, myths; to write upon
myths.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To construct and propagate myths.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythologizer</ent><br/
<hw>My*thol"o*gi`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which, mythologizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Imagination has always been, and still is, in a narrower sense,
the great <qex>mythologizer</qex>.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythologue</ent><br/
<hw>Myth"o*logue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Mythology</er>.]</ety> <def>A fabulous narrative; a myth.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>May we not . . . consider his history of the fall as an excellent
<qex>mythologue</qex>, to account for the origin of human evil?</q>
<rj><qau>Geddes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythology</ent><br/
<hw>My*thol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Mythologies</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>mythologie</ets>, L. <ets>mythologia</ets>, Gr.
<grk>myqologi`a</grk>; <grk>my^qos</grk>, fable, myth +
<grk>lo`gos</grk> speech, discourse.]</ety> <sn>1.</sn> <def>The science
which treats of myths; a treatise on myths.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A body of myths; esp., the collective myths which
describe the gods of a heathen people; <as>as, the <ex>mythology</ex> of
the Greeks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythoplasm</ent><br/
<hw>Myth"o*plasm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>my^qos</grk> myth + <grk>pla`ssein</grk> to form.]</ety> <def>A
narration of mere fable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythopoeic</ent><br/
<hw>Myth`o*poe"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>myqopoio`s</grk> making myths; <grk>my^qos</grk> myth +
<grk>poiei^n</grk> to make.]</ety> <def>Making or producing myths;
giving rise to mythical narratives.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>mythopoeic</qex> fertility of the Greeks.</q>
<rj><qau>Grote.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mythopoetic</ent><br/
<hw>Myth`o*po*et"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>my^qos</grk> myth + <?/ able to make, producing, fr.
<grk>poiei^n</grk> to make.]</ety> <def>Making or producing myths or
mythical tales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mytiloid</ent><br/
<hw>Myt"i*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Mytilus</ets>
+ <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like, or pertaining
to, the genus <gen>Mytilus</gen>, or family
<fam>Mytilidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mytilotoxine</ent><br/
<hw>Myt`i*lo*tox"ine</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Mytilus</ets> + <ets>toxic</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A poisonous base (leucomaine) found in the common
mussel. It either causes paralysis of the muscles, or gives rise to
convulsions, including death by an accumulation of carbonic acid in the
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Mytilus</ent><br/
\'d8<hw>Myt"i*lus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a sea
mussel, Gr. <?/.]</ety> <fld>(Zool.)</fld> <def>A genus of marine
bivalve shells, including the common mussel. See <xex>Illust.</xex>
under <er>Byssus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myxa</ent><br/
\'d8<hw>Myx"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a lamp nozzle,
Gr. <?/.]</ety> <fld>(Zool.)</fld> <def>The distal end of the mandibles
of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myxedema</ent><br/
<hw>myxedema</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>A pathological
condition due to severe hyperthyroidism, marked by dry skin and
swellings around lips and nose as well as mental and physical
deterioration.</def> <altsp>[Also spelled
<asp>myxoedema</asp>.]</altsp><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Myxine</ent><br/
<hw>Myx"ine</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Zool.)</fld>
<def>A genus of marsipobranchs, including the hagfish. See <er>Hag</er>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myxinoid</ent><br/
<hw>Myx"i*noid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like, or pertaining to, the genus <gen>Myxine</gen>.</def> --
<def2><pos>n.</pos> <def>A hagfish.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myxinoidei</ent><br/
<hw>Myxinoidei</hw> <pos>prop. n.</pos> <def>A suborder of hagfishes as
distinguished from lampreys.</def><br/
<syn><b>Syn. --</b> Myxiniformes, suborder
<subord>Myxiniformes</subord>, Hyperotreta, suborder
<subord>Hyperotreta</subord>, Myxinoidea, suborder
<subord>Myxinoidei</subord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxobacter</ent><br/
<hw>Myxobacter</hw> <pos>prop. n.</pos> <fld>(Microbiol.)</fld> <def>One
genus of <er>myxobacteria</er>.</def><br/
[<source>PJC</source> <source>+PJC</source>]</p>

<p><ent>myxobacterium</ent><br/
<hw>myxobacterium</hw> <pos>n.</pos>; <plu><it>pl.</it>
<plw>myxobacteria</plw> <pr>(#)</pr>.</plu> <def>A type of bacteria that
form colonies in self-produced slime; they inhabit moist soils or
decaying plant matter or animal waste.</def><br/
<syn><b>Syn. --</b> myxobacterium, myxobacter, gliding bacteria, slime
bacteria.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxobacteriaceae</ent><br/
<hw>Myxobacteriaceae</hw> <pos>prop. n.</pos> <def>A family of bacteria
living mostly in soils and on dung; called also
<fam>Polyangiaceae</fam>.</def><br/
<syn><b>Syn. --</b> Polyangiaceae, family <fam>Polyangiaceae</fam>,
family <fam>Myxobacteriaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxocephalus</ent><br/
<hw>Myxocephalus</hw> <pos>prop. n.</pos> <def>A genus of fish including
the grubb (<spn>Myxocephalus aenaeus</spn>), a type of
sculpin.</def><br/
<syn><b>Syn. --</b> genus <gen>Myxocephalus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxocystodea</ent><br/
\'d8<hw>Myx`o*cys*to"de*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ mucus + <?/ a bladder.]</ety> <fld>(Zool.)</fld>
<def>A division of Infusoria including the Noctiluca. See
<er>Noctiluca</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myxoedema</ent><br/
\'d8<hw>Myx`oe*de"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. fr. Gr.
<?/ mucus + <ets>oedema</ets>.]</ety> <fld>(Med.)</fld> <def>A disease
producing a peculiar cretinoid appearance of the face, slow speech, and
dullness of intellect, and due to failure of the functions of the
thyroid gland.</def> <altsp>[Also spelled
<asp>myxedema</asp>.]</altsp>-- <wordforms><wf>Myx`oe*dem"a*tous</wf>
<pr>(#)</pr>, <pos>a.</pos>, <wf>Myx`oe*dem"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Myxoma</ent><br/
\'d8<hw>Myx*o"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Myxomata</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/ mucus +
<ets>-oma</ets>.]</ety> <fld>(Med.)</fld> <def>A tumor made up of a
gelatinous tissue resembling that found in the umbilical cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>myxomatosis</ent><br/
<hw>myxomatosis</hw> <pos>n.</pos> <fld>(Biol.)</fld> <def>a viral
disease (usually fatal) of rabbits.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>myxomycete</ent><br/
<hw>myxomycete</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Biol.)</fld> <def>an
organism of the class <class>Myxomycetes</class>.</def><br/
<syn><b>Syn. --</b> true slime mold, acellular slime mold, plasmodial
slime mold.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxomycetes</ent><br/
\'d8<hw>Myx`o*my*ce"tes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.;
Gr. <?/ mucus, slime + <ets>myceles</ets>.]</ety> <fld>(Bot.)</fld>
<def>A class of peculiar organisms, the slime molds, formerly regarded
as animals (Mycetozoa), but now generally thought to be plants and often
separated as a distinct phylum (Myxophyta); essentially equivalent to
the division Myxomycota. They are found on damp earth and decaying
vegetable matter, and consist of naked masses of protoplasm, often of
considerable size, which creep very slowly over the surface and ingest
solid food.</def> -- <wordforms><wf>Myx`o*my*ce"tous</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
<syn><b>Syn. --</b> true slime molds, acellular slime molds, plasmodial
slime molds.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Myxomycota</ent><br/
<hw>Myxomycota</hw> <pos>n.</pos> <fld>(Biol.)</fld> <def>The slime
molds; organisms having a noncellular and multinucleate creeping
vegetative phase and a propagative spore-producing stage: comprises
Myxomycetes and Acrasiomycetes and Plasmodiophoromycetes; in some
classifications placed in the kingdom Protoctista.</def><br/
<syn><b>Syn. --</b> division Myxomycota, Gymnomycota, division
Gymnomycota.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxophyceae</ent><br/
<hw>Myxophyceae</hw> <pos>prop. n.</pos> <fld>(Biol.)</fld> <def>A
former term for the natural family
<altname><fam>Cyanophyceae</fam></altname>.</def><br/
<syn><b>Syn. --</b> family <fam>Myxophyceae</fam>, Schizophyceae, family
<fam>Schizophyceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myxophyta</ent><br/
\'d8<hw>Myx*oph"y*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.; Gr.
<?/ mucus, slime + <?/ plant.]</ety> <fld>(Bot.)</fld> <def>A phylum of
the vegetable kingdom consisting of the class
<class>Myxomycetes</class>. By some botanists it is not separated from
the Thallophyta.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myxopod</ent><br/
<hw>Myx"o*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ mucus,
slime + <ets>-pod</ets>.]</ety> <fld>(Zool.)</fld> <def>A rhizopod or
moneran. Also used adjectively; <as>as, a <ex>myxopod</ex>
state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myxosporidia</ent><br/
<hw>Myxosporidia</hw> <pos>prop. n.</pos> <def>An order of
sporozoans.</def><br/
<syn><b>Syn. --</b> order <ord>Myxosporidia</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>myxosporidian</ent><br/
<hw>myxosporidian</hw> <pos>n.</pos> <def>An organism of the order
<ord>Myxosporidia</ord>, mostly parasitic in fishes and including
various serious pathogens.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Myzontes</ent><br/
\'d8<hw>My*zon"tes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ to suck.]</ety> <fld>(Zool.)</fld> <def>The
Marsipobranchiata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Myzostomata</ent><br/
\'d8<hw>My`zo*stom"a*ta</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. Gr. <grk>my`zein</grk> to suck + <grk>sto`ma</grk>,
<grk>-atos</grk>, mouth.]</ety> <fld>(Zool.)</fld> <def>An order of
curious parasitic worms found on crinoids. The body is short and
disklike, with four pairs of suckers and five pairs of hook-bearing
parapodia on the under side.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 961 --></p>


<-- Local variables: -->
<-- mode: sgml -->
<-- fill-column: 72 -->
<-- End: -->
