<-- This file is part 12 of the GNU version of
    The Collaborative International Dictionary of English (GCIDE)

    Copyright (C) 1992-2012 Patrick J. Cassidy
    Copyright (C) 2012-2024 Sergey Poznyakoff

    GCIDE is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.

    GCIDE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this copy of GCIDE.  If not, see <http://www.gnu.org/licenses/>.
-->

<p><-- p. 821 --></p>

<p><centered><point26>L.</point26></centered><br/
[<source>1913 Webster</source>]</p>

<p><ent>L</ent><br/
<hw>L</hw> <pr>(<ecr/l)</pr> <pos>n.</pos> <sn>1.</sn> <def>L is the
twelfth letter of the English alphabet, and a vocal consonant. It is
usually called a <xex>semivowel</xex> or <xex>liquid</xex>. Its form and
value are from the Greek, through the Latin, the form of the Greek
letter being from the Ph<oe/nician, and the ultimate origin prob.
Egyptian. Etymologically, it is most closely related to <xex>r</xex> and
<xex>u</xex>; as in pi<xex>l</xex>grim, pe<xex>r</xex>egrine,
co<xex>u</xex>ch (fr. co<xex>ll</xex>ocare), a<xex>u</xex>bura (fr. LL.
a<xex>l</xex>burnus).</def><br/
[<source>1913 Webster</source>]</p>

<p><note> At the end of monosyllables containing a single vowel, it is
often doubled, as in <xex>fall</xex>, <xex>full</xex>, <xex>bell</xex>;
but not after digraphs, as in <xex>foul</xex>, <xex>fool</xex>,
<xex>prowl</xex>, <xex>growl</xex>, <xex>foal</xex>. In English words,
the terminating syllable <xex>le</xex> is unaccented, the <xex>e</xex>
is silent, and <xex>l</xex> is preceded by a voice glide, as in
<xex>able</xex>, <xex>eagle</xex>, pronounced <pr><amac/"b'l</pr>,
<pr><emac/"g'l</pr>. See <it>Guide to Pronunciation</it>,
<sect/241.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>As a numeral, L stands for fifty in the English, as
in the Latin language.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For 50 the Romans used the Chalcidian <it>chi</it>, <?/, which
assumed the less difficult lapidary type, <?/, and was then easily
assimilated to L.</q> <rj><qau>I. Taylor (The Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>L</ent><br/
<hw>L</hw> <pr>(<ecr/l)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
extension at right angles to the length of a main building, giving to
the ground plan a form resembling the letter <boxtype>L</boxtype>;
sometimes less properly applied to a narrower, or lower, extension in
the direction of the length of the main building; a wing.</def>
<altsp>[Written also <asp>ell</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A short right-angled pipe
fitting, used in connecting two pipes at right angles.</def>
<altsp>[Written also <asp>ell</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>L</ent><br/
<hw>L</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having the general shape of
the (capital) letter <universbold>L</universbold>; <as>as, an
<universbold>L</universbold> beam, or
<universbold>L</universbold>-beam</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Elevated; -- a symbol for <altname>el.</altname> as
an abbreviation of <xex>elevated</xex> in <xex>elevated road</xex> or
<xex>railroad</xex>.</def> -- <def2><pos>n.</pos> <def>An elevated road;
<as>as, to ride on the <ex>L</ex></as>.</def> <mark>[Colloq., U.
S.]</mark></def2><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>La</ent><br/
<hw>La</hw> <pr>(l<aum/)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<sd>(a)</sd> <def>A syllable applied to the sixth tone of the scale in
music in solmization.</def> <sd>(b)</sd> <def>The tone A; -- so called
among the French and Italians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>La</ent><br/
<hw>La</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Cf.
<er>Lo</er>.]</ety> <sn>1.</sn> <def>Look; see; behold; -- sometimes
followed by <xex>you</xex>.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An exclamation of surprise; -- commonly followed by
<xex>me</xex>; <as>as, <ex>La</ex> me!</as></def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>laager</ent><br/
<hw>laa"ger</hw> <pr>(l<add/"g<etil/r <it>or</it> l<aum/"g<etil/r)</pr>,
<pos>n.</pos> <ety>[D., also <ets>leger</ets>. Cf. 2d <er>Leaguer</er>,
<er>Lair</er>.]</ety> <def>A camp, especially one surrounded by a
circular formation of travelers' wagons for temporary defense.</def>
<mark>[South Africa]</mark><br/
<syn><b>Syn. --</b> lager.</syn><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>Wagons . . . can be readily formed into a <qex>laager</qex>, a
camp, by being drawn into a circle, with the oxen placed inside and so
kept safe from the attacks of wild beasts.</q> <rj><qau>James
Bryce.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Laager</ent><br/
<hw>Laa"ger</hw>, <pos>v. t. & i.</pos> <ety>[From <er>Laager</er>,
<pos>n.</pos>]</ety> <def>To form into, or camp in, a laager, or
protected camp.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Laas</ent><br/
<hw>Laas</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lace. See
<er>Lace</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lab</ent><br/
<hw>Lab</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. OD.
<ets>labben</ets> to babble.]</ety> <def>To prate; to gossip; to babble;
to blab.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lab</ent><br/
<hw>lab</hw>, <pos>n.</pos> <sn>1.</sn> <def>A telltale; a prater; a
blabber.</def> <mark>[Obs.]</mark> <ldquo/I am no <xex>lab</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[By truncation of <ets>laboratory</ets>.]</ety>
<def>Laboratory.</def> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>lab</ent><br/
<hw>lab</hw>, <pos>a.</pos> <def>Of or pertaining to a laboratory;
<as>as, a <ex>lab</ex> bench</as>.</def> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Labadist</ent><br/
<hw>Lab"a*dist</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>A
follower of <person>Jean de <etsep>Labadie</etsep></person>, a religious
teacher of the 17th century, who left the Roman Catholic Church and
taught a kind of mysticism, and the obligation of community of property
among Christians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labarraque's solution</ent><br/
<hw>La`bar`raque's" so*lu"tion</hw> <pr>(?)</pr> <pos>n.</pos>
<ety>[From <persfn><etsep>Labarraque</etsep></persfn>, a Parisian
apothecary.]</ety> <fld>(Med.)</fld> <def>An aqueous solution of sodium
hypochlorite, extensively used as a disinfectant.</def><br/
[<source>1913 Webster</source>]</p>

<p><note>Sodium hypochlorite is the same compound used in the commercial
trademarked bleach Clorox(TM). It has both disinfectant and bleaching
activity.</note><br/
[<source>PJC</source>]</p>

<p><ent>Labarum</ent><br/
\'d8<hw>Lab"a*rum</hw> <pr>(<?/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Labara</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>The standard
adopted by the Emperor Constantine after his conversion to Christianity.
It is described as a pike bearing a silk banner hanging from a
crosspiece, and surmounted by a golden crown. It bore a monogram of the
first two letters (<CHI/<RHO/) (which appear like the English letters X
and P), of the name of Christ in its Greek form. Later, the name was
given to various modifications of this standard.</def> <-- Illustration
of monogram, an X (Greek CHI) superimposed on a lengthened P (Greek RHO)
--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labdanum</ent><br/
<hw>Lab"da*num</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Ladanum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labefaction</ent><br/
<hw>Lab`e*fac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Labefy</er>.]</ety> <def>The act of labefying or making weak; the
state of being weakened; decay; ruin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is in it such a <qex>labefaction</qex> of all principles as
may be injurious to morality.</q> <rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labefy</ent><br/
<hw>Lab"e*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>labefacere</ets>; <ets>labare</ets> to totter + <ets>facere</ets>
to make.]</ety> <def>To weaken or impair.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Label</ent><br/
<hw>La"bel</hw> <pr>(l<amac/"b<ecr/l)</pr>, <pos>n.</pos> <ety>[OF.
<ets>label</ets> sort of ribbon or fringe, label in heraldry, F.
<ets>lambeau</ets> shred, strip, rag; of uncertain origin; cf. L.
<ets>labellum</ets>, dim. of <ets>labrum</ets> lip, edge, margin, G.
<ets>lappen</ets> flap, patch, rag, tatter (cf. <er>Lap</er> of a
dress), W. <ets>llab</ets>, <ets>llabed</ets>, label, flap, Gael.
<ets>leab</ets>, <ets>leob</ets>, slice, shred, hanging lip.]</ety>
<sn>1.</sn> <def>A tassel.</def> <mark>[Obs.]</mark>
<rj><au>Huloet.</au> <au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slip of silk, paper, parchment, etc., affixed to
anything, and indicating, usually by an inscription, the contents,
ownership, destination, etc.; <as>as, the <ex>label</ex> of a bottle or
a package</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A slip of ribbon, parchment, etc., attached to a
document to hold the appended seal; also, the seal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A writing annexed by way of addition, as a codicil
added to a will.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Her.)</fld> <def>A barrulet, or, rarely, a bendlet,
with pendants, or points, usually three, especially used as a mark of
cadency to distinguish an eldest or only son while his father is still
living.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A brass rule with sights, formerly used, in
connection with a circumferentor, to take altitudes.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Gothic Arch.)</fld> <def>The name now generally
given to the projecting molding by the sides, and over the tops, of
openings in medi<ae/val architecture. It always has a square form, as in
the illustration.</def> <rj><au>Arch. Pub. Soc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>In medi<ae/val art, the representation of a band or
scroll containing an inscription.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Label</ent><br/
<hw>La"bel</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Labeled</conjf> <pr>(l<amac/"b<ecr/ld)</pr> or
<conjf>Labelled</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Labeling</conjf> or <conjf>Labelling</conjf>.]</vmorph>
<sn>1.</sn> <def>To affix a label to; to mark with a name, etc.; <as>as,
to <ex>label</ex> a bottle or a package</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To affix in or on a label.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labeler</ent><br/
<hw>La"bel*er</hw> <pr>(l<amac/"b<ecr/l*<etil/r)</pr>, <pos>n.</pos>
<def>One who labels.</def> <altsp>[Written also
<asp>labeller</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labellum</ent><br/
\'d8<hw>La*bel"lum</hw> <pr>(l<adot/*b<ecr/l"l<ucr/m)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> L. <plw>Labella</plw>
<pr>(l<adot/*b<ecr/l"l<adot/)</pr>, E. <plw>Labellums</plw>
<pr>(l<adot/*b<ecr/l"l<ucr/mz)</pr>.</plu> <ety>[L., dim. of
<ets>labrum</ets> lip.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>The
lower or apparently anterior petal of an orchidaceous flower, often of a
very curious shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A small appendage beneath the
upper lip or labrum of certain insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labent</ent><br/
<hw>La"bent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>labens</ets>,
p. pr. of <ets>labi</ets> to slide, glide.]</ety> <def>Slipping;
sliding; gliding.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labia</ent><br/
\'d8<hw>La"bi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Labium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labial</ent><br/
<hw>La"bi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>labialis</ets>, fr. L. <ets>labium</ets> lip: cf. F.
<ets>labial</ets>. See <er>Lip</er>.]</ety> <sn>1.</sn> <def>Of or
pertaining to the lips or labia; <as>as, <ex>labial</ex>
veins</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Furnished with lips; <as>as, a
<ex>labial</ex> organ pipe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Phonetics)</fld> <sd>(a)</sd> <def>Articulated, as
a consonant, mainly by the lips, as b, p, m, w.</def> <sd>(b)</sd>
<def>Modified, as a vowel, by contraction of the lip opening, as <oomac/
(f<oomac/d), <omac/ (<omac/ld), etc., and as <it>eu</it> and <it>u</it>
in French, and <it><oum/</it>, <it><uum/</it> in German. See Guide to
Pronunciation, <sect/<sect/ 11, 178.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>Of or pertaining to the labium;
<as>as, the <ex>labial</ex> palpi of insects</as>. See
<er>Labium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labial</ent><br/
<hw>La"bi*al</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Phonetics)</fld>
<def>A letter or character representing an articulation or sound formed
or uttered chiefly with the lips, as <stype>b</stype>, <stype>p</stype>,
<stype>w</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>An organ pipe that is furnished
with lips; a flue pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>One of the scales which border
the mouth of a fish or reptile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labialism</ent><br/
<hw>La"bi*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Phonetics)</fld>
<def>The quality of being labial; <as>as, the <ex>labialism</ex> of an
articulation</as>; conversion into a labial, as of a sound which is
different in another language.</def> <rj><au>J. Peile.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labialization</ent><br/
<hw>La`bi*al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Phonetics)</fld> <def>The modification of an articulation by
contraction of the lip opening.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labialize</ent><br/
<hw>La"bi*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Phonetics)</fld> <def>To modify by contraction of the lip
opening.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labially</ent><br/
<hw>La"bi*al*ly</hw>, <pos>adv.</pos> <def>In a labial manner; with, or
by means of, the lips.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labiate</ent><br/
<hw>La"bi*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
labialize.</def> <rj><au>Brewer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labiate</ent><br/
<hw>La"bi*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>labiatus</ets>, fr. L. <ets>labium</ets> lip.]</ety>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>Having the limb of a tubular corolla
or calyx divided into two unequal parts, one projecting over the other
like the lips of a mouth, as in the snapdragon, sage, and catnip.</def>
<sd>(b)</sd> <def>Belonging to a natural order of plants
(<ord>Labiat<ae/</ord>), of which the mint, sage, and catnip are
examples. They are mostly aromatic herbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labiate</ent><br/
<hw>La"bi*ate</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A plant of the
order <ord>Labiat<ae/</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labiated</ent><br/
<hw>La"bi*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Same as <er>Labiate</er>, <pos>a.</pos> <sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labiatifloral</ent><br/
<ent>Labiatifloral</ent><br/
<mhw>{ <hw>La`bi*a`ti*flo"ral</hw> <pr>(?)</pr>,
<hw>La`bi*a`ti*flo"ral</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Labiate</ets> + L. <ets>flos</ets>, <ets>floris</ets>,
flower.]</ety> <fld>(Bot.)</fld> <def>Having labiate flowers, as the
snapdragon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labidometer</ent><br/
<hw>Lab`i*dom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>labi`s</grk>, <grk>-i`dos</grk>, a forceps + <ets>meter</ets>: cf.
F. <ets>labidometre</ets>.]</ety> <fld>(Med.)</fld> <def>A forceps with
a measuring attachment for ascertaining the size of the fetal
head.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labile</ent><br/
<hw>La"bile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>labilis</ets>
apt to slip, fr. <ets>labi</ets> to slip.]</ety> <sn>1.</sn> <def>Liable
to slip, err, fall, or apostatize.</def> <mark>[Obs.]</mark>
<rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Liable or likely to change.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>Easily decomposed or inactivated
when subjected to heat, radiation, or mildly acidic or alkaline
conditions; -- of chemical compounds; <as>as, enzymes from thermophilic
organisms are not as <ex>labile</ex> as those from
mesophiles</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lability</ent><br/
<hw>La*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Liability to lapse, err, or apostatize.</def>
<mark>[Archaic]</mark> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The property of changing readily.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>The property of being labile{3};
-- of chemical compounds; <as>as, the <ex>lability</ex> of some natural
products makes them difficult to isolate and identify</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Labimeter</ent><br/
<hw>La*bim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>labimetre</ets>.]</ety> <fld>(Med.)</fld> <def>See
<er>Labidometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labiodental</ent><br/
<hw>La`bi*o*den"tal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Labium</ets> + <ets>dental</ets>.]</ety>
<fld>(Phonetics)</fld> <def>Formed or pronounced by the cooperation of
the lips and teeth, as <xex>f</xex> and <xex>v</xex>.</def> --
<def2><pos>n.</pos> <def>A labiodental sound or letter.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labionasal</ent><br/
<hw>La`bi*o*na"sal</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Labium</ets> + <ets>nasal</ets>.]</ety>
<fld>(Phonetics)</fld> <def>Formed by the lips and the nose.</def> --
<def2><pos>n.</pos> <def>A labionasal sound or letter.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labioplasty</ent><br/
<hw>La"bi*o*plas`ty</hw>
<pr>(l<amac/"b<icr/*<osl/*pl<acr/s`t<ycr/)</pr>, <pos>n.</pos>
<ety>[<ets>Labium</ets> + <ets>-plasty</ets>.]</ety> <fld>(Surg.)</fld>
<def>A plastic operation for making a new lip, or for replacing a lost
tissue of a lip.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Labiose</ent><br/
<hw>La"bi*ose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Labium</er>.]</ety> <fld>(Bot.)</fld> <def>Having the appearance of
being labiate; -- said of certain polypetalous corollas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labipalp</ent><br/
<hw>La"bi*palp</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A labial palp.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Labipalpus</ent><br/
\'d8<hw>La`bi*pal"pus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Labipalpi</plw> <pr>(<?/)</pr>.</plu> <ety>[NL.
See <er>Labium</er>, and <er>Palpus</er>.]</ety> <fld>(Zool.)</fld>
<def>One of the labial palpi of an insect. See <xex>Illust.</xex> under
<er>Labium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labium</ent><br/
\'d8<hw>La"bi*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Labia</plw> <pr>(#)</pr>, E. <plw>Labiums</plw> <pr>(#)</pr>.</plu>
<ety>[L.]</ety> <sn>1.</sn> <def>A lip, or liplike organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The lip of an organ pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <fld>(Anat.)</fld> <def>The folds of
integument at the opening of the vulva.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The organ of insects
which covers the mouth beneath, and serves as an under lip. It consists
of the second pair of maxill<ae/, usually closely united in the middle
line, but bearing a pair of palpi in most insects. It often consists of
a thin anterior part (<part>ligula</part> or <part>palpiger</part>) and
a firmer posterior plate (<part>mentum</part>).</def> <sd>(b)</sd>
<def>Inner margin of the aperture of a shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lablab</ent><br/
<hw>Lab"lab</hw> <pr>(l<acr/b"l<acr/b)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>an East Indian name for several twining
leguminous plants related to the bean, but commonly applied to the
hyacinth bean (<spn>Dolichos Lablab</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labor</ent><br/
<hw>La"bor</hw> <pr>(l<amac/"b<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>labour</ets>, OF. <ets>labour</ets>, <ets>laber</ets>,
<ets>labur</ets>, F. <ets>labeur</ets>, L. <ets>labor</ets>; cf. Gr.
<grk>lamba`nein</grk> to take, Skr. <ets>labh</ets> to get,
seize.]</ety> <altsp>[Written also <asp>labour</asp>.]</altsp>
<sn>1.</sn> <def>Physical toil or bodily exertion, especially when
fatiguing, irksome, or unavoidable, in distinction from sportive
exercise; hard, muscular effort directed to some useful end, as
agriculture, manufactures, and like; servile toil; exertion;
work.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God hath set<br/
<qex>Labor</qex> and rest, as day and night, to men<br/
Successive.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Intellectual exertion; mental effort; <as>as, the
<ex>labor</ex> of compiling a history</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which requires hard work for its
accomplishment; that which demands effort.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Being a <qex>labor</qex> of so great a difficulty, the exact
performance thereof we may rather wish than look for.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Travail; the pangs and efforts of
childbirth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The queen's in <qex>labor</qex>,<br/
They say, in great extremity; and feared<br/
She'll with the <qex>labor</qex> end.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Any pang or distress.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>The pitching or tossing of a
vessel which results in the straining of timbers and rigging.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <ety>[Sp.]</ety> <def>A measure of land in Mexico and
Texas, equivalent to an area of 177<frac17/ acres.</def>
<rj><au>Bartlett.</au></rj></p>

<p><sn>8.</sn> <fld>(Mining.)</fld> <def>A stope or set of stopes.</def>
<mark>[Sp. Amer.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><syn><b>Syn.</b> -- Work; toil; drudgery; task; exertion; effort;
industry; painstaking. See <er>Toll</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labor</ent><br/
<hw>La"bor</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Labored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Laboring</conjf>.]</vmorph> <ety>[OE. <ets>labouren</ets>, F.
<ets>labourer</ets>, L. <ets>laborare</ets>. See <er>Labor</er>,
<pos>n.</pos>]</ety> <altsp>[Written also <asp>labour</asp>.]</altsp>
<sn>1.</sn> <def>To exert muscular strength; to exert one's strength
with painful effort, particularly in servile occupations; to work; to
toil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adam, well may we <qex>labor</qex> still to dress<br/
This garden.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To exert one's powers of mind in the prosecution of
any design; to strive; to take pains.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be oppressed with difficulties or disease; to do
one's work under conditions which make it especially hard, wearisome; to
move slowly, as against opposition, or under a burden; to be burdened;
-- often with <xex>under</xex>, and formerly with
<xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The stone that <qex>labors</qex> up the hill.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The line too <qex>labors</qex>, and the words move slow.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To cure the disorder under which he <qex>labored</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Come unto me, all ye that <qex>labor</qex> and are heavy laden,
and I will give you rest.</q> <rj><qau>Matt. xi. 28</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be in travail; to suffer the pangs of childbirth;
to be in labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>To pitch or roll heavily, as a
ship in a turbulent sea.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labor</ent><br/
<hw>La"bor</hw>, <pos>v. t.</pos> <ety>[F. <ets>labourer</ets>, L.
<ets>laborare</ets>.]</ety> <sn>1.</sn> <def>To work at; to work; to
till; to cultivate by toil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most excellent lands are lying fallow, or only
<qex>labored</qex> by children.</q> <rj><qau>W. Tooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form or fabricate with toil, exertion, or
care.</def> <ldquo/To <xex>labor</xex> arms for Troy.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To prosecute, or perfect, with effort; to urge
strenuously; <as>as, to <ex>labor</ex> a point or
argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To belabor; to beat.</def> <mark>[Obs.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laborant</ent><br/
<hw>Lab"o*rant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laborans</ets>, p. pr. of <ets>laborare</ets> to labor.]</ety>
<def>A chemist.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laboratory</ent><br/
<hw>Lab"o*ra*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Laboratories</plw> <pr>(#)</pr>.</plu> <ety>[Shortened fr.
<ets>elaboratory</ets>; cf. OF. <ets>elaboratoire</ets>, F.
<ets>laboratoire</ets>. See <er>Elaborate</er>, <er>Labor.</er>]</ety>
<altsp>[Formerly written also <asp>elaboratory</asp>.]</altsp>
<sn>1.</sn> <def>The workroom of a chemist; also, a place devoted to
experiments in any branch of natural science; <as>as, a chemical,
physical, or biological <ex>laboratory</ex></as>. Hence, by extension, a
place where something is prepared, or some operation is performed;
<as>as, the liver is the <ex>laboratory</ex> of the bile</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any place, activity or
situation suggestive of a scientific laboratory{1}, especially in being
conducive to learning new facts by experimentation or by systematic
observation; <as>as, the states serve as <ex>laboratories</ex> where
different new policies may be tested prior to adoption throughout the
country</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Labor Day</ent><br/
<hw>Labor Day</hw>. <def>In most of the States and Territories of the
United States, a day, usually the first Monday of September, set aside
as a legal holiday, in honor of, or in the interest of, workingmen as a
class. Also, a similar holiday in Canada, Australia, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Labored</ent><br/
<hw>La"bored</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Bearing
marks of labor and effort; elaborately wrought; not easy or natural;
<as>as, <ex>labored</ex> poetry; a <ex>labored</ex>
style.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>appearing to require strong effort; <as>as,
<ex>labored</ex> breathing</as>.</def><br/
<syn><b>Syn. --</b> heavy, laboured.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laboredly</ent><br/
<hw>La"bored*ly</hw>, <pos>adv.</pos> <def>In a labored manner; with
labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laborer</ent><br/
<hw>La"bor*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>labourer</ets>.]</ety> <def>One who labors in a toilsome
occupation; a person who does work that requires strength rather than
skill, as distinguished from that of an
<contr>artisan</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laboring</ent><br/
<hw>La"bor*ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>That labors;
performing labor; esp., performing coarse, heavy work, not requiring
skill also, set apart for labor; <as>as, <ex>laboring</ex>
days</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sleep of a <qex>laboring</qex> man is sweet.</q>
<rj><qau>Eccl. v. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suffering pain or grief.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Laboring oar</b></col>, <cd>the oar which requires most
strength and exertion; often used figuratively; <as>as, to have, or
pull, the <ex>laboring oar</ex> in some difficult
undertaking</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laborious</ent><br/
<hw>La*bo"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laboriosus</ets>, fr. <ets>labor</ets> labor: cf. F.
<ets>laborieux</ets>.]</ety> <sn>1.</sn> <def>Requiring labor,
perseverance, or sacrifices; toilsome; tiresome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dost thou love watchings, abstinence, or toil,<br/
<qex>Laborious</qex> virtues all? Learn these from Cato.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Devoted to labor; diligent; industrious; <as>as, a
<ex>laborious</ex> mechanic</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>La*bo"ri*ous*ly</wf>, <pos>adv.</pos> --
<wf>La*bo"ri*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laborless</ent><br/
<hw>La"bor*less</hw> <pr>(l<amac/"b<etil/r*l<ecr/s)</pr>, <pos>a.</pos>
<def>Not involving labor; not laborious; easy.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 822 --></p>

<p><ent>Laborous</ent><br/
<hw>La"bor*ous</hw> <pr>(l<amac/"b<etil/r*<ucr/s)</pr>, <pos>a.</pos>
<def>Laborious.</def> <mark>[Obs.]</mark> <au>Wyatt.</au> --
<wordforms><wf>La"bor*ous*ly</wf>, <pos>adv.</pos> <mark>[Obs.]</mark>
<au>Sir T. Elyot.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labor-saving</ent><br/
<hw>La"bor-sav`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Saving labor;
adapted to supersede or diminish the labor of men; designed to replace
or conserve human and especially manual labor; <as>as,
<ex>labor-saving</ex> machinery; <ex>labor-saving</ex> appliances{4};
<ex>labor-saving</ex> devices like washing machines</as>.</def><br/
<syn><b>Syn. --</b> laborsaving.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Laborsome</ent><br/
<hw>La"bor*some</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Made
with, or requiring, great labor, pains, or diligence.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>Likely or inclined to roll or
pitch, as a ship in a heavy sea; having a tendency to labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>labour</ent><br/
<hw>la"bour</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>labor</er>; -- British spelling.</def> <mark>[Chiefly
Brit.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>laboured</ent><br/
<hw>laboured</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>labored</er>; -- British spelling</def> <mark>[Chiefly
British]</mark> <br/
<syn><b>Syn. --</b> graceless, labored, strained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>labourer</ent><br/
<hw>labourer</hw> <pos>n.</pos> <def>a laborer; someone who works with
their hands.</def> <mark>[Chiefly Brit.]</mark> <br/
<syn><b>Syn. --</b> laborer, manual laborer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>labourious</ent><br/
<hw>labourious</hw> <pos>adj.</pos> <sn>1.</sn> <def>characterized by
toilsome effort; same as <er>laborious</er>; -- British spelling.</def>
<mark>[Chiefly Brit.]</mark> <br/
<syn><b>Syn. --</b> arduous, backbreaking, back-breaking, grueling,
gruelling, hard, heavy, laborious, punishing, slavish, strenuous,
toilsome.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Labourite</ent><br/
<hw>Labourite</hw> <pos>n.</pos> <def>a member of the British
<membof>Labour Party</membof>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Labrador</ent><br/
<hw>Lab`ra*dor"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A region of
British America on the Atlantic coast, north of Newfoundland.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Labrador duck</b></col> <fld>(Zool.)</fld>, <cd>a sea
duck (<spn>Camtolaimus Labradorius</spn>) allied to the eider ducks. It
was formerly common on the coast of New England, but is now supposed to
be extinct, no specimens having been reported since 1878.</cd> --
<col><b>Labrador feldspar</b></col>. <cd>See <er>Labradorite</er>.</cd>
-- <col><b>Labrador tea</b></col> <fld>(Bot.)</fld>, <cd>a name of two
low, evergreen shrubs of the genus <gen>Ledum</gen> (<spn>Ledum
palustre</spn> and <spn>Ledum latifolium</spn>), found in Northern
Europe and America. They are used as tea in British America, and in
Scandinavia as a substitute for hops.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labradorite</ent><br/
<hw>Lab"ra*dor`ite</hw> <pr>(<?/)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A kind of feldspar commonly showing a beautiful play of colors, and
hence much used for ornamental purposes. The finest specimens come from
Labrador. See <er>Feldspar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labras</ent><br/
<hw>La"bras</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>labrum</ets>; cf. It. <ets>labbro</ets>, pl.
<ets>labbra</ets>.]</ety> <def>Lips.</def> <mark>[Obs. & R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labret</ent><br/
<hw>La"bret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>labrum</ets>
lip.]</ety> <fld>(Anthropology)</fld> <def>A piece of wood, shell,
stone, or other substance, worn in a perforation of the lip or cheek by
many savages.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Labroid</ent><br/
<hw>La"broid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Labrus</ets> +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like the genus
<gen>Labrus</gen>; belonging to the family <fam>Labrid<ae/</fam>, an
extensive family of marine fishes, often brilliantly colored, which are
very abundant in the Indian and Pacific Oceans. The tautog and cunner
are American examples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labrose</ent><br/
<hw>La"brose`</hw> <pr>(l<amac/"br<omac/s`)</pr>, <pos>a.</pos> <ety>[L.
<ets>labrosus</ets>, fr. <ets>labrum</ets> lip.]</ety> <def>Having thick
lips.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labrum</ent><br/
\'d8<hw>La"brum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Labra</plw> <pr>(#)</pr>, E. <plw>Labrums</plw> <pr>(#)</pr>.</plu>
<ety>[L.]</ety> <sn>1.</sn> <def>A lip or edge, as of a basin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>An organ in insects
and crustaceans covering the upper part of the mouth, and serving as an
upper lip. See <xex>Illust.</xex> of <er>Hymenoptera</er>.</def>
<sd>(b)</sd> <def>The external margin of the aperture of a shell. See
<er>Univalve</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labrus</ent><br/
\'d8<hw>La"brus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Labri</plw> <pr>(-br<imac/)</pr>.</plu> <ety>[L., a sort of
fish.]</ety> <fld>(Zool.)</fld> <def>A genus of marine fishes, including
the wrasses of Europe. See <er>Wrasse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laburnic</ent><br/
<hw>La*bur`nic</hw> <pr>(l<adot/*b<ucir/r"n<icr/k)</pr>, <pos>a.</pos>
<def>Of, pertaining to, or derived from, the laburnum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laburnine</ent><br/
<hw>La*bur`nine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A poisonous alkaloid found in the unripe seeds of the
laburnum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laburnum</ent><br/
<hw>La*bur"num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Bot.)</fld> <def>A small leguminous tree (<spn>Cytisus
Laburnum</spn>), native of the Alps. The plant is reputed to be
poisonous, esp. the bark and seeds. It has handsome racemes of yellow
blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Scotch laburnum (<spn>Cytisus alpinus</spn>) is similar,
but has smooth leaves; purple laburnum is <spn>Cytisus
purpureus</spn>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinth</ent><br/
<hw>Lab"y*rinth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>labyrinthus</ets>, Gr. <grk>laby`rinthos</grk>: cf. F.
<ets>labyrinthe</ets>.]</ety> <sn>1.</sn> <def>An edifice or place full
of intricate passageways which render it difficult to find the way from
the interior to the entrance; <as>as, the Egyptian and Cretan
<ex>labyrinths</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <ex>Labyrinth</ex> of Classical Mythology was a vast
maze constructed by Daedalus on the island of Crete, in order to confine
the Minotaur; the task was done at the command of King Minos. One theory
suggests that the myth had some basis in the structure of the palace of
King Minos at Knossos, in Crete, it being a multistoried royal palace
with labyrinthine passages between rooms.</note><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any intricate or involved
inclosure; especially, an ornamental maze or inclosure in a park or
garden, having high hedges separating confusingly convoluted
passages.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any object or arrangement of an intricate or
involved form, or having a very complicated nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The serpent . . . fast sleeping soon he found,<br/
In <qex>labyrinth</qex> of many a round self-rolled.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>labyrinth</qex> of the mind.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An inextricable or bewildering difficulty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I' the maze and winding <qex>labyrinths o' the world</qex>.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anat.)</fld> <def>The internal ear. See Note under
<er>Ear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Metal.)</fld> <def>A series of canals through which
a stream of water is directed for suspending, carrying off, and
depositing at different distances, the ground ore of a metal.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Arch.)</fld> <def>A pattern or design representing
a maze, -- often inlaid in the tiled floor of a church, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Maze; confusion; intricacy; windings.</syn>
<usage> -- <er>Labyrinth</er>, <er>Maze</er>. <xex>Labyrinth</xex>,
originally; the name of an edifice or excavation, carries the idea of
design, and construction in a permanent form, while <xex>maze</xex> is
used of anything confused or confusing, whether fixed or shifting.
<xex>Maze</xex> is less restricted in its figurative uses than
<xex>labyrinth</xex>. We speak of the <xex>labyrinth</xex> of the ear,
or of the mind, and of a <xex>labyrinth</xex> of difficulties; but of
the <xex>mazes</xex> of the dance, the <xex>mazes</xex> of political
intrigue, or of the mind being in a <xex>maze</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthal</ent><br/
<hw>Lab`y*rin"thal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or resembling, a labyrinth; intricate; labyrinthian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthian</ent><br/
<hw>Lab`y*rin"thi*an</hw> <pr>(<?/)</pr>, <pos>a.</pos> <def>Intricately
winding; like a labyrinth; perplexed; labyrinthal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthibranch</ent><br/
<hw>Lab`y*rin"thi*branch</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Labyrinth</er>, and <er>Branchia</er>.]</ety> <fld>(Zool.)</fld>
<def>Of or pertaining to the <ord>Labyrinthici</ord>.</def> --
<def2><pos>n.</pos> <def>One of the
<ord>Labyrinthici</ord>.</def></def2></p>

<p><ent>Labyrinthical</ent><br/
<ent>Labyrinthic</ent><br/
<mhw>{ <hw>Lab`y*rin"thic</hw> <pr>(?)</pr>, <hw>Lab`y*rin`thic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>labyrinthicus</ets>:
cf. F. <ets>labyrinthique</ets>.]</ety> <def>Like or pertaining to a
labyrinth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthici</ent><br/
\'d8<hw>Lab`y*rin"thi*ci</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Labyrinth</er>.]</ety> <fld>(Zool.)</fld> <def>An order of
teleostean fishes, including the Anabas, or climbing perch, and other
allied fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They have, connected with the gill chamber, a special
cavity in which a labyrinthiform membrane is arranged so as to retain
water to supply the gills while the fish leaves the water and travels
about on land, or even climbs trees.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthiform</ent><br/
<hw>Lab`y*rin"thi*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Labyrinth</ets> + <ets>-form</ets>: cf. F.
<ets>labyrinthiforme</ets>.]</ety> <def>Having the form of a labyrinth;
intricate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthine</ent><br/
<hw>Lab`y*rin"thine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or like, a labyrinth; labyrinthal; labyrinthian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthodon</ent><br/
<hw>Lab`y*rin"tho*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>laby`rinthos</grk> labyrinth + <grk>'odoy`s</grk>,
<grk>'odo`ntos</grk>, tooth.]</ety> <fld>(Paleon.)</fld> <def>A genus of
very large fossil amphibians, of the Triassic period, having bony plates
on the under side of the body. It is the type of the order
<ord>Labyrinthodonta</ord>. Called also
<gen>Mastodonsaurus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthodont</ent><br/
<hw>Lab`y*rin"tho*dont</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Paleon.)</fld> <def>Of or pertaining to the
<ord>Labyrinthodonta</ord>.</def> -- <def2><pos>n.</pos> <def>One of the
<ord>Labyrinthodonta</ord>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Labyrinthodonta</ent><br/
\'d8<hw>Lab`y*rin`tho*don"ta</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL. See <er>Labyrinthodon</er>.]</ety> <fld>(Paleon.)</fld>
<def>An extinct order of Amphibia, including the typical genus
<gen>Labyrinthodon</gen>, and many other allied forms, from the
Carboniferous, Permian, and Triassic formations. By recent writers they
are divided into two or more orders. See
<er>Stegocephala</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lakh</ent><br/
<ent>Lac</ent><br/
<mhw>{ <hw>Lac</hw> <pr>(l<acr/k)</pr>, \'d8<hw>Lakh</hw>
<pr>(l<aum/k)</pr> }</mhw>, <pos>n.</pos> <ety>[Hind. <ets>lak</ets>,
<ets>l<amac/kh</ets>, <ets>l<amac/ksh</ets>, Skr. <ets>laksha</ets> a
mark, sign, lakh.]</ety> <def>One hundred thousand; also, a vaguely
great number; <as>as, a <ex>lac</ex> of rupees</as>.</def>
<altsp>[Written also <asp>lack</asp>.]</altsp> <mark>[East
Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lac</ent><br/
<hw>Lac</hw>, <pos>n.</pos> <ety>[Per. <ets>lak</ets>; akin to Skr.
<ets>l<amac/ksh<amac/</ets>: cf. F. <ets>lague</ets>, It. & NL.
<ets>lacca</ets>. Cf. <er>Lake</er> a color, <er>Lacquer</er>,
<er>Litmus</er>.]</ety> <def>A resinous substance produced mainly on the
banyan tree, but to some extent on other trees, by the <spn>Laccifer
lacca</spn> (formerly <spn>Coccus lacca</spn>), a scale-shaped insect,
the female of which fixes herself on the bark, and exudes from the
margin of her body this resinous substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <stype>Stick-lac</stype> is the substance in its natural
state, incrusting small twigs. When broken off, and the coloring matter
partly removed, the granular residuum is called <stype>seed-lac</stype>.
When melted, and reduced to a thin crust, it is called
<stype>shell-lac</stype> or <stype>shellac</stype>. Lac is an important
ingredient in sealing wax, dyes, varnishes, and lacquers.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ceylon lac</b></col>, <cd>a resinous exudation of the
tree <spn>Croton lacciferum</spn>, resembling lac.</cd> -- <col><b>Lac
dye</b></col>, <cd>a scarlet dye obtained from stick-lac.</cd> --
<col><b>Lac lake</b></col>, <cd>the coloring matter of lac dye when
precipitated from its solutions by alum.</cd> -- <col><b>Mexican
lac</b></col>, <cd>an exudation of the tree <spn>Croton
Draco</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laccic</ent><br/
<hw>Lac"cic</hw> <pr>(l<acr/k"s<icr/k)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>laccique</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to lac,
or produced from it; <as>as, <ex>laccic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laccin</ent><br/
<hw>Lac"cin</hw> <pr>(l<acr/k"s<icr/n)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>laccine</ets>.]</ety> <fld>(Chem.)</fld> <def>A yellow amorphous
substance obtained from lac.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laccolith</ent><br/
<ent>Laccolite</ent><br/
<mhw>{ <hw>Lac"co*lite</hw> <pr>(?)</pr>, <hw>Lac"co*lith</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <?/ a cistern +
<ets>-lite</ets>, <ets>-lith</ets>.]</ety> <fld>(Geol.)</fld> <def>A
mass of igneous rock intruded between sedimentary beds and resulting in
a mammiform bulging of the overlying strata.</def> --
<wordforms><wf>Lac`co*lit"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lace</ent><br/
<hw>Lace</hw> <pr>(l<amac/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>las</ets>, OF. <ets>laz</ets>, F. <ets>lacs</ets>, dim.
<ets>lacet</ets>, fr. L. <ets>laqueus</ets> noose, snare; prob. akin to
<ets>lacere</ets> to entice. Cf. <er>Delight</er>, <er>Elicit</er>,
<er>Lasso</er>, <er>Latchet</er>.]</ety> <sn>1.</sn> <def>That which
binds or holds, especially by being interwoven; a string, cord, or band,
usually one passing through eyelet or other holes, and used in drawing
and holding together parts of a garment, of a shoe, of a machine belt,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His hat hung at his back down by a <qex>lace</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For striving more, the more in <qex>laces</qex> strong<br/
Himself he tied.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A snare or gin, especially one made of interwoven
cords; a net.</def> <mark>[Obs.]</mark> <rj><au>Fairfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Vulcanus had caught thee [Venus] in his <qex>lace</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fabric of fine threads of linen, silk, cotton,
etc., often ornamented with figures; a delicate tissue of thread, much
worn as an ornament of dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our English dames are much given to the wearing of costly
<qex>laces</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Spirits added to coffee or some other
beverage.</def> <mark>[Old Slang]</mark> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Alen<cced/on lace</b></col>, <cd>a kind of point lace,
entirely of needlework, first made at Alen<cced/on in France, in the
17th century. It is very durable and of great beauty and cost.</cd> --
<mcol><col><b>Bone lace</b></col>, <col><b>Brussels
lace</b></col></mcol>, <cd>etc. See under <er>Bone</er>,
<er>Brussels</er>, etc.</cd> -- <mcol><col><b>Gold lace</b></col>,
<it>or</it> <col><b>Silver lace</b></col></mcol>, <cd>lace having warp
threads of silk, or silk and cotton, and a weft of silk threads covered
with gold (or silver), or with gilt.</cd> -- <col><b>Lace
leather</b></col>, <cd>thin, oil-tanned leather suitable for cutting
into lacings for machine belts.</cd> -- <col><b>Lace lizard</b></col>
<fld>(Zool.)</fld>, <cd>a large, aquatic, Australian lizard
(<spn>Hydrosaurus giganteus</spn>), allied to the monitors.</cd> --
<col><b>Lace paper</b></col>, <cd>paper with an openwork design in
imitation of lace.</cd> -- <col><b>Lace piece</b></col>
<fld>(Shipbuilding)</fld>, <cd>the main piece of timber which supports
the beak or head projecting beyond the stem of a ship.</cd> --
<mcol><col><b>Lace pillow</b></col>, and <col><b>Pillow
lace</b></col></mcol>. <cd>See under <er>Pillow</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lace</ent><br/
<hw>Lace</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Laced</conjf> <pr>(<amac/st)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lacing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To fasten
with a lace; to draw together with a lace passed through eyelet holes;
to unite with a lace or laces, or, figuratively. with anything
resembling laces.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When Jenny's stays are newly <qex>laced</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To adorn with narrow strips or braids of some
decorative material; <as>as, cloth <ex>laced</ex> with
silver</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To beat; to lash; to make stripes on.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll <qex>lace</qex> your coat for ye.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To add something to (a food or beverage) so as to
impart flavor, pungency, or some special quality; <as>as, to
<ex>lace</ex> a punch with alcohol; to <ex>lace</ex> the Kool-Aid with
LSD</as>.</def> <mark>[Old Slang]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>5.</sn> <def>To twine or draw as a lace; to interlace; to
intertwine.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The Gond . . . picked up a trail of the Karela, the vine that
bears the bitter wild gourd, and <qex>laced</qex> it to and fro across
the temple door.</q> <rj><qau>Kipling.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lace</ent><br/
<hw>Lace</hw>, <pos>v. i.</pos> <def>To be fastened with a lace, or
laces; <as>as, these boots <ex>lace</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lacebark</ent><br/
<hw>lacebark</hw> <pos>n.</pos> <def>A small tree or shrub (<spn>Hoheria
populnea</spn>) of New Zealand having a profusion of axillary clusters
of honey-scented paper-white flowers and whose bark is used for
cordage.</def><br/
<syn><b>Syn. --</b> ribbonwood, houhere, <spn>Hoheria
populnea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lace-bark</ent><br/
<hw>Lace"-bark`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A shrub in the West Indies (<spn>Lagetta Iintearia</spn>); -- so
called from the lacelike layers of its inner bark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laced</ent><br/
<hw>Laced</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Fastened
with a lace or laces; decorated with narrow strips or braid. See
<er>Lace</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Decorated with the fabric lace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A shirt with <qex>laced</qex> ruffles.</q>
<rj><qau>Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Laced mutton</b></col>, <cd>a prostitute.</cd> <mark>[Old
slang]</mark> -- <col><b>Laced stocking</b></col>, <cd>a strong stocking
which can be tightly laced; -- used in cases of weak legs, varicose
veins, etc.</cd> <au>Dunglison.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacedaemonian</ent><br/
<hw>Lac`e*d<ae/*mo"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Lacedamonius</ets>, Gr. <grk>Lakedaimo`nios</grk>, fr.
<grk>Lakedai`mwn</grk> Laced<ae/mon.]</ety> <def>Of or pertaining to
Laced<ae/mon or Sparta, the chief city of Laconia in the
Peloponnesus.</def> -- <def2><pos>n.</pos> <def>A Spartan.</def></def2>
<altsp>[Written also <asp>Lacedemonian</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>lace into</ent><br/
<hw>lace into</hw>, <pos>v. t.</pos> <def>To attack vigorously; -- used
of physical or verbal attacks; <as>as, the boss <ex>laced into</ex> him
for coming to the meeting late</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laceman</ent><br/
<hw>Lace"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lacemen</plw> <pr>(<?/)</pr>.</plu> <def>A man who deals in
lace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacerable</ent><br/
<hw>Lac"er*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lacerabilis</ets>: cf. F. <ets>lac<eacute/rable</ets>.]</ety>
<def>That can be lacerated or torn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacerate</ent><br/
<hw>Lac"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lacerated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lacerating</conjf> <pr>(<?/)</pr>.]</vmorph> <ety>[L.
<ets>laceratus</ets>, p. p. of <ets>lacerare</ets> to lacerate, fr.
<ets>lacer</ets> mangled, lacerated; cf. Gr. <?/ a rent, rending, <?/ to
tear; perh. akin to E. <ets>slay</ets>.]</ety> <def>To tear; to rend; to
separate by tearing; to mangle; <as>as, to <ex>lacerate</ex> the
flesh</as>.</def> <specif>Hence:</specif> <def>To afflict; to torture;
<as>as, to <ex>lacerate</ex> the heart</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacerated</ent><br/
<ent>Lacerate</ent><br/
<mhw>{ <hw>Lac"er*ate</hw> <pr>(?)</pr>, <hw>Lac"er*a`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>p. a.</pos> <ety>[L. <ets>laceratus</ets>,
<ets>p. p.</ets>]</ety> <sn>1.</sn> <def>Rent; torn; mangled; <as>as, a
<ex>lacerated</ex> wound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By each other's fury <qex>lacerate</qex></q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot. & Zool.)</fld> <def>Jagged, or slashed
irregularly, at the end, or along the edge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lacerated</ent><br/
<hw>lacerated</hw> <pos>adj.</pos> <def>torn roughly; -- of
skin.</def><br/
<syn><b>Syn. --</b> mangled, torn.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laceration</ent><br/
<hw>Lac`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laceratio</ets>: cf. F. <ets>lac<eacute/ration</ets>.]</ety>
<sn>1.</sn> <def>The act of lacerating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A breach or wound made by lacerating.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacerative</ent><br/
<hw>Lac"er*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lacerating, or
having the power to lacerate; <as>as, <ex>lacerative</ex>
humors</as>.</def> <rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacert</ent><br/
<hw>La"cert</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lacerte</ets>. See <er>Lacertus</er>.]</ety> <def>A muscle of the
human body.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacerta</ent><br/
<hw>La*cer"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lacertus</ets> the arm.]</ety> <def>A fathom.</def>
<mark>[Obs.]</mark> <rj><au>Domesday Book.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacerta</ent><br/
<hw>La*cer"ta</hw>, <pos>n.</pos> <ety>[L. a lizard. See
<er>Lizard</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A genus of
lizards. See <er>Lizard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly it included nearly all the known lizards. It is
now restricted to certain diurnal Old World species, like the green
lizard (<spn>Lacerta viridis</spn>) and the sand lizard (<spn>Lacerta
agilis</spn>), of Europe.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>The Lizard, a northern
constellation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacertian</ent><br/
<hw>La*cer"tian</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lacertien</ets>.]</ety> <fld>(Zool.)</fld> <def>Like a lizard; of
or pertaining to the <ord>Lacertilia</ord>.</def> -- <def2><pos>n.</pos>
<def>One of the <ord>Lacertilia</ord>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>lacertid</ent><br/
<hw>lacertid</hw> <pos>n.</pos> <def>Any lizard of the family
<gen>Lacertidae</gen>, a family of Old World terrestrial
lizard.</def><br/
<syn><b>Syn. --</b> lacertid lizard.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lacertidae</ent><br/
<hw>Lacertidae</hw> <pos>n.</pos> <def>A natural family of Old World
lizards.</def><br/
<syn><b>Syn. --</b> family <gen>Lacertidae</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lacertilia</ent><br/
\'d8<hw>Lac`er*til"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>lacertus</ets> a lizard.]</ety> <fld>(Zool.)</fld> <def>An
order of Reptilia, which includes the lizards.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They are closely related to the snakes, and like the
latter, usually have the body covered with scales or granules. They
usually have eyelids, and most of then have well-formed legs; but in
some groups (amphisb<ae/na, glass-snake, etc.) the legs are absent and
the body is serpentlike. None are venomous, unless <gen>Heloderma</gen>
be an exception. The order includes the chameleons, the
<gen>Cionocrania</gen>, or typical lizards, and the amphisb<ae/nas. See
<er>Amphisb<ae/na</er>, <er>Gecko</er>, <er>Gila monster</er>, and
<er>Lizard</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacertilian</ent><br/
<hw>Lac`er*til"i*an</hw> <pr>(-an)</pr>, <pos>a. & n.</pos> <def>Same as
<er>Lacertian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacertiloid</ent><br/
<hw>La*cer"ti*loid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lacertilia</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Like or belonging to the <ord>Lacertilia</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacertine</ent><br/
<hw>La*cer"tine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Lacertian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacertus</ent><br/
\'d8<hw>La*cer"tus</hw> <pr>(l<adot/*s<etil/r"t<ucr/s)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Lacerti</plw>
<pr>(-t<imac/)</pr>.</plu> <ety>[L., the upper arm.]</ety>
<fld>(Anat.)</fld> <def>A bundle or fascicle of muscular
fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacewing</ent><br/
<hw>Lace"wing`</hw> <pr>(l<amac/s"w<icr/ng`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any one of several species of neuropterous
insects of the genus <gen>Chrysopa</gen> and allied genera. They have
delicate, lacelike wings and brilliant eyes. Their larv<ae/ are useful
in destroying aphids. Called also <altname>lace-winged fly</altname>,
and <altname>goldeneyed fly</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lace-winged</ent><br/
<hw>Lace"-winged`</hw>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Having
thin, transparent, reticulated wings; <as>as, the <ex>lace-winged</ex>
flies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lache</ent><br/
<ent>Laches</ent><br/
<mhw>{ <hw>Lach"es</hw> <pr>(l<acr/sh"<ecr/z)</pr>, <hw>Lache</hw>
<pr>(l<acr/sh)</pr>, }</mhw> <pos>n.</pos> <ety>[OF.
<ets>lachesse</ets>, fr. <ets>lache</ets> lax, indolent, F.
<ets>l<acir/che</ets>, ultimately fr. L. <ets>laxus</ets> loose, lax.
See <er>Lax</er>.]</ety> <fld>(Law)</fld> <def>Neglect; negligence;
remissness; neglect to do a thing at the proper time; especially, a
delay in asserting a claim, sufficient to cause a person to lose the
right to adjuducation of the claim by a court.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It ill became him to take advantage of such a <qex>laches</qex>
with the eagerness of a shrewd attorney.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymable</ent><br/
<hw>Lach"ry*ma*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lacrimabilis</ets>, fr. <ets>lacrima</ets> a tear.]</ety>
<def>Lamentable.</def> <rj><au>Martin Parker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymae Christi</ent><br/
\'d8<hw>Lach"ry*m<ae/ Chris"ti</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L.,
lit., Christ's tears.]</ety> <def>A rich, sweet, red Neapolitan
wine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymal</ent><br/
<hw>Lach"ry*mal</hw> <pr>(<?/)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lacrymal</ets>. See <er>Lachrymose</er>.]</ety> <sn>1.</sn> <def>Of
or pertaining to tears; <as>as, <ex>lachrymal</ex>
effusions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Pertaining to, or secreting,
tears; <as>as, the <ex>lachrymal</ex> gland</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>Pertaining to the lachrymal{2}
organs; <as>as, <ex>lachrymal</ex> bone; <ex>lachrymal</ex>
duct.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacrymal</ent><br/
<ent>Lachrymal</ent><br/
<mhw>{ <hw>Lach"ry*mal</hw>, <hw>Lac"ry*mal</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>See <er>Lachrymatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymals</ent><br/
<hw>Lach"ry*mals</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[<er>See
Lachrymal</er>.]</ety> <def>Tears; also, lachrymal feelings or
organs.</def> <mark>[Colloq.]</mark></p>

<p><q>People go to the theaters to have . . . their risibles and
<qex>lachrymals</qex> set agoing.</q> <rj><qau>The
Lutheran.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lachrymary</ent><br/
<hw>Lach"ry*ma*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing, or
intended to contain, tears; lachrymal.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymate</ent><br/
<hw>Lach"ry*mate</hw> <pr>(-m<amac/t)</pr>, <pos>v. i.</pos> <def>To
weep.</def> <mark>[R.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymation</ent><br/
<hw>Lach`ry*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lacrimatio</ets>, from <ets>lacrimare</ets> to shed tears, fr.
<ets>lacrima</ets> tear.]</ety> <def>The act of shedding tears;
weeping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lachrymator</ent><br/
<hw>lachrymator</hw> <pos>n.</pos> <def>A chemical substance that causes
tears to flow; same as <er>lacrimator</er>.</def><br/
<syn><b>Syn. --</b> lacrimator.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Lachrymatory</ent><br/
<hw>Lach"ry*ma*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
-<plw>ries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>lacrymatoire</ets>.]</ety> <fld>(Antiq.)</fld> <def>A
<ldquo/tear-bottle;<rdquo/ a narrow-necked vessel found in sepulchers of
the ancient Romans; -- so called from a former notion that the tears of
the deceased person's friends were collected in it. Called also
<altname>lachrymal</altname> or <altname>lacrymal</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lachrymatory</ent><br/
<hw>lachrymatory</hw> <pos>adj.</pos> <def>Relating to or inducing
tears; -- especially of chemical substances.</def>
<see>lacrimator</see><br/
<syn><b>Syn. --</b> lacrimatory.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lachrymiform</ent><br/
<hw>Lach"ry*mi*form</hw> <pr>(?)</pr>, <pos>a.</pos>, <ety>[L.
<ets>lacrima</ets> tear + <ets>-form</ets>; cf. F.
<ets>lacrymiforme</ets>.]</ety> <def>Having the form of a tear;
tear-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lachrymose</ent><br/
<hw>Lach"ry*mose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lacrymosus</ets>, better <ets>lacrimosus</ets>, fr.
<ets>lacrima</ets>, <ets>lacruma</ets> (also badly spelt
<ets>lachryma</ets>) a tear, for older <ets>dacrima</ets>, akin to E.
<ets>tear</ets>. See <er>Tear</er> the secretion.]</ety> <def>Generating
or shedding tears; given to shedding tears; suffused with tears;
tearful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You should have seen his <qex>lachrymose</qex> visnomy.</q>
<rj><qau>Lamb.</qau></rj></p>

<p>-- <wordforms><wf>Lach"ry*mose`ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 823 --></p>

<p><ent>Lacing</ent><br/
<hw>La"cing</hw> <pr>(l<amac/"s<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of securing, fastening, or tightening, with a lace or
laces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lace;</def> <specif>specifically</specif>
<fld>(Mach.)</fld>, <def>a thong of thin leather for uniting the ends of
belts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A rope or line passing through
eyelet holes in the edge of a sail or an awning to attach it to a yard,
gaff, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bridge Building)</fld> <def>A system of bracing
bars, not crossing each other in the middle, connecting the channel bars
of a compound strut.</def> <rj><au>Waddell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A quantity of a substance, such as an alcoholic
liquor, added to a food or a drink; <as>as, punch with a <ex>lacing</ex>
of rum</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>A beating, especially with a lash.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lacinia</ent><br/
<ent>Laciniae</ent><br/
<hw>La*cin"i*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Lacini<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., the lappet or flap
of a garment.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>One
of the narrow, jagged, irregular pieces or divisions which form a sort
of fringe on the borders of the petals of some flowers.</def>
<sd>(b)</sd> <def>A narrow, slender portion of the edge of a
monophyllous calyx, or of any irregularly incised leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The posterior, inner process of
the stipes on the maxill<ae/ of insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laciniated</ent><br/
<ent>Laciniate</ent><br/
<mhw>{ <hw>La*cin"i*ate</hw> <pr>(?)</pr>, <hw>La*cin"i*a"ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Lacinia</er>.]</ety>
<sn>1.</sn> <def>Fringed; having a fringed border.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot. & Zool.)</fld> <def>Cut into deep, narrow,
irregular lobes; slashed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laciniolate</ent><br/
<hw>La*cin"i*o*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lacinia</er>.]</ety> <fld>(Bot.)</fld> <def>Consisting of, or
abounding in, very minute lacini<ae/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacinula</ent><br/
<ent>Lacinulaa</ent><br/
\'d8<hw>La*cin"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lacinul<ae/</plw> <pr>(#)</pr>, E. <plw>Lacinulas</plw>
<pr>(#)</pr>.</plu> <ety>[NL.]</ety> <fld>(Bot.)</fld> <def>A diminutive
lacinia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lack</ent><br/
<hw>Lack</hw> <pr>(l<acr/k)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lak</ets>; cf. D. <ets>lak</ets> slander, <ets>laken</ets> to
blame, OHG. <ets>lahan</ets>, AS. <ets>le<aacute/n</ets>.]</ety>
<sn>1.</sn> <def>Blame; cause of blame; fault; crime; offense.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deficiency; want; need; destitution; failure;
<as>as, a <ex>lack</ex> of sufficient food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She swooneth now and now for <qex>lakke</qex> of blood.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let his <qex>lack</qex> of years be no impediment.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lack</ent><br/
<hw>Lack</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lacked</conjf> <pr>(l<acr/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lacking</conjf>.]</vmorph> <sn>1.</sn> <def>To blame; to find
fault with.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Love them and <qex>lakke</qex> them not.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be without or destitute of; to want; to
need.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If any of you <qex>lack</qex> wisdom, let him ask of God.</q>
<rj><qau>James i. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lack</ent><br/
<hw>Lack</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be wanting; often,
impersonally, with <ptcl>of</ptcl>, meaning, to be less than, short, not
quite, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What hour now?<br/
I think it <qex>lacks</qex> of twelve.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Peradventure there shall <qex>lack</qex> five of the fifty.</q>
<rj><qau>Gen. xvii. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be in want.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The young lions do <qex>lack</qex>, and suffer hunger.</q>
<rj><qau>Ps. xxxiv. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lack</ent><br/
<hw>Lack</hw>, <pos>interj.</pos> <ety>[Cf. <er>Alack</er>.]</ety>
<def>Exclamation of regret or surprise.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lackadaisical</ent><br/
<hw>lack`a*dai"si*cal</hw>
<pr>(l<acr/k`<adot/*d<amac/"z<icr/*k<ait/l)</pr>, <pos>a.</pos>
<ety>[From <er>Lackadaisy</er>, <ets>interj</ets>.]</ety> <sn>1.</sn>
<def>Affectedly pensive; languidly sentimental; dreamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lacking spirit or liveliness; lethargic; listless;
languid.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Indolent; lazy; idle, especially in a dreamy
manner.</def><br/
[<source>PJC</source>]</p>

<p> -- <wordforms><wf>Lack`a*dai"si*cal*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackadaisy</ent><br/
<hw>Lack"a*dai`sy</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[From
<er>Lackaday</er>, <ets>interj</ets>.]</ety> <def>An expression of
languor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackadaisy</ent><br/
<hw>Lack"a*dai`sy</hw>, <pos>a.</pos> <def>Lackadaisical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackaday</ent><br/
<hw>Lack"a*day`</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Abbreviated
from <ets>alackaday</ets>.]</ety> <def>Alack the day; alas; -- an
expression of sorrow, regret, dissatisfaction, or surprise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackbrain</ent><br/
<hw>Lack"brain`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
deficient in understanding; a witless person.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacker</ent><br/
<hw>Lack"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who lacks or is in
want.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacker</ent><br/
<hw>Lack"er</hw>, <pos>n. & v.</pos> <def>See
<er>Lacquer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackey</ent><br/
<hw>Lack"ey</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lackeys</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>laquais</ets>; cf.
Sp. & Pg. <ets>lacayo</ets>; of uncertain origin; perh. of German
origin, and akin to E. <ets>lick</ets>, <pos>v.</pos>]</ety> <def>An
attending male servant; a footman; a servile follower.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a Christian footboy or a gentleman's <qex>lackey</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lackey caterpillar</b></col> <fld>(Zool.)</fld>, <cd>the
caterpillar, or larva, of any bombycid moth of the genus
<gen>Clisiocampa</gen>; -- so called from its party-colored markings.
The common European species (<spn>Clisiocampa neustria</spn>) is striped
with blue, yellow, and red, with a white line on the back. The American
species (<spn>Clisiocampa Americana</spn> and <spn>Clisiocampa
sylvatica</spn>) are commonly called <altname>tent
caterpillars</altname>. See <cref>Tent caterpillar</cref>, under
<er>Tent</er>.</cd> -- <col><b>Lackey moth</b></col> <fld>(Zool.)</fld>,
<cd>the moth which produces the lackey caterpillar.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackey</ent><br/
<hw>Lack"ey</hw>, <pos>v. t.</pos> <def>To attend as a lackey; to wait
upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A thousand liveried angels <qex>lackey</qex> her.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lackey</ent><br/
<hw>Lack"ey</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lackeyed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lackeying</conjf>.]</vmorph> <def>To act or serve as lackey; to
pay servile attendance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacklustre</ent><br/
<ent>Lackluster</ent><br/
<mhw>{ <hw>Lack"lus`ter</hw>, <hw>Lack"lus`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <def>A lack of luster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacklustre</ent><br/
<ent>Lackluster</ent><br/
<mhw>{ <hw>Lack"lus`ter</hw>, <hw>Lack"lus`tre</hw> }</mhw>
<pos>a.</pos> <sn>1.</sn> <def>Wanting luster or brightness.</def>
<ldquo/<xex>Lackluster</xex> eye.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lacking spirit, liveliness, or enthusiasm;
dull.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Mediocre; <as>as, a <ex>lackluster</ex>
performance</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lacmus</ent><br/
<hw>Lac"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Litmus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconian</ent><br/
<hw>La*co"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Laconia, a division of ancient Greece; Spartan.</def> --
<def2><pos>n.</pos> <def>An inhabitant of Laconia; esp., a
Spartan.</def></def2></p>

<p><ent>Laconic</ent><br/
<ent>Laconical</ent><br/
<mhw>{ <hw>La*con"ic</hw> <pr>(?)</pr>, <hw>La*con"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>Laconicus</ets>
Laconian, Gr. <?/<?/, fr. <?/<?/ a Laconian, Laced<ae/monian, or
Spartan: cf. F. <ets>laconique</ets>.]</ety> <sn>1.</sn> <def>Expressing
much in few words, after the manner of the Laconians or Spartans; brief
and pithy; concise; brusque; epigrammatic. In this sense
<ex>laconic</ex> is the usual form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I grow <qex>laconic</qex> even beyond laconicism; for sometimes I
return only yes, or no, to questionary or petitionary epistles of half a
yard long.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His sense was strong and his style <qex>laconic</qex>.</q>
<rj><qau>Welwood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Laconian; characteristic of, or like, the Spartans;
hence, stern or severe; cruel; unflinching.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His head had now felt the razor, his back the rod; all that
<qex>laconical</qex> discipline pleased him well.</q> <rj><qau>Bp.
Hall.</qau></rj></p>

<p><syn><b>Syn.</b> -- Short; brief; concise; succinct; sententious;
pointed; pithy.</syn> <usage> -- <er>Laconic</er>, <er>Concise</er>.
<xex>Concise</xex> means without irrelevant or superfluous matter; it is
the opposite of <xex>diffuse</xex>. <xex>Laconic</xex> means concise
with the additional quality of pithiness, sometimes of
brusqueness.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconic</ent><br/
<hw>La*con"ic</hw>, <pos>n.</pos> <def>Laconism.</def>
<mark>[Obs.]</mark> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconical</ent><br/
<hw>La*con"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Laconic</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconically</ent><br/
<hw>La*con"ic*al*ly</hw>, <pos>adv.</pos> <def>In a laconic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconicism</ent><br/
<hw>La*con"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Laconism</er>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconism</ent><br/
<hw>Lac"o*nism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr. <?/
to imitate Lacedaemonian manners, to speak laconically: cf. F.
<ets>laconisme</ets>.]</ety> <sn>1.</sn> <def>A vigorous, brief manner
of expression; laconic style.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instance of laconic style or
expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laconize</ent><br/
<hw>Lac"o*nize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Laconized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Laconizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Gr.
<?/. See <er>Laconic</er>.]</ety> <def>To imitate the manner of the
Laconians, especially in brief, pithy speech, or in frugality and
austerity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacquer</ent><br/
<hw>Lac"quer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>lacre</ets>
a sort of sealing wax, Pg. <ets>lacte</ets>, fr. <ets>laca</ets> lac.
See <er>Lac</er> the resin.]</ety> <altsp>[Written also
<asp>lacker</asp>.]</altsp> <def>A varnish, consisting of a solution of
shellac in alcohol, often colored with gamboge, saffron, or the like; --
used for varnishing metals, papier-mach<eacute/, and wood. The name is
also given to varnishes made of other ingredients, esp. the tough, solid
varnish of the Japanese, with which ornamental objects are
made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacquer</ent><br/
<hw>Lac"quer</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lacquered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lacquering</conjf>.]</vmorph> <def>To cover with lacquer.</def>
<ldquo/<xex>Lacquer'd</xex> chair.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacquerer</ent><br/
<hw>Lac"quer*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who lacquers,
especially one who makes a business of lacquering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacquering</ent><br/
<hw>Lac"quer*ing</hw>, <pos>n.</pos> <def>The act or business of putting
on lacquer; also, the coat of lacquer put on.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lacrimation</ent><br/
<hw>lacrimation</hw> <pos>n.</pos> <def>shedding tears; same as
<er>lachrymation</er>.</def><br/
<syn><b>Syn. --</b> lachrymation, tearing, watering.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lacrimator</ent><br/
<hw>lacrimator</hw> <pos>n.</pos> <def>a chemical substance that causes
tears to flow; same as <er>lachrymator</er>.</def><br/
<syn><b>Syn. --</b> lachrymator.</syn><br/
[<source>PJC</source>]</p>

<p><ent>lacrimatory</ent><br/
<hw>lacrimatory</hw> <pos>adj.</pos> <def>relating to or inducing tears;
-- especially of chemical substances; same as
<er>lachrymatory</er>.</def><br/
<syn><b>Syn. --</b> lachrymatory.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lacrimoso</ent><br/
\'d8<hw>La`cri*mo"so</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It. See
<er>Lachrymose</er>.]</ety> <fld>(Mus.)</fld> <def>Plaintive; -- a term
applied to a mournful or pathetic movement or style.</def>
<rj><au>Moore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacrosse</ent><br/
<hw>La*crosse"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>la
crosse</ets>, lit., the crosier, hooked stick. Cf.
<er>Crosier</er>.]</ety> <def>A game of ball, originating among the
North American Indians, now the popular field sport of Canada, and
played also in England and the United States. Each player carries a
long-handled racket, called a <ldquo/<xex>crosse</xex><rdquo/. The ball
is not handled but caught with the crosse and carried on it, or tossed
from it, the object being to carry it or throw it through one of the
goals placed at opposite ends of the field.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacrymal</ent><br/
<hw>Lac"ry*mal</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>See
<er>Lachrymatory</er>, <pos>n.</pos>, and <er>Lachrymal</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacrymose</ent><br/
<ent>Lacrytory</ent><br/
<ent>Lacrymary</ent><br/
<mhw>{ <hw>Lac"ry*ma*ry</hw>, <hw>Lac"ry*to*ry</hw>,
<hw>Lac"ry*mose</hw>. }</mhw> <def>See <er>Lachrymary</er>,
<er>Lachrymatory</er>, <er>Lachrymose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactage</ent><br/
<hw>Lac"tage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lac</ets>,
<ets>lactis</ets>, milk: cf. F. <ets>laitage</ets>. See
<er>Lacteal</er>.]</ety> <def>The produce of animals yielding milk; milk
and that which is made from it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactam</ent><br/
<hw>Lac"tam</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lact</ets>one +
<ets>ami</ets>do.]</ety> <fld>(Chem.)</fld> <def>One of a series of
anhydrides of an amido type, analogous to the lactones, as oxindol; a
cyclic amide.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>beta-lactam</b></col> <it>or</it>
<col><b><beta/-lactam</b></col></mcol>, <sd>(a)</sd> <cd>a lactam in
which the amide bond is contained within a four-membered ring, which
includes the amide nitrogen and the carbonyl carbon.</cd> <sd>(b)</sd>
<cd>an antibiotic containing a beta-lactam, such as a
<stype>penicillin</stype>, <stype>cephalosporin</stype>, or
<stype>carbapenem</stype>; also called a <altname>beta-lactam
antibiotic</altname>.</cd> <mark>[informal, laboratory
slang]</mark></cs><br/
[<source>PJC</source>]</p>

<p><ent>Lactamic</ent><br/
<hw>Lac*tam"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an amido acid related to lactic
acid, and called also <altname>amido-propionic</altname> acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactamide</ent><br/
<hw>Lac*tam"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lac</ets>tic
+ <ets>ami</ets>de.]</ety> <fld>(Chem.)</fld> <def>An acid amide derived
from lactic acid, and obtained as a white crystalline substance having a
neutral reaction. It is metameric with alanine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactant</ent><br/
<hw>Lac"tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lactans</ets>, p. pr. of <ets>lactare</ets> to suck, fr.
<ets>lac</ets>, <ets>lactis</ets>, milk.]</ety> <def>Suckling; giving
suck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactarene</ent><br/
<hw>Lac"ta*rene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk.]</ety> <def>A preparation of
casein from milk, used in printing calico.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactary</ent><br/
<hw>Lac"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lactarius</ets>, fr. <ets>lac</ets>, <ets>lactis</ets>, milk: cf.
F. <ets>lactaire</ets>.]</ety> <def>Milky; full of white juice like
milk.</def> <mark>[Obs.]</mark> <ldquo/<xex>Lactary</xex> or milky
plants.<rdquo/ <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactary</ent><br/
<hw>Lac"ta*ry</hw>, <pos>n.</pos> <def>a dairyhouse.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactate</ent><br/
<hw>Lac"tate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lac</ets>,
<ets>lactis</ets>, milk: cf. F. <ets>lactate</ets>.]</ety>
<fld>(Chem.)</fld> <def>A salt of lactic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lactating</ent><br/
<hw>lactating</hw> <pos>adj.</pos> <def>actively producing milk; -- of
female mammals.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Lactation</ent><br/
<hw>Lac*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The secretion and
yielding of milk by the mammary gland; giving suck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacteal</ent><br/
<hw>Lac"te*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lacteus</ets> milky, fr. <ets>lac</ets>, <ets>lactis</ets>, milk.
Cf. <er>Galaxy</er>, <er>Lettuce</er>.]</ety> <sn>1.</sn>
<def>Pertaining to, or resembling, milk; milky; <as>as, the
<ex>lacteal</ex> fluid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat. & Physiol.)</fld> <def>Pertaining to, or
containing, chyle; <as>as, the <ex>lacteal</ex> vessels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacteal</ent><br/
<hw>Lac"te*al</hw>, <pos>n.</pos> <fld>(Anat.)</fld> <def>One of the
lymphatic vessels which convey chyle from the small intestine through
the mesenteric glands to the thoracic duct; a chyliferous
vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacteally</ent><br/
<hw>Lac"te*al*ly</hw>, <pos>adv.</pos> <def>Milkily; in the manner of
milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactean</ent><br/
<hw>Lac"te*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lacteal</er>.]</ety> <sn>1.</sn> <def>Milky; consisting of, or
resembling, milk.</def> <ldquo/This <xex>lactean</xex> whiteness.<rdquo/
<rj><au>Moxon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat. & Physiol.)</fld> <def>Lacteal; conveying
chyle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacteous</ent><br/
<hw>Lac"te*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lacteal</er>.]</ety> <sn>1.</sn> <def>Milky; resembling milk.</def>
<ldquo/The <xex>lacteous</xex> circle.<rdquo/ <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lacteal; conveying chyle; <as>as, <ex>lacteous</ex>
vessels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacteously</ent><br/
<hw>Lac"te*ous*ly</hw>, <pos>adv.</pos> <def>In a lacteous manner; after
the manner of milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactescence</ent><br/
<hw>Lac*tes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lactescence</ets>.]</ety> <sn>1.</sn> <def>The state or quality of
producing milk, or milklike juice; resemblance to milk; a milky
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>lactescence</qex> does commonly ensue when . . . fair
water is suddenly poured upon the solution.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The latex of certain plants. See
<er>Latex</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactescent</ent><br/
<hw>Lac*tes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lactescens</ets>, p. pr. of <ets>lactescere</ets> to turn to milk,
incho. fr. <ets>lactere</ets> to be milky, fr. <ets>lac</ets>,
<ets>lactis</ets>, milk: cf. F. <ets>lactescent</ets>.]</ety>
<sn>1.</sn> <def>Having a milky look; becoming milky.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Producing milk or a milklike juice
or fluid, as the milkweed. See <er>Latex</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactic</ent><br/
<hw>Lac"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>lac</ets>,
<ets>lactis</ets>, milk: cf. F. <ets>lactique</ets>. See
<er>Lacteal</er>, and cf. <er>Galactic</er>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>Of or pertaining to milk; procured from sour milk or
whey; <as>as, <ex>lactic</ex> acid; <ex>lactic</ex> fermentation,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lactic acid</b></col> <fld>(Physiol. Chem.)</fld>, <cd>a
sirupy, colorless fluid, soluble in water, with an intensely sour taste
and strong acid reaction. There is one center of optical activity, and
this results in the observation of three isomeric modifications all
having the formula <chform>C3H6O3</chform>; one is dextrorotatory
(L-lactic acid), the other levorotatory (D-lactic acid), and the third
an optically inactive mixture of the first two (DL-lactic acid);
chemically it is <chname>2-hydroxypropanoic acid</chname>.
<stype>Sarcolactic acid</stype> or <stype>paralactic acid</stype> occurs
chiefly in dead muscle tissue, while <stype>ordinary lactic acid</stype>
(DL-lactic acid) results from fermentation, such as the fermentation of
milk by lactic acid bacteria. The two acids are alike in having the same
constitution (expressed by the name <altname>ethylidene lactic
acid</altname>), but the latter is optically inactive, while sarcolactic
acid rotates the plane of polarization to the right. The third acid,
<xex>ethylene lactic acid</xex>, accompanies sarcolactic acid in the
juice of flesh, and is optically inactive.</cd> -- <col><b>Lactic
ferment</b></col>, <cd>an organized ferment (<spn>Bacterium
lacticum</spn> <it>or</it> <spn>Bacterium lactis</spn>), which produces
lactic fermentation, decomposing the sugar of milk into carbonic and
lactic acids, the latter, of which renders the milk sour, and
precipitates the casein, thus giving rise to the so-called spontaneous
coagulation of milk.</cd> -- <col><b>Lactic fermentation</b></col>.
<cd>See under <er>Fermentation</er>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lactide</ent><br/
<hw>Lac"tide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lac</ets>tic +
anhydride.]</ety> <fld>(Chem.)</fld> <def>A white, crystalline
substance, obtained from lactic acid by distillation, and regarded as an
anhydride; also, by extension, any similar substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactiferous</ent><br/
<hw>Lac*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[l.
<ets>lac</ets>, <ets>lactis</ets>, milk + <ets>-ferous</ets>: cf. F.
<ets>lactif<egrave/re</ets>.]</ety> <def>Bearing or containing milk or a
milky fluid; <as>as, the <ex>lactiferous</ex> vessels, cells, or tissue
of various vascular plants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactifical</ent><br/
<ent>Lactific</ent><br/
<mhw>{ <hw>Lac*tif"ic</hw> <pr>(?)</pr>, <hw>Lac*tif"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lac</ets>,
<ets>lactis</ets>, milk + <ets>facere</ets> to make.]</ety>
<def>Producing or yielding milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactifuge</ent><br/
<hw>Lac"ti*fuge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk + <ets>fugare</ets> to
expel.]</ety> <fld>(Med.)</fld> <def>A medicine to check the secretion
of milk, or to dispel a supposed accumulation of milk in any part of the
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactim</ent><br/
<hw>Lac"tim</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lactic</ets> +
<ets>im</ets>ido.]</ety> <fld>(Chem.)</fld> <def>One of a series of
anhydrides resembling the lactams, but of an imido type; <as>as, isatine
is a <ex>lactim</ex></as>. Cf. <er>Lactam</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactimide</ent><br/
<hw>Lac*tim"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lactic</ets>
+ <ets>imide</ets>.]</ety> <fld>(Chem.)</fld> <def>A white, crystalline
substance obtained as an anhydride of alanine, and regarded as an imido
derivative of lactic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactin</ent><br/
<hw>Lac"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lac</ets>,
<ets>lactis</ets>, milk: cf. F. <ets>lactine</ets>. Cf.
<er>Galactin</er>.]</ety> <fld>(Physiol. Chem.)</fld> <def>See
<er>Lactose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactoabumin</ent><br/
<hw>Lac`to*a*bu"min</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk + E. <ets>albumin</ets>.]</ety>
<fld>(Physiol. Chem.)</fld> <def>The albumin present in milk, apparently
identical with ordinary serum albumin. It is distinct from the casein of
milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactobutyrometer</ent><br/
<hw>Lac`to*bu`ty*rom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk + E.
<ets>butyrometer</ets>.]</ety> <def>An instrument for determining the
amount of butter fat contained in a given sample of milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactodensimeter</ent><br/
<hw>Lac`to*den*sim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk + E.
<ets>densimeter</ets>.]</ety> <def>A form of hydrometer, specially
graduated, for finding the density of milk, and thus discovering whether
it has been mixed with water or some of the cream has been
removed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactometer</ent><br/
<hw>Lac*tom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk + <ets>meter</ets>: cf. F.
<ets>lactom<egrave/tre</ets>. Cf. <er>Galactometer</er>.]</ety> <def>An
instrument for estimating the purity or richness of milk, as a measuring
glass, a specific gravity bulb, or other apparatus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactone</ent><br/
<hw>Lac"tone</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>One of a series of organic compounds, being cyclic esters which may
be regarded as anhydrides of certain hydroxy acids. In general, they are
colorless liquids, having a weak aromatic odor. They are so called
because the typical lactone is derived from <xex>lactic</xex>
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactonic</ent><br/
<hw>Lac*ton"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Lactone</er>.]</ety> <fld>(Chem.)</fld> <def>Of, pertaining to, or
derived from, a lactone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactonic</ent><br/
<hw>Lac*ton"ic</hw>, <pos>a.</pos> <ety>[From <er>Lactose</er>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an acid obtained
by the oxidation of milk sugar (<xex>lactose</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactoprotein</ent><br/
<hw>Lac`to*pro"te*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets>, milk + E. <ets>protein</ets>.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A peculiar albuminous body considered a
normal constituent of milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactory</ent><br/
<hw>Lac"to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lactiferous.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Lactory</xex> or milky plants.<rdquo/
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactoscope</ent><br/
<hw>Lac"to*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lac</ets>, <ets>lactis</ets> + <ets>scope</ets>.]</ety> <def>An
instrument for estimating the amount of cream contained in milk by
ascertaining its relative opacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lactose</ent><br/
<hw>lac"tose`</hw> <pr>(l<acr/k"t<omac/s`)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Physiol. Chem.)</fld> <def>The main sugar present in
milk, called also <altname>sugar of milk</altname> or <altname>milk
sugar</altname>. When isolated pure it is obtained crystalline; it is
separable from the whey by evaporation and crystallization. It is a
disaccharide with the formula <chform>C12H22O11</chform>, being
chemically <chname>4-(<beta/-D-galactosido)-D-glucose</chname>. It has a
slightly sweet taste, is dextrorotary, and is much less soluble in water
than either cane sugar or glucose. Formerly called
<altname>lactin</altname>. When hydrolyzed it yields glucose and
galactose. In cells it may be hydrolyzed by the enzyme
<beta/-galactosidase.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>See <er>Galactose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lactose intolerance</ent><br/
<hw>lac"tose` in*tol"er*ance</hw> <pr>(l<acr/k"t<omac/s`
<icr/n*t<ocr/l"<etil/r*<ait/ns)</pr>, <pos>n.</pos> <def>A physiological
condition in which lactose cannot be hydrolyzed in the intestine,
leading to uncomfortable gaseousness, cramps, or diarrhea after eating a
lactose-containing food such as milk or ice cream. The symptoms may be
prevented by ingesting a preparation of beta-galactosidase before or
together with dairy products.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lactuca</ent><br/
\'d8<hw>Lac*tu"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., lettuce.
See <er>Lettuce</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of composite
herbs, several of which are cultivated for salad; lettuce.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactucarium</ent><br/
\'d8<hw>Lac`tu*ca"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
L. <ets>lactuca</ets> lettuce.]</ety> <def>The inspissated juice of the
common lettuce, sometimes used as a substitute for opium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactucic</ent><br/
<hw>Lac*tu"cic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, the juice of the <spn>Lactuca
virosa</spn>; -- said of certain acids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactucin</ent><br/
<hw>Lac*tu"cin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Lactuca</er>: cf. F. <ets>lactucine</ets>.]</ety> <fld>(Chem.)</fld>
<def>A white, crystalline substance, having a bitter taste and a neutral
reaction, and forming one of the essential ingredients of
lactucarium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactucone</ent><br/
<hw>Lac*tu"cone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Lactuca</er>.]</ety> <fld>(Chem.)</fld> <def>A white, crystalline,
tasteless substance, found in the milky sap of species of Lactuca, and
constituting an essential ingredient of lactucarium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacturamic</ent><br/
<hw>Lac`tu*ram"ic</hw> <pr>(<?/)</pr>, <pos>a.</pos>
<ety>[<ets>Lactic</ets> + <ets>urea</ets> + <ets>amic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an organic amido
acid, which is regarded as a derivative of lactic acid and
urea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lactyl</ent><br/
<hw>Lac"tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lactic</ets> +
<ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>An organic residue or
radical (<chform>CH3.CHOH.CO-</chform>) derived from lactic
acid.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lacuna</ent><br/
<ent>Lacunae</ent><br/
\'d8<hw>La*cu"na</hw> <pr>(l<adot/*k<umac/"n<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Lacun<ae/</plw>
<pr>(l<adot/*k<umac/"n<ae/)</pr>; E. <plw>Lacunas</plw>
<pr>(l<adot/*k<umac/"n<adot/z)</pr>.</plu> <ety>[L., ditch, pit, lake,
orig., anything hollow. See <er>Lagoon</er>.]</ety> <sn>1.</sn> <def>A
small opening; a small pit or depression; a small blank space; a gap or
vacancy; a hiatus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>A small opening; a small
depression or cavity; a space, as a vacant space between the cells of
plants, or one of the spaces left among the tissues of the lower
animals, which serve in place of vessels for the circulation of the body
fluids, or the cavity or sac, usually of very small size, in a mucous
membrane.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 824 --></p>

<p><ent>Lacunar</ent><br/
<ent>Lacunal</ent><br/
<mhw>{ <hw>La*cu"nal</hw> <pr>(l<adot/*k<umac/"n<ait/l)</pr>,
<hw>La*cu"nar</hw> <pr>(l<adot/*k<umac/"n<etil/r)</pr>, }</mhw>
<pos>a.</pos> <def>Pertaining to, or having, lacun<ae/; <as>as, a
<ex>lacunar</ex> circulation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacunar</ent><br/
<hw>La*cu"nar</hw>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Lacunars</plw> <pr>(l<adot/*k<umac/"n<etil/rz)</pr>, L.
<plw>Lacunaria</plw>
<pr>(l<acr/k`<usl/*n<amac/"r<icr/*<adot/)</pr>.</plu> <ety>[L.]</ety>
<fld>(Arch.)</fld> <sd>(a)</sd> <def>The ceiling or under surface of any
part, especially when it consists of compartments, sunk or hollowed
without spaces or bands between the panels.</def> <au>Gwilt</au>
<sd>(b)</sd> <def>One of the sunken panels in such a ceiling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacune</ent><br/
<hw>La*cune"</hw> <pr>(l<adot/*k<umac/n")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A lacuna.</def> <mark>[R.]</mark>
<au>Landor.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacunous</ent><br/
<ent>Lacunose</ent><br/
<mhw>{ <hw>Lac"u*nose`</hw> <pr>(?)</pr>, <hw>La*cu"nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lacunosus</ets> full
of holes or hollows; cf. F. <ets>lacuneux</ets>. See
<er>Lacuna</er>.]</ety> <fld>(Biol.)</fld> <def>Furrowed or pitted;
having shallow cavities or lacun<ae/; <as>as, a <ex>lacunose</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacustrine</ent><br/
<ent>Lacustral</ent><br/
<mhw>{ <hw>La*cus"tral</hw> <pr>(?)</pr>, <hw>La*cus"trine</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lacus</ets> lake: cf.
F. <ets>lacustral</ets>, <ets>lacustre</ets>.]</ety> <def>Found in, or
pertaining to, lakes or ponds, or growing in them; <as>as,
<ex>lacustrine</ex> flowers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lacustrine deposits</b></col> <fld>(Geol.)</fld>, <cd>the
deposits which have been accumulated in fresh-water areas.</cd> --
<col><b>Lacustrine dwellings</b></col>. <cd>See <cref>Lake
dwellings</cref>, under <er>Lake</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lacwork</ent><br/
<hw>Lac"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ornamentation by
means of lacquer painted or carved, or simply colored, sprinkled with
gold or the like; -- said especially of Oriental work of this
kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lad</ent><br/
<hw>Lad</hw> <pr>(l<acr/d)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos>
of <er>Lead</er>, to guide.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lad</ent><br/
<hw>Lad</hw> <pr>(l<acr/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ladde</ets>, of Celtic origin; cf. W. <ets>llawd</ets>, Ir.
<ets>lath</ets>. <root/123. Cf. <er>Lass</er>.]</ety> <sn>1.</sn> <def>A
boy; a youth; a stripling.</def> <ldquo/Cupid is a knavish
<xex>lad</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a <qex>lad</qex> here, which hath five barley loaves and
two small fishes.</q> <rj><qau>John vi. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A companion; a comrade; a mate.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lad's love</b></col>. <fld>(Bot.)</fld> <cd>See
<cref>Boy's love</cref>, under <er>Boy</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladanum</ent><br/
<hw>Lad"a*num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ladanum</ets>, <ets>ledanum</ets>, Gr. <grk>la`danon</grk>,
<grk>lh`danon</grk>, fr. <grk>lh^don</grk> name of a shrub, mastic; cf.
Per. <ets>l<amac/dan</ets>, <ets>l<amac/den</ets>. Cf.
<er>Laudanum</er>.]</ety> <def>A gum resin gathered from certain
Oriental species of <gen>Cistus</gen>. It has a pungent odor and is
chiefly used in making plasters, and for fumigation.</def>
<altsp>[Written also <asp>labdanum</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladde</ent><br/
<hw>Lad"de</hw> <pr>(?)</pr>, <mark>(obs.)</mark> <def><pos>imp.</pos>
of <er>Lead</er>, to guide.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladder</ent><br/
<hw>Lad"der</hw> <pr>(l<acr/d"d<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>laddre</ets>, AS. <ets>hl<aemac/der</ets>,
<ets>hl<aemac/dder</ets>; akin to OFries. <ets>hladder</ets>, OHG.
<ets>leitara</ets>, G. <ets>leiter</ets>, and from the root of E.
<ets>lean</ets>, v. <root/40. See <er>Lean</er>, <pos>v. i.</pos>, and
cf. <er>Climax</er>.]</ety> <sn>1.</sn> <def>A frame usually portable,
of wood, metal, or rope, for ascent and descent, consisting of two side
pieces to which are fastened cross strips or rounds forming
steps.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some the engines play,<br/
And some, more bold, mount <qex>ladders</qex> to the fire.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles a ladder in form or use;</def>
<specif>hence,</specif> <def>that by means of which one attains to
eminence; <as>as, to climb the corporate <ex>ladder</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Lowliness is young ambition's <qex>ladder</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fish ladder</b></col>. <cd>See under <er>Fish</er>.</cd>
-- <col><b>Ladder beetle</b></col> <fld>(Zool.)</fld>, <cd>an American
leaf beetle (<spn>Chrysomela scalaris</spn>). The elytra are silvery
white, striped and spotted with green; the under wings are rose-colored.
It feeds upon the linden tree.</cd> -- <col><b>Ladder handle</b></col>,
<cd>an iron rail at the side of a vertical fixed ladder, to grasp with
the hand in climbing.</cd> -- <col><b>Ladder shell</b></col>
<fld>(Zool.)</fld>, <cd>a spiral marine shell of the genus
<gen>Scalaria</gen>. See <er>Scalaria</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>ladder-back</ent><br/
<hw>ladder-back</hw> <pos>n.</pos> <def>a chair with a
ladder-back{2}.</def><br/
<syn><b>Syn. --</b> ladder-back chair.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a chair backrest consisting of 2 uprights with
several connecting slats.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>ladder-backed</ent><br/
<hw>ladder-backed</hw> <pos>n.</pos> <def>Having horizontal stripes on
the back, reminiscent of a ladder; -- used of birds; <as>as, a
<ex>ladder-backed</ex> woodpecker</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>ladder truck</ent><br/
<ent>ladder company</ent><br/
<mhw><hw>ladder company</hw>, <hw>ladder truck</hw></mhw> <pos>n.</pos>
<def>Same as <er>hook-and-ladder company</er>, <er>hook-and-ladder
truck</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>ladder-proof</ent><br/
<hw>ladder-proof</hw> <pos>adj.</pos> <def>resistant to runs or (in
Britain) ladders; -- of hosiery.</def><br/
<syn><b>Syn. --</b> runproof, run-resistant.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Laddie</ent><br/
<hw>Lad"die</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lad; a male
sweetheart.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lade</ent><br/
<hw>Lade</hw> <pr>(l<amac/d)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Laded</conjf>; <pos>p. p.</pos>
<conjf>Laded</conjf>, <conjf>Laden</conjf> <pr>(l<amac/d'n)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Lading</conjf>.]</vmorph> <ety>[AS.
<ets>hladan</ets> to heap, load, draw (water); akin to D. & G.
<ets>laden</ets> to load, OHG. <ets>hladan</ets>, <ets>ladan</ets>,
Icel. <ets>hla<edh/a</ets>, Sw. <ets>ladda</ets>, Dan. <ets>lade</ets>,
Goth. <ets>afhla<thorn/an</ets>. Cf. <er>Load</er>, <er>Ladle</er>,
<er>Lathe</er> for turning, <er>Last</er> a load.]</ety> <sn>1.</sn>
<def>To load; to put a burden or freight on or in; -- generally followed
by that which receives the load, as the direct object.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And they <qex>laded</qex> their asses with the corn.</q>
<rj><qau>Gen. xlii. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw in or out, with a ladle or dipper; to dip;
<as>as, to <ex>lade</ex> water out of a tub, or into a
cistern</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And chides the sea that sunders him from thence,<br/
Saying, he'll <qex>lade</qex> it dry to have his way.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Plate Glass Manuf.)</fld> <def>To transfer (the
molten glass) from the pot to the forming table.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lade</ent><br/
<hw>Lade</hw>, <pos>v. i.</pos> <ety>[See <er>Lade</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>To draw water.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To admit water by leakage, as a
ship, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lade</ent><br/
<hw>Lade</hw>, <pos>n.</pos> <ety>[Prov. E., a ditch or drain. Cf.
<er>Lode</er>, <er>Lead</er> to conduct.]</ety> <sn>1.</sn> <def>The
mouth of a river.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Gibson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A passage for water; a ditch or drain.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lademan</ent><br/
<hw>Lade"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who leads a pack
horse; a miller's servant.</def> <mark>[Obs. or Local]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laden</ent><br/
<hw>Lad"en</hw> <pr>(?)</pr>, <pos>p. & a.</pos> <def>Loaded; freighted;
burdened; <as>as, a <ex>laden</ex> vessel; a <ex>laden</ex>
heart.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ah sinful nation, a people <qex>laden</qex> with iniquity.</q>
<rj><qau>Is. i. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A ship <qex>laden</qex> with gold.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladied</ent><br/
<hw>La"died</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ladylike; not rough;
gentle.</def> <mark>[Obs.]</mark> <ldquo/Stroked with a
<xex>ladied</xex> land.<rdquo/ <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladies' eardrops</ent><br/
<hw>La"dies' ear`drops`</hw> <pr>(?)</pr> <pos>n.</pos>
<fld>(Bot.)</fld> <def>The small-flowered Fuchsia (<spn>Fuchsia
coccinea</spn>), and other closely related species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladify</ent><br/
<hw>La"di*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Lady</ets> +
<ets>-fy</ets>.]</ety> <def>To make a lady of; to make ladylike.</def>
<mark>[Obs.]</mark> <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladin</ent><br/
<hw>La*din"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>Latinus</ets> Latin. See <er>Latin</er>]</ety> <sn>1.</sn> <def>A
Romansch dialect spoken in some parts of Switzerland and the
Tyrol.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person speaking Ladin as a mother
tongue.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lading</ent><br/
<hw>Lad"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of
loading.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which lades or constitutes a load or cargo;
freight; burden; <as>as, the <ex>lading</ex> of a ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bill of lading</b></col>. <cd>See under
<er>Bill</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladino</ent><br/
<hw>La*di"no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ladinos</plw> <pr>(#)</pr>.</plu> <ety>[Sp.]</ety> <def>One of the
half-breed descendants of whites and Indians; a mestizo; -- so called
throughout Central America. They are usually of a yellowish orange
tinge.</def> <rj><au>Am. Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladino</ent><br/
<hw>La*di"no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl. <plw>-nos</plw>
<pr>(<?/)</pr></plu> <sn>1.</sn> <def>The mixed Spanish and Hebrew
language spoken by Sephardim.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A cunningly vicious horse.</def> <mark>[Southeastern
U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>A ladin.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ladkin</ent><br/
<hw>Lad"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little lad.</def>
<mark>[R.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladle</ent><br/
<hw>La"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hl<ae/del</ets>, fr. <ets>hladan</ets> to load, drain. See
<er>Lade</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A cuplike spoon,
often of large size, with a long handle, used in lading or
dipping.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the materials of glass have been kept long in fusion, the
mixture casts up the superfluous salt, which the workmen take off with
<qex>ladles</qex>.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Founding)</fld> <def>A vessel to carry liquid metal
from the furnace to the mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The float of a mill wheel; -- called also
<altname>ladle board</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gun.)</fld> <sd>(a)</sd> <def>An instrument for
drawing the charge of a cannon.</def> <sd>(b)</sd> <def>A ring, with a
handle or handles fitted to it, for carrying shot.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ladle wood</b></col> <fld>(Bot.)</fld>, <cd>the wood of a
South African tree (<spn>Cassine Colpoon</spn>), used for
carving.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladle</ent><br/
<hw>La"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Ladled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ladling</conjf> <pr>(?)</pr>.]</vmorph> <def>To take up and
convey in a ladle; to dip with, or as with, a ladle; <as>as, to
<ex>ladle</ex> out soup; to <ex>ladle</ex> oatmeal into a
kettle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladleful</ent><br/
<hw>La"dle*ful</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ladlefuls</plw> <pr>(<?/)</pr>.</plu> <def>A quantity sufficient to
fill a ladle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladrone</ent><br/
<hw>La*drone"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>ladron</ets>, L. <ets>latro</ets> servant, robber, Gr. (<?/) a
servant.]</ety> <def>A robber; a pirate; hence, loosely, a rogue or
rascal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady</ent><br/
<hw>La"dy</hw> <pr>(l<amac/"d<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Ladies</plw> <pr>(l<amac/"d<icr/z)</pr>.</plu>
<ety>[OE. <ets>ladi</ets>, <ets>l<ae/fdi</ets>, AS.
<ets>hl<aemac/fdige</ets>, <ets>hl<aemac/fdie</ets>; AS.
<ets>hl<amac/f</ets> loaf + a root of uncertain origin, possibly akin to
E. <ets>dairy</ets>. See <er>Loaf</er>, and cf.
<er>Lord</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A woman who looks after the domestic affairs of a
family; a mistress; the female head of a household.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Agar, the handmaiden of Sara, whence comest thou, and whither
goest thou? The which answered, Fro the face of Sara my
<qex>lady</qex>.</q> <rj><qau>Wyclif (Gen. xvi. 8.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman having proprietary rights or authority;
mistress; -- a feminine correlative of <xex>lord</xex>.</def>
<ldquo/Lord or <xex>lady</xex> of high degree.<rdquo/
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of all these bounds, even from this line to this, . . . <br/
We make thee <qex>lady</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A woman to whom the particular homage of a knight
was paid; a woman to whom one is devoted or bound; a
sweetheart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soldier here his wasted store supplies,<br/
And takes new valor from his <qex>lady's</qex> eyes.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A woman of social distinction or position. In
England, a title prefixed to the name of any woman whose husband is not
of lower rank than a baron, or whose father was a nobleman not lower
than an earl. The wife of a baronet or knight has the title of
<xex>Lady</xex> by courtesy, but not by right.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A woman of refined or gentle manners; a well-bred
woman; -- the feminine correlative of
<contr>gentleman</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A wife; -- not now in approved usage.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <specif>Hence:</specif> <def>Any woman; <as>as, a lounge
for <ex>ladies</ex>; a cleaning <ex>lady</ex></as>; also used in
combination; <as>as, sales<ex>lady</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <fld>(Zool.)</fld> <def>The triturating apparatus in the
stomach of a lobster; -- so called from a fancied resemblance to a
seated female figure. It consists of calcareous plates.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ladies' man</b></col>, <cd>a man who affects the society
of ladies.</cd> -- <col><b>Lady altar</b></col>, <cd>an altar in a lady
chapel.</cd> <au>Shipley.</au> -- <col><b>Lady chapel</b></col>, <cd>a
chapel dedicated to the Virgin Mary.</cd> -- <col><b>Lady
court</b></col>, <cd>the court of a lady of the manor.</cd> --
<col><b>Lady crab</b></col> <fld>(Zool.)</fld>, <cd>a handsomely spotted
swimming crab (<spn>Platyonichus ocellatus</spn>) very common on the
sandy shores of the Atlantic coast of the United States.</cd> --
<col><b>Lady fern</b></col>. <fld>(Bot.)</fld> <cd>See <cref>Female
fern</cref>, under <er>Female</er>, and <xex>Illust.</xex> of
<er>Fern</er>.</cd> -- <col><b>Lady in waiting</b></col>, <cd>a lady of
the queen's household, appointed to wait upon or attend the queen.</cd>
-- <col><b>Lady Mass</b></col>, <cd>a Mass said in honor of the Virgin
Mary.</cd> <au>Shipley.</au> <col><b>Lady of the manor</b></col>, <cd>a
lady having jurisdiction of a manor; also, the wife of a manor
lord.</cd> <col><b>Lady's maid</b></col>, <cd>a maidservant who dresses
and waits upon a lady.</cd> <au>Thackeray.</au> -- <col><b>Our
Lady</b></col>, <cd>the Virgin Mary.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady</ent><br/
<hw>La"dy</hw>, <pos>a.</pos> <def>Belonging or becoming to a lady;
ladylike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ldquo/Some <qex>lady</qex> trifles.<rdquo/
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>ladybeetle</ent><br/
<hw>ladybeetle</hw> <pos>n.</pos> <def>Same as
<er>ladybird</er>.</def><br/
<syn><b>Syn. --</b> ladybug, lady beetle, ladybird, ladybird
beetle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ladybird</ent><br/
<hw>La"dy*bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Equiv. to, bird
of Our Lady.]</ety> <fld>(Zool.)</fld> <def>Any one of numerous species
of small beetles of the genus <gen>Coccinella</gen> and allied genera
(family <fam>Coccinellid<ae/</fam>); -- called also
<altname>ladybug</altname>, <altname>ladyclock</altname>, <altname>lady
cow</altname>, <altname>lady fly</altname>,
<altname>ladybeetle</altname>, and <altname>lady beetle</altname>.
<spn>Coccinella seplempunctata</spn> in one of the common European
species. See <er>Coccinella</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The ladybirds are usually more or less hemispherical in
form, with a smooth, polished surface, and often colored red, brown, or
black, with small spots of brighter colors. Both the larvae and the
adult beetles of most species feed on aphids, and for this reason they
are very beneficial to agriculture and horticulture.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladybug</ent><br/
<hw>La"dy*bug`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Ladybird</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladyclock</ent><br/
<hw>La"dy*clock`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Ladybird</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady Day</ent><br/
<hw>La"dy` Day`</hw> <pr>(d<amac/)</pr> <pos>n.</pos> <def>The day of
the annunciation of the Virgin Mary, March 25. See
<er>Annunciation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladyfish</ent><br/
<hw>La"dy*fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A large, handsome oceanic fish (<spn>Albula
vulpes</spn>), found both in the Atlantic and Pacific oceans; -- called
also <altname>bonefish</altname>, <altname>grubber</altname>,
<altname>French mullet</altname>, and
<altname>macab<eacute/</altname>.</def> <sd>(b)</sd> <def>A labroid fish
(<spn>Harpe rufa</spn>) of Florida and the West Indies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladyhood</ent><br/
<hw>La"dy*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being a lady; the personality of a lady.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lady-in-waiting</ent><br/
<hw>lady-in-waiting</hw> <pos>n.</pos> <def>a lady appointed to attend
to a queen or princess.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lady-killer</ent><br/
<hw>La"dy-kill`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A gallant who
captivates the hearts of women.</def> <ldquo/A renowned dandy and
<xex>lady-killer</xex>.<rdquo/ <rj><au>Blackw. Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady-killing</ent><br/
<hw>La"dy-kill`ing</hw>, <pos>n.</pos> <def>The art or practice of
captivating the hearts of women.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Better for the sake of womankind that this dangerous dog should
leave off <qex>lady-killing</qex>.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladykin</ent><br/
<hw>La"dy*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lady</ets> +
<ets>-kin</ets>.]</ety> <def>A little lady; -- applied by the writers of
Queen Elizabeth's time, in the abbreviated form
<altname>Lakin</altname>, to the Virgin Mary.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The diminutive does not refer to size, but is equivalent
to <ldquo/dear.<rdquo/</note> <rj><au>Brewer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladylike</ent><br/
<hw>La"dy*like`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Like a
lady in appearance or manners; well-bred.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She was <qex>ladylike</qex>, too, after the manner of the feminine
gentility of those days.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Becoming or suitable to a lady; <as>as,
<ex>ladylike</ex> manners</as>.</def> <ldquo/With fingers
<xex>ladylike</xex>.<rdquo/ <rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Delicate; tender; feeble; effeminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Too <qex>ladylike</qex> a long fatigue to bear.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladylikeness</ent><br/
<hw>La"dy*like`ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being ladylike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladylove</ent><br/
<hw>La"dy*love`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sweetheart or
mistress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lady-of-the-night</ent><br/
<hw>lady-of-the-night</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A West
Indian shrub (<spn>Brunfelsia americana</spn>) with fragrant showy
yellowish-white flowers.</def><br/
<syn><b>Syn. --</b> lady of the night, Brunfelsia americana.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lady's bedstraw</ent><br/
<hw>La"dy's bed"straw`</hw> <pr>(?)</pr>, <fld>(Bot.)</fld> <def>The
common bedstraw (<spn>Galium verum</spn>); also, a slender-leaved East
Indian shrub (<spn>Pharnaceum Mollugo</spn>), with white flowers in
umbels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's bower</ent><br/
<hw>La"dy's bow"er</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Bot.)</fld>
<def>A climbing plant with fragrant blossoms (<spn>Clematis
vitalba</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term is sometimes applied to other plants of the
same genus.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's cloth</ent><br/
<hw>La"dy's cloth`</hw> <pr>(?)</pr> <def>A kind of broadcloth of light
weight, used for women's dresses, cloaks, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lady's comb</ent><br/
<hw>La"dy's comb"</hw> <pr>(?)</pr>, <fld>(Bot.)</fld> <def>An
umbelliferous plant (<spn>Scandix Pecten-Veneris</spn>), its clusters of
long slender fruits remotely resembling a comb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's cushion</ent><br/
<hw>La"dy's cush"ion</hw> <pr>(?)</pr>, <fld>(Bot.)</fld> <def>An herb
growing in dense tufts; the thrift (<spn>Armeria
vulgaris</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lady's-eardrop</ent><br/
<hw>lady's-eardrop</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An erect or climbing shrub (<spn>Fuchsia coccinea</spn>) of Brazil
with deep pink to red flowers.</def><br/
<syn><b>Syn. --</b> ladies'-eardrop, lady's-eardrops, ladies'-eardrops,
<spn>Fuchsia coccinea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lady's finger</ent><br/
<hw>La"dy's fin"ger</hw> <pr>(?)</pr>, <sn>1.</sn> <pluf>pl.</pluf>
<fld>(Bot.)</fld> <def>The kidney vetch, <spn>Anthyllis
vulneraria</spn>; called also <altname>lady's
fingers</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Cookery)</fld> <def>A variety of small cake of
about the dimensions of a finger.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A long, slender variety of the potato.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>One of the branchiae of the
lobster.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Bot.)</fld> <def>A tall coarse annual
(<spn>Abelmoschus esculentus</spn>) of Old World tropics widely
cultivated in southern U. S. and West Indies for its long mucilaginous
green pods used as basis for soups and stews; it is sometimes placed in
the genus <gen>Hibiscus</gen>.</def> <wns>[wns=1]</wns> <note>different
from <er>lady's fingers</er></note><br/
<syn><b>Syn. --</b> okra, gumbo, okra plant, <spn>Abelmoschus
esculentus</spn>, Hibiscus esculentus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lady's garters</ent><br/
<hw>La"dy's gar"ters</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Bot.)</fld>
<def>Ribbon grass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's hair</ent><br/
<hw>La"dy's hair"</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Bot.)</fld>
<def>A plant of the genus <gen>Briza</gen> (<spn>Briza media</spn>); a
variety of quaking grass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladyship</ent><br/
<hw>La"dy*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The rank or
position of a lady; -- given as a title (preceded by <xex>her</xex> or
<xex>your</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>ladyship</qex> shall observe their gravity.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's laces</ent><br/
<hw>La"dy's la"ces</hw> <pr>(l<amac/"d<icr/z l<amac/"s<ecr/z)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>A slender climbing plant;
dodder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lady-slipper</ent><br/
<hw>lady-slipper</hw> <pos>n.</pos> <pr>(l<amac/"d<ycr/
sl<icr/p"p<etil/r)</pr>, <fld>(Bot.)</fld> <def>Same as <er>lady's
slipper</er>.</def><br/
<syn><b>Syn. --</b> lady's slipper, lady's-slipper, slipper
orchid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lady's looking-glass</ent><br/
<hw>La"dy's look"ing-glass`</hw> <pr>(l<amac/"d<icr/z l<oocr/k"<icr/ng
gl<adot/s`)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See <cref>Venus's
looking-glass</cref>, under <er>Venus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's mantle</ent><br/
<hw>La"dy's man"tle</hw> <pr>(l<amac/"d<icr/z m<acr/n"t'l)</pr>.
<fld>(Bot.)</fld> <def>A genus of rosaceous herbs
(<gen>Alchemilla</gen>), esp. the European <spn>Alchemilla
vulgaris</spn>, which has leaves with rounded and finely serrated
lobes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's seal</ent><br/
<hw>La"dy's seal"</hw> <pr>(l<amac/"d<icr/z
s<emac/l")</pr>.<fld>(Bot.)</fld> <sd>(a)</sd> <def>The European
Solomon's seal (<spn>Polygonatum verticillatum</spn>).</def>
<sd>(b)</sd> <def>The black bryony (<spn>Tamus
communis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's slipper</ent><br/
<hw>La"dy's slip"per</hw> <pr>(l<amac/"d<icr/z sl<icr/p"p<etil/r)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>Any orchidaceous plant of the genus
<gen>Cypripedium</gen>, the labellum of which resembles a slipper. Less
commonly, in the United States, the garden balsam (<spn>Impatiens
Balsamina</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's smock</ent><br/
<hw>La"dy's smock"</hw> <pr>(l<amac/"d<icr/z sm<ocr/k")</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Cardamine</gen> (<spn>Cardamine pratensis</spn>); cuckoo
flower.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's thimble</ent><br/
<hw>La"dy's thim"ble</hw> <pr>(l<amac/"d<icr/z th<icr/m"b'l)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>The harebell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lady's thumb</ent><br/
<hw>La"dy's thumb"</hw> <pr>(l<amac/"d<icr/z th<ucr/m")</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>An annual weed (<spn>Polygonum
Persicaria</spn>), having a lanceolate leaf with a dark spot in the
middle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ladies' tresses</ent><br/
<ent>Lady's traces</ent><br/
<mhw>{ <hw>La"dy's tra"ces</hw> <pr>(l<amac/"d<icr/z
tr<amac/"s<ecr/z)</pr>, <hw>La"dies' tress"es</hw> <pr>(l<amac/"d<icr/z
tr<ecr/s"s<ecr/z)</pr>. }</mhw> <pos>n.</pos> <fld>(Bot.)</fld> <def>A
name given to several species of the orchidaceous genus
<gen>Spiranthes</gen>, in which the white flowers are set in spirals
about a slender axis and remotely resemble braided hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laelaps</ent><br/
\'d8<hw>L<ae/"laps</hw> <pr>(l<emac/"l<acr/ps)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>lai^laps</grk> a dark, furious storm.]</ety>
<fld>(Paleon.)</fld> <def>A genus of huge, carnivorous, dinosaurian
reptiles from the Cretaceous formation of the United States. They had
very large hind legs and tail, and are supposed to have been bipedal.
Some of the species were about eighteen feet high.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laemmergeyer</ent><br/
<hw>Laem"mer*gey`er</hw> <pr>(l<ecr/m"m<etil/r*g<imac/`<etil/r)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>See <er>Lammergeir</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laemodipod</ent><br/
<hw>L<ae/*mod"i*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Laemodipoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laemodipoda</ent><br/
\'d8<hw>L<ae/`mo*dip"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., from Gr. <grk>lai`mos</grk> throat + <grk>di`s</grk> twice +
<grk>poy`s</grk>, <grk>podo`s</grk>, foot.]</ety> <fld>(Zool.)</fld>
<def>A division of amphipod Crustacea, in which the abdomen is small or
rudimentary and the legs are often reduced to five pairs. The whale
louse, or <gen>Cyamus</gen>, and <gen>Caprella</gen> are
examples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laemodipodous</ent><br/
<hw>L<ae/`mo*dip"o*dous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Laemodipoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laetere Sunday</ent><br/
<hw>L<ae/*te"re Sun"day</hw> <pr>(?)</pr> <pos>n.</pos> <def>The fourth
Sunday of Lent; -- so named from the Latin word <xex>L<ae/tare</xex>
(rejoice), the first word in the antiphone of the introit sung that day
in the Roman Catholic service.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laevigate</ent><br/
<hw>L<ae/v"i*gate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Levigate</er>.]</ety> <fld>(Biol.)</fld> <def>Having a smooth
surface, as if polished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laevo-</ent><br/
<hw>L<ae/"vo-</hw> <pr>(?)</pr> <pos>pref.</pos> <def>A prefix. See
<er>Levo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laevorotatory</ent><br/
<hw>L<ae/"vo*ro"ta*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Levorotatory</er>. Cf. <er>Dextrorotatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laevulose</ent><br/
<hw>L<ae/v"u*lose`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Levulose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lafayette</ent><br/
<hw>La`fa`yette"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The dollar fish.</def> <sd>(b)</sd> <def>A market
fish, the goody, or spot (<spn>Liostomus xanthurus</spn>), of the
southern coast of the United States.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laft</ent><br/
<hw>Laft</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of
<er>Leave</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lafte</ent><br/
<hw>Laf"te</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Leave</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lag</ent><br/
<hw>Lag</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Of Celtic origin: cf.
Gael. & Ir. <ets>lag</ets>weak, feeble, faint, W. <ets>llag</ets>,
<ets>llac</ets>, slack, loose, remiss, sluggish; prob. akin to E.
<ets>lax</ets>, <ets>languid</ets>.]</ety> <sn>1.</sn> <def>Coming
tardily after or behind; slow; tardy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Came too <qex>lag</qex> to see him buried.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Last; long-delayed; -- obsolete, except in the
phrase <xex>lag end</xex>.</def> <ldquo/The <xex>lag end</xex> of my
life.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 825 --></p>

<p><sn>3.</sn> <def>Last made; hence, made of refuse; inferior.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Lag</xex> souls.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lag</ent><br/
<hw>Lag</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who lags;
that which comes in last.</def> <mark>[Obs.]</mark> <ldquo/The
<xex>lag</xex> of all the flock.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fag-end; the rump; hence, the lowest
class.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The common <qex>lag</qex> of people.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The amount of retardation of anything, as of a valve
in a steam engine, in opening or closing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A stave of a cask, drum, etc.;</def>
<specif>especially</specif>: <fld>(Mach.)</fld>, <def>one of the narrow
boards or staves forming the covering of a cylindrical object, as a
boiler, or the cylinder of a carding machine or a steam
engine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>See <er>Graylag</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The failing behind or retardation of one phenomenon
with respect to another to which it is closely related; <as>as, the
<ex>lag</ex> of magnetization compared with the magnetizing force
(hysteresis); the <ex>lag</ex> of the current in an alternating circuit
behind the impressed electro-motive force which produced
it</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Lag of the tide</b></col>, <cd>the interval by which the
time of high water falls behind the mean time, in the first and third
quarters of the moon; -- opposed to <contr>priming</contr> of the tide,
or the acceleration of the time of high water, in the second and fourth
quarters; depending on the relative positions of the sun and moon.</cd>
-- <col><b>Lag screw</b></col>, <cd>an iron bolt with a square head, a
sharp-edged thread, and a sharp point, adapted for screwing into wood; a
screw for fastening lags.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lag</ent><br/
<hw>Lag</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lagged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lagging</conjf> <pr>(?)</pr>.]</vmorph> <def>To walk or more
slowly; to stay or fall behind; to linger or loiter.</def> <ldquo/I
shall not <xex>lag</xex> behind.<rdquo/ <rj><au>Milton.</au></rj></p>

<p><syn><b>Syn.</b> -- To loiter; linger; saunter; delay; be
tardy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lag</ent><br/
<hw>Lag</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to lag; to
slacken.</def> <mark>[Obs.]</mark> <ldquo/To <xex>lag</xex> his
flight.<rdquo/ <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>To cover, as the cylinder of a
steam engine, with lags. See <er>Lag</er>, <pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lag</ent><br/
<hw>Lag</hw>, <pos>n.</pos> <def>One transported for a crime.</def>
<mark>[Slang, Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lag</ent><br/
<hw>Lag</hw>, <pos>v. t.</pos> <def>To transport for crime.</def>
<mark>[Slang, Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>lags</qex> us if we poach.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagan</ent><br/
<hw>La"gan</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Ligan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagarto</ent><br/
<hw>La*gar"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Alligator</er>.]</ety> <def>An alligator.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagena</ent><br/
<ent>Lagenae</ent><br/
\'d8<hw>La*ge"na</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Lagen<ae/</plw> <pr>(#)</pr>, E. <plw>Lagenas</plw>
<pr>(#)</pr>.</plu> <ety>[L., a flask; cf. Gr. <?/, <?/.]</ety>
<fld>(Anat.)</fld> <def>The terminal part of the cochlea in birds and
most reptiles; an appendage of the sacculus, corresponding to the
cochlea, in fishes and amphibians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagenian</ent><br/
<hw>La*ge"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lagena</er>.]</ety> <fld>(Zool.)</fld> <def>Like, or pertaining to,
<gen>Lagena</gen>, a genus of <ord>Foraminifera</ord> having a straight,
chambered shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lageniform</ent><br/
<hw>La*ge"ni*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lagena</er>, and <er>-form</er>.]</ety> <fld>(Bot.)</fld>
<def>Shaped like a bottle or flask; flag-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagenophera</ent><br/
<hw>Lagenophera</hw> <pos>prop. n.</pos> <def>A small genus of herbs of
Australia and South America having small solidary white or purple
flowers similar to true daisies of genus <gen>Bellis</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lagenophera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lager</ent><br/
<hw>La"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Lager beer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lager beer</ent><br/
<hw>La"ger beer`</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[G.
<ets>lager</ets> bed, storehouse + <ets>bier</ets> beer. See
<er>Lair</er>, and <er>Beer</er>.]</ety> <def>Originally a German beer,
but now also made in immense quantities in the United States; -- so
called from its being laid up or stored for some months before
use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lager wine</ent><br/
<hw>La"ger wine`</hw> <pr>(?)</pr> <pos>n.</pos> <def>Wine which has
been kept for some time in the cellar.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laggard</ent><br/
<hw>Lag"gard</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Lag</ets> +
<ets>-ard</ets>.]</ety> <def>Slow; sluggish; backward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laggard</ent><br/
<hw>Lag"gard</hw>, <pos>n.</pos> <def>One who lags; a
loiterer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagger</ent><br/
<hw>Lag"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A laggard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagging</ent><br/
<hw>Lag"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Mach.)</fld> <def>The clothing (esp., an outer, wooden covering),
as of a steam cylinder, applied to prevent the radiation of heat; a
covering of lags; -- called also <altname>deading</altname> and
<altname>cleading</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lags, collectively; narrow planks extending from one
rib to another in the centering of arches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laggingly</ent><br/
<hw>Lag"ging*ly</hw>, <pos>adv.</pos> <def>In a lagging manner;
loiteringly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagly</ent><br/
<hw>Lag"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Laggingly.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagnappe</ent><br/
<ent>Lagniappe</ent><br/
<mhw>{ <hw>La*gniappe</hw> <pr>(?)</pr>, <hw>La*gnappe"</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <altsp>[Also spelled
<asp>lagnappe</asp>.]</altsp><ety>[Etym. uncertain.]</ety> <sn>1.</sn>
<def>In Louisiana, a trifling present given to customers by tradesmen; a
gratuity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lagniappe</qex> . . .is something thrown in, gratis, for good
measure.</q> <rj><qau>Mark Twain.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A tip or gratuity.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>Anything obtained
gratuitously or unexpectedly.</def><br/
[<source>PJC</source>]</p>

<p><ent>lagomorph</ent><br/
<hw>lag"o*morph</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the <ord>Lagomorpha</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagomorpha</ent><br/
\'d8<hw>Lag`o*mor"pha</hw> <pr>(l<acr/g`<osl/*m<ocir/r"f<adot/)</pr>,
<pos>prop. n. pl.</pos> <ety>[NL., fr. Gr. <grk>lagw`s</grk> a hare +
<grk>morfh`</grk> form.]</ety> <fld>(Zool.)</fld> <def>an order of
rodent-like mammals, comprising the hares, rabbits, and pikas. They have
four incisors in the upper jaw. Called also
<altname>Duplicidentata</altname>. They were formerly classified
together with the rodents, but the <ord>Rodentia</ord> and
<ord>Lagomorpha</ord> are now classed as separate orders.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>lagoon</ent><br/
<hw>la*goon"</hw> <pr>(l<adot/*g<oomac/n")</pr>, <pos>n.</pos> <ety>[It.
or Sp. <ets>laguna</ets>, L. <ets>lacuna</ets> ditch, pool, pond,
<ets>lacus</ets> lake. See <er>Lake</er>, and cf.
<er>Lacuna</er>.]</ety> <altsp>[Written also <asp>lagune</asp>.]</altsp>
<sn>1.</sn> <def>A shallow sound, channel, pond, or lake, especially one
into which the sea flows; <as>as, the <ex>lagoons</ex> of
Venice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lake in a coral island, often occupying a large
portion of its area, and usually communicating with the sea. See
<er>Atoll</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lagoon island</b></col>, <cd>a coral island consisting of
a narrow reef encircling a lagoon.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagophthalmos</ent><br/
<ent>Lagophthalmia</ent><br/
<mhw>{ \'d8<hw>Lag`oph*thal"mi*a</hw> <pr>(?)</pr>,
\'d8<hw>Lag`oph*thal"mos</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[NL. <ets>lagophtalmia</ets>, fr. Gr. <grk>lagw`s</grk> hare +
<grk>'ofqalmo`s</grk> eye; -- so called from the notion that a hare
sleeps with his eyes open.]</ety> <fld>(Med.)</fld> <def>A morbid
condition in which the eye stands wide open, giving a peculiar staring
appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagopous</ent><br/
<hw>La*go"pous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>lagw`s</grk> a hare + <grk>poy`s</grk>, <grk>podo`s</grk>,
foot.]</ety> <fld>(Bot.)</fld> <def>Having a dense covering of long
hair, like the foot of a hare.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lagorchestes</ent><br/
<hw>Lagorchestes</hw> <pos>prop. n.</pos> <def>A mammal genus comprising
the hare wallabies.</def><br/
<syn><b>Syn. --</b> genus <gen>Lagorchestes</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lagostomus</ent><br/
<hw>Lagostomus</hw> <pos>prop. n.</pos> <def>A mammal genus comprising
the viscachas.</def><br/
<syn><b>Syn. --</b> genus <gen>Lagostomus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lagothrix</ent><br/
<hw>Lagothrix</hw> <pos>prop. n.</pos> <def>A mammal genus comprising
the woolly monkeys.</def><br/
<syn><b>Syn. --</b> genus <gen>Lagothrix</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lagthing</ent><br/
\'d8<hw>Lag"thing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Norw.
<ets>lagting</ets>, <ets>lagthing</ets>; <ets>lag</ets> company, society
(akin to E. <ets>law</ets>, <ets>lay</ets>) + <ets>ting</ets>,
<ets>thing</ets>, parliament. See <er>Thing</er>.]</ety> <def>See
<er>Legislatature</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lagune</ent><br/
<hw>La*gune"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lagoon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laical</ent><br/
<ent>Laic</ent><br/
<mhw>{ <hw>La"ic</hw> <pr>(?)</pr>, <hw>La"ic*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>laicus</ets>: cf. F.
<ets>la<ium/que</ets>. See <er>Lay</er> laic.]</ety> <def>Of or
pertaining to a layman or the laity.</def> <ldquo/<xex>Laical</xex>
literature.<rdquo/ <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An unprincipled, unedified, and <qex>laic</qex> rabble.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laic</ent><br/
<hw>La"ic</hw>, <pos>n.</pos> <def>A layman.</def> <rj><au>Bp.
Morton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laicality</ent><br/
<hw>La"ic*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being laic; the state or condition of a layman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laically</ent><br/
<hw>La"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>As a layman;
after the manner of a layman; <as>as, to treat a matter
<ex>laically</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laid</ent><br/
<hw>Laid</hw> <pr>(?)</pr>, <pos>imp. & p. p.</pos> <def>of
<er>Lay</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Laid paper</b></col>, <cd>paper marked with parallel
lines or water marks, as if ribbed, from parallel wires in the mold. It
is called <xex>blue laid</xex>, <xex>cream laid</xex>, etc., according
to its color.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laidly</ent><br/
<hw>Laid"ly</hw>, <pos>a.</pos> <def>Ugly; loathsome.</def> <mark>[Prov.
Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>laidly</qex> and loathsome worm.</q> <rj><qau>W.
Howitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lain</ent><br/
<hw>Lain</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of <er>Lie</er>,
<pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lainere</ent><br/
<hw>Lain"ere</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lanier</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lair</ent><br/
<hw>Lair</hw> <pr>(l<acir/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>leir</ets>, AS. <ets>leger</ets>; akin to D. <ets>leger</ets>, G.
<ets>lager</ets> couch, lair, OHG. <ets>legar</ets>, Goth.
<ets>ligrs</ets>, and to E. <ets>lie</ets>. See <er>Lie</er> to be
prostrate, and cf. <er>Layer</er>, <er>Leaguer</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A place in which to lie or rest; especially, the bed
or couch of a wild beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A burying place.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pasture; sometimes, food.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laird</ent><br/
<hw>Laird</hw> <pr>(l<acir/rd)</pr>, <pos>n.</pos> <ety>[See
<er>Lord</er>.]</ety> <def>A lord; a landholder, esp. one who holds land
directly of the crown.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lairdship</ent><br/
<hw>Laird"ship</hw>, <pos>n.</pos> <def>The state of being a laird; an
estate; landed property.</def> <mark>[Scot.]</mark>
<rj><au>Ramsay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laism</ent><br/
<hw>La"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lamaism</er>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laissez faire</ent><br/
\'d8<hw>Lais`sez" faire"</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[F., let
alone.]</ety> <def>Noninterference; -- an axiom of some political
economists, deprecating interference of government by attempts to foster
or regulate commerce, manufactures, etc., by bounty or by restriction;
<as>as, the doctrine of <ex>laissez faire</ex>; <ex>the laissez
faire</ex> system of government.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laity</ent><br/
<hw>La"i*ty</hw> <pr>(l<amac/"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<ety>[See <er>Lay</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The
people, as distinguished from the clergy; the body of the people not in
orders.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A rising up of the <qex>laity</qex> against the sacerdotal
caste.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of a layman.</def> <mark>[Obs.]</mark>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Those who are not of a certain profession, as law or
medicine, in distinction from those belonging to it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lakao</ent><br/
\'d8<hw>La*ka"o</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Sap green.</def>
<mark>[China]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lake</ent><br/
<hw>Lake</hw> <pr>(l<amac/k)</pr>, <pos>n.</pos> <ety>[F.
<ets>laque</ets>, fr. Per. See <er>Lac</er>.]</ety> <def>A pigment
formed by combining some coloring matter, usually by precipitation, with
a metallic oxide or earth, esp. with aluminium hydrate; <as>as, madder
<ex>lake</ex>; Florentine <ex>lake</ex>; yellow <ex>lake</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lake</ent><br/
<hw>Lake</hw>, <pos>n.</pos> <ety>[Cf. G. <ets>laken</ets>.]</ety>
<def>A kind of fine white linen, formerly in use.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lake</ent><br/
<hw>Lake</hw> <pr>(l<amac/k)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>l<amac/can</ets>, <ets>l<ae/can</ets>, to spring, jump,
<ets>l<amac/c</ets> play, sport, or fr. Icel. <ets>leika</ets> to play,
sport; both akin to Goth. <ets>laikan</ets> to dance. <root/120. Cf.
<er>Knowledge</er>.]</ety> <def>To play; to sport.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lake</ent><br/
<hw>Lake</hw>, <pos>n.</pos> <ety>[AS. <ets>lac</ets>, L.
<ets>lacus</ets>; akin to AS. <ets>lagu</ets> lake, sea, Icel.
<ets>l<oum/gr</ets>; OIr. <ets>loch</ets>; cf. Gr. <grk>la`kkos</grk>
pond, tank. Cf. <er>Loch</er>, <er>Lough</er>.]</ety> <def>A large body
of water contained in a depression of the earth's surface, and supplied
from the drainage of a more or less extended area.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Lakes are for the most part of fresh water; the salt
lakes, like the Great Salt Lake of Utah, have usually no outlet to the
ocean.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lake dwellers</b></col> <fld>(Ethnol.)</fld>, <cd>people
of a prehistoric race, or races, which inhabited different parts of
Europe. Their dwellings were built on piles in lakes, a short distance
from the shore. Their relics are common in the lakes of
Switzerland.</cd> -- <col><b>Lake dwellings</b></col>
<fld>(Archaeol.)</fld>, <cd>dwellings built over a lake, sometimes on
piles, and sometimes on rude foundations kept in place by piles;
specifically, such dwellings of prehistoric times. Lake dwellings are
still used by many savage tribes. Called also <altname>lacustrine
dwellings</altname>. See <er>Crannog</er>.</cd> -- <col><b>Lake
fly</b></col> <fld>(Zool.)</fld>, <cd>any one of numerous species of
dipterous flies of the genus <gen>Chironomus</gen>. In form they
resemble mosquitoes, but they do not bite. The larvae live in
lakes.</cd> -- <col><b>Lake herring</b></col> <fld>(Zool.)</fld>,
<cd>the cisco (<spn>Coregonus Artedii</spn>).</cd> -- <mcol><col><b>Lake
poets</b></col>, <col><b>Lake school</b></col></mcol>, <cd>a collective
name originally applied in contempt, but now in honor, to Southey,
Coleridge, and Wordsworth, who lived in the lake country of Cumberland,
England, Lamb and a few others were classed with these by hostile
critics. Called also <altname>lakers</altname> and
<altname>lakists</altname>.</cd> -- <col><b>Lake sturgeon</b></col>
<fld>(Zool.)</fld>, <cd>a sturgeon (<spn>Acipenser rubicundus</spn>), of
moderate size, found in the Great Lakes and the Mississippi River. It is
used as food.</cd> -- <col><b>Lake trout</b></col> <fld>(Zool.)</fld>,
<cd>any one of several species of trout and salmon; in Europe, esp.
<spn>Salmo fario</spn>; in the United States, esp. <spn>Salvelinus
namaycush</spn> of the Great Lakes, and of various lakes in New York,
Eastern Maine, and Canada. A large variety of brook trout
(<spn>Salvelinus fontinalis</spn>), inhabiting many lakes in New
England, is also called <ex>lake trout</ex>. See
<er>Namaycush</er>.</cd> -- <col><b>Lake whitefish</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Whitefish</er>.</cd> -- <col><b>Lake
whiting</b></col> <fld>(Zool.)</fld>, <cd>an American whitefish
(<spn>Coregonus Labradoricus</spn>), found in many lakes in the Northern
United States and Canada. It is more slender than the common
whitefish.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lake-dweller</ent><br/
<hw>Lake"-dwell`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <cref>Lake
dwellers</cref>, under <er>Lake</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lakefront</ent><br/
<hw>lakefront</hw> <pos>n.</pos> <def>land bordering a lake.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lakelet</ent><br/
<hw>Lake"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little lake.</def>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laker</ent><br/
<hw>Lak"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One that is connected
with a lake or lakes, as in habitation, toil, etc.:</def> <sd>(a)</sd>
<def>One of the poets of the Lake school. See <cref>Lake poets</cref>,
under <er>Lake</er>, <pos>n.</pos></def> <sd>(b)</sd> <fld>(Zool.)</fld>
<def>A fish living in, or taken from, a lake, esp. the namaycush.</def>
<sd>(c)</sd> <def>A lake steamer or canal boat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bridge tender . . . thought the Cowies <ldquo/a little
mite<rdquo/ longer than that <qex>laker</qex>.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>lakeshore</ent><br/
<hw>lakeshore</hw> <pos>n.</pos> <def>the shore of a lake.</def><br/
<syn><b>Syn. --</b> lakeside.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lakeside</ent><br/
<hw>lakeside</hw> <pos>n.</pos> <def>the shore of a lake.</def><br/
<syn><b>Syn. --</b> lakeshore.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lakeweed</ent><br/
<hw>Lake"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The water pepper (<spn>Polygonum Hydropiper</spn>), an aquatic
plant of Europe and North America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lakh</ent><br/
\'d8<hw>Lakh</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Lac</er>,
one hundred thousand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lakin</ent><br/
<hw>La"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ladykin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lakke</ent><br/
<hw>Lak"ke</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Lack</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laky</ent><br/
<hw>Lak"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
lake.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laky</ent><br/
<hw>Lak"y</hw>, <pos>a.</pos> <ety>[From <er>Lake</er> the
pigment.]</ety> <def>Transparent; -- said of blood rendered transparent
by the action of some solvent agent on the red blood
corpuscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lallation</ent><br/
<hw>Lal*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lallare</ets> to sing lalla, or lullaby: cf. F.
<ets>lallation</ets>.]</ety> <def>An imperfect enunciation of the letter
<it>r</it>, in which it sounds like <it>l</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lalo</ent><br/
<hw>La"lo</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The powdered leaves of
the baobab tree, used by the Africans to mix in their soup, as the
southern negroes use powdered sassafras. Cf.
<er>Couscous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lam</ent><br/
<hw>Lam</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lammed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lamming</conjf>.]</vmorph> <ety>[Icel. <ets>lemja</ets> to beat,
or <ets>lama</ets> to bruise, both fr. <ets>lami</ets>, <ets>lama</ets>,
lame. See <er>Lame</er>.]</ety> <def>To beat soundly; to thrash.</def>
<mark>[Obs. or Low]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lama</ent><br/
<hw>La"ma</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Llama</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lama</ent><br/
<hw>La"ma</hw>, <pos>n.</pos> <ety>[Tibet. <ets>blama</ets> (pronounced
<pr>l<aum/"ma</pr>) a chief, a high priest.]</ety> <def>In Tibet,
Mongolia, etc., a priest or monk of the belief called Lamaism.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>The Grand Lama</b></col>, <it>or</it> <col><b>Dalai
Lama</b></col></mcol> <ety>[lit., Ocean Lama]</ety>, <cd>the supreme
pontiff in the lamaistic hierarchy. Until the Chinese occupied Tibet he
resided in Lhasa, but now (1998) is in exile. See
<er>Lamaism</er>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lamaic</ent><br/
<hw>La"ma*ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Lamaism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamaism</ent><br/
<hw>La"ma*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A modified form of
Buddhism which prevails in Tibet, Mongolia, and some adjacent parts of
Asia; -- so called from the name of its priests. See 2d
<er>Lama</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamaite</ent><br/
<ent>Lamaist</ent><br/
<mhw>{ <hw>La"ma*ist</hw> <pr>(?)</pr>, <hw>La"ma*ite</hw> <pr>(?)</pr>
}</mhw> <pos>n.</pos> <def>One who believes in Lamaism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamaistic</ent><br/
<hw>La`ma*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Lamaism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamantin</ent><br/
<hw>La*man"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lamantin</ets>, <ets>lamentin</ets>, prob. from the name of the
animal in the Antilles. Cf. <er>Manater</er>.]</ety> <fld>(Zool.)</fld>
<def>The manatee.</def> <altsp>[Written also <asp>lamentin</asp>, and
<asp>lamantine</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamarckian</ent><br/
<hw>La*marck"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or involved in, the doctrines of Lamarckianism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamarckianism</ent><br/
<hw>La*marck"i*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Biol.)</fld> <def>Lamarckism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamarckism</ent><br/
<hw>La"marck"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Lamarck</ets>, a distinguished French naturalist.]</ety>
<fld>(Biol.)</fld> <def>The theory that structural variations,
characteristic of species and genera, are produced in animals and plants
by the direct influence of physical environments, and esp., in the case
of animals, by effort, or by use or disuse of certain organs. It is a
discredited theory, not believed by modern biologists.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lamasery</ent><br/
<hw>La"ma*ser*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 2d
<er>Lama</er>.]</ety> <def>A monastery or convent of lamas, in Tibet,
Mongolia, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamb</ent><br/
<hw>Lamb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>lamb</ets>;
akin to D. & Dan. <ets>lam</ets>, G. & Sw. <ets>lamm</ets>, OS., Goth.,
& Icel. <ets>lamb</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>The
young of the sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any person who is as innocent or gentle as a
lamb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A simple, unsophisticated person; in the cant of the
Stock Exchange, one who ignorantly speculates and is
victimized.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Lamb of God</b></col>, <col><b>The
Lamb</b></col></mcol> <fld>(Script.)</fld>, <cd>the Jesus Christ, in
allusion to the paschal lamb.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The twelve apostles of <qex>the Lamb</qex>.</q> <rj><qau>Rev. xxi.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold the <qex>Lamb of God</qex>, which taketh away the sin of
the world.</q> <rj><qau>John i. 29.</qau></rj></p>

<p>-- <col><b>Lamb's lettuce</b></col> <fld>(Bot.)</fld>, <cd>an annual
plant with small obovate leaves (<spn>Valerianella olitoria</spn>),
often used as a salad; corn salad.</cd> <altsp>[Written also <asp>lamb
lettuce</asp>.]</altsp> -- <col><b>Lamb's tongue</b></col>, <cd>a
carpenter's plane with a deep narrow bit, for making curved
grooves.</cd> <au>Knight.</au> -- <col><b>Lamb's wool</b></col>.
<sd>(a)</sd> <cd>The wool of a lamb.</cd> <sd>(b)</sd> <cd>Ale mixed
with the pulp of roasted apples; -- probably from the resemblance of the
pulp of roasted apples to lamb's wool.</cd> <mark>[Obs.]</mark>
<au>Goldsmith.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Lamb</ent><br/
<hw>Lamb</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lambed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lambing</conjf>.]</vmorph> <def>To bring forth a lamb or lambs,
as sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambale</ent><br/
<hw>Lamb"ale`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A feast at the time
of shearing lambs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lambast</ent><br/
<hw>lam*bast"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Same as
<er>lambaste</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lambaste</ent><br/
<hw>Lam*baste"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Lam</ets>
+ <ets>baste</ets> to beat.]</ety> <def>To beat severely;</def>
<specif>specifically,</specif> <def>to beat with a cane.</def>
<mark>[Low]</mark> <rj><au>Nares.</au></rj><br/
<syn><b>Syn. --</b> cane, flog, lambaste.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to scold, reprimand, or berate harshly.</def><br/
<syn><b>Syn. --</b> rebuke, rag, reproof, reprimand, jaw, dress down,
scold, chide, berate, bawl out, jaw at, remonstrate with, chew out, chew
up, have words with, lambast.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lambative</ent><br/
<hw>Lam"ba*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lambere</ets> to lick. See <er>Lambent</er>.]</ety> <def>Taken by
licking with the tongue.</def> <ldquo/Sirups and <xex>lambative</xex>
medicines.<rdquo/ <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambative</ent><br/
<hw>Lam"ba*tive</hw>, <pos>n.</pos> <def>A medicine taken by licking
with the tongue; a lincture.</def> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambda</ent><br/
\'d8<hw>Lamb"da</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>la`mbda</grk>.]</ety> <sn>1.</sn> <def>The name of the Greek letter
<LAMBDA/, <lambda/, corresponding with the English letter L,
l.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The point of junction of the
sagittal and lambdoid sutures of the skull.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Phys.)</fld> <def>A subatomic particle carrying no
charge, having a mass equal to 2183 times that of an electron; it decays
rapidly, typically forming a nucleon and a pion.</def> <au>MW10</au><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Lambda moth</b></col> <fld>(Zool.)</fld>, <cd>a moth so
called from a mark on its wings, resembling the Greek letter lambda
(<LAMBDA/).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambdacism</ent><br/
<hw>Lamb"da*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lambdacismus</ets>, Gr. <?/, fr. <grk>la`mbda</grk> the letter
lambda (<LAMBDA/).]</ety> <sn>1.</sn> <def>A fault in speaking or in
composition, which consists in too frequent use of the letter
<it>l</it>, or in doubling it erroneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A defect in pronunciation of the letter <it>l</it>
when doubled, which consists in giving it a sound as if followed by
<it>y</it>, similar to that of the letters <it>lli</it> in
<it>billion</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The use of the sound of <it>l</it> for that of
<it>r</it> in pronunciation; lallation; <as>as, Ame<it>l</it>ican for
Ame<it>r</it>ican</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambdoid</ent><br/
<hw>Lamb"doid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/,
<grk>la`mbda</grk> the letter lambda (<LAMBDA/) + <grk>e"i^dos</grk>
shape.]</ety> <def>Shaped like the Greek letter lambda (<LAMBDA/);
<as>as, the <ex>lambdoid</ex> suture between the occipital and parietal
bones of the skull</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambdoidal</ent><br/
<hw>Lamb*doid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Lambdoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambent</ent><br/
<hw>Lam"bent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lambens</ets>, <ets>-enlis</ets>, p. pr. of <ets>lambere</ets> to
lick; akin to <ets>lap</ets>. See <er>Lap</er> to drink by
licking.]</ety> <sn>1.</sn> <def>Playing on the surface; touching
lightly; gliding over.</def> <ldquo/A <xex>lambent</xex> flame.<rdquo/
<au>Dryden.</au> <ldquo/A <xex>lambent</xex> style.<rdquo/
<au>Beaconsfield.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Twinkling or gleaming; fickering.</def> <ldquo/The
<xex>lambent</xex> purity of the stars.<rdquo/ <rj><au>W.
Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambertia</ent><br/
<hw>Lambertia</hw> <pos>n.</pos> <def>A small genus of Australian
shrubs.</def><br/
<syn><b>Syn. --</b> genus <gen>Lambertia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lambert pine</ent><br/
<hw>Lam"bert pine`</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[So called from
<etsep>Lambert</etsep>, an English botanist.]</ety> <fld>(Bot.)</fld>
<def>The gigantic sugar pine of California and Oregon (<spn>Pinus
Lambertiana</spn>). It has the leaves in fives, and cones a foot long.
The timber is soft, and like that of the white pine of the Eastern
States.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambis</ent><br/
<hw>Lambis</hw> <pos>n.</pos> <def>A genus of scorpion shells of shallow
tropical waters of eastern hemisphere.</def><br/
<syn><b>Syn. --</b> genus <gen>Lambis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lambkill</ent><br/
<hw>Lamb"kill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
small American ericaceous shrub (<spn>Kalmia angustifolia</spn>),
resembling mountain laurel but having narrower leaves and small red
flowers; -- called also <altname>calfkill</altname>,
<altname>sheepkill</altname>, <altname>sheep laurel</altname>, etc. It
is supposed to poison young sheep and other animals that eat it at times
when the snow is deep and they cannot find other food.</def><br/
<syn><b>Syn. --</b> sheep laurel, pig laurel, <spn>Kalmia
angustifolia</spn>.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Lambkin</ent><br/
<hw>Lamb"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small
lamb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamblike</ent><br/
<hw>Lamb"like</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a lamb; gentle;
meek; inoffensive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamboys</ent><br/
<hw>Lam"boys</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Cf. F.
<ets>lambeau</ets>. Cf. <er>Label</er>.]</ety> <fld>(Anc. Armor)</fld>
<def>Same as <er>Base</er>, <pos>n.</pos>, 19.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambrequin</ent><br/
<hw>Lam"bre*quin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Cf.
<er>Lamboys</er>, <er>Label</er>.]</ety> <sn>1.</sn> <def>A kind of
pendent scarf or covering attached to the helmet, to protect it from wet
or heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A leather flap hanging from a cuirass.</def>
<rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A piece of ornament drapery or short decorative
hanging, pendent from a shelf or from the casing above a window, hiding
the curtain fixtures, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambskin</ent><br/
<hw>Lamb"skin`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
skin of a lamb; especially, a skin dressed with the wool on, and used as
a mat. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of woolen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lambskinnet</ent><br/
<hw>Lamb"skin`net"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lansquenet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamb's-quarters</ent><br/
<hw>Lamb's-quar"ters</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A name given to several common weedy European plants of the
Goosefoot family, introduced into N. America, and sometimes used as pot
herbs, as <spn>Chenopodium album</spn> and <spn>Atriplex
patulsa</spn>.</def> <note>It is sometimes collected from the wild and
eaten as a vegetable</note><br/
<syn><b>Syn. --</b> lamb's quarters, pigweed, wild spinach, Chenopodium
album.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Lamdoidal</ent><br/
<hw>Lam*doid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lambdoid.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lame</ent><br/
<hw>Lame</hw> <pr>(l<amac/m)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Lamer</adjf>
<pr>(l<amac/m"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Lamest</adjf>.]</amorph> <ety>[OE. <ets>lame</ets>, AS.
<ets>lama</ets>; akin to D. <ets>lam</ets>, G. <ets>lahm</ets>, OHG.,
Dan., & Sw. <ets>lam</ets>, Icel. <ets>lami</ets>, Russ.
<ets>lomate</ets> to break, <ets>lomota</ets> rheumatism.]</ety>
<sn>1.</sn> <sd>(a)</sd> <def>Moving with pain or difficulty on account
of injury, defect, or temporary obstruction of a function; <as>as, a
<ex>lame</ex> leg, arm, or muscle</as>.</def> <sd>(b)</sd> <def>To some
degree disabled by reason of the imperfect action of a limb; crippled;
<as>as, a <ex>lame</ex> man</as>.</def> <ldquo/<xex>Lame</xex> of one
leg.<rdquo/ <au>Arbuthnot.</au> <ldquo/<xex>Lame</xex> in both his
feet.<rdquo/ <au>2 Sam. ix. 13.</au> <ldquo/He fell, and became
<xex>lame</xex>.<rdquo/ <au>2 Sam. iv. 4.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, hobbling; limping; inefficient; imperfect;
<as>as, a <ex>lame</ex> answer</as>.</def> <ldquo/A <xex>lame</xex>
endeavor.<rdquo/ <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, most <qex>lame</qex> and impotent conclusion!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lame duck</b></col> <sd>(a)</sd> <fld>(Stock
Exchange)</fld>, <cd>a person who can not fulfill his contracts.</cd>
<mark>[Cant]</mark> <sd>(b)</sd> <cd>An elected politician who is
completing a term after having been defeated at an election; also, an
office holder who cannot or chooses not to run again for the same
office; -- So called from the presumed lack of political power of one
who is soon to be out of office.</cd> <sd>(b)</sd> <cd>Any office holder
who is serving out a term after a replacement has been
selected.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><-- p. 826 --></p>

<p><ent>Lame</ent><br/
<hw>Lame</hw> <pr>(l<amac/m)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lamed</conjf> <pr>(l<amac/md)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Laming</conjf>.]</vmorph> <def>To make lame.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If you happen to let child fall and <qex>lame</qex> it.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lamedh</ent><br/
<hw>lamedh</hw> <pos>n.</pos> <def>The 12th letter of the Hebrew
alphabet, corresponding to <sig>l</sig>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lamel</ent><br/
<hw>Lam"el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lamella</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamella</ent><br/
<ent>Lamellae</ent><br/
<hw>La*mel"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Lamell<ae/</plw> <pr>(#)</pr>, E. <plw>Lamellas</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>lamella</ets>, dim. of
<ets>lamina</ets> plate, leaf, layer: cf. F. <ets>lamelle</ets>. Cf.
<er>Lamina</er>, <er>Omelet</er>.]</ety> <def>A thin plate or scale of
anything, as a thin scale growing from the petals of certain flowers; or
one of the thin plates or scales of which certain shells are
composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellarly</ent><br/
<ent>Lamellar</ent><br/
<hw>Lam"el*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lamellaire</ets>.]</ety> <def>Flat and thin; lamelliform; composed
of lamellAE.</def> -- <def2><hw>Lam"el*lar*ly</hw>, <pos>adv.</pos>
<def>In thin plates or scales.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellary</ent><br/
<hw>Lam"el*la*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to lamella or to lamellae; lamellar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellated</ent><br/
<ent>Lamellate</ent><br/
<mhw>{ <hw>Lam"el*late</hw> <pr>(?)</pr>, <hw>Lam"el*la`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Lamella</er>.]</ety>
<def>Composed of, or furnished with, thin plates or scales. See
<xex>Illust.</xex> of <er>Antenn<ae/</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellibranch</ent><br/
<hw>La*mel"li*branch</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the <class>Lamellibranchia</class> (also called
<class>Pelecypoda</class>). Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellibranchiata</ent><br/
<ent>Lamellibranchia</ent><br/
<mhw>{ \'d8<hw>La*mel`li*bran"chi*a</hw> <pr>(?)</pr>,
\'d8<hw>La*mel`li*bran`chi*a"ta</hw> <pr>(?)</pr>, }</mhw> <pos>n.
pl.</pos> <ety>[NL. See <er>lamella</er>, and <er>Branchia</er>,
<er>Branchiate</er>.]</ety> <fld>(Zool.)</fld> <def>An earlier name for
the class of <isa><phylum>Mollusca</phylum></isa> including all those
that have bivalve shells, as the clams, oysters, mussels, etc., now
called <altname><class>Pelecypoda</class></altname> or
<altname><class>Bivalvia</class></altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ They usually have two (rarely but one) flat, lamelliform
gills on each side of the body. They have an imperfectly developed head,
concealed within the shell, whence they are called
<altname><ord>Acephala</ord></altname>. Called also
<altname>Conchifera</altname>, and <altname>Pelecypoda</altname>. See
<er>Bivalve</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellibranchiate</ent><br/
<hw>Lam`el*li*bran"chi*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having lamellar gills; belonging to the
<class>Lamellibranchia</class> (also called
<class>Pelecypoda</class>).</def> -- <def2><pos>n.</pos> <def>One of the
<class>Lamellibranchia</class> (also called
<class>Pelecypoda</class>).</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellicorn</ent><br/
<hw>La*mel"li*corn</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lamella</ets> + L. <ets>cornu</ets> a horn: cf. F.
<ets>lamellicorne</ets>. See <er>Lamella</er>.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>Having antennae terminating in a group of flat
lamellae; -- said of certain coleopterous insects.</def> <sd>(b)</sd>
<def>Terminating in a group of flat lamellae; -- said of antennae.</def>
-- <def2><pos>n.</pos> <def>A lamellicorn insect.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellicornia</ent><br/
\'d8<hw>La*mel`li*cor"ni*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Lamellicorn</er>.]</ety> <fld>(Zool.)</fld> <def>A
group of lamellicorn, plant-eating beetles; -- called also
<altname>Lamellicornes</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamelliferous</ent><br/
<hw>Lam`el*lif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lamella</ets> + <ets>-ferous</ets>: cf. F.
<ets>lamellif<egrave/re</ets>.]</ety> <def>Bearing, or composed of,
lamellae, or thin layers, plates, or scales; foliated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamelliform</ent><br/
<hw>La*mel"li*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lamella</ets> + <ets>-form</ets> : cf. F.
<ets>lamelliforme</ets>.]</ety> <def>Thin and flat; scalelike;
lamellar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellirostral</ent><br/
<hw>Lam`el*li*ros"tral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lamella</ets> + <ets>rostral</ets> : cf. F.
<ets>lamellirostre</ets>.]</ety> <fld>(Zool.)</fld> <def>Having a
lamellate bill, as ducks and geese.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellirostres</ent><br/
\'d8<hw>La*mel`li*ros"tres</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Lamella</er>, and <er>Rostrum</er>.]</ety>
<fld>(Zool.)</fld> <def>A group of birds embracing the Anseres and
flamingoes, in which the bill is lamellate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamellose</ent><br/
<hw>Lam"el*lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lamelleux</ets>.]</ety> <def>Composed of, or having, lamellae;
lamelliform.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamely</ent><br/
<hw>Lame"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[See
<er>Lame</er>.]</ety> <def>In a lame, crippled, disabled, or imperfect
manner; <as>as, to walk <ex>lamely</ex>; a figure <ex>lamely</ex>
drawn.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lameness</ent><br/
<hw>Lame"ness</hw>, <pos>n.</pos> <def>The condition or quality of being
lame; <as>as, the <ex>lameness</ex> of an excuse or an
argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lament</ent><br/
<hw>La*ment"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[F.
<ets>lamenter</ets>, L. <ets>lamentari</ets>, fr. <ets>lamentum</ets> a
lament.]</ety> <def>To express or feel sorrow; to weep or wail; to
mourn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jeremiah <qex>lamented</qex> for Josiah.</q> <rj><qau>2 Chron.
xxxv. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye shall weep and <qex>lament</qex>, but the world shall
rejoice.</q> <rj><qau>John xvi. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lament</ent><br/
<hw>La*ment"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lamented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lamenting</conjf>.]</vmorph> <def>To mourn for; to bemoan; to
bewail.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One laughed at follies, one <qex>lamented</qex> crimes.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To deplore; mourn; bewail. See
<er>Deplore</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lament</ent><br/
<hw>La*ment"</hw>, <pos>n.</pos> <ety>[L. <ets>lamentum</ets>. Cf.
<er>Lament</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>Grief or sorrow
expressed in complaints or cries; lamentation; a wailing; a moaning; a
weeping.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Torment, and loud <qex>lament</qex>, and furious rage.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An elegy or mournful ballad, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamentable</ent><br/
<hw>Lam"en*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lamentabilis</ets>: cf. F. <ets>lamentable</ets>.]</ety>
<sn>1.</sn> <def>Mourning; sorrowful; expressing grief; <as>as, a
<ex>lamentable</ex> countenance</as>.</def> <mark>[Archaic]</mark>
<ldquo/<xex>Lamentable</xex> eye.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fitted to awaken lament; to be lamented; sorrowful;
pitiable; regrettable; unfortunate; <as>as, a <ex>lamentable</ex>
misfortune, or error</as>.</def> <ldquo/<xex>Lamentable</xex>
helplessness.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Miserable; pitiful; paltry; -- in a contemptuous or
ridiculous sense.</def> <rj><au>Bp. Stillingfleet.</au></rj></p>

<p>-- <wordforms><wf>Lam"en*ta*ble*ness</wf>, <pos>n.</pos> --
<wf>Lam"en*ta*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamentation</ent><br/
<hw>Lam`en*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lamentation</ets>, L. <ets>lamentatio</ets>.]</ety> <sn>1.</sn>
<def>The act of bewailing; audible expression of sorrow; wailing;
moaning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In Rama was there a voice heard, <qex>lamentation</qex> and
weeping.</q> <rj><qau>Matt. ii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Script.)</fld> <def>A book of the
Old Testament attributed to the prophet Jeremiah, and taking its name
from the nature of its contents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamented</ent><br/
<hw>La*ment"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mourned for;
bewailed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This humble praise, <qex>lamented</qex> shade ! receive.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamenter</ent><br/
<hw>La*ment"er</hw> <pr>(<?/)</pr>, <pos>n.</pos> <def>One who
laments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamentin</ent><br/
<hw>La*men"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lamantin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamenting</ent><br/
<hw>La*ment"ing</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Lamentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lamentings</qex> heard i' the air.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamentingly</ent><br/
<hw>La*ment"ing*ly</hw>, <pos>adv.</pos> <def>In a lamenting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lames</ent><br/
<hw>Lames</hw> <pr>(l<adot/mz)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>lame</ets> a thin plate, L. <ets>lamina</ets>.]</ety>
<fld>(Armor)</fld> <def>Small steel plates combined together so as to
slide one upon the other and form a piece of armor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lametta</ent><br/
\'d8<hw>La*met"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>lametta</ets>, dim. of <ets>lama</ets> a thin plate.]</ety>
<def>Foil or wire made of gold, silver, or brass.</def> <rj><au>De
Colange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamia</ent><br/
<hw>La"mi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <fld>(Class. Myth.)</fld> <def>A monster capable of assuming
a woman's form, who was said to devour human beings or suck their blood;
a vampire; a sorceress; a witch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamina</ent><br/
<ent>Laminaa</ent><br/
<hw>Lam"i*na</hw> <pr>(l<acr/m"<icr/*n<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Lamin<ae/</plw> <pr>(-n<emac/)</pr> E.
<plw>Laminas</plw> <pr>(-n<adot/z)</pr>.</plu> <ety>[L. cf.
<er>Lamella</er>.]</ety> <sn>1.</sn> <def>A thin plate or scale; a layer
or coat lying over another; -- said of thin plates or platelike
substances, as of bone or minerals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The blade of a leaf; the broad,
expanded portion of a petal or sepal of a flower.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A thin plate or scale; specif.,
one of the thin, flat processes composing the vane of a
feather.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminability</ent><br/
<hw>Lam`i*na*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
or state of being laminable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminable</ent><br/
<hw>Lam"i*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
split into lamin<ae/ or thin plates, as mica; capable of being extended
under pressure into a thin plate or strip.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a body can be readily extended in all directions under the
hammer, it is said to be malleable; and when into fillets under the
rolling press, it is said to be <qex>laminable</qex>.</q>
<rj><qau>Ure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminal</ent><br/
<ent>Laminar</ent><br/
<mhw>{ <hw>Lam"i*nar</hw> <pr>(?)</pr>, <hw>Lam"i*nal</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[Cf. F. <ets>laminaire</ets>. See
<er>Lamina</er>]</ety> <def>In, or consisting of, thin plates or layers;
having the form of a thin plate or lamina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminaria</ent><br/
\'d8<hw>Lam`i*na"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Lamina</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of great seaweeds
with long and broad fronds; kelp, or devil's apron. The fronds commonly
grow in clusters, and are sometimes from thirty to fifty feet in length.
See <xex>Illust.</xex> of <er>Kelp</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminarian</ent><br/
<hw>Lam`i*na"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
seaweeds of the genus <gen>Laminaria</gen>, or to that zone of the sea
(from two to ten fathoms in depth) where the seaweeds of this genus
grow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminarite</ent><br/
<hw>Lam"i*na*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lamina</er>.]</ety> <fld>(Paleon.)</fld> <def>A broad-leafed fossil
alga.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminary</ent><br/
<hw>Lam"i*na*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Laminar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminate</ent><br/
<hw>Lam"i*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lamina</er>.]</ety> <def>Consisting of, or covered with, laminae, or
thin plates, scales, or layers, one over another; laminated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminate</ent><br/
<hw>Lam"i*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Laminated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Laminating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[See
<er>Lamina</er>.]</ety> <sn>1.</sn> <def>To cause to separate into thin
plates or layers; to divide into thin plates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form, as metal, into a thin plate, as by
rolling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To form by uniting two or more layers (in sheet
form) of a material, so that the layers are bonded tightly; <as>as,
plywood has at least three <ex>laminated</ex> layers</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>To unite (layers in sheet form) by bonding, so as to
create a single object with multiple layers; -- used with the material
in sheet form as the object; <as>as, to <ex>laminate</ex>
plywood</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laminate</ent><br/
<hw>Lam"i*nate</hw>, <pos>v. i.</pos> <def>To separate into
laminae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>laminated</ent><br/
<hw>lam"i*na`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Consisting of, or covered with, laminae, or thin plates, sheets,
scales, or layers, one over another; laminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Constructed of thin sheets
of material, bonded together to form a composite structure having
multiple layers.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Laminated arch</b></col> <fld>(Arch.)</fld>, <cd>a timber
arch made of layers of bent planks secured by treenails.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminating</ent><br/
<hw>Lam"i*na`ting</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forming, or
separating into, scales or thin layers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamination</ent><br/
<hw>Lam`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The process of
laminating, or the state of being laminated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminiferous</ent><br/
<hw>Lam`i*nif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lamina</ets> + <ets>-ferous</ets>.]</ety> <def>Having a
structure consisting of lamin<ae/, or thin layers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminiplantar</ent><br/
<hw>Lam`i*ni*plan"tar</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lamina</ets> + L. <ets>planta</ets> sole of the foot.]</ety>
<fld>(Zool.)</fld> <def>Having the tarsus covered behind with a horny
sheath continuous on both sides, as in most singing birds, except the
larks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laminitis</ent><br/
\'d8<hw>Lam`i*ni"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Lamina</er>, and <er>-itis</er>.]</ety> <fld>(Far.)</fld>
<def>Inflammation of the lamin<ae/ or fleshy plates along the coffin
bone of a horse; founder.</def> <rj><au>Youatt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamish</ent><br/
<hw>Lam"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat lame.</def>
<rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamm</ent><br/
<hw>Lamm</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Lam</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lammas</ent><br/
<hw>Lam"mas</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hl<amac/mmesse</ets>, <ets>hl<amac/fm<ae/sse</ets>, loaf mass,
bread feast, or feast of first fruits; <ets>hl<amac/f</ets> loaf +
<ets>m<ae/sse</ets> mass. See <er>Loaf</er>, and <er>Mass</er> religious
service.]</ety> <def>The first day of August; -- called also
<altname>Lammas day</altname>, and
<altname>Lammastide</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lammergeyer</ent><br/
<ent>Lammergeier</ent><br/
<ent>Lammergeir</ent><br/
<mhw>{ <hw>Lam"mer*geir</hw> <pr>(l<acr/m"m<etil/r*g<imac/r)</pr>,
<hw>Lam"mer*gei`er</hw>, <hw>lam"mer*gey`er</hw>
<pr>(l<acr/m"m<etil/r*g<imac/`<etil/r)</pr>, }</mhw> <pos>n.</pos>
<ety>[G. <ets>l<aum/mmergeier</ets>; <ets>lamm</ets>, pl.
<ets>l<aum/mmer</ets>, lamb + <ets>geier</ets> vulture.]</ety>
<fld>(Zool.)</fld> <def>A very large vulture (<spn>Gypa<eum/tus
barbatus</spn>), which inhabits the mountains of Southern Europe, Asia,
and Northern Africa. When full-grown it is nine or ten feet in extent of
wings. It is brownish black above, with the under parts and neck rusty
yellow; the forehead and crown white; the sides of the head and beard
black. It feeds partly on carrion and partly on small animals, which it
kills. It has the habit of carrying tortoises and marrow bones to a
great height, and dropping them on stones to obtain the contents, and is
therefore called <altname>bonebreaker</altname> and
<altname>ossifrage</altname>. It is supposed to be the
<altname>ossifrage</altname> of the Bible. Called also <altname>bearded
vulture</altname> and <altname>bearded eagle</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamnidae</ent><br/
<hw>Lamnidae</hw> <pos>n.</pos> <def>A natural family of oceanic
sharks.</def><br/
<syn><b>Syn. --</b> family <fam>Lamnidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lamnunguia</ent><br/
\'d8<hw>Lam*nun"gui*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>lamina</ets> a scale + <ets>unguis</ets> a nail.]</ety>
<fld>(Zool.)</fld> <def>Same as <er>Hyracoidea</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamp</ent><br/
<hw>Lamp</hw> <pr>(l<acr/mp)</pr>, <pos>n.</pos> <ety>[OE. (with
excrescent <ets>p</ets>), fr. F. <ets>lame</ets>, L. <ets>lamina</ets>.
See <er>Lamina</er>.]</ety> <def>A thin plate or lamina.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamp</ent><br/
<hw>Lamp</hw> <pr>(l<acr/mp)</pr>, <pos>n.</pos> <ety>[F.
<ets>lampe</ets>, L. <ets>lampas</ets>, <ets>-adis</ets>, fr. Gr. <?/ ,
<?/, torch, fr. <?/ to give light, to shine. Cf. <er>Lampad</er>,
<er>Lantern</er>.]</ety> <sn>1.</sn> <def>A light-producing vessel,
device, instrument or apparatus;</def> <specif>formerly referring
especially to</specif> <def>a vessel with a wick used for the combustion
of oil or other inflammable liquid, for the purpose of producing
artificial light; also, a similar device using a gas as the combustible
fuel;</def> <specif>now referring mainly to</specif> <def>an electric
lamp. See sense {3}.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Figuratively, anything which enlightens
intellectually or morally; anything regarded metaphorically a performing
the uses of a lamp.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy word is a <qex>lamp</qex> unto my feet, and a light unto my
path.</q> <rj><qau>Ps. cxix. 105.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ages elapsed ere Homer's <qex>lamp</qex> appeared.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Elec.)</fld> <def>A device or mechanism for
producing light by electricity, usually having a glass bulb or tube
containing the light-emitting element. Most lamps belong to one of two
categories, the <styp><cref>Incandescent lamp</cref></styp> (See under
<er>Incandescent</er>) or the <stype>fluorescent lamp</stype>. However,
see also <styp><cref>arc lamp</cref></styp>, below.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <def>A device that emits radiant energy in the form of
heat, infrared, or ultraviolet rays; <as>as, a <ex>heat</ex>
lamp</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Aeolipile lamp</b></col>, <cd>a hollow ball of copper
containing alcohol which is converted into vapor by a lamp beneath, so
as to make a powerful blowpipe flame when the vapor is ignited.</cd>
<au>Weale.</au> -- <col><b>Arc lamp</b></col> <fld>(Elec.)</fld>, <cd>a
form of lamp in which the voltaic arc is used as the source of
light.</cd> -- <col><b>D<eum/bereiner's lamp</b></col>, <cd>an apparatus
for the instantaneous production of a flame by the spontaneous ignition
of a jet of hydrogen on being led over platinum sponge; -- named after
the German chemist <etsep>D<oum/bereiner</etsep>, who invented it.
Called also <altname>philosopher's lamp</altname>.</cd> --
<col><b>Flameless lamp</b></col>, <cd>an aphlogistic lamp.</cd> --
<col><b>Lamp burner</b></col>, <cd>the part of a lamp where the wick is
exposed and ignited.</cd> <au>Knight.</au> -- <col><b>Lamp
fount</b></col>, <cd>a reservoir for oil, in a lamp.</cd> --
<col><b>Lamp jack</b></col>. <cd>See 2d <er>Jack</er>, <pos>n.</pos>, 4
<sd>(l)</sd> & <sd>(n)</sd>.</cd> -- <col><b>Lamp shade</b></col>, <cd>a
screen, as of paper, glass, or tin, for softening or obstructing the
light of a lamp.</cd> -- <col><b>Lamp shell</b></col>
<fld>(Zool.)</fld>, <cd>any brachiopod shell of the genus
<gen>Terebratula</gen> and allied genera. The name refers to the shape,
which is like that of an antique lamp. See <er>Terebratula</er>.</cd> --
<col><b>Safety lamp</b></col>, <cd>a miner's lamp in which the flame is
surrounded by fine wire gauze, preventing the kindling of dangerous
explosive gases; -- called also, from <person>Sir Humphry
<etsep>Davy</etsep></person> the inventor, <altname>Davy
lamp</altname>.</cd> -- <col><b>To smell of the lamp</b></col>, <cd>to
bear marks of great study and labor, as a literary
composition.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampad</ent><br/
<hw>Lam"pad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ , <?/. See
<er>Lamp</er>.]</ety> <def>A lamp or candlestick.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By him who 'mid the golden <qex>lampads</qex> went.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampadist</ent><br/
<hw>Lam"pa*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr. <?/,
<?/, torch. See <er>Lamp</er>.]</ety> <fld>(Gr. Antiq.)</fld> <def>One
who gained the prize in the lampadrome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampadrome</ent><br/
<hw>Lam"pa*drome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/,
<?/, torch + <?/ course, race, fr. <?/ to run.]</ety> <fld>(Gr.
Antiq.)</fld> <def>A race run by young men with lighted torches in their
hands. He who reached the goal first, with his torch unextinguished,
gained the prize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampas</ent><br/
<hw>Lam"pas</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lampas</ets>.]</ety> <def>An inflammation and swelling of the soft
parts of the roof of the mouth immediately behind the fore teeth in the
horse; -- called also <altname>lampers</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampate</ent><br/
<hw>Lam"pate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lampate</ets>.]</ety> <fld>(Chem.)</fld> <def>A supposed salt of
lampic acid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampblack</ent><br/
<hw>Lamp"black`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lamp</ets> +
<ets>black</ets>.]</ety> <def>The fine impalpable soot obtained from the
smoke of carbonaceous substances which have been only partly burnt, as
in the flame of a smoking lamp. It consists of finely divided carbon,
with sometimes a very small proportion of various impurities. It is used
as an ingredient of printers' ink, and various black pigments and
cements.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamper eel</ent><br/
<hw>Lam"per eel`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Lamprey</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampern</ent><br/
<hw>Lam"pern</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lamprey</er>.]</ety> <fld>(Zool.)</fld> <def>The river lamprey
(<spn>Ammoc<oe/tes fluviatilis</spn> syn. <spn>Lampetra
fluviatilis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also applied to other river
lampreys.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampers</ent><br/
<hw>Lam"pers</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lampas</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampic</ent><br/
<hw>Lam"pic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>lampique</ets>, fr. <ets>lampe</ets> lamp. See
<er>Lamp</er>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or produced
by, a lamp; -- formerly said of a supposed acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamping</ent><br/
<hw>Lamp"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shining;
brilliant.</def> <mark>[Obs.]</mark> <ldquo/<xex>Lamping</xex>
eyes.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampless</ent><br/
<hw>Lamp"less</hw>, <pos>a.</pos> <def>Being without a lamp, or without
light; hence, being without appreciation; dull.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your ladies' eyes are <qex>lampless</qex> to that virtue.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamplight</ent><br/
<hw>Lamp"light`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Light from a
lamp.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This world's artificial <qex>lamplights</qex>.</q> <rj><qau>Owen
Meredith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamplighter</ent><br/
<hw>Lamp"light`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, lights a lamp;</def> <specif>esp.,</specif> <def>a
person who in former times lighted street lamps which were illuminated
by a combustible gas; -- such lamps are now little used, and primarily
as nostalgic ornaments.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>He made the night a little brighter<br/
Wherever he did go,<br/
The old <qex>lamplighter</qex><br/
Of long, long ago.</q> <rj><qau>Song lyrics. (?)</qau></rj><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The calico bass.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A device used to light lamps.</def><br/
[<source>PJC</source>]</p>

<p><ent>lamplit</ent><br/
<hw>lamplit</hw> <pos>adj.</pos> <def>Illuminated by a lamp.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lampoon</ent><br/
<hw>Lam*poon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lampon</ets> a drinking song, fr. <ets>lampons</ets> let us drink,
-- the burden of such a song, fr. <ets>lamper</ets> to guzzle, to drink
much and greedily; of German origin, and akin to E. <ets>lap</ets> to
drink. Prob. so called because drinking songs often contain personal
slander or satire.]</ety> <sn>1.</sn> <def>A personal satire in writing;
usually, malicious and abusive censure written only to reproach and
distress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like her who missed her name in a <qex>lampoon</qex>,<br/
And grieved to find herself decayed so soon.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any satire ridiculing or
mocking a person, activity, or institution by representing its character
or behavior in an exaggerated or grotesque form; the representation may
be written, filmed, or performed as a live skit, and may be intended as
a severe reproach, or as good-natured humor.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lampoon</ent><br/
<hw>Lam*poon"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lampooned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lampooning</conjf>.]</vmorph> <def>To subject to abusive ridicule
expressed in a work of art; to make (a person, behavior, or institution)
the subject of a lampoon.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Ribald poets had <qex>lampooned</qex> him.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- To libel; defame; satirize; lash.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampooner</ent><br/
<hw>Lam*poon"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The writer of a
lampoon.</def> <ldquo/Libelers, <xex>lampooners</xex>, and
pamphleteers.<rdquo/ <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampoonry</ent><br/
<hw>Lam*poon"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
lampooning; a lampoon, or lampoons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamp-post</ent><br/
<hw>Lamp"-post`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A post (generally
a pillar of iron) supporting a lamp or lantern for lighting a street,
park, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamprel</ent><br/
<hw>Lam"prel</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Lamprey</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lamprey</ent><br/
<hw>Lam"prey</hw> <pr>(l<acr/m"pr<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lampreys</plw> <pr>(l<acr/m"pr<icr/z)</pr>.</plu>
<ety>[OE. <ets>lampreie</ets>, F. <ets>lamproie</ets>, LL.
<ets>lampreda</ets>, <ets>lampetra</ets>, from L. <ets>lambere</ets> to
lick + <ets>petra</ets> rock, stone. The lampreys are so called because
they attach themselves with their circular mouths to rocks and stones,
whence they are also called <altname>rocksuckers</altname>. See
<er>Lap</er> to drink, <er>Petrify</er>.]</ety> <fld>(Zool.)</fld>
<def>An eel-like marsipobranch of the genus <gen>Petromyzon</gen>, and
allied genera; called also <altname>lamprey eel</altname> and
<altname>lamper eel</altname>. The lampreys have a round, sucking mouth,
without jaws, but set with numerous minute teeth, and one to three
larger teeth on the palate (see <xex>Illust.</xex> of
<er>Cyclostomi</er>). There are seven small branchial openings on each
side.</def> <altsp>[Written also <asp>lamprel</asp>, and
<asp>lampron</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 827 --></p>

<p><note><hand/ The common or sea lamprey of America and Europe
(<spn>Petromyzon marinus</spn>), which in spring ascends rivers to
spawn, is considered excellent food by many, and is sold as a market
fish in some localities. The smaller river lampreys mostly belong to the
genus <gen>Ammoc<oe/les</gen>, or <gen>Lampetra</gen>, as
<spn>Ammoc<oe/les fluviatilis</spn>, of Europe, and <spn>Ammoc<oe/les
<ae/pypterus</spn> of America. All lampreys attach themselves to other
fishes, as parasites, by means of the suckerlike mouth.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampron</ent><br/
<hw>Lam"pron</hw> <pr>(l<acr/m"pr<ocr/n)</pr>, <pos>n.</pos> <ety>[Cf.
OE. <ets>lampreon</ets>. See <er>Lamprey</er>.]</ety> <fld>(Zool.)</fld>
<def>See <er>Lamprey</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lamp shade</ent><br/
<ent>lampshade</ent><br/
<mhw><hw>lampshade</hw>, <hw>lamp shade</hw></mhw> <pos>n.</pos> <def>a
protective ornamental covering used to screen the light bulb in a lamp
from direct view.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lamp shell</ent><br/
<ent>lampshell</ent><br/
<mhw><hw>lampshell</hw>, <hw>lamp shell</hw></mhw> <pos>n.</pos> <def>A
mollusklike marine animal with bivalve shell having a pair of arms
bearing tentacles for capturing food, found worldwide.</def><br/
<syn><b>Syn. --</b> brachiopod.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lampyridae</ent><br/
<hw>Lampyridae</hw> <pos>prop. n.</pos> <def>A natural family of insects
comprising the fireflies.</def><br/
<syn><b>Syn. --</b> family <fam>Lampyridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lampyrine</ent><br/
<hw>Lam*py"rine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lampyris</er>.]</ety> <fld>(Zool.)</fld> <def>An insect of the genus
<gen>Lampyris</gen>, or family <fam>Lampyrid<ae/</fam>. See
<er>Lampyris</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lampyris</ent><br/
\'d8<hw>Lam*py"ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., glowworm,
Gr. (<?/).]</ety> <fld>(Zool.)</fld> <def>A genus of coleopterous
insects, including the glowworms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>LAN</ent><br/
<hw>LAN</hw> <pos>n.</pos> <ety>[<ets>L</ets>ocal <ets>A</ets>rea
<ets>N</ets>etwork.]</ety> <def>A <altname>local area network</altname>;
a network{3} connecting computers and word processors and other
electronic office equipment within a small area, to create an
inter-office system, typically within one building or one site of a
corporation. Contrasted to <contr>WAN</contr>, a wide-area
network.</def><br/
<syn><b>Syn. --</b> local area network.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lanai</ent><br/
<hw>Lanai</hw> <pos>n.</pos> <sn>1.</sn> <mark>(upper case)</mark>
<def>an island in the Hawaiian chain.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <mark>(lower case)</mark> <def>a veranda or roofed patio
often furnished and used as a living room.</def> <mark>[Hawaii]</mark>
<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lanarkite</ent><br/
<hw>Lan"ark*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<etsep>Lanark</etsep>shire, a county in Scotland.]</ety>
<fld>(Min.)</fld> <def>A mineral consisting of sulphate of lead,
occurring either massive or in long slender prisms, of a greenish white
or gray color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanary</ent><br/
<hw>La"na*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lanaria</ets>, fr. <ets>lanarius</ets> belonging to wool,
<ets>lana</ets> wool.]</ety> <def>A place for storing wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanated</ent><br/
<ent>Lanate</ent><br/
<mhw>{ <hw>La"nate</hw> <pr>(?)</pr>, <hw>La"na*ted</hw> <pr>(?)</pr>,
}</mhw> <ety>[L. <ets>lanatus</ets>, fr. <ets>lana</ets> wool,
down.]</ety> <sn>1.</sn> <def>Wooly; covered with fine long hair, or
hairlike filaments.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <fld>(Biol.)</fld> <def>covered
with dense often matted or curly hairs.</def><br/
<syn><b>Syn. --</b> wooly, woolly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lancashire boiler</ent><br/
<hw>Lan"ca*shire boil"er</hw> <pr>(?)</pr> <pos>n.</pos> <def>A steam
boiler having two flues which contain the furnaces and extend through
the boiler from end to end.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancaster</ent><br/
<hw>Lancaster</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A city in
Northwest England on the river Lune.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The English royal house that reigned from 1399 to
1461; its symbol was a red rose; called also the <altname>House of
Lancaster</altname>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> Lancastrian line.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lancasterian</ent><br/
<hw>Lan`cas*te"ri*an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to the monitorial system of instruction followed by
<person>Joseph <etsep>Lancaster</etsep></person>, of England, in which
advanced pupils in a school teach pupils below them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancastrian</ent><br/
<hw>Lancastrian</hw> <pos>prop. a.</pos> <sn>1.</sn> <def>Of or
pertaining to Lancaster{2}; <as>as, <ex>Lancastrian</ex>
royalty</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the city of Lancaster{1};
<as>as, <ex>Lancastrian</ex> city center</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to the members of the house of
Lancaster; <as>as, <ex>Lancastrian</ex> members</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>Of or pertaining to the inhabitants of Lancaster;
<as>as, the <ex>Lancastrian</ex> population</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lancastrian</ent><br/
<hw>Lancastrian</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A member (or
supporter) of the house of Lancaster.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A resident of Lancaster{1}.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lance</ent><br/
<hw>Lance</hw> <pr>(l<acr/ns)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lance</ets>, F. <ets>lance</ets>, <ets>fr</ets>. L.
<ets>lancea</ets>; cf. Gr. <grk>lo`gchh</grk>. Cf.
<er>Launch</er>.]</ety> <sn>1.</sn> <def>A weapon of war, consisting of
a long shaft or handle and a steel blade or head; a spear carried by
horsemen, and often decorated with a small flag; also, a spear or
harpoon used by whalers and fishermen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A braver soldier never couched <qex>lance</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A soldier armed with a lance; a lancer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Founding)</fld> <def>A small iron rod which
suspends the core of the mold in casting a shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>An instrument which conveys the
charge of a piece of ordnance and forces it home.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Pyrotech.)</fld> <def>One of the small paper cases
filled with combustible composition, which mark the outlines of a
figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Med.)</fld> <def>A lancet.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Free lance</b></col>, <cd>in the Middle Ages, and
subsequently, a knight or roving soldier, who was free to engage for any
state or commander that purchased his services; hence, a person who
assails institutions or opinions on his own responsibility without
regard to party lines or deference to authority. See also
<er>freelance</er>, <pos>n.</pos> and <pos>a.</pos>, and
<er>freelancer</er>.</cd> -- <col><b>Lance bucket</b></col>
<fld>(Cavalry)</fld>, <cd>a socket attached to a saddle or stirrup
strap, in which to rest the but of a lance.</cd> -- <col><b>Lance
corporal</b></col>, <cd>same as <er>Lancepesade</er>.</cd> --
<col><b>Lance knight</b></col>, <cd>a lansquenet.</cd> <au>B.
Jonson.</au> -- <col><b>Lance snake</b></col> <fld>(Zool.)</fld>,
<cd>the fer-de-lance.</cd> -- <col><b>Stink-fire lance</b></col>
<fld>(Mil.)</fld>, <cd>a kind of fuse filled with a composition which
burns with a suffocating odor; -- used in the counter operations of
miners.</cd> -- <col><b>To break a lance</b></col>, <cd>to engage in a
tilt or contest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lance</ent><br/
<hw>Lance</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lanced</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lancing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To
pierce with a lance, or with any similar weapon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seized the due victim, and with fury <qex>lanced</qex><br/
Her back.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To open with a lancet; to pierce; <as>as, to
<ex>lance</ex> a vein or an abscess</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw in the manner of a lance. See
<er>Lanch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lance corporal</ent><br/
<hw>lance" cor`por*al</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A <er>lancepesade</er>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>An enlisted member of the United States Marine Corps
ranking between a private first class and a corporal.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The lowest rank of corporal; -- a term used in the
British military.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>Lance fish</ent><br/
<hw>Lance" fish`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Zool.)</fld>
<def>A slender marine fish of the genus <gen>Ammodytes</gen>, especially
<spn>Ammodytes tobianus</spn> of the English coast; -- called also
<altname>sand lance</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancegaye</ent><br/
<ent>Lancegay</ent><br/
<mhw>{ <hw>Lance"gay`</hw>, <hw>Lance"gaye`</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[OF. <ets>lancegaie</ets>, corrupted from the same
source as E. <ets>assagai</ets>, under the influence of F.
<ets>lance</ets> lance. See <er>Assagai</er>.]</ety> <def>A kind of
spear anciently used. Its use was prohibited by a statute of Richard
II.</def> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In his hand a <qex>launcegay</qex>,<br/
A long sword by his side.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancelet</ent><br/
<hw>Lance"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lance</ets> +
<ets>-let</ets>.]</ety> <fld>(Zool.)</fld> <def>A small fishlike animal
(<spn>Amphioxus lanceolatus</spn>), remarkable for the rudimentary
condition of its organs. It is the type of the class
<class>Leptocardia</class>. See <er>Amphioxus</er>,
<er>Leptocardia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancely</ent><br/
<hw>Lance"ly</hw>, <pos>a.</pos> <def>Like a lance.</def>
<mark>[R.]</mark> <au>Sir P. Sidney.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanceolar</ent><br/
<hw>Lan"ce*o*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lanceola</ets> a little lance, dim. of <ets>lancea</ets> lance: cf.
F. <ets>lanc<eacute/olaire</ets>.]</ety> <fld>(Bot.)</fld>
<def>Lanceolate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanceolated</ent><br/
<ent>Lanceolate</ent><br/
<mhw>{ <hw>Lan"ce*o*late</hw> <pr>(?)</pr>, <hw>Lan"ce*o*la`ted</hw>
<pr>(?)</pr> }</mhw> <pos>a.</pos> <ety>[L. <ets>lanceolatus</ets>: cf.
F. <ets>lanc<eacute/ol<eacute/</ets>. See <er>Lanceolar</er>.]</ety>
<fld>(Bot. & Zool.)</fld> <def>Rather narrow, tapering to a point at the
apex, and sometimes at the base also; <as>as, a <ex>lanceolate</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancepesade</ent><br/
<hw>Lance`pe*sade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lancepessade</ets>, <ets>lanspessade</ets>, <ets>anspessade</ets>,
It. <ets>lancia spezzata</ets> a broken lance or demilance, a demilance
roan, a light horseman, bodyguard.]</ety> <def>An assistant to a
corporal; a private performing the duties of a corporal; -- called also
<altname>lance corporal</altname>.</def> <mark>[Obsolete]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancer</ent><br/
<hw>Lan"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lancier</ets>.]</ety> <sn>1.</sn> <def>One who lances; one who
carries a lance; especially, a member of a mounted body of men armed
with lances, attached to the cavalry service of some nations.</def>
<rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lancet.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <fld>(Dancing)</fld> <def>A set of
quadrilles of a certain arrangement.</def> <altsp>[Written also
<asp>lanciers</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>lancers</ent><br/
<hw>lancers</hw> <pos>n.</pos> <sn>1.</sn> <def>A set of quadrilles for
8 or 16 couples.</def> <wns>[wns=1]</wns> <altsp>[Written also
<asp>lanciers</asp>.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Music appropriate for a set of lancers{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lancet</ent><br/
<hw>Lan"cet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lancette</ets>, dim. of <ets>lance</ets> lance. See
<er>Lance</er>.]</ety> <sn>1.</sn> <def>A surgical knife-like instrument
of various forms, commonly sharp-pointed and two-edged, used in
venesection, and in opening abscesses, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal.)</fld> <def>An iron bar used for tapping a
melting furnace.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lancet arch</b></col> <fld>(Arch.)</fld>, <cd>a pointed
arch, of which the width, or span, is narrow compared with the
height.</cd> -- <col><b>Lancet architecture</b></col>, <cd>a name given
to a style of architecture, in which lancet arches are common; --
peculiar to England and 13th century.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lancet fish</ent><br/
<ent>lancetfish</ent><br/
<mhw><hw>lan"cet*fish`</hw>, <hw>lan"cet fish`</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>A large, elongated, scaleless, voracious,
deep-sea fish (<spn>Alepidosaurus ferox</spn>), having long, sharp,
lancetlike teeth and a long saillike dorsal fin.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> lancet fish, wolffish.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The doctor, or surgeon fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancewood</ent><br/
<hw>Lance"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A tough, elastic wood, often used for the shafts of gigs, archery
bows, fishing rods, and the like. Also, the tree which produces this
wood, <spn>Duguetia Quitarensis</spn> (a native of Guiana and Cuba), and
several other trees of the same family
(<fam>Anonase<ae/</fam>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Australian lancewood</b></col>, <cd>a myrtaceous tree
(<spn>Backhousia Australis</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanch</ent><br/
<hw>Lanch</hw> <pr>(l<adot/nch)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lanched</conjf>
<pr>(l<adot/ncht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lanching</conjf>. See <er>Launch</er>, <er>Lance</er>.]</vmorph>
<def>To throw, as a lance; to let fly; to launch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>See Whose arm can <qex>lanch</qex> the surer bolt.</q>
<rj><qau>Dryden & Lee.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanciferous</ent><br/
<hw>Lan*cif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lance</ets> + <ets>-ferous</ets>.]</ety> <def>Bearing a
lance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanciform</ent><br/
<hw>Lan"ci*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Lance</ets>
+ <ets>-form</ets>: cf. F. <ets>lanciforme</ets>.]</ety> <def>Having the
form of a lance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancinate</ent><br/
<hw>Lan"ci*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lancinated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lancinating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>lancinatus</ets>, p. p. of <ets>lancinare</ets> to fear.]</ety>
<def>To tear; to lacerate; to pierce or stab.</def> <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancinating</ent><br/
<hw>Lan"ci*na`ting</hw>, <pos>a.</pos> <def>Piercing; seeming to pierce
or stab; <as>as, <ex>lancinating</ex> pains (i.e., severe, darting
pains)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lancination</ent><br/
<hw>Lan`ci*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tearing;
laceration.</def> <ldquo/<xex>Lancinations</xex> of the spirit.<rdquo/
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Land</ent><br/
<hw>Land</hw> <pr>(l<acr/nd)</pr>, <pos>n.</pos> <def>Urine. See
<er>Lant</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Land</ent><br/
<hw>Land</hw>, <pos>n.</pos> <ety>[AS. <ets>land</ets>, <ets>lond</ets>;
akin to D., G., Icel., Sw., Dan., and Goth. <ets>land</ets>. ]</ety>
<sn>1.</sn> <def>The solid part of the surface of the earth; -- opposed
to water as constituting a part of such surface, especially to oceans
and seas; <as>as, to sight <ex>land</ex> after a long
voyage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They turn their heads to sea, their sterns to <qex>land</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any portion, large or small, of the surface of the
earth, considered by itself, or as belonging to an individual or a
people, as a country, estate, farm, or tract.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go view the <qex>land</qex>, even Jericho.</q> <rj><qau>Josh. ii.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ill fares the <qex>land</qex>, to hastening ills a prey,<br/
Where wealth accumulates and men decay.</q>
<rj><qau>Goldsmith.</qau></rj> <-- See also, Goldsmith: Where wealth and
freedom reign contentment fails, And honor sinks where commerce long
prevails. (THe captivity, an Oratorio. Act II line 91) --><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the expressions <ldquo/to be, or dwell, upon
<xex>land</xex>,<rdquo/ <ldquo/<xex>to go</xex>, <xex>or fare</xex>, on
<xex>land</xex>,<rdquo/ as used by Chaucer, <xex>land</xex> denotes the
country as distinguished from the town.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>A poor parson dwelling upon <qex>land</qex> [i.e., in the
country].</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ground, in respect to its nature or quality; soil;
<as>as, wet <ex>land</ex>; good or bad <ex>land</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The inhabitants of a nation or people.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These answers, in the silent night received,<br/
The king himself divulged, the <qex>land</qex> believed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The mainland, in distinction from islands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The ground or floor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Herself upon the <qex>land</qex> she did prostrate.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Agric.)</fld> <def>The ground left unplowed between
furrows; any one of several portions into which a field is divided for
convenience in plowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Law)</fld> <def>Any ground, soil, or earth
whatsoever, as meadows, pastures, woods, etc., and everything annexed to
it, whether by nature, as trees, water, etc., or by the hand of man, as
buildings, fences, etc.; real estate.</def> <rj><au>Kent. Bouvier.
Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Naut.)</fld> <def>The lap of the strakes in a
clinker-built boat; the lap of plates in an iron vessel; -- called also
<altname>landing</altname>.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>In any surface prepared with indentations,
perforations, or grooves, that part of the surface which is not so
treated, as the level part of a millstone between the furrows, or the
surface of the bore of a rifled gun between the grooves.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Land agent</b></col>, <cd>a person employed to sell or
let land, to collect rents, and to attend to other money matters
connected with land.</cd> -- <col><b>Land boat</b></col>, <cd>a vehicle
on wheels propelled by sails.</cd> -- <col><b>Land blink</b></col>,
<cd>a peculiar atmospheric brightness seen from sea over distant
snow-covered land in arctic regions. See <er>Ice blink</er>.</cd> --
<col><b>Land breeze</b></col>. <cd>See under <er>Breeze</er>.</cd> --
<col><b>Land chain</b></col>. <cd>See <er>Gunter's chain</er>.</cd> --
<col><b>Land crab</b></col> <fld>(Zool.)</fld>, <cd>any one of various
species of crabs which live much on the land, and resort to the water
chiefly for the purpose of breeding. They are abundant in the West
Indies and South America. Some of them grow to a large size.</cd> --
<col><b>Land fish</b></col> <cd>a fish on land; a person quite out of
place.</cd> <au>Shak.</au> -- <col><b>Land force</b></col>, <cd>a
military force serving on land, as distinguished from a naval
force.</cd> -- <col><b>Land, ho!</b></col> <fld>(Naut.)</fld>, <cd>a
sailor's cry in announcing sight of land.</cd> -- <col><b>Land
ice</b></col>, <cd>a field of ice adhering to the coast, in distinction
from a floe.</cd> -- <col><b>Land leech</b></col> <fld>(Zool.)</fld>,
<cd>any one of several species of blood-sucking leeches, which, in
moist, tropical regions, live on land, and are often troublesome to man
and beast.</cd> -- <col><b>Land measure</b></col>, <cd>the system of
measurement used in determining the area of land; also, a table of areas
used in such measurement.</cd> -- <mcol><col><b>Land of
bondage</b></col> <it>or</it> <col><b>House of bondage</b></col></mcol>,
<cd>in Bible history, Egypt; by extension, a place or condition of
special oppression.</cd> -- <col><b>Land o' cakes</b></col>,
<cd>Scotland.</cd> -- <col><b>Land of Nod</b></col>, <cd>sleep.</cd> --
<col><b>Land of promise</b></col>, <cd>in Bible history, Canaan: by
extension, a better country or condition of which one has
expectation.</cd> -- <col><b>Land of steady habits</b></col>, <cd>a
nickname sometimes given to the State of Connecticut.</cd> --
<col><b>Land office</b></col>, <cd>a government office in which the
entries upon, and sales of, public land are registered, and other
business respecting the public lands is transacted.</cd>
<mark>[U.S.]</mark> -- <col><b>Land pike</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The gray pike, or sauger.</cd> <sd>(b)</sd> <cd>The
Menobranchus.</cd> -- <col><b>Land service</b></col>, <cd>military
service as distinguished from naval service.</cd> -- <col><b>Land
rail</b></col>. <fld>(Zool)</fld> <sd>(a)</sd> <cd>The crake or
corncrake of Europe.</cd> See <er>Crake</er>. <sd>(b)</sd> <cd>An
Australian rail (<spn>Hypot<ae/nidia Phillipensis</spn>); -- called also
<altname>pectoral rail</altname>.</cd> -- <col><b>Land scrip</b></col>,
<cd>a certificate that the purchase money for a certain portion of the
public land has been paid to the officer entitled to receive it.</cd>
<mark>[U.S.]</mark> -- <col><b>Land shark</b></col>, <cd>a swindler of
sailors on shore.</cd> <mark>[Sailors' Cant]</mark> -- <col><b>Land
side</b></col> <sd>(a)</sd> <cd>That side of anything in or on the sea,
as of an island or ship, which is turned toward the land.</cd>
<sd>(b)</sd> <cd>The side of a plow which is opposite to the moldboard
and which presses against the unplowed land.</cd> -- <col><b>Land
snail</b></col> <fld>(Zool.)</fld>, <cd>any snail which lives on land,
as distinguished from the aquatic snails are Pulmonifera, and belong to
the Geophila; but the operculated land snails of warm countries are
Di<oe/cia, and belong to the T<ae/nioglossa. See <er>Geophila</er>, and
<er>Helix</er>.</cd> -- <col><b>Land spout</b></col>, <cd>a descent of
cloud and water in a conical form during the occurrence of a tornado and
heavy rainfall on land.</cd> -- <col><b>Land steward</b></col>, <cd>a
person who acts for another in the management of land, collection of
rents, etc.</cd> -- <mcol><col><b>Land tortoise</b></col>, <col><b>Land
turtle</b></col></mcol> <fld>(Zool.)</fld>, <cd>any tortoise that
habitually lives on dry land, as the box tortoise. See
<er>Tortoise</er>.</cd> -- <col><b>Land warrant</b></col>, <cd>a
certificate from the Land Office, authorizing a person to assume
ownership of a public land.</cd> <mark>[U.S.]</mark> -- <col><b>Land
wind</b></col>. <cd>Same as <cref>Land breeze</cref> (above).</cd> --
<col><b>To make land</b></col> <fld>(Naut.)</fld>, <cd>to sight
land.</cd> <col><b>To set the land</b></col>, <cd>to see by the compass
how the land bears from the ship.</cd> -- <col><b>To shut in the
land</b></col>, <cd>to hide the land, as when fog, or an intervening
island, obstructs the view.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Land</ent><br/
<hw>Land</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Landed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Landing</conjf>.]</vmorph> <sn>1.</sn> <def>To set or put on
shore from a ship or other water craft; to disembark; to
debark.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll undertake to <qex>land</qex> them on our coast.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To catch and bring to shore; to capture; <as>as, to
<ex>land</ex> a fish</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To set down after conveying; to cause to fall,
alight, or reach; to bring to the end of a course; <as>as, he
<ex>landed</ex> the quoit near the stake; to be thrown from a horse and
<ex>landed</ex> in the mud; to <ex>land</ex> one in difficulties or
mistakes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Specifically:</specif> <fld>(Aeronautics)</fld>
<def>To pilot (an airplane) from the air onto the land; <as>as, to
<ex>land</ex> the plane on a highway</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Land</ent><br/
<hw>Land</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To come to the end of a
course; to arrive at a destination, literally or figuratively; <as>as,
he <ex>landed</ex> in trouble; after hithchiking for a week, he
<ex>landed</ex> in Los Angeles</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>To go on shore from a
ship or boat; to disembark.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <def>To reach and come to
rest on land after having been in the air; <as>as, the arrow
<ex>landed</ex> in a flower bed; the golf ball <ex>landed</ex> in a sand
trap; our airplane <ex>landed</ex> in Washington</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Landamman</ent><br/
<hw>Lan"dam*man</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>Landamman</ets>; <ets>land</ets> land, country + <ets>amimann</ets>
bailiff. See <er>Land</er>, and <er>Ambassador</er>.]</ety> <sn>1.</sn>
<def>A chief magistrate in some of the Swiss cantons.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The president of the diet of the Helvetic
republic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landau</ent><br/
<hw>Lan"dau</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the town
<etsep>Ladau</etsep> in Germany; cf. F. <ets>landau</ets>. See
<er>Land</er>, <er>Island</er>.]</ety> <def>A four-wheeled covered
vehicle, the top of which is divided into two sections which can be let
down, or thrown back, in such a manner as to make an open
carriage.</def> <altsp>[Written also <asp>landaw</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landaulet</ent><br/
<hw>Lan`dau*let"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>landaulet</ets>, dim, of <ets>landau</ets>. See
<er>Landau</er>.]</ety> <def>A small landau.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landtrost</ent><br/
<ent>Landdrost</ent><br/
<mhw>\'d8<hw>Land"drost`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>-drosten</plw> <pr>(#)</pr></plu>. Sometimes incorrectly
<hw>Landtrost</hw></mhw>. <ety>[D., fr. <ets>land</ets> land +
<ets>drost</ets> a kind of official; akin to G.
<ets>truchsess</ets>.]</ety> <mark>(In South Africa)</mark> <sd>(a)</sd>
<def>A chief magistrate in rural districts. He was replaced in 1827 by
<ldquo/resident magistrates.<rdquo/</def> <sd>(b)</sd> <def>The
president of the Heemraad.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landed</ent><br/
<hw>Land"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having an
estate in land.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The House of Commons must consist, for the most part, of
<qex>landed</qex> men.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting in real estate or land; <as>as,
<ex>landed</ex> property; <ex>landed</ex> security.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lander</ent><br/
<hw>Land"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
lands, or makes a landing.</def> <ldquo/The <xex>lander</xex> in a
lonely isle.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A person who waits at the mouth
of the shaft to receive the kibble of ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landfall</ent><br/
<hw>Land"fall</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A sudden
transference of property in land by the death of its owner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>Sighting or making land when at
sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A good landfall</b></col> <fld>(Naut.)</fld>, <cd>the
sighting of land in conformity with the navigator's reckoning and
expectation.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landflood</ent><br/
<hw>Land"flood`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An overflowing of
land by river; an inundation; a freshet.</def>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landgrave</ent><br/
<hw>Land"grave`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>landgraf</ets>; <ets>land</ets> land + <ets>graf</ets> earl, count;
cf. D. <ets>landgraaf</ets>, F. <ets>landgrave</ets>.]</ety> <def>A
German nobleman of a rank corresponding to that of an earl in England
and of a count in France.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The title was first adopted by some German counts in the
twelfth century, to distinguish themselves from the inferior counts
under their jurisdiction. Three of them were princes of the
empire.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landgraviate</ent><br/
<hw>Land*gra"vi*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>landgraviat</ets>.]</ety> <sn>1.</sn> <def>The territory held by a
landgrave.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The office, jurisdiction, or authority of a
landgrave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landgravine</ent><br/
<hw>Land"gra*vine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>landgr<aum/fin</ets>; cf. D. <ets>landgravin</ets>.]</ety> <def>The
wife of a landgrave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landholder</ent><br/
<hw>Land"hold`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A holder, owner,
or proprietor of land.</def> -- <wordforms><wf>Land"hold`ing</wf>,
<pos>n. & a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>landholding</ent><br/
<hw>landholding</hw> <pos>n.</pos> <sn>1.</sn> <def>ownership of land;
the state or fact of owning land.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A holding in the form of land; the land owned by a
person.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Landing</ent><br/
<hw>Land"ing</hw>, <pos>a.</pos> <def>Of, pertaining to, or used for,
setting, bringing, or going, on shore.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Landing charges</b></col>, <cd>charges or fees paid on
goods unloaded from a vessel.</cd> -- <col><b>Landing net</b></col>,
<cd>a small, bag-shaped net, used in fishing to take the fish from the
water after being hooked.</cd> -- <col><b>Landing stage</b></col>, <cd>a
floating platform attached at one end to a wharf in such a manner as to
rise and fall with the tide, and thus facilitate passage between the
wharf and a vessel lying beside the stage.</cd> -- <col><b>Landing
waiter</b></col>, <cd>a customhouse officer who oversees the landing of
goods, etc., from vessels; a landwaiter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landing</ent><br/
<hw>Land"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A going or bringing on
shore.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place for landing, as from a ship, a carriage.
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>The level part of a staircase, at
the top of a flight of stairs, or connecting one flight with
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Aeronautics)</fld> <def>The act or process of
bringing an aircraft to land after having been in the air; <as>as, the
pilot made a perfect three-point <ex>landing</ex></as>. Contrasted with
<contr>take-off</contr>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Landing place</b></col>. <cd>me as <er>Landing</er>,
<pos>n.</pos>, 2 and 3.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>landing gear</ent><br/
<hw>land"ing gear`</hw>, <pos>n.</pos> <def>The wheels and attached
structures under an airplane that support it and allow it to move when
on the ground; also, the floats or pontoons of an amphibious airplane
together with their supporting structures. Landing gear may be fixed
rigidly in place, or retractable when in flight.</def><br/
[<source>PJC</source>]</p>

<p><ent>landing strip</ent><br/
<hw>land"ing strip`</hw>, <pos>n.</pos> <fld>(Aeronautics)</fld> <def>A
runway at an airport, at which airplanes land{3}; the long smooth
surface used for takeoff or landing{4}.</def><br/
[<source>PJC</source>]</p>

<p><ent>landlady</ent><br/
<hw>land"la`dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>landladies</plw> <pr>(#)</pr>.</plu> <ety>[Cf.
<er>landlord</er>.]</ety> <sn>1.</sn> <def>A woman having real estate
which she leases to a tenant or tenants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mistress of an inn or lodging house.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 828 --></p>

<p><ent>Land League</ent><br/
<hw>Land League</hw> <pos>n.</pos> <def>In Ireland, a combination of
tenant farmers and other, organized, with <person>Charles Stewart
Parnell</person> as president, in 1879 with a view to the reduction of
farm rents and a reconstruction of the land laws.</def> --
<wordforms><wf>Land"*lea`guer</wf> <pr>(#)</pr>, <pos>n.</pos> --
<wf>Land"*lea`guism</wf> <pr>(#)</pr>, <pos>n.</pos></wordforms></p>

<p><q>The <qex>Land League</qex>, of which <person>Michael
Davitt</person> was the founder, originated in Mayo in August, and at a
Dublin in October the organization was extended to all Ireland, with
<persfn>Parnell</persfn> as president.</q> <rj><qau>Encyc.
Brit.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landleaper</ent><br/
<hw>Land"leap`er</hw> <pr>(l<acr/nd"l<emac/p`<etil/r)</pr>,
<pos>n.</pos> <def>See <er>Landlouper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landless</ent><br/
<hw>Land"less</hw> <pr>(l<acr/nd"l<ecr/s)</pr>, <pos>a.</pos>
<def>Having no property in land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlock</ent><br/
<hw>Land"lock`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To inclose, or
nearly inclose, as a harbor or a vessel, with land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlocked</ent><br/
<hw>Land"locked`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Inclosed, or nearly inclosed, by land; having no border on the sea;
<as>as, a <ex>landlocked</ex> country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Confined to a fresh-water lake by
reason of waterfalls or dams; -- said of fishes that would naturally
seek the sea, after spawning; <as>as, the <ex>landlocked</ex>
salmon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landloper</ent><br/
<hw>Land"lo`per</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Landlouper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlord</ent><br/
<hw>Land"lord`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Land</er>,
and <er>Lord</er>.]</ety> <sn>1.</sn> <def>The lord of a manor, or of
land; the owner of land or houses which he leases to a tenant or
tenants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The master of an inn or of any form of lodging
house; <as>as, the <ex>landlord</ex> collects the rents on the first of
the month</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Upon our arrival at the inn, my companion fetched out the jolly
<qex>landlord</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlordism</ent><br/
<hw>Land"lord`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being a landlord; the characteristics of a landlord; specifically, in
Great Britain, the relation of landlords to tenants, especially as
regards leased agricultural lands.</def> <rj><au>J. S.
Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlordry</ent><br/
<hw>Land"lord`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of a
landlord.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlouper</ent><br/
<hw>Land"loup`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>landlooper</ets>, lit., <ets>landrunner</ets>; <ets>land</ets> land
+ <ets>loopen</ets> to run. See <er>Land</er>, and <er>Leap</er>.]</ety>
<def>A vagabond; a vagrant.</def> <altsp>[Written also
<asp>landleaper</asp> and <asp>landloper</asp>.]</altsp> <ldquo/Bands of
<xex>landloupers</xex>.<rdquo/ <rj><au>Moltey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlouping</ent><br/
<hw>Land"loup`ing</hw>, <pos>a.</pos> <def>Vagrant; wandering
about.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landlubber</ent><br/
<hw>Land"lub`ber</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prop. fr.
<ets>land</ets> + <ets>lubber</ets>, or possibly corrupted fr.
<ets>laudlouper</ets>.]</ety> <fld>(Naut.)</fld> <def>One who passes his
life on land; -- so called among seamen in contempt or
ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>landlubberly</ent><br/
<hw>landlubberly</hw> <pos>adj.</pos> <def>Like a landlubber:
inexperienced in seamanshap.</def><br/
<syn><b>Syn. --</b> lubberly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Landman</ent><br/
<hw>Land"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Landmen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A man who
lives or serves on land; -- opposed to <contr>seaman</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng.)</fld> <def>An occupier of land.</def>
<rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landmark</ent><br/
<hw>Land"mark`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>landmearc</ets>. See <er>Land</er>, and <er>Mark</er> a
sign.]</ety> <sn>1.</sn> <def>A mark to designate the boundary of land;
any mark or fixed object (as a marked tree, a stone, a ditch, or a heap
of stones) by which the limits of a farm, a town, or other portion of
territory may be known and preserved.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any conspicuous object on land that serves as a
guide; some prominent object, as a hill or steeple.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A structure that has special significance, such as a
building with historical associations;</def>
<specif>especially,</specif> <def>a building that is protected from
destruction or alteration by special laws intended to preserve
structures of historical significance; <as>as, a <ex>landmark</ex>
preservation law</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>An event or accomplishment of great significance;
<as>as, Brown v. Board of Education was a <ex>landmark</ex> of the civil
rights movement</as>. Also used attributively, as a <ex>landmark</ex>
court decision.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Landmarks of history</b></col>, <cd>important events by
which eras or conditions are determined.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>landmass</ent><br/
<hw>landmass</hw> <pos>n.</pos> <def>a large continuous extent of land;
<as>as, the Eurasian <ex>landmass</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Land of Steady Habits</ent><br/
<hw>Land of Steady Habits</hw> <pos>prop. n.</pos> <def>Connecticut; --
a nickname alluding to the moral character of its inhabitants, implied
by the rigid laws (see <er>Blue laws</er>) of the early
period.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landowner</ent><br/
<hw>Land"own`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An owner of
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landowning</ent><br/
<hw>Land"own`ing</hw>, <pos>n.</pos> <def>The owning of land.</def> --
<def2><pos>a.</pos> <def>Having property in land; of or pertaining to
landowners.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Land-poor</ent><br/
<hw>Land"-poor`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pecuniarily
embarrassed through owning much unprofitable land.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landreeve</ent><br/
<hw>Land"reeve`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Land</ets> +
<ets>reeve</ets> an officer.]</ety> <def>A subordinate officer on an
extensive estate, who acts as an assistant to the steward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landscape</ent><br/
<hw>Land"scape</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Formerly written
also <asp>landskip</asp>.]</altsp> <ety>[D. <ets>landschap</ets>;
<ets>land</ets> land + <ets>-schap</ets>, equiv. to E.
<ets>-schip</ets>; akin to G. <ets>landschaft</ets>, Sw.
<ets>landskap</ets>, Dan. <ets>landskab</ets>. See <er>Land</er>,
<er>and</er> <er>-schip</er>.]</ety> <sn>1.</sn> <def>A portion of land
or territory which the eye can comprehend in a single view, including
all the objects it contains.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A picture representing a scene by land or sea,
actual or fancied, the chief subject being the general aspect of nature,
as fields, hills, forests, water. etc. Compare
<contr>seascape</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The pictorial aspect of a country.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>landscape</qex> of his native country had taken hold on
his heart.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Landscape gardening</b></col>, <cd>The art of laying out
grounds and arranging trees, shrubbery, etc., in such a manner as to
produce a picturesque effect.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>landscaping</ent><br/
<hw>landscaping</hw> <pos>n.</pos> <def>Working as a landscape
gardner.</def><br/
<syn><b>Syn. --</b> landscape gardening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Landscapist</ent><br/
<hw>Land"scap`ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A painter of
landscapes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landskip</ent><br/
<hw>Land"skip</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Landscape</er>.]</ety> <def>A landscape.</def> <mark>[Obs. except in
poetry.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Straight my eye hath caught new pleasures,<br/
Whilst the <qex>landskip</qex> round it measures.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landslip</ent><br/
<ent>Landslide</ent><br/
<mhw>{ <hw>Land"slide`</hw> <pr>(?)</pr>, <hw>Land"slip`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <sn>1.</sn> <def>The slipping down
of a mass of land from a mountain, hill, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The land which slips down.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An election victory in which the winning candidate
receives a substantial majority of the votes, usually meaning at least
ten per cent more than any opposing candidate.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Any overwhelming victory.</def><br/
[<source>PJC</source>]</p>

<p><ent>Landsman</ent><br/
<hw>Lands"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Landsmen</plw> <pr>(#)</pr>.</plu> <sn>1.</sn> <def>One who lives
on the land; -- opposed to <contr>seaman</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A sailor on his first
voyage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landsthing</ent><br/
\'d8<hw>Lands"thing`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dan.
<ets>landsthing</ets>, <ets>landsting</ets>, fr. <ets>land</ets> land +
<ets>thing</ets>, <ets>ting</ets>, parliament. See <er>Land</er>;
<er>Thing</er>.]</ety> <fld>(Denmark.)</fld> <def>See
<er>Legislature</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landstorm</ent><br/
\'d8<hw>Land"storm`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sw.]</ety>
<def>See <er>Varnpligtige</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landstreight</ent><br/
<hw>Land"streight`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Strait</er>.]</ety> <def>A narrow strip of land.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landsturm</ent><br/
\'d8<hw>Land"sturm`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G. See
<er>Land</er>; <er>Storm</er>.]</ety> <mark>[In Germany and other
European nations, and Japan:]</mark> <sd>(a)</sd> <def>A general levy in
time of war.</def> <sd>(b)</sd> <def>The forces called out on such levy,
composed of all men liable to service who are not in the army, navy, or
Landwehr; the last line of defense, supposed to be called out only in
case of invasion or other grave emergency. See <er>Army
organization</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landtag</ent><br/
\'d8<hw>Land"tag`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G. See
<er>Land</er>; <er>Day</er>.]</ety> <fld>(Prussia.)</fld> <def>The diet
or legislative body; <as>as, the <ex>Landtag</ex> of Prussia</as>. See
<er>Legislature</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Landwaiter</ent><br/
<hw>Land"wait`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <cref>Landing
waiter</cref>, under <er>Landing</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landward</ent><br/
<hw>Land"ward</hw> <pr>(?)</pr>, <pos>adv. & a.</pos> <def>Toward the
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Landwehr</ent><br/
\'d8<hw>Land"wehr`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., fr.
<ets>land</ets> land, country + <ets>wehr</ets> defense.]</ety>
<def>That part of the army, in Germany and Austria, which has completed
the usual military service and is exempt from duty in time of peace,
except that it is called out occasionally for drill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lane</ent><br/
<hw>Lane</hw> <pr>(l<amac/n)</pr>, <pos>a.</pos> <ety>[See
<er>Lone</er>.]</ety> <def>Alone.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>His lane</b></col>, <cd>by himself; himself
alone.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lane</ent><br/
<hw>Lane</hw> <pr>(l<amac/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lane</ets>, <ets>lone</ets>, AS. <ets>lone</ets>, <ets>lone</ets>;
akin to D. <ets>laan</ets>, OFries. <ets>lana</ets>,
<ets>lona</ets>.]</ety> <def>A passageway between fences or hedges which
is not traveled as a highroad; an alley between buildings; a narrow way
among trees, rocks, and other natural obstructions; hence, in a general
sense, a narrow passageway; <as>as, a <ex>lane</ex> between lines of
men, or through a field of ice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is become a turn-again <qex>lane</qex> unto them which they can
not go through.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lang</ent><br/
<hw>Lang</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <def>Long.</def>
<mark>[Obs. or Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langaha</ent><br/
<hw>Lan"ga*ha</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
curious colubriform snake of the genus <gen>Xyphorhynchus</gen>, from
Madagascar. It is brownish red, and its nose is prolonged in the form of
a sharp blade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langarey</ent><br/
<hw>Lan`ga*rey"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of numerous species of long-winged, shrikelike birds of
Australia and the East Indies, of the genus <gen>Artamus</gen>, and
allied genera; called also <altname>wood swallow</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langate</ent><br/
<hw>Lan"gate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Surg.)</fld> <def>A
linen roller used in dressing wounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langdak</ent><br/
<hw>Lang"dak`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
wolf (<spn>Canis pallipes</spn>), found in India, allied to the
jackal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langrel</ent><br/
<ent>Langrage</ent><br/
<mhw>{ <hw>Lan"grage</hw> <pr>(?)</pr>, <hw>Lan"grel</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <def>A kind of shot formerly used at sea for
tearing sails and rigging. It consisted of bolts, nails, and other
pieces of iron fastened together or inclosed in a canister.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langret</ent><br/
<hw>Lan"gret</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of loaded
die.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langridge</ent><br/
<hw>Lan"gridge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Langrage</er>.</def> <note>[Sometimes compounded with
<xex>shot</xex>.]</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langsyne</ent><br/
<hw>Lang`syne"</hw> <pr>(?)</pr>, <pos>adv. & n.</pos> <ety>[Scot.
<ets>lang</ets> long + <ets>syne</ets> since.]</ety> <def>Long since;
long ago.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langteraloo</ent><br/
<hw>Lang`ter*a*loo"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Loo</er>.]</ety> <def>An old game at cards. See <er>Loo</er>
<sd>(a)</sd>.</def> <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Language</ent><br/
<hw>Lan"guage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>langage</ets>, F. <ets>langage</ets>, fr. L. <ets>lingua</ets> the
tongue, hence speech, language; akin to E. <ets>tongue</ets>. See
<er>Tongue</er>, cf. <er>Lingual</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Any means of conveying or communicating ideas;</def>
<specif>specifically,</specif> <def>human speech; the expression of
ideas by the voice; sounds, expressive of thought, articulated by the
organs of the throat and mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Language</xex> consists in the oral utterance of
sounds which usage has made the representatives of ideas. When two or
more persons customarily annex the same sounds to the same ideas, the
expression of these sounds by one person communicates his ideas to
another. This is the primary sense of <xex>language</xex>, the use of
which is to communicate the thoughts of one person to another through
the organs of hearing. Articulate sounds are represented to the eye by
letters, marks, or characters, which form words.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The expression of ideas by writing, or any other
instrumentality.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The forms of speech, or the methods of expressing
ideas, peculiar to a particular nation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The characteristic mode of arranging words, peculiar
to an individual speaker or writer; manner of expression;
style.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Others for <qex>language</qex> all their care express.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The inarticulate sounds by which animals inferior to
man express their feelings or their wants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The suggestion, by objects, actions, or conditions,
of ideas associated therewith; <as>as, the <ex>language</ex> of
flowers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was . . . <qex>language</qex> in their very gesture.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The vocabulary and phraseology belonging to an art
or department of knowledge; <as>as, medical <ex>language</ex>; the
<ex>language</ex> of chemistry or theology.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A race, as distinguished by its speech.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All the people, the nations, and the <qex>languages</qex>, fell
down and worshiped the golden image.</q> <rj><qau>Dan. iii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Any system of symbols created for the purpose of
communicating ideas, emotions, commands, etc., between sentient
agents.</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <specif>Specifically:</specif> <fld>(computers)</fld>
<def>Any set of symbols and the rules for combining them which are used
to specify to a computer the actions that it is to take; also referred
to as a <altname>computer lanugage</altname> or <altname>programming
language</altname>; <as>as, JAVA is a new and flexible high-level
<ex>language</ex> which has achieved popularity very
rapidly</as>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ Computer <ex>languages</ex> are classed a low-level if
each instruction specifies only one operation of the computer, or
high-level if each instruction may specify a complex combination of
operations. <stype>Machine language</stype> and <stype>assembly
language</stype> are low-level computer languages.
<stype>FORTRAN</stype>, <stype>COBOL</stype> and <stype>C</stype> are
high-level computer languages. Other computer languages, such as JAVA,
allow even more complex combinations of low-level operations to be
performed with a single command. Many programs, such as databases, are
supplied with special <ex>languages</ex> adapted to manipulate the
objects of concern for that specific program. These are also high-level
languages.</note><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Language master</b></col>, <cd>a teacher of
languages.</cd> <mark>[Obs.]</mark></cs></p>

<p><syn><b>Syn.</b> -- Speech; tongue; idiom; dialect; phraseology;
diction; discourse; conversation; talk.</syn> <usage> --
<er>Language</er>, <er>Speech</er>, <er>Tongue</er>, <er>Idiom</er>,
<er>Dialect</er>. <xex>Language</xex> is generic, denoting, in its most
extended use, any mode of conveying ideas; <xex>speech</xex> is the
language of articulate sounds; <xex>tongue</xex> is the Anglo-Saxon term
for language, esp. for spoken language; as, the English
<xex>tongue</xex>. <xex>Idiom</xex> denotes the forms of construction
peculiar to a particular language; <xex>dialects</xex> are varieties of
expression which spring up in different parts of a country among people
speaking substantially the same <xex>language</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Language</ent><br/
<hw>Lan"guage</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Languaged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Languaging</conjf> <pr>(?)</pr>.]</vmorph> <def>To communicate by
language; to express in language.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Others were <qex>languaged</qex> in such doubtful expressions that
they have a double sense.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languaged</ent><br/
<hw>Lan"guaged</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a language;
skilled in language; -- chiefly used in composition.</def> <ldquo/
Many-<xex>languaged</xex> nations.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languageless</ent><br/
<hw>Lan"guage*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lacking or
wanting language; speechless; silent.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langued</ent><br/
<hw>Langued</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>langue</ets>
tongue. See <er>Language</er>.]</ety> <fld>(Her.)</fld> <def>Tongued;
having the tongue visible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lions . . . represented as armed and <qex>langued</qex> gules.</q>
<rj><qau>Cussans.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langue d'oc</ent><br/
\'d8<hw>Langue` d'oc"</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[F., language
of <ets>oc</ets> yes.]</ety> <def>The dialect, closely akin to French,
formerly spoken south of the Loire (in which the word for
<ldquo/yes<rdquo/ was <tr>oc</tr>); Proven<cced/al.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langue d'oil</ent><br/
\'d8<hw>Langue` d'o<ium/l"</hw> <pr>(?)</pr>. <ety>[F., language of
<ets>o<ium/l</ets> yes.]</ety> <def>The dialect formerly spoken north of
the Loire (in which the word for <ldquo/yes<rdquo/ was <tr>oil</tr>, F.
<xex>oui</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languente</ent><br/
\'d8<hw>Lan*guen"te</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[It., p. pr.
of <ets>languire</ets>. See <er>Languish</er>.]</ety> <fld>(Mus.)</fld>
<def>In a languishing manner; pathetically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languet</ent><br/
<hw>Lan"guet</hw>, <pos>n.</pos> <ety>[F. <ets>languette</ets>, dim. of
<ets>langue</ets> tongue, L. <ets>lingua</ets>.]</ety> <sn>1.</sn>
<def>Anything resembling the tongue in form or office; specif., the slip
of metal in an organ pipe which turns the current of air toward its
mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That part of the hilt, in certain kinds of swords,
which overlaps the scabbard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languid</ent><br/
<hw>Lan"guid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>languidus</ets>, fr. <ets>languere</ets> to be faint or languid:
cf. F. <ets>languide</ets>. See <er>Languish</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Drooping or flagging from exhaustion; indisposed to
exertion; without animation; weak; weary; heavy; dull.</def> <ldquo/
<xex>Languid</xex>, powerless limbs. <rdquo/
<rj><au>Armstrong.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fire their <qex>languid</qex> souls with Cato's virtue.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Slow in progress; tardy.</def> <ldquo/ No motion so
swift or <xex>languid</xex>.<rdquo/ <rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Promoting or indicating weakness or heaviness;
<as>as, a <ex>languid</ex> day</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Feebly she laugheth in the <qex>languid</qex> moon.</q>
<rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their idleness, aimless flirtations and <qex>languid</qex>
airs.</q> <rj><qau>W. Black.</qau></rj></p>

<p><syn><b>Syn.</b> -- Feeble; weak; faint; sickly; pining; exhausted;
weary; listless; heavy; dull; heartless.</syn></p>

<p>-- <wordforms><wf>Lan"guid*ly</wf>, <pos>adv.</pos> --
<wf>Lan"guid*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languish</ent><br/
<hw>Lan"guish</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Languished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Languishing</conjf>.]</vmorph> <ety>[OE.
<ets>languishen</ets>, <ets>languissen</ets>, F. <ets>languir</ets>, L.
<ets>languere</ets>; cf. Gr. <?/ to slacken, <?/ slack, Icel.
<ets>lakra</ets> to lag behind; prob. akin to E. <ets>lag</ets>,
<ets>lax</ets>, and perh. to E. <ets>slack</ets>. See
<er>-ish</er>.]</ety> <sn>1.</sn> <def>To become languid or weak; to
lose strength or animation; to be or become dull, feeble or spiritless;
to pine away; to linger in a weak or deteriorating condition; to wither
or fade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We . . . do <qex>languish</qex> of such diseases.</q> <rj><qau>2
Esdras viii. 31.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cease, fond nature, cease thy strife,<br/
And let me <qex>languish</qex> into life.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For the fields of Heshbon <qex>languish</qex>.</q> <rj><qau>Is.
xvi. 8. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To assume an expression of weariness or tender
grief, appealing for sympathy.</def> <rj><au>Tennyson.</au></rj></p>

<p><sn>3.</sn> <def>To be neglected and unattended to; <as>as, the
proposal <ex>languished</ex> on the director's desk for
months</as>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- To pine; wither; fade; droop; faint.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languish</ent><br/
<hw>Lan"guish</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To cause to droop
or pine.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au>
<au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languish</ent><br/
<hw>Lan"guish</hw>, <pos>n.</pos> <def>See <er>Languishment</er>.</def>
<mark>[Obs. or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What, of death, too,<br/
That rids our dogs of <qex>languish</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the blue <qex>languish</qex> of soft Allia's eye.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languisher</ent><br/
<hw>Lan"guish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
languishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languishing</ent><br/
<hw>Lan"guish*ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Becoming languid
and weak; pining; losing health and strength.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Amorously pensive; indicating melancholy; <as>as,
<ex>languishing</ex> eyes, or look</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Suffering neglect; neglected.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Continuing in a weak or deteriorating state;
lingering.</def><br/
[<source>PJC</source>]</p>

<p><ent>Languishingly</ent><br/
<hw>Lan"guish*ing*ly</hw>, <pos>adv.</pos> <def>In a languishing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languishment</ent><br/
<hw>Lan"guish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state of languishing.</def> <ldquo/Lingering
<xex>languishment</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tenderness of look or mien; amorous
pensiveness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languishness</ent><br/
<hw>Lan"guish*ness</hw>, <pos>n.</pos> <def>Languishment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languor</ent><br/
<hw>Lan"guor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>langour</ets>, OF. <ets>langour</ets>, F. <ets>langueur</ets>, L.
<ets>languor</ets>. See Languish.]</ety> <sn>1.</sn> <def>A state of the
body or mind which is caused by exhaustion of strength and characterized
by a languid feeling; feebleness; lassitude; laxity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any enfeebling disease.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sick men with divers <qex>languors</qex>.</q> <rj><qau>Wyclif
(Luke iv. 40).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Listless indolence; dreaminess.</def> <au>Pope.</au>
<ldquo/ German dreams, Italian <xex>languors</xex>.<rdquo/ <rj><au>The
Century.</au></rj></p>

<p><syn><b>Syn.</b> -- Feebleness; weakness; faintness; weariness;
dullness; heaviness; lassitude; listlessness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Languorous</ent><br/
<hw>Lan"guor*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Languor</er>: cf. F. <ets>langoureux</ets>.]</ety> <def>Producing,
or tending to produce, languor; characterized by languor.</def>
<mark>[Obs. or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whom late I left in <qex>languorous</qex> constraint.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To wile the length from <qex>languorous</qex> hours, and draw<br/
The sting from pain.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langure</ent><br/
<hw>Lan"gure</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To languish.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Langya</ent><br/
<hw>Lan"gya</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<ety>[Native name Anglicized.]</ety> <def>One of several species of East
Indian and Asiatic fresh-water fishes of the genus
<gen>Ophiocephalus</gen>, remarkable for their power of living out of
water, and for their tenacity of life; -- called also <altname>walking
fishes</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniard</ent><br/
<hw>Lan"iard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lanyard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniariform</ent><br/
<hw>La`ni*ar"i*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Laniary</ets> + <ets>-form</ets>.]</ety> <fld>(Anat.)</fld>
<def>Shaped like a laniary, or canine, tooth.</def>
<rj><au>Owen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniary</ent><br/
<hw>La"ni*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laniarius</ets>, fr. <ets>lanius</ets> butcher, <ets>laniare</ets>
to tear in pieces: cf. F. <ets>laniaire</ets>.]</ety> <fld>(Anat.)</fld>
<def>Lacerating or tearing; <as>as, the <ex>laniary</ex> canine
teeth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniary</ent><br/
<hw>La"ni*a*ry</hw>, <pos>n.</pos> <ety>[L. <er>Laniary</er>,
<pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The shambles; a place of slaughter.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A laniary, or canine,
tooth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniate</ent><br/
<hw>La"ni*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>laniatus</ets>, p. p. of <ets>laniare</ets>.]</ety> <def>To tear in
pieces.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniation</ent><br/
<hw>La`ni*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laniatio</ets>.]</ety> <def>A tearing in pieces.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanier</ent><br/
<hw>Lan"ier</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lani<egrave/re</ets>. See <er>Lanyard</er>.]</ety> <altsp>[Written
also <asp>lanner</asp>, <asp>lanyer</asp>.]</altsp> <sn>1.</sn> <def>A
thong of leather; a whip lash.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A strap used to fasten together parts of armor, to
hold the shield by, and the like.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laniferous</ent><br/
<hw>La*nif"er*ous</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lanifer</ets>; <ets>lana</ets> wool + <ets>ferre</ets> to bear: cf.
F. <ets>lanif<egrave/re</ets>.]</ety> <def>Bearing or producing
wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanifical</ent><br/
<hw>La*nif"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lanificus</ets>; <ets>lana</ets> wool + <ets>facere</ets> to
make.]</ety> <def>Working in wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanifice</ent><br/
<hw>Lan"i*fice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lanificium</ets>: cf. OF. <ets>lanifice</ets>.]</ety> <def>Anything
made of wool.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanigerous</ent><br/
<hw>La*nig"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laniger</ets>; <ets>lano</ets> wool + <ets>gerere</ets> to
hear.]</ety> <def>Bearing or producing wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanioid</ent><br/
<hw>La"ni*oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>Lanius</ets> (fr. L. <ets>lanius</ets> a butcher), the typical
genus + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Of or pertaining
to the shrikes (family <fam>Laniid<ae/</fam>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lank</ent><br/
<hw>Lank</hw> <pr>(l<acr/<nsm/k)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Lanker</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Lankest</adjf>.]</amorph> <ety>[<er>AS</er>.
<ets>hlanc</ets>; cf. G. <ets>lenken</ets> to turn, <ets>gelenk</ets>
joint, OHG. <ets>hlanca</ets> hip, side, flank, and E. <ets>link</ets>
of a chain.]</ety> <sn>1.</sn> <def>Slender and thin; not well filled
out; not plump; shrunken; lean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Meager and <qex>lank</qex> with fasting grown.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who would not choose . . . to have rather a <qex>lank</qex> purse
than an empty brain?</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Languid; drooping.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, piteous of her woes, reared her <qex>lank</qex> head.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lank hair</b></col>, <cd>long, thin hair.</cd>
<rj><au>Macaulay.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lank</ent><br/
<hw>Lank</hw>, <pos>v. i. & t.</pos> <def>To become lank; to make
lank.</def> <mark>[Obs.]</mark> <au>Shak.</au> <au>G. Fletcher.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lankiness</ent><br/
<hw>Lank"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition or
quality or being lanky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lankly</ent><br/
<hw>Lank"ly</hw>, <pos>adv.</pos> <def>In a lank manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lankness</ent><br/
<hw>Lank"ness</hw>, <pos>n.</pos> <def>The state or quality of being
lank.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanky</ent><br/
<hw>Lank"y</hw>, <pos>a.</pos> <def>Somewhat lank; tall, thin, bony and
ungraceful.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lanky</qex> Dinka, nearly seven feet in height.</q>
<rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanneret</ent><br/
<ent>Lanner</ent><br/
<mhw>{ <hw>Lan"ner</hw> <pr>(?)</pr>, <pos>n. f.</pos>
<hw>Lan"ner*et</hw> <pr>(?)</pr>, <pos>n. m.</pos>}</mhw> <ety>[F.
<ets>lanier</ets>, OF. also, <ets>lasnier</ets>. Cf.
<er>Lanyard</er>.]</ety> <fld>(Zool.)</fld> <def>A long-tailed falcon
(<spn>Falco lanarius</spn>), of Southern Europe, Asia, and Northern
Africa, resembling the American prairie falcon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanolin</ent><br/
<hw>Lan"o*lin</hw> <pr>(l<acr/n"<osl/*l<icr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>lana</ets> wool + <ets>ole</ets>um oil.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A peculiar fatlike body, made up of
cholesterin and certain fatty acids, found in feathers, hair, wool, and
keratin tissues generally.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Under the same name, it is prepared from wool for
commercial purposes, and forms an admirable basis for ointments, being
readily absorbed by the skin.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>lansah</ent><br/
<ent>lansa</ent><br/
<mhw><hw>lansa</hw>, <hw>lansah</hw></mhw> <pos>n.</pos> <def>Same as
<er>lanseh</er>.</def><br/
<syn><b>Syn. --</b> lanseh, lansat, lanset.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 829 --></p>

<p><ent>Lanseh</ent><br/
\'d8<hw>Lan"seh</hw> <pr>(l<adot/n"s<asl/)</pr>, <pos>n.</pos> <def>The
small, yellow to whitish brown berrylike fruit of an East Indian tree
(<spn>Lansium domesticum</spn>). It has a fleshy pulp, with an agreeable
tart subacid taste.</def> <rj><au>Balfour.</au></rj><br/
<syn><b>Syn. --</b> lansah, lansa, lansat, lanset.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Lansquenet</ent><br/
<hw>Lans"que*net</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. G.
<ets>landsknecht</ets> a foot soldier, also a game of cards introduced
by these foot soldiers; <ets>land</ets> country + <ets>knecht</ets> boy,
servant. See <er>Land</er>, and <er>Knight</er>.]</ety> <sn>1.</sn>
<def>A German foot soldier in foreign service in the 15th and 16th
centuries; a soldier of fortune; -- a term used in France and Western
Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A game at cards, vulgarly called
<altname>lambskinnet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[They play] their little game of <qex>lansquenet</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lant</ent><br/
<hw>Lant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Urine.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lant</ent><br/
<hw>Lant</hw>, <pos>n.</pos> <ety>[Cf. <er>Lance</er>.]</ety>
<fld>(Zool.)</fld> <def>Any one of several species of small, slender,
marine fishes of the genus <gen>Ammedytes</gen>. The common European
species (<spn>Ammedytes tobianus</spn>) and the American species
(<spn>Ammedytes Americanus</spn>) live on sandy shores, buried in the
sand, and are caught in large quantities for bait. Called also
<altname>launce</altname>, and <altname>sand eel</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lant</ent><br/
<hw>Lant</hw>, <pos>n.</pos> <def>See <er>Lanterloo</er>.</def>
<mark>[Obs.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lantanum</ent><br/
<ent>Lantanium</ent><br/
<mhw>{ <hw>Lan*ta"ni*um</hw> <pr>(?)</pr>, <hw>Lan"ta*num</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Chem.)</fld> <def>See
<er>Lanthanum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lantanuric</ent><br/
<hw>Lan`ta*nu"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Formed by
transposition of the letters of <ets>allantoin</ets> and
<ets>-uric</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, a nitrogenous organic acid of the uric acid group, obtained
by the decomposition of allantoin, and usually called
<altname>allanturic acid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanterloo</ent><br/
<hw>Lan"ter*loo`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An old name of
<altname>loo</altname> <sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lantern</ent><br/
<hw>Lan"tern</hw> <pr>(l<acr/n"t<etil/rn)</pr>, <pos>n.</pos> <ety>[F.
<ets>lanterne</ets>, L. <ets>lanterna</ets>, <ets>laterna</ets>, from
Gr. <grk>lampth`r</grk> light, torch. See <er>Lamp</er>.]</ety>
<sn>1.</sn> <def>Something inclosing a light, and protecting it from
wind, rain, etc.; -- sometimes portable, as a closed vessel or case of
horn, perforated tin, glass, oiled paper, or other material, having a
lamp or candle within; sometimes fixed, as the glazed inclosure of a
street light, or of a lighthouse light.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>An open structure of
light material set upon a roof, to give light and air to the
interior.</def> <sd>(b)</sd> <def>A cage or open chamber of rich
architecture, open below into the building or tower which it
crowns.</def> <sd>(c)</sd> <def>A smaller and secondary cupola crowning
a larger one, for ornament, or to admit light; such as the lantern of
the cupola of the Capitol at Washington, or that of the Florence
cathedral.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>A lantern pinion or trundle
wheel. See <cref>Lantern pinion</cref> (below).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Steam Engine)</fld> <def>A kind of cage inserted in
a stuffing box and surrounding a piston rod, to separate the packing
into two parts and form a chamber between for the reception of steam,
etc.; -- called also <altname>lantern brass</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Founding)</fld> <def>A perforated barrel to form a
core upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Zool.)</fld> <def>See <er>Aristotle's
lantern</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Fig. 1 represents a <xex>hand lantern</xex>; fig. 2, an
<xex>arm lantern</xex>; fig. 3, a <xex>breast lantern</xex>; -- so named
from the positions in which they are carried.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dark lantern</b></col>, <cd>a lantern with a single
opening, which may be closed so as to conceal the light; -- called also
<altname>bull's-eye</altname>.</cd> -- <col><b>Lantern jaws</b></col>,
<cd>long, thin jaws; hence, a thin visage.</cd> -- <mcol><col><b>Lantern
pinion</b></col>, <col><b>Lantern wheel</b></col></mcol>
<fld>(Mach.)</fld>, <cd>a kind of pinion or wheel having cylindrical
bars or trundles, instead of teeth, inserted at their ends in two
parallel disks or plates; -- so called as resembling a lantern in shape;
-- called also <altname>wallower</altname>, or
<altname>trundle</altname>.</cd> -- <col><b>Lantern shell</b></col>
<fld>(Zool.)</fld>, <cd>any translucent, marine, bivalve shell of the
genus <altname>Anatina</altname>, and allied genera.</cd> --
<col><b>Magic lantern</b></col>, <cd>an optical instrument consisting of
a case inclosing a light, and having suitable lenses in a lateral tube,
for throwing upon a screen, in a darkened room or the like, greatly
magnified pictures from slides placed in the focus of the outer
lens.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lantern</ent><br/
<hw>Lan"tern</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lanterned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lanterning</conjf>.]</vmorph> <ety>[Cf. F. <ets>lanterner</ets>
to hang at the lamp post, fr. <ets>lanterne</ets>. See
<er>Lantern</er>.]</ety> <def>To furnish with a lantern; <as>as, to
<ex>lantern</ex> a lighthouse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lanternfish</ent><br/
<hw>lanternfish</hw> <pos>n.</pos> <def>A small fish having rows of
luminous organs along each side; some surface at night.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lantern fly</ent><br/
<ent>lanternfly</ent><br/
<mhw><hw>lanternfly</hw>, <hw>lantern fly</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>any one of several species of large, handsome,
brightly marked, tropical hemipterous insects of the genera
<gen>Laternaria</gen>, <gen>Fulgora</gen>, and allies, of the family
<fam>Fulgorid<ae/</fam>. The largest species is <spn>Laternaria
phosphorea</spn> of Brazil. The head has a snoutlike process in some
species which was formerly thought to emit a phosphorescent
light.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lantern-jawed</ent><br/
<hw>Lan"tern-jawed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having lantern
jaws or long, thin jaws; <as>as, a <ex>lantern-jawed</ex>
person</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lanthanide</ent><br/
<hw>lanthanide</hw> <pos>n.</pos> <def>Any <isa>rare earth element</isa>
of the lanthanide series (atomic numbers 57 through 71).</def><br/
<syn><b>Syn. --</b> rare earth, rare-earth element, lanthanon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lanthanite</ent><br/
<hw>Lan"tha*nite</hw> <pr>(l<acr/n"th<adot/*n<imac/t)</pr>,
<pos>n.</pos> <fld>(Min.)</fld> <def>Hydrous carbonate of lanthanum,
found in tabular white crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lanthanon</ent><br/
<hw>lanthanon</hw> <pos>n.</pos> <def>Same as
<er>lanthanide</er>.</def><br/
<syn><b>Syn. --</b> rare earth, rare-earth element,
lanthanide.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lanthanotidae</ent><br/
<hw>Lanthanotidae</hw> <pos>n.</pos> <def>A natural family of
stout-bodied lizards.</def><br/
<syn><b>Syn. --</b> family <fam>Lanthanotidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lanthanotus</ent><br/
<hw>Lanthanotus</hw> <pos>n.</pos> <def>A genus withonly one
species.</def><br/
<syn><b>Syn. --</b> genus <gen>Lanthanotus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lanthanum</ent><br/
<hw>Lan"tha*num</hw> <pr>(l<acr/n"th<adot/*n<ucr/m)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>lanqa`nein</grk> to lie hid, to be
concealed.]</ety> <fld>(Chem.)</fld> <def>A rare element of the rare
earth group of the metals, of atomic number 57, allied to aluminum. It
occurs in certain rare minerals, as cerite, gadolinite, orthite, etc.,
and was so named from the difficulty of separating it from cerium,
didymium, and other rare earth elements with which it is usually
associated. Atomic weight 138.9. Symbol La.</def> <altsp>[Formerly
written also <asp>lanthanium</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanthopine</ent><br/
<hw>Lan"tho*pine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lanqa`nein</grk> to lie hid + E. <ets>op</ets>ium.]</ety>
<fld>(Chem.)</fld> <def>An alkaloid found in opium in small quantities,
and extracted as a white crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanthorn</ent><br/
<hw>Lan"thorn</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lantern</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanuginous</ent><br/
<ent>Lanuginose</ent><br/
<mhw>{ <hw>La*nu"gi*nose`</hw> <pr>(?)</pr>, <hw>La*nu"gi*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lanuginosus</ets>, fr.
<ets>lanugo</ets>, <ets>-ginis</ets>, woolly substance, down, fr.
<ets>lana</ets> wool: cf. F. <ets>lanugineux</ets>.]</ety> <def>Covered
with down, or fine soft hair; downy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanugo</ent><br/
\'d8<hw>La*nu"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lanuginose</er>.]</ety> <fld>(Anat.)</fld> <def>The soft woolly hair
which covers most parts of the mammal fetus, and in man is shed before
or soon after birth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanyard</ent><br/
<hw>Lan"yard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lani<egrave/re</ets> thong, strap, OF. <ets>lasniere</ets>, fr.
<ets>lasne</ets> strap, thong, L. <ets>lacinia</ets> lappet. flap, edge
of a garment. Cf. <er>Lanier</er>.]</ety> <altsp>[Written also
<asp>laniard</asp>.]</altsp> <sn>1.</sn> <fld>(Naut.)</fld> <def>A short
piece of rope or line for fastening something in ships; <as>as, the
<ex>lanyards</ex> of the gun ports, of the buoy, and the like</as>;
esp., pieces passing through the dead-eyes, and used to extend shrouds,
stays, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A strong cord, about twelve feet
long, with an iron hook at one end a handle at the other, used in firing
cannon with a friction tube.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lanyer</ent><br/
<hw>Lan"yer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lanier</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laocoon</ent><br/
<hw>La*oc"o*<oum/n</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., fr.
Gr. <?/ ]</ety> <sn>1.</sn> <fld>(Class. Myth.)</fld> <def>A priest of
Apollo, during the Trojan war. (See 2.)</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Sculp.)</fld> <def>A marble group in the Vatican at
Rome, representing the priest Laoco<oum/n, with his sons, infolded in
the coils of two serpents, as described by Virgil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laodicean</ent><br/
<hw>La*od`i*ce"an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to <etsep>Laodicea</etsep>, a city in Phrygia Major; like the Christians
of Laodicea; lukewarm in religion.</def> <rj><au>Rev. iii.
14-16.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laos</ent><br/
<hw>Laos</hw> <pos>prop. n.</pos> <def>a country in Southeast
Asia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laotian</ent><br/
<hw>Laotian</hw> <pos>prop. n.</pos> <def>a native or inhabitant of
Laos.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laotian</ent><br/
<hw>Laotian</hw> <pos>prop. a.</pos> <sn>1.</sn> <def>of or pertaining
to Laos; <as>as, the <ex>Laotian</ex> Prime Minister</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to the inhabitants of Laos; <as>as,
<ex>Laotian</ex> refugees</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laozi</ent><br/
<ent>Lao-tse</ent><br/
<mhw><hw>Lao-tse</hw>, <hw>Laozi</hw></mhw> <pos>prop. n.</pos> <def>A
Chinese philosopher who founded Taoism in the 6th-century b.c.</def><br/
<syn><b>Syn. --</b> Lao-Tzu, Lao-Tse.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw> <pr>(l<acr/p)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lappe</ets>, AS. <ets>l<ae/ppa</ets>; akin to D. <ets>lap</ets>
patch, piece, G. <ets>lappen</ets>, OHG. <ets>lappa</ets>, Dan.
<ets>lap</ets>, Sw. <ets>lapp</ets>.]</ety> <sn>1.</sn> <def>The loose
part of a coat; the lower part of a garment that plays loosely; a skirt;
an apron.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An edge; a border; a hem, as of cloth.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If he cuts off but a <qex>lap</qex> of truth's garment, his heart
smites him.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The part of the clothing that lies on the knees or
thighs when one sits down; that part of the person thus covered;
figuratively, a place of rearing and fostering; <as>as, to be reared in
the <ex>lap</ex> of luxury</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men expect that happiness should drop into their
<qex>laps</qex>.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That part of any substance or fixture which extends
over, or lies upon, or by the side of, a part of another; <as>as, the
<ex>lap</ex> of a board</as>; also, the measure of such extension over
or upon another thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>lap</xex> of shingles or slates in roofing is
the distance one course extends over the second course below, the
distance over the course immediately below being called the
<xex>cover</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Steam Engine)</fld> <def>The amount by which a
slide valve at its half stroke overlaps a port in the seat, being equal
to the distance the valve must move from its mid stroke position in
order to begin to open the port. Used alone, <xex>lap</xex> refers to
outside lap. See <cref>Outside lap</cref> (below).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The state or condition of being in part extended
over or by the side of something else; or the extent of the overlapping;
<as>as, the second boat got a <ex>lap</ex> of half its length on the
leader</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>One circuit around a race track, esp. when the
distance is a small fraction of a mile; <as>as, to run twenty
<ex>laps</ex>; to win by three <ex>laps</ex>. See <er>Lap</er>, to fold,
2.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>In card playing and other games, the points won in
excess of the number necessary to complete a game; -- so called when
they are counted in the score of the following game.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Cotton Manuf.)</fld> <def>A sheet, layer, or bat,
of cotton fiber prepared for the carding machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Mach.)</fld> <def>A piece of brass, lead, or other
soft metal, used to hold a cutting or polishing powder in cutting glass,
gems, and the like, or in polishing cutlery, etc. It is usually in the
form of wheel or disk, which revolves on a vertical axis.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lap joint</b></col>, <cd>a joint made by one layer, part,
or piece, overlapping another, as in the scarfing of timbers.</cd> --
<col><b>Lap weld</b></col>, <cd>a lap joint made by welding together
overlapping edges or ends.</cd> -- <col><b>Inside lap</b></col>
<fld>(Steam Engine)</fld>, <cd>lap of the valve with respect to the
exhaust port.</cd> -- <col><b>Outside lap</b></col>, <cd>lap with
respect to the admission, or steam, port.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lapped</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lapping</conjf>.]</vmorph> <sn>1.</sn> <def>To rest or recline in
a lap, or as in a lap.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>lap</qex> his head on lady's breast.</q>
<rj><qau>Praed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut or polish with a lap, as glass, gems,
cutlery, etc. See 1st <er>Lap</er>, 10.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw>, <pos>v. t.</pos> <ety>[OE. <ets>lappen</ets> to fold (see
<er>Lap</er>, <pos>n.</pos>); cf. also OE. <ets>wlappen</ets>, perh.
another form of <ets>wrappen</ets>, E, <ets>wrap</ets>.]</ety>
<sn>1.</sn> <def>To fold; to bend and lay over or on something; <as>as,
to <ex>lap</ex> a piece of cloth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wrap or wind around something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>About the paper . . . I <qex>lapped</qex> several times a slender
thread of very black silk.</q> <rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To infold; to hold as in one's lap; to
cherish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her garment spreads, and <qex>laps</qex> him in the folds.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To lay or place over anything so as to partly or
wholly cover it; <as>as, to <ex>lap</ex> one shingle over another</as>;
to lay together one partly over another; <as>as, to <ex>lap</ex>
weather-boards</as>; also, to be partly over, or by the side of
(something); <as>as, the hinder boat <ex>lapped</ex> the foremost
one</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Carding & Spinning)</fld> <def>To lay together one
over another, as fleeces or slivers for further working.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To lap boards</b></col>,
<col><b>shingles</b></col>, etc.</mcol>, <cd>to lay one partly over
another.</cd> -- <col><b>To lap timbers</b></col>, <cd>to unite them in
such a way as to preserve the same breadth and depth throughout, as by
scarfing.</cd> <rj><au>Weale.</au></rj> </cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw>, <pos>v. i.</pos> <def>To be turned or folded; to lie
partly upon or by the side of something, or of one another; <as>as, the
cloth <ex>laps</ex> back; the boats <ex>lap</ex>; the edges
<ex>lap</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The upper wings are opacous; at their hinder ends, where they
<qex>lap</qex> over, transparent, like the wing of a flay.</q>
<rj><qau>Grew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE. <ets>lappen</ets>,
<ets>lapen</ets>, AS. <ets>lapian</ets>; akin to LG. <ets>lappen</ets>,
OHG. <ets>laffan</ets>, Icel. <ets>lepja</ets>, Dan. <ets>lade</ets>,
Sw. <ets>l<aum/ppja</ets>, L. <ets>lambere</ets>; cf. Gr. <?/, W.
<ets>llepio</ets>. Cf. <er>Lambent</er>.]</ety> <sn>1.</sn> <def>To take
up drink or food with the tongue; to drink or feed by licking up
something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dogs by the River Nilus's side, being thirsty, <qex>lap</qex>
hastily as they run along the shore.</q> <rj><qau>Sir K.
Digby.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a sound like that produced by taking up
drink with the tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I heard the ripple washing in the reeds,<br/
And the wild water <qex>lapping</qex> on the crag.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw>, <pos>v. t.</pos> <def>To take into the mouth with the
tongue; to lick up with a quick motion of the tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They 'II take suggestion as a cat <qex>laps</qex> milk.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap</ent><br/
<hw>Lap</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of lapping with, or
as with, the tongue; <as>as, to take anything into the mouth with a
<ex>lap</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sound of lapping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laparocele</ent><br/
<hw>Lap"a*ro*cele`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ loins
+ <?/ tumor.]</ety> <fld>(Med.)</fld> <def>A rupture or hernia in the
lumbar regions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>laparoscope</ent><br/
<hw>laparoscope</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>A slender
endoscope, containing fiber-optic viewing capability and miniature
surgical devices, which can be inserted through a small incision in the
abdominal wall, allowing a surgeon to perform minor surgery with minimal
damage to the abdominal muscles.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>laparoscopy</ent><br/
<hw>laparoscopy</hw> <pos>n.</pos> <def>Laparotomy performed with a
laparoscope.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laparotomy</ent><br/
<hw>Lap`a*rot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ loins
+ <grk>te`mnein</grk> to cut.]</ety> <fld>(Surg.)</fld> <def>A cutting
through the walls of the abdomen, as in the Caesarean section.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapboard</ent><br/
<hw>Lap"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A board used on the
lap as a substitute for a table, as by tailors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapdog</ent><br/
<hw>Lap"dog`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A small
dog which is or can be fondled in the lap.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who does the bidding of another; a servile
follower.</def> <mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Lapel</ent><br/
<hw>La*pel"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>lap</ets> a fold.]</ety> <def>That part of a garment which is
turned back; specifically, the lap, or fold, of the front of a coat in
continuation of collar.</def> <altsp>[Written also <asp>lappel</asp> and
<asp>lapelle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapelled</ent><br/
<hw>La*pelled"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with
lapels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapful</ent><br/
<hw>Lap"ful</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lapfuls</plw> <pr>(<?/)</pr>.</plu> <def>As much as the lap can
contain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapicide</ent><br/
<hw>Lap"i*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lapicida</ets>, fr. <ets>lapis</ets> stone + <ets>caedere</ets> to
cut.]</ety> <def>A stonecutter.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidarian</ent><br/
<hw>Lap`i*da"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to stone; inscribed on stone; <as>as, a <ex>lapidarian</ex>
record</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidarious</ent><br/
<hw>Lap`i*da"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lapidarius</ets>, fr. <ets>lapis</ets>, <ets>-idis</ets>,
stone.]</ety> <def>Consisting of stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidary</ent><br/
<hw>Lap"i*da*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lapidaries</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>lapidarius</ets>, fr. <ets>lapidarius</ets> pertaining to stone:
cf. F. <ets>lapidaire</ets>.]</ety> <sn>1.</sn> <def>An artificer who
cuts, polishes, and engraves precious stones; hence, a dealer in
precious stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A virtuoso skilled in gems or precious stones; a
connoisseur of lapidary work.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Lapidary's lathe</b></col>, <col><b>Lapidary's
mill</b></col>, <col><b>Lapidary's wheel</b></col></mcol>, <cd>a machine
consisting essentially of a revolving lap on a vertical spindle, used by
a lapidary for grinding and polishing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidary</ent><br/
<hw>Lap"i*da*ry</hw>, <pos>a.</pos> <ety>[L. <ets>lapidarius</ets>
pertaining to stone: cf. F. <ets>lapidaire</ets>.]</ety> <sn>1.</sn>
<def>Of or pertaining to the art of cutting stones, or engraving on
stones, either gems or monuments; <as>as, <ex>lapidary</ex>
ornamentation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to monumental inscriptions; <as>as,
<ex>lapidary</ex> adulation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lapidary style</b></col>, <cd>that style which is proper
for monumental and other inscriptions; terse; sententious.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidate</ent><br/
<hw>Lap"i*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>lapidatus</ets>, p. p. of <ets>lapidare</ets>, fr. <ets>lapis</ets>
stone.]</ety> <def>To stone.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidation</ent><br/
<hw>Lap`i*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lapidatio</ets>: cf. F. <ets>lapidation</ets>.]</ety> <def>The act
of stoning.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapideous</ent><br/
<hw>La*pid"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lapideus</ets>, fr. <ets>lapis</ets> stone.]</ety> <def>Of the
nature of stone.</def> <mark>[Obs.]</mark> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidescence</ent><br/
<hw>Lap`i*des"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The state or quality of being lapidescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hardening into a stone substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A stony concretion.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidescent</ent><br/
<hw>Lap`i*des"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lapidescens</ets>, p. pr. of <ets>lapidescere</ets> to become
stone, fr. <ets>lapis</ets>, <ets>-idis</ets>, stone: cf. F.
<ets>lapidescent</ets>.]</ety> <def>Undergoing the process of becoming
stone; having the capacity of being converted into stone; having the
quality of petrifying bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidescent</ent><br/
<hw>Lap"i*des"cent</hw>, <pos>n.</pos> <def>Any substance which has the
quality of petrifying other bodies, or of converting or being converted
into stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidifical</ent><br/
<ent>Lapidific</ent><br/
<mhw>{ <hw>Lap`i*dif"ic</hw> <pr>(?)</pr>, <hw>Lap`i*dif"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lapis</ets>,
<ets>-idis</ets>, stone + <ets>facere</ets> to make: cf. F.
<ets>lapidifique</ets>.]</ety> <def>Forming or converting into
stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidification</ent><br/
<hw>La*pid`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lapidification</ets>.]</ety> <def>The act or process of
lapidifying; fossilization; petrifaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidify</ent><br/
<hw>La*pid"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lapidified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lapidifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. f.
<ets>lapidifier</ets>. See <er>Lapidific</er>, and <er>-fy</er>.]</ety>
<def>To convert into stone or stony material; to petrify.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidify</ent><br/
<hw>La*pid"i*fy</hw>, <pos>v. i.</pos> <def>To become stone or
stony.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapidist</ent><br/
<hw>Lap"i*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lapis</ets>, <ets>-idis</ets>, a stone.]</ety> <def>A
lapidary.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapillation</ent><br/
<hw>Lap"il*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lapilli</er>.]</ety> <def>The state of being, or the act of making,
stony.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapilli</ent><br/
\'d8<hw>La*pil"li</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>lapillus</ets> a little stone, dim. of <ets>lapis</ets>
stone.]</ety> <fld>(Min.)</fld> <def>Volcanic ashes, consisting of
small, angular, stony fragments or particles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapis</ent><br/
\'d8<hw>La"pis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lapides</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>A
stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lapis calaminaris</b></col> <pr>(<?/)</pr> <pos>n.</pos>
<ety>[NL.]</ety> <fld>(Min.)</fld> <cd>Calamine.</cd> -- <col><b>Lapis
infernalis</b></col> <pr>(<?/)</pr> <pos>n.</pos> <ety>[L.]</ety>
<cd>Fused nitrate of silver; lunar caustic.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapis lazuli</ent><br/
<hw>La"pis laz"u*li</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Min.)</fld>
<def>An albuminous mineral of a rich blue color; also called
<altname>lapis</altname>. Same as <er>Lazuli</er>, which see.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap-jointed</ent><br/
<hw>Lap"-joint`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a lap
joint, or lap joints, as many kinds of woodwork and metal
work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laplander</ent><br/
<hw>Lap"land*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A native or
inhabitant of Lapland; -- called also <altname>Lapp</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laplandish</ent><br/
<hw>Lap"land*ish</hw>, <pos>a.</pos> <def>Of or pertaining to
Lapland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapling</ent><br/
<hw>Lap"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lap</ets> of a
garment + <ets>ling</ets>.]</ety> <def>One who has been fondled to
excess; one fond of ease and sensual delights; -- a term of
contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapp</ent><br/
<hw>Lapp</hw> <pr>(l<acr/p)</pr>, <pos>n.</pos> <def>Same as
<er>Laplander</er>. Cf. <er>Lapps</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 830 --></p>

<p><ent>Lappaceous</ent><br/
<hw>Lap*pa"ceous</hw> <pr>(l<acr/p*p<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>lappaceus</ets> burlike, fr. <ets>lappa</ets> a
bur.]</ety> <fld>(Bot.)</fld> <def>Resembling the capitulum of burdock;
covered with forked points.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapper</ent><br/
<hw>Lap"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>La</er>p to
drink.]</ety> <def>One who takes up food or liquid with his
tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lappet</ent><br/
<hw>Lap"pet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>lap</ets> a fold.]</ety> <def>A small decorative fold or flap, esp.
of lace or muslin, in a garment or headdress.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lappet moth</b></col> <fld>(Zool.)</fld>, <cd>one of
several species of bombycid moths, which have stout, hairy caterpillars,
flat beneath. Two common American species (<spn>Gastropacha
Americana</spn>, and <spn>Tolype velleda</spn>) feed upon the apple
tree.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lappet</ent><br/
<hw>Lap"pet</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lappeted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lappeting</conjf>.]</vmorph> <def>To decorate with, or as with, a
lappet.</def> <mark>[R.]</mark> <rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lappic</ent><br/
<hw>Lap"pic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Lapland, or the Lapps.</def> -- <def2><pos>n.</pos> <def>The language of
the Lapps. See <er>Lappish</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapping</ent><br/
<hw>Lap"ping</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of machine
blanket or wrapping material used by calico printers.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Lapping engine</b></col>, <col><b>Lapping
machine</b></col></mcol> <fld>(Textile Manuf.)</fld>, <cd>A machine for
forming fiber info a lap. See its <er>Lap</er>, 9.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lappish</ent><br/
<hw>Lap"pish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the Lapps; Laplandish.</def> -- <def2><pos>n.</pos> <def>The language
spoken by the Lapps in Lapland. It is related to the Finnish and
Hungarian, and is not an Aryan language.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapponic</ent><br/
<ent>Lapponian</ent><br/
<mhw>{ <hw>Lap*po"ni*an</hw> <pr>(?)</pr>, <hw>Lap*pon"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Laplandish; Lappish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapps</ent><br/
<hw>Lapps</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Lapp</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld> <def>A
branch of the Mongolian race, now living in the northern parts of
Norway, Sweden, and the adjacent parts of Russia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapsable</ent><br/
<hw>Laps"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lapsible.</def>
<rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapse</ent><br/
<hw>Lapse</hw> <pr>(l<acr/ps)</pr>, <pos>n.</pos> <ety>[L.
<ets>lapsus</ets>, fr. <ets>labi</ets>, p. p. <ets>lapsus</ets>, to
slide, to fall: cf. F. <ets>laps</ets>. See <er>Sleep</er>.]</ety>
<sn>1.</sn> <def>A gliding, slipping, or gradual falling; an unobserved
or imperceptible progress or passing away,; -- restricted usually to
immaterial things, or to figurative uses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lapse</qex> to indolence is soft and imperceptible.</q>
<rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bacon was content to wait the <qex>lapse</qex> of long centuries
for his expected revenue of fame.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slip; an error; a fault; a failing in duty; a
slight deviation from truth or rectitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To guard against those <qex>lapses</qex> and failings to which our
infirmities daily expose us.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The termination of a right or
privilege through neglect to exercise it within the limited time, or
through failure of some contingency; hence, the devolution of a right or
privilege.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Theol.)</fld> <def>A fall or apostasy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapse</ent><br/
<hw>Lapse</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lapsed</conjf> <pr>(#)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lapsing</conjf>.]</vmorph> <sn>1.</sn> <def>To pass slowly and
smoothly downward, backward, or away; to slip downward, backward, or
away; to glide; -- mostly restricted to figurative uses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A tendency to <qex>lapse</qex> into the barbarity of those
northern nations from whom we are descended.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Homer, in his characters of Vulcan and Thersites, has
<qex>lapsed</qex> into the burlesque character.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To slide or slip in moral conduct; to fail in duty;
to fall from virtue; to deviate from rectitude; to commit a fault by
inadvertence or mistake.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>lapse</qex> in fullness<br/
Is sorer than to lie for need.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>To fall or pass from
one proprietor to another, or from the original destination, by the
omission, negligence, or failure of some one, as a patron, a legatee,
etc.</def> <sd>(b)</sd> <def>To become ineffectual or void; to
fall.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the archbishop shall not fill it up within six months ensuing,
it <qex>lapses</qex> to the king.</q> <rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapse</ent><br/
<hw>Lapse</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To let slip; to permit
to devolve on another; to allow to pass.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An appeal may be deserted by the appellant's <qex>lapsing</qex>
the term of law.</q> <rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To surprise in a fault or error; hence, to surprise
or catch, as an offender.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For which, if be <qex>lapsed</qex> in this place,<br/
I shall pay dear.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapse rate</ent><br/
<hw>Lapse rate</hw>, <pos>n.</pos>
<def>The rate of decrease of air temperature with height.</def><br/
[<source>A. T. Young</source>]</p>

<p><ent>Lapsed</ent><br/
<hw>Lapsed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
slipped downward, backward, or away; having lost position, privilege,
etc., by neglect; -- restricted to figurative uses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Once more I will renew<br/
His <qex>lapsed</qex> powers, though forfeit.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ineffectual, void, or forfeited; <as>as, a
<ex>lapsed</ex> policy of insurance; a <ex>lapsed</ex>
legacy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Lapsed devise</b></col>, <col><b>Lapsed
legacy</b></col></mcol> <fld>(Law)</fld>, <cd>a devise, or legacy, which
fails to take effect in consequence of the death of the devisee, or
legatee, before that of the testator, or for other cause.</cd>
<rj><au>Wharton (Law Dict.).</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapsible</ent><br/
<hw>Laps"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Liable to
lapse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapsided</ent><br/
<hw>Lap"sid`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Lopsided</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapstone</ent><br/
<hw>Lap"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stone for the
lap, on which shoemakers beat leather.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lap-straked</ent><br/
<ent>lap-streaked</ent><br/
<ent>Lapstrake</ent><br/
<ent>Lapstreak</ent><br/
<mhw>{ <hw>Lap"streak`</hw> <pr>(?)</pr>, <hw>Lap"strake`</hw>
<pr>(?)</pr>, <hw>lap-streaked</hw>, <hw>lap-straked</hw> }</mhw>
<pos>a.</pos> <def>Made with boards whose edges lap one over another;
clinker-built; -- said of boats. Contrasted with
<contr>carvel-built</contr>.</def><br/
<syn><b>Syn. --</b> lap-jointed, overlapping.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>lap up</ent><br/
<hw>lap up</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>lap</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To take up (drink or food) with
the tongue; to drink by licking up.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>(fig.)</mark> <def>To accept or enjoy
enthusiatically and uncritically; <as>as, to <ex>lap up</ex>
praise</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laputan</ent><br/
<hw>La*pu"tan</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Laputa, an imaginary flying island described in <xex>Gulliver's
Travels</xex> as the home of chimerical philosophers.</def>
<specif>Hence,</specif> <def>fanciful; preposterous; absurd in science
or philosophy.</def> <ldquo/<xex>Laputan</xex> ideas.<rdquo/ <rj><au>G.
Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lap-welded</ent><br/
<hw>Lap"-weld`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having edges or
ends united by a lap weld; <as>as, a <ex>lap-welded</ex>
pipe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapwing</ent><br/
<hw>Lap"wing`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lapwynke</ets>, <ets>leepwynke</ets>, AS.
<ets>hle<aacute/pewince</ets>; <ets>hle<aacute/pan</ets> to leap, jump +
(prob.) a word akin to AS. <ets>wincian</ets> to wink, E.
<ets>wink</ets>, AS. <ets>wancol</ets> wavering; cf. G.
<ets>wanken</ets> to stagger, waver. See <er>Leap</er>, and
<er>Wink</er>.]</ety> <fld>(Zool.)</fld> <def>A small European bird of
the Plover family (<spn>Vanellus cristatus</spn>, or <spn>Vanellus
vanellus</spn>). It has long and broad wings, and is noted for its
rapid, irregular fight, upwards, downwards, and in circles. Its back is
coppery or greenish bronze. Its eggs are the <ldquo/plover's eggs<rdquo/
of the London market, esteemed a delicacy. It is called also
<altname>peewit</altname>, <altname>dastard plover</altname>, and
<altname>wype</altname>. The <stype>gray lapwing</stype> is the
<spn>Squatarola cinerea</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lapwork</ent><br/
<hw>Lap"work`</hw> <pr>(l<acr/p"w<ucir/rk`)</pr>, <pos>n.</pos>
<def>Work in which one part laps over another.</def>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laquay</ent><br/
<hw>Laq"uay</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lackey.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laquear</ent><br/
<hw>La"que*ar</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Laquearia</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety>
<fld>(Arch.)</fld> <def>A lacunar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laqueary</ent><br/
<hw>Laq"ue*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laqueus</ets> a noose.]</ety> <def>Using a noose, as a
gladiator.</def> <mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Retiary and <qex>laqueary</qex> combatants.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lar</ent><br/
<hw>Lar</hw> <pr>(l<aum/r)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lares</plw> <pr>(#)</pr>, sometimes <plw>Lars</plw>
<pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Rom. Myth.)</fld> <def>A
tutelary deity; a deceased ancestor regarded as a protector of the
family. The domestic Lares were the tutelar deities of a house;
household gods.</def> <specif>Hence,</specif> <mark>(Fig.)</mark>:
<def>Hearth or dwelling house.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor will she her dear <qex>Lar</qex> forget,<br/
Victorious by his benefit.</q> <rj><qau>Lovelace.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Lars</qex> and Lemures moan with midnight plaint.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Looking backward in vain toward their <qex>Lares</qex> and
lands.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lar</ent><br/
<hw>Lar</hw> <pr>(l<aum/r)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
species of gibbon (<spn>Hylobates lar</spn>), found in Burmah. Called
also <altname>white-handed gibbon</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laramie group</ent><br/
<hw>Lar"a*mie group`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Geol.)</fld>
<def>An extensive series of strata, principally developed in the Rocky
Mountain region, as in the <etsep>Laramie</etsep> Mountains, and
formerly supposed to be of the Tertiary age, but now generally regarded
as Cretaceous, or of intermediate and transitional character. It
contains beds of lignite, often valuable for coal, and is hence also
called the <altname>lignitic group</altname>. See <xex>Chart</xex> of
<er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larboard</ent><br/
<hw>Lar"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lar-</ets> is
of uncertain origin, possibly the same as <ets>lower</ets>, i. e.,
humbler in rank, because the starboard side is considered by mariners as
higher in rank; cf. D. <ets>laag</ets> low, akin to E. <ets>low</ets>.
See <er>Board</er>, <pos>n.</pos>, 8.]</ety> <fld>(Naut.)</fld> <def>The
left-hand side of a ship to one on board facing toward the bow; port; --
opposed to <ant>starboard</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Larboard</xex> is a nearly obsolete term, having
been superseded by <altname>port</altname> to avoid liability of
confusion with <xex>starboard</xex>, owing to similarity of
sound.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larboard</ent><br/
<hw>Lar"board`</hw>, <pos>a.</pos> <def>On or pertaining to the
left-hand side of a vessel; port; <as>as, the <ex>larboard</ex>
quarter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larcenist</ent><br/
<ent>Larcener</ent><br/
<mhw>{ <hw>Lar"ce*ner</hw> <pr>(?)</pr>, <hw>Lar"ce*nist</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>One who commits
larceny.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larcenous</ent><br/
<hw>Lar"ce*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OE.
<ets>larrecinos</ets>. See <er>Larceny</er>.]</ety> <def>Having the
character of larceny; <as>as, a <ex>larcenous</ex> act</as>; committing
larceny.</def> <ldquo/The <ex>larcenous</ex> and burglarious
world.<rdquo/ <au>Sydney Smith.</au> --
<wordforms><wf>Lar"ce*nous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larceny</ent><br/
<hw>Lar"ce*ny</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Larcenies</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>larcin</ets>, OE.
<ets>larrecin</ets>, L. <ets>latrocinium</ets>, fr. <ets>latro</ets>
robber, mercenary, hired servant; cf. Gr. (<?/) hired servant. Cf.
<er>Latrociny</er>.]</ety> <fld>(Law)</fld> <def>The unlawful taking and
carrying away of things personal with intent to deprive the right owner
of the same; theft. Cf. <er>Embezzlement</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Grand larceny</b></col> <and/ <col><b>Petit larceny
are</b></col></mcol> <cd>distinctions having reference to the nature or
value of the property stolen. They are abolished in England.</cd> --
<mcol><col><b>Mixed larceny</b></col>, <it>or</it> <col><b>Compound
larceny</b></col></mcol>, <cd>that which, under statute, includes in it
the aggravation of a taking from a building or the person.</cd> --
<col><b>Simple larceny</b></col>, <cd>that which is not accompanied with
any aggravating circumstances.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larch</ent><br/
<hw>Larch</hw> <pr>(l<aum/rch)</pr>, <pos>n.</pos> <ety>[Cf. OE.
<ets>larege</ets> (Cotgrave), It. <ets>larice</ets>, Sp.
<ets>larice</ets>, <ets>alerce</ets>, G. <ets>l<aum/rche</ets>; all fr.
L. <ets>larix</ets>, <ets>-icis</ets>, Gr. <grk>la`rix</grk>.]</ety>
<fld>(Bot.)</fld> <def>A genus of coniferous trees, having deciduous
leaves, in fascicles (see <xex>Illust.</xex> of
<er>Fascicle</er>).</def> <note>The European larch is <spn>Larix
Europ<ae/a</spn>. The American or black larch is <spn>Larix
Americana</spn>, the hackmatack or tamarack. The trees are generally of
a drooping, graceful appearance.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larchen</ent><br/
<hw>Larch"en</hw> <pr>(l<aum/rch"<ecr/n)</pr>, <pos>a.</pos> <def>Of or
pertaining to the larch.</def> <rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lard</ent><br/
<hw>Lard</hw> <pr>(l<aum/rd)</pr>, <pos>n.</pos> <ety>[F., bacon, pig's
fat, L. <ets>lardum</ets>, <ets>laridum</ets>; cf. Gr. (<?/) fattened,
fat.]</ety> <sn>1.</sn> <def>Bacon; the flesh of swine.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fat of swine, esp. the internal fat of the
abdomen; also, this fat melted and strained.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lard oil</b></col>, <cd>an illuminating and lubricating
oil expressed from lard.</cd> -- <col><b>Leaf lard</b></col>, <cd>the
internal fat of the hog, separated in leaves or masses from the kidneys,
etc.; also, the same melted.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lard</ent><br/
<hw>Lard</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Larded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Larding</conjf>.]</vmorph> <ety>[F. <ets>larder</ets>. See
<er>Lard</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To stuff with
bacon; to dress or enrich with lard; esp., to insert lardons of bacon or
pork in the surface of, before roasting; <as>as, to <ex>lard</ex>
poultry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>larded</qex> thighs on loaded altars laid.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fatten; to enrich.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The oak] with his nuts <qex>larded</qex> many a swine.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Falstaff sweats to death.<br/
And <qex>lards</qex> the lean earth as he walks along.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To smear with lard or fat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In his buff doublet <qex>larded</qex> o'er with fat<br/
Of slaughtered brutes.</q> <rj><qau>Somerville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To mix or garnish with something, as by way of
improvement; to interlard.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let no alien Sedley interpose<br/
To <qex>lard</qex> with wit thy hungry Epsom prose.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lard</ent><br/
<hw>Lard</hw> <pr>(l<aum/rd)</pr>, <pos>v. i.</pos> <def>To grow
fat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lardacein</ent><br/
<hw>Lar`da*ce"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lardaceous</er>.]</ety> <fld>(Physiol. Chem.)</fld> <def>A peculiar
amyloid substance, colored blue by iodine and sulphuric acid, occurring
mainly as an abnormal infiltration into the spleen, liver,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lardaceous</ent><br/
<hw>Lar*da"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lardac<eacute/</ets>.]</ety> <def>Consisting of, or resembling,
lard.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><cd>Lardaceous degeneration</cd> <fld>(Med.)</fld>, <cd>amyloid
degeneration.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larder</ent><br/
<hw>Lard"er</hw> <pr>(l<aum/rd"<etil/r)</pr>, <pos>n.</pos> <ety>[OF.
<ets>lardier</ets>. See <er>Lard</er>, <pos>n.</pos>]</ety> <def>A room
or place where meat and other articles of food are kept before they are
cooked.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larderer</ent><br/
<hw>Lard"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One in charge of
the larder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lardery</ent><br/
<hw>Lard"er*y</hw>, <pos>n.</pos> <ety>[Cf. OE.
<ets>larderie</ets>.]</ety> <def>A larder.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lardoon</ent><br/
<ent>Lardon</ent><br/
<mhw>{ <hw>Lar"don</hw> <pr>(?)</pr>, <hw>Lar*doon"</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[F. <ets>lardon</ets>, fr. <ets>lard</ets>
lard.]</ety> <def>A bit of fat pork or bacon used in larding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lardry</ent><br/
<hw>Lard"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lardery</er>.]</ety> <def>A larder.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lardy</ent><br/
<hw>Lard"y</hw> <pr>(l<aum/rd"<ycr/)</pr>, <pos>a.</pos>
<def>Containing, or resembling, lard; of the character or consistency of
lard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lare</ent><br/
<hw>Lare</hw> <pr>(l<acir/r)</pr>, <pos>n.</pos> <ety>[See
<er>Lore</er>.]</ety> <def>Lore; learning.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lare</ent><br/
<hw>Lare</hw>, <pos>n.</pos> <def>Pasture; feed. See
<er>Lair</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lare</ent><br/
<hw>Lare</hw>, <pos>v. t.</pos> <def>To feed; to fatten.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lares</ent><br/
\'d8<hw>La"res</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See 1st
<er>Lar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Large</ent><br/
<hw>Large</hw> <pr>(l<aum/rj)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Larger</adjf>
<pr>(l<aum/r"j<etil/r)</pr>; <pos>superl.</pos>
<adjf>Largest</adjf>.]</amorph> <ety>[F., fr. L. <ets>largus</ets>. Cf.
<er>Largo</er>.]</ety> <sn>1.</sn> <def>Exceeding most other things of
like kind in bulk, capacity, quantity, superficial dimensions, or number
of constituent units; big; great; capacious; extensive; -- opposed to
<ant>small</ant>; <as>as, a <ex>large</ex> horse; a <ex>large</ex> house
or room; a <ex>large</ex> lake or pool; a <ex>large</ex> jug or spoon; a
<ex>large</ex> vineyard; a <ex>large</ex> army; a <ex>large</ex>
city.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ For linear dimensions, and mere extent,
<xex>great</xex>, and not <xex>large</xex>, is used as a qualifying
word; as, <xex>great</xex> length, breadth, depth; a <xex>great</xex>
distance; a <xex>great</xex> height.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Abundant; ample; <as>as, a <ex>large</ex> supply of
provisions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have yet <qex>large</qex> day.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Full in statement; diffuse; full; profuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I might be very <qex>large</qex> upon the importance and
advantages of education.</q> <rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Having more than usual power or capacity; having
broad sympathies and generous impulses; comprehensive; -- said of the
mind and heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Free; unembarrassed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of burdens all he set the Paynims <qex>large</qex>.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Unrestrained by decorum; -- said of language.</def>
<mark>[Obs.]</mark> <ldquo/Some <xex>large</xex> jests he will
make.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Prodigal in expending; lavish.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Naut.)</fld> <def>Crossing the line of a ship's
course in a favorable direction; -- said of the wind when it is abeam,
or between the beam and the quarter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At large</b></col>. <sd>(a)</sd> <cd>Without restraint or
confinement; <as>as, to go <ex>at large</ex>; to be left <ex>at
large</ex></as>.</cd> <sd>(b)</sd> <cd>Diffusely; fully; in the full
extent; <as>as, to discourse on a subject <ex>at large</ex></as>.</cd>
-- <col><b>Common at large</b></col>. <cd>See under <er>Common</er>,
<pos>n.</pos></cd> -- <mcol><col><b>Electors at large</b></col>,
<col><b>Representative at large</b></col></mcol>, <cd>electors, or a
representative, as in Congress, chosen to represent the whole of a
State, in distinction from those chosen to represent particular
districts in a State.</cd> <mark>[U. S.]</mark> -- <mcol><col><b>To give
large</b></col>, <col><b>To go large</b></col>, <col><b>To run
large</b></col>, <it>or</it> <col><b>To sail large</b></col></mcol>
<fld>(Naut.)</fld>, <cd>to have the wind crossing the direction of a
vessel's course in such a way that the sails feel its full force, and
the vessel gains its highest speed. See <er>Large</er>, <pos>a.</pos>,
8.</cd></cs></p>

<p><syn><b>Syn.</b> -- Big; bulky; huge; capacious; comprehensive;
ample; abundant; plentiful; populous; copious; diffusive;
liberal.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Large</ent><br/
<hw>Large</hw>, <pos>adv.</pos> <def>Freely; licentiously.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Large</ent><br/
<hw>Large</hw>, <pos>n.</pos> <fld>(Mus.)</fld> <def>A musical note,
formerly in use, equal to two longs, four breves, or eight
semibreves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Large-acred</ent><br/
<hw>Large"-a`cred</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Possessing much
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Large-handed</ent><br/
<hw>Large"-hand`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having large
hands.</def> <mark>(Fig.)</mark>: <def>Taking, or giving, in large
quantities; rapacious or bountiful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Large-hearted</ent><br/
<hw>Large"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a large
or generous heart or disposition; noble; liberal.</def> --
<wordforms><wf>Large"-heart`ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largely</ent><br/
<hw>Large"ly</hw>, <pos>adv.</pos> <def>In a large manner.</def>
<rj><au>Dryden.</au> <au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largeness</ent><br/
<hw>Large"ness</hw>, <pos>n.</pos> <def>The quality or state of being
large.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>large-scale</ent><br/
<hw>large-scale</hw> <pos>adj.</pos> <sn>1.</sn> <def>large in area,
scope or degree; <as>as, a <ex>large-scale</ex> attack on AIDS is
needed</as>.</def><br/
<syn><b>Syn. --</b> extensive, wide-ranging.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>constructed or drawn to a big scale{4}; <as>as,
<ex>large-scale</ex> maps</as>. See 3rd <er>scale</er>, <pos>n.</pos>,
sense 4.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>widespread; applying to all or most members of a
category or group.</def><br/
<syn><b>Syn. --</b> mass.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Largesse</ent><br/
<ent>Largess</ent><br/
<mhw>{ <hw>Lar"gess</hw>, <hw>Lar"gesse</hw> <pr>(l<aum/r*j<ecr/s"
<it>or</it> l<aum/r"j<ecr/s)</pr>, }</mhw> <pos>n.</pos> <ety>[F.
<ets>largesse</ets>, fr. <ets>large</ets>. See <er>Large</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>Liberality; generosity;
bounty.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fulfilled of <qex>largesse</qex> and of all grace.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A present; a gift; a bounty bestowed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The heralds finished their proclamation with their usual cry of
<ldquo/<qex>Largesse</qex>, <qex>largesse</qex>, gallant knights!<rdquo/
and gold and silver pieces were showered on them from the galleries.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>largest</ent><br/
<hw>largest</hw> <pos>adj.</pos> <sn>1.</sn> <def>greatest in size of
those under consideration.</def><br/
<syn><b>Syn. --</b> biggest, greatest.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>maximal.</def><br/
<syn><b>Syn. --</b> outside.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Larget</ent><br/
<hw>Lar"get</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>larget</ets>.]</ety> <def>A short piece of bar iron for rolling
into a sheet; a small billet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larghetto</ent><br/
\'d8<hw>Lar*ghet"to</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[It.,
dim. of <ets>largo</ets> largo.]</ety> <fld>(Mus.)</fld> <def>Somewhat
slow or slowly, but not so slowly as <contr>largo</contr>, and rather
more so than <contr>andante</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largifical</ent><br/
<hw>Lar*gif"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>largificus</ets>; <ets>largus</ets> large +
<ets>facere</ets>.]</ety> <def>Generous; ample; liberal.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largifluous</ent><br/
<hw>Lar*gif"lu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>largifluus</ets>; <ets>large</ets> abundantly + <ets>fluere</ets>
to flow.]</ety> <def>Flowing copiously.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largiloquent</ent><br/
<hw>Lar*gil"o*quent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>largiloquus</ets>.]</ety> <def>Grandiloquent.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largish</ent><br/
<hw>Lar"gish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat large.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largition</ent><br/
<hw>Lar*gi"tion</hw> <pr>(?)</pr>, <ety>[L. <ets>largitio</ets>, fr.
<ets>largiri</ets>, p. p. <ets>largitus</ets>, to give
bountifully.]</ety> <def>The bestowment of a largess or gift.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Largo</ent><br/
\'d8<hw>Lar"go</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[It., large,
L. <ets>largus</ets>, See <er>Large</er>.]</ety> <fld>(Mus.)</fld>
<def>Slow or slowly; -- more so than <contr>adagio</contr>; next in
slowness to <contr>grave</contr>, which is also weighty and
solemn.</def> -- <def2><pos>n.</pos> <def>A movement or piece in
<ex>largo</ex> time.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lari</ent><br/
<hw>Lari</hw> <pos>prop. n.</pos> <def>A suborder of birds including the
gulls; terns; jaegers; and skimmers.</def><br/
<syn><b>Syn. --</b> suborder <subord>Lari</subord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lariat</ent><br/
<hw>Lar"i*at</hw> <pr>(l<acr/r"<icr/*<acr/t)</pr>, <pos>n.</pos>
<ety>[Sp. <ets>la reata</ets> the rope; <ets>la</ets> the +
<ets>reata</ets> rope. Cf. <er>Reata</er>.]</ety> <def>A long, slender
rope made of hemp or strips of hide, esp. one with a noose; -- used as a
lasso for catching cattle, horses, etc., and for picketing a horse so
that he can graze without wandering.</def> <mark>[Mexico & Western
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 831 --></p>

<p><ent>Lariat</ent><br/
<hw>Lar"i*at</hw> <pr>(l<acr/r"<icr/*<acr/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lariated</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Lariating</conjf>.]</vmorph> <def>To secure with a
lariat fastened to a stake, as a horse or mule for grazing; also, to
lasso or catch with a lariat.</def> <mark>[Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laridae</ent><br/
<hw>Laridae</hw> <pos>prop. n.</pos> <def>The natural family of birds
including the gulls and terns; the gull family.</def><br/
<syn><b>Syn. --</b> family <fam>Laridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Larine</ent><br/
<hw>La"rine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Of
or pertaining to the Gull family (<fam>Larid<ae/</fam>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larix</ent><br/
<hw>Larix</hw> <pos>prop. n.</pos> <def>The genus of trees comrising the
larches.</def><br/
<syn><b>Syn. --</b> genus <gen>Larix</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Larixinic</ent><br/
<hw>Lar`ix*in"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of, or derived from, the larch (<gen>Larix</gen>); <as>as,
<ex>larixinic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lark</ent><br/
<hw>Lark</hw> <pr>(l<aum/rk)</pr>, <pos>n.</pos> <ety>[Perh fr. AS.
<ets>l<amac/c</ets> play, sport. Cf. <er>Lake</er>, <pos>v.
i.</pos>]</ety> <def>A frolic; a jolly time.</def>
<mark>[Colloq.]</mark> <au>Dickens.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lark</ent><br/
<hw>Lark</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Larked</conjf> <pr>(l<aum/rkt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Larking</conjf>.]</vmorph> <def>To sport; to frolic.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lark</ent><br/
<hw>Lark</hw>, <pos>n.</pos> <ety>[OE. <ets>larke</ets>,
<ets>laverock</ets>, AS. <ets>l<amac/werce</ets>; akin to D.
<ets>leeuwerik</ets>, LG. <ets>lewerke</ets>, OHG.
<ets>l<emac/rahha</ets>, G. <ets>lerche</ets>, Sw. <ets>l<aum/rka</ets>,
Dan. <ets>lerke</ets>, Icel. <ets>l<ae/virki</ets>.]</ety>
<fld>(Zool.)</fld> <def>Any one numerous species of singing birds of the
genus <gen>Alauda</gen> and allied genera (family
<fam>Alaudid<ae/</fam>). They mostly belong to Europe, Asia, and
Northern Africa. In America they are represented by the shore larks, or
horned larks, of the genus <gen>Otocoris</gen>. The true larks have
holaspidean tarsi, very long hind claws, and, usually, dull, sandy brown
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The European skylark, or lark of the poets (<spn>Alauda
arvensis</spn>), is of a brown mottled color, and is noted for its clear
and sweet song, uttered as it rises and descends almost perpendicularly
in the air. It is considered a table delicacy, and immense numbers are
killed for the markets. Other well-known European species are the
crested, or tufted, lark (<spn>Alauda cristata</spn>), and the wood lark
(<spn>Alauda arborea</spn>). The pipits, or titlarks, of the genus
<gen>Anthus</gen> (family <fam>Motacillid<ae/</fam>) are often called
larks. See <er>Pipit</er>. The American meadow larks, of the genus
<gen>Sturnella</gen>, are allied to the starlings. See <er>Meadow
Lark</er>. The Australian bush lark is <spn>Mirafra Horsfieldii</spn>.
See <er>Shore lark</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lark bunting</b></col> <fld>(Zool.)</fld>, <cd>a
fringilline bird (<spn>Calamospiza melanocorys</spn>) found on the
plains of the Western United States.</cd> -- <col><b>Lark
sparrow</b></col> <fld>(Zool.)</fld>, <cd>a sparrow (<spn>Chondestes
grammacus</spn>), found in the Mississippi Valley and the Western United
States.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lark</ent><br/
<hw>Lark</hw>, <pos>v. i.</pos> <def>To catch larks; <as>as, to go
<ex>larking</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lark-colored</ent><br/
<hw>Lark"-col`ored</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
sandy brown color of the European larks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larker</ent><br/
<hw>Lark"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 3d <er>Lark</er>,
for sense 1, and 1st <er>Lark</er>, for sense 2.]</ety> <sn>1.</sn>
<def>A catcher of larks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who indulges in a lark or frolic.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lark's-heel</ent><br/
<hw>Lark's"-heel`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Indian cress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larkspur</ent><br/
<hw>Lark"spur</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus of ranunculaceous plants (<gen>Delphinium</gen>), having showy
flowers, and a spurred calyx. They are natives of the North Temperate
zone. The commonest larkspur of the gardens is <spn>Delphinium
Consolida</spn>. The flower of the bee larkspur (<spn>Delphinium
elatum</spn>) has two petals bearded with yellow hairs, and looks not
unlike a bee.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larmier</ent><br/
<hw>Lar"mi*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>larme</ets> tear, drop, L. <ets>lacrima</ets>. See
<er>Lachrymose</er>.]</ety> <fld>(Anat.)</fld> <def>See
<er>Tearpit</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laroid</ent><br/
<hw>La"roid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Larus</ets> +
<ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or belonging to the
Gull family (<fam>Larid<ae/</fam>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larrikin</ent><br/
<hw>Lar"ri*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. E. dial.
<ets>larrikin</ets> a mischievous or frolicsome youth,
<ets>larrick</ets> lively, careless, <ets>larack</ets> to frolic, to
romp.]</ety> <def>A rowdy street loafer; a rowdyish or noisy ill-bred
fellow; a hoodlum; -- variously applied, as to a street blackguard, a
street Arab, a youth given to horse-play, etc.</def> <mark>[Australia &
Eng.]</mark> -- <def2><pos>a.</pos> <def>Rowdy; rough; disorderly.</def>
<mark>[Australia & Eng.]</mark></def2></p>

<p><q>Mobs of unruly <qex>larrikins</qex>.</q> <rj><qau>Sydney Daily
Telegraph.</qau></rj></p>

<p><note><hand/ <xex>Larrikin</xex> is often popularly explained by the
following anecdote (which is without foundation): An Irish policeman at
Melbourne, on bringing a notorious rough into court, was asked by the
magistrate what the prisoner had been doing, and replied, <ldquo/He was
<xex>a-larrikin'</xex> [i. e., a-larking] about the
streets.<rdquo/</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Larrup</ent><br/
<hw>Lar"rup</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Larruped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Larruping</conjf>.]</vmorph> <ety>[Perh, a corrupt. of
<ets>lee rope</ets>, used by sailors in beating the boys; but cf. D.
<ets>larpen</ets> to thresh, <ets>larp</ets> a whip, blow.]</ety>
<def>To beat or flog soundly.</def> <mark>[Prov. Eng. & Colloq.
U.S.]</mark> <rj><au>Forby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larry</ent><br/
<hw>Lar"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Lorry</er>,
or <er>Lorrie</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larum</ent><br/
<hw>Lar"um</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Alarum</er>,
and <er>Alarm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larva</ent><br/
<ent>Larvae</ent><br/
<hw>Lar"va</hw> <pr>(l<aum/r"v<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Larv<ae/</plw> <pr>(l<aum/r"v<ae/)</pr>, E.
<plw>Larvas</plw> <pr>(l<aum/r"v<adot/z)</pr>.</plu> <ety>[L.
<ets>larva</ets> ghost, specter, mask.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Any young insect from the time that it hatches
from the egg until it becomes a pupa, or chrysalis. During this time it
usually molts several times, and may change its form or color each time.
The larv<ae/ of many insects are much like the adults in form and
habits, but have no trace of wings, the rudimentary wings appearing only
in the pupa stage. In other groups of insects the larv<ae/ are totally
unlike the parents in structure and habits, and are called
<stype>caterpillars</stype>, <stype>grubs</stype>,
<stype>maggots</stype>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The early, immature form of any
animal when more or less of a metamorphosis takes place, before the
assumption of the mature shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larvacea</ent><br/
<hw>Larvacea</hw> <pos>prop. n.</pos> <def>A class sometimes classified
as an order.</def><br/
<syn><b>Syn. --</b> class <class>Larvacea</class>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>larval</ent><br/
<hw>lar"val</hw> <pr>(l<aum/r"v<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>larvalis</ets> ghostly. See <er>Larva</er>.]</ety>
<fld>(Zool.)</fld> <def>Of or pertaining to a larva.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larvalia</ent><br/
\'d8<hw>Lar*va"li*a</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos> <ety>[NL.
See <er>Larval</er>.]</ety> <fld>(Zool.)</fld> <def>An order of
<subphylum>Tunicata</subphylum>, including <gen>Appendicularia</gen>,
and allied genera; -- so called because certain larval features are
retained by them through life. Called also <altname>Copelata</altname>.
See <er>Appendicularia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larvate</ent><br/
<hw>Lar"vate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>larva</ets>
mask.]</ety> <def>Masked; hence, concealed; obscure; -- applied in
medicine to doubtful cases of some diseases; <as>as, <ex>larvate</ex>
pneumonis; <ex>larvate</ex> epilepsy</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Larvated</ent><br/
<hw>Lar"va*ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>larvatus</ets> bewitched. See <er>Larva</er>.]</ety> <def>Masked;
clothed as with a mask.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larve</ent><br/
<hw>Larve</hw> <pr>(l<aum/rv)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Larves</plw> <pr>(l<aum/rvz)</pr>.</plu> <ety>[F.]</ety> <def>A
larva.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larviform</ent><br/
<hw>Lar"vi*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Larva</ets>
+ <ets>-form</ets>.]</ety> <fld>(Zool.)</fld> <def>Having the form or
structure of a larva.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Larviparous</ent><br/
<hw>Lar*vip"a*rous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Larva</ets> + L. <ets>parete</ets> to bring forth.]</ety>
<fld>(Zool.)</fld> <def>Depositing living larv<ae/, instead of eggs; --
said of certain insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lary</ent><br/
<hw>La"ry</hw> <pr>(l<amac/"r<ycr/)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lare</ets> sea gull, L. <ets>larus</ets> a sort of sea bird, Gr.
<grk>la`ros</grk>.]</ety> <def>A guillemot; -- called also
<altname>lavy</altname>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngeal</ent><br/
<hw>Lar`yn*ge"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Larynx</er>.]</ety> <def>Of or pertaining to the larynx; adapted to
operations on the larynx; <as>as, <ex>laryngeal</ex>
forceps</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngean</ent><br/
<hw>Lar`yn*ge"an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Laryngeal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngectomy</ent><br/
<hw>Lar`yn*gec"to*my</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Larynx</ets> + Gr. <?/ to cut out.]</ety> <fld>(Surg.)</fld>
<def>Excision of the larynx.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Laryngismus</ent><br/
\'d8<hw>Lar`yn*gis"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>laryggismo`s</grk> a croaking. See <er>Larynx</er>.]</ety>
<fld>(Med.)</fld> <def>A spasmodic state of the glottis, giving rise to
contraction or closure of the opening.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngitis</ent><br/
\'d8<hw>Lar`yn*gi"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Larynx</er>, and <er>-tis</er>.]</ety> <fld>(Med.)</fld>
<def>Inflammation of the larynx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngograph</ent><br/
<hw>La*ryn"go*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>larynx</ets> + <ets>-graph</ets>.]</ety> <def>An instrument
for recording the larynx movements in speech.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Laryngological</ent><br/
<hw>La*ryn`go*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to laryngology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngologist</ent><br/
<hw>Lar`yn*gol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
applies himself to laryngology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngology</ent><br/
<hw>Lar`yn*gol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Larynx</ets> + <ets>-logy</ets>.]</ety> <def>Systematized
knowledge of the action and functions of the larynx; in pathology, the
department which treats of the diseases of the larynx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngophony</ent><br/
<hw>Lar`yn*goph"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Larynx</ets> + Gr. (<?/) voice.]</ety> <def>The sound of the
voice as heard through a stethoscope when the latter is placed upon the
larynx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngoscope</ent><br/
<hw>La*ryn"go*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Larynx</ets> + <ets>-scope</ets>.]</ety> <sn>1.</sn>
<fld>(Surg.)</fld> <def>An instrument, consisting of an arrangement of
two mirrors, for reflecting light upon the larynx, and for examining its
image.</def> <mark>[Archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A type of endoscope having a light
source and lenses, permitting theviewing of a magnified image of the
larynx. It may be flexible or rigid.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laryngoscopic</ent><br/
<hw>La*ryn`go*scop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the inspection of the larynx; of or pertaining to the
laryngoscope or laryngoscopy.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Laryngoscopist</ent><br/
<hw>Lar`yn*gos"co*pist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled
in laryngoscopy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngoscopy</ent><br/
<hw>Lar`yn*gos"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
using the laryngoscope; investigations made with the
laryngoscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngotome</ent><br/
<hw>La*ryn"go*tome</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Surg.)</fld>
<def>An instrument for performing laryngotomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngotomy</ent><br/
<hw>Lar`yn*got"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. (<?/);
(<?/), (<?/), the larynx + <grk>te`mnein</grk> to cut: cf. F.
<ets>laryngotomie</ets>.]</ety> <fld>(Surg.)</fld> <def>The operation of
cutting into the larynx, from the outside of the neck, for assisting
respiration when obstructed, or for removing foreign bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laryngotracheal</ent><br/
<hw>La*ryn`go*tra"che*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Larynx</ets> + <ets>tracheal</ets>.]</ety> <fld>(Anat.)</fld>
<def>Pertaining to both larynx and trachea; <as>as, the
<ex>laryngotracheal</ex> cartilage in the frog</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>laryngotracheotomy</ent><br/
<hw>la*ryn`go*tra`che*ot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Larynx</ets> + <ets>tracheotomy</ets>.]</ety>
<fld>(Surg.)</fld> <def>The operation of cutting into the larynx and the
upper part of the trachea, -- a frequent operation for obstruction to
breathing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>larynx</ent><br/
<hw>lar"ynx</hw> <pr>(l<acr/r"<icr/<nsm/ks; 277)</pr>, <pos>n.</pos>
<ety>[NL. from Gr. <grk>la`rygx</grk>, <grk>la`ryggos</grk>.]</ety>
<fld>(Anat.)</fld> <def>The expanded upper end of the windpipe or
trachea, connected with the hyoid bone or cartilage. It contains the
vocal cords, which produce the voice by their vibrations, when they are
stretched and a current of air passes between them. The larynx is
connected with the pharynx by an opening, the glottis, which, in
mammals, is protected by a lidlike epiglottis.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the framework of the human larynx, the thyroid
cartilage, attached to the hyoid bone, makes the protuberance on the
front of the neck known as <xex>Adam's apple</xex>, and is articulated
below to the ringlike cricoid cartilage. This is narrow in front and
high behind, where, within the thyroid, it is surmounted by the two
arytenoid cartilages, from which the vocal cords pass forward to be
attached together to the front of the thyroid. See
<er>Syrinx</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Las</ent><br/
<hw>Las</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lace. See
<er>Lace</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Las</ent><br/
<hw>Las</hw>, <pos>a. & adv.</pos> <def>Less.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lasagne</ent><br/
<ent>lasagna</ent><br/
<mhw><hw>lasagna</hw>, <hw>lasagne</hw></mhw>
<pr>(l<adot/*z<adot/n"y<ucr/)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
baked dish of layers of lasagna{2} pasta with sauce and cheese and meat
or vegetables; -- a popular dish of Italian cuisine.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>large flat rectangular strips of pasta.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lascar</ent><br/
<hw>Las"car</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Per. & Hind.
<ets>lashkar</ets> an army, an inferior artillery man, a cooly, a native
sailor.]</ety> <def>A native sailor, employed in European vessels; also,
a menial employed about arsenals, camps, camps, etc.; a camp
follower.</def> <mark>[East Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lascious</ent><br/
<hw>Las"ci*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Loose;
lascivious.</def> <mark>[Obs.]</mark> <ldquo/To depaint
<xex>lascious</xex> wantonness.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lasciviency</ent><br/
<hw>las*civ"i*en*cy</hw> <pr>(l<acr/s*s<icr/v"<icr/*<eit/n*s<ycr/)</pr>,
<pos>n.</pos> <ety>[See <er>Lascivient</er>.]</ety> <def>Lasciviousness;
wantonness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lascivient</ent><br/
<hw>Las*civ"i*ent</hw> <pr>(l<acr/s*s<icr/v"<icr/*<eit/nt)</pr>,
<pos>a.</pos> <ety>[L. <ets>lasciviens</ets>, pr. of
<ets>lascivire</ets> to be wanton, fr. <ets>lascivus</ets>. See
<er>Lascivious</er>.]</ety> <def>Lascivious.</def> <mark>[Obs.]</mark>
<rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lascivious</ent><br/
<hw>Las*civ"i*ous</hw> <pr>(l<acr/s*s<icr/v"<icr/*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>lascivia</ets> wantonness, fr.
<ets>lascivus</ets> wanton; cf. Gr. <grk>la`stauros</grk> lecherous,
<grk>lh^n</grk> to wish, Skr. <ets>lash</ets> to desire.]</ety>
<sn>1.</sn> <def>Wanton; lewd; lustful; <as>as, <ex>lascivious</ex> men;
<ex>lascivious</ex> desires.</as></def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tending to produce voluptuous or lewd
emotions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He capers nimbly in a lady's chamber<br/
To the <qex>lascivious</qex> pleasing of a lute.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <wordforms><wf>Las*civ"i*ous*ly</wf>, <pos>adv.</pos> --
<wf>Las*civ"i*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lasciviousness</ent><br/
<hw>las*civ"i*ous*ness</hw> <pos>n.</pos> <def>The state or habitual
condition of feeling an excessive or morbid sexual desire.</def><br/
<syn><b>Syn. --</b> prurience, pruriency, carnality.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lase</ent><br/
<hw>lase</hw> <pr>(l<amac/z)</pr> <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>lased</conjf> <pr>(l<amac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>lasing</conjf>.]</vmorph> <ety>[by back-formation from
<er>laser</er>. See <er>laser</er>.]</ety> <def>To give off a beam of
coherent light; -- of a laser.</def><br/
[<source>PJC</source>]</p>

<p><ent>laser</ent><br/
<hw>laser</hw> <pos>n.</pos> <ety>[acronym from <ets>L</ets>ight
<ets>A</ets>mplification by <ets>S</ets>timulated <ets>E</ets>mission of
<ets>R</ets>adiation: ca. <fu>1955</fu>.]</ety> <def>A device which
produces an intense, usually narrow, monochromatic beam of coherent
light; called also <altname>optical maser</altname>. It has various
forms, and is used in various applications in science and technology.
The beam is produced by boosting the majority of the electrons in
specific radiation-absorbing atoms in a medium into a higher energy
level, from which they are stimulated by their own emitted radiation to
drop back synchronously to their lower energy level, and emit light
which is in phase (coherent).</def><br/
<syn><b>Syn. --</b> optical maser.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>laser beam</ent><br/
<hw>laser beam</hw> <pos>n.</pos> <def>A beam of light from a
laser.</def><br/
[<source>PJC</source>]</p>

<p><ent>laser disk</ent><br/
<hw>laser disk</hw> <pos>n.</pos> <def>A digital data storage medium
consisting of a thin disk onto which the data is impressed by a laser,
in the form of a linear sequence of dots; same as <altname>optical
disk</altname>. The data is subsequently read back by the use of a laser
beam. See also <stype>compact disk</stype>.</def> <note>The original
disk may be created by use of a laser, but copies of the original disk
may be created by a replicating process which does not itself require a
laser.</note><br/
[<source>PJC</source>]</p>

<p><ent>laser light</ent><br/
<hw>laser light</hw> <pos>n.</pos> <def>Light produced by a
laser.</def><br/
[<source>PJC</source>]</p>

<p><ent>laser printer</ent><br/
<hw>laser printer</hw> <pos>n.</pos> <def>A printer controlled by a
computer, using a laser beam to produce images in a fine dot-matrix
pattern of charge on an electrostatic drum, to which fine particles of
ink are subsequently caused to adhere, and the image of which is
subsequently transferred to paper or another type of material in sheet
form. It is capable of high-speed production of images with a higher
resolution than those from dot-matrix impact printers.</def><br/
[<source>PJC</source>]</p>

<p><ent>laser surgery</ent><br/
<hw>laser surgery</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>Surgery
using lasers.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laserwort</ent><br/
<hw>La"ser*wort`</hw> <pr>(l<amac/"s<etil/r*w<ucir/rt`)</pr>,
<pos>n.</pos> <ety>[L. <ets>laser</ets> the juice of the
laserwort.]</ety> <fld>(Bot.)</fld> <def>Any plant of the umbelliferous
genus <gen>Laserpitium</gen>, of several species (as <spn>Laserpitium
glabrum</spn>, and <spn>Laserpitium siler</spn>), the root of which
yields a resinous substance of a bitter taste. The genus is mostly
European.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lash</ent><br/
<hw>Lash</hw> <pr>(l<acr/sh)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lasche</ets>; cf. D. <ets>lasch</ets> piece set in, joint, seam, G.
<ets>lashe</ets> latchet, a bit of leather, gusset, stripe,
<ets>laschen</ets> to furnish with flaps, to lash or slap, Icel.
<ets>laski</ets> gusset, flap, <ets>laska</ets> to break.]</ety>
<sn>1.</sn> <def>The thong or braided cord of a whip, with which the
blow is given.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I observed that your whip wanted a <qex>lash</qex> to it.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A leash in which an animal is caught or held; hence,
a snare.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A stroke with a whip, or anything pliant and tough;
<as>as, the culprit received thirty-nine <ex>lashes</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A stroke of satire or sarcasm; an expression or
retort that cuts or gives pain; a cut.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The moral is a <qex>lash</qex> at the vanity of arrogating that to
ourselves which succeeds well.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A hair growing from the edge of the eyelid; an
eyelash.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>In carpet weaving, a group of strings for lifting
simultaneously certain yarns, to form the figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lash</ent><br/
<hw>Lash</hw> <pr>(l<acr/sh)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lashed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lashng</conjf>.]</vmorph> <sn>1.</sn> <def>To strike
with a lash; to whip or scourge with a lash, or with something like
one.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>lash</qex> the pupil, and defraud the ward.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strike forcibly and quickly, as with a lash; to
beat, or beat upon, with a motion like that of a lash; <as>as, a whale
<ex>lashes</ex> the sea with his tail</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And big waves <qex>lash</qex> the frighted shores.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw out with a jerk or quickly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He falls, and <qex>lashing</qex> up his heels, his rider
throws.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To scold; to berate; to satirize; to censure with
severity; <as>as, to <ex>lash</ex> vice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lash</ent><br/
<hw>Lash</hw>, <pos>v. i.</pos> <def>To ply the whip; to strike; to
utter censure or sarcastic language.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To laugh at follies, or to <qex>lash</qex> at vice.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lash out</b></col>, <cd>to strike out wildly or
furiously; also used figuratively.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lash</ent><br/
<hw>Lash</hw>, <pos>v. t.</pos> <ety>[Cf. D. <ets>lasschen</ets> to
fasten together, <ets>lasch</ets> piece, joint, Sw. <ets>laska</ets> to
stitch, Dan. <ets>laske</ets> stitch. See <er>Lash</er>, <pos>n.</pos>
]</ety> <def>To bind with a rope, cord, thong, or chain, so as to
fasten; <as>as, to <ex>lash</ex> something to a spar; to <ex>lash</ex> a
pack on a horse's back.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasher</ent><br/
<hw>Lash"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who whips or
lashes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasher</ent><br/
<hw>Lash"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>A piece of rope for
binding or making fast one thing to another; -- called also
<altname>lashing</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A weir in a river.</def> <mark>[Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lashing</ent><br/
<hw>Lash"ing</hw>, <pos>n.</pos> <def>The act of one who, or that which,
lashes; castigation; chastisement.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lashing out</b></col>, <cd>a striking out; also,
extravagance.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lashing</ent><br/
<hw>Lash"ing</hw>, <pos>n.</pos> <def>See 2d <er>Lasher</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lasiocampid</ent><br/
<hw>lasiocampid</hw> <pos>n.</pos> <def>A member of the
<fam>Lasiocampidae</fam>, a family of medium-sized stout-bodied
neutral-colored moth with comblike antennae.</def><br/
<syn><b>Syn. --</b> lasiocampid moth.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lasiocampidae</ent><br/
<hw>Lasiocampidae</hw> <pos>n.</pos> <def>A natural family of moths
whose larvae include the tent caterpillars; the eggars; the lappet
moths.</def><br/
<syn><b>Syn. --</b> family <fam>Lasiocampidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lask</ent><br/
<hw>Lask</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A diarrhea or flux.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasket</ent><br/
<hw>Las"ket</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Lash</er>,
<er>Latching</er>.]</ety> <fld>(Naut.)</fld> <def>latching.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lass</ent><br/
<hw>Lass</hw> <pr>(l<adot/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lasse</ets>; prob. of Celtic origin; cf. W. <ets>llodes</ets> girl,
fem. of <ets>llawd</ets> lad. <root/123. See <er>Lad</er> a
youth.]</ety> <def>A young woman; a girl; a sweetheart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasse</ent><br/
<hw>Lasse</hw> <pr>(l<acr/s)</pr>, <pos>a. & adv.</pos> <def>Less.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lassie</ent><br/
<hw>Las"sie</hw> <pr>(l<acr/s"s<icr/)</pr>, <pos>n.</pos> <def>A young
girl; a lass.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lassitude</ent><br/
<hw>Las"si*tude</hw> <pr>(l<acr/s"s<icr/*t<umac/d)</pr>, <pos>n.</pos>
<ety>[L. <ets>lassitudo</ets>, fr. <ets>lassus</ets> faint, weary; akin
to E. <ets>late</ets>: cf. F. <ets>lassitude</ets>. See
<er>Late</er>.]</ety> <def>A condition of the body, or mind, when its
voluntary functions are performed with difficulty, and only by a strong
exertion of the will; languor; debility; weariness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The corporeal instruments of action being strained to a high pitch
. . . will soon feel a <qex>lassitude</qex>.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasslorn</ent><br/
<hw>Lass"lorn`</hw> <pr>(l<adot/s"l<ocir/rn`)</pr>, <pos>a.</pos>
<def>Forsaken by a lass.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasso</ent><br/
<hw>Lass"o</hw> <pr>(l<acr/s"s<osl/)</pr> <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lassos</plw> <pr>(-s<omac/z)</pr>.</plu>
<ety>[Sp. <ets>lazo</ets>, L. <ets>laqueus</ets>. See
<er>Lace</er>.]</ety> <def>A rope or long thong of leather with a
running noose, used for catching horses, cattle, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lasso cell</b></col> <fld>(Zool.)</fld>, <cd>one of a
peculiar kind of defensive and offensive stinging cells, found in great
numbers in all c<oe/lenterates, and in a few animals of other groups.
They are most highly developed in the tentacles of jellyfishes,
hydroids, and Actini<ae/. Each of these cells is filled with, fluid, and
contains a long, slender, often barbed, hollow thread coiled up within
it. When the cell contracts the thread is quickly ejected, being at the
same time turned inside out. The thread is able to penetrate the flesh
of various small, soft-bodied animals, and carries a subtle poison by
which they are speedily paralyzed and killed. The threads, at the same
time, hold the prey in position, attached to the tentacles. Some of the
jellyfishes, as the Portuguese man-of-war, and <gen>Cyanea</gen>, are
able to penetrate the human skin, and inflict painful stings in the same
way. Called also <altname>nettling cell</altname>,
<altname>cnida</altname>, <altname>cnidocell</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasso</ent><br/
<hw>Las"so</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lassoed</conjf> <pr>(l<acr/s"s<osl/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lassoing</conjf>.]</vmorph> <def>To catch with a
lasso.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw> <pr>(l<adot/st)</pr>, <pos>3d pers. sing. pres.</pos>
<def>of <er>Last</er>, to endure, contracted from
<sig>lasteth</sig>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw> <pr>(l<adot/st)</pr>, <pos>a.</pos> <ety>[OE.
<ets>last</ets>, <ets>latst</ets>, contr. of <ets>latest</ets>, superl.
of <ets>late</ets>; akin to OS. <ets>lezt</ets>, <ets>lazt</ets>,
<ets>last</ets>, D. <ets>laatst</ets>, G. <ets>letzt.</ets> See
<er>Late</er>, and cf. <er>Latest</er>.]</ety> <sn>1.</sn> <def>Being
after all the others, similarly classed or considered, in time, place,
or order of succession; following all the rest; final; hindmost;
farthest; <as>as, the <ex>last</ex> year of a century; the <ex>last</ex>
man in a line of soldiers; the <ex>last</ex> page in a book; his last
chance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Also day by day, from the first day unto the <qex>last</qex> day,
he read in the book of the law of God.</q> <rj><qau>Neh. viii.
18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fairest of stars, <qex>last</qex> in the train of night.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Next before the present; <as>as, I saw him
<ex>last</ex> week</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Supreme; highest in degree; utmost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Contending for principles of the <qex>last</qex> importance.</q>
<rj><qau>R. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Lowest in rank or degree; <as>as, the a
<ex>last</ex> place finish</as>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Farthest of all from a given quality, character, or
condition; most unlikely; having least fitness; <as>as, he is the
<ex>last</ex> person to be accused of theft</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 832 --></p>

<p><cs><col><b>At last</b></col>, <cd>at the end of a certain period;
after delay.</cd> <ldquo/The duke of Savoy felt that the time had
<xex>at last</xex> arrived.<rdquo/ <au>Motley.</au> -- <col><b>At the
last</b></col>. <ety>[Prob. fr. AS. <ets>on l<amac/ste</ets> behind,
following behind, fr. <ets>l<amac/st</ets> race, track, footstep. See
<er>Last</er> mold of the foot.]</ety> <cd>At the end; in the
conclusion.</cd> <mark>[Obs.]</mark> <ldquo/Gad, a troop shall overcome
him; but he shall overcome <xex>at the last</xex>.<rdquo/ <au>Gen. xlix.
19.</au> -- <col><b>Last heir</b></col>, <cd>the person to whom lands
escheat for lack of an heir.</cd> <mark>[Eng.]</mark> <au>Abbott.</au>
-- <col><b>On one's last legs</b></col>, <cd>at, or near, the end of
one's resources; hence, on the verge of failure or ruin, especially in a
financial sense.</cd> <mark>[Colloq.]</mark> -- <col><b>To breathe one's
last</b></col>, <cd>to die.</cd> -- <col><b>To the last</b></col>,
<cd>to the end; till the conclusion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>And blunder on in business <qex>to the last</qex>.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>At Last</er>, <er>At Length</er>.</syn>
<usage> These phrases both denote that some delayed end or result has
been reached. <xex>At length</xex> implies that a long period was spent
in so doing; as, after a voyage of more than three months, we <xex>at
Length</xex> arrived safe. <xex>At last</xex> commonly implies that
something has occurred (as interruptions, disappointments, etc.) which
leads us to emphasize the idea of having reached the end; as, in spite
of every obstacle, we have <xex>at last</xex> arrived.</usage><--
"eventually" also suggests a (relatively) long interval, but does not
specifically imply any interruptions --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw> <pr>(l<adot/st)</pr>, <pos>adv.</pos> <ety>[See
<er>Last</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>At a time or on an
occasion which is the latest of all those spoken of or which have
occurred; the last time; <as>as, I saw him <ex>last</ex> in New
York</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In conclusion; finally; lastly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pleased with his idol, he commends, admires,<br/
Adores; and, <qex>last</qex>, the thing adored desires.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>At a time next preceding the present time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How long is't now since <qex>last</qex> yourself and I<br/
Were in a mask ?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lasting</conjf>.]</vmorph> <ety>[OE. <ets>lasten</ets>, As.
<ets>l<ae/stan</ets> to perform, execute, follow, last, continue, fr.
<ets>l<amac/st</ets>, <ets>l<aemac/st</ets>, trace, footstep, course;
akin to G. <ets>leisten</ets> to perform, Goth. <ets>laistjan</ets> to
follow. See <er>Last</er> mold of the foot.]</ety> <sn>1.</sn> <def>To
continue in time; to endure; to remain in existence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[I] proffered me to be slave in all that she me would ordain while
my life <qex>lasted</qex>.</q> <rj><qau>Testament of
Love.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To endure use, or continue in existence, without
impairment or exhaustion; <as>as, this cloth <ex>lasts</ex> better than
that; the fuel will <ex>last</ex> through the winter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw>, <pos>n.</pos> <ety>[AS. <ets>l<amac/st</ets> trace,
track, footstep; akin to D. <ets>leest</ets> a last, G.
<ets>leisten</ets>, Sw. <ets>l<aum/st</ets>, Dan. <ets>l<ae/st</ets>,
Icel. <ets>leistr</ets> the foot below the ankle, Goth.
<ets>laists</ets> track, way; from a root signifying, to go. Cf.
<er>Last</er>, <pos>v. i.</pos>, <er>Learn</er>,
<er>Delirium</er>.]</ety> <def>A wooden block shaped like the human
foot, on which boots and shoes are formed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cobbler is not to go beyond his <qex>last</qex>.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Darning last</b></col>, <cd>a smooth, hard body, often
egg-shaped, put into a stocking to preserve its shape in
darning.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw>, <pos>v. t.</pos> <def>To shape with a last; to fasten or
fit to a last; to place smoothly on a last; <as>as, to <ex>last</ex> a
boot</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Last</ent><br/
<hw>Last</hw>, <pos>n.</pos> <ety>[As. <ets>hl<ae/st</ets>, fr.
<ets>hladan</ets> to lade; akin to OHG. <ets>hlast</ets>, G., D., Dan.,
& Sw. <ets>last</ets>: cf. F. <ets>laste</ets>, <ets>last</ets>, a last,
of German or Dutch origin. See <er>Lade</er>.]</ety> <sn>1.</sn> <def>A
load; a heavy burden; hence, a certain weight or measure, generally
estimated at 4,000 lbs., but varying for different articles and in
different countries. In England, a <ex>last</ex> of codfish, white
herrings, meal, or ashes, is twelve barrels; a <ex>last</ex> of corn,
ten quarters, or eighty bushels, in some parts of England, twenty-one
quarters; of gunpowder, twenty-four barrels, each containing 100 lbs; of
red herrings, twenty cades, or 20,000; of hides, twelve dozen; of
leather, twenty dickers; of pitch and tar, fourteen barrels; of wool,
twelve sacks; of flax or feathers, 1,700 lbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The burden of a ship; a cargo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lastage</ent><br/
<hw>Last"age</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[E. <ets>lestage</ets>
ballasting, fr. <ets>lest</ets> ballast, or LL. <ets>lastagium</ets>,
<ets>lestagium</ets>. See <er>Last</er> a load.]</ety> <sn>1.</sn>
<def>A duty exacted, in some fairs or markets, for the right to carry
things where one will.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tax on wares sold by the last.</def>
<mark>[Obs.]</mark> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The lading of a ship; also, ballast.</def>
<rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Room for stowing goods, as in a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laste</ent><br/
<hw>Last"e</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Last</er>, to endure.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laster</ent><br/
<hw>Last"er</hw>, <pos>n.</pos> <def>A workman whose business it is to
shape boots or shoes, or place leather smoothly, on lasts; a tool for
stretching leather on a last.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lastery</ent><br/
<hw>Last"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A red color.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasthenia</ent><br/
<hw>Lasthenia</hw> <pos>prop. n.</pos> <def>A small genus of herbs of
the Pacific coast of North and South America.</def><br/
<syn><b>Syn. --</b> genus <gen>Lasthenia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lasting</ent><br/
<hw>Last"ing</hw>, <pos>a.</pos> <def>Existing or continuing a long
while; enduring; <as>as, a <ex>lasting</ex> good or evil; a
<ex>lasting</ex> color.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Durable; permanent; undecaying; perpetual;
unending.</syn> <usage> -- <er>Lasting</er>, <er>Permanent</er>,
<er>Durable</er>. <xex>Lasting</xex> commonly means merely continuing in
existence; <xex>permanent</xex> carries the idea of continuing in the
same state, position, or course; <xex>durable</xex> means lasting in
spite of agencies which tend to destroy.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lasting</ent><br/
<hw>Last"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>Continuance;
endurance.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A species of very durable woolen stuff, used for
women's shoes; everlasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act or process of shaping on a last.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lastingly</ent><br/
<hw>Last"ing*ly</hw>, <pos>adv.</pos> <def>In a lasting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lastingness</ent><br/
<hw>lastingness</hw> <pos>n.</pos> <def>permanence by virtue of the
power to resist stress or force.</def><br/
<syn><b>Syn. --</b> durability, enduringness, strength.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lastly</ent><br/
<hw>Last"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In the last place; in
conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>at last; finally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lastreopsis</ent><br/
<hw>Lastreopsis</hw> <pos>prop. n.</pos> <def>A genus of tropical
terrestrial shield ferns.</def><br/
<syn><b>Syn. --</b> genus <gen>Lastreopsis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lat</ent><br/
<hw>Lat</hw> <pr>(l<acr/t)</pr>, <pos>v. t.</pos> <def>To let; to
allow.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latah</ent><br/
<ent>Lata</ent><br/
<mhw>{ <hw>La"ta</hw>, <hw>La"tah</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Malay.]</ety> <def>A convulsive tic or hysteric
neurosis prevalent among Malays, similar to or identical with miryachit
and jumping disease, the person affected performing various involuntary
actions and making rapid inarticulate ejaculations in imitation of the
actions and words of another person.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Latakia</ent><br/
<hw>Lat`a*ki"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk.]</ety>
<def>A superior quality of Turkish smoking tobacco, so called from the
place where produced, the ancient Laodicea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latch</ent><br/
<hw>Latch</hw> <pr>(l<acr/ch)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>l<eacute/cher</ets> to lick (of German origin). Cf.
<er>Lick</er>.]</ety> <def>To smear; to anoint.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latch</ent><br/
<hw>Latch</hw>, <pos>n.</pos> <ety>[OE. <ets>lacche</ets>, fr.
<ets>lacchen</ets> to seize, As. <ets>l<ae/ccan</ets>.]</ety>
<sn>1.</sn> <def>That which fastens or holds; a lace; a snare.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A movable piece which holds anything in place by
entering a notch or cavity; specifically, the catch which holds a door
or gate when closed, though it be not bolted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A latching.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A crossbow.</def> <mark>[Obs.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latch</ent><br/
<hw>Latch</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Latched</conjf> <pr>(l<acr/cht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Latching</conjf>.]</vmorph> <ety>[OE. <ets>lacchen</ets>. See
<er>Latch</er>. <pos>n.</pos>]</ety> <sn>1.</sn> <def>To catch so as to
hold.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those that remained threw darts at our men, and
<qex>latching</qex> our darts, sent them again at us.</q>
<rj><qau>Golding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To catch or fasten by means of a latch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The door was only <qex>latched</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>latched</ent><br/
<hw>latched</hw> <pos>adj.</pos> <def>secured by means of a latch
against opening.</def><br/
<syn><b>Syn. --</b> fastened.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Latchet</ent><br/
<hw>Latch"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lachet</ets>, from an OF. dialect form of F. <ets>lacet</ets>
plaited string, lace dim. of <ets>lacs</ets>. See <er>Lace</er>.]</ety>
<def>The string that fastens a shoe; a shoestring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latching</ent><br/
<hw>Latch"ing</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A loop or eye
formed on the head rope of a bonnet, by which it is attached to the foot
of a sail; -- called also <altname>latch</altname> and
<altname>lasket</altname>.</def> <mark>[Usually in pl.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latchkey</ent><br/
<hw>Latch"key`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A key used to
raise, or throw back, the latch of a door, esp. a night latch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>latchkey child</ent><br/
<hw>latch"key` child</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A child who
frequently spends part of the day at home without adult supervision,
especially a school child who returns home before the parent(s) return
from work. Called also <altname>door-key child</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Latchstring</ent><br/
<hw>Latch"string`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A string for
raising the latch of a door by a person outside. It is fastened to the
latch and passed through a hole above it in the door.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To find the latchstring out</b></col>, <cd>to meet with
hospitality; to be welcome. (Intrusion is prevented by drawing in the
latchstring.)</cd> <mark>[Colloq. U.S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Late</ent><br/
<hw>Late</hw> <pr>(l<amac/t)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Later</adjf>
<pr>(l<amac/t"<etil/r)</pr>, or <adjf>latter</adjf>
<pr>(l<acr/t"t<etil/r)</pr>; <pos>superl.</pos> <adjf>Latest</adjf>
<pr>(l<amac/t"<ecr/st)</pr> or <adjf>Last</adjf>
<pr>(l<adot/st)</pr>.]</amorph> <ety>[OE. <ets>lat</ets> slow, slack,
AS. <ets>l<ae/t</ets>; akin to OS. <ets>lat</ets>, D. <ets>laat</ets>
late, G. <ets>lass</ets> weary, lazy, slack, Icel. <ets>latr</ets>, Sw.
<ets>lat</ets>, Dan. <ets>lad</ets>, Goth. <ets>lats</ets>, and to E.
<ets>let</ets>, <pos>v.</pos> See <er>Let</er> to permit, and cf.
<er>Alas</er>, <er>Lassitude</er>.]</ety> <sn>1.</sn> <def>Coming after
the time when due, or after the usual or proper time; not early; slow;
tardy; long delayed; <as>as, a <ex>late</ex> spring</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Far advanced toward the end or close; <as>as, a
<ex>late</ex> hour of the day; a <ex>late</ex> period of
life.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Existing or holding some position not long ago, but
not now; recently deceased, departed, or gone out of office; <as>as, the
<ex>late</ex> bishop of London; the <ex>late</ex>
administration.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not long past; happening not long ago; recent;
<as>as, the <ex>late</ex> rains; we have received <ex>late</ex>
intelligence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Continuing or doing until an advanced hour of the
night; <as>as, <ex>late</ex> revels; a <ex>late</ex>
watcher.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Late</ent><br/
<hw>Late</hw>, <pos>adv.</pos> <ety>[AS. <ets>late</ets>. See
<er>Late</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>After the usual or
proper time, or the time appointed; after delay; <as>as, he arrived
<ex>late</ex></as>; -- opposed to <ant>early</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not long ago; lately.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Far in the night, day, week, or other particular
period; <as>as, to lie abed <ex>late</ex>; to sit up <ex>late</ex> at
night.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Of late</b></col>, <cd>in time not long past, or near the
present; lately; <as>as, the practice is <ex>of late</ex>
uncommon</as>.</cd> -- <col><b>Too late</b></col>, <cd>after the proper
or available time; when the time or opportunity is past.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>latecomer</ent><br/
<hw>latecomer</hw> <pos>n.</pos> <def>someone who arrives
late.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lated</ent><br/
<hw>Lat"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belated; too
late.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lateen</ent><br/
<hw>la*teen"</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>Of or pertaining to a peculiar rig used in the
Mediterranean and adjacent waters, esp. on the northern coast of Africa;
pertaining to a lateen sail. See below.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>rigged with a triangular (lateen sail).</def><br/
<syn><b>Syn. --</b> lateen-rigged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lateen sail</ent><br/
<hw>lateen sail</hw> <pos>n.</pos> <ety>[F. voile <ets>latine</ets> a
sail in the shape of a right-angled triangle; cf. It. & Sp. vela
<ets>latina</ets>; properly <ets>Latin</ets> sail. See
<er>Latin</er>.]</ety> <fld>(Naut.)</fld> <def>A triangular sail,
extended by a long yard, which is slung at about one fourth of its
length from the lower end, to a low mast, this end being brought down at
the tack, while the other end is elevated at an angle or about
forty-five degrees; -- used in small boats, feluccas, xebecs, etc.,
especially in the Mediterranean and adjacent waters. Some lateen sails
have also a boom on the lower side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lateen-rig</ent><br/
<hw>lateen-rig</hw> <pos>n.</pos> <def>the rig on a sailing vessel with
a lateen sail.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lateen-rigged</ent><br/
<hw>lateen-rigged</hw> <pos>adj.</pos> <def>rigged with a triangular
(lateen sail).</def><br/
<syn><b>Syn. --</b> lateen.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lately</ent><br/
<hw>Late"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Not long ago;
recently; <as>as, he has <ex>lately</ex> arrived from
Italy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latence</ent><br/
<hw>La"tence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Latency.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latency</ent><br/
<hw>La"ten*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Latent</er>.]</ety> <sn>1.</sn> <def>The state or quality of being
latent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To simplify the discussion, I shall distinguish three degrees of
this <qex>latency</qex>.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The time between a stimulus the appearance of the
response; the time between any causal action and the first appearance of
the effect. Called also <altname>latent period</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <fld>(Med.)</fld> <def>The time
between exposure to a carcinogen or other disease-causing agent and the
appearance of the consequent disease.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lateness</ent><br/
<hw>Late"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state,
condition, or quality, of being late; <as>as, the <ex>lateness</ex> of
his arrival; the <ex>lateness</ex> of the hour; the <ex>lateness</ex> of
the season.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latent</ent><br/
<hw>La"tent</hw> <pr>(l<amac/"t<eit/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>latens</ets>, <ets>-entis</ets>, p. pr. of <ets>latere</ets> to lie
hid or concealed; cf. Gr. <grk>lanqa`nein</grk>, E. <ets>lethargy</ets>:
cf. F. <ets>latent</ets>.]</ety> <sn>1.</sn> <def>Not visible or
apparent; hidden; concealed; secret; dormant; <as>as, <ex>latent</ex>
springs of action</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The evils <qex>latent</qex> in the most promising contrivances are
provided for as they arise.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Existing but not presenting
symptoms; dormant or developing; -- of disease, especially infectious
diseases; <as>as, the <ex>latent</ex> phase of an
infection</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Latent buds</b></col> <fld>(Bot.)</fld>, <cd>buds which
remain undeveloped or dormant for a long time, but may eventually
grow.</cd> <col><b>Latent heat</b></col> <fld>(Physics)</fld>, <cd>that
quantity of heat which disappears or becomes concealed in a body while
producing some change in it other than rise of temperature, as fusion,
evaporation, or expansion, the quantity being constant for each
particular body and for each species of change; the amount of heat
required to produce a change of phase.</cd> -- <col><b>Latent
period</b></col>. <sd>(a)</sd> <fld>(Med.)</fld> <cd>The regular time in
which a disease is supposed to be existing without manifesting
itself.</cd> <sd>(b)</sd> <fld>(Physiol.)</fld> <cd>One of the phases in
a simple muscular contraction, in which invisible preparatory changes
are taking place in the nerve and muscle.</cd> <sd>(c)</sd>
<fld>(Biol.)</fld> <cd>One of those periods or resting stages in the
development of the ovum, in which development is arrested prior to
renewed activity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latently</ent><br/
<hw>La"tent*ly</hw>, <pos>adv.</pos> <def>In a secret or concealed
manner; invisibly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Later</ent><br/
\'d8<hw>La"ter</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lateres</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>A brick or
tile.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Later</ent><br/
<hw>Lat"er</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Compar. of
<er>Late</er>, <pos>a. & adv.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laterad</ent><br/
<hw>Lat"er*ad</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[L.
<ets>latus</ets>, <ets>lateris</ets>, side + <ets>ad</ets> to.]</ety>
<fld>(Anat.)</fld> <def>Toward the side; away from the mesial plane; --
opposed to <ant>mesiad</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lateral</ent><br/
<hw>Lat"er*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lateralis</ets>, fr. <ets>latus</ets>, <ets>lateris</ets>, side:
cf. F. <ets>lat<eacute/ral</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to the sides; <as>as, the <ex>lateral</ex> walls of a house;
the <ex>lateral</ex> branches of a tree.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Lying at, or extending toward,
the side; away from the mesial plane; external; -- opposed to
<ant>mesial</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Directed to the side; <as>as, a <ex>lateral</ex>
view of a thing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lateral cleavage</b></col> <fld>(Crystallog.)</fld>,
<cd>cleavage parallel to the lateral planes.</cd> -- <col><b>Lateral
equation</b></col> <fld>(Math.)</fld>, <cd>an equation of the first
degree.</cd> <mark>[Obs.]</mark> -- <col><b>Lateral line</b></col>
<fld>(Anat.)</fld>, <cd>in fishes, a line of sensory organs along either
side of the body, often marked by a distinct line of color.</cd> --
<mcol><col><b>Lateral pressure</b></col> or
<col><b>stress</b></col></mcol> <fld>(Mech.)</fld>, <cd>a pressure or
stress at right angles to the length, as of a beam or bridge; --
distinguished from <xex>longitudinal pressure or stress</xex>.</cd> --
<col><b>Lateral strength</b></col> <fld>(Mech.)</fld>, <cd>strength
which resists a tendency to fracture arising from lateral pressure.</cd>
-- <col><b>Lateral system</b></col> <fld>(Bridge Building)</fld>,
<cd>the system of horizontal braces (as between two vertical trusses) by
which lateral stiffness is secured.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lateral pass</ent><br/
<ent>lateral</ent><br/
<mhw><hw>lat"er*al</hw>, <hw>lat"er*al pass`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Football)</fld> <sn>1.</sn> <def>A short pass to a
receiver who is upfield from the passer, i.e. is behind the passer
relative to the direction of the passer's goal.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A part or extension of something that points
sideways, as a drift in a mine that goes to the side from the main
one.</def><br/
[<source>PJC</source>]</p>

<p><ent>lateral</ent><br/
<hw>lat"er*al</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<fld>(Football)</fld> <def>To pass the footbal to a receiver who is
behind the passer; to make a lateral pass; <as>as, the ball was
<ex>lateraled</ex> to the fullback, who ran it for a
touchdown</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laterality</ent><br/
<hw>Lat`er*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
condition of being lateral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laterally</ent><br/
<hw>Lat"er*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By the side;
sidewise; toward, or from, the side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lateran</ent><br/
<hw>Lat"er*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The church and
palace of St. John Lateran, the church being the cathedral church of
Rome, and the highest in rank of all churches in the Catholic
world.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is said to have been derived from that of the
<etsep>Laterani</etsep> family, who possessed a palace on or near the
spot where the church now stands. In this church several ecclesiastical
councils, hence called <ex>Lateran</ex> councils, have been
held.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latered</ent><br/
<hw>Lat"ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inclined to delay;
dilatory.</def> <mark>[Obs.]</mark> <ldquo/When a man is too
<xex>latered</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laterifolious</ent><br/
<hw>Lat`er*i*fo"li*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latus</ets>, <ets>lateris</ets>, side + <ets>folium</ets> leaf: cf.
F. <ets>lat<eacute/rifoli<eacute/</ets>.]</ety> <fld>(Bot.)</fld>
<def>Growing from the stem by the side of a leaf; <as>as, a
<ex>laterifolious</ex> flower</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laterite</ent><br/
<hw>Lat"er*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>later</ets> brick, tile: cf. F. <ets>lat<eacute/rite</ets>.]</ety>
<fld>(Geol.)</fld> <def>An argillaceous sandstone, of a red color, and
much seamed; -- found in India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lateritic</ent><br/
<hw>Lat`er*it"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of,
containing, or characterized by, laterite; <as>as, <ex>lateritic</ex>
formations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lateritious</ent><br/
<hw>Lat"er*i"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lateritius</ets>, fr. <ets>later</ets> a brick.]</ety> <def>Like
bricks; of the color of red bricks.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lateritious sediment</b></col> <fld>(Med.)</fld>, <cd>a
sediment in urine resembling brick dust, observed after the crises of
fevers, and at the termination of gouty paroxysms. It usually consists
of uric acid or urates with some coloring matter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lates</ent><br/
\'d8<hw>La"tes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/ a
fish of the Nile.]</ety> <fld>(Zool.)</fld> <def>A genus of large
percoid fishes, of which one species (<spn>Lates Niloticus</spn>)
inhabits the Nile, and another (<spn>Lates calcarifer</spn>) is found in
the Ganges and other Indian rivers. They are valued as food
fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latescence</ent><br/
<hw>La*tes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A slight
withdrawal from view or knowledge.</def> <rj><au>Sir W.
Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latescent</ent><br/
<hw>La*tes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latescens</ets>, <ets>-entis</ets>, p. pr. of <ets>latescere</ets>
to be concealed, fr. <ets>latere</ets> to be hid.]</ety> <def>Slightly
withdrawn from view or knowledge; <as>as, a <ex>latescent</ex>
meaning</as>.</def> <rj><au>Sir W. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latewake</ent><br/
<hw>Late"wake`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <cref>Lich
wake</cref>, under <er>Lich</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lateward</ent><br/
<hw>Late"ward</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <def>Somewhat
late; backward.</def> <mark>[Obs.]</mark> <ldquo/<xex>Lateward</xex>
lands.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latex</ent><br/
\'d8<hw>La"tex</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A milky or colored juice in certain
plants in cavities (called <xex>latex cells</xex> or <xex>latex
tubes</xex>). It contains the peculiar principles of the plants, whether
aromatic, bitter, or acid, and in many instances yields caoutchouc upon
coagulation. The lattex of the India rubber plant produces the rubber of
commerce on coagulation.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Any aqueous emulsion of finely
divided rubber or plastic particles, especially such an emulsion used as
a base for paint; <as>as, a <ex>latex</ex> paint</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lath</ent><br/
<hw>Lath</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Laths</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>laththe</ets>,
<ets>latthe</ets>, <ets>latte</ets>, AS. <ets>l<ae/tta</ets>; akin to D.
<ets>lat</ets>, G. <ets>latte</ets>, OHG. <ets>latta</ets>; cf. W.
<ets>llath</ets> a rod, staff, yard. Cf. <er>Lattice</er>,
<er>Latten</er>.]</ety> <def>A thin, narrow strip of wood, nailed to the
rafters, studs, or floor beams of a building, for the purpose of
supporting the tiles, plastering, etc. A corrugated metallic strip or
plate is sometimes used.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lath brick</b></col>, <cd>a long, slender brick, used in
making the floor on which malt is placed in the drying kiln.</cd>
<col><b>Lath nail</b></col> <cd>a slender nail for fastening
laths.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lath</ent><br/
<hw>Lath</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lathed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lathing</conjf>.]</vmorph> <def>To cover or line with
laths.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lathe</ent><br/
<hw>Lathe</hw> <pr>(l<aum/<th/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>l<aemac/<edh/</ets>. Of uncertain origin.]</ety> <def>Formerly, a
part or division of a county among the Anglo-Saxons. At present it
consists of four or five hundreds, and is confined to the county of
Kent.</def> <altsp>[Written also <asp>lath</asp>.]</altsp>
<rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lathe</ent><br/
<hw>Lathe</hw> <pr>(l<amac/<th/)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lathe</ets> a granary; akin to G. <ets>lade</ets> a chest, Icel.
<ets>hla<edh/a</ets> a storehouse, barn; but cf. also Icel.
<ets>l<oum/<edh/</ets> a smith's lathe. Senses 2 and 3 are perh. of the
same origin as <ets>lathe</ets> a granary, the original meaning being, a
frame to hold something. If so, the word is from an older form of E.
<ets>lade</ets> to load. See <er>Lade</er> to load.]</ety> <sn>1.</sn>
<def>A granary; a barn.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A machine for turning, that is,
for shaping articles of wood, metal, or other material, by causing them
to revolve while acted upon by a cutting tool.</def> <-- "turning" here
is in the sense of cutting while turning. turn 6 and turning 4, in this
dict. --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The movable swing frame of a loom, carrying the reed
for separating the warp threads and beating up the weft; -- called also
<altname>lay</altname> and <altname>batten</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Blanchard lathe</b></col>, <cd>a lathe for turning
irregular forms after a given pattern, as lasts, gunstocks, and the
like.</cd> -- <mcol><col><b>Drill lathe</b></col>, <it>or</it>
<col><b>Speed lathe</b></col></mcol>, <cd>a small lathe which, from its
high speed, is adapted for drilling; a hand lathe.</cd> --
<col><b>Engine lathe</b></col>, <cd>a turning lathe in which the cutting
tool has an automatic feed; -- used chiefly for turning and boring
metals, cutting screws, etc.</cd> -- <col><b>Foot lathe</b></col>, <cd>a
lathe which is driven by a treadle worked by the foot.</cd> --
<col><b>Geometric lathe</b></col>. See under <er>Geometric</er> --
<col><b>Hand lathe</b></col>, <cd>a lathe operated by hand; a power
turning lathe without an automatic feed for the tool.</cd> --
<col><b>Slide lathe</b></col>, <cd>an engine lathe.</cd> --
<col><b>Throw lathe</b></col>, <cd>a small lathe worked by one hand,
while the cutting tool is held in the other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lathee</ent><br/
<hw>lathee</hw> <pos>n.</pos> <def>a heavy stick (often bamboo) bound
with iron; used by police in India.</def><br/
<syn><b>Syn. --</b> lathi.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 833 --></p>

<p><ent>Lather</ent><br/
<hw>Lath"er</hw> <pr>(l<acr/<th/"<etil/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>le<aacute/<edh/or</ets> niter, in <ets>le<aacute/<edh/orwyrt</ets>
soapwort; cf. Icel. <ets>lau<edh/r</ets>; perh. akin to E.
<ets>lye</ets>.]</ety> <sn>1.</sn> <def>Foam or froth made by soap
moistened with water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Foam from profuse sweating, as of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lather</ent><br/
<hw>Lath"er</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lathered</conjf> <pr>(l<acr/<th/"<etil/rd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Lathering</conjf>.]</vmorph> <ety>[AS.
<ets>l<emac/<edh/rian</ets> to lather, anoint. See <er>Lather</er>,
<pos>n.</pos> ]</ety> <def>To spread over with lather; <as>as, to
<ex>lather</ex> the face</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lather</ent><br/
<hw>Lath"er</hw>, <pos>v. i.</pos> <def>To form lather, or a froth like
lather; to accumulate foam from profuse sweating, as a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lather</ent><br/
<hw>Lath"er</hw>, <pos>v. t.</pos> <ety>[Cf. <er>Leather</er>.]</ety>
<def>To beat severely with a thong, strap, or the like; to flog.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lathreeve</ent><br/
<ent>Lathereeve</ent><br/
<mhw>{ <hw>Lathe"reeve`</hw> <pr>(?)</pr>, <hw>Lath"reeve`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>Formerly, the head officer of a
lathe. See 1st <er>Lathe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lathing</ent><br/
<hw>Lath"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or process of covering with laths.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Laths, collectively; a covering of laths.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lath-shaped</ent><br/
<hw>Lath"-shaped`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a slender
elongated form, like a lath; -- said of the feldspar of certain igneous
rocks, as diabase, as seen in microscopic sections.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lathwork</ent><br/
<hw>Lath"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Lathing</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lathy</ent><br/
<hw>Lath"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a lath; long and
slender.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>lathy</qex> horse, all legs and length.</q> <rj><qau>R.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latian</ent><br/
<hw>La"tian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging, or
relating, to Latium, a country of ancient Italy. See
<er>Latin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latibulize</ent><br/
<hw>La*tib"u*lize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Latibulized</conjf> <pr>(<?/)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Latibulizing</conjf> <pr>(?)</pr>.]</vmorph>
<ety>[L. <ets>latibulum</ets> hiding place, fr. <ets>latere</ets> to lie
hid.]</ety> <def>To retire into a den, or hole, and lie dormant in
winter; to retreat and lie hid.</def> <mark>[R.]</mark> <rj><au>G.
Shaw.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latibulum</ent><br/
\'d8<hw>La*tib"u*lum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Latibula</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>A concealed
hiding place; a burrow; a lair; a hole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laticiferous</ent><br/
<hw>Lat`i*cif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latex</ets>, <ets>laticis</ets>, a liquid +
<ets>-ferous</ets>.]</ety> <fld>(Bot.)</fld> <def>Containing the latex;
-- applied to the tissue or tubular vessels in which the latex of the
plant is found.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laticlave</ent><br/
<hw>Lat"i*clave</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laticlavus</ets>, <ets>laticlavium</ets>; <ets>latus</ets> broad +
<ets>clavus</ets> nail, a purple stripe on the tunica: cf. F.
<ets>laticlave</ets>.]</ety> <fld>(Rom. Antiq.)</fld> <def>A broad
stripe of purple on the fore part of the tunic, worn by senators in
ancient Rome as an emblem of office.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laticostate</ent><br/
<hw>Lat`i*cos"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latus</ets> broad + E. <ets>costate</ets>.]</ety>
<def>Broad-ribbed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latidentate</ent><br/
<hw>Lat`i*den"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latus</ets> broad + E. <ets>dentate</ets>.]</ety>
<def>Broad-toothed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latifolious</ent><br/
<ent>Latifoliate</ent><br/
<mhw>{ <hw>Lat`i*fo"li*ate</hw> <pr>(?)</pr>, <hw>Lat`i*fo"li*ous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>latifolius</ets>;
<ets>latus</ets> broad + <ets>folium</ets> leaf: cf. F.
<ets>latifoli<eacute/</ets>.]</ety> <fld>(Bot.)</fld> <def>Having broad
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latigo</ent><br/
\'d8<hw>La"ti*go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>l<aacute/tigo</ets>.]</ety> <def>A strap for tightening a saddle
girth.</def> <mark>[Western U. S. & Sp. Amer.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Latigo halter</ent><br/
<hw>La"ti*go hal"ter</hw> <pr>(?)</pr> <pos>n.</pos> <def>A kind of
halter usually made of raw hide.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Latimer</ent><br/
<hw>Lat"i*mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>latinier</ets>, <ets>latimier</ets>, prop., one knowing
Latin.]</ety> <def>An interpreter.</def> <mark>[Obs.]</mark>
<au>Coke</au>.<br/
[<source>1913 Webster</source>]</p>

<p><ent>Latimeria</ent><br/
<hw>Latimeria</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Latimeridae</fam>, including the coelacanth.</def><br/
<syn><b>Syn. --</b> genus <gen>Latimeria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Latimeridae</ent><br/
<hw>Latimeridae</hw> <pos>prop. n.</pos> <def>A natural family of fish
extinct except for the coelacanth.</def><br/
<syn><b>Syn. --</b> family <fam>Latimeridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Latin</ent><br/
<hw>Lat"in</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>Latinus</ets> belonging to Latium, Latin, fr. <ets>Latium</ets> a
country of Italy, in which Rome was situated. Cf. <er>Ladin</er>,
<ets>Lateen sail</ets>, under <er>Lateen</er>.]</ety> <sn>1.</sn>
<def>Of or pertaining to Latium, or to the Latins, a people of Latium;
Roman; <as>as, the <ex>Latin</ex> language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of, pertaining to, or composed in, the language used
by the Romans or Latins; <as>as, a <ex>Latin</ex> grammar; a
<ex>Latin</ex> composition or idiom.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Latin Church</b></col> <fld>(Eccl. Hist.)</fld>, <cd>the
Western or Roman Catholic Church, as distinct from the Greek or Eastern
Church.</cd> -- <col><b>Latin cross</b></col>. <cd>See
<xex>Illust.</xex> 1 of <er>Cross</er>.</cd> -- <col><b>Latin
races</b></col>, <cd>a designation sometimes loosely given to certain
nations, esp. the French, Spanish, and Italians, who speak languages
principally derived from Latin.</cd> <col><b>Latin Union</b></col>,
<cd>an association of states, originally comprising France, Belgium,
Switzerland, and Italy, which, in 1865, entered into a monetary
agreement, providing for an identity in the weight and fineness of the
gold and silver coins of those countries, and for the amounts of each
kind of coinage by each. Greece, Servia, Roumania, and Spain
subsequently joined the Union.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latin</ent><br/
<hw>Lat"in</hw>, <pos>n.</pos> <sn>1.</sn> <def>A native or inhabitant
of Latium; a Roman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language of the ancient Romans.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An exercise in schools, consisting in turning
English into Latin.</def> <mark>[Obs.]</mark>
<rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eccl.)</fld> <def>A member of the Roman Catholic
Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dog Latin</b></col>, <cd>barbarous Latin; a jargon in
imitation of Latin; <as>as, the <ex>log Latin</ex> of
schoolboys</as>.</cd> -- <mcol><col><b>Late Latin</b></col>, <col><b>Low
Latin</b></col></mcol>, <cd>terms used indifferently to designate the
latest stages of the Latin language; low Latin (and, perhaps, late Latin
also), including the barbarous coinages from the French, German, and
other languages into a Latin form made after the Latin had become a dead
language for the people.</cd> -- <col><b>Law Latin</b></col>, <cd>that
kind of late, or low, Latin, used in statutes and legal instruments; --
often barbarous.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latin</ent><br/
<hw>Lat"in</hw>, <pos>v. t.</pos> <def>To write or speak in Latin; to
turn or render into Latin.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latin America</ent><br/
<hw>Lat"in A*me"ri*ca</hw>, <pos>prop. n.</pos> <def>That part of the
American continents that speak Spanish, Portuguese, or French; the part
of the American continents south of the United States.</def><br/
[<source>PJC</source>]</p>

<p><ent>Latin American</ent><br/
<hw>Lat"in A*me"ri*can</hw>, <pos>prop. a.</pos> <def>Of, pertaining to,
or characteristic of Latin America.</def><br/
[<source>PJC</source>]</p>

<p><ent>Latin American</ent><br/
<hw>Lat"in A*me"ri*can</hw>, <pos>prop. n.</pos> <def>A native or
inhabitant of Latin America.</def><br/
[<source>PJC</source>]</p>

<p><ent>latinate</ent><br/
<hw>latinate</hw> <pos>adj.</pos> <def>derived from or imitative of
Latin.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Latinise</ent><br/
<hw>Latinise</hw> <pos>v. t.</pos> <def>Same as
<er>Latinize</er>.</def><br/
<syn><b>Syn. --</b> Romanize, Latinize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Latinism</ent><br/
<hw>Lat"in*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>latinisme</ets>.]</ety> <def>A Latin idiom; a mode of speech
peculiar to Latin; also, a mode of speech in another language, as
English, formed on a Latin model.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is also sometimes used by Biblical scholars to
designate a Latin word in Greek letters, or the Latin sense of a Greek
word in the Greek Testament.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinist</ent><br/
<hw>Lat"in*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>latiniste</ets>.]</ety> <def>One skilled in Latin; a Latin
scholar.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He left school a good <qex>Latinist</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinistic</ent><br/
<hw>Lat`in*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining
to, or derived from, Latin; in the Latin style or idiom.</def>
<ldquo/<xex>Latinistic</xex> words.<rdquo/ <rj><au>Fitzed.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinitaster</ent><br/
<hw>La*tin"i*tas`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Poetaster</er>.]</ety> <def>One who has but a smattering of
Latin.</def> <rj><au>Walker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinity</ent><br/
<hw>La*tin"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>latinitas</ets>: cf. F. <ets>latinit<eacute/</ets>.]</ety> <def>The
Latin tongue, style, or idiom, or the use thereof; specifically, purity
of Latin style or idiom.</def> <ldquo/His elegant
<xex>Latinity</xex>.<rdquo/ <rj><au>Motley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinization</ent><br/
<hw>Lat`in*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of Latinizing, as a word, language, or country.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Germanization of Britain went far deeper than the
<qex>Latinization</qex> of France.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinize</ent><br/
<hw>Lat"in*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Latinized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Latinizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>latinizare</ets>: cf. F. <ets>latiniser</ets>.]</ety> <sn>1.</sn>
<def>To give Latin terminations or forms to, as to foreign words, in
writing Latin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring under the power or influence of the Romans
or Latins; to affect with the usages of the Latins, especially in
speech.</def> <ldquo/<xex>Latinized</xex> races.<rdquo/
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make like the Roman Catholic Church or diffuse
its ideas in; <as>as, to <ex>Latinize</ex> the Church of
England</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>to write in the latin alphabet.</def><br/
<syn><b>Syn. --</b> Romanize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Latinize</ent><br/
<hw>Lat"in*ize</hw>, <pos>v. i.</pos> <def>To use words or phrases
borrowed from the Latin.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come under the influence of the Romans, or of the
Roman Catholic Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latinly</ent><br/
<hw>Lat"in*ly</hw>, <pos>adv.</pos> <def>In the manner of the Latin
language; in correct Latin.</def> <mark>[Obs.]</mark>
<rj><au>Heylin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lation</ent><br/
<hw>La"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>latio</ets>,
fr. <ets>latus</ets> borne. See <er>Tolerate</er>.]</ety>
<def>Transportation; conveyance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latirostrous</ent><br/
<ent>Latirostral</ent><br/
<mhw>{ <hw>Lat`i*ros"tral</hw> <pr>(?)</pr>, <hw>Lat`i*ros"trous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F. <ets>latirostre</ets>.
See <er>Latirostres</er>.]</ety> <fld>(Zool.)</fld> <def>Having a broad
beak.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latirostres</ent><br/
\'d8<hw>Lat`i*ros"tres</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>latus</ets> broad + <ets>rostrum</ets> beak.]</ety>
<fld>(Zool.)</fld> <def>The broad-billed singing birds, such as the
swallows, and their allies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latish</ent><br/
<hw>Lat"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat late.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latisternal</ent><br/
<hw>Lat`i*ster"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latus</ets> broad + E. <ets>sternal</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having a broad breastbone, or sternum; -- said
of anthropoid apes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitancy</ent><br/
<hw>Lat"i*tan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Latitant</er>.]</ety> <def>Act or state of lying hid, or
lurking.</def> <mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitant</ent><br/
<hw>Lat"i*tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latitans</ets>, pr. of <ets>latitare</ets> to lie hid, to lurk, v.
intens. fr. <ets>latere</ets> to be hid: cf. F.
<ets>latitant</ets>.]</ety> <def>Lying hid; concealed; latent.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitat</ent><br/
\'d8<hw>Lat"i*tat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., he lies
hid.]</ety> <fld>(O. Eng. Law)</fld> <def>A writ based upon the
presumption that the person summoned was hiding.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitation</ent><br/
<hw>Lat`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>latitatio</ets>.]</ety> <def>A lying in concealment; hiding.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitude</ent><br/
<hw>Lat"i*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>latitude</ets>, L. <ets>latitudo</ets>, fr. <ets>latus</ets> broad,
wide, for older <ets>stlatus</ets>; perh. akin to E.
<ets>strew</ets>.]</ety> <sn>1.</sn> <def>Extent from side to side, or
distance sidewise from a given point or line; breadth; width.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Provided the length do not exceed the <qex>latitude</qex> above
one third part.</q> <rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Room; space; freedom from confinement or restraint;
hence, looseness; laxity; independence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In human actions there are no degrees and precise natural limits
described, but a <qex>latitude</qex> is indulged.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Extent or breadth of signification, application,
etc.; extent of deviation from a standard, as truth, style,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No discreet man will believe Augustine's miracles, in the
<qex>latitude</qex> of monkish relations.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Extent; size; amplitude; scope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I pretend not to treat of them in their full
<qex>latitude</qex>.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Geog.)</fld> <def>Distance north or south of the
equator, measured on a meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Astron.)</fld> <def>The angular distance of a
heavenly body from the ecliptic.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Ascending latitude</b></col>, <col><b>Circle of
latitude</b></col>, <col><b>Geographical latitude</b></col></mcol>,
<cd>etc. See under <er>Ascending</er>. <er>Circle</er>, etc.</cd> --
<col><b>High latitude</b></col>, <cd>that part of the earth's surface
near either pole, esp. that part within either the arctic or the
antarctic circle.</cd> -- <col><b>Low latitude</b></col>, <cd>that part
of the earth's surface which is near the equator.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitudinal</ent><br/
<hw>Lat`i*tu"di*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to latitude; in the direction of latitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitudinarian</ent><br/
<hw>Lat`i*tu`di*na"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>latitudinaire</ets>.]</ety> <sn>1.</sn> <def>Not restrained; not
confined by precise limits.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indifferent to a strict application of any standard
of belief or opinion; hence, deviating more or less widely from such
standard; lax in doctrine; <as>as, <ex>latitudinarian</ex> divines;
<ex>latitudinarian</ex> theology.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Latitudinarian</qex> sentiments upon religious subjects.</q>
<rj><qau>Allibone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lax in moral or religious principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitudinarian</ent><br/
<hw>Lat`i*tu`di*na"ri*an</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who is
moderate in his notions, or not restrained by precise settled limits in
opinion; one who indulges freedom in thinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Eccl. Hist.)</fld> <def>A member of the Church
of England, in the time of Charles II., who adopted more liberal notions
in respect to the authority, government, and doctrines of the church
than generally prevailed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They were called <ldquo/men of latitude;<rdquo/ and upon this, men
of narrow thoughts fastened upon them the name of
<qex>latitudinarians</qex>.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Theol.)</fld> <def>One who departs in opinion from
the strict principles of orthodoxy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitudinarianism</ent><br/
<hw>Lat`i*tu`di*na"ri*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
latitudinarian system or condition; freedom of opinion in matters
pertaining to religious belief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fierce sectarianism bred fierce <qex>latitudinarianism</qex>.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Ammonius Saccas] plunged into the wildest
<qex>latitudinarianism</qex> of opinion.</q> <rj><qau>J. S.
Harford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latitudinous</ent><br/
<hw>Lat`i*tu"di*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
latitude, or wide extent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latoun</ent><br/
<ent>Laton</ent><br/
<mhw>{ <hw>Lat"on</hw> <pr>(?)</pr>, <hw>Lat"oun</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <def>Latten, 1.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latrant</ent><br/
<hw>La"trant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>latrans</ets>, p. pr. of <ets>latrare</ets>. See
<er>Latrate</er>.]</ety> <def>Barking.</def> <mark>[Obs.]</mark>
<rj><au>Tickell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latrate</ent><br/
<hw>La"trate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>latratus</ets>, p. p. of <ets>latrare</ets> to bark.]</ety> <def>To
bark as a dog.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latration</ent><br/
<hw>La*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A barking.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latreutical</ent><br/
<hw>La*treu"tic*al</hw> <pr>(l<adot/*tr<udd/"t<icr/*k<ait/l)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>latreytiko`s</grk>, fr.
<grk>latrey`ein</grk> to serve, to worship.]</ety> <sn>1.</sn>
<def>Acting as a hired servant; serving; ministering; assisting.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to latria.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latria</ent><br/
\'d8<hw>La*tri"a</hw> <pr>(l<adot/*tr<imac/"<adot/; 277)</pr>,
<pos>n.</pos> <ety>[L., fr. Gr. <grk>latrei`a</grk>, fr.
<grk>latrey`ein</grk> to serve, fr. <grk>la`tris</grk> servant.]</ety>
<def>The highest kind of worship, or that paid to God; -- distinguished
by the Roman Catholics from <contr>dulia</contr>, or the inferior
worship paid to saints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latrine</ent><br/
<hw>La*trine"</hw> <pr>(l<adot/*tr<emac/n")</pr>, <pos>n.</pos> <ety>[L.
<ets>latrina</ets>: cf. F. <ets>latrines</ets>.]</ety> <def>A privy, or
water-closet, esp. in a camp, hospital, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latrociny</ent><br/
<hw>Lat"ro*cin`y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>latrocinium</ets>. Cf. <er>Larceny</er>.]</ety> <def>Theft;
larceny.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>latte</ent><br/
<hw>lat"te</hw> <pr>(l<adot/*t<amac/")</pr>, <pos>n.</pos> <def>Same as
<er>cafe latte</er>; a type of espresso coffee served with foamy steamed
milk, and usually served in a tall glass or mug.</def><br/
[<source>PJC</source>]</p>

<p><ent>Latten</ent><br/
<hw>Lat"ten</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>latoun</ets>, <ets>laton</ets>, OF. <ets>laton</ets>, F.
<ets>laiton</ets>, prob. fr. OF. <ets>late</ets> lath, F.
<ets>latte</ets>; -- because made in thin plates; cf. It.
<ets>latta</ets> a sheet of tinned iron, tin plate. F. <ets>latte</ets>
is of German origin. See <er>Lath</er> a thin board.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A kind of brass hammered into thin sheets, formerly
much used for making church utensils, as candlesticks, crosses, etc.; --
called also <altname>latten brass</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had a cross of <qex>latoun</qex> full of stones.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sheet tin; iron plate, covered with tin; also, any
metal in thin sheets; <as>as, gold <ex>latten</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Black latten</b></col>, <cd>brass in milled sheets,
composed of copper and zinc, used by braziers, and for drawing into
wire.</cd> -- <col><b>Roll latten</b></col>, <cd>latten polished on both
sides ready for use.</cd> -- <col><b>Shaven latten</b></col>, <cd>a
thinner kind than black latten.</cd> -- <col><b>White latten</b></col>,
<cd>a mixture of brass and tin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latter</ent><br/
<hw>Lat"ter</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>later</ets>,
<ets>l<ae/tter</ets>, compar. of <ets>lat</ets> late. See <er>Late</er>,
and cf. <er>Later</er>.]</ety> <sn>1.</sn> <def>Later; more recent;
coming or happening after something else; -- opposed to
<ant>former</ant>; <as>as, the former and <ex>latter</ex>
rain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of two things, the one mentioned second.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The difference between reason and revelation, and in what sense
the <qex>latter</qex> is superior.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Recent; modern.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hath not navigation discovered in these <qex>latter</qex> ages,
whole nations at the bay of Soldania?</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Last; latest; final.</def> <mark>[R.]</mark>
<ldquo/My <xex>latter</xex> gasp.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Latter harvest</b></col>, <cd>the last part of the
harvest.</cd> -- <col><b>Latter spring</b></col>, <cd>the last part of
the spring of the year.</cd> <au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latterday</ent><br/
<hw>Lat"ter*day`</hw>, <pos>a.</pos> <def>Belonging to present times or
those recent by comparison.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Latter-day saint</ent><br/
<hw>Lat"ter-day` saint"</hw> <pr>(?)</pr> <pos>n.</pos> <def>A Mormon;
-- the <membof>Church of Jesus Christ of Latter-day Saints</membof>
being the name assumed by the whole body of Mormons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latterkin</ent><br/
<hw>Lat"ter*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pointed wooden
tool used in glazing leaden lattice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latterly</ent><br/
<hw>Lat"ter*ly</hw>, <pos>adv.</pos> <def>Lately; of late; recently; at
a later, as distinguished from a former, period.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Latterly</qex> Milton was short and thick.</q>
<rj><qau>Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lattermath</ent><br/
<hw>Lat"ter*math</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Aftermath</er>.]</ety> <def>The latter, or second, mowing; the
aftermath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lattice</ent><br/
<hw>Lat"tice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>latis</ets>, F. <ets>lattis</ets> lathwork, fr. <ets>latte</ets>
lath. See <er>Latten</er>, 1st <er>Lath</er>.]</ety> <sn>1.</sn>
<def>Any work of wood, metal, plastic, or other solid material, made by
crossing a series of parallel laths, or thin strips, with another series
at a diagonal angle, and forming a network with openings between the
strips; <as>as, the <ex>lattice</ex> of a window</as>; -- called also
<altname>latticework</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mother of Sisera looked out at a window, and cried through the
<qex>lattice</qex>.</q> <rj><qau>Judg. v. 28. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>The representation of a piece of
latticework used as a bearing, the bands being vertical and
horizontal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Crystallography)</fld> <def>The arrangement of
atoms or molecules in a crystal, represented as a repeating arrangement
of points in space, each point representing the location of an atom or
molecule; called also <altname>crystal lattice</altname> and
<altname>space lattice</altname>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Lattice bridge</b></col>, <cd>a bridge supported by
lattice girders, or latticework trusses.</cd> -- <col><b>Lattice
girder</b></col> <fld>(Arch.)</fld>, <cd>a girder of which the wed
consists of diagonal pieces crossing each other in the manner of
latticework.</cd> -- <col><b>Lattice plant</b></col> <fld>(Bot.)</fld>,
<cd>an aquatic plant of Madagascar (<spn>Ouvirandra fenestralis</spn>),
whose leaves have interstices between their ribs and cross veins, so as
to resemble latticework. A second species is <spn>Ouvirandra
Berneriana</spn>. The genus is merged in <gen>Aponogeton</gen> by recent
authors.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lattice</ent><br/
<hw>Lat"tice</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Latticed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Latticing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To
make a lattice of; <as>as, to <ex>lattice</ex> timbers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To close, as an opening, with latticework; to
furnish with a lattice; <as>as, to <ex>lattice</ex> a
window</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lattice up</b></col>, <cd>to cover or inclose with a
lattice.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Therein it seemeth he [Alexander] hath <qex>latticed up</qex>
Caesar.</q> <rj><qau>Sir T. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>latticed</ent><br/
<hw>latticed</hw> <pos>adj.</pos> <def>having a lattice.</def><br/
<syn><b>Syn. --</b> fretted, interlaced, latticelike.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>latticelike</ent><br/
<hw>latticelike</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>latticed</er>.</def><br/
<syn><b>Syn. --</b> fretted, interlaced, latticed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Latticework</ent><br/
<hw>Lat"tice*work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Lattice</er>, <pos>n.</pos>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latticing</ent><br/
<hw>Lat"ti*cing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act or process of making a lattice of, or of fitting a lattice
to.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bridge Building)</fld> <def>A system of bars
crossing in the middle to form braces between principal longitudinal
members, as of a strut.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Latus rectum</ent><br/
\'d8<hw>La"tus rec"tum</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L., the
right side.]</ety> <fld>(Conic Sections)</fld> <def>The line drawn
through a focus of a conic section parallel to the directrix and
terminated both ways by the curve. It is the parameter of the principal
axis. See <er>Focus</er>, and <er>Parameter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laud</ent><br/
<hw>Laud</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>laus</ets>,
<ets>laudis</ets>. See <er>Laud</er>, <pos>v. i.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>High commendation; praise; honor; exaltation;
glory.</def> <ldquo/<xex>Laud</xex> be to God.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So do well and thou shalt have <qex>laud</qex> of the same.</q>
<rj><qau>Tyndals.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A part of divine worship, consisting chiefly of
praise; -- usually in the <pluf>pl.</pluf></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the Roman Catholic Church, the prayers used at
daybreak, between those of matins and prime, are called
<xex>lauds</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Music or singing in honor of any one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laud</ent><br/
<hw>Laud</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lauded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lauding</conjf>.]</vmorph> <ety>[L. <ets>laudare</ets>, fr.
<ets>laus</ets>, <ets>laudis</ets>, praise. Cf. <er>Allow</er>.]</ety>
<def>To praise in words alone, or with words and singing; to celebrate;
to extol.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With all the company of heaven, we <qex>laud</qex> and magnify thy
glorious name.</q> <rj><qau>Book of Common Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudability</ent><br/
<hw>Laud`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laudabilitas</ets>.]</ety> <def>Laudableness;
praiseworthiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudable</ent><br/
<hw>Laud"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laudabilis</ets>: cf. OE. <ets>laudable</ets>. See <er>Laud</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>Worthy of being lauded;
praiseworthy; commendable; <as>as, <ex>laudable</ex> motives;
<ex>laudable</ex> actions; <ex>laudable</ex> ambition.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Healthy; salubrious; normal;
having a disposition to promote healing; not noxious; <as>as,
<ex>laudable</ex> juices of the body; <ex>laudable</ex> pus.</as></def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 834 --></p>

<p><ent>Laudableness</ent><br/
<hw>Laud"a*ble*ness</hw> <pr>(l<add/d"<adot/*b'l*n<ecr/s)</pr>,
<pos>n.</pos> <def>The quality of being laudable; praiseworthiness;
commendableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudably</ent><br/
<hw>Laud"a*bly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a laudable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudanine</ent><br/
<hw>Lau"da*nine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Laudanum</er>.]</ety> <fld>(Chem.)</fld> <def>A white organic base,
resembling morphine, and obtained from certain varieties of
opium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudanum</ent><br/
<hw>Lau"da*num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Orig. the same
wort as <ets>ladanum</ets>, <ets>ladbdanum</ets>: cf. F.
<ets>laudanum</ets>, It. <ets>laudano</ets>, <ets>ladano</ets>. See
<er>Ladanum</er>.]</ety> <def>Tincture of opium, used for various
medical purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A fluid ounce of American laudanum should contain the
soluble matter of one tenth of an ounce avoirdupois of powdered opium
with equal parts of alcohol and water. English laudanum should have ten
grains less of opium in the fluid ounce. <au>U. S. Disp.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dutchman's laudanum</b></col> <fld>(Bot.)</fld> <cd>See
under <er>Dutchman</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudation</ent><br/
<hw>Lau*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laudatio</ets>: cf. OE. <ets>taudation</ets>. See <er>Land</er>,
<pos>v. t.</pos>]</ety> <def>The act of lauding; praise; high
commendation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudative</ent><br/
<hw>Laud"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laudativus</ets> laudatory: cf. F. <ets>laudatif</ets>.]</ety>
<def>Laudatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudative</ent><br/
<hw>Laud"a*tive</hw>, <pos>n.</pos> <def>A panegyric; a eulogy.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudator</ent><br/
\'d8<hw>Lau*da"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>One who lauds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An arbitrator.</def>
<mark>[Obs.]</mark> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laudatory</ent><br/
<hw>Laud"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laudatorius</ets>: cf. OF. <ets>laudatoire</ets>.]</ety> <def>Of or
pertaining praise, or to the expression of praise; <as>as,
<ex>laudatory</ex> verses; the <ex>laudatory</ex> powers of
Dryden.</as></def> <rj><au>Sir J. Stephen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lauder</ent><br/
<hw>Laud"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
lauds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laugh</ent><br/
<hw>Laugh</hw> <pr>(l<aum/f)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Laughed</conjf> <pr>(l<aum/ft)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Laughing</conjf>.]</vmorph> <ety>[OE.
<ets>laughen</ets>, <ets>laghen</ets>, <ets>lauhen</ets>, AS.
<ets>hlehhan</ets>, <ets>hlihhan</ets>, <ets>hlyhhan</ets>,
<ets>hliehhan</ets>; akin to OS. <ets>hlahan</ets>, D. & G.
<ets>lachen</ets>, OHG. <ets>hlahhan</ets>, <ets>lahhan</ets>,
<ets>lahh<emac/n</ets>, Icel. <ets>hl<ae/ja</ets>,W Dan. <ets>lee</ets>,
Sw. <ets>le</ets>, Goth. <ets>hlahjan</ets>; perh. of imitative
origin.]</ety> <sn>1.</sn> <def>To show mirth, satisfaction, or
derision, by peculiar movement of the muscles of the face, particularly
of the mouth, causing a lighting up of the face and eyes, and usually
accompanied by the emission of explosive or chuckling sounds from the
chest and throat; to indulge in laughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Queen Hecuba <qex>laughed</qex> that her eyes ran o'er.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>laugheth</qex> that winneth.</q> <rj><qau>Heywood's
Prov.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To be or appear gay, cheerful, pleasant,
mirthful, lively, or brilliant; to sparkle; to sport.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then <qex>laughs</qex> the childish year, with flowerets
crowned.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In Folly's cup still <qex>laughs</qex> the bubble Joy.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To laugh at</b></col>, <cd>to make an object of laughter
or ridicule; to make fun of; to deride.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>No wit to flatter left of all his store,<br/
No fool <qex>to laugh at</qex>, which he valued more.</q>
<rj><qau>Pope.</qau></rj></p>

<p>-- <mcol><col><b>To laugh in the sleeve</b></col>, <col><b>To laugh
up one's sleeve</b></col></mcol>, <cd>to laugh secretly, or so as not to
be observed, especially while apparently preserving a grave or serious
demeanor toward the person or persons laughed at.</cd> -- <col><b>To
laugh out</b></col>, <cd>to laugh in spite of some restraining
influence; to laugh aloud.</cd> -- <mcol><col><b>To laugh out of the
other corner of the mouth</b></col> <it>or</it> <col><b>To laugh out of
the other side of the mouth</b></col></mcol>, <cd>to weep or cry; to
feel regret, vexation, or disappointment after hilarity or
exaltation.</cd> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Laugh</ent><br/
<hw>Laugh</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To affect or influence
by means of laughter or ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Will you <qex>laugh</qex> me asleep, for I am very heavy?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall <qex>laugh</qex> myself to death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express by, or utter with, laughter; -- with
<xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From his deep chest <qex>laughs</qex> out a loud applause.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To laugh away</b></col>. <sd>(a)</sd> <cd>To drive away
by laughter; <as>as, <ex>to laugh away</ex> regret</as>.</cd>
<sd>(b)</sd> <cd>To waste in hilarity.</cd> <ldquo/Pompey doth this day
<xex>laugh away</xex> his fortune.<rdquo/ <au>Shak.</au> -- <col><b>To
laugh down</b></col>. <sd>(a)</sd> <cd>To cause to cease or desist by
laughter; as, <xex>to laugh down</xex> a speaker.</cd> <sd>(b)</sd>
<cd>To cause to be given up on account of ridicule; as, <xex>to laugh
down</xex> a reform.</cd> -- <col><b>To laugh one out of</b></col>,
<cd>to cause one by laughter or ridicule to abandon or give up; <as>as,
<ex>to laugh one out of</ex> a plan or purpose</as>.</cd> -- <col><b>To
laugh to scorn</b></col>, <cd>to deride; to treat with mockery,
contempt, and scorn; to despise.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laugh</ent><br/
<hw>Laugh</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An expression of mirth
peculiar to the human species; the sound heard in laughing; laughter.
See <er>Laugh</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the loud <qex>laugh</qex> that spoke the vacant mind.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That man is a bad man who has not within him the power of a hearty
<qex>laugh</qex>.</q> <rj><qau>F. W. Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughable</ent><br/
<hw>Laugh"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fitted to excite
laughter; <as>as, a <ex>laughable</ex> story; a <ex>laughable</ex>
scene.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Droll; ludicrous; mirthful; comical. See
<er>Droll</er>, and <er>Ludicrous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Laugh"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Laugh"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laugher</ent><br/
<hw>Laugh"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
laughs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A variety of the domestic pigeon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A contest in which one side wins easily; a lopsided
victory.</def> <mark>[Informal]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A blatantly false statement, especially a
self-serving one.</def> <mark>[Slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Laughing</ent><br/
<hw>Laugh"ing</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>from
<er>Laugh</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Laughing falcon</b></col> <fld>(Zool.)</fld>, <cd>a South
American hawk (<spn>Herpetotheres cachinnans</spn>); -- so called from
its notes, which resemble a shrill laugh.</cd> -- <col><b>Laughing
gas</b></col> <fld>(Chem.)</fld>, <cd>nitrous oxide, also called
hyponitrous oxide, or protoxide of nitrogen; -- so called from the
exhilaration and laughing which it sometimes produces when inhaled. It
has been much used as an anaesthetic agent, though now its use is
primarily in dentistry</cd> -- <col><b>Laughing goose</b></col>
<fld>(Zool.)</fld>, <cd>the European white-fronted goose.</cd> --
<col><b>Laughing gull</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A
common European gull (<spn>Xema ridibundus</spn>); -- called also
<altname>pewit</altname>, <altname>black cap</altname>,
<altname>red-legged gull</altname>, and <altname>sea
crow</altname>.</cd> <sd>(b)</sd> <cd>An American gull (<spn>Larus
atricilla</spn>). In summer the head is nearly black, the back slate
color, and the five outer primaries black.</cd> -- <col><b>Laughing
hyena</b></col> <fld>(Zool.)</fld>, <cd>the spotted hyena. See
<er>Hyena</er>.</cd> -- <col><b>Laughing jackass</b></col>
<fld>(Zool.)</fld>, <cd>the great brown kingfisher (<spn>Dacelo
gigas</spn>), of Australia; -- called also <altname>giant
kingfisher</altname>, and <altname>gogobera</altname>.</cd> --
<col><b>Laughing owl</b></col> <fld>(Zool.)</fld>, <cd>a peculiar owl
(<spn>Sceloglaux albifacies</spn>) of New Zealand, said to be on the
verge of extinction. The name alludes to its notes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughingly</ent><br/
<hw>Laugh"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With laughter
or merriment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughingstock</ent><br/
<hw>Laugh"ing*stock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An object of
ridicule; a butt of sport.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When he talked, he talked nonsense, and made himself the
<qex>laughingstock</qex> of his hearers.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughsome</ent><br/
<hw>Laugh"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Exciting laughter;
also, addicted to laughter; merry.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughter</ent><br/
<hw>Laugh"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hleahtor</ets>; akin to OHG. <ets>hlahtar</ets>, G.
<ets>gel<aum/chter</ets>, Icel. <ets>hl<amac/tr</ets>, Dan.
<ets>latter</ets>. See <er>Laugh</er>, <pos>v. i.</pos> ]</ety> <def>A
movement (usually involuntary) of the muscles of the face, particularly
of the lips, with a peculiar expression of the eyes, indicating
merriment, satisfaction, or derision, and usually attended by a sonorous
and interrupted expulsion of air from the lungs. See <er>Laugh</er>,
<pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The act of <qex>laughter</qex>, which is a sweet contraction of
the muscles of the face, and a pleasant agitation of the vocal organs,
is not merely, or totally within the jurisdiction of ourselves.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Archly the maiden smiled, and with eyes overrunning with
<qex>laughter</qex>.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughterless</ent><br/
<hw>Laugh"ter*less</hw>, <pos>a.</pos> <def>Not laughing; without
laughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laughworthy</ent><br/
<hw>Laugh"wor`thy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deserving to be
laughed at.</def> <mark>[R.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laumontite</ent><br/
<hw>Lau"mont*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Dr.
<ets>Laumont</ets>, the discoverer.]</ety> <fld>(Min.)</fld> <def>A
mineral, of a white color and vitreous luster. It is a hydrous silicate
of alumina and lime. Exposed to the air, it loses water, becomes opaque,
and crumbles.</def> <altsp>[Written also
<asp>laumonite</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launce</ent><br/
<hw>Launce</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lance.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launce</ent><br/
<hw>Launce</hw>, <pos>n.</pos> <ety>[It. <ets>lance</ets>, L.
<ets>lanx</ets>, <ets>lancis</ets>, plate, scale of a balance. Cf.
<er>Balance</er>.]</ety> <def>A balance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fortune all in equal <qex>launce</qex> doth sway.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launce</ent><br/
<hw>Launce</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Lant</er>, the fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launcegaye</ent><br/
<hw>Launce"gaye`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lancegaye</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launch</ent><br/
<hw>Launch</hw> <pr>(l<add/nch <it>or</it> l<aum/nch)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Launched</conjf>
<pr>(l<add/ncht <it>or</it> l<aum/ncht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Launching</conjf>.]</vmorph> <ety>[OE. <ets>launchen</ets> to
throw as a lance, OF. <ets>lanchier</ets>, another form of
<ets>lancier</ets>, F. <ets>lancer</ets>, fr. <ets>lance</ets> lance.
See <er>Lance</er>.]</ety> <altsp>[Written also
<asp>lanch</asp>.]</altsp> <sn>1.</sn> <def>To throw, as a lance or
dart; to hurl; to let fly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strike with, or as with, a lance; to
pierce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Launch</qex> your hearts with lamentable wounds.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to move or slide from the land into the
water; to set afloat; <as>as, to <ex>launch</ex> a ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With stays and cordage last he rigged the ship,<br/
And rolled on levers, <qex>launched</qex> her in the deep.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To send out; to start (one) on a career; to set
going; to give a start to (something); to put in operation; <as>as, to
<ex>launch</ex> a son in the world; to <ex>launch</ex> a business
project or enterprise.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>All art is used to sink episcopacy, and <qex>launch</qex>
presbytery in England.</q> <rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launch</ent><br/
<hw>Launch</hw>, <pos>v. i.</pos> <def>To move with force and swiftness
like a sliding from the stocks into the water; to plunge; to make a
beginning; <as>as, to <ex>launch</ex> into the current of a stream; to
<ex>launch</ex> into an argument or discussion; to <ex>launch</ex> into
lavish expenditures</as>; -- often with <xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Launch</qex> out into the deep, and let down your nets for a
draught.</q> <rj><qau>Luke v. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Spenser] <qex>launches</qex> out into very flowery paths.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launch</ent><br/
<hw>Launch</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
launching.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The movement of a vessel from land into the water;
especially, the sliding on ways from the stocks on which it is
built.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. Sp. <ets>lancha</ets>.]</ety>
<fld>(Naut.)</fld> <def>The boat of the largest size belonging to a ship
of war; also, an open boat of any size driven by steam, naphtha,
electricity, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Launching ways</b></col>. <fld>(Naut.)</fld> <cd>See
<er>Way</er>, <pos>n.</pos> <fld>(Naut.)</fld>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>launcher</ent><br/
<hw>launcher</hw> <pos>n.</pos> <sn>1.</sn> <def>a device capable of
launching a rocket.</def><br/
<syn><b>Syn. --</b> rocket launcher.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A device which launches aircraft from an aircraft
carrier; -- it provides additional velocity to the airplane, to
supplement that from the airplane's engines, so that the airplane
rapidly achieves a velocity sufficient to sustain it in flight when
taking off.</def><br/
<syn><b>Syn. --</b> catapult.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>launching</ent><br/
<hw>launching</hw> <pos>n.</pos> <sn>1.</sn> <def>the act of moving a
newly-built vessel into the water for the first time.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the act of beginning something new.</def><br/
<syn><b>Syn. --</b> debut, first appearance, unveiling, introduction,
entry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>the act of propelling with force.</def><br/
<syn><b>Syn. --</b> launch.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>launchpad</ent><br/
<hw>launchpad</hw> <pos>n.</pos> <fld>(Rocketry)</fld> <def>a platform
from which rockets or space craft are launched.</def><br/
<syn><b>Syn. --</b> launching pad, launch pad, launch area,
pad.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laund</ent><br/
<hw>Laund</hw> <pr>(l<add/nd)</pr>, <pos>n.</pos> <ety>[See
<er>Lawn</er> of grass.]</ety> <def>A plain sprinkled with trees or
underbrush; a glade.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In a <qex>laund</qex> upon an hill of flowers.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Through this <qex>laund</qex> anon the deer will come.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launder</ent><br/
<hw>Laun"der</hw> <pr>(l<add/n"d<etil/r <it>or</it>
l<aum/n"d<etil/r)</pr>, <pos>n.</pos> <ety>[Contracted fr. OE.
<ets>lavender</ets>, F. <ets>lavandi<egrave/re</ets>, LL.
<ets>lavandena</ets>, from L. <ets>lavare</ets> to wash. See
<er>Lave</er>.]</ety> <sn>1.</sn> <def>A washerwoman.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A trough used by miners to
receive the powdered ore from the box where it is beaten, or for
carrying water to the stamps, or other apparatus, for comminuting, or
sorting, the ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launder</ent><br/
<hw>Laun"der</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Laundered</conjf> <pr>(l<add/n"d<etil/rd <it>or</it>
l<aum/n"d<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Laundering</conjf>.]</vmorph> <sn>1.</sn> <def>To wash, as
clothes; to wash, and to smooth with a flatiron or mangle; to wash and
iron; <as>as, to <ex>launder</ex> shirts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lave; to wet.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Launderer</ent><br/
<hw>Laun"der*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who follows
the business of laundering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laundering</ent><br/
<hw>Laun"der*ing</hw>, <pos>n.</pos> <def>The act, or occupation, of one
who launders; washing and ironing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laundress</ent><br/
<hw>Laun"dress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman whose
employment is laundering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laundress</ent><br/
<hw>Laun"dress</hw>, <pos>v. i.</pos> <def>To act as a laundress.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laundry</ent><br/
<hw>Laun"dry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Laundries</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>lavendrie</ets>,
OF. <ets>lavanderie</ets>. See <er>Launder</er>.]</ety> <sn>1.</sn>
<def>A laundering; a washing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place or room where laundering is done; a laundry
room.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A business establishment where clothing is laundered
for a fee.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A collection of items such as articles of clothing
or bed linens that need to be laundered, or have just been laundered;
<as>as, put the dirty <ex>laundry</ex> in the basket and take it
downstairs; hang the <ex>laundry</ex> out to dry</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>coin laundry</b></col> <cd>A business establishment with
washing and drying machines operated by coins, where items such as
articles of clothing may be laundered and dried by the
customer.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Laundryman</ent><br/
<hw>Laun"dry*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Laundrymen</plw> <pr>(<?/)</pr>.</plu> <def>A man who follows the
business of laundering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laura</ent><br/
<hw>Lau"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL., fr. Gr. (<?/)
lane, defile, also, a kind of monastery.]</ety> <fld>(R. C. Ch.)</fld>
<def>A number of hermitages or cells in the same neighborhood occupied
by anchorites who were under the same superior.</def> <rj><au>C.
Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lauraceous</ent><br/
<hw>Lau*ra"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Laurus</er>.]</ety> <fld>(Bot.)</fld> <def>Belonging to, or
resembling, a natural order (<ord>Laurace<ae/</ord>) of trees and shrubs
having aromatic bark and foliage, and including the laurel, sassafras,
cinnamon tree, true camphor tree, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurate</ent><br/
<hw>Lau"rate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
salt of lauric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laureate</ent><br/
<hw>Lau"re*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laureatus</ets>, fr. <ets>laurea</ets> laurel tree, fr.
<ets>laureus</ets> of laurel, fr. <ets>laurus</ets> laurel: cf. F.
<ets>laur<eacute/at</ets>. Cf. <er>Laurel</er>.]</ety> <def>Crowned, or
decked, with laurel.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To strew the <qex>laureate</qex> hearse where Lycid lies.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Soft on her lap her <qex>laureate</qex> son reclines.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Poet laureate</b></col>. <sd>(b)</sd> <cd>One who
received an honorable degree in grammar, including poetry and rhetoric,
at the English universities; -- so called as being presented with a
wreath of laurel.</cd> <mark>[Obs.]</mark> <sd>(b)</sd> <cd>Formerly, an
officer of the king's household, whose business was to compose an ode
annually for the king's birthday, and other suitable occasions; now, a
poet officially distinguished by such honorary title, the office being a
sinecure. It is said this title was first given in the time of Edward
IV.</cd> <mark>[Eng.]</mark> <sd>(c)</sd> <cd>A poet who has been
publicly recognized as the most pre-eminent poet of a country or region;
<as>as, the <ex>poet laureate</ex> of the United
States</as>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Laureate</ent><br/
<hw>Lau"re*ate</hw>, <pos>n.</pos> <sn>1.</sn> <def>One crowned with
laurel; a poet laureate.</def> <ldquo/A learned
<xex>laureate</xex>.<rdquo/ <rj><au>Cleveland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who has been presented with an award for
some distinguished achievement; <as>as, a Nobel <ex>laureate</ex>; the
Pris de Rome <ex>laureate</ex>; the Music Director <ex>Laureate</ex>;
the conductor <ex>laureate</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Laureate</ent><br/
<hw>Lau"re*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Laureated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Laureating</conjf> <pr>(?)</pr>.]</vmorph> <def>To honor
with a wreath of laurel, as formerly was done in bestowing a degree at
the English universities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laureateship</ent><br/
<hw>Lau"re*ate*ship</hw>, <pos>n.</pos> <def>State, or office, of a
laureate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laureation</ent><br/
<hw>Lau`re*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>laur<eacute/ation</ets>.]</ety> <def>The act of crowning with
laurel; the act of conferring an academic degree, or honorary
title.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurel</ent><br/
<hw>Lau"rel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>lorel</ets>,
<ets>laurer</ets>, <ets>lorer</ets>, OF. <ets>lorier</ets>,
<ets>laurier</ets>, F. <ets>laurier</ets>, (assumed) LL.
<ets>Laurarius</ets>, fr. L. <ets>laurus</ets>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>An evergreen shrub, of the genus
<gen>Laurus</gen> (<spn>Laurus nobilis</spn>), having aromatic leaves of
a lanceolate shape, with clusters of small, yellowish white flowers in
their axils; -- called also <altname>sweet bay</altname>.</def>
<note>The fruit is a purple berry. It is found about the Mediterranean,
and was early used by the ancient Greeks to crown the victor in the
games of Apollo. At a later period, academic honors were indicated by a
crown of laurel, with the fruit. The leaves and tree yield an aromatic
oil, used to flavor the bay water of commerce.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is extended to other plants which in some
respect resemble the true laurel. See Phrases, below.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A crown of laurel; hence, honor; distinction; fame;
-- especially in the plural; <as>as, to win
<ex>laurels</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An English gold coin made in 1619, and so called
because the king's head on it was crowned with laurel.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Laurel water</b></col>, <cd>water distilled from the
fresh leaves of the cherry laurel, and containing prussic acid and other
products carried over in the process.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>American laurel</b></col>, <it>or</it>
<col><b>Mountain laurel</b></col></mcol>, <cd><spn>Kalmia
latifolia</spn>; called also <altname>calico bush</altname>. See under
<er>Mountain</er>.</cd> -- <col><b>California laurel</b></col>,
<cd><spn>Umbellularia Californica</spn>.</cd> -- <col><b>Cherry
laurel</b></col> <cd>(in England called <altname>laurel</altname>). See
under <er>Cherry</er>.</cd> -- <col><b>Great laurel</b></col>, <cd>the
rosebay (<spn>Rhododendron maximum</spn>).</cd> -- <col><b>Ground
laurel</b></col>, <cd>trailing arbutus.</cd> -- <col><b>New Zealand
laurel</b></col>, <cd>the <spn>Laurelia Nov<ae/ Zelandi<ae/</spn>.</cd>
-- <col><b>Portugal laurel</b></col>, <cd>the <spn>Prunus
Lusitanica</spn>.</cd> -- <col><b>Rose laurel</b></col>, <cd>the
oleander. See <er>Oleander</er>.</cd> -- <col><b>Sheep laurel</b></col>,
<cd>a poisonous shrub, <spn>Kalmia angustifolia</spn>, smaller than the
mountain laurel, and with smaller and redder flowers.</cd> --
<col><b>Spurge laurel</b></col>, <cd><spn>Daphne Laureola</spn>.</cd> --
<col><b>West Indian laurel</b></col>, <cd><spn>Prunus
occidentalis</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laureled</ent><br/
<hw>Lau"reled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Crowned with laurel,
or with a laurel wreath; laureate.</def> <altsp>[Written also
<asp>laurelled</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>laurels</ent><br/
<hw>lau"rels</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>An honor or
honors conferred for some notable achievement.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>to rest on one's laurels</b></col> <mark>[fig.]</mark>
<cd>to be content with one's past achievements and not strive to
continue to excel; <as>as, he didn't <ex>rest on his laurels</ex> after
receiving the Nobel Prize, but went on to made even more significant
discoveries</as>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>laurel-tree</ent><br/
<hw>laurel-tree</hw> <pos>n.</pos> <def>A small tree (<spn>Persea
borbonia</spn>) of the Southern U. S. having dark red
heartwood.</def><br/
<syn><b>Syn. --</b> red bay, <spn>Persea borbonia</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laurentian</ent><br/
<hw>Lau*ren"tian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
near, the St. Lawrence River; <as>as, the <ex>Laurentian</ex>
hills</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Laurentian period</b></col> <fld>(Geol.)</fld>, <cd>the
lower of the two divisions of the Arch<ae/an age; -- called also
<altname>the Laurentian</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurer</ent><br/
<hw>Lau"rer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Laurel.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurestine</ent><br/
<hw>Lau"res*tine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. <ets>lautus
tinus</ets>, fr. L. <ets>laurus</ets> the laurel + <ets>tinus</ets>
laurestine. See <er>Laurel</er>.]</ety> <fld>(Bot.)</fld> <def>The
<spn>Viburnum Tinus</spn>, an evergreen shrub or tree of the south of
Europe, which flowers during the winter months.</def> <altsp>[Written
also <asp>laurustine</asp> and <asp>laurestina</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lauric</ent><br/
<hw>Lau"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Pertaining
to, or derived from, the European bay or laurel (<spn>Laurus
nobilis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>pertaining to or combined with <er>lauric acid</er>,
the 12-carbon member of the fatty acid series; combined with the acyl
group of lauric acid.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lauric acid</ent><br/
<hw>Lauric acid</hw> <fld>(Chem.)</fld>, <def>a white, crystalline
substance, <chform>CH3.(CH2)10.COOH</chform>, resembling palmitic acid,
and obtained from the fruit of the bay tree, and various other vegetable
sources. The sodium salt (<er>sodium lauryl sulfate</er>) is used as a
detergent.</def> <syn><b>Syn. --</b> dodecanoic acid, laurostearic acid,
dodecoic acid.</syn><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Lauriferous</ent><br/
<hw>Lau*rif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laurifer</ets>; <ets>laurus</ets> + <ets>ferre</ets> to
bear.]</ety> <def>Producing, or bringing, laurel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurin</ent><br/
<hw>Lau"rin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>laurine</ets>.]</ety> <fld>(Chem.)</fld> <def>A white crystalline
substance extracted from the fruit of the bay (<spn>Laurus
nobilis</spn>), and consisting of a complex mixture of glycerin ethers
of several organic acids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurinol</ent><br/
<hw>Lau"ri*nol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Laurin</ets>
+ <ets>-ol</ets>.]</ety> <fld>(Chem.)</fld> <def>Ordinary camphor; -- so
called in allusion to the family name (<fam>Laurace<ae/</fam>) of the
camphor trees. See <er>Camphor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lauriol</ent><br/
<hw>Lau"ri*ol</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Spurge laurel.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurite</ent><br/
<hw>Lau"rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Min.)</fld> <def>A rare sulphide of osmium and
ruthenium found with platinum in Borneo and Oregon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurone</ent><br/
<hw>Lau"rone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lauric</ets> +
<ets>-one</ets>.]</ety> <fld>(Chem.)</fld> <def>The ketone of lauric
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laurus</ent><br/
\'d8<hw>Lau"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
laurel.]</ety> <fld>(Bot.)</fld> <def>A genus of trees including,
according to modern authors, only the true laurel (<spn>Laurus
nobilis</spn>), and the larger <spn>Laurus Canariensis</spn> of Madeira
and the Canary Islands. Formerly the sassafras, the camphor tree, the
cinnamon tree, and several other aromatic trees and shrubs, were also
referred to the genus <gen>Laurus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laus</ent><br/
<hw>Laus</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Loose.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lautverschiebung</ent><br/
\'d8<hw>Laut"ver*schie`bung</hw>
<pr>(lout"f<ecr/r*sh<emac/`b<oocr/ng)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Lautverschiebungen</plw>
<pr>(lout"f<ecr/r*sh<emac/`b<oocr/ng*<eit/n)</pr></plu>. <ety>[G.;
<ets>laut</ets> sound + <ets>verschiebung</ets> shifting.]</ety>
<fld>(Philol.)</fld> <sd>(a)</sd> <def>The regular changes which the
primitive Indo-European stops, or mute consonants, underwent in the
Teutonic languages, probably as early as the 3d century <sc>b. c.</sc> ,
often called the <altname>first Lautverschiebung</altname>,
<altname>sound shifting</altname>, or <altname>consonant
shifting</altname>.</def> <sd>(b)</sd> <def>A somewhat similar set of
changes taking place in the High German dialects (less fully in modern
literary German) from the 6th to the 8th century, known as the
<altname>second Lautverschiebung</altname>, the results of which form
the striking differences between High German and The Low German
Languages. The statement of these changes is commonly regarded as
forming part of <er>Grimm's law</er>, because included in it as
originally framed.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>lav</ent><br/
<hw>lav</hw> <pos>n.</pos> <ety>[by truncation of
<ets>lav</ets>atory.]</ety> <def>Same as <er>lavatory</er>{5}; -- a
shortened form of the word.</def> <mark>[informal]</mark> <br/
<syn><b>Syn. --</b> toilet, lavatory, can, facility, john, privy,
bathroom.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lava</ent><br/
<hw>La"va</hw> <pr>(l<aum/"v<adot/; 277)</pr>, <pos>n.</pos> <ety>[It.
<ets>lava</ets> lava, orig. in Naples, a torrent of rain overflowing the
streets, fr. It. & L. <ets>lavare</ets> to wash. See
<er>Lave</er>.]</ety> <def>The melted rock ejected by a volcano from its
top or fissured sides. It flows out in streams sometimes miles in
length. It also issues from fissures in the earth's surface, and forms
beds covering many square miles, as in the Northwestern United
States.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Lavas are classed, according to their structure, as
scoriaceous or cellular, glassy, stony, etc., and according to the
material of which they consist, as doleritic, trachytic, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lava millstone</b></col>, <cd>a hard and coarse basaltic
millstone from the neighborhood of the Rhine.</cd> -- <col><b>Lava
ware</b></col>, <cd>a kind of cheap pottery made of iron slag cast into
tiles, urns, table tops, etc., resembling lava in
appearance.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lavalava</ent><br/
<hw>la`va*la"va</hw> <pr>(l<aum/`v<adot/*l<aum/"v<adot/)</pr>,
<pos>n.</pos> <def>A printed cloth garment resembling a skirt or kilt,
worn as the principle garment by both men and women in Polynesia,
especialy in Samoa; called also <altname>pareu</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>La valliere</ent><br/
<ent>lavallier</ent><br/
<ent>lavaliere</ent><br/
<mhw>{ <hw>la`va`liere"</hw>, <hw>la`val`lier"</hw>, or <hw>La
val`liere"</hw> }</mhw> <pr>(?)</pr>, <pos>n.</pos> <ety>[after the
<person>Duchesse de <ets>La Valliere</ets></person>, a mistress of
<person>Louis XI.</person> <au>RHUD</au>.]</ety> <def>A neck ornament
consisting of a chain and single jewelled pendant, or drop; also, the
pendant itself.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>lavaliere microphone</ent><br/
<hw>la`va`liere" mic"ro*phone</hw> <pos>n.</pos> <def>A small microphone
worn around the neck on a supporting string or chain.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lavandula</ent><br/
<hw>Lavandula</hw> <pos>n.</pos> <def>A genus of plants of the mint
family including the lavender{1}.</def><br/
<syn><b>Syn. --</b> genus <gen>Lavandula</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lavaret</ent><br/
<hw>Lav"a*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>A European whitefish (<spn>Coregonus
laveretus</spn>), found in the mountain lakes of Sweden, Germany, and
Switzerland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavatera</ent><br/
<hw>Lavatera</hw> <pos>n.</pos> <def>A widespread genus of herbs or
soft-wooded arborescent shrubs cultivated for their showy
flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Lavatera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 835 --></p>

<p><ent>Lavatic</ent><br/
<hw>La*vat"ic</hw> <pr>(l<adot/*v<acr/t"<icr/k)</pr>, <pos>a.</pos>
<def>Like lava, or composed of lava; lavic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavation</ent><br/
<hw>La*va"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lavatio</ets>: cf. OF. <ets>lavation</ets>.]</ety> <def>A washing
or cleansing.</def> <mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavatory</ent><br/
<hw>Lav"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Washing, or
cleansing by washing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavatory</ent><br/
<hw>Lav"a*to*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lavatories</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>lavatorium</ets>: cf. <ets>lavatoire</ets>. See <er>Lave</er> to
wash, and cf. <er>Laver</er>.]</ety> <sn>1.</sn> <def>A place for
washing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A basin or other vessel for washing in.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A wash or lotion for a diseased part.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A place where gold is obtained by washing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A room containing one or more sinks for washing, as
well as one or more toilet fixtures; also called
<altname>bathroom</altname>, <altname>toilet</altname>, and sometimes
<altname>commode</altname>. Commode and toilet may refer to a room with
only a toilet fixture, but without a sink.</def><br/
<syn><b>Syn. --</b> toilet, lavatory, can, facility, john, privy,
bathroom.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Lavature</ent><br/
<hw>Lav"a*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>A wash or
lotion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lave</ent><br/
<hw>Lave</hw> <pr>(l<amac/v)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Laved</conjf> <pr>(l<amac/vd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Laving</conjf>.]</vmorph> <ety>[F. <ets>laver</ets>, L.
<ets>lavare</ets>, akin to <ets>luere</ets> to wash, Gr. <?/. Cf.
<er>Ablution</er>, <er>Deluge</er>, <er>Lavender</er>, <er>Lava</er>,
<er>Lotion</er>.]</ety> <def>To wash; to bathe; <as>as, to <ex>lave</ex>
a bruise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His feet the foremost breakers <qex>lave</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lave</ent><br/
<hw>Lave</hw>, <pos>v. i.</pos> <def>To bathe; to wash one's
self.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In her chaste current oft the goddess <qex>laves</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lave</ent><br/
<hw>Lave</hw>, <pos>v. t.</pos> <ety>[OE. <ets>laven</ets>. See
<er>Lavish</er>.]</ety> <def>To lade, dip, or pour out.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lave</ent><br/
<hw>Lave</hw>, <pos>n.</pos> <ety>[AS. <ets>l<amac/f</ets> the
remainder, what is left. <root/119. See <er>Leave</er>.]</ety> <def>The
remainder; others.</def> <mark>[Scot.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lave-eared</ent><br/
<hw>Lave"-eared`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. W.
<ets>llaf</ets> that extends round, <ets>llipa</ets> flaccid, flapping,
G. <ets>lapp</ets> flabby, <ets>lappohr</ets> flap ear.]</ety>
<def>Having large, pendent ears.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laveer</ent><br/
<hw>La*veer"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[D.
<ets>laveren</ets>.]</ety> <fld>(Naut.)</fld> <def>To beat against the
wind; to tack.</def> <mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavement</ent><br/
<hw>Lave"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lavement</ets>, fr. <ets>laver</ets> to wash.]</ety> <def>A washing
or bathing; also, an enema.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavender</ent><br/
<hw>Lav"en*der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lavendre</ets>, F. <ets>lavande</ets>, It. <ets>lavanda</ets>
lavender, a washing, fr. L. <ets>lavare</ets> to wash; cf. It.
<ets>lsavendola</ets>, LL. <ets>lavendula</ets>. So called because it
was used in bathing and washing. See <er>Lave</er>. to wash, and cf.
<er>Lavender</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>An aromatic
plant of the genus <gen>Lavandula</gen> (<spn>Lavandula vera</spn>),
common in the south of Europe. It yields and oil used in medicine and
perfumery. The <stype>Spike lavender</stype> (<spn>Lavandula
Spica</spn>) yields a coarser oil (oil of spike), used in the
arts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The pale, purplish color of lavender flowers, paler
and more delicate than lilac.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lavender cotton</b></col> <fld>(Bot.)</fld>, <cd>a low,
twiggy, aromatic shrub (<spn>Santolina Cham<ae/cyparissus</spn>) of the
Mediterranean region, formerly used as a vermifuge, etc., and still used
to keep moths from wardrobes. Also called <altname>ground
cypress</altname>.</cd> -- <col><b>Lavender water</b></col>, <cd>a
perfume, toilet water, or shaving lotion containing the essential oil of
lavender, and sometimes the essential oil of bergamot, and essence of
ambergris.</cd> -- <col><b>Sea lavender</b></col>. <fld>(Bot.)</fld>
<cd>See <er>Marsh rosemary</er>.</cd> -- <col><b>To lay in
lavender</b></col>. <sd>(a)</sd> <cd>To lay away, as clothing, with
sprigs of lavender.</cd> <sd>(b)</sd> <cd>To pawn.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Laver</ent><br/
<hw>Lav"er</hw> <pr>(l<amac/"v<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lavour</ets>, F. <ets>lavoir</ets>, L. <ets>lavatorium</ets> a
washing place. See <er>Lavatory</er>.]</ety> <sn>1.</sn> <def>A vessel
for washing; a large basin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Script. Hist.)</fld> <sd>(a)</sd> <def>A large
brazen vessel placed in the court of the Jewish tabernacle where the
officiating priests washed their hands and feet.</def> <sd>(b)</sd>
<def>One of several vessels in Solomon's Temple in which the offerings
for burnt sacrifices were washed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which washes or cleanses.</def> <rj><au>J. H.
Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laver</ent><br/
<hw>Lav"er</hw>, <pos>n.</pos> <ety>[From <er>Lave</er> to wash.]</ety>
<def>One who laves; a washer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laver</ent><br/
<hw>La"ver</hw> <pr>(l<amac/"v<etil/r)</pr>, <pos>n.</pos> <def>The
fronds of certain marine alg<ae/ used as food, and for making a sauce
called laver sauce. Green <ex>laver</ex> is the <spn>Ulva
latissima</spn>; purple <ex>laver</ex>, <spn>Porphyra laciniata</spn>
and <spn>Porphyra vulgaris</spn>. It is prepared by stewing, either
alone or with other vegetables, and with various condiments; -- called
also <altname>sloke</altname>, or <altname>sloakan</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mountain laver</b></col> <fld>(Bot.)</fld>, <cd>a reddish
gelatinous alga of the genus <gen>Palmella</gen>, found on the sides of
mountains</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laverock</ent><br/
<hw>La"ver*ock</hw> <pr>(l<amac/"v<etil/r*<ocr/k)</pr>, <pos>n.</pos>
<ety>[See <er>Lark</er> the bird.]</ety> <def>The lark.</def> <mark>[Old
Eng. & Scot.]</mark> <altsp>[Written also <asp>lavrock</asp>.]</altsp>
<rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavic</ent><br/
<hw>La"vic</hw> <pr>(l<aum/"v<icr/k)</pr>, <pos>a.</pos> <def>See
<er>Lavatic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavish</ent><br/
<hw>Lav"ish</hw> <pr>(l<acr/v"<icr/sh)</pr>, <pos>a.</pos> <ety>[Akin to
E. <ets>lave</ets> to lade out; cf. AS. <ets>gelafian</ets> to refresh,
G. <ets>laben</ets>.]</ety> <sn>1.</sn> <def>Expending or bestowing
profusely; profuse; prodigal; <as>as, <ex>lavish</ex> of money;
<ex>lavish</ex> of praise.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Superabundant; excessive; <as>as, <ex>lavish</ex>
spirits</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let her have needful, but not <qex>lavish</qex>, means.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Profuse; prodigal; wasteful; extravagant;
exuberant; immoderate. See <er>Profuse</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavish</ent><br/
<hw>Lav"ish</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lavished</conjf> <pr>(-<icr/sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lavishing</conjf>.]</vmorph> <def>To expend or bestow with
profusion; to use with prodigality; to squander; <as>as, to
<ex>lavish</ex> money or praise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavisher</ent><br/
<hw>Lav"ish*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
lavishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavishly</ent><br/
<hw>Lav"ish*ly</hw>, <pos>adv.</pos> <def>In a lavish manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavishment</ent><br/
<hw>Lav"ish*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The act
of lavishing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavishness</ent><br/
<hw>Lav"ish*ness</hw>, <pos>n.</pos> <def>The quality or state of being
lavish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavoesium</ent><br/
\'d8<hw>La*v<oe/"si*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
<persfn><etsep>Lavoisier</etsep></persfn>, the celebrated French
chemist.]</ety> <fld>(Chem.)</fld> <def>A supposed new metallic element,
which was said to have been discovered in pyrites, and some other
minerals, and to be of a silver-white color, and malleable. It is not
currently (1998) a recognized element.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lavolta</ent><br/
<ent>Lavolt</ent><br/
<mhw>{ <hw>La*volt"</hw> <pr>(?)</pr>, <hw>La*vol"ta</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[It. <ets>la volta</ets> the turn, turning,
whirl. Cf. <er>Volt</er> of a horse, <er>Volta</er>.]</ety> <def>An old
dance, for two persons, being a kind of waltz, in which the woman made a
high spring or bound.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavoltateer</ent><br/
<hw>La*vol`ta*teer"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dancer of
the lavolta.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavour</ent><br/
<hw>Lav"our</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A laver.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lavrock</ent><br/
<hw>La"vrock</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Laverock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Law</ent><br/
<hw>Law</hw> <pr>(l<add/)</pr>, <pos>n.</pos> <ety>[OE. <ets>lawe</ets>,
<ets>laghe</ets>, AS. <ets>lagu</ets>, from the root of E.
<ets>lie</ets>: akin to OS. <ets>lag</ets>, Icel. <ets>l<oum/g</ets>,
Sw. <ets>lag</ets>, Dan. <ets>lov</ets>; cf. L. <ets>lex</ets>, E.
<ets>legal</ets>. A <ets>law</ets> is that which is <ets>laid</ets>,
set, or fixed; like <ets>statute</ets>, fr. L. <ets>statuere</ets> to
make to stand. See <er>Lie</er> to be prostrate.]</ety> <sn>1.</sn>
<def>In general, a rule of being or of conduct, established by an
authority able to enforce its will; a controlling regulation; the mode
or order according to which an agent or a power acts.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A law may be universal or particular, written or
unwritten, published or secret. From the nature of the highest laws a
degree of permanency or stability is always implied; but the power which
makes a law, or a superior power, may annul or change it.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>These are the statutes and judgments and <qex>laws</qex>, which
the Lord made.</q> <rj><qau>Lev. xxvi. 46.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>law</qex> of thy God, and the <qex>law</qex> of the
King.</q> <rj><qau>Ezra vii. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As if they would confine the Interminable . . . <br/
Who made our <qex>laws</qex> to bind us, not himself.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His mind his kingdom, and his will his <qex>law</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In morals: The will of God as the rule for the
disposition and conduct of all responsible beings toward him and toward
each other; a rule of living, conformable to righteousness; the rule of
action as obligatory on the conscience or moral nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The Jewish or Mosaic code, and that part of
Scripture where it is written, in distinction from the
<contr>gospel</contr>; hence, also, the Old Testament.</def>
<specif>Specifically:</specif> <def>the first five books of the bible,
called also <altname>Torah</altname>, <altname>Pentatech</altname>, or
<altname>Law of Moses</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>What things soever the <qex>law</qex> saith, it saith to them who
are under the <qex>law</qex> . . . But now the righteousness of God
without the <qex>law</qex> is manifested, being witnessed by the
<qex>law</qex> and the prophets.</q> <rj><qau>Rom. iii. 19, 21.
</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> In human government: <sd>(a)</sd> <def>An organic rule,
as a constitution or charter, establishing and defining the conditions
of the existence of a state or other organized community.</def>
<sd>(b)</sd> <def>Any edict, decree, order, ordinance, statute,
resolution, judicial, decision, usage, etc., or recognized, and
enforced, by the controlling authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>In philosophy and physics: A rule of being,
operation, or change, so certain and constant that it is conceived of as
imposed by the will of God or by some controlling authority; <as>as, the
<ex>law</ex> of gravitation; the <ex>laws</ex> of motion; the
<ex>law</ex> heredity; the <ex>laws</ex> of thought; the <ex>laws</ex>
of cause and effect; <ex>law</ex> of self-preservation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>In mathematics: The rule according to which
anything, as the change of value of a variable, or the value of the
terms of a series, proceeds; mode or order of sequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>In arts, works, games, etc.: The rules of
construction, or of procedure, conforming to the conditions of success;
a principle, maxim; or usage; <as>as, the <ex>laws</ex> of poetry, of
architecture, of courtesy, or of whist</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Collectively, the whole body of rules relating to
one subject, or emanating from one source; -- including usually the
writings pertaining to them, and judicial proceedings under them;
<as>as, divine <ex>law</ex>; English <ex>law</ex>; Roman <ex>law</ex>;
the <ex>law</ex> of real property; insurance
<ex>law</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Legal science; jurisprudence; the principles of
equity; applied justice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reason is the life of the <qex>law</qex>; nay, the common
<qex>law</qex> itself is nothing else but reason.</q>
<rj><qau>Coke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Law</qex> is beneficence acting by rule.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And sovereign <qex>Law</qex>, that state's collected will<br/
O'er thrones and globes elate,<br/
Sits empress, crowning good, repressing ill.</q> <rj><qau>Sir W.
Jones.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Trial by the laws of the land; judicial remedy;
litigation; <as>as, to go <ex>law</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When every case in <qex>law</qex> is right.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He found <qex>law</qex> dear and left it cheap.</q>
<rj><qau>Brougham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>An oath, as in the presence of a court.</def>
<mark>[Obs.]</mark> <see>See <cref>Wager of law</cref>, under
<er>Wager</er>.</see><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Avogadro's law</b></col> <fld>(Chem.)</fld>, <cd>a
fundamental conception, according to which, under similar conditions of
temperature and pressure, all gases and vapors contain in the same
volume the same number of ultimate molecules; -- so named after
<etsep>Avogadro</etsep>, an Italian scientist. Sometimes called
<altname>Amp<egrave/re's law</altname>.</cd> -- <col><b>Bode's
law</b></col> <fld>(Astron.)</fld>, <cd>an approximative empirical
expression of the distances of the planets from the sun, as follows: --
</cd></p>

<p><table><pre>
<row>Mer. Ven. Earth. Mars.  Aste.  Jup.  Sat.  Uran.   Nep.</row>
<row> 4    4     4     4      4      4     4      4      4</row>
<row> 0    3     6    12     24     48    96     192   384</row>
<row> --   --   --    --     --     --    --     ---   ---</row>
<row> 4    7    10    16     28     52   100     196   388</row>
<row> 5.9  7.3  10    15.2   27.4   52    95.4   192   300</row>
</pre></table></p>

<p><cd>where each distance (line third) is the sum of 4 and a multiple of 3
by the series 0, 1, 2, 4, 8, etc., the true distances being given in the
lower line.</cd> -- <col><b>Boyle's law</b></col> <fld>(Physics)</fld>,
<cd>an expression of the fact, that when an elastic fluid is subjected
to compression, and kept at a constant temperature, the product of the
pressure and volume is a constant quantity, <it>i. e.</it>, the volume
is inversely proportioned to the pressure; -- known also as
<altname>Mariotte's law</altname>, and the <altname>law of Boyle and
Mariotte</altname>.</cd> -- <col><b>Brehon laws</b></col>. <cd>See under
<er>Brehon</er>.</cd> -- <col><b>Canon law</b></col>, <cd>the body of
ecclesiastical law adopted in the Christian Church, certain portions of
which (for example, the law of marriage as existing before the Council
of Tent) were brought to America by the English colonists as part of the
common law of the land.</cd> <au>Wharton.</au> -- <col><b>Civil
law</b></col>, <cd>a term used by writers to designate Roman law, with
modifications thereof which have been made in the different countries
into which that law has been introduced. The civil law, instead of the
<contr>common law</contr>, prevails in the State of Louisiana.</cd>
<au>Wharton.</au> -- <col><b>Commercial law</b></col>. <cd>See <cref>Law
merchant</cref> (below).</cd> -- <col><b>Common law</b></col>. <cd>See
under <er>Common</er>.</cd> -- <col><b>Criminal law</b></col>, <cd>that
branch of jurisprudence which relates to crimes.</cd> --
<col><b>Ecclesiastical law</b></col>. <cd>See under
<er>Ecclesiastical</er>.</cd> -- <col><b>Grimm's law</b></col>
<fld>(Philol.)</fld>, <cd>a statement (propounded by the German
philologist <person>Jacob <etsep>Grimm</etsep></person>) of certain
regular changes which the primitive Indo-European mute consonants,
so-called (most plainly seen in Sanskrit and, with some changes, in
Greek and Latin), have undergone in the Teutonic languages. Examples:
Skr. <xex>bh</xex><amac/t<rsdot/, L. <xex>f</xex>rater, E.
<xex>b</xex>rother, G. <xex>b</xex>ruder; L. <xex>t</xex>res, E.
<xex>th</xex>ree, G. <xex>dr</xex>ei, Skr. <xex>g</xex>o, E.
<xex>c</xex>ow, G. <xex>k</xex>uh; Skr. <xex>dh</xex><amac/ to put, Gr.
<grk>ti-qe`-nai</grk>, E. <xex>d</xex>o, OHG, <xex>t</xex>uon, G.
<xex>th</xex>un. See also <er>lautverschiebung</er>.</cd> --
<col><b>Kepler's laws</b></col> <fld>(Astron.)</fld>, <cd>three
important laws or expressions of the order of the planetary motions,
discovered by John <etsep>Kepler</etsep>. They are these: (1) The orbit
of a planet with respect to the sun is an ellipse, the sun being in one
of the foci. (2) The areas swept over by a vector drawn from the sun to
a planet are proportioned to the times of describing them. (3) The
squares of the times of revolution of two planets are in the ratio of
the cubes of their mean distances.</cd> -- <col><b>Law
binding</b></col>, <cd>a plain style of leather binding, used for law
books; -- called also <altname>law calf</altname>.</cd> -- <col><b>Law
book</b></col>, <cd>a book containing, or treating of, laws.</cd> --
<col><b>Law calf</b></col>. <cd>See <cref>Law binding</cref>
(above).</cd> -- <col><b>Law day</b></col>. <sd>(a)</sd> <cd>Formerly, a
day of holding court, esp. a court-leet.</cd> <sd>(b)</sd> <cd>The day
named in a mortgage for the payment of the money to secure which it was
given.</cd> <mark>[U. S.]</mark> -- <col><b>Law French</b></col>,
<cd>the dialect of Norman, which was used in judicial proceedings and
law books in England from the days of <person>William the
Conqueror</person> to the thirty-sixth year of Edward III.</cd> --
<col><b>Law language</b></col>, <cd>the language used in legal writings
and forms.</cd> -- <col><b>Law Latin</b></col>. <cd>See under
<er>Latin</er>.</cd> -- <col><b>Law lords</b></col>, <cd>peers in the
British Parliament who have held high judicial office, or have been
noted in the legal profession.</cd> -- <mcol><col><b>Law
merchant</b></col>, <it>or</it> <col><b>Commercial law</b></col></mcol>,
<cd>a system of rules by which trade and commerce are regulated; --
deduced from the custom of merchants, and regulated by judicial
decisions, as also by enactments of legislatures.<-- now in most state
superseded by the Uniform Commercial Code --></cd> -- <col><b>Law of
Charles</b></col> <fld>(Physics)</fld>, <cd>the law that the volume of a
given mass of gas increases or decreases, by a definite fraction of its
value for a given rise or fall of temperature; -- sometimes less
correctly styled <altname>Gay Lussac's law</altname>, or
<altname>Dalton's law</altname>.</cd> -- <col><b>Law of
nations</b></col>. <cd>See <cref>International law</cref>, under
<er>International</er>.</cd> -- <col><b>Law of nature</b></col>.
<sd>(a)</sd> <cd>A broad generalization expressive of the constant
action, or effect, of natural conditions; <as>as, death is a <ex>law of
nature</ex>; self-defense is a <ex>law of nature</ex></as>. See
<er>Law</er>, 4.</cd> <sd>(b)</sd> <cd>A term denoting the standard, or
system, of morality deducible from a study of the nature and natural
relations of human beings independent of supernatural revelation or of
municipal and social usages.</cd> -- <col><b>Law of the land</b></col>,
<cd>due process of law; the general law of the land.</cd> --
<col><b>Laws of honor</b></col>. <cd>See under <er>Honor</er>.</cd> --
<col><b>Laws of motion</b></col> <fld>(Physics)</fld>, <cd>three laws
defined by <person>Sir Isaac Newton</person>: (1) Every body perseveres
in its state of rest or of moving uniformly in a straight line, except
so far as it is made to change that state by external force. (2) Change
of motion is proportional to the impressed force, and takes place in the
direction in which the force is impressed. (3) Reaction is always equal
and opposite to action, that is to say, the actions of two bodies upon
each other are always equal and in opposite directions.</cd> --
<mcol><col><b>Marine law</b></col>, <it>or</it> <col><b>Maritime
law</b></col></mcol>, <cd>the law of the sea; a branch of the law
merchant relating to the affairs of the sea, such as seamen, ships,
shipping, navigation, and the like.</cd> <au>Bouvier.</au> --
<col><b>Mariotte's law</b></col>. <cd>See <cref>Boyle's law</cref>
(above).</cd> -- <col><b>Martial law</b></col>.<cd>See under
<er>Martial</er>.</cd> -- <col><b>Military law</b></col>, <cd>a branch
of the general municipal law, consisting of rules ordained for the
government of the military force of a state in peace and war, and
administered in courts martial.</cd> <au>Kent.</au> <au>Warren's
Blackstone.</au> -- <col><b>Moral law</b></col>, <cd>the law of duty as
regards what is right and wrong in the sight of God; specifically, the
ten commandments given by Moses. See <er>Law</er>, 2.</cd> --
<mcol><col><b>Mosaic law</b></col>, <it>or</it> <col><b>Ceremonial
law</b></col></mcol>. <fld>(Script.)</fld> <cd>See <er>Law</er>, 3.</cd>
-- <mcol><col><b>Municipal law</b></col>, <it>or</it> <col><b>Positive
law</b></col></mcol>, <cd>a rule prescribed by the supreme power of a
state, declaring some right, enforcing some duty, or prohibiting some
act; -- distinguished from <contr>international law</contr> and
<contr>constitutional law</contr>. See <er>Law</er>, 1.</cd> --
<col><b>Periodic law</b></col>. <fld>(Chem.)</fld> <cd>See under
<er>Periodic</er>.</cd> -- <col><b>Roman law</b></col>, <cd>the system
of principles and laws found in the codes and treatises of the lawmakers
and jurists of ancient Rome, and incorporated more or less into the laws
of the several European countries and colonies founded by them. See
<cref>Civil law</cref> (above).</cd> -- <col><b>Statute law</b></col>,
<cd>the law as stated in statutes or positive enactments of the
legislative body.</cd> -- <col><b>Sumptuary law</b></col>. <cd>See under
<er>Sumptuary</er>.</cd> -- <col><b>To go to law</b></col>, <cd>to seek
a settlement of any matter by bringing it before the courts of law; to
sue or prosecute some one.</cd> -- <mcol><col><b>To take the law
of</b></col>, <it>or</it> <col><b>To have the law of</b></col></mcol>,
<cd>to bring the law to bear upon; <as>as, <ex>to take the law of</ex>
one's neighbor</as>.</cd> <au>Addison.</au> -- <col><b>Wager of
law</b></col>. <cd>See under <er>Wager</er>.</cd></p></cs>

<p><syn><b>Syn.</b> -- Justice; equity.</syn> <usage> -- <er>Law</er>,
<er>Statute</er>, <er>Common law</er>, <er>Regulation</er>,
<er>Edict</er>, <er>Decree</er>. <xex>Law</xex> is generic, and, when
used with reference to, or in connection with, the other words here
considered, denotes whatever is commanded by one who has a right to
require obedience. A <xex>statute</xex> is a particular law drawn out in
form, and distinctly enacted and proclaimed. <xex>Common law</xex> is a
rule of action founded on long usage and the decisions of courts of
justice. A <xex>regulation</xex> is a limited and often, temporary law,
intended to secure some particular end or object. An <xex>edict</xex> is
a command or law issued by a sovereign, and is peculiar to a despotic
government. A <xex>decree</xex> is a permanent order either of a court
or of the executive government. See <er>Justice</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Law</ent><br/
<hw>Law</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Same as <er>Lawe</er>,
<pos>v. t.</pos></def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Law</ent><br/
<hw>Law</hw>, <pos>interj.</pos> <ety>[Cf. <er>La</er>.]</ety> <def>An
exclamation of mild surprise.</def> <mark>[Archaic or Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Law-abiding</ent><br/
<hw>Law"-a*bid`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abiding the
law; waiting for the operation of law for the enforcement of rights;
also, abiding by the law; obedient to the law; <as>as,
<ex>law-abiding</ex> people</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>law-breaking</ent><br/
<hw>law-breaking</hw> <pos>n.</pos> <sn>1.</sn> <def>an act punishable
by law; usually considered an evil act.</def><br/
<syn><b>Syn. --</b> crime.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>law-breaker</ent><br/
<ent>lawbreaker</ent><br/
<mhw><hw>law"break`er</hw>, <hw>law"-break`er</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>One who disobeys the law; someone who violates the
law; a criminal.</def><br/
<syn><b>Syn. --</b> violator, lawbreaker, law breaker,
perpetrator.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p> -- <wordforms><wf>Law"break`ing</wf>, <pos>n. &
a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawe</ent><br/
<hw>Lawe</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See 2d
<er>Lawing</er>.]</ety> <def>To cut off the claws and balls of, as of a
dog's fore feet.</def> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawer</ent><br/
<hw>Law"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lawyer.</def>
<mark>[Obs.]</mark> <rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawful</ent><br/
<hw>Law"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Conformable to law; allowed by law; legitimate;
competent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Constituted or authorized by law; rightful; <as>as,
the <ex>lawful</ex> owner of lands</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lawful age</b></col>, <cd>the age when the law recognizes
one's right of independent action; majority; -- generally the age of
twenty-one years. Also called <altname>legal age</altname> or
<altname>age of majority</altname>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ In some of the States, and for some purposes, a woman
attains <xex>lawful age</xex> at eighteen. <au>Abbott.</au></note></p>

<p><syn><b>Syn.</b> -- Legal; constitutional; allowable; regular;
rightful.</syn> <usage> -- <er>Lawful</er>, <er>Legal</er>.
<xex>Lawful</xex> means conformable to the principle, spirit, or essence
of the law, and is applicable to moral as well as juridical law.
<xex>Legal</xex> means conformable to the letter or rules of the law as
it is administered in the courts; conformable to juridical law.
<xex>Legal</xex> is often used as antithetical to <xex>equitable</xex>,
but <xex>lawful</xex> is seldom used in that sense.</usage></p>

<p>-- <wordforms><wf>Law"ful*ly</wf>, <pos>adv.</pos> --
<wf>Law"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lawfully-begotten</ent><br/
<hw>lawfully-begotten</hw> <pos>adj.</pos> <def>born in wedlock;
legitimate; enjoying full filial rights; not illegitimate; -- of
people.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lawgiver</ent><br/
<hw>Law"giv`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes or
enacts a law or system of laws; a legislator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawgiving</ent><br/
<hw>Law"giv`ing</hw>, <pos>a.</pos> <def>Enacting laws;
legislative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawing</ent><br/
<hw>Law"ing</hw>, <pos>n.</pos> <def>Going to law; litigation.</def>
<rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawing</ent><br/
<hw>Law"ing</hw>, <pos>n.</pos> <ety>[So called because done in
compliance with an English forest <ets>law</ets>.]</ety>
<def>Expeditation.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawless</ent><br/
<hw>Law"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Contrary to, or
unauthorized by, law; illegal; <as>as, a <ex>lawless</ex>
claim</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He needs no indirect nor <qex>lawless</qex> course.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not subject to, or restrained by, the law of
morality or of society; <as>as, <ex>lawless</ex> men or
behavior</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not subject to the laws of nature;
uncontrolled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Or, meteorlike, flame <qex>lawless</qex> through the void.</q>
<rj><qau>Pope.</qau></rj></p>

<p>-- <wordforms><wf>Law"less*ly</wf>, <pos>adv.</pos> --
<wf>Law"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawmaker</ent><br/
<hw>Law"mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A legislator; a
lawgiver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>law-makers</ent><br/
<hw>law-makers</hw> <pos>n. pl.</pos> <def>Those persons who make or
amend or repeal laws, collectively.</def><br/
<syn><b>Syn. --</b> legislature, legislative assembly, general
assembly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 836 --></p>

<p><ent>Lawmaking</ent><br/
<hw>Law"mak`ing</hw> <pr>(l<add/"m<amac/`k<icr/ng)</pr>, <pos>a.</pos>
<def>Enacting laws; legislative.</def> -- <def2><pos>n.</pos> <def>The
enacting of laws; legislation.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawmonger</ent><br/
<hw>Law"mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A trader in law;
one who practices law as if it were a trade.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawn</ent><br/
<hw>Lawn</hw> <pr>(l<add/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>laund</ets>, <ets>launde</ets>, F. <ets>lande</ets> heath, moor; of
Celtic origin; cf. W. <ets>llan</ets> an open, clear place,
<ets>llawnt</ets> a smooth rising hill, lawn, Armor. <ets>lann</ets> or
<ets>lan</ets> territory, country, <ets>lann</ets> a prickly plant, pl.
<ets>lannou</ets> heath, moor.]</ety> <sn>1.</sn> <def>An open space
between woods.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Orchard <qex>lawns</qex> and bowery hollows.<rdquo/</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ground (generally in front of or around a house)
covered with grass kept closely mown.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lawn mower</b></col>, <cd>a machine for clipping the
short grass of lawns.</cd> -- <col><b>Lawn tennis</b></col>, <cd>a
variety of the game of tennis, played in the open air, sometimes upon a
lawn, instead of in a tennis court. See <er>Tennis</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawn</ent><br/
<hw>Lawn</hw>, <pos>n.</pos> <ety>[Earlier <ets>laune lynen</ets>, i.
e., <ets>lawn linen</ets>; prob. from the town <ets>Laon</ets> in
France.]</ety> <def>A very fine linen (or sometimes cotton) fabric with
a rather open texture. Lawn is used for the sleeves of a bishop's
official dress in the English Church, and, figuratively, stands for the
office itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A saint in crape is twice a saint in <qex>lawn</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawnd</ent><br/
<hw>Lawnd</hw> <pr>(l<add/nd)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Laund</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawny</ent><br/
<hw>Lawn"y</hw> <pr>(l<add/n"<ycr/)</pr>, <pos>a.</pos> <def>Having a
lawn; characterized by a lawn or by lawns; like a lawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Musing through the <qex>lawny</qex> park.</q> <rj><qau>T.
Warton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawny</ent><br/
<hw>Lawn"y</hw>, <pos>a.</pos> <def>Made of lawn or fine linen.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lawrencium</ent><br/
<hw>lawrencium</hw> <pos>n.</pos> <ety>[from <person>Ernest O.
<etsep>Lawrence</etsep></person>, inventer of the cyclotron.]</ety>
<def>A transuranic element of atomic number 103. It was discovered in
1961 by bombardment of californium in a cyclotron with boron nuclei.
Other isotopes were prepared in 1965 at Dubna. The atomic weight of the
most stable isotope is 256, having a half-life of 35 seconds. Symbol
Lr.</def> <au>HCP61</au><br/
<syn><b>Syn. --</b> Lr.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laws</ent><br/
<hw>Laws</hw> <pos>n.</pos> <def>the first five books of the Old
Testament, also called <altname>The Law</altname> and
<altname>Torah</altname>.</def><br/
<syn><b>Syn. --</b> Pentateuch, Law of Moses, Torah.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lawsonia</ent><br/
<hw>Law*so"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An Asiatic and North African shrub (<spn>Lawsonia inermis</spn>),
with smooth oval leaves, and fragrant white flowers. <prod>Henna</prod>
is prepared from the leaves and twigs. In England the shrub is called
<altname>Egyptian privet</altname>, and in the West Indies,
<altname>Jamaica mignonette</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawsuit</ent><br/
<hw>Law"suit`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An action at law; a
suit in equity or admiralty; any legal proceeding before a court for the
enforcement of a claim.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lawyer</ent><br/
<hw>Law"yer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Law</er>,
like <ets>bowyer</ets>, fr. <ets>bow</ets>.]</ety> <sn>1.</sn> <def>One
versed in the laws, or a practitioner of law; one whose profession is to
conduct lawsuits for clients, or to advise as to prosecution or defence
of lawsuits, or as to legal rights and obligations in other matters. It
is a general term, comprehending attorneys, counselors, solicitors,
barristers, sergeants, and advocates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The black-necked
stilt. See <er>Stilt</er>.</def> <sd>(b)</sd> <def>The bowfin (<spn>Amia
calva</spn>).</def> <sd>(c)</sd> <def>The burbot (<spn>Lota
maculosa</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Philadelphia lawyer</b></col>, <cd>A lawyer knowledgeable
about the most detailed and minute points of law, especially one with an
exceptional propensity and ability to exploit fine technical points of
law for the client's advantage.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>lawyerbush</ent><br/
<hw>lawyerbush</hw> <pos>n.</pos> <def>A stout-stemmed trailing shrub
(<spn>Rubus cissoides</spn>) of New Zealand that scrambles over other
growth.</def><br/
<syn><b>Syn. --</b> lawyer bush, bush lawyer, <spn>Rubus
cissoides</spn>, <spn>Rubus australis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lawyerly</ent><br/
<ent>Lawyerlike</ent><br/
<mhw>{ <hw>Law"yer*like`</hw> <pr>(?)</pr>, <hw>Law"yer*ly</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Like, or becoming, a lawyer;
<as>as, <ex>lawyerlike</ex> sagacity</as>.</def>
<ldquo/<xex>Lawyerly</xex> mooting of this point.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lax</ent><br/
<hw>Lax</hw> <pr>(l<acr/ks)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Laxer</adjf>
<pr>(l<acr/ks"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Laxest</adjf>.]</amorph> <ety>[L. <ets>laxus</ets> Cf.
<er>Laches</er>, <er>Languish</er>, <er>Lease</er>, <pos>v. t.</pos>,
<er>Leash</er>.]</ety> <sn>1.</sn> <def>Not tense, firm, or rigid;
loose; slack; <as>as, a <ex>lax</ex> bandage; <ex>lax</ex>
fiber.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The flesh of that sort of fish being <qex>lax</qex> and
spongy.</q> <rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not strict or stringent; not exact; loose; weak;
vague; equivocal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The discipline was <qex>lax</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Society at that epoch was lenient, if not <qex>lax</qex>, in
matters of the passions.</q> <rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The word <ldquo/<ae/ternus<rdquo/ itself is sometimes of a
<qex>lax</qex> signification.</q> <rj><qau>Jortin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having a looseness of the bowels;
diarrheal.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Loose; slack; vague; unconfined; unrestrained;
dissolute; licentious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lax</ent><br/
<hw>Lax</hw>, <pos>n.</pos> <def>A looseness; diarrhea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxation</ent><br/
<hw>Lax*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>laxatio</ets>, fr. <ets>laxare</ets> to loosen, fr.
<ets>laxus</ets> loose, slack.]</ety> <def>The act of loosening or
slackening, or the state of being loosened or slackened.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxative</ent><br/
<hw>Lax"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>laxativus</ets> mitigating, assuaging: cf. F. <ets>laxatif</ets>.
See <er>Lax</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>Having a
tendency to loosen or relax.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Having the effect of loosening or
opening the intestines, and relieving from constipation; -- opposed to
<contr>astringent</contr>.</def> -- <def2><pos>n.</pos>
<fld>(Med.)</fld> <def>A laxative medicine. See the Note under
<er>Cathartic</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxativeness</ent><br/
<hw>Lax"a*tive*ness</hw>, <pos>n.</pos> <def>The quality of being
laxative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxator</ent><br/
\'d8<hw>Lax*a"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>laxare</ets>, <ets>laxatum</ets>, to loosen.]</ety>
<fld>(Anat.)</fld> <def>That which loosens; -- esp., a muscle which by
its contraction loosens some part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxity</ent><br/
<hw>Lax"i*ty</hw> <pr>(l<acr/ks"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<ety>[L. <ets>laxitas</ets>, fr. <ets>laxus</ets> loose, slack: cf. F.
<ets>laxit<eacute/</ets>, See <er>Lax</er>, <pos>a.</pos>]</ety>
<def>The state or quality of being lax; lack of tenseness, strictness,
or exactness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxly</ent><br/
<hw>Lax"ly</hw>, <pos>adv.</pos> <def>In a lax manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laxness</ent><br/
<hw>Lax"ness</hw>, <pos>n.</pos> <def>The state of being lax;
laxity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of <er>Lie</er>, to
recline.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw>, <pos>a.</pos> <ety>[F. <ets>lai</ets>, L.
<ets>laicus</ets>, Gr. <?/ of or from the people, lay, from <?/, <?/,
people. Cf. <er>Laic</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to
the laity, as distinct from the clergy; <as>as, a <ex>lay</ex> person; a
<ex>lay</ex> preacher; a <ex>lay</ex> brother.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not educated or cultivated; ignorant.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not belonging to, or emanating from, a particular
profession; unprofessional; <as>as, a <ex>lay</ex> opinion regarding the
nature of a disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lay baptism</b></col> <fld>(Eccl.)</fld>, <cd>baptism
administered by a lay person.</cd> <au>F. G. Lee.</au> -- <col><b>Lay
brother</b></col> <fld>(R. C. Ch.)</fld>, <cd>one received into a
convent of monks under the three vows, but not in holy orders.</cd> --
<col><b>Lay clerk</b></col> <fld>(Eccl.)</fld>, <cd>a layman who leads
the responses of the congregation, etc., in the church service.</cd>
<au>Hook.</au> -- <col><b>Lay days</b></col> <fld>(Com.)</fld>, <cd>time
allowed in a charter party for taking in and discharging cargo.</cd>
<au>McElrath.</au> -- <col><b>Lay elder</b></col>. <cd>See 2d
<er>Elder</er>, 3, note.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The laity; the common
people.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The learned have no more privilege than the <qex>lay</qex>.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw>, <pos>n.</pos> <def>A meadow. See <er>Lea</er>.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw>, <pos>n.</pos> <ety>[OF. <ets>lei</ets> faith, law, F.
<ets>loi</ets> law. See <er>Legal</er>.]</ety> <sn>1.</sn> <def>Faith;
creed; religious profession.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of the sect to which that he was born<br/
He kept his <qex>lay</qex>, to which that he was sworn.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A law.</def> <mark>[Obs.]</mark> <ldquo/Many goodly
<xex>lays</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An obligation; a vow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They bound themselves by a sacred <qex>lay</qex> and oath.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF. <ets>lai</ets>,
<ets>lais</ets>, prob. of Celtic origin; cf. Ir. <ets>laoi</ets>,
<ets>laoidh</ets>, song, poem, OIr. <ets>laoidh</ets> poem, verse; but
cf. also AS. <ets>l<amac/c</ets> play, sport, G. <ets>leich</ets> a sort
of poem (cf. <er>Lake</er> to sport). <?/.]</ety> <sn>1.</sn> <def>A
song; a simple lyrical poem; a ballad.</def> <rj><au>Spenser. Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A melody; any musical utterance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The throstle cock made eke his <qex>lay</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw> <pr>(l<amac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Laid</conjf> <pr>(l<amac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Laying</conjf>.]</vmorph> <ety>[OE. <ets>leggen</ets>,
AS. <ets>lecgan</ets>, causative, fr. <ets>licgan</ets> to lie; akin to
D. <ets>leggen</ets>, G. <ets>legen</ets>, Icel. <ets>leggja</ets>,
Goth. <ets>lagjan</ets>. See <er>Lie</er> to be prostrate.]</ety>
<sn>1.</sn> <def>To cause to lie down, to be prostrate, or to lie
against something; to put or set down; to deposit; <as>as, to
<ex>lay</ex> a book on the table; to <ex>lay</ex> a body in the grave; a
shower <ex>lays</ex> the dust.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A stone was brought, and <qex>laid</qex> upon the mouth of the
den.</q> <rj><qau>Dan. vi. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Soft on the flowery herb I found me <qex>laid</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place in position; to establish firmly; to
arrange with regularity; to dispose in ranks or tiers; <as>as, to
<ex>lay</ex> a corner stone; to <ex>lay</ex> bricks in a wall; to
<ex>lay</ex> the covers on a table.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To prepare; to make ready; to contrive; to provide;
<as>as, to <ex>lay</ex> a snare, an ambush, or a plan</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To spread on a surface; <as>as, to <ex>lay</ex>
plaster or paint</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To cause to be still; to calm; to allay; to
suppress; to exorcise, as an evil spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After a tempest when the winds are <qex>laid</qex>.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To cause to lie dead or dying.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Brave C<ae/neus <qex>laid</qex> Ortygius on the plain,<br/
The victor C<ae/neus was by Turnus slain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To deposit, as a wager; to stake; to risk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I dare <qex>lay</qex> mine honor<br/
He will remain so.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To bring forth and deposit; <as>as, to <ex>lay</ex>
eggs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To apply; to put.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>layeth</qex> her hands to the spindle.</q> <rj><qau>Prov.
xxxi. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To impose, as a burden, suffering, or punishment;
to assess, as a tax; <as>as, to <ex>lay</ex> a tax on
land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord hath <qex>laid</qex> on him the iniquity of us all.</q>
<rj><qau>Is. liii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To impute; to charge; to allege.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>layeth</qex> not folly to them.</q> <rj><qau>Job xxiv.
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lay</qex> the fault on us.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To impose, as a command or a duty; <as>as, to
<ex>lay</ex> commands on one</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>To present or offer; <as>as, to <ex>lay</ex> an
indictment in a particular county; to <ex>lay</ex> a scheme before
one.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Law)</fld> <def>To state; to allege; <as>as, to
<ex>lay</ex> the venue</as>.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <fld>(Mil.)</fld> <def>To point; to aim; <as>as, to
<ex>lay</ex> a gun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <fld>(Rope Making)</fld> <def>To put the strands of (a
rope, a cable, etc.) in their proper places and twist or unite them;
<as>as, to <ex>lay</ex> a cable or rope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <fld>(Print.)</fld> <sd>(a)</sd> <def>To place and
arrange (pages) for a form upon the imposing stone.</def> <sd>(b)</sd>
<def>To place (new type) properly in the cases.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To lay asleep</b></col>, <cd>to put sleep; to make
unobservant or careless.</cd> <au>Bacon.</au> -- <col><b>To lay
bare</b></col>, <cd>to make bare; to strip.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>laid</qex> those proud roofs <qex>bare</qex> to summer's
rain.</q> <rj><qau>Byron.</qau></rj></p>

<p>-- <col><b>To lay before</b></col>, <cd>to present to; to submit for
consideration; <as>as, the papers are <ex>laid before</ex>
Congress</as>.</cd> -- <col><b>To lay by</b></col>. <sd>(a)</sd> <cd>To
save.</cd> <sd>(b)</sd> <cd>To discard.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Let brave spirits . . . not be <qex>laid by</qex>.</q>
<rj><qau>Bacon.</qau></rj></p>

<p>-- <col><b>To lay by the heels</b></col>, <cd>to put in the
stocks.</cd> <au>Shak.</au> -- <col><b>To lay down</b></col>.
<sd>(a)</sd> <cd>To stake as a wager.</cd> <sd>(b)</sd> <cd>To yield; to
relinquish; to surrender; <as>as, to <ex>lay down</ex> one's life; to
<ex>lay down</ex> one's arms</as>.</cd> <sd>(c)</sd> <cd>To assert or
advance, as a proposition or principle.</cd> -- <col><b>To lay
forth</b></col>. <sd>(a)</sd> <cd>To extend at length; (reflexively) to
exert one's self; to expatiate.</cd> <mark>[Obs.]</mark> <sd>(b)</sd>
<cd>To lay out (as a corpse).</cd> <mark>[Obs.]</mark> <au>Shak.</au> --
<col><b>To lay hands on</b></col>, <cd>to seize.</cd> --
<mcol><col><b>To lay hands on one's self</b></col>, or <col><b>To lay
violent hands on one's self</b></col></mcol>, <cd>to injure one's self;
specif., to commit suicide.</cd> -- <col><b>To lay heads
together</b></col>, <cd>to consult.</cd> -- <mcol><col><b>To lay hold
of</b></col>, <it>or</it> <col><b>To lay hold on</b></col></mcol>,
<cd>to seize; to catch.</cd> -- <col><b>To lay in</b></col>, <cd>to
store; to provide.</cd> -- <col><b>To lay it on</b></col>, <cd>to apply
without stint.</cd> <au>Shak.</au> -- <col><b>To lay it on
thick</b></col>, <cd>to flatter excessively.</cd> -- <col><b>To lay
on</b></col>, <cd>to apply with force; to inflict; <as>as, <ex>to lay
on</ex> blows</as>.</cd> -- <col><b>To lay on load</b></col>, <cd>to lay
on blows; to strike violently.</cd> <mark>[Obs. <or/ Archaic]</mark> --
<col><b>To lay one's self out</b></col>, <cd>to strive
earnestly.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>No selfish man will be concerned <qex>to lay out himself</qex> for
the good of his country.</q> <rj><qau>Smalridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To lay one's self open to</b></col>, <cd>to expose one's
self to, as to an accusation.</cd> -- <col><b>To lay open</b></col>,
<cd>to open; to uncover; to expose; to reveal.</cd> -- <col><b>To lay
over</b></col>, <cd>to spread over; to cover.</cd> -- <col><b>To lay
out</b></col>. <sd>(a)</sd> <cd>To expend.</cd> <au>Macaulay.</au>
<sd>(b)</sd> <cd>To display; to discover.</cd> <sd>(c)</sd> <cd>To plan
in detail; to arrange; as, <xex>to lay out</xex> a garden.</cd>
<sd>(d)</sd> <cd>To prepare for burial; <as>as, <ex>to lay out</ex> a
corpse</as>.</cd> <sd>(e)</sd> <cd>To exert; <as>as, <ex>to lay out</ex>
all one's strength</as>.</cd> -- <col><b>To lay siege to</b></col>.
<sd>(a)</sd> <cd>To besiege; to encompass with an army.</cd>
<sd>(b)</sd> <cd>To beset pertinaciously.</cd> -- <col><b>To lay the
course</b></col> <fld>(Naut.)</fld>, <cd>to sail toward the port
intended without jibing.</cd> -- <col><b>To lay the land</b></col>
<fld>(Naut.)</fld>, <cd>to cause it to disappear below the horizon, by
sailing away from it.</cd> -- <col><b>To lay to</b></col> <sd>(a)</sd>
<cd>To charge upon; to impute.</cd> <sd>(b)</sd> <cd>To apply with
vigor.</cd> <sd>(c)</sd> <cd>To attack or harass.</cd>
<mark>[Obs.]</mark> <au>Knolles.</au> <sd>(d)</sd> <fld>(Naut.)</fld>
<cd>To check the motion of (a vessel) and cause it to be
stationary.</cd> -- <col><b>To lay to heart</b></col>, <cd>to feel
deeply; to consider earnestly.</cd> -- <col><b>To lay under</b></col>,
<cd>to subject to; <as>as, <ex>to lay under</ex> obligation or
restraint</as>.</cd> -- <col><b>To lay unto</b></col>. <sd>(a)</sd>
<cd>Same as <cref>To lay to</cref> (above).</cd> <sd>(b)</sd> <cd>To put
before.</cd> <au>Hos. xi. 4.</au> -- <col><b>To lay up</b></col>.
<sd>(a)</sd> <cd>To store; to reposit for future use.</cd> <sd>(b)</sd>
<cd>To confine; to disable.</cd> <sd>(c)</sd> <cd>To dismantle, and
retire from active service, as a ship.</cd> -- <col><b>To lay wait
for</b></col>, <cd>to lie in ambush for.</cd> -- <col><b>To lay
waste</b></col>, <cd>to destroy; to make desolate; <as>as, <ex>to lay
waste</ex> the land</as>.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- See <er>Put</er>, <pos>v. t.</pos>, and the Note
under 4th <er>Lie</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To produce and deposit
eggs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To take a position; to come or
go; <as>as, to <ex>lay</ex> forward; to <ex>lay</ex>
aloft.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lay a wager; to bet.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To lay about</b></col>, <it>or</it> <col><b>To lay
about one</b></col></mcol>, <cd>to strike vigorously in all
directions.</cd> <au>J. H. Newman.</au> -- <col><b>To lay at</b></col>,
<cd>to strike or strike at.</cd> <au>Spenser.</au> -- <col><b>To lay
for</b></col>, <cd>to prepare to capture or assault; to lay wait
for.</cd> <mark>[Colloq.]</mark> <au>Bp Hall.</au> -- <col><b>To lay in
for</b></col>, <cd>to make overtures for; to engage or secure the
possession of.</cd> <mark>[Obs.]</mark> <ldquo/I have <xex>laid in
for</xex> these.<rdquo/ <au>Dryden.</au> -- <col><b>To lay on</b></col>,
<cd>to strike; to beat; to attack.</cd> <au>Shak.</au> -- <col><b>To lay
out</b></col>, <cd>to purpose; to plan; <as>as, he <ex>lays out</ex> to
make a journey</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lay</ent><br/
<hw>Lay</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That which
lies or is laid or is conceived of as having been laid or placed in its
position; a row; a stratum; a layer; <as>as, a <ex>lay</ex> of stone or
wood</as>.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A viol should have a <qex>lay</qex> of wire strings below.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>lay</xex> of a rope is right-handed or
left-handed according to the hemp or strands are laid up. See
<er>Lay</er>, <pos>v. t.</pos>, 16. The <xex>lay</xex> of land is its
topographical situation, esp. its slope and its surface
features.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A wager.</def> <ldquo/My fortunes against any
<xex>lay</xex> worth naming.<rdquo/<br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <sd>(a)</sd> <def>A job, price, or profit.</def>
<mark>[Prov. Eng.]</mark> <au>Wright.</au> <sd>(b)</sd> <def> A share of
the proceeds or profits of an enterprise; <as>as, when a man ships for a
whaling voyage, he agrees for a certain <ex>lay</ex></as>.</def>
<mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Textile Manuf.)</fld> <sd>(a)</sd> <def>A measure
of yarn; a lea. See 1st <er>Lea</er> <sd>(a)</sd>.</def> <sd>(b)</sd>
<def>The lathe of a loom. See <er>Lathe</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A plan; a scheme.</def> <mark>[Slang]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lay figure</b></col>. <sd>(a)</sd> <cd>A jointed model of
the human body that may be put in any attitude; -- used for showing the
disposition of drapery, etc.</cd> <sd>(b)</sd> <cd>A mere puppet; one
who serves the will of others without independent volition.</cd> --
<col><b>Lay race</b></col>, <cd>that part of a lay on which the shuttle
travels in weaving; -- called also <altname>shuttle race</altname>.</cd>
-- <col><b>the lay of the land</b></col>, <cd>the general situation or
state of affairs.</cd> -- <col><b>to get the lay of the land</b></col>,
<cd>to learn the general situation or state of affairs, especially in
preparation for action.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>layabout</ent><br/
<hw>layabout</hw> <pos>n.</pos> <def>A person who does no
work.</def><br/
<syn><b>Syn. --</b> idler, loafer, do-nothing, bum.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>layby</ent><br/
<hw>layby</hw> <pos>n.</pos> <def>A paved area beside a main road where
cars can stop temporarily.</def> <mark>[Chiefly Brit.]</mark> <br/
<syn><b>Syn. --</b> pull-off, turnout.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Layer</ent><br/
<hw>Lay"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Lay</er> to
cause to lie flat.]</ety> <sn>1.</sn> <def>One who, or that which,
lays.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Prob. a corruption of <ets>lair</ets>.]</ety>
<def>That which is laid; a stratum; a bed; one thickness, course, or
fold laid over another; <as>as, a <ex>layer</ex> of clay or of sand in
the earth; a <ex>layer</ex> of bricks, or of plaster; the
<ex>layers</ex> of an onion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A shoot or twig of a plant, not detached from the
stock, laid under ground for growth or propagation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An artificial oyster bed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>layered</ent><br/
<hw>layered</hw> <pos>adj.</pos> <def>arranged in layers.</def><br/
<syn><b>Syn. --</b> superimposed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Layering</ent><br/
<hw>Lay"er*ing</hw>, <pos>n.</pos> <def>A propagating by layers.</def>
<rj><au>Gardner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Layette</ent><br/
<hw>Lay*ette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Med.)</fld> <def>The outfit of clothing, blankets, etc., prepared
for a newborn infant, and placed ready for use.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Layia</ent><br/
<hw>Layia</hw> <pos>n.</pos> <def>A genus of Western U. S. annuals with
showy yellow or white flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Layia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Laying</ent><br/
<hw>Lay"ing</hw> <pr>(?)</pr>, <pos>n.</pos><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of one who, or that which, lays.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or period of laying eggs; the eggs laid for
one incubation; a clutch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The first coat on laths of plasterer's two-coat
work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Layland</ent><br/
<hw>Lay"land`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lay</ets> a
meadow + <ets>land</ets>.]</ety> <def>Land lying untilled; fallow
ground.</def> <mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Layman</ent><br/
<hw>Lay"man</hw> <pr>(?)</pr> <pos>n.</pos>; <plu><it>pl.</it>
<plw>Laymen</plw> <pr>(<?/)</pr>.</plu> <ety>[<ets>Lay</ets>,
<pos>adj.</pos> + <ets>man</ets>.]</ety> <sn>1.</sn> <def>One of the
people, in distinction from the clergy; one of the laity; sometimes, a
man not belonging to some particular profession, in distinction from
those who do.</def><-- used esp. by physicians of those w/o medical
training --><br/
[<source>1913 Webster</source>]</p>

<p><q>Being a <qex>layman</qex>, I ought not to have concerned myself
with speculations which belong to the profession.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lay figure. See under <er>Lay</er>, <pos>n.</pos>
(above).</def> <rj><au>Dryden</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Layner</ent><br/
<hw>Lay"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lanier</er>.]</ety> <def>A whiplash.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>layperson</ent><br/
<hw>layperson</hw> <pos>n.</pos> <def>someone who is not a clergyman or
a professional person; a <er>layman</er>.</def><br/
<syn><b>Syn. --</b> layman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lay reader</ent><br/
<hw>Lay" read"er</hw>. <fld>(Eccl.)</fld> <def>A layman authorized to
read parts of the public service of the church.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Layshaft</ent><br/
<ent>Lay shaft</ent><br/
<mhw>{ <hw>Lay shaft</hw>, <it>or</it> <hw>Lay"shaft`</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <fld>(Mach.)</fld> <def>A secondary shaft,
as in a sliding change gear for an automobile; a cam shaft operated by a
two-to-one gear in an internal-combustion engine. It is generally a
shaft moving more or less independently of the other parts of a machine,
<as>as, in some marine engines, a shaft, driven by a small auxiliary
engine, for independently operating the valves of the main engine to
insure uniform motion</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Layship</ent><br/
<hw>Lay"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
being a layman.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laystall</ent><br/
<hw>Lay"stall`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A place
where rubbish, dung, etc., are laid or deposited.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Smithfield was a <qex>laystall</qex> of all ordure and filth.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place where milch cows are kept, or cattle on the
way to market are lodged.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazar</ent><br/
<hw>La"zar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>lazare</ets>,
fr. <ets>Lazarus</ets> the beggar. <ets>Luke xvi</ets>.
<ets>20</ets>.]</ety> <def>A person infected with a filthy or
pestilential disease; a leper.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Like loathsome <qex>lazars</qex>, by the hedges lay.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lazar house</b></col> <cd>a lazaretto; also, a hospital
for quarantine.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazaretto</ent><br/
<ent>Lazaret</ent><br/
<mhw>{ <hw>Laz`a*ret"</hw> <pr>(l<acr/z`<adot/*r<ecr/t")</pr>,
<hw>Laz`a*ret"to</hw> <pr>(l<acr/z`<adot/*r<ecr/t"t<osl/)</pr>, }</mhw>
<pos>n.</pos> <ety>[F. <ets>lazaret</ets>, or It. <ets>lazzeretto</ets>,
fr. <ets>Lazarus</ets>. See <er>Lazar</er>.]</ety> <sn>1.</sn> <def>A
public building, hospital, or pesthouse for the reception of diseased
persons, particularly those affected with contagious diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <note>(Pronounced by seamen
<pr>l<acr/z`<adot/*r<emac/t"</pr>)</note> <def>A low space under the
after part of the main deck, used as a storeroom.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lazaret fever</ent><br/
<hw>Lazaret fever</hw>. <fld>(Med.)</fld> <def>Typhus fever.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lazarite</ent><br/
<ent>Lazarist</ent><br/
<mhw>{ <hw>Laz"a*rist</hw> <pr>(?)</pr>, <hw>Laz"a*rite</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(R. C. Ch.)</fld> <def>One of
the <membof>Congregation of the Priests of the Mission</membof>, a
religious institute founded by <person>Vincent de Paul</person> in 1624,
and popularly called Lazarists or Lazarites from the College of St.
Lazare in Paris, which was occupied by them until 1792.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazarly</ent><br/
<ent>Lazarlike</ent><br/
<mhw>{ <hw>La"zar*like`</hw> <pr>(?)</pr>, <hw>La"zar*ly</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Full of sores; leprous.</def>
<rj><au>Shak.</au> <au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazaroni</ent><br/
<hw>Laz`a*ro"ni</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Lazzaroni</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazarwort</ent><br/
<hw>La"zar*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Laserwort.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laze</ent><br/
<hw>Laze</hw> <pr>(l<amac/z)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lazed</conjf> <pr>(l<amac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lazing</conjf>.]</vmorph> <ety>[See
<er>Lazy</er>.]</ety> <def>To be lazy or idle.</def>
<mark>[Colloq.]</mark> <rj><au>Middleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laze</ent><br/
<hw>Laze</hw>, <pos>v. t.</pos> <def>To waste in sloth; to spend, as
time, in idleness; <as>as, to <ex>laze</ex> away whole days</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazily</ent><br/
<hw>La"zi*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a lazy
manner.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Laziness</ent><br/
<hw>La"zi*ness</hw>, <pos>n.</pos> <def>The state or quality of being
lazy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Laziness</qex> travels so slowly, that Poverty soon overtakes
him.</q> <rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazuli</ent><br/
<hw>Laz"u*li</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. & NL. <ets>lapis
lazuli</ets>, LL. <ets>lazulus</ets>, <ets>lazurius</ets>,
<ets>lazur</ets> from the same Oriental source as E. <ets>azure</ets>.
See <er>Azure</er>.]</ety> <fld>(Min.)</fld> <def>A mineral of a fine
azure-blue color, usually in small rounded masses. It is essentially a
silicate of alumina, lime, and soda, with some sodium sulphide, is often
marked by yellow spots or veins of sulphide of iron, and is much valued
for ornamental work. Called also <altname>lapis lazuli</altname>, and
<altname>Armenian stone</altname>.</def> <-- and lapis. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazulite</ent><br/
<hw>Laz"u*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>lazuli</ets> : cf. F. <ets>lazulite</ets>, G.
<ets>lazulith</ets>.]</ety> <fld>(Min.)</fld> <def>A mineral of a light
indigo-blue color, occurring in small masses, or in monoclinic crystals;
blue spar. It is a hydrous phosphate of alumina and magnesia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazy</ent><br/
<hw>La"zy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lazier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Laziest</adjf>.]</amorph> <ety>[OE. <ets>lasie</ets>,
<ets>laesic</ets>, of uncertain origin; cf. F. <ets>las</ets> tired, L.
<ets>lassus</ets>, akin to E. <ets>late</ets>; or cf. LG.
<ets>losig</ets>, <ets>lesig</ets>.]</ety> <sn>1.</sn> <def>Disinclined
to action or exertion; averse to labor; idle; shirking work.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inactive; slothful; slow; sluggish; <as>as, a
<ex>lazy</ex> stream</as>.</def> <ldquo/The night owl's <xex>lazy</xex>
flight.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wicked; vicious.</def> <mark>[Obs. or Prov.
Eng.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 837 --></p>

<p><cs><col><b>Lazy tongs</b></col>, <cd>a system of jointed bars
capable of great extension, originally made for picking up something at
a distance, now variously applied in machinery.</cd></cs></p>

<p><syn><b>Syn.</b> -- Idle; indolent; sluggish; slothful. See
<er>Idle</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazyback</ent><br/
<hw>La"zy*back`</hw> <pr>(l<amac/"z<ycr/*b<acr/k`)</pr>, <pos>n.</pos>
<def>A support for the back, attached to the seat of a carriage.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazybones</ent><br/
<hw>La"zy*bones`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lazy
person.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lazzaroni</ent><br/
<hw>Laz`za*ro"ni</hw> <pr>(l<acr/z`z<adot/*r<omac/"n<icr/; It.
l<aum/t`s<adot/*r<omac/"n<esl/)</pr>, <pos>n. pl.</pos> <ety>[It.
<ets>lazzarone</ets>, pl. <ets>lazzaroni</ets>.]</ety> <def>The homeless
idlers of Naples who live by chance work or begging; -- so called from
the Hospital of St. Lazarus, which serves as their refuge.</def>
<altsp>[Written also, but improperly, <asp>lazaroni</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>lcm</ent><br/
<hw>lcm</hw> <pos>n.</pos> <def>Abbreviation for the least common
multiple, the smallest multiple that is exactly divisible by every
member of a set of numbers; <as>as, the <ex>least common multiple</ex>
of 12 and 18 is 36</as>.</def> <mark>[abbr.]</mark> <br/
<syn><b>Syn. --</b> lowest common multiple, least common
multiple.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ld.</ent><br/
<hw>Ld.</hw> <pos>n.</pos> <def>The abbreviation for
<altname>limited</altname>, term appended to the name of a company that
is organized to give its owners limited liability; also abbreviated
<altname>Ltd.</altname> It corresponds to <altname>Inc.</altname> in the
United States.</def> <mark>[Chiefly British]</mark> <mark>[abbr.]</mark>
<br/
<syn><b>Syn. --</b> limited company, Ltd.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>LDL</ent><br/
<hw>LDL</hw> <pr>(<ecr/l`d<emac/*<ecr/l/")</pr> <pos>n.</pos>
<ety>[acronym from <ets>L</ets>ow-<ets>D</ets>ensity
<ets>L</ets>ipoprotein.]</ety> <fld>(Med., Biochem.)</fld>
<def><altname>Low-density lipoprotein</altname>, a lipoprotein that
transports cholesterol in the blood; high levels are thought to be
associated with increased risk of coronary heart disease and
atherosclerosis; sometimes called informally <altname>bad
cholesterol</altname>.</def><br/
<syn><b>Syn. --</b> low-density lipoprotein.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lea</ent><br/
<hw>Lea</hw>, <pos>n.</pos> <ety>[Cf. <er>Lay</er>, <pos>n.</pos> (that
which is laid), 4.]</ety> <fld>(Textile Manuf.)</fld> <sd>(a)</sd>
<def>A measure of yarn; for linen, 300 yards; for cotton, 120 yards; a
lay.</def> <sd>(b)</sd> <def>A set of warp threads carried by a loop of
the heddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lea</ent><br/
<hw>Lea</hw>, <pos>n.</pos> <ety>[OE. <ets>ley</ets>, <ets>lay</ets>,
As. <ets>le<aacute/h</ets>, <ets>le<aacute/</ets>; akin to Prov. G.
<ets>lon</ets> bog, morass, grove, and perh. to L. <ets>lucus</ets>
grove, E. <ets>light</ets>, <pos>n.</pos>]</ety> <def>A meadow or sward
land; a grassy field.</def> <ldquo/Plow-torn <xex>leas</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The lowing herd wind slowly o'er the <qex>lea</qex>.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leach</ent><br/
<hw>Leach</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>See
3d <er>Leech</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leach</ent><br/
<hw>Leach</hw>, <pos>n.</pos> <altsp>[Written also
<asp>letch</asp>.]</altsp> <ety>[Cf. As. <ets>le<aacute/h</ets> lye, G.
<ets>lauge</ets>. See <er>Lye</er>.]</ety> <sn>1.</sn> <def>A quantity
of wood ashes, through which water passes, and thus imbibes the
alkali.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tub or vat for leaching ashes, bark,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leach tub</b></col>, <cd>a wooden tub in which ashes are
leached.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leach</ent><br/
<hw>Leach</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leached</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leaching</conjf>.]</vmorph> <ety>[Written also <ets>leech</ets>
and <ets>letch</ets>.]</ety> <sn>1.</sn> <def>To remove the soluble
constituents from by subjecting to the action of percolating water or
other liquid; <as>as, to <ex>leach</ex> ashes or coffee</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dissolve out; -- often used with <xex>out</xex>;
<as>as, to <ex>leach</ex> out alkali from ashes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leach</ent><br/
<hw>Leach</hw>, <pos>v. i.</pos> <def>To part with soluble constituents
by percolation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leach</ent><br/
<hw>Leach</hw>, <pos>n.</pos> <def>See <er>Leech</er>, a
physician.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leachy</ent><br/
<hw>Leach"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Permitting liquids to
pass by percolation; not capable of retaining water; porous; pervious;
-- said of gravelly or sandy soils, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lead</ent><br/
<hw>Lead</hw> <pr>(l<ecr/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>led</ets>, <ets>leed</ets>, <ets>lead</ets>, AS.
<ets>le<aacute/d</ets>; akin to D. <ets>lood</ets>, MHG.
<ets>l<omac/t</ets>, G. <ets>loth</ets> plummet, sounding lead, small
weight, Sw. & Dan. <ets>lod</ets>. <root/123.]</ety> <sn>1.</sn>
<fld>(Chem.)</fld> <def>One of the elements, a heavy, pliable, inelastic
metal, having a bright, bluish color, but easily tarnished. It is both
malleable and ductile, though with little tenacity, and is used for
tubes, sheets, bullets, etc. Its specific gravity is 11.37. It is easily
fusible (melting point 327.5<deg/ C), forms alloys with other metals,
and is an ingredient of solder and type metal. Atomic number 82. Atomic
weight, 207.2. Symbol Pb (L. <xex>Plumbum</xex>). It is chiefly obtained
from the mineral galena, lead sulphide.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An article made of lead or an alloy of lead</def>;
as: <sd>(a)</sd> <def>A plummet or mass of lead, used in sounding at
sea.</def> <sd>(b)</sd> <fld>(Print.)</fld> <def>A thin strip of type
metal, used to separate lines of type in printing.</def> <sd>(c)</sd>
<def>Sheets or plates of lead used as a covering for roofs; hence,
<pluf>pl.</pluf>, a roof covered with lead sheets or terne
plates.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would have the tower two stories, and goodly <qex>leads</qex>
upon the top.</q> <rj><qau>Bacon</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A small cylinder of black lead or graphite, used in
pencils.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Black lead</b></col>, <cd>graphite or plumbago; -- so
called from its leadlike appearance and streak.</cd>
<mark>[Colloq.]</mark> -- <col><b>Coasting lead</b></col>, <cd>a
sounding lead intermediate in weight between a hand lead and deep-sea
lead.</cd> -- <col><b>Deep-sea lead</b></col>, <cd>the heaviest of
sounding leads, used in water exceeding a hundred fathoms in depth.</cd>
<au>Ham. Nav. Encyc.</au> -- <col><b>Hand lead</b></col>, <cd>a small
lead use for sounding in shallow water.</cd> -- <mcol><col><b>Krems
lead</b></col>, <col><b>Kremnitz lead</b></col></mcol> <ety>[so called
from <etsep>Krems</etsep> or <etsep>Kremnitz</etsep>, in Austria]</ety>,
<cd>a pure variety of white lead, formed into tablets, and called also
<altname>Krems white</altname>, <it>or</it> <altname>Kremnitz
white</altname>, and <altname>Vienna white</altname>.</cd> --
<col><b>Lead arming</b></col>, <cd>tallow put in the hollow of a
sounding lead. See <cref>To arm the lead</cref> (below).</cd> --
<col><b>Lead colic</b></col>. <cd>See under <er>Colic</er>.</cd> --
<col><b>Lead color</b></col>, <cd>a deep bluish gray color, like
tarnished lead.</cd> -- <col><b>Lead glance</b></col>. <fld>(Min.)</fld>
<cd>Same as <er>Galena</er>.</cd> -- <col><b>Lead line</b></col>
<sd>(a)</sd> <fld>(Med.)</fld> <cd>A dark line along the gums produced
by a deposit of metallic lead, due to lead poisoning.</cd> <sd>(b)</sd>
<fld>(Naut.)</fld> <cd>A sounding line.</cd> -- <col><b>Lead
mill</b></col>, <cd>a leaden polishing wheel, used by lapidaries.</cd>
-- <col><b>Lead ocher</b></col> <fld>(Min.)</fld>, <cd>a massive
sulphur-yellow oxide of lead. Same as <er>Massicot</er>.</cd> --
<col><b>Lead pencil</b></col>, <cd>a pencil of which the marking
material is graphite (black lead).</cd> -- <col><b>Lead plant</b></col>
<fld>(Bot.)</fld>, <cd>a low leguminous plant, genus <gen>Amorpha</gen>
(<spn>Amorpha canescens</spn>), found in the Northwestern United States,
where its presence is supposed to indicate lead ore.</cd> <au>Gray.</au>
-- <col><b>Lead tree</b></col>. <sd>(a)</sd> <fld>(Bot.)</fld> <cd>A
West Indian name for the tropical, leguminous tree, <spn>Leuc<ae/na
glauca</spn>; -- probably so called from the glaucous color of the
foliage.</cd> <sd>(b)</sd> <fld>(Chem.)</fld> <cd>Lead crystallized in
arborescent forms from a solution of some lead salt, as by suspending a
strip of zinc in lead acetate.</cd> -- <col><b>Mock lead</b></col>,
<cd>a miner's term for blende.</cd> -- <col><b>Red lead</b></col>, <cd>a
scarlet, crystalline, granular powder, consisting of minium when pure,
but commonly containing several of the oxides of lead. It is used as a
paint or cement and also as an ingredient of flint glass.</cd> --
<col><b>Red lead ore</b></col> <fld>(Min.)</fld>, <cd>crocoite.</cd> --
<col><b>Sugar of lead</b></col>, <cd>acetate of lead.</cd> -- <col><b>To
arm the lead</b></col>, <cd>to fill the hollow in the bottom of a
sounding lead with tallow in order to discover the nature of the bottom
by the substances adhering.</cd> <au>Ham. Nav. Encyc.</au> --
<mcol><col><b>To cast the lead</b></col>, <it>or</it> <col><b>To heave
the lead</b></col></mcol>, <cd>to cast the sounding lead for
ascertaining the depth of water.</cd> -- <col><b>White lead</b></col>,
<cd>hydrated carbonate of lead, obtained as a white, amorphous powder,
and much used as an ingredient of white paint.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lead</ent><br/
<hw>Lead</hw> <pr>(l<ecr/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Leaded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Leading</conjf>.]</vmorph> <sn>1.</sn> <def>To cover, fill, or
affect with lead; <as>as, continuous firing <ex>leads</ex> the grooves
of a rifle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>To place leads between the lines
of; <as>as, to <ex>lead</ex> a page; <ex>leaded</ex>
matter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lead</ent><br/
<hw>Lead</hw> <pr>(l<emac/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Led</conjf> <pr>(l<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Leading</conjf>.]</vmorph> <ety>[OE. <ets>leden</ets>,
AS. <ets>l<aemac/dan</ets> (akin to OS. <ets>l<emac/dian</ets>, D.
<ets>leiden</ets>, G. <ets>leiten</ets>, Icel.
<ets>le<imac/<edh/a</ets>, Sw. <ets>leda</ets>, Dan. <ets>lede</ets>),
properly a causative fr. AS. <ets>li<edh/an</ets> to go; akin to OHG.
<ets>l<imac/dan</ets>, Icel. <ets>l<imac/<edh/a</ets>, Goth.
<ets>lei<thorn/an</ets> (in comp.). Cf. <er>Lode</er>,
<er>Loath</er>.]</ety> <sn>1.</sn> <def>To guide or conduct with the
hand, or by means of some physical contact or connection; <as>as, a
father <ex>leads</ex> a child; a jockey <ex>leads</ex> a horse with a
halter; a dog <ex>leads</ex> a blind man.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a blind man <qex>lead</qex> a blind man, both fall down in the
ditch.</q> <rj><qau>Wyclif (Matt. xv. 14.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They thrust him out of the city, and <qex>led</qex> him unto the
brow of the hill.</q> <rj><qau>Luke iv. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In thy right hand <qex>lead</qex> with thee<br/
The mountain nymph, sweet Liberty.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To guide or conduct in a certain course, or to a
certain place or end, by making the way known; to show the way, esp. by
going with or going in advance of.</def> <specif>Hence,</specif>
<mark>figuratively</mark>: <def>To direct; to counsel; to instruct;
<as>as, to <ex>lead</ex> a traveler; to <ex>lead</ex> a
pupil.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord went before them by day in a pillar of a cloud, to
<qex>lead</qex> them the way.</q> <rj><qau>Ex. xiii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>leadeth</qex> me beside the still waters.</q> <rj><qau>Ps.
xxiii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This thought might <qex>lead</qex> me through the world's vain
mask.<br/
Content, though blind, had I no better guide.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To conduct or direct with authority; to have
direction or charge of; <as>as, to <ex>lead</ex> an army, an exploring
party, or a search; to <ex>lead</ex> a political party.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Christ took not upon him flesh and blood that he might conquer and
rule nations, <qex>lead</qex> armies, or possess places.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To go or to be in advance of; to precede; hence, to
be foremost or chief among; <as>as, the big sloop <ex>led</ex> the fleet
of yachts; the Guards <ex>led</ex> the attack;
<persfn>Demosthenes</persfn> <ex>leads</ex> the orators of all
ages.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>As Hesperus, that <qex>leads</qex> the sun his way.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>lo</qex> ! Ben Adhem's name <qex>led</qex> all the
rest.</q> <rj><qau>Leigh Hunt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To draw or direct by influence, whether good or bad;
to prevail on; to induce; to entice; to allure; <as>as, to <ex>lead</ex>
one to espouse a righteous cause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was driven by the necessities of the times, more than
<qex>led</qex> by his own disposition, to any rigor of actions.</q>
<rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Silly women, laden with sins, <qex>led</qex> away by divers
lusts.</q> <rj><qau>2 Tim. iii. 6 (Rev. Ver.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To guide or conduct one's self in, through, or along
(a certain course); hence, to proceed in the way of; to follow the path
or course of; to pass; to spend. Also, to cause (one) to proceed or
follow in (a certain course).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That we may <qex>lead</qex> a quiet and peaceable life.</q>
<rj><qau>1 Tim. ii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor thou with shadowed hint confuse<br/
A life that <qex>leads</qex> melodious days.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You remember . . . the life he used to <qex>lead</qex> his wife
and daughter.</q> <rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Cards & Dominoes)</fld> <def>To begin a game,
round, or trick, with; <as>as, to <ex>lead</ex> trumps; the double five
was <ex>led</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lead astray</b></col>, <cd>to guide in a wrong way, or
into error; to seduce from truth or rectitude.</cd> -- <col><b>To lead
captive</b></col>, <cd>to carry or bring into captivity.</cd> --
<col><b>To lead the way</b></col>, <cd>to show the way by going in
front; to act as guide.</cd> <au>Goldsmith.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lead</ent><br/
<hw>Lead</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To guide
or conduct, as by accompanying, going before, showing, influencing,
directing with authority, etc.; to have precedence or pre<eum/minence;
to be first or chief; -- used in most of the senses of <xex>lead</xex>,
<pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tend or reach in a certain direction, or to a
certain place; <as>as, the path <ex>leads</ex> to the mill; gambling
<ex>leads</ex> to other vices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mountain foot that <qex>leads</qex> towards Mantua.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To lead off</b></col> <it>or</it> <col><b>To lead
out</b></col></mcol>, <cd>to go first; to begin; <as>as, Mickey Mantle
<ex>led off</ex> in the fifth inning of the game</as>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lead</ent><br/
<hw>Lead</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of leading or
conducting; guidance; direction; <as>as, to take the <ex>lead</ex>; to
be under the <ex>lead</ex> of another.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>At the time I speak of, and having a momentary <qex>lead</qex>, .
. . <qex>I am sure I did my country important service</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Precedence; advance position; also, the measure of
precedence; <as>as, the white horse had the <ex>lead</ex>; <ex>a
lead</ex> of a boat's length, or of half a second.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Cards & Dominoes)</fld> <def>The act or right of
playing first in a game or round; the card suit, or piece, so played;
<as>as, your partner has the <ex>lead</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An open way in an ice field.</def>
<rj><au>Kane.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mining)</fld> <def>A lode.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>The course of a rope from end to
end.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Steam Engine)</fld> <def>The width of port opening
which is uncovered by the valve, for the admission or release of steam,
at the instant when the piston is at end of its stroke.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When used alone it means <xex>outside lead</xex>, or
lead for the admission of steam. <xex>Inside lead</xex> refers to the
release or exhaust.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Civil Engineering)</fld> <def>the distance of haul,
as from a cutting to an embankment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Horology)</fld> <def>The action of a tooth, as a
tooth of a wheel, in impelling another tooth or a pallet.</def>
<rj><au>Saunier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Music.)</fld> <sd>(a)</sd> <def>The announcement
by one voice part of a theme to be repeated by the other parts.</def>
<sd>(b)</sd> <def>A mark or a short passage in one voice part, as of a
canon, serving as a cue for the entrance of others.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>11.</sn> <def>In an internal-combustion engine, the distance,
measured in actual length of piston stroke or the corresponding angular
displacement of the crank, of the piston from the end of the compression
stroke when ignition takes place; -- called in full <col><b>lead of the
ignition</b></col>. When ignition takes place during the working stroke
the corresponding distance from the commencement of the stroke is called
<col><b>negative lead</b></col>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>12.</sn> <fld>(Mach.)</fld> <def>The excess above a right angle
in the angle between two consecutive cranks, as of a compound engine, on
the same shaft.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>13.</sn> <fld>(Mach.)</fld> <def>In spiral screw threads, worm
wheels, or the like, the amount of advance of any point in the spiral
for a complete turn.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>14.</sn> <fld>(Elec.)</fld> <sd>(a)</sd> <def>The angle between
the line joining the brushes of a continuous-current dynamo and the
diameter symmetrical between the poles.</def> <sd>(b)</sd> <def>The
advance of the current phase in an alternating circuit beyond that of
the electromotive force producing it.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>15.</sn> <fld>(Theat.)</fld> <def>A role for a leading man or
leading woman; also, one who plays such a role.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>16.</sn> <def>The first story in a newspaper or broadcast news
program.</def><br/
[<source>PJC</source>]</p>

<p><sn>17.</sn> <def>an electrical conductor, typically as an insulated
wire or cable, connecting an electrical device to another device or to a
power source, such as a conductor conveying electricity from a
dynamo.</def><br/
[<source>PJC</source>]</p>

<p><sn>18.</sn> <fld>(Baseball)</fld> <def>the distance a runner on base
advances from one base toward the next before the pitch; <as>as, the
long <ex>lead</ex> he usually takes tends to distract the
pitchers</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Lead angle</b></col> <fld>(Steam Engine)</fld>, <cd>the
angle which the crank maker with the line of centers, in approaching it,
at the instant when the valve opens to admit steam.</cd> -- <col><b>Lead
screw</b></col> <fld>(Mach.)</fld>, <cd>the main longitudinal screw of a
lathe, which gives the feed motion to the carriage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaded</ent><br/
<hw>Lead"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Fitted
with lead; set in lead; <as>as, <ex>leaded</ex> windows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>Separated by leads, as the lines
of a page.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaden</ent><br/
<hw>Lead"en</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Made of
lead; of the nature of lead; <as>as, a <ex>leaden</ex>
ball</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like lead in color, etc.; <as>as, a <ex>leaden</ex>
sky</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Heavy; dull; sluggish.</def>
<ldquo/<xex>Leaden</xex> slumber.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leader</ent><br/
<hw>Lead"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, leads or conducts; a guide; a conductor.</def>
<specif>Especially:</specif> <sd>(a)</sd> <def>One who goes first.</def>
<sd>(b)</sd> <def>One having authority to direct; a chief; a
commander.</def> <sd>(c)</sd> <fld>(Mus.)</fld> <def>A performer who
leads a band or choir in music; also, in an orchestra, the principal
violinist; the one who plays at the head of the first violins.</def>
<sd>(d)</sd> <fld>(Naut.)</fld> <def>A block of hard wood pierced with
suitable holes for leading ropes in their proper places.</def>
<sd>(e)</sd> <fld>(Mach.)</fld> <def>The principal wheel in any kind of
machinery.</def> <mark>[Obs. or R.]</mark> <au>G. Francis.</au>
<sd>(f)</sd> <def>A horse placed in advance of others; one of the
forward pair of horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He forgot to pull in his <qex>leaders</qex>, and they gallop away
with him at times.</q> <rj><qau>Hare.</qau></rj></p>

<p><sd>(g)</sd> <def>A pipe for conducting rain water from a roof to a
cistern or to the ground; a conductor.</def> <sd>(h)</sd>
<fld>(Fishing)</fld> <def>A net for leading fish into a pound, weir,
etc.; also, a line of gut, to which the snell of a fly hook is
attached.</def> <sd>(i)</sd> <fld>(Mining)</fld> <def>A branch or small
vein, not important in itself, but indicating the proximity of a better
one.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The first, or the principal, editorial article in a
newspaper; a leading or main editorial article.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Print.)</fld> <sd>(a)</sd> <def>A type having a dot
or short row of dots upon its face.</def> <sd>(b)</sd> <pluf>pl.</pluf>
<def>a row of dots, periods, or hyphens, used in tables of contents,
etc., to lead the eye across a space to the right word or
number.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- chief; chieftain; commander. See
<er>Chief</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>leaderless</ent><br/
<hw>leaderless</hw> <pos>adj.</pos> <def>lacking a leader; <as>as, a
<ex>leaderless</ex> mob running riot in the streets</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leaders</ent><br/
<hw>leaders</hw> <pos>n.</pos> <def>the body of people who lead a group;
the leadership{3}; <as>as, they hung the <ex>leaders</ex> of the
insurrection</as>.</def><br/
<syn><b>Syn. --</b> leadership.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leadership</ent><br/
<hw>Lead"er*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
office, position or function of a leader; <as>as, Gingrich held the
House <ex>leadership</ex> for six years</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of character and personality giving a
person the ability to gain the confidence of and lead others; <as>as,
Washington's <ex>leadership</ex> was indispensible to success of the
American Revolution</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The people who serve as leaders of a group; <as>as,
the party <ex>leadership</ex> was in disarray after the
election</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>lead-free</ent><br/
<hw>lead-free</hw> <pos>adj.</pos> <sn>1.</sn> <def>not containing the
element lead.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>specifically:</specif> <def>Not containing a lead
additive such as tetraethyllead or tetramethyllead; -- of gasoline;
<as>as, Most modern cars run on <ex>lead-free</ex> gasoline</as>.
Oposite of <ant>leaded</ant>.</def><br/
<syn><b>Syn. --</b> nonleaded, unleaded.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <specif>specifically:</specif> <def>Not containing a
pigment having lead as a component; -- of paints; <as>as,
<ex>lead-free</ex> paint should be used wherever children are exposed to
the painted surface</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leadhillite</ent><br/
<hw>Lead"hill*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A mineral of a yellowish or greenish white color, consisting of the
sulphate and carbonate of lead; -- so called from having been first
found at <etsep>Leadhills</etsep>, Scotland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lead-in</ent><br/
<hw>lead-in</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Elec.)</fld> <def>a
wire connecting an antenna to a receiver or a transmitter to a
transmission line.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Radio and Television Broadcasting)</fld> <def>The
short segment of a program or program script introducing and immediately
preceding another part of the program or a commercial.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leading</ent><br/
<hw>Lead"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Guiding; directing;
controlling; foremost; <as>as, a <ex>leading</ex> motive; a
<ex>leading</ex> man; a <ex>leading</ex> example.</as></def> --
<wordforms><wf>Lead"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leading case</b></col> <fld>(Law)</fld>, <cd>a reported
decision which has come to be regarded as settling the law of the
question involved.</cd> <au>Abbott.</au> -- <col><b>Leading
motive</b></col> <ety>[a translation of G. <ets>leitmotif</ets>]</ety>
<fld>(Mus.)</fld>, <cd>a guiding theme; in the musical drama of Wagner,
a marked melodic phrase or short passage which always accompanies the
reappearance of a certain person, situation, abstract idea, or allusion
in the course of the play; a sort of musical label. Also called
<altname>leitmotif</altname> or <altname>leitmotiv</altname>.</cd> --
<col><b>Leading note</b></col> <fld>(Mus.)</fld>, <cd>the seventh note
or tone in the ascending major scale; the sensible note.</cd> --
<col><b>Leading question</b></col>, <cd>a question so framed as to guide
the person questioned in making his reply.</cd> -- <col><b>Leading
strings</b></col>, <cd>strings by which children are supported when
beginning to walk.</cd> -- <col><b>To be in leading strings</b></col>,
<cd>to be in a state of infancy or dependence, or under the guidance of
others.</cd> -- <col><b>Leading wheel</b></col>, <cd>a wheel situated
before the driving wheels of a locomotive engine.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leading</ent><br/
<hw>Lead"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of guiding,
directing, governing, or enticing; guidance.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suggestion; hint; example.</def>
<mark>[Archaic]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leading edge</ent><br/
<hw>Lead"ing edge</hw> <pr>(?)</pr> <pos>n.</pos><sn>1.</sn>
<fld>(Aeronautics)</fld> <def>the front edge of an airfoil; same as
<altname><er>Advancing edge</er></altname>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>the front edge of anything that moves; also used
metaphorically, <as>as the <ex>leading edge</ex> in art</as>. See also
<er>cutting edge</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leadman</ent><br/
<hw>Lead"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Leadmen</plw> <pr>(<?/)</pr>.</plu> <def>One who leads a
dance.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leadsman</ent><br/
<hw>Leads"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Leadsmen</plw> <pr>(<?/)</pr>.</plu> <fld>(Naut.)</fld> <def>The
man who heaves the lead.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>leadplant</ent><br/
<hw>leadplant</hw> <pos>n.</pos> <def>A shrub (<spn>Amorpha
canescens</spn>) of sandy woodlands and streambanks of the Western U. S.
having hoary pinnate flowers and dull-colored racemose flowers; it is
thought to indicate the presence of lead ore.</def><br/
<syn><b>Syn. --</b> lead plant, <spn>Amorpha canescens</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lead to</ent><br/
<hw>lead to</hw> <pos>v. t.</pos> <sn>1.</sn> <def>Same as
<er>cause</er>; <as>as, the roaring stock market <ex>led to</ex> an
increase in the purchase of big-ticket items during the 1996 Christmas
season</as>.</def><br/
<syn><b>Syn. --</b> result in, lead to.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>to be a contributory cause of; <as>as, IBM's
inattention to the needs of individual users <ex>led to</ex> the demise
of OS/2 as a viable alternative to Windows 95</as>.</def><br/
<syn><b>Syn. --</b> be conducive to, contribute to, lead to, conduce
to.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Leadwort</ent><br/
<hw>Lead"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus of maritime herbs (<gen>Plumbago</gen>). <spn>Plumbago
Europ<ae/a</spn> has lead-colored spots on the leaves, and nearly
lead-colored flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leady</ent><br/
<hw>Lead"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling lead.</def>
<rj><au>Sir T. Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaf</ent><br/
<hw>Leaf</hw> <pr>(l<emac/f)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Leaves</plw> <pr>(l<emac/vz)</pr>.</plu> <ety>[OE. <ets>leef</ets>,
<ets>lef</ets>, <ets>leaf</ets>, AS. <ets>le<aacute/f</ets>; akin to S.
<ets>l<omac/f</ets>, OFries. <ets>laf</ets>, D. <ets>loof</ets> foliage,
G. <ets>laub</ets>, OHG. <ets>loub</ets> leaf, foliage, Icel.
<ets>lauf</ets>, Sw. <ets>l<oum/f</ets>, Dan. <ets>l<oum/v</ets>, Goth.
<ets>laufs</ets>; cf. Lith. <ets>lapas</ets>. Cf. <er>Lodge</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A colored, usually green, expansion
growing from the side of a stem or rootstock, in which the sap for the
use of the plant is elaborated under the influence of light; one of the
parts of a plant which collectively constitute its foliage.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Such leaves usually consist of a blade, or
<part>lamina</part> , supported upon a leafstalk or
<part>petiole</part>, which, continued through the blade as the
<part>midrib</part>, gives off woody <parts>ribs</parts> and
<parts>veins</parts> that support the cellular texture. The petiole has
usually some sort of an appendage on each side of its base, which is
called the <part>stipule</part>. The green parenchyma of the leaf is
covered with a thin epiderm pierced with closable microscopic openings,
known as <parts>stomata</parts>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A special organ of vegetation in
the form of a lateral outgrowth from the stem, whether appearing as a
part of the foliage, or as a cotyledon, a scale, a bract, a spine, or a
tendril.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this view every part of a plant, except the root and
the stem, is either a leaf, or is composed of leaves more or less
modified and transformed.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something which is like a leaf in being wide and
thin and having a flat surface, or in being attached to a larger body by
one edge or end;</def> <specif>as</specif>: <sd>(a)</sd> <def>A part of
a book or folded sheet containing two pages upon its opposite
sides.</def> <sd>(b)</sd> <def>A side, division, or part, that slides or
is hinged, as of window shutters, folding doors, etc.</def> <sd>(c)</sd>
<def>The movable side of a table.</def> <sd>(d)</sd> <def>A very thin
plate; <as>as, gold <ex>leaf</ex></as>.</def> <sd>(e)</sd> <def>A
portion of fat lying in a separate fold or layer.</def> <sd>(f)</sd>
<def>One of the teeth of a pinion, especially when small.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leaf beetle</b></col> <fld>(Zool.)</fld>, <cd>any beetle
which feeds upon leaves; esp., any species of the family
<fam>Chrysomelid<ae/</fam>, as the potato beetle and helmet beetle.</cd>
-- <col><b>Leaf bridge</b></col>, <cd>a draw-bridge having a platform or
leaf which swings vertically on hinges.</cd> -- <col><b>Leaf
bud</b></col> <fld>(Bot.)</fld>, <cd>a bud which develops into leaves or
a leafy branch.</cd> -- <col><b>Leaf butterfly</b></col>
<fld>(Zool.)</fld>, <cd>any butterfly which, in the form and colors of
its wings, resembles the leaves of plants upon which it rests; esp.,
butterflies of the genus <gen>Kallima</gen>, found in Southern Asia and
the East Indies.</cd> -- <col><b>Leaf crumpler</b></col>
<fld>(Zool.)</fld>, <cd>a small moth (<spn>Phycis indigenella</spn>),
the larva of which feeds upon leaves of the apple tree, and forms its
nest by crumpling and fastening leaves together in clusters.</cd> --
<col><b>Leaf fat</b></col>, <cd>the fat which lies in leaves or layers
within the body of an animal.</cd> -- <col><b>Leaf flea</b></col>
<fld>(Zool.)</fld>, <cd>a jumping plant louse of the family
<fam>Psyllid<ae/</fam>.</cd> -- <col><b>Leaf frog</b></col>
<fld>(Zool.)</fld>, <cd>any tree frog of the genus
<gen>Phyllomedusa</gen>.</cd> -- <col><b>Leaf
green</b></col>.<fld>(Bot.)</fld> <cd>See <er>Chlorophyll</er>.</cd> --
<col><b>Leaf hopper</b></col> <fld>(Zool.)</fld>, <cd>any small jumping
hemipterous insect of the genus <gen>Tettigonia</gen>, and allied
genera. They live upon the leaves and twigs of plants. See <er>Live
hopper</er>.</cd> -- <col><b>Leaf insect</b></col> <fld>(Zool.)</fld>,
<cd>any one of several genera and species of orthopterous insects, esp.
of the genus <gen>Phyllium</gen>, in which the wings, and sometimes the
legs, resemble leaves in color and form. They are common in Southern
Asia and the East Indies.</cd> -- <col><b>Leaf lard</b></col>, <cd>lard
from leaf fat. See under <er>Lard</er>.</cd> -- <col><b>Leaf
louse</b></col> <fld>(Zool.)</fld>, <cd>an aphid.</cd> -- <col><b>Leaf
metal</b></col>, <cd>metal in thin leaves, as gold, silver, or tin.</cd>
-- <col><b>Leaf miner</b></col> <fld>(Zool.)</fld>, <cd>any one of
various small lepidopterous and dipterous insects, which, in the larval
stages, burrow in and eat the parenchyma of leaves; <as>as, the
pear-tree <ex>leaf miner</ex> (<spn>Lithocolletis
geminatella</spn>)</as>.</cd> -- <col><b>Leaf notcher</b></col>
<fld>(Zool.)</fld>, <cd>a pale bluish green beetle (<spn>Artipus
Floridanus</spn>), which, in Florida, eats the edges of the leaves of
orange trees.</cd> -- <col><b>Leaf roller</b></col> <fld>(Zool.)</fld>,
<cd>See <er>leaf roller</er> in the vocabulary.</cd> -- <col><b>Leaf
scar</b></col> <fld>(Bot.)</fld>, <cd>the cicatrix on a stem whence a
leaf has fallen.</cd> -- <col><b>Leaf sewer</b></col>
<fld>(Zool.)</fld>, <cd>a tortricid moth, whose caterpillar makes a nest
by rolling up a leaf and fastening the edges together with silk, as if
sewn; esp., <spn>Phoxopteris nubeculana</spn>, which feeds upon the
apple tree.</cd> -- <col><b>Leaf sight</b></col>, <cd>a hinged sight on
a firearm, which can be raised or folded down.</cd> -- <col><b>Leaf
trace</b></col> <fld>(Bot.)</fld>, <cd>one or more fibrovascular
bundles, which may be traced down an endogenous stem from the base of a
leaf.</cd> -- <col><b>Leaf tier</b></col> <fld>(Zool.)</fld>, <cd>a
tortricid moth whose larva makes a nest by fastening the edges of a leaf
together with silk; esp., <spn>Teras cinderella</spn>, found on the
apple tree.</cd> -- <col><b>Leaf valve</b></col>, <cd>a valve which
moves on a hinge.</cd> -- <col><b>Leaf wasp</b></col>
<fld>(Zool.)</fld>, <cd>a sawfly.</cd> -- <col><b>To turn over a new
leaf</b></col>, <cd>to make a radical change for the better in one's way
of living or doing.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q> They were both determined <qex>to turn over a new leaf</qex>.</q>
<rj><qau>Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 838 --></p>

<p><ent>Leaf out</ent><br/
<ent>Leaf</ent><br/
<mhw><hw>Leaf</hw>, <hw>Leaf out</hw></mhw> <pr>(l<emac/f)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Leafed</conjf>
<pr>(l<emac/ft)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leafing</conjf>.]</vmorph> <def>To shoot out leaves; to produce
leaves; to leave; <as>as, the trees <ex>leaf</ex> in May</as>.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leafage</ent><br/
<hw>Leaf"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Leaves, collectively;
foliage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leafcup</ent><br/
<hw>Leaf"cup`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
coarse American composite weed (<spn>Polymnia Uvedalia</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leaf-cutter</ent><br/
<ent>leaf cutter</ent><br/
<mhw><hw>leaf cutter</hw>, <hw>leaf-cutter</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any one of various species of wild bees of the
genus <gen>Megachile</gen>, which cut rounded pieces from the edges of
leaves, or the petals of flowers, to be used in the construction of
their nests, which are made in holes and crevices, or in a leaf rolled
up for the purpose. Among the common American species are <spn>Megachile
brevis</spn> and <spn>Megachile centuncularis</spn>. Called also
<altname>rose-cutting bee</altname>.</def><br/
<syn><b>Syn. --</b> leaf-cutting bee, leaf-cutter bee.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Leafed</ent><br/
<hw>Leafed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having (such) a leaf or
(so many) leaves; -- used in composition; <as>as, broad<ex>-leafed</ex>;
four<ex>-leafed</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leafet</ent><br/
<hw>Leaf"et</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
leaflet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaf-footed</ent><br/
<hw>Leaf"-foot`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having leaflike expansions on the legs; -- said of certain insects;
<as>as, the <ex>leaf-footed</ex> bug (<spn>Leptoglossus
phyllopus</spn>)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leaf-hopper</ent><br/
<hw>leaf-hopper</hw> <pos>n.</pos> <def>A small leaping insect that
sucks the juices of plants.</def><br/
<syn><b>Syn. --</b> leafhopper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leafiness</ent><br/
<hw>Leaf"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
leafy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leafless</ent><br/
<hw>Leaf"less</hw>, <pos>a.</pos> <def>Having no leaves or foliage;
bearing no foliage.</def> <ldquo/<xex>Leafless</xex> groves.<rdquo/
<au>Cowper.</au> -- <wordforms><wf>Leaf"less*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leafless plants</b></col>, <cd>plants having no foliage,
though leaves may be present in the form of scales and bracts. See
<er>Leaf</er>, <pos>n.</pos>, 1 and 2.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaflet</ent><br/
<hw>Leaf"let</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A little
leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>One of the divisions of a compound
leaf; a foliole.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A leaflike organ or part; <as>as,
a <ex>leaflet</ex> of the gills of fishes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A printed sheet of paper, of one page, or one sheet
folded over, containing an advertisement, tract, or other notice, and
usually distributed for free or included in the package with a purchased
item.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leaf-nosed</ent><br/
<hw>Leaf"-nosed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Having a leaflike membrane on the nose; -- said of certain bats,
esp. of the genera <gen>Phyllostoma</gen> and <gen>Rhinonycteris</gen>.
See <er>Vampire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leaf roller</ent><br/
<ent>leafroller</ent><br/
<mhw><hw>leafroller</hw>, <hw>leaf roller</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>The larva of any tortricid moth which makes a
nest by rolling up the leaves of plants and tying the leaves with spun
silk; aalso, the moth itself. See <er>Tortrix</er>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Leafstalk</ent><br/
<hw>Leaf"stalk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The stalk or petiole which supports a leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leafy</ent><br/
<hw>Leaf"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Leafier</adjf> <pr>(?)</pr>; <pos>superl</pos>.
<adjf>Leafiest</adjf>.]</amorph> <sn>1.</sn> <def>Full of leaves;
abounding in leaves; <as>as, the <ex>leafy</ex> forest</as>.</def>
<ldquo/The <xex>leafy</xex> month of June.<rdquo/
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of leaves.</def> <ldquo/A
<xex>leafy</xex> bed.<rdquo/ <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>League</ent><br/
<hw>League</hw> <pr>(l<emac/g)</pr>, <pos>n.</pos> <ety>[Cf. OE.
<ets>legue</ets>, <ets>lieue</ets>, a measure of length, F.
<ets>lieue</ets>, Pr. <ets>lega</ets>, <ets>legua</ets>, It. & LL.
<ets>lega</ets>, Sp. <ets>legua</ets>, Pg. <ets>legoa</ets>,
<ets>legua</ets>; all fr. LL. <ets>leuca</ets>, of Celtic origin: cf.
Arm. <ets>leo</ets>, <ets>lev</ets> (perh. from French), Ir.
<ets>leige</ets> (perh. from English); also Ir. & Gael. <ets>leac</ets>
a flag, a broad, flat stone, W. <ets>llech</ets>, -- such stones having
perh. served as a sort of milestone (cf. <er>Cromlech</er>).]</ety>
<sn>1.</sn> <def>A measure of length or distance, varying in different
countries from about 2.4 to 4.6 English statute miles of 5,280 feet
each, and used (as a land measure) chiefly on the continent of Europe,
and in the Spanish parts of America. The <xex>marine league</xex> of
England and the United States is equal to three marine, or geographical,
miles of 6080 feet each.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The English land league is equal to three English
statute miles. The Spanish and French leagues vary in each country
according to usage and the kind of measurement to which they are
applied. The Dutch and German leagues contain about four geographical
miles, or about 4.6 English statute miles.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stone erected near a public road to mark the
distance of a league.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>League</ent><br/
<hw>League</hw> <pr>(l<emac/g)</pr>, <pos>n.</pos> <ety>[F.
<ets>ligue</ets>, LL. <ets>liga</ets>, fr. L. <ets>ligare</ets> to bind;
cf. Sp. <ets>liga</ets>. Cf. <er>Ally</er> a confederate,
<er>Ligature</er>.]</ety> <sn>1.</sn> <def>An alliance or combination of
two or more nations, parties, organizations, or persons, for the
accomplishment of a purpose which requires a continued course of action,
as for mutual defense, or for furtherance of commercial, religious, or
political interests, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And let there be<br/
'Twixt us and them no <qex>league</qex>, nor amity.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <fld>(Sports)</fld>
<def>An association of sports teams that establishes rules of play,
decides questions of membership in the league, and organizes matches
between the member teams. In some cases a sports league is called a
<altname>conference</altname>, as in the <stype>National Football
Conference</stype>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ A <xex>league</xex> may be <xex>offensive</xex> or
<xex>defensive</xex>, or both; <xex>offensive</xex>, when the parties
agree to unite in attacking a common enemy; <xex>defensive</xex>, when
they agree to a mutual defense of each other against an
enemy.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Holy League</b></col>, <cd>an alliance of Roman
Catholics formed in 1576 by influence of the Duke of Guise for the
exclusion of Protestants from the throne of France.</cd> --
<col><b>Solemn League and Covenant</b></col>. <cd>See
<er>Covenant</er>,2.</cd> -- <col><b>The land league</b></col>, <cd>an
association, organized in Dublin in 1879, to promote the interests of
the Irish tenantry, its avowed objects being to secure fixity of tenure,
fair rent, and free sale of the tenants' interest. It was declared
illegal by Parliament, but vigorous prosecutions have failed to suppress
it.</cd></cs></p>

<p><syn><b>Syn.</b> -- Alliance; confederacy; confederation; coalition;
combination; compact; cooperation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>League</ent><br/
<hw>League</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Leagued</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leaguing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F. <ets>se
liguer</ets>. See 2d <er>League</er>.]</ety> <def>To unite in a league
or confederacy; to combine for mutual support; to confederate.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>League</ent><br/
<hw>League</hw>, <pos>v. t.</pos> <def>To join in a league; to cause to
combine for a joint purpose; to combine; to unite; <as>as, common
interests will <ex>league</ex> heterogeneous elements</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaguer</ent><br/
<hw>Lea"guer</hw>, <pos>n.</pos> <ety>[D. <ets>leger</ets> camp, bed,
couch, lair. See <er>Lair</er>, and cf.<er>Beleaguer</er>.]</ety>
<sn>1.</sn> <def>The camp of a besieging army; a camp in general.</def>
<rj><au>b. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A siege or beleaguering.</def> <mark>[R.]</mark>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaguer</ent><br/
<hw>Lea"guer</hw>, <pos>v. t.</pos> <def>To besiege; to beleaguer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaguerer</ent><br/
<hw>Lea"guer*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A besieger.</def>
<mark>[R.]</mark> <rj><au>J. Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leak</ent><br/
<hw>Leak</hw> <pr>(l<emac/k)</pr>, <pos>n.</pos> <ety>[Akin to D.
<ets>lek</ets> leaky, a leak, G. <ets>leck</ets>, Icel. <ets>lekr</ets>
leaky, Dan. <ets>l<ae/k</ets> leaky, a leak, Sw. <ets>l<aum/ck</ets>;
cf. AS. <ets>hlec</ets> full of cracks or leaky. Cf. <er>Leak</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>A crack, crevice, fissure, or hole
which admits water or other fluid, or lets it escape; <as>as, a
<ex>leak</ex> in a roof; a <ex>leak</ex> in a boat; a <ex>leak</ex> in a
gas pipe.</as></def> <ldquo/One <xex>leak</xex> will sink a ship.<rdquo/
<rj><au>Bunyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The entrance or escape of a fluid through a crack,
fissure, or other aperture; <as>as, the <ex>leak</ex> gained on the
ship's pumps</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Elec.)</fld> <def>A loss of electricity through
imperfect insulation; also, the point at which such loss
occurs.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>an act of urinating; -- used mostly in the phrase
<col><b>take a leak</b></col>, <it>i. e.</it> to urinate.</def>
<mark>[vulgar]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>The disclosure of information that is expected to be
kept confidential; <as>as, <ex>leaks</ex> by the White House staff
infuriated Nixon; <ex>leaks</ex> by the Special Prosecutor were
criticized as illegal</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To spring a leak</b></col>, <cd>to open or crack so as to
let in water; to begin to let in water; <as>as, the ship <ex>sprung a
leak</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leak</ent><br/
<hw>Leak</hw>, <pos>a.</pos> <def>Leaky.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leak</ent><br/
<hw>Leak</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leaked</conjf> <pr>(l<emac/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leaking</conjf>.]</vmorph> <ety>[Akin to D. <ets>lekken</ets>, G.
<ets>lecken</ets>, <ets>lechen</ets>, Icel. <ets>leka</ets>, Dan.
<ets>l<ae/kke</ets>, Sw. <ets>l<aum/cka</ets>, AS. <ets>leccan</ets> to
wet, moisten. See <er>Leak</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>To let water or other fluid in or out through a hole, crevice,
etc.; <as>as, the cask <ex>leaks</ex>; the roof <ex>leaks</ex>; the boat
<ex>leaks</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enter or escape, as a fluid, through a hole,
crevice, etc.; to pass gradually into, or out of, something; -- usually
with <ptcl>in</ptcl> or <ptcl>out</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To leak out</b></col>, <cd>to be divulged gradually or
clandestinely; to become public; as, <as>the facts <ex>leaked
out</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leakage</ent><br/
<hw>Leak"age</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>lekkage</ets>, for sense 1.]</ety> <sn>1.</sn> <def>A leaking;
also, the quantity that enters or issues by leaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>An allowance of a certain rate per
cent for the leaking of casks, or waste of liquors by leaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Elec.)</fld> <def>A <er>leak{3}</er>; also; the
quantity of electricity thus wasted.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Leakiness</ent><br/
<hw>Leak"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being leaky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leaking</ent><br/
<hw>leak"ing</hw> <pos>adj.</pos> <def>having liquid seeping in or out
through openings; leaky.</def><br/
<syn><b>Syn. --</b> leaky.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leakproof</ent><br/
<hw>leak"proof`</hw> <pos>adj.</pos> <def>having no leaks.</def><br/
<syn><b>Syn. --</b> watertight.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leaky</ent><br/
<hw>Leak"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Leakier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Leakiest</adjf>.]</amorph> <sn>1.</sn> <def>Permitting water or
other fluid to leak in or out; <as>as, a <ex>leaky</ex> roof or cask; a
<ex>leaky</ex> faucet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Apt to disclose secrets; tattling; not close.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Genetics)</fld> <def>Retaining some function; not
completely inactivating the gene; <as>as, substitution mutations are
sometimes <ex>leaky</ex></as>; -- of mutations.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leal</ent><br/
<hw>Leal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>leial</ets>,
another form of <ets>loial</ets>, F. <ets>loyal</ets>. See
<er>Loyal</er>.]</ety> <def>Faithful; loyal; true.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All men true and <qex>leal</qex>, all women pure.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Land of the leal</b></col>, <cd>the place of the
faithful; heaven.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leam</ent><br/
<hw>Leam</hw> <pr>(?)</pr>, <pos>n. & v. i.</pos> <def>See
<er>Leme</er>.</def> <mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leam</ent><br/
<hw>Leam</hw>, <pos>n.</pos> <ety>[See <er>Leamer</er>,
<er>Lien</er>.]</ety> <def>A cord or strap for leading a dog.</def>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leamer</ent><br/
<hw>Leam"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>limier</ets>,
OF. <ets>liemier</ets>, fr. L. <ets>ligamen</ets> band, bandage. See
<er>Lien</er>.]</ety> <def>A dog held by a leam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean</ent><br/
<hw>Lean</hw> <pr>(l<emac/n)</pr>, <pos>v. t.</pos> <ety>[Icel.
<ets>leyna</ets>; akin to G. <ets>l<aum/ugnen</ets> to deny, AS.
<ets>l<ymac/gnian</ets>, also E. <ets>lie</ets> to speak falsely.]</ety>
<def>To conceal.</def> <mark>[Obs.]</mark> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean</ent><br/
<hw>Lean</hw> <pr>(l<emac/n)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Leaned</conjf> <pr>(l<emac/nd)</pr>, sometimes
<conjf>Leant</conjf> (l<ecr/nt); <pos>p. pr. & vb. n.</pos>
<conjf>Leaning</conjf>.]</vmorph> <ety>[OE. <ets>lenen</ets>, AS.
<ets>hlinian</ets>, <ets>hleonian</ets>, <pos>v. i.</pos>; akin to OS.
<ets>hlin<omac/n</ets>, D. <ets>leunen</ets>, OHG.
<ets>hlin<emac/n</ets>, <ets>lin<emac/n</ets>, G. <ets>lehnen</ets>, L.
<ets>inclinare</ets>, Gr. <grk>kli`nein</grk>, L. <ets>clivus</ets>
hill, slope. <root/40. Cf. <er>Declivity</er>, <er>Climax</er>,
<er>Incline</er>, <er>Ladder</er>.]</ety> <sn>1.</sn> <def>To incline,
deviate, or bend, from a vertical position; to be in a position thus
inclining or deviating; <as>as, she <ex>leaned</ex> out at the window; a
<ex>leaning</ex> column.</as></def> <ldquo/He <xex>leant</xex>
forward.<rdquo/ <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To incline in opinion or desire; to conform in
conduct; -- with <ptcl>to</ptcl>, <ptcl>toward</ptcl>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They delight rather to <qex>lean</qex> to their old customs.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To rest or rely, for support, comfort, and the like;
-- with <ptcl>on</ptcl>, <ptcl>upon</ptcl>, or
<ptcl>against</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>leaned</qex> not on his fathers but himself.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean</ent><br/
<hw>Lean</hw>, <pos>v. t.</pos> <ety>[From <er>Lean</er>, <pos>v.
i.</pos>; AS. <ets>hl<aemac/nan</ets>, v. t., fr. <ets>hleonian</ets>,
<ets>hlinian</ets>, <pos>v. i.</pos>]</ety> <def>To cause to lean; to
incline; to support or rest.</def> <rj><au>Mrs. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His fainting limbs against an oak he <qex>leant</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean</ent><br/
<hw>Lean</hw> <pr>(l<emac/n)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Leaner</adjf>
<pr>(l<emac/n"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Leanest</adjf>.]</amorph> <ety>[OE. <ets>lene</ets>, AS.
<ets>hl<aemac/ne</ets>; prob. akin to E. <ets>lean</ets> to incline. See
<er>Lean</er>, <pos>v. i.</pos> ]</ety> <sn>1.</sn> <def>Wanting flesh;
destitute of or deficient in fat; slim; not plump; slender; meager;
thin; lank; <as>as, a <ex>lean</ex> body; a <ex>lean</ex>
cattle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting fullness, richness, sufficiency, or
productiveness; deficient in quality or contents; slender; scant;
barren; bare; mean; -- used literally and figuratively; <as>as, the
<ex>lean</ex> harvest; a <ex>lean</ex> purse; a <ex>lean</ex> discourse;
<ex>lean</ex> wages.</as></def> <ldquo/No <xex>lean</xex>
wardrobe.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their <qex>lean</qex> and flashy songs.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What the land is, whether it be fat or <qex>lean</qex>.</q>
<rj><qau>Num. xiii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Out of my <qex>lean</qex> and low ability<br/
I'll lend you something.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Typog.)</fld> <def>Of a character which prevents
the compositor from earning the usual wages; -- opposed to
<ant>fat</ant>; <as>as, <ex>lean</ex> copy, matter, or
type</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- slender; spare; thin; meager; lank; skinny;
gaunt.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean</ent><br/
<hw>Lean</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That part of
flesh which consists principally of muscle without the fat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fat was so white and the <qex>lean</qex> was so ruddy.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Typog.)</fld> <def>Unremunerative copy or
work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean-faced</ent><br/
<hw>Lean"-faced`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a thin face.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Typog.)</fld> <def>slender or narrow; -- said of
type the letters of which have thin lines, or are unusually narrow in
proportion to their height.</def> <rj><au>W. Savage.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaning</ent><br/
<hw>Lean"ing</hw>, <pos>n.</pos> <def>The act, or state, of inclining;
inclination; tendency; <as>as, a <ex>leaning</ex> towards
Calvinism</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leanly</ent><br/
<hw>Lean"ly</hw>, <pos>adv.</pos> <def>Meagerly; without fat or
plumpness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leanness</ent><br/
<hw>Lean"ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>hl<aemac/nnes</ets>.]</ety> <def>The condition or quality of being
lean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean-to</ent><br/
<hw>Lean"-to`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Arch.)</fld>
<def>Having only one slope or pitch; -- said of a roof.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lean-to</ent><br/
<hw>Lean"-to`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Arch.)</fld> <def>A shed or slight building placed against the
wall of a larger structure and having a single-pitched roof; -- called
also <altname>penthouse</altname>, and
<altname>to-fall</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The outer circuit was covered as a <qex>lean-to</qex>, all round
this inner apartment.</q> <rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A crude, usually temporary shelter comprising a
lean-to roof braced against any convenient support, as a wall, a tree or
a pole. The roof may extend all the way to the ground.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lean-witted</ent><br/
<hw>Lean"-wit`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having but
little sense or shrewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leany</ent><br/
<hw>Lean"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lean.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leap</ent><br/
<hw>Leap</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>le<aacute/p</ets>.]</ety> <sn>1.</sn> <def>A basket.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A weel or wicker trap for fish.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leap</ent><br/
<hw>Leap</hw> <pr>(l<emac/p)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Leaped</conjf> <pr>(l<emac/pt; 277)</pr>, rarely
<conjf>Leapt</conjf> <pr>(l<emac/pt <it>or</it> l<ecr/pt)</pr>; <pos>p.
pr. & vb. n.</pos> <conjf>Leaping</conjf>.]</vmorph> <ety>[OE.
<ets>lepen</ets>, <ets>leapen</ets>, AS. <ets>hle<aacute/pan</ets> to
leap, jump, run; akin to OS. <ets><amac/hl<omac/pan</ets>, OFries.
<ets>hlapa</ets>, D. <ets>loopen</ets>, G. <ets>laufen</ets>, OHG.
<ets>louffan</ets>, <ets>hlauffan</ets>, Icel. <ets>hlaupa</ets>, Sw.
<ets>l<oum/pa</ets>, Dan. <ets>l<oum/be</ets>, Goth.
<ets>ushlaupan</ets>. Cf. <er>Elope</er>, <er>Lope</er>,
<er>Lapwing</er>, <er>Loaf</er> to loiter.]</ety> <sn>1.</sn> <def>To
spring clear of the ground, with the feet; to jump; to vault; <as>as, a
man <ex>leaps</ex> over a fence, or <ex>leaps</ex> upon a
horse</as>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> <qex>Leap</qex> in with me into this angry flood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spring or move suddenly, as by a jump or by
jumps; to bound; to move swiftly. Also Fig.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My heart <qex>leaps</qex> up when I behold<br/
A rainbow in the sky.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leap</ent><br/
<hw>Leap</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To pass over by a leap
or jump; <as>as, to <ex>leap</ex> a wall, or a ditch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To copulate with (a female beast); to
cover.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to leap; <as>as, to <ex>leap</ex> a horse
across a ditch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leap</ent><br/
<hw>Leap</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of leaping, or the
space passed by leaping; a jump; a spring; a bound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wickedness comes on by degrees, . . . and sudden <qex>leaps</qex>
from one extreme to another are unnatural.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Changes of tone may proceed either by <qex>leaps</qex> or
glides.</q> <rj><qau>H. Sweet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Copulation with, or coverture of, a female
beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mining)</fld> <def>A fault.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>A passing from one note to another
by an interval, especially by a long one, or by one including several
other and intermediate intervals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaper</ent><br/
<hw>Leap"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hle<aacute/pere</ets>.]</ety> <def>One who, or that which,
leaps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaper</ent><br/
<hw>Leap"er</hw>, <pos>n.</pos> <ety>[See 1st <er>Leap</er>.]</ety>
<def>A kind of hooked instrument for untwisting old cordage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leapfrog</ent><br/
<hw>Leap"frog`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A play among boys,
in which one stoops down and another leaps over him by placing his hands
on the shoulders of the former.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leapful</ent><br/
<hw>Leap"ful</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Leap</er>.]</ety> <def>A basketful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaping</ent><br/
<hw>Leap"ing</hw>, <pos>a. & n.</pos> <def>from <er>Leap</er>, to
jump.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leaping house</b></col>, <cd>a brothel.</cd>
<mark>[Obs.]</mark> <au>Shak.</au> -- <col><b>Leaping pole</b></col>,
<cd>a pole used in some games of leaping.</cd> -- <col><b>Leaping
spider</b></col> <fld>(Zool.)</fld>, <cd>a jumping spider; one of the
<fam>Saltigrad<ae/</fam>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leapingly</ent><br/
<hw>Leap"ing*ly</hw>, <pos>adv.</pos> <def>By leaps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leap year</ent><br/
<hw>Leap" year`</hw> <pr>(?)</pr> <pos>n.</pos><def>Bissextile; a year
containing 366 days; every fourth year which <xex>leaps</xex> over a day
more than a common year, giving to February twenty-nine days. See
<er>Bissextile</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Every year whose number is divisible by four without a
remainder is a leap year, excepting the full centuries, which, to be
leap years, must be divisible by 400 without a remainder. If not so
divisible they are common years. 1900, therefore, is not a leap year,
but 2000 is.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lear</ent><br/
<hw>Lear</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To learn. See
<er>Lere</er>, to learn.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lear</ent><br/
<hw>Lear</hw>, <pos>n.</pos> <def>Lore; lesson.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lear</ent><br/
<hw>Lear</hw>, <pos>a.</pos> <def>See <er>Leer</er>, <pos>a.</pos></def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lear</ent><br/
<hw>Lear</hw>, <pos>n.</pos> <def>An annealing oven. See <er>Leer</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Learn</ent><br/
<hw>Learn</hw> <pr>(l<etil/rn)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Learned</conjf> <pr>(l<etil/rnd)</pr>, or
<conjf>Learnt</conjf> (l<etil/rnt); <pos>p. pr. & vb. n.</pos>
<conjf>Learning</conjf>.]</vmorph> <ety>[OE. <ets>lernen</ets>,
<ets>leornen</ets>, AS. <ets>leornian</ets>; akin to OS.
<ets>lin<omac/n</ets>, for <ets>lirn<omac/n</ets>, OHG.
<ets>lirn<emac/n</ets>, <ets>lern<emac/n</ets>, G. <ets>lernen</ets>,
fr. the root of AS. <ets>l<aemac/ran</ets> to teach, OS.
<ets>l<emac/rian</ets>, OHG. <ets>l<emac/ran</ets>, G.
<ets>lehren</ets>, Goth. <ets>laisjan</ets>, also Goth <ets>lais</ets> I
know, <ets>leis</ets> acquainted (in comp.); all prob. from a root
meaning, to go, go over, and hence, to learn; cf. AS. <ets>leoran</ets>
to go. Cf. <er>Last</er> a mold of the foot, <er>lore</er>.]</ety>
<sn>1.</sn> <def>To gain knowledge or information of; to ascertain by
inquiry, study, or investigation; to receive instruction concerning; to
fix in the mind; to acquire understanding of, or skill; <as>as, to
<ex>learn</ex> the way; to <ex>learn</ex> a lesson; to <ex>learn</ex>
dancing; to <ex>learn</ex> to skate; to <ex>learn</ex> the violin; to
<ex>learn</ex> the truth about something.</as></def>
<ldquo/<xex>Learn</xex> to do well.<rdquo/ <rj><au>Is. i.
17.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now <qex>learn</qex> a parable of the fig tree.</q> <rj><qau>Matt.
xxiv. 32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To communicate knowledge to; to teach.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Hast thou not <qex>learned</qex> me how<br/
To make perfumes ?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Learn</xex> formerly had also the sense of
<xex>teach</xex>, in accordance with the analogy of the French and other
languages, and hence we find it with this sense in Shakespeare, Spenser,
and other old writers. This usage has now passed away. To
<xex>learn</xex> is to receive instruction, and to <xex>teach</xex> is
to give instruction. He who is <xex>taught</xex> learns, not he who
<xex>teaches</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Learn</ent><br/
<hw>Learn</hw>, <pos>v. i.</pos> <def>To acquire knowledge or skill; to
make progress in acquiring knowledge or skill; to receive information or
instruction; <as>as, this child <ex>learns</ex> quickly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Take my yoke upon you and <qex>learn</qex> of me.</q>
<rj><qau>Matt. xi. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To learn by heart</b></col>. <cd>See <cref>By
heart</cref>, under <er>Heart</er>.</cd> -- <col><b>To learn by
rote</b></col>, <cd>to memorize by repetition without exercise of the
understanding.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 839 --></p>

<p><ent>Learnable</ent><br/
<hw>Learn"a*ble</hw> <pr>(l<etil/rn"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Such as can be learned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Learned</ent><br/
<hw>Learn"ed</hw> <pr>(l<etil/rn"<ecr/d)</pr>, <pos>a.</pos> <def>Of or
pertaining to learning; possessing, or characterized by, learning, esp.
scholastic learning; erudite; well-informed; <as>as, a <ex>learned</ex>
scholar, writer, or lawyer; a <ex>learned</ex> book; a <ex>learned</ex>
theory.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>learned</qex>lover lost no time.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men of much reading are greatly <qex>learned</qex>, but may be
little knowing.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Words of <qex>learned</qex> length and thundering sound.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The learned</b></col>, <cd>learned men; men of erudition;
scholars.</cd></cs></p>

<p>-- <wordforms><wf>Learn"ed*ly</wf>, <pos>adv.</pos>
<wf>Learn"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Every coxcomb swears as <qex>learnedly</qex> as they.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>learnedness</ent><br/
<hw>learn"ed*ness</hw> <pos>n.</pos> <def>profound knowledge.</def><br/
<syn><b>Syn. --</b> eruditeness, erudition, learning,
scholarship.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Learner</ent><br/
<hw>Learn"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who learns; a
scholar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Learning</ent><br/
<hw>Learn"ing</hw>, <pos>n.</pos> <ety>[AS. <ets>leornung</ets>.]</ety>
<sn>1.</sn> <def>The acquisition of knowledge or skill; <as>as, the
<ex>learning</ex> of languages; the <ex>learning</ex> of
telegraphy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The knowledge or skill received by instruction or
study; acquired knowledge or ideas in any branch of science or
literature; erudition; literature; science; <as>as, he is a man of great
<ex>learning</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Book learning</b></col>. <cd>See under
<er>Book</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Literature; erudition; lore; scholarship;
science; letters. See <er>Literature</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leasable</ent><br/
<hw>Leas"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From 2d
<er>Lease</er>.]</ety> <def>Such as can be leased.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lease</ent><br/
<hw>Lease</hw> <pr>(l<emac/z)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>lesan</ets> to gather; akin to D. <ets>lezen</ets> to gather, read,
G. <ets>lesen</ets>, Goth. <ets>lisan</ets> to gather; cf. Lith
<ets>lesti</ets> to peck.]</ety> <def>To gather what harvesters have
left behind; to glean.</def> <mark>[Obs.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lease</ent><br/
<hw>Lease</hw> <pr>(l<emac/s)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Leased</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Leasing</conjf>.]</vmorph> <ety>[F. <ets>laisser</ets>,
OF. <ets>laissier</ets>, <ets>lessier</ets>, to leave, transmit, L.
<ets>laxare</ets> to loose, slacken, from <ets>laxus</ets> loose, wide.
See <er>Lax</er>, and cf. <er>Lesser</er>.]</ety> <sn>1.</sn> <def>To
grant to another by lease the possession of, as of lands, tenements, and
hereditaments; to let; to demise; <as>as, a landowner <ex>leases</ex> a
farm to a tenant</as>; -- sometimes with <ptcl>out</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There were some [houses] that were <qex>leased</qex> out for three
lives.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hold under a lease; to take lease of; <as>as, a
tenant <ex>leases</ex> his land from the owner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lease</ent><br/
<hw>Lease</hw> <pr>(l<emac/s)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>lais</ets>. See <er>Lease</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<def>The temporary transfer of a possession to another person in return
for a fee or other valuable consideration paid for the transfer;</def>
<specif>especially,</specif> <def>A demise or letting of lands,
tenements, or hereditaments to another for life, for a term of years, or
at will, or for any less interest than that which the lessor has in the
property, usually for a specified rent or compensation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The contract for such letting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any tenure by grant or permission; the time for
which such a tenure holds good; allotted time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our high-placed Macbeth<br/
Shall live the <qex>lease</qex> of nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lease and release</b></col> <cd>a mode of conveyance of
freehold estates, formerly common in England and in New York. its place
is now supplied by a simple deed of grant.</cd> <rj><au>Burrill.</au>
<au>Warren's Blackstone.</au></rj> </cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leasehold</ent><br/
<hw>Lease"hold`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Held by
lease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leasehold</ent><br/
<hw>Lease"hold`</hw>, <pos>n.</pos> <def>A tenure by lease;
specifically, land held as personalty under a lease for years.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaseholder</ent><br/
<hw>Lease"hold`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tenant under a
lease.</def> -- <wordforms><wf>Lease"hold`ing</wf>, <pos>a. &
n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lease-lend</ent><br/
<hw>lease-lend</hw> <pos>n.</pos> <def>Same as
<er>lend-lease</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leaser</ent><br/
<hw>Leas"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From 1st
<er>Lease</er>.]</ety> <def>One who leases or gleans.</def>
<mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaser</ent><br/
<hw>Leas"er</hw>, <pos>n.</pos> <def>A liar.</def> <mark>[Obs.]</mark>
<see>See <er>Leasing</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leash</ent><br/
<hw>Leash</hw> <pr>(l<emac/sh)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lese</ets>, <ets>lees</ets>, <ets>leece</ets>, OF.
<ets>lesse</ets>, F. <ets>laisse</ets>, LL. <ets>laxa</ets>, fr. L.
<ets>laxus</ets> loose. See <er>Lax</er>.]</ety> <sn>1.</sn> <def>A
thong of leather, or a long cord, by which a person may hold or restrain
an animal, such as a falconer holding his hawk, or a courser his dog.
For dogs and cats, the <ex>leash</ex> is commonly attached to a collar
around the neck of the animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even like a fawning greyhound in the <qex>leash</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Sporting)</fld> <def>A brace and a half; a tierce;
three; three creatures of any kind, especially greyhounds, foxes, bucks,
and hares; hence, the number three in general.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[I] kept my chamber a <qex>leash</qex> of days.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then were I wealthier than a <qex>leash</qex> of kings.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Weaving)</fld> <def>A string with a loop at the end
for lifting warp threads, in a loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To keep (a person) on a short leash</b></col> <cd>to
maintain close control over the activities of (a person).</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Leash</ent><br/
<hw>Leash</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leashed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leashing</conjf>.]</vmorph> <def>To tie together, or hold, with a
leash.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leasing</ent><br/
<hw>Leas"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>le<aacute/sung</ets>, fr. <ets>le<aacute/s</ets> loose, false,
deceitful. See <er>-less</er>, <er>Loose</er>, <pos>a.</pos>]</ety>
<def>The act of lying; falsehood; a lie or lies.</def>
<mark>[Archaic]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt destroy them that speak <qex>leasing</qex>.</q>
<rj><qau>Ps. v. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Blessed be the lips that such a <qex>leasing</qex> told.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leasing making</b></col> <fld>(Scots Law)</fld>, <cd>the
uttering of lies or libels upon the personal character of the sovereign,
his court, or his family.</cd> <rj><au>Bp. Burnet.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leasow</ent><br/
<hw>Lea"sow</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>lesu</ets>,
<ets>l<ae/su</ets>.]</ety> <def>A pasture.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Least</ent><br/
<hw>Least</hw> <pr>(l<emac/st)</pr>, <pos>a.</pos> <ety>[OE.
<ets>last</ets>, <ets>lest</ets>, AS. <ets>l<aemac/sast</ets>,
<ets>l<aemac/sest</ets>, superl. of <ets>l<aemac/ssa</ets> less. See
<er>Less</er>, <pos>a.</pos>]</ety> <mark>[Used as the superlative of
<xex>little</xex>.]</mark> <def>Smallest, either in size or degree;
shortest; lowest; most unimportant; <as>as, the <ex>least</ex> insect;
the <ex>least</ex> mercy; the <ex>least</ex> space.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Least</xex> is often used with <xex>the</xex>, as
if a noun.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>I am the <qex>least</qex> of the apostles.</q> <rj><qau>1 Cor. xv.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>At least</b></col>, <it>or</it> <col><b>At the
least</b></col></mcol>, <cd>at the least estimate, consideration,
chance, etc.; being no less than; hence, at any rate; at all events;
even. See <er>However</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>He who tempts, though in vain, <qex>at least</qex> asperses<br/
The tempted with dishonor.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon the mast they saw a young man, <qex>at least</qex> if he were
a man, who sat as on horseback.</q> <rj><qau>Sir P.
Sidney.</qau></rj></p>

<p>-- <mcol><col><b>In least</b></col>, <it>or</it> <col><b>In the
least</b></col></mcol>, <cd>in the least degree, manner, etc.</cd>
<ldquo/He that is unjust <xex>in the least</xex> is unjust also in
much.<rdquo/ <au>Luke xvi. 10.</au> -- <col><b>Least squares</b></col>
<fld>(Math.)</fld>, <cd>a method of deducing from a number of carefully
made yet slightly discordant observations of a phenomenon the most
probable values of the unknown quantities.</cd> <note>It takes as its
fundamental principle that the most probable values are those which make
the sum of the squares of the residual errors of the observation a
minimum.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Least</ent><br/
<hw>Least</hw>, <pos>adv.</pos> <def>In the smallest or lowest degree;
in a degree below all others; <as>as, to reward those who <ex>least</ex>
deserve it</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Least</ent><br/
<hw>Least</hw>, <pos>conj.</pos> <def>See <er>Lest</er>,
<pos>conj.</pos></def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leastwise</ent><br/
<ent>Leastways</ent><br/
<mhw>{ <hw>Least"ways`</hw> <pr>(?)</pr>, <hw>Least"wise`</hw>
<pr>(?)</pr>, }</mhw> <pos>adv.</pos> <def>At least; at all
events.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>At leastways</b></col>, <it>or</it> <col><b>At
leastwise</b></col></mcol>, <cd>at least.</cd> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leasy</ent><br/
<hw>Lea"sy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>le<aacute/s</ets> void, loose, false. Cf. <er>Leasing</er>.]</ety>
<def>Flimsy; vague; deceptive.</def> <mark>[Obs.]</mark>
<rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leat</ent><br/
<hw>Leat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Lead</er> to
conduct.]</ety> <def>An artificial water trench, esp. one to or from a
mill.</def> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leather</ent><br/
<hw>Leath"er</hw> <pr>(l<ecr/<th/"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lether</ets>, AS. <ets>le<edh/er</ets>; akin to D.
<ets>leder</ets>, <ets>le<ecir/r</ets>, G. <ets>leder</ets>, OHG.
<ets>ledar</ets>, Icel. <ets>le<edh/r</ets>, Sw. <ets>l<aum/der</ets>,
Dan. <ets>l<ae/der</ets>.]</ety> <sn>1.</sn> <def>The skin of an animal,
or some part of such skin, with the hair removed, and tanned, tawed, or
otherwise dressed for use; also, dressed hides, collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The skin.</def> <mark>[Ironical or
Sportive]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Leather</xex> is much used adjectively in the sense
of <xex>made of</xex>, <xex>relating to</xex>, <xex>or like</xex>,
<xex>leather</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leather board</b></col>, <cd>an imitation of sole
leather, made of leather scraps, rags, paper, etc.</cd> --
<col><b>Leather carp</b></col> <fld>(Zool.)</fld> <cd>, a variety of
carp in which the scales are all, or nearly all, absent. See
<xex>Illust.</xex> under <er>Carp</er>.</cd> -- <col><b>Leather
jacket</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A California
carangoid fish (<spn>Oligoplites saurus</spn>).</cd> <sd>(b)</sd> <cd>A
trigger fish (<spn>Balistes Carolinensis</spn>).</cd> -- <col><b>Leather
flower</b></col> <fld>(Bot.)</fld>, <cd>a climbing plant (<spn>Clematis
Viorna</spn>) of the Middle and Southern States having thick, leathery
sepals of a purplish color.</cd> -- <col><b>Leather leaf</b></col>
<fld>(Bot.)</fld>, <cd>a low shrub (<spn>Cassandra calyculata</spn>),
growing in Northern swamps, and having evergreen, coriaceous, scurfy
leaves.</cd> -- <col><b>Leather plant</b></col> <fld>(Bot.)</fld>,
<cd>one or more New Zealand plants of the composite genus
<gen>Celmisia</gen>, which have white or buff tomentose leaves.</cd> --
<col><b>Leather turtle</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Leatherback</er>.</cd> -- <col><b>Vegetable leather</b></col>.
<sd>(a)</sd> <cd>An imitation of leather made of cotton waste.</cd>
<sd>(b)</sd> <cd>Linen cloth coated with India rubber.</cd>
<rj><au>Ure.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leather</ent><br/
<hw>Leath"er</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leathered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leathering</conjf>.]</vmorph> <def>To beat, as with a thong of
leather.</def> <mark>[Obs. or Colloq.]</mark> <rj><au>G.
Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>leather</ent><br/
<hw>leath"er</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining to or
made of leather; consisting of leather; <as>as, a black <ex>leather</ex>
jacket</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leatherback</ent><br/
<hw>Leath"er*back`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A large sea turtle (<spn>Sphargis coriacea</spn>), having no bony
shell on its back. It is common in the warm and temperate parts of the
Atlantic, and sometimes weighs over a thousand pounds; -- called also
<altname>leather turtle</altname>, <altname>leathery turtle</altname>,
<altname>leather-backed tortoise</altname>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leatherette</ent><br/
<ent>Leatheret</ent><br/
<mhw>{ <hw>Leath"er*et</hw> <pr>(?)</pr>, <hw>Leath`er*ette"</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[<ets>Leather</ets> +
<ets>et</ets>, F. <ets>-ette</ets>.]</ety> <def>A material made in
imitation of leather, made of paper and cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leatherfish</ent><br/
<hw>leatherfish</hw> <pos>n.</pos> <def>any of several brightly colored
tropical filefishes.</def><br/
<syn><b>Syn. --</b> leatherjacket.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leatherhead</ent><br/
<hw>Leath"er*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The friar bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leatherjack</ent><br/
<hw>leatherjack</hw> <pos>n.</pos> <def>any of several New World
tropical fishes having tiny embedded scales; the
leatherjacket{2}.</def><br/
<syn><b>Syn. --</b> leatherjacket.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leatherjacket</ent><br/
<hw>leatherjacket</hw> <pos>n.</pos> <sn>1.</sn> <def>any of several
brightly colored tropical filefishes.</def><br/
<syn><b>Syn. --</b> leatherfish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>any of several New World tropical fishes having tiny
embedded scales.</def><br/
<syn><b>Syn. --</b> leatherjack.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>The tough-skinned larva of certain crane
flies.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leatherleaf</ent><br/
<hw>leatherleaf</hw> <pos>n.</pos> <sn>1.</sn> <def>A stiff
leathery-leaved fern (<spn>Polypodium scouleri</spn>) of Western North
America having ovate fronds parted to the midrib.</def><br/
<syn><b>Syn. --</b> leathery polypody, coast polypody, <spn>Polypodium
scouleri</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A northern temperate bog shrub (<spn>Chamaedaphne
calyculata</spn>) with evergreen leathery leaves and small white
cylindrical flowers.</def><br/
<syn><b>Syn. --</b> <spn>Chamaedaphne calyculata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leatherlike</ent><br/
<hw>leatherlike</hw> <pos>adj.</pos> <def>resembling or made to resemble
leather; tough but pliable; leathery.</def><br/
<syn><b>Syn. --</b> coriaceous, leathered, leathery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leathern</ent><br/
<hw>Leath"ern</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of leather;
consisting of leather; <as>as, a <ex>leathern</ex> purse</as>.</def>
<ldquo/A <xex>leathern</xex> girdle about his loins.<rdquo/
<rj><au>Matt. iii. 4.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>leatherneck</ent><br/
<hw>leath"er*neck`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>The sordid friar bird of Australia
(<spn>Tropidorhynchus sordidus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[from the leather collar that was once part of their
uniform.]</ety> <def>A member of the United States Marine Corps; a
United States Marine.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Leatherwood</ent><br/
<hw>Leath"er*wood`</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A small
branching shrub (<spn>Dirca palustris</spn>), with a white, soft wood,
and a tough, leathery bark, common in damp woods in the Northern United
States; -- called also <altname>moosewood</altname>, and
<altname>wicopy</altname>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>leatherwork</ent><br/
<hw>leatherwork</hw> <pos>n.</pos> <def>Articles made of
leather.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leathery</ent><br/
<hw>Leath"er*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling leather
in appearance or consistency; tough; <as>as, nothing but a
<ex>leathery</ex> steak left to eat</as>.</def> <ldquo/A
<xex>leathery</xex> skin.<rdquo/ <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leave</ent><br/
<hw>Leave</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Leaved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leaving</conjf>]</vmorph> <def>To send out leaves; to leaf; --
often with <ptcl>out</ptcl>.</def> <rj><au>G. Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leave</ent><br/
<hw>Leave</hw>, <pos>v. t.</pos> <ety>[See <er>Levy</er>.]</ety> <def>To
raise; to levy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>An army strong she <qex>leaved</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leave</ent><br/
<hw>Leave</hw>, <pos>n.</pos> <ety>[OE. <ets>leve</ets>,
<ets>leave</ets>, AS. <ets>le<aacute/f</ets>; akin to
<ets>le<oacute/f</ets> pleasing, dear, E. <ets>lief</ets>, D.
oor<ets>lof</ets> leave, G. ar<ets>laub</ets>, and er<ets>lauben</ets>
to permit, Icel. <ets>leyfi</ets>. <root/124. See <er>Lief</er>.]</ety>
<sn>1.</sn> <def>Liberty granted by which restraint or illegality is
removed; permission; allowance; license.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>David earnestly asked <qex>leave</qex> of me.</q> <rj><qau>1 Sam.
xx. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No friend has <qex>leave</qex> to bear away the dead.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of leaving or departing; a formal parting; a
leaving; farewell; adieu; -- used chiefly in the phrase, <xex>to take
leave</xex>, i. e., literally, to take permission to go.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A double blessing is a'double grace;<br/
Occasion smiles upon a second <qex>leave</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And Paul after this tarried there yet a good while, and then took
his <qex>leave</qex> of the brethren.</q> <rj><qau>Acts xviii.
18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>French leave</b></col>. <cd>See under
<er>French</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- See <er>Liberty</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leave</ent><br/
<hw>Leave</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Left</conjf> <pr>(l<ecr/ft)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leaving</conjf>.]</vmorph> <ety>[OE. <ets>leven</ets>, AS.
<ets>l<?/fan</ets>, fr. <ets>l<amac/f</ets> remnant, heritage; akin to
<ets>lifian</ets>, <ets>libban</ets>, to live, orig., to remain; cf.
be<ets>l<imac/fan</ets> to remain, G. b<ets>leiben</ets>, Goth.
bi<ets>leiban</ets>. <root/119. See <er>Live</er>, <pos>v.</pos>]</ety>
<sn>1.</sn> <def>To withdraw one's self from; to go away from; to depart
from; <as>as, to <ex>leave</ex> the house</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore shall a man <qex>leave</qex> his father and his mother,
and shall cleave unto his wife.</q> <rj><qau>Gen. ii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To let remain unremoved or undone; to let stay or
continue, in distinction from what is removed or changed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If grape gatherers come to thee, would they not <qex>leave</qex>
some gleaning grapes ?</q> <rj><qau>Jer. xlix. 9. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These ought ye to have done, and not to <qex>leave</qex> the other
undone.</q> <rj><qau>Matt. xxiii. 23. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Besides it <qex>leaveth</qex> a suspicion, as if more might be
said than is expressed.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cease from; to desist from; to abstain
from.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now <qex>leave</qex> complaining and begin your tea.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To desert; to abandon; to forsake; hence, to give
up; to relinquish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lo, we have <qex>left</qex> all, and have followed thee.</q>
<rj><qau>Mark x. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The heresies that men do <qex>leave</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To let be or do without interference; <as>as, I
<ex>left</ex> him to his reflections; I <ex>leave</ex> my hearers to
judge.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>leave</qex> you now to your gossiplike humor.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To put; to place; to deposit; to deliver; to commit;
to submit -- with a sense of withdrawing one's self from; <as>as,
<ex>leave</ex> your hat in the hall; we <ex>left</ex> our cards; to
<ex>leave</ex> the matter to arbitrators.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Leave</qex> there thy gift before the altar and go thy
way.</q> <rj><qau>Matt. v. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The foot<br/
That <qex>leaves</qex> the print of blood where'er it walks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To have remaining at death; hence, to bequeath;
<as>as, he <ex>left</ex> a large estate; he <ex>left</ex> a good name;
he <ex>left</ex> a legacy to his niece.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>to cause to be; -- followed by an adjective or
adverb describing a state or condition; <as>as, the losses due to fire
<ex>leave</ex> me penniless; The cost of defending himself <ex>left</ex>
<person>Bill Clinton</person> with a mountain of lawyers'
bills</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>To leave alone</b></col>. <sd>(a)</sd> <cd>To leave in
solitude.</cd> <sd>(b)</sd> <cd>To desist or refrain from having to do
with; <as>as, <ex>to leave</ex> dangerous chemicals
<ex>alone</ex></as>.</cd> -- <col><b>To leave off</b></col>.
<sd>(a)</sd> <cd>To desist from; to forbear; to stop; <as>as, <ex>to
leave off</ex> work at six o'clock</as>.</cd> <sd>(b)</sd> <cd>To cease
wearing or using; to omit to put in the usual position; <as>as, <ex>to
leave off</ex> a garment; <ex>to leave off</ex> the
tablecloth</as>.</cd> <sd>(c)</sd> <cd>To forsake; <as>as, <ex>to leave
off</ex> a bad habit</as>.</cd> -- <col><b>To leave out</b></col>,
<cd>to omit; <as>as, <ex>to leave out</ex> a word or name in
writing</as>.</cd> -- <col><b>To leave to one's self</b></col>, <cd>to
let (one) be alone; to cease caring for (one).</cd></cs></p>

<p><syn>Syn>- To quit; depart from; forsake; abandon; relinquish;
deliver; bequeath; give up; forego; resign; surrender; forbear. See
<er>Quit</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leave</ent><br/
<hw>Leave</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
depart; to set out.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By the time I <qex>left</qex> for Scotland.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cease; to desist; to leave off.</def> <ldquo/He .
. . began at the eldest, and <xex>left</xex> at the youngest.<rdquo/
<rj><au>Gen. xliv. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To leave off</b></col>, <cd>to cease; to desist; to
stop.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Leave off</qex>, and for another summons wait.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaved</ent><br/
<hw>Leaved</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Leaf</er>.]</ety> <def>Bearing, or having, a leaf or leaves; having
folds; -- used in combination; <as>as, a four<ex>-leaved</ex> clover; a
two-<ex>leaved</ex> gate; long<ex>-leaved</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaveless</ent><br/
<hw>Leave"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Leafless.</def>
<mark>[Obs.]</mark> <rj><au>Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaven</ent><br/
<hw>Leav"en</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>levain</ets>, <ets>levein</ets>, F. <ets>levain</ets>, L.
<ets>levamen</ets> alleviation, mitigation; but taken in the sense of, a
raising, that which raises, fr. <ets>levare</ets> to raise. See
<er>Lever</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Any substance that
produces, or is designed to produce, fermentation, as in dough or
liquids; esp., a portion of fermenting dough, which, mixed with a larger
quantity of dough, produces a general change in the mass, and renders it
light; yeast; barm.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything which makes a general assimilating
(especially a corrupting) change in the mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Beware of the <qex>leaven</qex> of the Pharisees, which is
hypocrisy.</q> <rj><qau>Luke xii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaven</ent><br/
<hw>Leav"en</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leavened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leavening</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To
make light by the action of leaven; to cause to ferment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A little leaven <qex>leaveneth</qex> the whole lump.</q>
<rj><qau>1 Cor. v. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To imbue; to infect; to vitiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With these and the like deceivable doctrines, he
<qex>leavens</qex> also his prayer.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>leavened</ent><br/
<hw>leavened</hw> <pos>adj.</pos> <def>made light by aerating, as with
yeast or baking powder. Opposite of <ant>unleavened</ant>.</def>
[Narrower terms: <stype>sourdough(prenominal) </stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leavening</ent><br/
<hw>Leav"en*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of making light, or causing to ferment, by means of
leaven.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which leavens or makes light.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leavenous</ent><br/
<hw>Leav"en*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
leaven.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaver</ent><br/
<hw>Leav"er</hw> <pr>(l<emac/v"<etil/r)</pr>, <pos>n.</pos> <def>One who
leaves, or withdraws.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaves</ent><br/
<hw>Leaves</hw> <pr>(l<emac/vz)</pr>, <pos>n.</pos>, <def><pos>pl.</pos>
of <er>Leaf</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leave-taking</ent><br/
<hw>Leave"-tak`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Taking of
leave; the act of departing politely; the giving of parting
compliments.</def> <rj><au>Shak.</au></rj><br/
<syn><b>Syn. --</b> farewell, leave, parting.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leaviness</ent><br/
<hw>Leav"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Fr.
<er>Leaf</er>.]</ety> <def>Leafiness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leavings</ent><br/
<hw>Leav"ings</hw>, <pos>n. pl.</pos> <sn>1.</sn> <def>Things left;
remnants; relics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Refuse; offal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leavy</ent><br/
<hw>Leav"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Leafy.</def>
<mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lebban</ent><br/
<ent>Leban</ent><br/
<mhw>{ <hw>Leb"an</hw>, <hw>Leb"ban</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>Coagulated sour milk diluted with water; -- a common
beverage among the Arabs. Also, a fermented liquor made of the
same.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecama</ent><br/
<hw>Le*ca"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The hartbeest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecanomancy</ent><br/
<hw>Le*can"o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>leka`nh</grk> bowl or basin + <ets>-mancy</ets>.]</ety>
<def>Divination practiced with water in a basin, by throwing three
stones into it, and invoking the demon whose aid was sought.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecanoric</ent><br/
<hw>Lec`a*no"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an organic acid which is obtained
from several varieties of lichen (<gen>Lecanora</gen>,
<gen>Roccella</gen>, etc.), as a white, crystalline substance, and is
called also <altname>orsellic acid</altname>, <altname>diorsellinic
acid</altname>, <altname>lecanorin</altname>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecanorin</ent><br/
<hw>Lec`a*no"rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Lecanoric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lech</ent><br/
<hw>Lech</hw> <pr>(l<ecr/ch)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>l<eacute/cher</ets>. See <er>Lick</er>.]</ety> <def>To lick.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>lech</ent><br/
<hw>lech</hw> <pr>(l<ecr/ch)</pr>, <pos>n. & v. i.</pos> <def>Same as
<er>letch</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lechanorales</ent><br/
<hw>Lechanorales</hw> <pos>n.</pos> <fld>(Biol.)</fld> <def>A category
used in some classification systems for all lichens that produce
apothecia.</def><br/
<syn><b>Syn. --</b> order <ord>Lechanorales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lechatelierite</ent><br/
<hw>lechatelierite</hw> <pos>n.</pos> <def>A naturally occurring
colorless glass made of almost pure silica, and found in fulgurites,
which are produced by lightning striking sand.</def><br/
<syn><b>Syn. --</b> quartz glass, vitreous silica, crystal.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Leche</ent><br/
<hw>Le*che"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <cref>water
buck</cref>, under 3d <er>Buck</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecher</ent><br/
<hw>Lech"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lechur</ets>, <ets>lechour</ets>, OF. <ets>lecheor</ets>,
<ets>lecheur</ets>, gormand, glutton, libertine, parasite, fr.
<ets>lechier</ets> to lick, F. <ets>l<eacute/cher</ets>; of Teutonic
origin. See <er>Lick</er>.]</ety> <def>A man given to lewdness; one
addicted, in an excessive degree, to the indulgence of sexual desire, or
to illicit sexual relations with women; also called
<altname>letch</altname> and <altname>lech</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecher</ent><br/
<hw>Lech"er</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lechered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lechering</conjf>.]</vmorph> <def>To practice lewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecherer</ent><br/
<hw>Lech"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lecher</er>, <pos>n.</pos></def> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecherous</ent><br/
<hw>Lech"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a lecher;
addicted to lewdness; excessively lustful; -- used mostly of men;</def>
<specif>also,</specif> <def>lust-provoking.</def> <ldquo/A
<xex>lecherous</xex> thing is wine.<rdquo/ <au>Chaucer.</au> --
<wordforms><wf>Lech"er*ous*ly</wf>, <pos>adv.</pos> --
<wf>Lech"er*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lecherousness</ent><br/
<hw>lech"er*ous*ness</hw> <pos>n.</pos> <def>an inclination to excessive
indulgence in sexual activity; habitually developing a strong sexual
arousal.</def><br/
<syn><b>Syn. --</b> lust, lustfulness, itch.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lechery</ent><br/
<hw>Lech"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lecherie</ets>, OF. <ets>lecherie</ets>. See
<er>Lecher</er>.]</ety> <sn>1.</sn> <def>Free indulgence of lust;
excessive indulgence in sexual relations; -- used mostly of
men.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Selfish pleasure; delight.</def> <mark>[Obs.]</mark>
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecithin</ent><br/
<hw>Lec"i*thin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>le`kiqos</grk> the yolk of an egg.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A complex, nitrogenous phosphorized substance widely
distributed through the animal body, and especially conspicuous in the
brain and nerve tissue, in yolk of eggs, and in the white blood
corpuscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lectern</ent><br/
<hw>Lec"tern</hw> <pr>(l<ecr/k"t<ucr/rn)</pr>, <pos>n.</pos>
<altsp>[Written also <asp>lecturn</asp> and <asp>lettern</asp>.]</altsp>
<ety>[LL. <ets>lectrinum</ets>, fr. <ets>lectrum</ets>; cf. L.
<ets>legere</ets>, <ets>lectum</ets>, to read.]</ety> <sn>1.</sn> <def>A
choir desk, or reading desk, in some churches, from which the lections,
or Scripture lessons, are chanted or read.</def>
<rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A reading desk, usually in
the form of a stand with a slanted top that holds books or lecture notes
at a height convenient for reading by a speaker who is standing. A
modern <ex>lectern</ex> may be of adjustable height, and be fitted with
a light to illuminate the material on the desk, and sometimes a
microphone or other electrical equipment for use of a speaker.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lectica</ent><br/
\'d8<hw>Lec*ti"ca</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lectic<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Rom.
Antiq.)</fld> <def>A kind of litter or portable couch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lection</ent><br/
<hw>Lec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lectio</ets>, fr. <ets>legere</ets>, <ets>lectum</ets>, to read.
See <er>lesson</er>, <er>Legend</er>.]</ety> <sn>1.</sn>
<fld>(Eccl.)</fld> <def>A lesson or selection, especially of Scripture,
read in divine service.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A reading; a variation in the text.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We ourselves are offended by the obtrusion of the new
<qex>lections</qex> into the text.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lectionary</ent><br/
<hw>Lec"tion*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(#)</pr>.</plu> <ety>[LL. <ets>lectionarium</ets>,
<ets>lectionarius</ets> : cf. F. <ets>lectionnaire</ets>.]</ety>
<fld>(Eccl.)</fld> <def>A book, or a list, of lections, for reading in
divine service.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 840 pr=VMG --></p>

<p><ent>Lector</ent><br/
<hw>Lec"tor</hw> <pr>(l<ecr/k"t<ocr/r)</pr>, <pos>n.</pos> <ety>[L. See
<er>Lection</er>.]</ety> <fld>(Eccl.)</fld> <def>A reader of lections;
formerly, a person designated to read lessons to the
illiterate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lectual</ent><br/
<hw>Lec"tu*al</hw> <pr>(-t<usl/*<ait/l)</pr>, <pos>a.</pos> <ety>[LL.
<ets>lectualis</ets>, fr. L. <ets>lectus</ets> bed.]</ety>
<fld>(Med.)</fld> <def>Confining to the bed; <as>as, a <ex>lectual</ex>
disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecture</ent><br/
<hw>Lec"ture</hw> <pr>(-t<usl/r; 135)</pr>, <pos>n.</pos> <ety>[F.
<ets>lecture</ets>, LL. <ets>lectura</ets>, fr. L. <ets>legere</ets>,
<ets>lectum</ets>, to read. See <er>Legend</er>.]</ety> <sn>1.</sn>
<def>The act of reading; <as>as, the <ex>lecture</ex> of Holy
Scripture</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A discourse on any subject; especially, a formal or
methodical discourse, intended for instruction; sometimes, a familiar
discourse, in contrast with a sermon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A reprimand or formal reproof from one having
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eng. Universities)</fld> <def>A rehearsal of a
lesson.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecture</ent><br/
<hw>Lec"ture</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lectured</conjf> <pr>(-t<usl/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lecturing</conjf>.]</vmorph> <sn>1.</sn> <def>To read or deliver
a lecture to.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reprove formally and with authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecture</ent><br/
<hw>Lec"ture</hw>, <pos>v. i.</pos> <def>To deliver a lecture or
lectures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecturer</ent><br/
<hw>Lec"tur*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
lectures; an assistant preacher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lectureship</ent><br/
<hw>Lec"ture*ship</hw>, <pos>n.</pos> <def>The office of a
lecturer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecturn</ent><br/
<hw>Lec"turn</hw> <pr>(l<ecr/k"t<ucr/rn)</pr>, <pos>n.</pos> <ety>[LL.
<ets>lectrinum</ets>, fr. <ets>lectrum</ets>; cf. L. <ets>legere</ets>,
<ets>lectum</ets>, to read.]</ety> <def>Same as <er>lectern</er>.</def>
<altsp>[Written also <asp>lectern</asp> and <asp>lettern</asp>.]</altsp>
<rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lecythis</ent><br/
\'d8<hw>Lec"y*this</hw> <pr>(l<ecr/s"<icr/*th<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. 3 an oil flask.]</ety> <fld>(Bot.)</fld> <def>A genus
of gigantic trees, chiefly Brazilian, of the order
<ord>Myrtace<ae/</ord>, having woody capsules opening by an apical lid.
<spn>Lecythis Zabucajo</spn> yields the delicious sapucaia nuts.
<spn>Lecythis Ollaria</spn> produces the monkey-pots, its capsules. Its
bark separates into thin sheets, like paper, used by the natives for
cigarette wrappers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Led</ent><br/
<hw>Led</hw> <pr>(l<ecr/d)</pr>, <pos>imp. & p. p.</pos> <def>of
<er>Lead</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Led captain</b></col>. <cd>An obsequious follower or
attendant.</cd> <mark>[Obs.]</mark> <au>Swift.</au> -- <col><b>Led
horse</b></col>, <cd>a sumpter horse, or a spare horse, that is led
along.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledden</ent><br/
<ent>Leden</ent><br/
<mhw>{ <hw>Led"en</hw> <pr>(l<ecr/d"'n)</pr>, <hw>Led"den</hw>
<pr>(-d'n)</pr> }</mhw> <pos>n.</pos> <ety>[AS. <ets>l<emac/den</ets>,
<ets>l<ymac/den</ets>, language, speech. Cf. <er>Leod</er>.]</ety>
<def>Language; speech; voice; cry.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer. Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledge</ent><br/
<hw>Ledge</hw> <pr>(l<ecr/j)</pr>, <pos>n.</pos> <ety>[Akin to AS.
<ets>licgan</ets> to lie, Icel. <ets>liggja</ets>; cf. Icel.
<ets>l<oum/gg</ets> the ledge or rim at the bottom of a cask. See
<er>Lie</er> to be prostrate.]</ety> <altsp>[Formerly written
<asp>lidge</asp>.]</altsp> <sn>1.</sn> <def>A shelf on which articles
may be laid; also, that which resembles such a shelf in form or use, as
a projecting ridge or part, or a molding or edge in joinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A shelf, ridge, or reef, of rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A layer or stratum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lowest <qex>ledge</qex> or row should be of stone.</q>
<rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <def>A lode; a limited mass of rock
bearing valuable mineral.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Shipbuilding)</fld> <def>A piece of timber to
support the deck, placed athwartship between beams.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledgement</ent><br/
<hw>Ledge"ment</hw> <pr>(l<ecr/j"m<eit/nt)</pr>, <pos>n.</pos> <def>See
<er>Ledgment</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledger</ent><br/
<hw>Ledg"er</hw><pr>(l<ecr/j"<etil/r)</pr>, <pos>n.</pos> <ety>[Akin to
D. <ets>legger</ets> layer, daybook (fr. <ets>leggen</ets> to lay,
<ets>liggen</ets> to lie), E. <ets>ledge</ets>, <ets>lie</ets>. See
<er>Lie</er> to be prostrate.]</ety> <sn>1.</sn> <def>A book in which a
summary of accounts is laid up or preserved; the final book of record in
business transactions, in which all debits and credits from the journal,
etc., are placed under appropriate heads.</def> <altsp>[Written also
<asp>leger</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>A large flat stone,
esp. one laid over a tomb.</def> <au>Oxf. Gloss.</au> <sd>(b)</sd>
<def>A horizontal piece of timber secured to the uprights and supporting
floor timbers, a staircase, scaffolding, or the like. It differs from an
<xex>intertie</xex> in being intended to carry weight.</def>
<altsp>[Written also <asp>ligger</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ledger bait</b></col>, <cd>fishing bait attached to a
floating line fastened to the bank of a stream, pond, etc.</cd>
<au>Walton.</au> <au>J. H. Walsh.</au> -- <col><b>Ledger
blade</b></col>,<cd>a stationary shearing blade in a machine for
shearing the nap of cloth.</cd> -- <col><b>Ledger line</b></col>.
<cd>See <cref>Leger line</cref>, under 3d <er>Leger</er>,
<pos>a.</pos></cd> -- <col><b>Ledger wall</b></col> <fld>(Mining)</fld>,
<cd>the wall under a vein; the foot wall.</cd>
<au>Raymond.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledgment</ent><br/
<hw>Ledg"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos>
<fld>(Arch.)</fld> <sd>(a)</sd> <def>A string-course or horizontal suit
of moldings, such as the base moldings of a building.</def> <au>Oxf.
Gloss.</au> <sd>(b)</sd> <def> The development of the surface of a body
on a plane, so that the dimensions of the different sides may be easily
ascertained.</def> <au>Gwilt.</au> <altsp>[Written also
<asp>ledgement</asp>, <asp>legement</asp>, and
<asp>ligement</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledgy</ent><br/
<hw>Ledg"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <def>Abounding in
ledges; consisting of a ledge or reef; <as>as, a <ex>ledgy</ex>
island</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ledum</ent><br/
<hw>Ledum</hw> <pos>prop. n.</pos> <def>A genus of evergreen shrubs of
the north temperate regions.</def><br/
<syn><b>Syn. --</b> genus <gen>Ledum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lee</ent><br/
<hw>Lee</hw> <pr>(l<emac/)</pr>, <pos>v. i.</pos>, <def>To lie; to speak
falsely.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lee</ent><br/
<hw>Lee</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Lees</plw>
<pr>(l<emac/z)</pr>.</plu> <ety>[F. <ets>lie</ets>, perh. fr. L.
<ets>levare</ets> to lift up, raise. Cf. <er>Lever</er>.]</ety>
<def>That which settles at the bottom, as of a cask of liquor (esp.
wine); sediment; dregs; -- used now only in the plural.</def>
<mark>[Lees occurs also as a form of the singular.]</mark> <ldquo/The
<xex>lees</xex> of wine.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A thousand demons lurk within the <qex>lee</qex>.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The wine of life is drawn, and the mere <qex>lees</qex><br/
Is left this vault to brag of.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lee</ent><br/
<hw>Lee</hw>, <pos>n.</pos> <ety>[OE. <ets>lee</ets> shelter, Icel.
<ets>hl<emac/</ets>, akin to AS. <ets>hle<oacute/</ets>,
<ets>hle<oacute/w</ets>, shelter, protection, OS.
<ets>hl<egrave/o</ets>, D. <ets>lij</ets> lee, Sw. <ets>l<aum/</ets>,
Dan. <ets>l<ae/</ets>.]</ety> <sn>1.</sn> <def>A sheltered place; esp.,
a place protected from the wind by some object; the side sheltered from
the wind; shelter; protection; <as>as, the <ex>lee</ex> of a mountain,
an island, or a ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We lurked under <qex>lee</qex>.</q> <rj><qau>Morte
d'Arthure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Desiring me to take shelter in his <qex>lee</qex>.</q>
<rj><qau>Tyndall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>That part of the hemisphere, as
one stands on shipboard, toward which the wind blows. See <er>Lee</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>By the lee</b></col>, <col><b>To bring by the
lee</b></col></mcol>. <cd>See under <er>By</er>, and
<er>Bring</er>.</cd> -- <col><b>Under the lee of</b></col>, <cd>on that
side which is sheltered from the wind; <as>as, to be <ex>under the lee
of</ex> a ship</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lee</ent><br/
<hw>Lee</hw>, <pos>a.</pos> <fld>(Naut.)</fld> <def>Of or pertaining to
the part or side opposite to that against which the wind blows; --
opposed to <contr>weather</contr>; <as>as, the <ex>lee</ex> side or
<ex>lee</ex> rail of a vessel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lee gauge</b></col>. <cd>See <er>Gauge</er>,
<pos>n.</pos></cd> <fld>(Naut.)</fld> -- <col><b>Lee shore</b></col>,
<cd>the shore on the lee side of a vessel.</cd> -- <col><b>Lee
tide</b></col>, <cd>a tide running in the same direction that the wind
blows.</cd> -- <col><b>On the lee beam</b></col>, <cd>directly to the
leeward; in a line at right angles to the length of the vessel and to
the leeward.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liangle</ent><br/
<ent>Leeangle</ent><br/
<mhw>{ <hw>Lee"an`gle</hw>, <hw>Li"an`gle</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[From native name.]</ety> <def>A heavy weapon of the
Australian aborigines with a sharp-pointed end, about nine inches in
length, projecting at right angles from the main part.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Leeboard</ent><br/
<hw>Lee"board`</hw> <pr>(l<emac/"b<omac/rd`)</pr>, <pos>n.</pos> <def>A
board, or frame of planks, lowered over the side of a vessel to lessen
her leeway when closehauled, by giving her greater draught.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leech</ent><br/
<hw>Leech</hw> <pr>(l<emac/ch)</pr>, <pos>n.</pos> <def>See 2d
<er>Leach</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leech</ent><br/
<hw>Leech</hw>, <pos>v. t.</pos> <def>See <er>Leach</er>, <pos>v.
t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leech</ent><br/
<hw>Leech</hw>, <pos>n.</pos> <ety>[Cf. LG. <ets>leik</ets>, Icel.
<ets>l<imac/k</ets>, Sw. <ets>lik</ets> boltrope, st<aring/ende
<ets>liken</ets> the leeches.]</ety> <fld>(Naut.)</fld> <def>The border
or edge at the side of a sail.</def> <altsp>[Written also
<asp>leach</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leech line</b></col>, <cd>a line attached to the leech
ropes of sails, passing up through blocks on the yards, to haul the
leeches by.</cd> <au>Totten.</au> -- <col><b>Leech rope</b></col>,
<cd>that part of the boltrope to which the side of a sail is
sewed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leech</ent><br/
<hw>Leech</hw>, <pos>n.</pos> <ety>[OE. <ets>leche</ets>,
<ets>l<ae/che</ets>, physician, AS. <ets>l<aemac/ce</ets>; akin to
Fries. <ets>l<emac/tza</ets>, OHG. <ets>l<amac/hh<imac/</ets>,
<ets>Icel</ets>. <ets>l<ae/knari</ets>, Sw. <ets>l<aum/kare</ets>, Dan.
<ets>l<ae/ge</ets>, Goth. <ets>l<emac/keis</ets>, AS.
<ets>l<amac/cnian</ets> to heal, Sw. <ets>l<aum/ka</ets>, Dan.
<ets>l<ae/ge</ets>, Icel. <ets>l<ae/kna</ets>, Goth.
<ets>l<emac/kin<omac/n</ets>.]</ety> <sn>1.</sn> <def>A physician or
surgeon; a professor of the art of healing.</def> <altsp>[Written also
<asp>leach</asp>.]</altsp> <mark>[Archaic]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Leech</qex>, heal thyself.</q> <rj><qau>Wyclif (Luke iv.
23).</qau></rj></p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any one of numerous genera and
species of annulose worms, belonging to the order <ord>Hirudinea</ord>,
or Bdelloidea, esp. those species <-- formerly! --> used in medicine, as
<spn>Hirudo medicinalis</spn> of Europe, and allied species.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the mouth of bloodsucking leeches are three
convergent, serrated jaws, moved by strong muscles. By the motion of
these jaws a stellate incision is made in the skin, through which the
leech sucks blood till it is gorged, and then drops off. The stomach has
large pouches on each side to hold the blood. The common large
bloodsucking leech of America (<spn>Macrobdella decora</spn>) is dark
olive above, and red below, with black spots. Many kinds of leeches are
parasitic on fishes; others feed upon worms and mollusks, and have no
jaws for drawing blood. See <er>Bdelloidea</er>. <er>Hirudinea</er>, and
<er>Clepsine</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <def>A glass tube of peculiar
construction, adapted for drawing blood from a scarified part by means
of a vacuum.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horse leech</b></col>, <cd>a less powerful European leech
(<spn>H<ae/mopis vorax</spn>), commonly attacking the membrane that
lines the inside of the mouth and nostrils of animals that drink at
pools where it lives.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leech</ent><br/
<hw>Leech</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leeched</conjf> <pr>(l<emac/cht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leeching</conjf>.]</vmorph> <sn>1.</sn> <def>To treat as a
surgeon; to doctor; <as>as, to <ex>leech</ex> wounds</as>.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bleed by the use of leeches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leechcraft</ent><br/
<hw>Leech"craft`</hw> <pr>(-kr<adot/ft`)</pr>, <pos>n.</pos> <def>The
art of healing; skill of a physician.</def> <mark>[Archaic]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leede</ent><br/
<ent>Leed</ent><br/
<mhw>{ <hw>Leed</hw>, <hw>Leede</hw> <pr>(l<emac/d)</pr> }</mhw>,
<pos>n.</pos> <ety>[Etymol. uncertain.]</ety> <def>A caldron; a copper
kettle.</def> <mark>[Obs.]</mark> <ldquo/A furnace of a
<xex>leed</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leef</ent><br/
<hw>Leef</hw> <pr>(l<emac/f)</pr>, <pos>a. & adv.</pos> <def>See
<er>Lief</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leek</ent><br/
<hw>Leek</hw> <pr>(l<emac/k)</pr>, <pos>n.</pos> <ety>[AS.
<ets>le<aacute/c</ets>; akin to D. <ets>look</ets>, G. <ets>lauch</ets>,
OHG. <ets>louh</ets>, Icel. <ets>laukr</ets>, Sw. <ets>l<oum/k</ets>,
Dan <ets>l<oum/g</ets>. Cf. <er>Garlic</er>.]</ety> <fld>(Bot.)</fld>
<def>A plant of the genus <gen>Allium</gen> (<spn>Allium Porrum</spn>),
having broadly linear succulent leaves rising from a loose oblong
cylindrical bulb. The flavor is stronger than that of the common
onion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Wild leek</b></col> , <cd>in America, a plant
(<spn>Allium tricoccum</spn>) with a cluster of ovoid bulbs and large
oblong elliptical leaves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leeme</ent><br/
<hw>Leeme</hw> <pr>(l<emac/m)</pr>, <pos>v. & n.</pos> <def>See
<er>Leme</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leep</ent><br/
<hw>Leep</hw> <pr>(l<emac/p)</pr>, <mark>obs.</mark> <pos>strong
imp.</pos> <mord>of <er>Leap</er></mord>. <def>Leaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leer</ent><br/
<hw>Leer</hw> <pr>(l<emac/r)</pr>, <pos>v. t.</pos> <def>To learn.</def>
<mark>[Obs.]</mark> <see>See <er>Lere</er>, to learn.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leer</ent><br/
<hw>Leer</hw>, <pos>a.</pos> <ety>[OE. <ets>lere</ets>; akin to G.
<ets>leer</ets>, OHG. & OS. <ets>l<amac/ri</ets>.]</ety> <mark>[Obs. or
Prov. Eng.]</mark> <def>Empty; destitute; wanting</def>; as:
<sd>(a)</sd> <def>Empty of contents.</def> <ldquo/A <xex>leer</xex>
stomach.<rdquo/ <au>Gifford.</au> <sd>(b)</sd> <def>Destitute of a
rider; and hence, led, not ridden; <as>as, a <ex>leer</ex>
horse</as>.</def> <au>B. Jonson.</au> <sd>(c)</sd> <def>Wanting sense or
seriousness; trifling; trivolous; <as>as, <ex>leer</ex>
words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leer</ent><br/
<hw>Leer</hw>, <pos>n.</pos> <def>An oven in which glassware is
annealed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leer</ent><br/
<hw>Leer</hw>, <pos>n.</pos> <ety>[OE. <ets>lere</ets> cheek, face,
look, AS. <ets>hle<oacute/r</ets> cheek, face; akin to OS.
<ets>hlear</ets>, <ets>hlior</ets>, OD. <ets>lier</ets>, Icel.
<ets>hl<ymac/r</ets>.]</ety> <sn>1.</sn> <def>The cheek.</def>
<mark>[Obs.]</mark> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Complexion; aspect; appearance.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A Rosalind of a better <qex>leer</qex> than you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A distorted expression of the face, or an indirect
glance of the eye, conveying a sinister or immodest
suggestion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With jealous <qex>leer</qex> malign<br/
Eyed them askance.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She gives the <qex>leer</qex> of invitation.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Damn with faint praise, assent with civil <qex>leer</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leer</ent><br/
<hw>Leer</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leered</conjf> <pr>(l<emac/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Leering</conjf>.]</vmorph> <def>To look with a leer; to look
askance with a suggestive expression, as of hatred, contempt, lust,
etc.; to cast a sidelong lustful or malign look.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>leer</qex>upon him as a' comes by.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The priest, above his book,<br/
<qex>Leering</qex> at his neighbor's wife.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leer</ent><br/
<hw>Leer</hw>, <pos>v. t.</pos> <def>To entice with a leer, or leers;
<as>as, to <ex>leer</ex> a man to ruin</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leere</ent><br/
<hw>Leere</hw> <pr>(l<emac/r)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>Tape or braid; an ornament.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leere side</b></col>, <cd>the left side, as that on which
a leere or ornament was worn.</cd> <rj><au>B. Jonson.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leeringly</ent><br/
<hw>Leer"ing*ly</hw>, <pos>adv.</pos> <def>In a leering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lees</ent><br/
<hw>Lees</hw> <pr>(l<emac/z)</pr>, <pos>n. pl.</pos> <def>Dregs. See 2d
<er>Lee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lees</ent><br/
<hw>Lees</hw> <pr>(l<emac/s)</pr>, <pos>n.</pos> <def>A leash.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leese</ent><br/
<hw>Leese</hw> <pr>(l<emac/z)</pr>, <pos>v. t.</pos> <ety>[See
<er>Lose</er>.]</ety> <def>To lose.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They would rather <qex>leese</qex> their friend than their
jest.</q> <rj><qau>Lord Burleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leese</ent><br/
<hw>Leese</hw>, <pos>v. t.</pos> <ety>[Cf. F. <ets>l<eacute/ser</ets>,
L. <ets>laesus</ets>, p. p. of <ets>laedere</ets>.]</ety> <def>To
hurt.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leet</ent><br/
<hw>Leet</hw> <pr>(l<emac/t)</pr>, <pos>obs. imp.</pos> <def>of
<er>Let</er>, to allow.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leet</ent><br/
<hw>Leet</hw>, <pos>n.</pos> <ety>[Cf. AS. <ets>hl<emac/t</ets> share,
lot.]</ety> <def>A portion; a list, esp. a list of candidates for an
office.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leet</ent><br/
<hw>Leet</hw>, <pos>n.</pos> <ety>[LL. <ets>leta</ets>. Cf. F. <ets>lit
de justice</ets> a solemn sitting of the king in Parliament, L.
<ets>lis</ets>, <ets>litis</ets>, a lawsuit, It., Sp., & Pg.
<ets>lite</ets>.]</ety> <fld>(Eng. Hist.)</fld> <def>A court-leet; the
district within the jurisdiction of a court-leet; the day on which a
court-leet is held.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The original intent of the court-leet was to view the
frankpledges or freemen within the liberty; hence called <xex>the view
of frankpledge</xex>. Latterly it has fallen into almost entire
disuse.</note> <rj><au>Burrill. Warren's Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leet ale</b></col>, <cd>a feast or merrymaking in time of
leet.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leet</ent><br/
<hw>Leet</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety>
<fld>(Zool.)</fld> <def>The European pollock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leetman</ent><br/
<hw>Leet"man</hw> <pr>(-m<ait/n)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Leetmen</plw> <pr>(-m<eit/n)</pr>.</plu> <def>One subject to the
jurisdiction of a court-leet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leeward</ent><br/
<hw>Lee"ward</hw> <pr>(l<emac/"w<etil/rd <or/ l<umac/"<etil/rd)</pr>,
<pos>a.</pos> <fld>(Naut.)</fld> <def>Pertaining to, or in the direction
of, the part or side toward which the wind blows; -- opposed to
<ant>windward</ant>; <as>as, a <ex>leeward</ex> berth; a
<ex>leeward</ex> ship.</as></def> -- <def2><pos>n.</pos> <def>The lee
side; the lee.</def></def2> -- <def2><pos>adv.</pos> <def>Toward the
lee.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leeway</ent><br/
<hw>Lee"way`</hw> <pr>(l<emac/"w<amac/`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>The lateral movement of a ship to the leeward of
her course; drift.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Left</ent><br/
<hw>Left</hw> <pr>(l<ecr/ft)</pr>, <pos>imp. & p. p.</pos> <def>of
<er>Leave</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Left</ent><br/
<hw>Left</hw>, <pos>a.</pos> <ety>[OE. <ets>left</ets>, <ets>lift</ets>,
<ets>luft</ets>; akin to Fries. <ets>leeft</ets>, OD. <ets>lucht</ets>,
<ets>luft</ets>; cf. AS. <ets>left</ets> (equiv. to L.
<ets>inanis</ets>), <ets>lyft<amac/dl</ets> palsy; or cf. AS.
<ets>l<emac/f</ets> weak.]</ety> <sn>1.</sn> <def>Of or pertaining to
that side of the body in man on which the muscular action of the limbs
is usually weaker than on the other side; -- opposed to
<ant>right</ant>, when used in reference to a part of the body; <as>as,
the <ex>left</ex> hand, or arm; the <ex>left</ex> ear</as>. Also said of
the corresponding side of the lower animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Situated so that the left side of the body is toward
it; <as>as, the <ex>left</ex> side of a deliberative meeting is that to
the left of the presiding officer; the <ex>left</ex> wing of an army is
that to the left of the center to one facing an enemy</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Left bank of a river</b></col>, <cd>that which is on the
<xex>left</xex> hand of a person whose face is turned downstream.</cd>
-- <col><b>Left bower</b></col>. <cd>See under 2d <er>Bower</er>.</cd>
-- <col><b>Left center</b></col>, <cd>the members whose sympathies are,
in the main, with the members of the Left, but who do not favor extreme
courses, and on occasions vote with the government. They sit between the
Center and the extreme Left.</cd> -- <mcol><col><b>Over the left
shoulder</b></col>, <it>or</it> <col><b>Over the left</b></col></mcol>,
<cd>an old but still current colloquialism, or slang expression, used as
an aside to indicate insincerity, negation, or disbelief; <as>as, he
said it, and it is true, -- <ex>over the left</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Left</ent><br/
<hw>Left</hw>, <pos>n.</pos> <sn>1.</sn> <def>That part of surrounding
space toward which the left side of one's body is turned; <as>as, the
house is on the <ex>left</ex> when you face North</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Put that rose a little more to the <qex>left</qex>.</q>
<rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Those members of a legislative assembly (as in
France) who are in the opposition; the advanced republicans and extreme
radicals. They have their seats at the left-hand side of the presiding
officer. See <er>Center</er>, and <er>Right</er>.</def><-- now used of
any group advocating a leftist policy -- which is variously interpeted,
as meaning "radical", "liberal", "reformist", "anti-establishment"
"advocating change in the name of greater freedom or well-being of the
common man[MW10]" -- opposed to rightist, and in the "liberal"
interpretation, opposed to "conservative". --><br/
[<source>1913 Webster</source>]</p>

<p><ent>left brain</ent><br/
<hw>left" brain`</hw>, <pos>n.</pos> <def>The left cerebral hemisphere
of the brain; in humans, it controls motor activity on the right side of
the body, and in most people is the primary location for control of
language, logic, and mathematical thought.</def><br/
[<source>PJC</source>]</p>

<p><ent>left-brain</ent><br/
<hw>left"-brain`</hw>, <pos>a.</pos> <def>Of or pertaining to the left
cerebral hemisphere of the brain.</def><br/
[<source>PJC</source>]</p>

<p><ent>left-brained</ent><br/
<hw>left"-brained`</hw>, <pos>a.</pos> <def>Exhibiting intellectual or
personality characteristics suggesting dominance of linguistic or
logical modes of thought, which are usually controlled by the left
cerebral hemisphere; <as>as, <ex>left-brained</ex> pedants unable to
appreciate music</as>; also referred to as <altname>linear</altname>.
See <er>linear</er>{3}. Contrasted with
<contr>right-brained</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>leftfield</ent><br/
<ent>left field</ent><br/
<mhw><hw>left` field"</hw>, <hw>left`field"</hw></mhw> <pos>n.</pos>
<fld>(Baseball)</fld> <def>the part of the outfield on the catcher's or
batter's left.</def><br/
<syn><b>Syn. --</b> left.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Left-hand</ent><br/
<hw>Left"-hand`</hw> <pr>(l<ecr/ft"h<acr/nd`)</pr>, <pos>a.</pos>
<def>Situated on the left; nearer the left hand than the right; <as>as,
the <ex>left-hand</ex> side; the <ex>left-hand</ex> road.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Left-hand rope</b></col>, <cd>rope laid up and twisted
over from right to left, or against the sun; -- called also
<altname>water-laid rope</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Left-handed</ent><br/
<hw>Left"-hand`ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having the left
hand or arm stronger and more dexterous than the right; using the left
hand and arm with more dexterity than the right.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Clumsy; awkward; unlucky; insincere; sinister;
malicious; <as>as, a <ex>left-handed</ex> compliment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The commendations of this people are not always
<qex>left-handed</qex> and detractive.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having a direction contrary to that of the hands of
a watch when seen in front; -- said of a twist, a rotary motion, etc.,
looked at from a given direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Left-handed marriage</b></col>, <cd>a morganatic
marriage. See <er>Morganatic</er>.</cd> -- <col><b>Left-handed
screw</b></col>, <cd>a screw constructed to advance away from the
observer, when turned, as in a nut, with a left-handed rotation. An
ordinary wood screw is right-handed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Left-handiness</ent><br/
<ent>Left-handedness</ent><br/
<mhw>{ <hw>Left"-hand`ed*ness</hw>, <hw>Left"-hand`i*ness</hw>
<pr>(-<icr/*n<ecr/s)</pr>, }</mhw> <pos>n.</pos> <def>The state or
quality of being left-handed; awkwardness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An awkward address, ungraceful attitudes and actions, and a
certain <qex>left-handiness</qex> (if I may use the expression) proclaim
low education.</q> <rj><qau>Chesterfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>left-hander</ent><br/
<ent>lefthander</ent><br/
<mhw><hw>left`hand"er</hw>, <hw>left`-hand"er</hw></mhw> <pos>n.</pos>
<def>a person who uses the left hand with greater skill than the right;
a left-handed{1} person.</def><br/
<syn><b>Syn. --</b> lefty, southpaw.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leftish</ent><br/
<hw>leftish</hw> <pos>adj.</pos> <def>Inclined toward the political
left.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leftist</ent><br/
<hw>leftist</hw> <pos>adj.</pos> <def>same as
<er>left-wing</er>.</def><br/
<syn><b>Syn. --</b> left-of-center, left-wing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leftist</ent><br/
<hw>leftist</hw> <pos>n.</pos> <def>a person who belongs to the
political left.</def><br/
<syn><b>Syn. --</b> socialist, collectivist, left-winger.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>left-of-center</ent><br/
<hw>left-of-center</hw> <pos>adj.</pos> <def>same as
<er>left-wing</er>.</def><br/
<syn><b>Syn. --</b> leftist, left-wing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Left-off</ent><br/
<hw>Left"-off`</hw> <pr>(-<ocr/f`; 115)</pr>, <pos>a.</pos> <def>Laid
aside; cast-off.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leftover</ent><br/
<hw>leftover</hw> <pos>adj.</pos> <sn>1.</sn> <def>not used up;
remaining after use of part; <as>as, unusable <ex>leftover</ex> auto
parts</as>.</def><br/
<syn><b>Syn. --</b> left over(predicate), left(predicate), odd,
remaining, unexpended.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>remaining from a
previous meal; -- of food; <as>as, <ex>leftover</ex> food served at a
later meal</as>.</def><br/
<syn><b>Syn. --</b> cooked-over, warmed-over, reheated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leftover</ent><br/
<hw>leftover</hw> <pos>n.</pos> <def>An unused part or portion; -- used
especially of food remaining uneaten from a previous meal; <as>as, to
have <ex>leftovers</ex> for dinner</as>.</def><br/
<syn><b>Syn. --</b> remnant.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>left-slanting</ent><br/
<hw>left-slanting</hw> <pos>adj.</pos> <def>slanting toward the left; --
of handwriting.</def> <note>Such handwriting is usually found in
left-handed writers</note><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leftward</ent><br/
<hw>Left"ward</hw> <pr>(-w<etil/rd)</pr>, <pos>adv.</pos> <def>Toward or
on the left side.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rightward and <qex>leftward</qex> rise the rocks.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>left-wing</ent><br/
<hw>left-wing</hw> <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
the political left or its ideology.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Believing in or supporting tenets of the political
left.</def><br/
<syn><b>Syn. --</b> leftist, left-of-center.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>left wing</ent><br/
<hw>left wing</hw> <pos>n.</pos> <def>Those trying to reform the
established order, particularly in political matters, to enhance the
condition of the common people; -- sometimes applied to those advocating
overthrow of an existing government by radical means.</def><br/
<syn><b>Syn. --</b> left, left wing, leftists, political left.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>left-winger</ent><br/
<hw>left-winger</hw> <pos>n.</pos> <sn>1.</sn> <def>a person who belongs
to the political left.</def><br/
<syn><b>Syn. --</b> socialist, collectivist, leftist.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lefty</ent><br/
<hw>lefty</hw> <pos>n.</pos> <sn>1.</sn> <def>a person who uses the left
hand with greater skill than the right; a left-handed person.</def><br/
<syn><b>Syn. --</b> lefthander, southpaw.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a baseball pitcher who throws the ball with the left
hand.</def><br/
<syn><b>Syn. --</b> left-handed pitcher, left-hander,
southpaw.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leful</ent><br/
<hw>Le"ful</hw> <pr>(l<emac/"f<usdot/l)</pr>, <pos>a.</pos> <def>See
<er>Leveful</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leg</ent><br/
<hw>Leg</hw> <pr>(l<ecr/g)</pr>, <pos>n.</pos> <ety>[Icel.
<ets>leggr</ets>; akin to Dan. <ets>l<ae/g</ets> calf of the leg, Sw.
<ets>l<aum/gg</ets>.]</ety> <sn>1.</sn> <def>A limb or member of an
animal used for supporting the body, and in running, climbing, and
swimming; esp., that part of the limb between the knee and
foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles a leg in form or use;
especially, any long and slender support on which any object rests;
<as>as, the <ex>leg</ex> of a table; the <ex>leg</ex> of a pair of
compasses or dividers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The part of any article of clothing which covers the
leg; <as>as, the <ex>leg</ex> of a stocking or of a pair of
trousers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A bow, esp. in the phrase <xex>to make a leg</xex>;
probably from drawing the leg backward in bowing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He that will give a cap and make a <qex>leg</qex> in thanks for a
favor he never received.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A disreputable sporting character; a blackleg.</def>
<mark>[Slang, Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>The course and distance made by a
vessel on one tack or between tacks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Steam Boiler)</fld> <def>An extension of the boiler
downward, in the form of a narrow space between vertical plates,
sometimes nearly surrounding the furnace and ash pit, and serving to
support the boiler; -- called also <altname>water
leg</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Grain Elevator)</fld> <def>The case containing the
lower part of the belt which carries the buckets.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Cricket)</fld> <def>A fielder whose position is on
the outside, a little in rear of the batter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Math.)</fld> <def>Either side of a triangle
distinguished from the base or, in a right triangle, from the
hypotenuse; also, an indefinitely extending branch of a curve, as of a
hyperbola.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>11.</sn> <fld>(Telephony)</fld> <def>A branch or lateral circuit
connecting an instrument with the main line.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>12.</sn> <fld>(Elec.)</fld> <def>A branch circuit; one phase of a
polyphase system.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>A good leg</b></col> <fld>(Naut.)</fld>, <cd>a course
sailed on a tack which is near the desired course.</cd> -- <col><b>Leg
bail</b></col>, <cd>escape from custody by flight.</cd>
<mark>[Slang]</mark> -- <col><b>Legs of an hyperbola</b></col> (or other
curve) <fld>(Geom.)</fld>, <cd>the branches of the curve which extend
outward indefinitely.</cd> -- <col><b>Legs of a triangle</b></col>,
<cd>the sides of a triangle; -- a name seldom used unless one of the
sides is first distinguished by some appropriate term; <as>as, the
hypotenuse and two <ex>legs</ex> of a right-angled triangle</as>.</cd>
<col><b>On one's legs</b></col>, <cd>standing to speak.</cd> --
<col><b>On one's last legs</b></col>. <cd>See under <er>Last</er>.</cd>
-- <col><b>To have legs</b></col> <fld>(Naut.)</fld>, <cd>to have
speed.</cd><-- also, to have endurance, to continue longer than usual.
--> -- <col><b>To stand on one's own legs</b></col>, <cd>to support
one's self; to be independent.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 841 pr=VMG --></p>

<p><ent>Leg</ent><br/
<hw>Leg</hw> <pr>(l<ecr/g)</pr>, <pos>v. t.</pos> <def>To use as a leg,
with <xex>it</xex> as object</def>: <sd>(a)</sd> <def>To bow.</def>
<mark>[Obs.]</mark> <sd>(b)</sd> <def>To run.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legacy</ent><br/
<hw>Leg"a*cy</hw> <pr>(l<ecr/g"<adot/*s<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Legacies</plw> <pr>(-s<icr/z)</pr>.</plu>
<ety>[L. (assumed) <ets>legatia</ets>, for <ets>legatum</ets>, from
<ets>legare</ets> to appoint by last will, to bequeath as a legacy, to
depute: cf. OF. <ets>legat</ets> legacy. See <er>Legate</er>.]</ety>
<sn>1.</sn> <def>A gift of property by will, esp. of money or personal
property; a bequest. Also Fig.; <as>as, a <ex>legacy</ex> of dishonor or
disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A business with which one is intrusted by another; a
commission; -- obsolete, except in the phrases <xex>last legacy</xex>,
<xex>dying legacy</xex>, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>legacy</qex> and message wherefore I am sent into the
world.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He came and told his <qex>legacy</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Legacy duty</b></col>, <cd>a tax paid to government on
legacies.</cd> <au>Wharton.</au> -- <col><b>Legacy hunter</b></col>,
<cd>one who flatters and courts any one for the sake of a
legacy.</cd></cs><-- related to gold-digger (latter for any riches, not
just a legacy) --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legal</ent><br/
<hw>Le"gal</hw> <pr>(l<emac/"g<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>legalis</ets>, fr. <ets>lex</ets>, <ets>legis</ets>, law; prob.
orig., that which lies or is fixed (cf. L. <ets>lectus</ets> bed), and
if so akin to E. <ets>lie</ets>, <ets>law</ets>: cf. F.
<ets>l<eacute/gal</ets>. Cf. <er>Lie</er> to be prostrate,
<er>Loyal</er>, <er>Leal</er>.]</ety> <sn>1.</sn> <def>Created by,
permitted by, in conformity with, or relating to, law; <as>as, a
<ex>legal</ex> obligation; a <ex>legal</ex> standard or test; a
<ex>legal</ex> procedure; a <ex>legal</ex> claim; a <ex>legal</ex>
trade; anything is <ex>legal</ex> which the laws do not
forbid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <sd>(a)</sd> <def>According to the
law of works, as distinguished from free grace; or resting on works for
salvation.</def> <sd>(b)</sd> <def>According to the old or Mosaic
dispensation; in accordance with the law of Moses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>Governed by the rules of law as
distinguished from the rules of equity; <as>as, <ex>legal</ex> estate;
<ex>legal</ex> assets.</as></def> <rj><au>Bouvier.</au>
<au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Legal cap</b></col>. <cd>See under <er>Cap</er>.</cd> --
<col><b>Legal tender</b></col>. <sd>(a)</sd> <cd>The act of tendering in
the performance of a contract or satisfaction of a claim that which the
law prescribes or permits, and at such time and place as the law
prescribes or permits.</cd> <sd>(b)</sd> <cd>That currency, or money,
which the law authorizes a debtor to tender and requires a creditor to
receive. It differs in different countries.</cd></cs></p>

<p><syn><b>Syn.</b> -- Lawful; constitutional; legitimate; licit;
authorized. See <er>Lawful</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>legalese</ent><br/
<hw>legalese</hw> <pos>n.</pos> <def>A style of writing or speaking
heavily emphasizing the abstruse technical vocabulary of the law, to the
point where a speech or document may be incomprehensible to
non-specialists.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>legalisation</ent><br/
<hw>legalisation</hw> <pos>n.</pos> <sn>1.</sn> <def>the act of
legalizing; same as <er>legalization</er>.</def><br/
<syn><b>Syn. --</b> legalization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Legalism</ent><br/
<hw>Le"gal*ism</hw> <pr>(l<emac/"g<ait/l*<icr/z'm)</pr>, <pos>n.</pos>
<def>Strictness, or the doctrine of strictness, in conforming to
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legalist</ent><br/
<hw>Le"gal*ist</hw>, <pos>n.</pos> <def>One who practices or advocates
strict conformity to law; in theology, one who holds to the law of
works. See <er>Legal</er>, 2 <sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legality</ent><br/
<hw>Le*gal"i*ty</hw> <pr>(l<esl/*g<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[Cf. LL. <ets>legalitas</ets>, F.
<ets>l<eacute/galit<eacute/</ets>. Cf. <er>Loyalty</er>.]</ety>
<sn>1.</sn> <def>The state or quality of being legal; conformity to
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>A conformity to, and resting
upon, the letter of the law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legalization</ent><br/
<hw>Le`gal*i*za"tion</hw>
<pr>(l<emac/`g<ait/l*<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The act of making legal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legalize</ent><br/
<hw>Le"gal*ize</hw> <pr>(l<emac/"g<ait/l*<imac/z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Legalized</conjf>
<pr>(-<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Legalizing</conjf> <pr>(-<imac/`z<icr/ng)</pr>.]</vmorph>
<ety>[Cf. F. <ets>l<eacute/galiser</ets>.]</ety> <sn>1.</sn> <def>To
make legal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>To interpret or apply in a legal
spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legally</ent><br/
<hw>Le"gal*ly</hw>, <pos>adv.</pos> <def>In a legal manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legantine</ent><br/
<hw>Le*gan"tine</hw> <pr>(l<esl/*g<acr/n"t<icr/n)</pr>, <pos>a.</pos>
<mark>[Obs.]</mark> <def>See <er>Legatine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legatary</ent><br/
<hw>Leg"a*ta*ry</hw> <pr>(l<ecr/g"<adot/*t<asl/*r<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>legatarius</ets>, fr. <ets>legaturius</ets>
enjoined by a last will: cf. F. <ets>l<eacute/gataire</ets>. See
<er>Legacy</er>.]</ety> <def>A legatee.</def> <mark>[R.]</mark>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legate</ent><br/
<hw>Leg"ate</hw> <pr>(l<ecr/g"<asl/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>legat</ets>, L. <ets>legatus</ets>, fr. <ets>legare</ets> to send
with a commission or charge, to depute, fr. <ets>lex</ets>,
<ets>legis</ets>, law: cf. F. <ets>l<eacute/gat</ets>, It.
<ets>legato</ets>. See <er>Legal</er>.]</ety> <sn>1.</sn> <def>An
ambassador or envoy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ecclesiastic representing the pope and invested
with the authority of the Holy See.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Legates are of three kinds: (<stype>a</stype>)
<xex>Legates a latere</xex>, now always cardinals. They are called
<xex>ordinary</xex> or <xex>extraordinary</xex> legates, the former
governing provinces, and the latter class being sent to foreign
countries on extraordinary occasions. (<stype>b</stype>) <xex>Legati
missi</xex>, who correspond to the ambassadors of temporal governments.
(<stype>c</stype>) <xex>Legati nati</xex>, or <xex>legates by virtue of
their office</xex>, as the archbishops of Salzburg and
Prague.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Rom. Hist.)</fld> <sd>(a)</sd> <def>An official
assistant given to a general or to the governor of a province.</def>
<sd>(b)</sd> <def>Under the emperors, a governor sent to a
province.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legatee</ent><br/
<hw>Leg`a*tee"</hw> <pr>(l<ecr/g`<adot/*t<emac/")</pr>, <pos>n.</pos>
<ety>[See <er>Legacy</er>.]</ety> <fld>(Law)</fld> <def>One to whom a
legacy is bequeathed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legateship</ent><br/
<hw>Leg"ate*ship</hw> <pr>(l<ecr/g"<asl/t*sh<icr/p)</pr>, <pos>n.</pos>
<def>The office of a legate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legatine</ent><br/
<hw>Leg"a*tine</hw> <pr>(-<adot/*t<imac/n)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Of or pertaining to a legate; <as>as, <ex>legatine</ex>
power</as>.</def> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made by, proceeding from, or under the sanction of,
a legate; <as>as, a <ex>legatine</ex> constitution</as>.</def>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legation</ent><br/
<hw>Le*ga"tion</hw> <pr>(l<esl/*g<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>legatio</ets>: cf. F. <ets>l<eacute/gation</ets>, It.
<ets>legazione</ets>. See <er>Legate</er>.]</ety> <sn>1.</sn> <def>The
sending forth or commissioning one person to act for another.</def>
<ldquo/The Divine <xex>legation</xex> of Moses.<rdquo/ <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A legate, or envoy, and the persons associated with
him in his mission; an embassy; or, in stricter usage, a diplomatic
minister and his suite; a deputation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The place of business or official residence of a
diplomatic minister at a foreign court or seat of government.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A district under the jurisdiction of a
legate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legato</ent><br/
\'d8<hw>Le*ga"to</hw> <pr>(l<asl/*g<aum/"t<osl/)</pr>, <pos>a.</pos>
<ety>[It., tied, joined, fr. <ets>legare</ets> to tie, bind, L.
<ets>ligare</ets>.]</ety> <fld>(Mus.)</fld> <def>Connected; tied; -- a
term used when successive tones are to be produced in a closely
connected, smoothly gliding manner. It is often indicated by a
<xex>tie</xex>, thus <?/, <?/, or <?/, <?/, written over or under the
notes to be so performed; -- opposed to
<contr>staccato</contr>.</def><-- music notation: slur down, slur up,
legato down, legato up. Use graphic? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legator</ent><br/
\'d8<hw>Leg`a*tor"</hw> <pr>(l<ecr/g`<adot/*t<ocir/r")</pr>,
<pos>n.</pos> <ety>[L., fr. <ets>legare</ets>: cf. OF.
<ets>legateur</ets>. See <er>Legacy</er>.]</ety> <fld>(Law)</fld> <def>A
testator; one who bequeaths a legacy.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legatura</ent><br/
\'d8<hw>Le`ga*tu"ra</hw> <pr>(l<asl/`g<adot/*t<oomac/"r<adot/)</pr>,
<pos>n.</pos> <ety>[It. See <er>Ligature</er>.]</ety> <fld>(Mus.)</fld>
<def>A tie or brace; a syncopation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legature</ent><br/
<hw>Leg"a*ture</hw> <pr>(l<ecr/g"<adot/*t<usl/r; 135)</pr>,
<pos>n.</pos> <def>Legateship.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leg bridge</ent><br/
<hw>Leg bridge</hw>. <def>A type of bridge for small spans in which the
floor girders are rigidly secured at their extremities to supporting
steel legs, driven into the ground as piling, or resting on
mudsills.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lege</ent><br/
<hw>Lege</hw> <pr>(l<ecr/j)</pr>, <pos>v. t.</pos> <ety>[Abbrev. fr.
<ets>allege</ets> to assert.]</ety> <def>To allege; to assert.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Fisher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legement</ent><br/
<hw>Lege"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>See
<er>Ledgment</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legend</ent><br/
<hw>Leg"end</hw> <pr>(l<ecr/j"<ecr/nd <or/ l<emac/"j<ecr/nd; 277)</pr>,
<pos>n.</pos> <ety>[OE. <ets>legende</ets>, OF. <ets>legende</ets>, F.
<ets>l<eacute/gende</ets>, LL. <ets>legenda</ets>, fr. L.
<ets>legendus</ets> to be read, fr. <ets>legere</ets> to read, gather;
akin to Gr. <grk>le`gein</grk> to gather, speak. Cf. <er>Collect</er>,
<er>Dialogue</er>, <er>Lesson</er>, <er>Logic</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>That which is appointed to be read; especially, a
chronicle or register of the lives of saints, formerly read at matins,
and in the refectories of religious houses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A story respecting saints; especially, one of a
marvelous nature.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any wonderful story coming down from the past, but
not verifiable by historical record; a myth; a fable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And in this <qex>legend</qex> all that glorious deed<br/
Read, whilst you arm you.</q> <rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An inscription, motto, or title, esp. one
surrounding the field in a medal or coin, or placed upon an heraldic
shield or beneath an engraving or illustration.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Golden legend</b></col>. <cd>See under
<er>Golden</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legend</ent><br/
<hw>Leg"end</hw>, <pos>v. t.</pos> <def>To tell or narrate, as a
legend.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legendary</ent><br/
<hw>Leg"end*a*ry</hw> <pr>(l<ecr/j"<ecr/n*d<asl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Of or pertaining to a legend or to legends;
consisting of legends; like a legend; fabulous.</def>
<ldquo/<xex>Legendary</xex> writers.<rdquo/ <rj><au>Bp.
Lloyd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Legendary</qex> stories of nurses and old women.</q>
<rj><qau>Bourne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legendary</ent><br/
<hw>Leg"end*a*ry</hw>, <pos>n.</pos> <ety>[Cf. OF.
<ets>legendaire</ets>, LL. <ets>legendarius</ets>.]</ety> <sn>1.</sn>
<def>A book of legends; a tale or narrative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Read the Countess of Pembroke's <ldquo/Arcadia,<rdquo/ a gallant
<qex>legendary</qex> full of pleasurable accidents.</q> <rj><qau>James
I.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who relates legends.</def> <rj><au>Bp.
Lavington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leger</ent><br/
<hw>Leg"er</hw> <pr>(l<ecr/j"<etil/r)</pr>, <pos>n.</pos> <ety>[See
<er>Ledger</er>.]</ety> <sn>1.</sn> <def>Anything that lies in a place;
that which, or one who, remains in a place.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A minister or ambassador resident at a court or seat
of government.</def> <altsp>[Written also <asp>lieger</asp>,
<asp>leiger</asp>.]</altsp> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir Edward Carne, the queen's <qex>leger</qex> at Rome.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A ledger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leger</ent><br/
<hw>Leg"er</hw>, <pos>a.</pos> <def>Lying or remaining in a place;
hence, resident; <as>as, <ex>leger</ex> ambassador</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leger</ent><br/
<hw>Leg"er</hw>, <pos>a.</pos> <ety>[F. <ets>l<eacute/ger</ets>, fr. LL.
(assumed) <ets>leviarius</ets>, fr. L. <ets>levis</ets> light in weight.
See <er>Levity</er>.]</ety> <def>Light; slender; slim; trivial.</def>
<mark>[Obs. except in special phrases.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leger line</b></col> <fld>(Mus.)</fld>, <cd>a line added
above or below the staff to extend its compass; -- called also
<altname>added line</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legerdemain</ent><br/
<hw>Leg`er*de*main"</hw> <pr>(l<ecr/j`<etil/r*d<esl/*m<amac/n")</pr>,
<pos>n.</pos> <ety>[F. <ets>l<eacute/ger</ets> light, nimble +
<ets>de</ets> of + <ets>main</ets> hand, L. <ets>manus</ets>. See 3d
<er>Leger</er>, and <er>Manual</er>.]</ety> <def>Sleight of hand; a
trick of sleight of hand; hence, any artful deception or
trick.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He of <qex>legierdemayne</qex> the mysteries did know.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The tricks and <qex>legerdemain</qex> by which men impose upon
their own souls.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legerdemainist</ent><br/
<hw>Leg`er*de*main"ist</hw>, <pos>n.</pos> <def>One who practices
sleight of hand; a prestidigitator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legerity</ent><br/
<hw>Le*ger"i*ty</hw> <pr>(l<esl/*j<ecr/r"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[F. <ets>l<eacute/g<egrave/ret<eacute/</ets>. See 3d
<er>Leger</er>.]</ety> <def>Lightness; nimbleness.</def>
<mark>[Archaic]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legge</ent><br/
<hw>Legge</hw> <pr>(l<ecr/g)</pr>, <pos>v. t.</pos> <ety>[See
<er>Lay</er>, <pos>v. t.</pos> ]</ety> <def>To lay.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legge</ent><br/
<hw>Legge</hw>, <pos>v. t.</pos> <ety>[Abbrev. fr.
<ets>alegge</ets>.]</ety> <def>To lighten; to allay.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legged</ent><br/
<hw>Legged</hw> <pr>(l<ecr/gd <or/ l<ecr/g"g<ecr/d)</pr>, <pos>a.</pos>
<ety>[From <er>Leg</er>.]</ety> <def>Having (such or so many) legs; --
used in composition; <as>as, a long<ex>-legged</ex> man; a
two<ex>-legged</ex> animal.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leggiero</ent><br/
<ent>Leggiadro</ent><br/
<mhw>{ \'d8<hw>Leg`gi*a"dro</hw>
<pr>(l<asl/d`j<esl/*<aum/"dr<osl/)</pr>, \'d8<hw>Leg`gi*e"ro</hw>
<pr>(l<asl/d`j<esl/*<asl/"r<osl/)</pr>, }</mhw> <pos>a. & adv.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>Light or graceful; in a light,
delicate, and brisk style.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leggin</ent><br/
<ent>Legging</ent><br/
<mhw>{ <hw>Leg"ging</hw> <pr>(l<ecr/g"g<icr/ng)</pr>, <hw>Leg"gin</hw>
<pr>(l<ecr/g"g<icr/n)</pr>, }</mhw> <pos>n.</pos> <ety>[From
<er>Leg</er>.]</ety> <def>A cover for the leg, like a long
gaiter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legging</ent><br/
<hw>Leg"ging</hw>, <def><pos>a. & vb. n.</pos>, from <er>Leg</er>,
<pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leggy</ent><br/
<hw>Leg"gy</hw> <pr>(l<ecr/g"g<ycr/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>having tall spindly stems; -- of plants.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> tall-growing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Having long legs.</def> <wns>[wns=2]</wns>
<rj><au>Thackeray.</au></rj><br/
<syn><b>Syn. --</b> long-legged, long-shanked.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leghorn</ent><br/
<hw>Leg"horn</hw> <pr>(l<ecr/g"h<ocir/rn)</pr>, <pos>n.</pos> <def>A
straw plaiting used for bonnets and hats, made from the straw of a
particular kind of wheat, grown for the purpose in Tuscany, Italy; -- so
called from Leghorn, the place of exportation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legibility</ent><br/
<hw>Leg`i*bil"i*ty</hw> <pr>(l<ecr/j`<icr/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The quality of being legible; legibleness.</def>
<rj><au>Sir. D. Brewster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legible</ent><br/
<hw>Leg"i*ble</hw> <pr>(l<ecr/j"<icr/*b'l)</pr>, <pos>a.</pos> <ety>[L.
<ets>legibilis</ets>, fr. <ets>legere</ets> to read: cf. OF.
<ets>legible</ets>. See <er>Legend</er>.]</ety> <sn>1.</sn> <def>Capable
of being read or deciphered; distinct to the eye; plain; -- used of
writing or printing; <as>as, a fair, <ex>legible</ex>
manuscript</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The stone with moss and lichens so overspread,<br/
Nothing is <qex>legible</qex> but the name alone.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being discovered or understood by
apparent marks or indications; <as>as, the thoughts of men are often
<ex>legible</ex> in their countenances</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legibleness</ent><br/
<hw>Leg"i*ble*ness</hw>, <pos>n.</pos> <def>The state or quality of
being legible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legibly</ent><br/
<hw>Leg"i*bly</hw>, <pos>adv.</pos> <def>In a legible manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legific</ent><br/
<hw>Le*gif"ic</hw> <pr>(l<esl/*j<icr/f"<icr/k)</pr>, <pos>a.</pos>
<ety>[L. <ets>lex</ets>, <ets>legis</ets>, law + <ets>-ficare</ets> (in
comp.) to make. See <er>-fy</er>.]</ety> <def>Of or pertaining to making
laws.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Practically, in many cases, authority or <qex>legific</qex>
competence has begun in bare power.</q> <rj><qau>J.
Grote.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legion</ent><br/
<hw>Le"gion</hw> <pr>(l<emac/"j<ucr/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>legioun</ets>, OF. <ets>legion</ets>, F. <ets>l<eacute/gion</ets>,
fr. L. <ets>legio</ets>, fr. <ets>legere</ets> to gather, collect. See
<er>Legend</er>.]</ety> <sn>1.</sn> <fld>(Rom. Antiq.)</fld> <def>A body
of foot soldiers and cavalry consisting of different numbers at
different periods, -- from about four thousand to about six thousand
men, -- the cavalry being about one tenth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A military force; an army; military bands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A great number; a multitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where one sin has entered, <qex>legions</qex> will force their way
through the same breach.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Taxonomy)</fld> <def>A group of orders inferior to
a class.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Legion of honor</b></col>, <cd>an order instituted by the
French government in 1802, when Bonaparte was First Consul, as a reward
for merit, both civil and military.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legionary</ent><br/
<hw>Le"gion*a*ry</hw> <pr>(-<asl/*r<ycr/)</pr>, <pos>a.</pos> <ety>[L.
<ets>legionarius</ets>: cf. F. <ets>l<eacute/gionnaire</ets>.]</ety>
<def>Belonging to a legion; consisting of a legion or legions, or of an
indefinitely great number; <as>as, <ex>legionary</ex> soldiers; a
<ex>legionary</ex> force.</as></def> <ldquo/The <xex>legionary</xex>
body of error.<rdquo/ <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legionary</ent><br/
<hw>Le"gion*a*ry</hw> <pr>(l<emac/"j<ucr/n*<asl/*r<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Legionaries</plw>
<pr>(-r<icr/z)</pr>.</plu> <def>A member of a legion.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legioned</ent><br/
<hw>Le"gioned</hw> <pr>(l<emac/"j<ucr/nd)</pr>, <pos>a.</pos>
<def>Formed into a legion or legions; legionary.</def>
<rj><au>Shelley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legionry</ent><br/
<hw>Le"gion*ry</hw> <pr>(l<emac/"j<ucr/n*r<ycr/)</pr>, <pos>n.</pos>
<def>A body of legions; legions, collectively.</def> <mark>[R.]</mark>
<rj><au>Pollok.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislate</ent><br/
<hw>Leg"is*late</hw> <pr>(l<ecr/j"<icr/s*l<amac/t)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Legislated</conjf>
<pr>(-l<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Legislating</conjf> <pr>(-l<amac/`t<icr/ng)</pr>.]</vmorph>
<ety>[See <er>Legislator</er>.]</ety> <def>To make or enact a law or
laws.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Solon, in <qex>legislating</qex> for the Athenians, had an idea of
a more perfect constitution than he gave them.</q> <rj><qau>Bp. Watson
(1805).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>legislating</ent><br/
<hw>legislating</hw> <pos>n.</pos> <def>the act of making or enacting
laws; legislation{1}.</def><br/
<syn><b>Syn. --</b> legislation, lawmaking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Legislation</ent><br/
<hw>Leg`is*la"tion</hw> <pr>(-l<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>l<eacute/gislation</ets>, L. <ets>legis latio</ets>.
See <er>Legislator</er>.]</ety> <def>The act of legislating; preparation
and enactment of laws; the laws enacted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pythagoras joined <qex>legislation</qex> to his philosophy.</q>
<rj><qau>Lyttelton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislative</ent><br/
<hw>Leg"is*la*tive</hw> <pr>(l<ecr/j"<icr/s*l<asl/*t<icr/v)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>l<eacute/gislatif</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Making, or having the power to make, a law or laws;
lawmaking; -- distinguished from <contr>executive</contr>; <as>as, a
<ex>legislative</ex> act; a <ex>legislative</ex> body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The supreme <qex>legislative</qex> power of England was lodged in
the king and great council, or what was afterwards called the
Parliament.</q> <rj><qau>Hume.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the making of laws; suitable to
legislation; <as>as, the transaction of <ex>legislative</ex> business;
the <ex>legislative</ex> style.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislatively</ent><br/
<hw>Leg"is*la*tive*ly</hw>, <pos>adv.</pos> <def>In a legislative
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislator</ent><br/
<hw>Leg"is*la`tor</hw> <pr>(l<ecr/j"<icr/s*l<amac/`t<etil/r)</pr>,
<pos>n.</pos> <ety>[L. <ets>legis lator</ets>, prop., a proposer of a
law; <ets>lex</ets>, <ets>legis</ets>, law + <ets>lator</ets> a
proposer, bearer, fr. <ets>latus</ets>, used as p. p. of
<ets>ferre</ets> to bear: cf. F. <ets>l<eacute/gislateur</ets>. See
<er>Legal</er>, and <er>Tolerate</er>.]</ety> <def>A lawgiver; one who
makes laws for a state or community; a member of a legislative
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>legislators</qex> in ancient and heroical times.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Many of the <qex>legislators</qex> themselves had taken an oath of
abjuration of his Majesty's person and family.</q> <rj><qau>E.
Phillips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislatorial</ent><br/
<hw>Leg`is*la*to"ri*al</hw> <pr>(-l<adot/*t<omac/"r<icr/*<ait/l)</pr>,
<pos>a.</pos> <def>Of or pertaining to a legislator or
legislature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislatorship</ent><br/
<hw>Leg"is*la`tor*ship</hw>
<pr>(l<ecr/j"<icr/s*l<amac/`t<etil/r*sh<icr/p)</pr>, <pos>n.</pos>
<def>The office of a legislator.</def> <rj><au>Halifax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislatrix</ent><br/
<ent>Legislatress</ent><br/
<mhw>{ <hw>Leg"is*la`tress</hw> <pr>(-tr<ecr/s)</pr>,
<hw>Leg"is*la`trix</hw> <pr>(-tr<icr/ks)</pr>, }</mhw> <pos>n.</pos>
<def>A woman who makes laws.</def> <rj><au>Shaftesbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legislature</ent><br/
<hw>Leg"is*la`ture</hw> <pr>(l<ecr/j"<icr/s*l<amac/`t<usl/r; 135)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>l<eacute/gislature</ets>.]</ety>
<def>The body of persons in a state or kingdom invested with power to
make and repeal laws; a legislative body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Without the concurrent consent of all three parts of the
<qex>legislature</qex>, no law is, or can be, made.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <ex>legislature</ex> of Great Britain consists of
the Lords and Commons, with the king or queen, whose sanction is
necessary to every bill before it becomes a law. The
<ex>legislatures</ex> of most of the United States consist of two houses
or branches; but the sanction or consent of the governor is required to
give their acts the force of law, or a concurrence of two thirds of the
two houses after he has refused his sanction and assigned his
objections.</note><br/
[<source>1913 Webster</source>]</p>

<note><p>The legislatures of some of the more important states having
constitutional government are as follows, the general name (or a
translation of it) of the legislative body collectively being given
under the heading <xex>legislature</xex>, <xex>or parliament</xex>:</p>

<p><-- ##?? Untyped: a Table of countries with their types of
legislatures. -->
<table><pre>
<headrow><item>State</item><item>Legislature, or parliament</item><mitem>Upper House<colret/<item>Name</item><item>Number of members -- how chosen or composed -- term of office</item></mitem><mitem>Lower House<colret/<item>Name</item><item>Number of members -- suffrage -- term of office</item></mitem></headrow>
-----------------------------------------------------------------
<row><item>Argentina</item><item>National Congress</item><item>Senate</item><item>30 -- 2 from each province and 2 from capital -- 9 years</item><item>House of Deputies</item><item>120  (1 to 33,000) -- Manhood -- 4 years</item></row>
<row><item>Austria</item><item>Reichsrath</item><item></item><item></item><item></item><item></item></row>
<row><item>Belgium</item><item>The Chambers</item><item></item><item></item><item></item><item></item></row>
<row><item>Brazil</item><item>National Congress</item><item></item><item></item><item></item><item></item></row>
<row><item>Chile</item><item>National Congress</item><item></item><item></item><item></item><item></item></row>
<row><item>Denmark</item><item>Rigsdag</item><item></item><item></item><item></item><item></item></row>
<row><item>France</item><item>National Assembly</item><item></item><item></item><item></item><item></item></row>
<row><item>German Empire</item><item>Imperial legislature</item><item></item><item></item><item></item><item></item></row>
<row><item>*Great Britain</item><item>Parliament</item><item>House of Lords</item><item>About 600</item><item>House of Commons</item><item>About 670 -- 7 years, or until dissolution</item></row>
<row><item>Greece</item><item></item><item></item><item></item><item></item><item></item></row>
<row><item>Hungary</item><item>Orz<aacute/g-gy<uum/l<eacute/s</item><item></item><item></item><item></item><item></item></row>
<row><item>Italy</item><item>Parliament</item><item></item><item></item><item></item><item></item></row>
<row><item>Japan</item><item>Imperial Diet</item><item></item><item></item><item></item><item></item></row>
<row><item>Mexico</item><item>Congress</item><item></item><item></item><item></item><item></item></row>
<row><item>Netherlands</item><item>States-General</item><item></item><item></item><item></item><item></item></row>
<row><item>#Norway</item><item>Storthing</item><item></item><item></item><item></item><item></item></row>
<row><item>Portugal</item><item>Cortes Geraes (general Assembly)</item><item></item><item></item><item></item><item></item></row>
<row><item>Prussia</item><item>Landtag</item>Herrenhaus<item></item><item>No limit -- very various classes -- For different terms</item><item>Abgeordnetenhaus</item><item>433 -- Indirect election, general suffrage<sect/ -- 5 years, or until dissolution</item></row>
<row><item>Spain</item><item>Cortes</item><item></item><item></item><item></item><item></item></row>
<row><item>Sweden</item><item>Diet</item><item></item><item></item><item></item><item></item></row>
<row><item>Switzerland</item><item>Bundesversammlung</item><item></item><item></item><item></item><item></item></row>
<row><item>United States</item><item>Congress</item><item>Senate</item><item>92(1908) -- 6 years</item><item>House of Representatives</item><item>391 (1908) -- 2 years.</item></row>
</pre></table>
---------------------------------------------------------------- *In the
self-governing colonies of Great Britain the legislative body usually
consists of two chambers, the names of the legislature and the chambers
varying. Thus in Australia the Federal Parliament is composed of the
Senate and the House of Commons, in New Zealand the General Assembly is
composed of the Legislative Council and the House of Representatives,
etc.</p>

<p>#Members of the Storthing are chosen for three years by direct
election by manhood suffrage, forty-one being elected from the towns and
eighty-two from the rural districts. The Storthing on assembling divides
into the Lagthing including one fourth and the Odelsthing including
three fourths of the total membership of the Storthing. All new laws are
laid first before the Odelsthing. If the two houses do not agree they
vote in joint session, a majority of two thirds of those voting being
necessary to a decision.</p>

<p><sect/ While theoretically general, the suffrage is so classified as
often practically to disfranchise those who are not property holders.
<br/
[<source>Webster 1913 Suppl.</source>]</p></note>

<p><ent>Legist</ent><br/
<hw>Le"gist</hw> <pr>(l<emac/"j<icr/st)</pr>, <pos>n.</pos> <ety>[F.
<ets>l<eacute/giste</ets>, LL. <ets>legista</ets>, fr. L.
<ets>lex</ets>, <ets>legis</ets>, law. See <er>Legal</er>.]</ety>
<def>One skilled in the laws; a writer on law.</def>
<rj><au>Milman.</au> <au>J. Morley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitim</ent><br/
<hw>Le*git"im</hw> <pr>(l<esl/*j<icr/"<icr/m)</pr>, <pos>n.</pos>
<ety>[See <er>Legitimate</er>, <pos>a.</pos>]</ety> <fld>(Scots
Law)</fld> <def>The portion of movable estate to which the children are
entitled upon the death of the father.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimacy</ent><br/
<hw>Le*git"i*ma*cy</hw> <pr>(-<icr/*m<adot/*s<ycr/)</pr>, <pos>n.</pos>
<ety>[See <er>Legitimate</er>, <pos>a.</pos>]</ety> <def>The state, or
quality, of being legitimate, or in conformity with law; hence, the
condition of having been lawfully begotten, or born in
wedlock.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The doctrine of Divine Right, which has now come back to us, like
a thief from transportation, under the alias of
<qex>Legitimacy</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimate</ent><br/
<hw>Le*git"i*mate</hw> <pr>(-m<asl/t)</pr>, <pos>a.</pos> <ety>[LL.
<ets>legitimatus</ets>, p. p. of <ets>legitimare</ets> to legitimate,
fr. L. <ets>legitimus</ets> legitimate. See <er>Legal</er>.]</ety>
<sn>1.</sn> <def>Accordant with law or with established legal forms and
requirements; lawful; <as>as, <ex>legitimate</ex> government;
<ex>legitimate</ex> rights; the <ex>legitimate</ex> succession to the
throne; a <ex>legitimate</ex> proceeding of an officer; a
<ex>legitimate</ex> heir.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lawfully begotten; born in wedlock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Authorized; real; genuine; not false, counterfeit,
or spurious; <as>as,$<ex>legitimate</ex> poems of Chaucer;
<ex>legitimate</ex> inscriptions.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Conforming to known principles, or accepted rules;
<as>as, <ex>legitimate</ex> reasoning; a <ex>legitimate</ex> standard,
or method; a <ex>legitimate</ex> combination of colors.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tillotson still keeps his place as a <qex>legitimate</qex> English
classic.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Following by logical sequence; reasonable; <as>as, a
<ex>legitimate</ex> result; a <ex>legitimate</ex>
inference.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimate</ent><br/
<hw>Le*git"i*mate</hw> <pr>(-m<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Legitimated</conjf>
<pr>(-m<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Legitimating</conjf> <pr>(-m<amac/`t<icr/ng)</pr>.]</vmorph>
<def>To make legitimate, lawful, or valid; esp., to put in the position
or state of a legitimate person before the law, by legal means; <as>as,
to <ex>legitimate</ex> a bastard child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To enact a statute of that which he dares not seem to approve,
even to <qex>legitimate</qex> vice.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimately</ent><br/
<hw>Le*git"i*mate*ly</hw> <pr>(-m<asl/t*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a legitimate manner; lawfully; genuinely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimateness</ent><br/
<hw>Le*git"i*mate*ness</hw>, <pos>n.</pos> <def>The state or quality of
being legitimate; lawfulness; genuineness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimation</ent><br/
<hw>Le*git`i*ma"tion</hw> <pr>(-m<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>l<eacute/gitimation</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of making legitimate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The coining or <qex>legitimation</qex> of money.</q>
<rj><qau>East.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lawful birth.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimatist</ent><br/
<hw>Le*git"i*ma*tist</hw>
<pr>(l<esl/*j<icr/t"<icr/*m<adot/*t<icr/st)</pr>, <pos>n.</pos> <def>See
<er>Legitimist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimatize</ent><br/
<hw>Le*git"i*ma*tize</hw> <pr>(-t<imac/z)</pr>, <pos>v. t.</pos> <def>To
legitimate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimism</ent><br/
<hw>Le*git"i*mism</hw> <pr>(-m<icr/z'm)</pr>, <pos>n.</pos> <def>The
principles or plans of legitimists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legitimist</ent><br/
<hw>Le*git"i*mist</hw> <pr>(-m<icr/st)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>l<eacute/gitimiste</ets>.]</ety> <sn>1.</sn> <def>One who supports
legitimate authority; esp., one who believes in hereditary monarchy, as
a divine right.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, a supporter of the claims of the elder
branch of the Bourbon dynasty to the crown of France.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 842 pr=VMG --></p>

<p><ent>Legitimize</ent><br/
<hw>Le*git"i*mize</hw> <pr>(l<esl/*j<icr/t"<icr/*m<imac/z)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Legitimized</conjf>
<pr>(-m<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Legitimizing</conjf>.]</vmorph> <def>To legitimate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legless</ent><br/
<hw>Leg"less</hw> <pr>(l<ecr/g"l<ecr/s)</pr>, <pos>a.</pos> <def>Not
having a leg.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leg-of-mutton</ent><br/
<hw>Leg"-of-mut"ton</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
general shape or outline of a leg of mutton; <as>as, a
<ex>leg-of-mutton</ex>, or shoulder-of-mutton, sail</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lego-literary</ent><br/
<hw>Le"go-lit"er*a*ry</hw>
<pr>(l<emac/"g<osl/-l<icr/t"<etil/r*<asl/*r<ycr/)</pr>, <pos>a.</pos>
<ety>[See <er>Legal</er>, and <er>Literary</er>.]</ety> <def>Pertaining
to the literature of law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leg-pull</ent><br/
<hw>leg-pull</hw> <pos>n.</pos> <def>An attempt to make somebody believe
something that is not true, done as a joke.</def><br/
<syn><b>Syn. --</b> leg-pulling.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leg-pulling</ent><br/
<hw>leg-pulling</hw> <pos>n.</pos> <def>The act of attempting to make
somebody believe something that is not true, done as a joke.</def><br/
<syn><b>Syn. --</b> leg-pull.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leguleian</ent><br/
<hw>Le`gu*le"ian</hw> <pr>(l<emac/`g<usl/*l<emac/"y<ait/n)</pr>,
<pos>a.</pos> <ety>[L. <ets>leguleius</ets> pettifogger, fr.
<ets>lex</ets>, <ets>legis</ets>, law.]</ety> <def>Lawyerlike;
legal.</def> <mark>[R.]</mark> <ldquo/<xex>Leguleian</xex>
barbarism.<rdquo/ <au>De Quincey.</au> -- <def2><pos>n.</pos> <def>A
lawyer.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legume</ent><br/
<hw>Leg"ume</hw> <pr>(l<ecr/g"<usl/m <or/ l<esl/*g<umac/m")</pr>,
<pos>n.</pos> <ety>[F. <ets>l<eacute/gume</ets>, L. <ets>legumen</ets>,
fr. <ets>legere</ets> to gather. So called because they may be gathered
without cutting. See <er>Legend</er>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A pod dehiscent into two pieces or valves, and
having the seed attached at one suture, as that of the pea.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the latter circumstance, it differs from a
<xex>siliqua</xex>, in which the seeds are attached to both sutures. In
popular use, a <xex>legume</xex> is called a <xex>pod</xex>, or
<xex>cod</xex>; as, pea <xex>pod</xex>, or peas
<xex>cod</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>The fruit of leguminous plants, as
peas, beans, lupines; pulse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legumen</ent><br/
\'d8<hw>Le*gu"men</hw> <pr>(l<esl/*g<umac/"m<ecr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Legumina</plw> <pr>(-m<icr/*n<adot/)</pr>, E.
<plw>Legumens</plw> <pr>(-m<ecr/nz)</pr>.</plu> <ety>[L.]</ety>
<def>Same as <er>Legume</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Legumin</ent><br/
<hw>Le*gu"min</hw> <pr>(-m<icr/n)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>l<eacute/gumine</ets>.]</ety> <fld>(Physiol. Chem.)</fld> <def>An
albuminous substance resembling casein, found as a characteristic
ingredient of the seeds of leguminous and grain-bearing
plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leguminous</ent><br/
<hw>Le*gu"mi*nous</hw> <pr>(-m<icr/*n<ucr/s)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>l<eacute/gumineux</ets>.]</ety> <sn>1.</sn>
<def>Pertaining to pulse; consisting of pulse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Belonging to, or resembling, a
very large natural order of plants (<ord>Leguminos<ae/</ord>), which
bear legumes, including peas, beans, clover, locust trees, acacias, and
mimosas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leiger</ent><br/
<hw>Lei"ger</hw> <pr>(l<emac/"j<etil/r)</pr>, <pos>n.</pos> <ety>[See
<er>Leger</er>, and <er>Ledger</er>.]</ety> <def>See <er>Leger</er>,
<pos>n.</pos>, 2.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leiopelma</ent><br/
<hw>Leiopelma</hw> <pos>n.</pos> <def>The type and sole genus of the
family <fam>Leiopelmatidae</fam>.</def> <altsp>[Also spelled
<asp><gen>Liopelma</gen></asp>.]</altsp><br/
<syn><b>Syn. --</b> genus <gen>Leiopelma</gen>, Liopelma, genus
<gen>Liopelma</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leiopelmatidae</ent><br/
<hw>Leiopelmatidae</hw> <pos>n.</pos> <def>A natural family of primitive
New Zealand frogs.</def> <altsp>[Also spelled
<asp><fam>Liopelmidae</fam></asp>.]</altsp><br/
<syn><b>Syn. --</b> family <fam>Leiopelmatidae</fam>, Liopelmidae,
family <fam>Liopelmidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leiophyllum</ent><br/
<hw>Leiophyllum</hw> <pos>n.</pos> <def>A genus having only one species,
the sand myrtle.</def><br/
<syn><b>Syn. --</b> genus <gen>Leiophyllum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leiotrichan</ent><br/
<hw>Lei*ot"ri*chan</hw> <pr>(l<isl/*<ocr/t"r<icr/*k<ait/n)</pr>,
<pos>a.</pos> <def>Of or pertaining to the Leiotrichi.</def> --
<def2><pos>n.</pos> <def>One of the Leiotrichi.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leiotrichi</ent><br/
\'d8<hw>Lei*ot"ri*chi</hw> <pr>(-k<imac/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>lei^os</grk> smooth + <grk>qri`x</grk>,
<grk>tricho`s</grk>, hair.]</ety> <fld>(Anthropol.)</fld> <def>The
division of mankind which embraces the smooth-haired races.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leiotrichous</ent><br/
<hw>Lei*ot"ri*chous</hw> <pr>(-k<ucr/s)</pr>, <pos>a.</pos> <ety>[See
<er>Leiotrichi</er>.]</ety> <fld>(Anthropol.)</fld> <def>Having smooth,
or nearly smooth, hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leipoa</ent><br/
\'d8<hw>Lei*po"a</hw> <pr>(l<isl/*p<omac/"<adot/)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A genus of Australian
gallinaceous birds including but a single species (<spn>Leipoa
ocellata</spn>), about the size of a turkey. Its color is variegated,
brown, black, white, and gray. Called also <altname>native
pheasant</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It makes large mounds of sand and vegetable material, in
which its eggs are laid to be hatched by the heat of the decomposing
mass.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leipothymic</ent><br/
<hw>Lei`po*thym"ic</hw> <pr>(l<imac/`p<osl/*th<icr/m"<icr/k)</pr>,
<pos>a.</pos> <def>See <er>Lipothymic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lister</ent><br/
<ent>Leister</ent><br/
<mhw>{ <hw>Leis"ter</hw>, <hw>Lis"ter</hw> }</mhw>
<pr>(l<icr/s"t<etil/r)</pr>, <pos>n.</pos> <def>A spear armed with three
or more prongs, for striking fish.</def> <mark>[Scotland]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisurable</ent><br/
<hw>Lei"sur*a*ble</hw> <pr>(l<emac/"zh<usl/r*<adot/*b'l; 135)</pr>,
<pos>a.</pos> <ety>[See <er>Leisure</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Leisurely.</def> <mark>[Obs.]</mark>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vacant of employment; not occupied; idle; leisure;
<as>as <ex>leisurable</ex> hours</as>.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisurably</ent><br/
<hw>Lei"sur*a*bly</hw>, <pos>adv.</pos> <def>At leisure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisure</ent><br/
<hw>Lei"sure</hw> <pr>(l<emac/"zh<usl/r; 135)</pr>, <pos>n.</pos>
<ety>[OE. <ets>leisere</ets>, <ets>leiser</ets>, OF. <ets>leisir</ets>,
F. <ets>loisir</ets>, orig., permission, fr. L. <ets>licere</ets> to be
permitted. See <er>License</er>.]</ety> <sn>1.</sn> <def>Freedom from
occupation or business; vacant time; time free from
employment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The desire of <qex>leisure</qex> is much more natural than of
business and care.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Time at one's command, free from engagement;
convenient opportunity; hence, convenience; ease.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He sighed, and had no <qex>leisure</qex> more to say.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At leisure</b></col>. <sd>(a)</sd> <cd>Free from
occupation; not busy.</cd> <sd>(b)</sd> <cd>In a leisurely manner; at a
convenient time.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisure</ent><br/
<hw>Lei"sure</hw>, <pos>a.</pos> <def>Unemployed; <as>as,
<ex>leisure</ex> hours</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisured</ent><br/
<hw>Lei"sured</hw> <pr>(l<emac/"zh<usl/rd)</pr>, <pos>a.</pos>
<def>Having leisure.</def> <ldquo/The <xex>leisured</xex>
classes.<rdquo/ <rj><au>Gladstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisurely</ent><br/
<hw>Lei"sure*ly</hw> <pr>(l<emac/"zh<usl/r*l<ycr/)</pr>, <pos>a.</pos>
<def>Characterized by leisure; taking abundant time; not hurried;
<as>as, a <ex>leisurely</ex> manner; a <ex>leisurely</ex>
walk.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leisurely</ent><br/
<hw>Lei"sure*ly</hw>, <pos>adv.</pos> <def>In a leisurely manner.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leitmotiv</ent><br/
<ent>Leitmotif</ent><br/
<mhw><hw>Leit"mo*tif"</hw>, \'d8<hw>Leit"mo*tiv"</hw></mhw>
<pr>(l<imac/t"m<osl/*t<esl/f")</pr>, <pos>n.</pos> <ety>[G., leading
motive.]</ety> <sn>1.</sn> <fld>(Mus.)</fld> <def>a guiding theme; in
Wagnerian opera, a marked melodic phrase or short musical passage which
always accompanies the reappearance of a certain person, situation,
abstract idea, or allusion in the course of the play; a sort of musical
label. Also called <cref>Leading motive</cref>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>a recurring theme in the activities of a person or
group.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leitneria</ent><br/
<hw>Leitneria</hw> <pos>prop. n.</pos> <def>A genus of trees or shrubs
coextensive with the family <fam>Leitneriaceae</fam>, and including the
corkwood (<spn>Leitneria floridana</spn>).</def><br/
<syn><b>Syn. --</b> family <fam>Leitneriaceae</fam>, corkwood
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leitneriaceae</ent><br/
<hw>Leitneriaceae</hw> <pos>prop. n.</pos> <def>A natural family of
trees coextensive with the genus <gen>Leitneria</gen>; commonly isolated
in a distinct order.</def><br/
<syn><b>Syn. --</b> family Leitneriaceae, corkwood family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>L.E.M.</ent><br/
<ent>LEM</ent><br/
<mhw><hw>LEM</hw>, <hw>L.E.M.</hw></mhw> <pos>n.</pos> <ety>[acronym
from <ets>L</ets>unar <ets>E</ets>xcursion <ets>M</ets>odule.]</ety>
<fld>(Astronautics)</fld> <def>A <altname>lunar excursion
module</altname>, a spacecraft designed to transport people from a
command module in orbit around the moon to the surface of the moon and
back again.</def><br/
<syn><b>Syn. --</b> lunar excursion module, lunar module.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lemaireocereus</ent><br/
<hw>Lemaireocereus</hw> <pos>n.</pos> <def>A genus of tropical American
cacti, usually tall and branching with stout spines and funnel-shaped
flowers and globular or ovoid often edible fruit.</def><br/
<syn><b>Syn. --</b> genus <gen>Lemaireocereus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leman</ent><br/
<hw>Le"man</hw> <pr>(l<emac/"m<ait/n <or/ l<ecr/m"<ait/n; 277)</pr>,
<pos>n.</pos> <ety>[OE. <ets>lemman</ets>, <ets>lefman</ets>; AS.
<ets>le<oacute/f</ets> dear + <ets>mann</ets> man. See <er>Lief</er>,
and <er>Man</er>.]</ety> <def>A sweetheart, of either sex; a gallant, or
a mistress; -- usually in a bad sense.</def> <mark>[Archaic]</mark>
<rj><au>Chaucer.</au> <au>Spenser.</au> <au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lemanderin</ent><br/
<hw>lemanderin</hw> <pos>n.</pos> <def>A fruit tree (<spn>Citrus
limonia</spn>) which is a hybrid between the mandarin orange and the
lemon, having a very acid fruit with an orange peel; also, the fruit of
this tree, the <altname>rangpur</altname>.</def><br/
<syn><b>Syn. --</b> rangpur, rangpur lime, <spn>Citrus
limonia</spn>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Leme</ent><br/
<hw>Leme</hw> <pr>(l<emac/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>leem</ets>, <ets>leme</ets>, <ets>leam</ets>, AS.
<ets>le<oacute/ma</ets> light, brightness; akin to E. <ets>light</ets>,
<pos>n.</pos> <root/122.]</ety> <def>A ray or glimmer of light; a
gleam.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leme</ent><br/
<hw>Leme</hw>, <pos>v. i.</pos> <def>To shine.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemma</ent><br/
<hw>Lem"ma</hw> <pr>(l<ecr/m"m<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Lemmata</plw> <pr>(-m<adot/*t<adot/)</pr>, E.
<plw>Lemmas</plw> <pr>(-m<adot/z)</pr>.</plu> <ety>[L. <ets>lemma</ets>,
Gr. <grk>lh^mma</grk> anything received, an assumption or premise taken
for granted, fr. <grk>lamba`nein</grk> to take, assume. Cf.
<er>Syllable</er>.]</ety> <sn>1.</sn> <fld>(Math., Logic)</fld> <def>A
preliminary or auxiliary proposition demonstrated or accepted for
immediate use in the demonstration of some other proposition, as in
mathematics or logic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A word that is included in a glossary or list of
headwords; a headword.</def><br/
[<source>PJC</source>]</p>

<p><ent>lemmatization</ent><br/
<hw>lem`ma*tiz*a"tion</hw>
<pr>(l<ecr/m`m<adot/*t<icr/z*<amac/"sh<ucr/n)</pr>, <pos>v. t.</pos>
<def>The act or process of lemmatizing; conversion into a
lemma{2}.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ <ex>Lemmatization</ex> of search words in a computerized
Information Retrieval System may allow more effective retrieval of
documents of interest to the searcher.</note><br/
[<source>PJC</source>]</p>

<p><ent>lemmatize</ent><br/
<hw>lem"ma*tize</hw> <pr>(l<ecr/m"m<adot/*t<imac/z`)</pr>, <pos>v.
t.</pos> <def>To convert into a lemma{2}; to normalize the form of (a
word) to that form used as the headword in a dictionary, glossary, or
index; <as>as, <ldquo/ride<rdquo/ is the <ex>lemmatized</ex> form for
<ldquo/riding<rdquo/ and <ldquo/ridden<rdquo/</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lemman</ent><br/
<hw>Lem"man</hw> <pr>(l<ecr/m"m<ait/n)</pr>, <pos>n.</pos> <def>A
leman.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemming</ent><br/
<hw>Lem"ming</hw> <pr>(l<ecr/m"m<icr/ng)</pr>, <pos>n.</pos> <ety>[Nor.
<ets>lemming</ets>, <ets>lemende</ets>; cf. Sw. <ets>lemel</ets>, Lapp.
<ets>lummik</ets>.]</ety> <fld>(Zool.)</fld> <def>Any one of several
species of small arctic rodents of the genera <gen>Myodes</gen> and
<gen>Cuniculus</gen>, resembling the meadow mice in form. They are found
in both hemispheres.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common Northern European lemming (<spn>Myodes
lemmus</spn>) is remarkable for making occasional devastating migrations
in enormous numbers from the mountains into the lowlands.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemna</ent><br/
<hw>Lemna</hw> <pos>n.</pos> <def>A genus of minute aquatic herbs
floating on or below the water surface of still water consisting of a
leaflike frond or plant body and single root.</def><br/
<syn><b>Syn. --</b> genus <gen>Lemna</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lemnaceae</ent><br/
<hw>Lemnaceae</hw> <pos>n.</pos> <def>A natural family of small
free-floating thalloid plants.</def><br/
<syn><b>Syn. --</b> family <fam>Lemnaceae</fam>, duckweed
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lemnian</ent><br/
<hw>Lem"ni*an</hw> <pr>(l<ecr/m"n<icr/*<ait/n)</pr>, <pos>a.</pos>
<ety>[L. <ets>Lemnius</ets>, fr. <ets>Lemnus</ets>, Gr.
<grk>Lh^mnos</grk>.]</ety> <def>Of or pertaining to the isle of
Lemnos.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Lemnian bole</b></col>, <col><b>Lemnian
earth</b></col></mcol>, <cd>an aluminous earth of a grayish yellow
color; sphragide; -- formerly sold as medicine, having astringent
properties.</cd> -- <col><b>Lemnian reddle</b></col>, <cd>a reddle of
firm consistence and deep red color; -- used by artificers in
coloring.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemniscate</ent><br/
<ent>Lemniscata</ent><br/
<mhw>{ <hw>Lem`nis*ca"ta</hw>
<pr>(l<ecr/m`n<icr/s*k<amac/"t<adot/)</pr>, <hw>Lem*nis"cate</hw>
<pr>(l<ecr/m*n<icr/s"k<asl/t)</pr>, }</mhw> <pos>n.</pos> <ety>[L.
<ets>lemniscatus</ets> adorned with ribbons, fr. <ets>lemniscus</ets> a
ribbon hanging down, Gr. <grk>lhmni`skos</grk>.]</ety>
<fld>(Geom.)</fld> <def>A curve in the form of the figure 8, with both
parts symmetrical, generated by the point in which a tangent to an
equilateral hyperbola meets the perpendicular on it drawn from the
center.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemniscus</ent><br/
\'d8<hw>Lem*nis"cus</hw> <pr>(l<ecr/m*n<icr/s"k<ucr/s)</pr>,
<pos>n.</pos>; <plu><it>pl.</it></plu> <plw>Lemnisci</plw>
<pr>(-s<imac/)</pr> <pos>n.</pos><ety>[L. See
<er>Lemniscata</er>.]</ety> <fld>(Zool.)</fld> <def>One of two oval
bodies hanging from the interior walls of the body in the
Acanthocephala.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemon</ent><br/
<hw>Lem"on</hw> <pr>(l<ecr/m"<ucr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>limon</ets>, Per. <ets>l<imac/m<umac/n</ets>; cf. Ar.
<ets>laim<umac/n</ets>, Sp. <ets>limon</ets>, It. <ets>limone</ets>. Cf.
<er>Lime</er> a fruit.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>An oval or roundish fruit
resembling the orange, and containing a pulp usually intensely acid. It
is produced by a tropical tree of the genus <gen>Citrus</gen>, the
common fruit known in commerce being that of the species <spn>Citrus
Limonum</spn> or <spn>Citrus Medica</spn> (var. <varn>Limonum</varn>).
There are many varieties of the fruit, some of which are
sweet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The tree which bears lemons; the lemon
tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lemon grass</b></col> <fld>(Bot.)</fld>, <cd>a fragrant
East Indian grass (<spn>Andropogon Sh<oe/nanthus</spn>, and perhaps
other allied species), which yields the grass oil used in
perfumery.</cd> -- <col><b>Lemon sole</b></col> <fld>(Zool.)</fld>,
<cd>a yellow European sole (<spn>Solea aurantiaca</spn>).</cd> --
<col><b>Salts of lemon</b></col> <fld>(Chem.)</fld>, <cd>a white
crystalline substance, inappropriately named, as it consists of an acid
potassium oxalate and contains no citric acid, which is the
characteristic acid of lemon; -- called also <altname>salts of
sorrel</altname>. It is used in removing ink stains. See <cref>Oxalic
acid</cref>, under <er>Oxalic</er>.</cd> <mark>[Colloq.]</mark></cs></p>

<p><-- Lemon adj. 1. of the color lemon-yellow. 2. of or relating to
lemons, as lemon pie. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemonade</ent><br/
<hw>Lem`on*ade"</hw> <pr>(l<ecr/m`<ucr/n*<amac/d")</pr>, <pos>n.</pos>
<ety>[F. <ets>limonade</ets>; cf. Sp. <ets>limonada</ets>, It.
<ets>limonata</ets>. See <er>Lemon</er>.]</ety> <def>A beverage
consisting of lemon juice mixed with water and sweetened.</def>
<ldquo/If you have lemons, make <xex>lemonade</xex><rdquo/ <br/
[<source>1913 Webster</source>]</p>

<p><ent>lemonwood</ent><br/
<hw>lemonwood</hw> <pos>n.</pos> <sn>1.</sn> <def>hard tough elastic
wood of the lemonwood tree; used for making bows and fishing
rods.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A South African evergreen having hard tough
wood.</def><br/
<syn><b>Syn. --</b> lemonwood tree, <spn>Psychotria capensis</spn>
.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lemony</ent><br/
<hw>lemony</hw> <pos>adj.</pos> <sn>1.</sn> <def>tasting like
lemons.</def><br/
<syn><b>Syn. --</b> sourish, tangy, tart.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lemur</ent><br/
<hw>Le"mur</hw> <pr>(l<emac/"m<ucr/r)</pr>, <pos>n.</pos> <ety>[L., a
ghost, specter. So called on account of its habit of going abroad by
night.]</ety> <fld>(Zool.)</fld> <def>One of a family
(<fam>Lemurid<ae/</fam>) of nocturnal mammals allied to the monkeys, but
of small size, and having a sharp and foxlike muzzle, and large eyes.
They feed upon birds, insects, and fruit, and are mostly natives of
Madagascar and the neighboring islands, one genus (<gen>Galago</gen>)
occurring in Africa. The slow lemur or <stype>kukang</stype> of the East
Indies is <spn>Nycticebus tardigradus</spn>. See <er>Galago</er>,
<er>Indris</er>, and <er>Colugo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemures</ent><br/
\'d8<hw>Lem"u*res</hw> <pr>(l<ecr/m"<usl/*r<emac/z; E.
l<emac/"m<umac/rz)</pr>, <pos>n. pl.</pos> <ety>[L. See
<er>Lemur</er>.]</ety> <def>Spirits or ghosts of the departed;
specters.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lars and <qex>Lemures</qex> moan with midnight plaint.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemuria</ent><br/
<hw>Le*mu"ri*a</hw> <pr>(l<esl/*m<umac/"r<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[So named from the supposition that it was the
original home of the <ets>lemurs</ets>.]</ety> <def>A hypothetical land,
or continent, supposed by some to have existed formerly in the Indian
Ocean, of which Madagascar is a remnant.</def>
<rj><au>Herschel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemurid</ent><br/
<hw>Lem"u*rid</hw> <pr>(l<ecr/m"<usl/*r<icr/d)</pr>, <pos>a. & n.</pos>
<fld>(Zool.)</fld> <def>Same as <er>Lemuroid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemurine</ent><br/
<ent>Lemuridous</ent><br/
<mhw>{ <hw>Le*mu"ri*dous</hw> <pr>(l<esl/*m<umac/"r<icr/*d<ucr/s)</pr>,
<hw>Lem"u*rine</hw> <pr>(l<ecr/m"<usl/*r<icr/n <or/ -r<imac/n)</pr>,
}</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Lemuroid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemuroid</ent><br/
<hw>Lem"u*roid</hw> <pr>(l<ecr/m"<usl/*roid)</pr>, <pos>a.</pos>
<ety>[<ets>Lemur</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Like or pertaining to the lemurs or the
<ord>Lemuroidea</ord>.</def> -- <def2><pos>n.</pos> <def>One of the
Lemuroidea.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lemuroidea</ent><br/
\'d8<hw>Lem`u*roi"de*a</hw> <pr>(l<ecr/m`<usl/*roi"d<esl/*<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL. See <er>Lemur</er>, and
<er>-oid</er>.]</ety> <fld>(Zool.)</fld> <def>A suborder of primates,
including the lemurs, the aye-aye, and allied species.</def>
<altsp>[Written also <asp>Lemuroida</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lena</ent><br/
\'d8<hw>Le"na</hw> <pr>(l<emac/"n<adot/)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <def>A procuress.</def> <rj><au>J.
Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenard rays</ent><br/
<hw>Le*nard" rays</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Physics.)</fld>
<def>Rays emanating from the outer surface of a plate composed of any
material permeable by cathode rays, as aluminium, which forms a portion
of a wall of a vacuum tube, or which is mounted within the tube and
exposed to radiation from the cathode. Lenard rays are similar in all
their known properties to cathode rays. So called from the German
physicist Philipp Lenard (b. 1862), who first described them.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lenard tube</ent><br/
<hw>Lenard tube</hw>. <fld>(Elec.)</fld> <def>A tube for producing
Lenard rays.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lend</ent><br/
<hw>Lend</hw> <pr>(l<ecr/nd)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lent</conjf> <pr>(l<ecr/nt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lending</conjf>.]</vmorph> <ety>[OE. <ets>lenen</ets>,
AS. <ets>l<aemac/nan</ets>, fr. <ets>l<aemac/n</ets> loan; akin to G.
<ets>lehnen</ets> to lend. See <er>Loan</er>.]</ety> <sn>1.</sn> <def>To
allow the custody and use of, on condition of the return of the same; to
grant the temporary use of; <as>as, to <ex>lend</ex> a book</as>; --
opposed to <contr>borrow</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give me that ring.<br/
I'll <qex>lend</qex> it thee, my dear, but have no power<br/
To give it from me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To allow the possession and use of, on condition of
the return of an equivalent in kind; <as>as, to <ex>lend</ex> money or
some article of food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt not give him thy money upon usury, nor <qex>lend</qex>
him thy victuals for increase.</q> <rj><qau>Levit. xxv.
37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To afford; to grant or furnish in general; <as>as,
to <ex>lend</ex> assistance; to <ex>lend</ex> one's name or
influence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cato, <qex>lend</qex> me for a while thy patience.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mountain lines and distant horizons <qex>lend</qex> space and
largeness to his compositions.</q> <rj><qau>J. A.
Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To let for hire or compensation; <as>as, to
<ex>lend</ex> a horse or gig</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This use of the word is rare in the United States,
except with reference to money.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lend a hand</b></col>, <cd>to give assistance; to
help.</cd> <mark>[Colloq.]</mark> -- <mcol><col><b>To lend one's
ears</b></col> <it>or</it> <col><b>To lend an ear</b></col></mcol>,
<cd>to give attention.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lendable</ent><br/
<hw>Lend"a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <def>Such as
can be lent.</def> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lender</ent><br/
<hw>Lend"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
lends.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The borrower is servant to the <qex>lender</qex>. </q>
<rj><qau>Prov. xxii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lendes</ent><br/
<hw>Lend"es</hw> <pr>(l<ecr/nd"<ecr/z)</pr>, <pos>n. pl.</pos> <def>See
<er>Lends</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lending</ent><br/
<hw>Lend"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
lends.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is lent or furnished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lend-lease</ent><br/
<hw>lend-lease</hw> <pos>n.</pos> <def>the temporary transfer of goods
and services to an ally to aid in a common cause; <as>as,
<ex>lend-lease</ex> during World War II was extremely
generous</as>.</def><br/
<syn><b>Syn. --</b> lease-lend.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lends</ent><br/
<hw>Lends</hw> <pr>(l<ecr/ndz)</pr>, <pos>n. pl.</pos> <ety>[AS.
<ets>lend</ets>, <ets>lenden</ets>; akin to D. & G. <ets>lende</ets>,
OHG. <ets>lenti</ets>, Icel. <ets>lend</ets>, and perh to E.
<ets>loin</ets>.]</ety> <def>Loins.</def> <mark>[Obs.]</mark>
<rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lene</ent><br/
<hw>Lene</hw> <pr>(l<emac/n)</pr>, <pos>v. t.</pos> <ety>[See
<er>Lend</er>.]</ety> <def>To lend; to grant; to permit.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lene</ent><br/
<hw>Le"ne</hw> <pr>(l<emac/"n<esl/)</pr>, <pos>a.</pos> <ety>[L.
<ets>lenis</ets> smooth.]</ety> <fld>(Phonetics)</fld> <sd>(a)</sd>
<def>Smooth; <as>as, the <ex>lene</ex> breathing</as>.</def>
<sd>(b)</sd> <def>Applied to certain mute consonants, as <it>p</it>,
<it>k</it>, and <it>t</it> (or Gr. <pi/, <kappa/, <tau/).</def>
<rj><au>W. E. Jelf.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lene</ent><br/
<hw>Le"ne</hw>, <pos>n.</pos> <fld>(Phonetics)</fld> <sd>(a)</sd>
<def>The smooth breathing (spiritus lenis).</def> <sd>(b)</sd> <def>Any
one of the lene consonants, as <it>p</it>, <it>k</it>, or <it>t</it> (or
Gr. <pi/, <kappa/, <tau/).</def> <rj><au>W. E. Jelf.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengest</ent><br/
<ent>Lenger</ent><br/
<mhw>{ <hw>Leng"er</hw> <pr>(l<ecr/ng"<etil/r)</pr>, <hw>Leng"est</hw>
}</mhw>, <pos>a.</pos> <def>Longer; longest; -- obsolete compar. and
superl. of <xex>long</xex>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Length</ent><br/
<hw>Length</hw> <pr>(l<ecr/ngth)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lengthe</ets>, AS. <ets>leng<edh/</ets>, fr. <ets>lang</ets>,
<ets>long</ets>, long; akin to D. <ets>lengte</ets>, Dan.
<ets>l<ae/ngde</ets>, Sw. <ets>l<aum/ngd</ets>, Icel. <ets>lengd</ets>.
See <er>Long</er>, <pos>a.</pos> ]</ety> <sn>1.</sn> <def>The longest,
or longer, dimension of any object, in distinction from
<contr>breadth</contr> or <contr>width</contr>; extent of anything from
end to end; the longest line which can be drawn through a body, parallel
to its sides; <as>as, the <ex>length</ex> of a church, or of a ship; the
<ex>length</ex> of a rope or line.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A portion of space or of time considered as measured
by its length; -- often in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Large <qex>lengths</qex> of seas and shores.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The future but a <qex>length</qex> behind the past.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The quality or state of being long, in space or
time; extent; duration; <as>as, some sea birds are remarkable for the
<ex>length</ex> of their wings; he was tired by the <ex>length</ex> of
the sermon, and the <ex>length</ex> of his walk.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A single piece or subdivision of a series, or of a
number of long pieces which may be connected together; <as>as, a
<ex>length</ex> of pipe; a <ex>length</ex> of fence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Detail or amplification; unfolding; continuance as,
to pursue a subject to a great <xex>length</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>May Heaven, great monarch, still augment your bliss<br/
With <qex>length</qex> of days, and every day like this.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Distance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He had marched to the <qex>length</qex> of Exeter.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At length</b></col>. <sd>(a)</sd> <cd>At or in the full
extent; without abbreviation; as, let the name be inserted <xex>at
length</xex>.</cd> <sd>(b)</sd> <cd>At the end or conclusion; after a
long period. See <sc>Syn.</sc> of <xex>At last</xex>, under
<er>Last</er>.</cd> -- <col><b>At arm's length</b></col>. <cd>See under
<er>Arm</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Length</ent><br/
<hw>Length</hw>, <pos>v. t.</pos> <def>To lengthen.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthen</ent><br/
<hw>Length"en</hw> <pr>(-'n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lengthened</conjf> <pr>(-'nd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lengthening</conjf> <pr>(-'n*<icr/ng)</pr>.]</vmorph>
<def>To extent in length; to make longer in extent or duration; <as>as,
to <ex>lengthen</ex> a line or a road; to <ex>lengthen</ex> life; --
sometimes followed by <ptcl>out</ptcl>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>What if I please to <qex>lengthen</qex> out his date.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthen</ent><br/
<hw>Length"en</hw>, <pos>v. i.</pos> <def>To become longer.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthful</ent><br/
<hw>Length"ful</hw> <pr>(-f<usdot/l)</pr>, <pos>a.</pos>
<def>Long.</def> <mark>[Obs.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthily</ent><br/
<hw>Length"i*ly</hw> <pr>(-<icr/*l<ycr/)</pr>, <pos>adv.</pos> <def>In a
lengthy manner; at great length or extent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthiness</ent><br/
<hw>Length"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
lengthy; prolixity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthwise</ent><br/
<ent>Lengthways</ent><br/
<mhw>{ <hw>Length"ways`</hw> <pr>(-w<amac/z`)</pr>,
<hw>Length"wise`</hw> <pr>(-w<imac/z`)</pr>, }</mhw> <pos>adv.</pos>
<def>In the direction of the length; running or extending in the
direction of the length of a thing; in a longitudinal direction.
Contrasted with <ant>crosswise</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lengthy</ent><br/
<hw>Length"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Lengthier</adjf>
<pr>(-<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Lengthiest</adjf>.]</amorph> <def>Having length; rather long or
too long; prolix; not brief; -- said chiefly of discourses, writings,
and the like.</def> <ldquo/<xex>Lengthy</xex> periods.<rdquo/
<au>Washington.</au> <ldquo/Some <xex>lengthy</xex> additions.<rdquo/
<au>Byron.</au> <ldquo/These would be details too
<xex>lengthy</xex>.<rdquo/ <au>Jefferson.</au> <ldquo/To cut short
<xex>lengthy</xex> explanations.<rdquo/ <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leniency</ent><br/
<ent>Lenience</ent><br/
<mhw>{ <hw>Le"ni*ence</hw> <pr>(l<emac/"n<icr/*<eit/ns <or/
l<emac/n"y<eit/ns; 106)</pr>, <hw>Le"ni*en*cy</hw>
<pr>(l<emac/"n<icr/*<eit/n*s<ycr/ <or/ l<emac/n"y<eit/n*s<ycr/)</pr>,
}</mhw> <pos>n.</pos> <def>The quality or state of being lenient;
lenity; clemency.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenient</ent><br/
<hw>Le"ni*ent</hw> <pr>(l<emac/"n<icr/*<eit/nt <or/
l<emac/n"y<eit/nt)</pr>, <pos>a.</pos> <ety>[L. <ets>leniens</ets>,
<ets>-entis</ets>, p. pr. of <ets>lenire</ets> to soften, fr.
<ets>lenis</ets> soft, mild. Cf. <er>Lithe</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Relaxing; emollient; softening; assuasive; --
sometimes followed by <xex>of</xex>.</def> <ldquo/<xex>Lenient</xex> of
grief.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O<?/<?/ relax the fibers, are <qex>lenient</qex>, balsamic.</q>
<rj><qau>Arbuthnot.</qau></rj> <-- illegible: oils? --><br/
[<source>1913 Webster</source>]</p>

<p><q>Time, that on all things lays his <qex>lenient</qex> hand.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mild; clement; merciful; not rigorous or severe;
<as>as, a <ex>lenient</ex> disposition; a <ex>lenient</ex> judge or
sentence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenient</ent><br/
<hw>Le"ni*ent</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A lenitive; an
emollient.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leniently</ent><br/
<hw>Le"ni*ent*ly</hw>, <pos>adv.</pos> <def>In a lenient
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenify</ent><br/
<hw>Len"i*fy</hw> <pr>(l<ecr/n"<icr/*f<imac/)</pr>, <pos>v. t.</pos>
<ety>[L. <ets>lenis</ets> soft, mild + <ets>-fy</ets>: cf. F.
<ets>l<eacute/nifier</ets>.]</ety> <def>To assuage; to soften; to
mitigate; to alleviate.</def> <rj><au>Bacon.</au>
<au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leniment</ent><br/
<hw>Len"i*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <ety>[L.
<ets>lenimentum</ets>: cf. OF. <ets>leniment</ets>. See
<er>Lenient</er>.]</ety> <def>An assuasive.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leningrad</ent><br/
<hw>Leningrad</hw> <pos>prop. n.</pos> <def>A city in the European part
of Soviet Russia; the former capital of Russia. The name was formerly
<altname>St. Petersburg</altname> and <altname>Petrograd</altname>, and
was changed back to <altname>Saint Petersburg</altname> (<tran>Sankt
Peterburg</tran> in Russian) in 1992.</def><br/
<syn><b>Syn. --</b> St. Petersburg, Peterburg, Petrograd, Saint
Petersburg.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Leninism</ent><br/
<hw>Leninism</hw> <pos>prop. n.</pos> <def>a form of communism based on
the writings of Marx and Lenin; called also
<altname>Marxism-Leninism</altname>.</def><br/
<syn><b>Syn. --</b> bolshevism, collectivism, Marxism-Leninism, Marxism,
Sovietism, sovietism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lenitive</ent><br/
<hw>Len"i*tive</hw> <pr>(-t<icr/v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>l<eacute/nitif</ets>. See <er>Lenient</er>.]</ety> <def>Having the
quality of softening or mitigating, as pain or acrimony; assuasive;
emollient.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenitive</ent><br/
<hw>Len"i*tive</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>l<eacute/nitif</ets>.]</ety> <sn>1.</sn> <fld>(Med.)</fld>
<sd>(a)</sd> <def>A medicine or application that has the quality of
easing pain or protecting from the action of irritants.</def>
<sd>(b)</sd> <def>A mild purgative; a laxative.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which softens or mitigates; that which tends to
allay passion, excitement, or pain; a palliative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is one sweet <qex>lenitive</qex> at least for evils, which
Nature holds out; so I took it kindly at her hands, and fell asleep.</q>
<rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenitiveness</ent><br/
<hw>Len"i*tive*ness</hw>, <pos>n.</pos> <def>The quality of being
lenitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenitude</ent><br/
<hw>Len"i*tude</hw> <pr>(-t<umac/d)</pr>, <pos>n.</pos> <ety>[L.
<ets>lenitudo</ets>.]</ety> <def>The quality or habit of being lenient;
lenity.</def> <mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenity</ent><br/
<hw>Len"i*ty</hw> <pr>(-t<ycr/)</pr>, <pos>n.</pos> <ety>[L.
<ets>lenitas</ets>, fr. <ets>lenis</ets> soft, mild: cf. OF.
<ets>lenit<eacute/</ets>. See <er>Lenient</er>.]</ety> <def>The state or
quality of being lenient; mildness of temper or disposition; gentleness
of treatment; softness; tenderness; clemency; -- opposed to
<ant>severity</ant> and <ant>rigor</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His exceeding <qex>lenity</qex> disposes us to be somewhat too
severe.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Gentleness; kindness; tenderness; softness;
humanity; clemency; mercy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenni-Lenape</ent><br/
<hw>Len`ni-Len*a"pe</hw> <pr>(l<ecr/n`n<icr/-l<ecr/n*<aum/"p<asl/)</pr>,
<pos>n. pl.</pos> <fld>(Ethnol.)</fld> <def>A general name for a group
of Algonquin tribes which formerly occupied the coast region of North
America from Connecticut to Virginia. They included the Mohicans,
Delawares, Shawnees, and several other tribes.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 843 pr=VMG --></p>

<p><ent>Leno</ent><br/
<hw>Le"no</hw> <pr>(l<emac/"n<osl/)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>leno</ets> weak, flexible.]</ety> <def>A light open cotton fabric
used for window curtains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenocinant</ent><br/
<hw>Le*noc"i*nant</hw> <pr>(l<esl/*n<ocr/s"<icr/*n<ait/nt)</pr>,
<pos>a.</pos> <ety>[L. <ets>lenocinans</ets>, p. pr. of
<ets>lenocinari</ets> to pander, cajole; akin to <ets>leno</ets>
pimp.]</ety> <def>Given to lewdness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lens</ent><br/
<hw>Lens</hw> <pr>(l<ecr/nz)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lenses</plw> <pr>(-<ecr/z)</pr>.</plu> <ety>[L. <ets>lens</ets> a
lentil. So named from the resemblance in shape of a double convex lens
to the seed of a lentil. Cf. <er>Lentil</er>.]</ety> <fld>(Opt.)</fld>
<def>A piece of glass, or other transparent substance, ground with two
opposite regular surfaces, either both curved, or one curved and the
other plane, and commonly used, either singly or combined, in optical
instruments, for changing the direction of rays of light, and thus
magnifying objects, or otherwise modifying vision. In practice, the
curved surfaces are usually spherical, though rarely cylindrical, or of
some other figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><figure><figtitle>Lenses</figtitle></figure><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Of spherical lenses, there are six varieties, as shown
in section in the figures herewith given: viz., <figref>a</figref>
plano-concave; <figref>b</figref> double-concave; <figref>c</figref>
plano-convex; <figref>d</figref> double-convex; <figref>e</figref>
converging concavo-convex, or converging meniscus; <figref>f</figref>
diverging concavo-convex, or diverging meniscus.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Crossed lens</b></col> <fld>(Opt.)</fld>, <cd>a
double-convex lens with one radius equal to six times the other.</cd> --
<col><b>Crystalline lens</b></col>. <fld>(Anat.)</fld> <cd>See
<er>Eye</er>.</cd> -- <col><b>Fresnel lens</b></col> <fld>(Opt.)</fld>,
<cd>a compound lens formed by placing around a central convex lens rings
of glass so curved as to have the same focus; used, especially in
lighthouses, for concentrating light in a particular direction; -- so
called from the inventor.</cd> -- <mcol><col><b>Multiplying
lens</b></col> <it>or</it> <col><b>Multiplying glass</b></col></mcol>
<fld>(Opt.)</fld>, <cd>a lens one side of which is plane and the other
convex, but made up of a number of plane faces inclined to one another,
each of which presents a separate image of the object viewed through it,
so that the object is, as it were, multiplied.</cd> -- <col><b>Polyzonal
lens</b></col>. <cd>See <er>Polyzonal</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lent</ent><br/
<hw>Lent</hw> <pr>(l<ecr/nt)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Lend</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lent</ent><br/
<hw>Lent</hw>, <pos>n.</pos> <ety>[OE. <ets>lente</ets>,
<ets>lenten</ets>, <ets>leynte</ets>, AS. <ets>lengten</ets>,
<ets>lencten</ets>, spring, lent, akin to D. <ets>lente</ets>, OHG.
<ets>lenzin</ets>, <ets>langiz</ets>, G. <ets>lenz</ets>, and perh. fr.
AS. <ets>lang</ets> long, E. <ets>long</ets>, because at this season of
the year the days lengthen.]</ety> <fld>(Eccl.)</fld> <def>A fast of
forty days, beginning with Ash Wednesday and continuing till Easter,
observed by some Christian churches as commemorative of the fast of our
Savior.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lent lily</b></col> <fld>(Bot.)</fld>, <cd>the daffodil;
-- so named from its blossoming in spring.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lent</ent><br/
<hw>Lent</hw>, <pos>a.</pos> <ety>[L. <ets>lentus</ets>; akin to
<ets>lenis</ets> soft, mild: cf. F. <ets>lent</ets>. See
<er>Lenient</er>.]</ety> <sn>1.</sn> <def>Slow; mild; gentle; <as>as,
<ex>lenter</ex> heats</as>.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>See <er>Lento</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentamente</ent><br/
\'d8<hw>Len`ta*men"te</hw> <pr>(l<asl/n`t<adot/*m<asl/n"t<asl/; E.
l<ecr/n`t<adot/*m<ecr/n"t<esl/)</pr>, <pos>adv.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Slowly; in slow time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentando</ent><br/
\'d8<hw>Len*tan"do</hw> <pr>(l<asl/n*t<aum/n"d<osl/; E.
l<ecr/n*t<acr/n"d<osl/)</pr>, <pos>a.</pos> <ety>[It., p. pr. of
<ets>lentare</ets> to make slow. See <er>Lent</er>, <pos>a.</pos>]</ety>
<fld>(Mus.)</fld> <def>Slackening; retarding. Same as
<er>Rallentando</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenten</ent><br/
<hw>Lent"en</hw> <pr>(l<ecr/nt"'n)</pr>, <pos>n.</pos> <def>Lent.</def>
<mark>[Obs.]</mark> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenten</ent><br/
<hw>Lent"en</hw>, <pos>a.</pos> <ety>[From OE. <ets>lenten</ets> lent.
See <er>Lent</er>, <pos>n.</pos> ]</ety> <sn>1.</sn> <def>Of or
pertaining to the fast called Lent; used in, or suitable to, Lent;
<as>as, the <ex>Lenten</ex> season</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She quenched her fury at the flood,<br/
And with a <qex>Lenten</qex> salad cooled her blood.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Spare; meager; plain; somber; unostentatious; not
abundant or showy.</def> <ldquo/<xex>Lenten</xex> entertainment.<rdquo/
<ldquo/ <xex>Lenten</xex> answer.<rdquo/ <au>Shak.</au> <ldquo/
<xex>Lenten</xex> suit.<rdquo/ <au>Beau. & Fl.</au><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lenten color</b></col>, <cd>black or violet.</cd>
<rj><au>F. G. Lee.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lententide</ent><br/
<hw>Lent"en*tide`</hw> <pr>(-t<imac/d`)</pr>, <pos>n.</pos> <def>The
season of Lenten or Lent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenticel</ent><br/
<hw>Len"ti*cel</hw> <pr>(l<ecr/n"t<icr/*s<ecr/l)</pr>, <pos>n.</pos>
<ety>[F. <ets>lenticelle</ets>, dim. fr. L. <ets>lens</ets>,
<ets>lentis</ets>, a lentil. Cf. <er>Lentil</er>.]</ety>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>One of the small, oval, rounded
spots upon the stem or branch of a plant, from which the underlying
tissues may protrude or roots may issue, either in the air, or more
commonly when the stem or branch is covered with water or earth.</def>
<sd>(b)</sd> <def>A small, lens-shaped gland on the under side of some
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenticellate</ent><br/
<hw>Len`ti*cel"late</hw> <pr>(l<ecr/n`t<icr/*s<ecr/l"l<asl/t)</pr>,
<pos>a.</pos> <fld>(Bot.)</fld> <def>Producing lenticels; dotted with
lenticels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenticelle</ent><br/
<hw>Len`ti*celle"</hw> <pr>(l<ecr/n`t<icr/*s<ecr/l")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <fld>(Bot.)</fld> <def>Lenticel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenticula</ent><br/
\'d8<hw>Len*tic"u*la</hw> <pr>(l<ecr/n*t<icr/k"<usl/*l<adot/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> E. <plw>Lenticulas</plw>
<pr>(-l<adot/z)</pr>, L. <plw>Lenticul<ae/</plw>
<pr>(-l<emac/)</pr>.</plu> <ety>[L. See <er>Lenticel</er>.]</ety>
<sn>1.</sn> <fld>(Med.)</fld> <def>A kind of eruption upon the skin;
lentigo; freckle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Opt.)</fld> <def>A lens of small size.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A lenticel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenticular</ent><br/
<hw>Len*tic"u*lar</hw> <pr>(-l<etil/r)</pr>, <pos>a.</pos> <ety>[L.
<ets>lenticularis</ets>: cf. F. <ets>lenticulaire</ets>. See
<er>Lenticel</er>.]</ety> <def>Resembling a lentil in size or form;
having the form of a double-convex lens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lenticularly</ent><br/
<hw>Len*tic"u*lar*ly</hw>, <pos>adv.</pos> <def>In the manner of a lens;
with a curve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentiform</ent><br/
<hw>Len"ti*form</hw> <pr>(l<ecr/n"t<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[L. <ets>lens</ets>, <ets>lentis</ets>, lentil + <ets>-form</ets>:
cf. F. <ets>lentiforme</ets>.]</ety> <def>Lenticular.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentiginose</ent><br/
<hw>Len*tig"i*nose`</hw> <pr>(l<ecr/n*t<icr/j"<icr/*n<omac/s`)</pr>,
<pos>a.</pos> <ety>[See <er>Lentiginous</er>.]</ety> <fld>(Bot.)</fld>
<def>Bearing numerous dots resembling freckles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentiginous</ent><br/
<hw>Len*tig"i*nous</hw> <pr>(-n<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>lentiginosus</ets>. See <er>Lentigo</er>.]</ety> <def>Of or
pertaining to lentigo; freckly; scurfy; furfuraceous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentigo</ent><br/
\'d8<hw>Len*ti"go</hw> <pr>(l<ecr/n*t<imac/"g<osl/)</pr>, <pos>n.</pos>
<ety>[L., fr. <ets>lens</ets>, <ets>lentis</ets>, lentil.]</ety>
<fld>(Med.)</fld> <def>A freckly eruption on the skin;
freckles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentil</ent><br/
<hw>Len"til</hw> <pr>(l<ecr/n"t<icr/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>lentille</ets>, fr. L. <ets>lenticula</ets>, dim. of
<ets>lens</ets>, <ets>lentis</ets>, lentil. Cf. <er>Lens</er>.]</ety>
<fld>(Bot.)</fld> <def>A leguminous plant of the genus <gen>Ervum</gen>
(<spn>Ervum Lens</spn>), of small size, common in the fields in Europe.
Also, its seed, which is used for food on the continent.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>lentil</xex> of the Scriptures probably
included several other vetchlike plants.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lentil shell</b></col> <fld>(Zool.)</fld>, <cd>a small
bivalve shell of the genus <gen>Ervillia</gen>, family
<fam>Tellinid<ae/</fam>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentinus</ent><br/
<hw>Lentinus</hw> <pos>n.</pos> <def>The most important genus of
mushrooms in the Far East.</def><br/
<syn><b>Syn. --</b> genus <gen>Lentinus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lentisk</ent><br/
<ent>Lentiscus</ent><br/
<mhw>{ <hw>Len*tis"cus</hw> <pr>(l<ecr/n*t<icr/s"k<ucr/s)</pr>,
<hw>Len"tisk</hw> <pr>(l<ecr/n"t<icr/sk)</pr>, }</mhw> <pos>n.</pos>
<ety>[L. <ets>lentiscus</ets>, <ets>lentiscum</ets>: cf. F.
<ets>lentisque</ets>.]</ety> <fld>(Bot.)</fld> <def>A tree; the mastic.
See <er>Mastic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lentissimo</ent><br/
<hw>lentissimo</hw> <pos>a. & adv.</pos> <fld>(Music)</fld> <def>very
slow; very slowly; -- of music tempo.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lentitude</ent><br/
<hw>Len"ti*tude</hw> <pr>(l<ecr/n"t<icr/*t<umac/d)</pr>, <pos>n.</pos>
<ety>[L. <ets>lentitudo</ets>, fr. <ets>lentus</ets> slow: cf. OF.
<ets>lentitude</ets>. See <er>Lent</er>, <pos>a.</pos>]</ety>
<def>Slowness; sluggishness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lento</ent><br/
\'d8<hw>Len"to</hw> <pr>(l<asl/n"t<osl/; E. l<ecr/n"t<osl/)</pr>,
<pos>a. & adv.</pos> <ety>[It.]</ety> <fld>(Mus.)</fld> <def>Slow; in
slow time; slowly; -- rarely written <altname>lente</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentoid</ent><br/
<hw>Len"toid</hw> <pr>(l<ecr/n"toid)</pr>, <pos>a.</pos>
<ety>[<ets>Lens</ets> + <ets>-oid</ets>.]</ety> <def>Having the form of
a lens; lens-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentor</ent><br/
\'d8<hw>Len"tor</hw> <pr>(-t<ocr/r)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>lentus</ets> pliant, tough, slow. See <er>Lent</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>Tenacity; viscidity, as of
fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Slowness; delay; sluggishness.</def>
<au>Arbuthnot.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lentous</ent><br/
<hw>Len"tous</hw> <pr>(-t<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>lentus</ets>. See <er>Lentor</er>.]</ety> <def>Viscid; viscous;
tenacious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Spawn of a <qex>lentous</qex> and transparent body.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>L'envoy</ent><br/
<ent>L'envoi</ent><br/
<mhw>\'d8<hw>L'en`voi"</hw>, <it>or</it> <hw>L'en`voy"</hw>
<pr>(l<aum/n`vw<aum/")</pr></mhw>, <pos>n.</pos> <ety>[F. <ets>le</ets>
the + <ets>envoi</ets> a sending. See <er>Envoy</er>.]</ety> <sn>1.</sn>
<def>One or more detached verses at the end of a literary composition,
serving to convey the moral, or to address the poem to a particular
person; -- orig. employed in old French poetry.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A conclusion; a result.</def>
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leo</ent><br/
\'d8<hw>Le"o</hw> <pr>(l<emac/"<omac/)</pr>, <pos>n.</pos> <ety>[L. See
<er>Lion</er>.]</ety> <fld>(Astron.)</fld> <sn>1.</sn> <def>The Lion,
the fifth sign of the zodiac, marked thus [<Leo/] in almanacs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A northern constellation east of Cancer, containing
the bright star Regulus at the end of the handle of the
Sickle.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leo Minor</b></col>, <cd>a small constellation between
Leo and the Great Bear.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leod</ent><br/
<hw>Le"od</hw> <pr>(l<emac/"<ocr/d)</pr>, <pos>n.</pos> <ety>[AS.
<ets>le<oacute/d</ets> people, nation, man, chief; akin to OS.
<ets>liud</ets>, OHG. <ets>liut</ets>, pl. <ets>liuti</ets>, G.
<ets>leute</ets>, pl., fr. AS. <ets>le<oacute/dan</ets> to grow, akin to
Goth. <ets>liudan</ets>, OS. <ets>liodan</ets>, <ets>OHG</ets>.
<ets>liotan</ets> to grow; cf. Skr. <ets>ruh</ets>. <root/123.]</ety>
<def>People; a nation; a man.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman. Bp. Gibson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leon</ent><br/
<hw>Le"on</hw> <pr>(l<emac/"<ocr/n)</pr>, <pos>n.</pos> <def>A
lion.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leonced</ent><br/
<hw>Le"onced</hw> <pr>(l<emac/"<ocr/nst)</pr>, <pos>a.</pos>
<fld>(Her.)</fld> <def>See <er>Lionced</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leonese</ent><br/
<hw>Le`o*nese"</hw> <pr>(l<emac/`<osl/*n<emac/z" <it>or</it>
-n<emac/s")</pr>, <pos>a.</pos> <def>Of or pertaining to Leon, in
Spain.</def> -- <def2><pos>n. sing. & pl.</pos> <def>A native or natives
of Leon.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leonid</ent><br/
<hw>Le"o*nid</hw> <pr>(l<emac/"<osl/*n<icr/d)</pr>, <pos>n.</pos>
<ety>[From <er>Leo</er>: cf. F. <ets>l<eacute/onides</ets>, pl.]</ety>
<fld>(Astron.)</fld> <def>One of the shooting stars which constitute the
star shower that recurs near the fourteenth of November at intervals of
about thirty-three years; -- so called because these shooting stars
appear on the heavens to move in lines directed from the constellation
Leo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leonine</ent><br/
<hw>Le"o*nine</hw> <pr>(l<emac/"<osl/*n<imac/n)</pr>, <pos>a.</pos>
<ety>[L. <ets>leoninus</ets>, fr. <ets>leo</ets>, <ets>leonis</ets>,
lion: cf. F. <ets>l<eacute/onin</ets>. See <er>Lion</er>.]</ety>
<def>Pertaining to, or characteristic of, the lion; <as>as, a
<ex>leonine</ex> look; <ex>leonine</ex> rapacity.</as></def> --
<wordforms><wf>Le"o*nine*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leonine verse</b></col>, <cd>a kind of verse, in which
the end of the line rhymes with the middle; -- so named from
<etsep>Leo</etsep>, or <etsep>Leoninus</etsep>, a Benedictine and canon
of Paris in the twelfth century, who wrote largely in this measure,
though he was not the inventor. The following line is an
example:</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Gloria <xex>factorum</xex> temere conceditur
<xex>horum</xex>.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leonotis</ent><br/
<hw>Leonotis</hw> <pos>n.</pos> <def>A small genus of tropical herbs and
subshrubs of S Africa.</def><br/
<syn><b>Syn. --</b> genus <gen>Leonotis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leontocebus</ent><br/
<hw>Leontocebus</hw> <pos>prop. n.</pos> <def>A genus of marmosets
including some of the tamarins. Called also
<altname><gen>Leontopithecus</gen></altname> and
<altname><gen>Leontideus</gen></altname>.</def><br/
<syn><b>Syn. --</b> genus <gen>Leontocebus</gen>, genus
<gen>Leontideus</gen>, genus <gen>Leontopithecus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leontopodium</ent><br/
<hw>Leontopodium</hw> <pos>n.</pos> <def>A genus of plants including the
edelweiss (<spn>Leontopodium alpinum</spn>).</def><br/
<syn><b>Syn. --</b> genus <gen>Leontopodium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leontodon</ent><br/
<hw>Le*on"to*don</hw> <pr>(l<esl/*<ocr/n"t<osl/*d<ocr/n)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>le`wn</grk>, <grk>le`ontos</grk>, lion +
<grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, tooth. Cf.
<er>Lion's-tooth</er>, <er>Dandelion</er>.]</ety> <fld>(Bot.)</fld>
<def>A genus of liguliflorous composite plants, including the fall
dandelion (<spn>Leontodon autumnale</spn>), and formerly the true
dandelion; -- called also <altname>lion's tooth</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leonurus</ent><br/
<hw>Leonurus</hw> <pos>n.</pos> <def>A genus of stout Old World herbs
having cut-lobed leaves and flowers in whorls.</def><br/
<syn><b>Syn. --</b> genus <gen>Leonurus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leopard</ent><br/
<hw>Leop"ard</hw> <pr>(l<ecr/p"<etil/rd)</pr>, <pos>n.</pos> <ety>[OE.
<ets>leopart</ets>, <ets>leparde</ets>, <ets>lebarde</ets>,
<ets>libbard</ets>, OF. <ets>leopard</ets>, <ets>liepart</ets>, F.
<ets>l<eacute/opard</ets>, L. <ets>leopardus</ets>, fr. Gr.
<grk>leo`pardos</grk>; <grk>le`wn</grk> lion + <grk>pa`rdos</grk> pard.
See <er>Lion</er>, and <er>Pard</er>.]</ety> <fld>(Zool.)</fld> <def>A
large, savage, carnivorous mammal (<spn>Felis leopardus</spn>). It is of
a yellow or fawn color, with rings or roselike clusters of black spots
along the back and sides. It is found in Southern Asia and Africa. By
some the panther (<spn>Felis pardus</spn>) is regarded as a variety of
leopard.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hunting leopard</b></col>. <cd>See <er>Cheetah</er>.</cd>
--<col><b>Leopard cat</b></col> <fld>(Zool.)</fld> <cd>any one of
several species or varieties of small, spotted cats found in Africa,
Southern Asia, and the East Indies; esp., <spn>Felis
Bengalensis</spn>.</cd> -- <col><b>Leopard marmot</b></col>. <cd>See
<er>Gopher</er>, 2.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>leopardbane</ent><br/
<hw>leop"ard*bane</hw> <pr>(l<ecr/p"<etil/rd*b<amac/n`)</pr>,
<pos>n.</pos> <def>Any of several herbs of the genus
<gen>Doronicum</gen> (as <spn>Doronicum acaule</spn> syn. <spn>Arnica
acaulis</spn>) having alternate often clasping stem leaves cultivated
for their long stalks of yellow flower heads. See <er>leopard's
bane</er>.</def><br/
<syn><b>Syn. --</b> leopard's-bane, leopard's bane.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><cs><col><b>false" leop`ard*bane</b></col> <pr>(f<add/ls"
l<ecr/p`<etil/rd*b<amac/n`)</pr>, <pos>n.</pos> <cd>Any of several herbs
of the genus <gen>Doronicum</gen>, such as the <stype>great false
leopardbane</stype> (<spn>Doronicum pardalianches</spn>) of North
America and the <stype>oriental false leopardbane</stype>
(<spn>Doronicum orientale</spn> syn. <spn>Doronicum
caucasicum</spn>).</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>leopardess</ent><br/
<hw>leop"ard*ess</hw> <pr>(l<ecr/p"<etil/rd*<ecr/s)</pr>, <pos>n.</pos>
<def>A female leopard.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leopard's bane</ent><br/
<hw>leop"ard's bane`</hw> <pr>(l<ecr/p"<etil/rdz b<amac/n`)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>A name of several harmless plants,
as <spn>Arnica montana</spn> (<spn>Arnica acaulis</spn> syn.
<spn>Doronicum acaule</spn>), <spn>Senecio Doronicum</spn>, and
<spn>Paris quadrifolia</spn>.</def><br/
<syn><b>Syn. --</b> leopardbane, leopard's-bane.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>leopardwood</ent><br/
<hw>leop"ard*wood`</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<er>Letterwood</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lep</ent><br/
<hw>lep</hw> <pr>(l<ecr/p)</pr>, <mark>obs.</mark> <pos>strong
imp.</pos> <mord>of <er>Leap</er></mord>. <def>Leaped.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepadidae</ent><br/
<hw>Lepadidae</hw> <pos>prop. n.</pos> <def>A natural family of
crustaceans including the goose barnacles.</def><br/
<syn><b>Syn. --</b> family <fam>Lepadidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lepadite</ent><br/
<hw>Lep"a*dite</hw> <pr>(l<ecr/p"<adot/*d<imac/t)</pr>, <pos>n.</pos>
<ety>[L. <ets>lepas</ets>, <ets>lepadis</ets>, limpet, Gr.
<grk>lepa`s</grk>, <grk>lepa`dos</grk>.]</ety> <fld>(Zool.)</fld>
<def>Same as <er>Lepadoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepadoid</ent><br/
<hw>Lep"a*doid</hw> <pr>(l<ecr/p"<adot/*doid)</pr>, <pos>n.</pos>
<ety>[<ets>Lepas</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>A stalked barnacle of the genus Lepas, or family
<fam>Lepadid<ae/</fam>; a goose barnacle. Also used
adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepal</ent><br/
<hw>Lep"al</hw> <pr>(l<ecr/p"<ait/l)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lepi`s</grk> a scale: cf. F. <ets>l<eacute/pale</ets>.]</ety>
<fld>(Bot.)</fld> <def>A sterile transformed stamen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepanto</ent><br/
<hw>Lepanto</hw> <pos>n.</pos> <def>The name of a battle in which
Turkish seapower was destroyed by the Christian League in
1571.</def><br/
<syn><b>Syn. --</b> battle of Lepanto.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lepas</ent><br/
\'d8<hw>Le"pas</hw> <pr>(l<emac/"p<acr/s)</pr>, <pos>n.</pos> <ety>[L.,
a limpet, fr. Gr. <grk>lepa`s</grk>.]</ety> <fld>(Zool.)</fld> <def>Any
one of various species of <gen>Lepas</gen>, a genus of pedunculated
barnacles found attached to floating timber, bottoms of ships, Gulf
weed, etc.; -- called also <altname>goose barnacle</altname>. See
<er>Barnacle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leper</ent><br/
<hw>Lep"er</hw> <pr>(l<ecr/p"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lepre</ets> leprosy, F. <ets>l<egrave/pre</ets>, L.
<ets>leprae</ets>, <ets>lepra</ets>, fr. Gr. <grk>le`pra</grk>, fr.
<grk>lepro`s</grk> scaly, fr. <grk>le`pos</grk> scale,
<grk>le`pein</grk> to peel.]</ety> <def>A person affected with
leprosy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepered</ent><br/
<hw>Lep"ered</hw> <pr>(-<etil/rd)</pr>, <pos>a.</pos> <def>Affected or
tainted with leprosy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leperize</ent><br/
<hw>Lep"er*ize</hw> <pr>(l<ecr/p"<etil/r*<imac/z)</pr>, <pos>v. t.</pos>
<def>To affect with leprosy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leperous</ent><br/
<hw>Lep"er*ous</hw> <pr>(-<etil/r*<ucr/s)</pr>, <pos>a.</pos>
<def>Leprous; infectious; corrupting; poisonous.</def> <ldquo/The
<xex>leperous</xex> distillment.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepid</ent><br/
<hw>Lep"id</hw> <pr>(-<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>lepidus</ets>.]</ety> <def>Pleasant; jocose.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The joyous and <qex>lepid</qex> consul.</q> <rj><qau>Sydney
Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidine</ent><br/
<hw>Lep"i*dine</hw> <pr>(l<ecr/p"<icr/*d<icr/n <it>or</it>
*d<emac/n)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>An organic base,
<chform>C9H6.N.CH3</chform>, metameric with quinaldine, and obtained by
the distillation of cinchonine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidodendrales</ent><br/
<hw>Lepidodendrales</hw> <pos>n.</pos> <def>An order of fossil
arborescent plants arising during the Lower Devonian and conspicuous
throughout the Carboniferous.</def><br/
<syn><b>Syn. --</b> order <ord>Lepidodendrales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lepidodendrid</ent><br/
<hw>Lep`i*do*den"drid</hw>
<pr>(l<ecr/p`<icr/*d<osl/*d<ecr/n"dr<icr/d)</pr>, <pos>n.</pos>
<fld>(Paleon.)</fld> <def>One of an extinct family of trees allied to
the modern club mosses, and including <gen>Lepidodendron</gen> and its
allies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidodendroid</ent><br/
<hw>Lep`i*do*den"droid</hw> <pr>(-droid)</pr>, <pos>a.</pos>
<fld>(Paleon.)</fld> <def>Allied to, or resembling, Lepidodendron.</def>
-- <def2><pos>n.</pos> <def>A lepidodendrid.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidodendron</ent><br/
\'d8<hw>Lep`i*do*den"dron</hw> <pr>(-dr<ocr/n)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>lepi`s</grk> <grk>-i`dos</grk>, a scale +
<grk>de`ndron</grk> tree.]</ety> <fld>(Paleon.)</fld> <def>A genus of
fossil trees of the Devonian and Carboniferous ages, having the exterior
marked with scars, mostly in quincunx order, produced by the separation
of the leafstalks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidoganoid</ent><br/
<hw>Lep`i*do*ga"noid</hw> <pr>(l<ecr/p`<icr/*d<osl/*g<amac/"noid
<it>or</it> -g<acr/n"oid)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lepi`s</grk> <grk>-i`dos</grk>, a scale + E.
<ets>ganoid</ets>.]</ety> <fld>(Zool.)</fld> <def>Any one of a division
(<ord>Lepidoganoidei</ord>) of ganoid fishes, including those that have
scales forming a coat of mail. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidolite</ent><br/
<hw>Le*pid"o*lite</hw> <pr>(l<esl/*p<icr/d"<osl/*l<imac/t; 277)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>lepi`s</grk> <grk>-i`dos</grk>, a scale +
<ets>-lite</ets>: cf. F. <ets>l<eacute/pidolithe</ets>.]</ety>
<fld>(Min.)</fld> <def>A species of mica, of a lilac or rose-violet
color, containing lithia. It usually occurs in masses consisting of
small scales. See <er>Mica</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidomelane</ent><br/
<hw>Lep`i*dom"e*lane</hw>
<pr>(l<ecr/p`<icr/*d<ocr/m"<esl/*l<amac/n)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lepi`s</grk> <grk>-i`dos</grk>, a scale + <grk>me`las</grk>,
<grk>me`laina</grk>, black.]</ety> <fld>(Min.)</fld> <def>An iron-potash
mica, of a raven-black color, usually found in granitic rocks in small
six-sided tables, or as an aggregation of minute opaque scales. See
<er>Mica</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidopter</ent><br/
<hw>Lep`i*dop"ter</hw> <pr>(l<ecr/p`<icr/*d<ocr/p"t<etil/r)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>l<eacute/pidopt<egrave/re</ets>.]</ety>
<fld>(Zool.)</fld> <def>One of the Lepidoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidoptera</ent><br/
\'d8<hw>Lep`i*dop"te*ra</hw> <pr>(-d<ocr/p"t<esl/*r<adot/)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. Gr. <grk>lepi`s</grk> <grk>-i`dos</grk>, a
scale + <grk>ptero`n</grk> a feather, wing.]</ety> <fld>(Zool.)</fld>
<def>An order of insects, which includes the butterflies and moths. They
have broad wings, covered with minute overlapping scales, usually
brightly colored.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They have a tubular proboscis, or haustellum, formed by
the two slender maxill<ae/. The labial palpi are usually large, and the
proboscis, when not in use, can be coiled up spirally between them. The
mandibles are rudimentary. The larv<ae/, called
<stage>caterpillars</stage>, are often brightly colored, and they
commonly feed on leaves. The adults feed chiefly on the honey of
flowers.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidopterous</ent><br/
<ent>Lepidopteral</ent><br/
<mhw>{ <hw>Lep`i*dop"ter*al</hw> <pr>(-t<etil/r*<ait/l)</pr>,
<hw>Lep`i*dop"ter*ous</hw> <pr>(-<ucr/s)</pr>, }</mhw> <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Lepidoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lepidopteran</ent><br/
<hw>lepidopteran</hw> <pos>a.</pos> <def>Same as
<er>lepidopterous</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>lepidopteran</ent><br/
<hw>lepidopteran</hw> <pos>n.</pos> <def>An insect that in the adult
state has four wings more or less covered with tiny scales; a
lepidopterous insect.</def><br/
<syn><b>Syn. --</b> lepidopterous insect, lepidopteron.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lepidopterist</ent><br/
<hw>Lep`i*dop"ter*ist</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One
who studies the Lepidoptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lepidopteron</ent><br/
<hw>lepidopteron</hw> <pos>n.</pos> <def>An insect that in the adult
state has four wings more or less covered with tiny scales.</def><br/
<syn><b>Syn. --</b> lepidopterous insect, lepidopteran.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lepidopterous</ent><br/
<hw>lepidopterous</hw> <pos>a.</pos> <def>See
<er>lepidopteral</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lepidosauria</ent><br/
\'d8<hw>Lep`i*do*sau"ri*a</hw> <pr>(-d<osl/*s<add/"r<icr/*<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>lepi`s</grk>
<grk>-i`dos</grk>, a scale + <grk>say^ros</grk> a lizard.]</ety>
<fld>(Zool.)</fld> <def>A division of reptiles, including the serpents
and lizards; the Plagiotremata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidosiren</ent><br/
<hw>Lep`i*do*si"ren</hw> <pr>(-s<imac/"r<ecr/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>lepi`s</grk> <grk>-i`dos</grk>, a scale +
<grk>seirh`n</grk> a siren.]</ety> <fld>(Zool.)</fld> <def>An eel-shaped
ganoid fish of the order Dipnoi, having both gills and lungs. It
inhabits the rivers of South America. The name is also applied to a
related African species (<spn>Protopterus annectens</spn>). The
lepidosirens grow to a length of from four to six feet. Called also
<altname>doko</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepidoted</ent><br/
<ent>Lepidote</ent><br/
<mhw>{ <hw>Lep"i*dote</hw> <pr>(l<ecr/p"<icr/*d<omac/t)</pr>,
<hw>Lep"i*do`ted</hw> <pr>(-d<omac/`t<ecr/d)</pr>, }</mhw> <pos>a.</pos>
<ety>[Gr. <grk>lepidwto`s</grk> covered with scales, fr.
<grk>lepi`s</grk> <grk>-i`dos</grk>, a scale.]</ety> <fld>(Bot.)</fld>
<def>Having a coat of scurfy scales, as the leaves of the
oleaster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lepiota</ent><br/
<hw>lepiota</hw> <pos>n.</pos> <def>any fungus of the genus
<gen>Lepiota</gen>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lepisma</ent><br/
\'d8<hw>Le*pis"ma</hw> <pr>(l<esl/*p<icr/z"m<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>le`pisma</grk> peel, fr. <grk>lepi`s</grk>
<grk>-i`dos</grk>, a scale.]</ety> <fld>(Zool.)</fld> <def>A genus of
wingless thysanurous insects having an elongated flattened body, covered
with shining scales and terminated by seven unequal bristles. A common
species (<spn>Lepisma saccharina</spn>) is found in houses, and often
injures books and furniture; it feeds on starch and eats sized paper and
starched clothes. Called also <altname>shiner</altname>,
<altname>silverfish</altname>, <altname>silver witch</altname>,
<altname>silver moth</altname>, and <altname>furniture
bug</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lepismoid</ent><br/
<hw>Le*pis"moid</hw> <pr>(-moid)</pr>, <pos>a.</pos>
<ety>[<ets>Lepisma</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Like or pertaining to the Lepisma.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepomis</ent><br/
<hw>Lepomis</hw> <pos>n.</pos> <def>A genus of freshwater sunfishes,
inclding some of the breams.</def><br/
<syn><b>Syn. --</b> genus <gen>Lepomis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leporid</ent><br/
<hw>leporid</hw> <pos>n.</pos> <def>A mammal of the family
<fam>Leporidae</fam>, including the rabbits and hares.</def><br/
<syn><b>Syn. --</b> leporid mammal.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leporidae</ent><br/
<hw>Leporidae</hw> <pos>n.</pos> <def>A natural family of mammals
comprising the hares and rabbits.</def><br/
<syn><b>Syn. --</b> family <fam>Leporidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>leporide</ent><br/
<hw>leporide</hw> <pos>n.</pos> <sn>1.</sn> <def>red breed of domestic
rabbits, also called <altname>Belgian hare</altname>.</def><br/
<syn><b>Syn. --</b> Belgian hare.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leporine</ent><br/
<hw>Lep"o*rine</hw> <pr>(l<ecr/p"<osl/*r<imac/n <it>or</it>
-r<icr/n)</pr>, <pos>a.</pos> <ety>[L. <ets>leporinus</ets>, fr.
<ets>lepus</ets>, <ets>leporis</ets>, hare. See <er>Leveret</er>.]</ety>
<fld>(Zool.)</fld> <def>Of or pertaining to a hare; like or
characteristic of, a hare.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leppy</ent><br/
<hw>leppy</hw> <pos>n.</pos> <def>A motherless calf in a range herd of
cattle.</def> <mark>[Western U. S.]</mark> <br/
<syn><b>Syn. --</b> dogie, dogy, dogey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lepra</ent><br/
\'d8<hw>Le"pra</hw> <pr>(l<emac/"pr<adot/)</pr>, <pos>n.</pos> <ety>[L.
See <er>Leper</er>.]</ety> <fld>(Med.)</fld> <def>Leprosy.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <xex>lepra</xex> was formerly given to various
skin diseases, the leprosy of modern authors being <stype>Lepra
Arabum</stype>. See <er>Leprosy</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 844 pr=VMG --></p>

<p><ent>Lepre</ent><br/
<hw>Lep"re</hw> <pr>(l<ecr/p"<etil/r)</pr>, <pos>n.</pos>
<def>Leprosy.</def> <mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>leprechaun</ent><br/
<hw>leprechaun</hw> <pos>n.</pos> <fld>(Irish folklore)</fld> <def>A
small mischevous elf or spirit in Irish folklore; it is often depicted
in literature as a dwarfish bearded old man; -- legend tells that if a
leprechaun is captured, he will reveal the location of his hidden pot of
gold.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Leprose</ent><br/
<hw>Lep"rose`</hw> <pr>(l<ecr/p"r<omac/s`)</pr>, <pos>a.</pos> <ety>[See
<er>Leprous</er>.]</ety> <fld>(Nat. Hist.)</fld> <def>Covered with thin,
scurfy scales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leprosity</ent><br/
<hw>Le*pros"i*ty</hw> <pr>(l<esl/*pr<ocr/s"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The state or quality of being leprous or scaly; also,
a scale.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leprosy</ent><br/
<hw>Lep"ro*sy</hw> <pr>(l<ecr/p"r<osl/*s<ycr/)</pr>, <pos>n.</pos>
<ety>[See <er>Leprous</er>.]</ety> <fld>(Med.)</fld> <def>A cutaneous
disease which first appears as blebs or as reddish, shining, slightly
prominent spots, with spreading edges. These are often followed by an
eruption of dark or yellowish prominent nodules, frequently producing
great deformity. In one variety of the disease, an<ae/sthesia of the
skin is a prominent symptom. In addition there may be wasting of the
muscles, falling out of the hair and nails, and distortion of the hands
and feet with destruction of the bones and joints. It is incurable, and
is probably contagious.</def><-- caused by the bacterium
<spn>Mycobacterium leprae</spn>, curable in most cases by therapy with a
combination of antibiotics, but cases resistant to therapy are
increasing. --><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The disease now called leprosy, also designated as
<xex>Lepra</xex> or <xex>Lepra Arabum</xex>, and <xex>Elephantiasis
Gr<ae/corum</xex>, is not the same as the leprosy of the ancients. The
latter was, indeed, a generic name for many varieties of skin disease
(including our modern leprosy, psoriasis, etc.), some of which, among
the Hebrews, rendered a person ceremonially unclean. A variety of
leprosy of the Hebrews (probably identical with modern leprosy) was
characterized by the presence of smooth, shining, depressed white
patches or scales, the hair on which participated in the whiteness,
while the skin and adjacent flesh became insensible. It was an incurable
disease.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leprous</ent><br/
<hw>Lep"rous</hw> <pr>(-r<umac/s)</pr>, <pos>a.</pos> <ety>[OF.
<ets>leprous</ets>, <ets>lepros</ets>, F. <ets>l<eacute/preux</ets>, fr.
L. <ets>leprosus</ets>, fr. <ets>lepra</ets>, <ets>leprae</ets>,
leprosy. See <er>Leper</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Infected with leprosy; pertaining to or resembling
leprosy.</def> <ldquo/His hand was <xex>leprous</xex> as snow.<rdquo/
<rj><au>Ex. iv. 6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Nat. Hist.)</fld> <def>Leprose.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Lep"rous*ly</wf>, <pos>adv.</pos> --
<wf>Lep"rous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepry</ent><br/
<hw>Lep"ry</hw> <pr>(-r<ycr/)</pr>, <pos>n.</pos> <def>Leprosy.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptiform</ent><br/
<hw>Lep"ti*form</hw> <pr>(-t<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[<ets>Leptus</ets> + <ets>-form</ets>.]</ety> <fld>(Zool.)</fld>
<def>Having a form somewhat like leptus; -- said of active insect larvae
having three pairs of legs. See <er>Larva</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptocardia</ent><br/
\'d8<hw>Lep`to*car"di*a</hw>
<pr>(l<ecr/p`t<osl/*k<aum/r"d<icr/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>lepto`s</grk> small + <grk>kardi`a</grk> the
heart.]</ety> <fld>(Zool.)</fld> <def>The lowest class of Vertebrata,
including only the Amphioxus. The heart is represented only by a simple
pulsating vessel. The blood is colorless; the brain, renal organs, and
limbs are wanting, and the backbone is represented only by a simple,
unsegmented notochord. See <er>Amphioxus</er>.</def> <altsp>[Written
also <asp>Leptocardii</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptocardian</ent><br/
<hw>Lep`to*car"di*an</hw>
<pr>(l<ecr/p`t<osl/*k<aum/r"d<icr/*<ait/n)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the
<er>Leptocardia</er>.</def> -- <def2><pos>n.</pos> <def>One of the
Leptocardia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptocercous</ent><br/
<ent>Leptocercal</ent><br/
<mhw><hw>Lep`to*cer"cal</hw>,
<pr>(l<ecr/p`t<osl/*s<etil/r"k<ait/l)</pr>, <hw>Lep`to*cerc"ous</hw>
<pr>(l<ecr/p`t<osl/*s<etil/rk"<ucr/s)</pr>,</mhw> <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having a long slender tail.</def><br/
[<source>PJC</source>]</p>

<p><ent>Leptodactyl</ent><br/
<hw>Lep`to*dac"tyl</hw> <pr>(l<ecr/p`t<osl/*d<acr/k"t<icr/l)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>lepto`s</grk> small, thin +
<grk>da`ktylos</grk> finger, toe.]</ety> <fld>(Zool.)</fld> <def>A bird
or other animal having slender toes.</def> <altsp>[Written also
<asp>lepodactyle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptodactylidae</ent><br/
<hw>Leptodactylidae</hw> <pos>n.</pos> <ety>[See
<er>leptodactyl</er>.]</ety> <def>A natural family of New World frogs;
in some classifications it is essentially coextensive with the family
<fam>Bufonidae</fam>.</def><br/
<syn><b>Syn. --</b> family <fam>Leptodactylidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leptodactylous</ent><br/
<hw>Lep`to*dac"tyl*ous</hw> <pr>(-<ucr/s)</pr>, <pos>a.</pos>
<def>Having slender toes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptodactylus</ent><br/
<hw>Leptodactylus</hw> <pos>n.</pos> <def>The type genus of the
<fam>Leptodactylidae</fam>; in some classifications it is placed in the
family <fam>Bufonidae</fam>.</def><br/
<syn><b>Syn. --</b> genus Leptodactylus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leptoglossus</ent><br/
<hw>Leptoglossus</hw> <pos>n.</pos> <def>A genus of leaf-footed
bugs.</def><br/
<syn><b>Syn. --</b> genus <gen>Leptoglossus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leptology</ent><br/
<hw>Lep*tol"o*gy</hw> <pr>(l<ecr/p*t<ocr/l"<osl/*j<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>leptologi`a</grk>; <grk>lepto`s</grk>
small, subtile + <grk>lo`gos</grk> discourse.]</ety> <def>A minute and
tedious discourse on trifling things.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptomeningitis</ent><br/
\'d8<hw>Lep`to*men`in*gi"tis</hw>
<pr>(l<ecr/p`t<osl/*m<ecr/n`<icr/n*j<imac/"t<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>lepto`s</grk> small +
<ets>meningitis</ets>.]</ety> <fld>(Med.)</fld> <def>Inflammation of the
<xex>pia mater</xex> or of the arachnoid membrane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lepton</ent><br/
<hw>lepton</hw> <pos>n.</pos> <fld>(Physics)</fld> <def>an elementary
particle that participates in weak interactions but does not participate
in the strong interaction; it has a baryon number of 0. Some known
leptons are the <stype>electron</stype>, the <stype>negative
muon</stype>, the <stype>tau-minus particle</stype>, and the neutrinos
associated with each of these particles.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Leptopteris</ent><br/
<hw>Leptopteris</hw> <pos>n.</pos> <def>A genus including some ferns
sometimes placed in genus <gen>Todea</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Leptopteris</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leptoptilus</ent><br/
<hw>Leptoptilus</hw> <pos>n.</pos> <def>A genus of birds including the
adjutant bird (<spn>Leptoptilus dubius</spn>, also called adjutant
stork) and marabous.</def><br/
<syn><b>Syn. --</b> genus <gen>Leptoptilus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leptorhine</ent><br/
<hw>Lep"to*rhine</hw> <pr>(l<ecr/p"t<osl/*r<imac/n <or/ *r<icr/n)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>lepto`s</grk> small + <grk>"ri`s</grk>,
<grk>"rino`s</grk>, the nose.]</ety> <fld>(Anat.)</fld> <def>Having the
nose narrow; -- said especially of the skull. Opposed to
<contr>platyrhine</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptostraca</ent><br/
\'d8<hw>Lep*tos"tra*ca</hw> <pr>(l<ecr/p*t<ocr/s"tr<adot/*k<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>lepto`s</grk> thin, slender +
<grk>'o`strakon</grk> shell of a testacean.]</ety> <fld>(Zool.)</fld>
<def>An order of Crustacea, including Nebalia and allied
forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptothrix</ent><br/
\'d8<hw>Lep"to*thrix</hw> <pr>(l<ecr/p"t<osl/*thr<icr/ks)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>lepto`s</grk> small +
<grk>qri`x</grk> hair.]</ety> <fld>(Biol.)</fld> <def>A genus of
bacteria, characterized by having their filaments very long, slender,
and indistinctly articulated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptothrix</ent><br/
\'d8<hw>Lep"to*thrix</hw>, <pos>a.</pos> <ety>[See <er>Leptothrix</er>,
<pos>n.</pos> ]</ety> <fld>(Biol.)</fld> <def>Having the form of a
little chain; -- applied to bacteria when, as in multiplication by
fission, they form a chain of filiform individuals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptus</ent><br/
\'d8<hw>Lep"tus</hw> <pr>(l<ecr/p"t<ucr/s)</pr>, <pos>n.</pos>
<ety>[NL., from Gr. <grk>lepto`s</grk> thin, small.]</ety>
<fld>(Zool.)</fld> <def>The six-legged young, or larva, of certain
mites; -- sometimes used as a generic name. See <cref>Harvest
mite</cref>, under <er>Harvest</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leptynite</ent><br/
<hw>Lep"ty*nite</hw> <pr>(l<ecr/p"t<icr/*n<imac/t)</pr>, <pos>n.</pos>
<fld>(Min.)</fld> <def>See <er>Granulite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lepus</ent><br/
<hw>Lepus</hw> <pos>n.</pos> <def>The type genus of the
<fam>Leporidae</fam>, comprising the hares.</def><br/
<syn><b>Syn. --</b> genus <fam>Lepus</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ler</ent><br/
<hw>Ler</hw> <pos>n.</pos> <fld>(Irish mythology)</fld> <def>the sea
personified; father of Manannan; corresponds to the Welsh
Llyr.</def><br/
<syn><b>Syn. --</b> Lir.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lere</ent><br/
<hw>Lere</hw> <pr>(l<emac/r)</pr>, <pos>n.</pos> <ety>[See <er>Lore</er>
knowledge.]</ety> <def>Learning; lesson; lore.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lere</ent><br/
<hw>Lere</hw>, <pos>v. t. & i.</pos> <ety>[OE. <ets>leeren</ets>,
<ets>leren</ets>, AS. <ets>l<aemac/ran</ets>. See <er>Lore</er>,
<er>Learn</er>.]</ety> <def>To learn; to teach.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lere</ent><br/
<hw>Lere</hw>, <pos>a.</pos> <def>Empty.</def> <mark>[Obs.]</mark>
<see>See <er>Leer</er>, <pos>a.</pos></see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lere</ent><br/
<hw>Lere</hw>, <pos>n.</pos> <ety>[AS. <ets>lira</ets> flesh; cf. Icel.
<ets>l<ae/r</ets> thigh.]</ety> <def>Flesh; skin.</def>
<mark>[Obs.]</mark> <ldquo/His white <xex>leer</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lered</ent><br/
<hw>Ler"ed</hw> <pr>(l<emac/r"<ecr/d)</pr>, <pos>a.</pos> <ety>[From
<ets>lere</ets>, <pos>v. t.</pos>]</ety> <def>Learned.</def>
<mark>[Obs.]</mark> <ldquo/ Lewed man or <xex>lered</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lernaea</ent><br/
\'d8<hw>Ler*n<ae/"a</hw> <pr>(l<etil/r*n<emac/"<adot/)</pr>,
<pos>n.</pos> <ety>[NL., fr. L. <ets>Lernaeus</ets> Lern<ae/an, fr.
<ets>Lerna</ets>, Gr. <grk>Le`rnh</grk>, a forest and marsh near Argos,
the mythological abode of the hydra.]</ety> <fld>(Zool.)</fld> <def>A
Linn<ae/an genus of parasitic Entomostraca, -- the same as the family
<fam>Lern<ae/id<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The genus is restricted by modern Zoologists to a
limited number of species similar to <spn>Lern<ae/a branchialis</spn>
found on the gills of the cod.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lernaeacea</ent><br/
\'d8<hw>Ler`n<ae/*a"ce*a</hw>
<pr>(l<etil/r`n<esl/*<amac/"sh<esl/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Lern<ae/a</er>.]</ety> <fld>(Zool.)</fld> <def>A
suborder of copepod Crustacea, including a large number of remarkable
forms, mostly parasitic on fishes. The young, however, are active and
swim freely. See <xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lernean</ent><br/
<hw>Ler*ne"an</hw> <pr>(l<etil/r*n<emac/"<ait/n)</pr>, <pos>n.</pos>
<ety>[See <er>Lern<ae/a</er>.]</ety> <fld>(Zool.)</fld> <def>One of a
family (<fam>Lern<ae/id<ae/</fam>) of parasitic Crustacea found attached
to fishes and other marine animals. Some species penetrate the skin and
flesh with the elongated head, and feed on the viscera. See
<xex>Illust.</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lerot</ent><br/
<ent>lerot</ent><br/
<mhw><hw>lerot</hw>, \'d8<hw>L<eacute/`rot"</hw></mhw>
<pr>(l<asl/`r<osl/")</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>A small rodent (<spn>Eliomys nitela</spn>) of
Europe and Northern Africa, allied to the dormouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Les</ent><br/
<hw>Les</hw> <pr>(l<ecr/s)</pr>, <pos>n.</pos> <def>A leash.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lesbian</ent><br/
<hw>Les"bi*an</hw> <pr>(l<ecr/z"b<icr/*<ait/n)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Of or pertaining to the island anciently called
<etsep>Lesbos</etsep>, now Mitylene, in the Grecian
Archipelago.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Amatory; erotic; -- in allusion to the reputed
sensuality of the Lesbian people and literature; <as>as,
<ex>Lesbian</ex> novels</as>.</def> <mark>[archaic]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>Homosexual; -- applied to female
homosexuals.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lesbian</ent><br/
<hw>Les"bi*an</hw> <pr>(l<ecr/z"b<icr/*<ait/n)</pr>, <pos>n.</pos>
<def>A female homosexual.</def><br/
<syn><b>Syn. --</b> dyke[vulgar, deprecatory].</syn>
[<source>PJC</source>]</p>

<p><ent>Lesbianism</ent><br/
<hw>Les"bi*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Homosexual relations between women.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lesbian love</ent><br/
<hw>Lesbian love</hw>. <def>See <er>Lesbianism</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lese</ent><br/
<hw>Lese</hw> <pr>(l<emac/z)</pr>, <pos>v. t.</pos> <def>To lose.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lese-majesty</ent><br/
<hw>Lese`-maj"es*ty</hw> <pr>(l<emac/z`-m<acr/j"<ecr/s*t<ycr/)</pr>,
<pos>n.</pos> <def>See <er>Leze majesty</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lesion</ent><br/
<hw>Le"sion</hw> <pr>(l<emac/"zh<ucr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>l<eacute/sion</ets>, L. <ets>laesio</ets>, fr. <ets>laedere</ets>,
<ets>laesum</ets>, to hurt, injure.]</ety> <def>A hurt; an injury.</def>
Specifically: <sd>(a)</sd> <fld>(Civil Law)</fld> <def>Loss sustained
from failure to fulfill a bargain or contract.</def> <au>Burrill.</au>
<sd>(b)</sd> <fld>(Med.)</fld> <def>Any morbid change in the exercise of
functions or the texture of organs.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lespedeza</ent><br/
<hw>lespedeza</hw> <pos>n.</pos> <def>Any shrubby or herbaceous plant of
the genus <gen>Lespedeza</gen>, widely used for forage, soil
improvement, and especially hay in the Southern U.S.</def><br/
<syn><b>Syn. --</b> bush clover.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lesquerella</ent><br/
<hw>Lesquerella</hw> <pos>prop. n.</pos> <def>A genus of low-growing
hairy herbs, comprising some of the bladderpods.</def><br/
<syn><b>Syn. --</b> genus <gen>Lesquerella</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>-less</ent><br/
<hw>-less</hw> <pr>(-l<ecr/s)</pr> <pr>suff.</pr> <ety>[AS.
<ets>le<aacute/s</ets> loose, false; akin to OS. <ets>l<omac/s</ets>
loose, false, D. <ets>los</ets> loose, <ets>loos</ets> false, sly, G.
<ets>los</ets> loose, Icel. <ets>lauss</ets> loose, vacant, Goth.
<ets>laus</ets> empty, vain, and also to E. <ets>loose</ets>,
<ets>lose</ets>. <root/127. See <er>Lose</er>, and cf. <er>Loose</er>,
<er>Leasing</er>.]</ety> <def>A privative adjective suffix, denoting
<xex>without</xex>, <xex>destitute of</xex>, <xex>not having</xex>; as
wit<xex>less</xex>, child<xex>less</xex>,
father<xex>less</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Less</ent><br/
<hw>Less</hw> <pr>(l<ecr/s)</pr>, <pos>conj.</pos> <def>Unless.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Less</ent><br/
<hw>Less</hw>, <pos>a.</pos> <ety>[OE. <ets>lesse</ets>, AS.
<ets>l<aemac/ssa</ets>; akin to OFries. <ets>l<emac/ssa</ets>; a compar.
from a lost positive form. Cf. <er>Lesser</er>, <er>Lest</er>,
<er>Least</er>. <ets>Less</ets> has the sense of the comparative degree
of <ets>little</ets>.]</ety> <def>Smaller; not so large or great; not so
much; shorter; inferior; <as>as, a <ex>less</ex> quantity or number; a
horse of <ex>less</ex> size or value; in <ex>less</ex> time than
before.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The substantive which <xex>less</xex> qualifies is often
omitted; as, the purse contained <xex>less</xex> (money) than ten
dollars. See <er>Less</er>, <pos>n.</pos></note><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus in <qex>less</qex> [time] than a hundred years from the
coming of Augustine, all England became Christian.</q> <rj><qau>E. A.
Freeman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Less</ent><br/
<hw>Less</hw>, <pos>adv.</pos> <ety>[AS. <ets>l<aemac/s</ets>. See
<er>Less</er>, <pos>adj.</pos>, and cf. <er>Lest</er>.]</ety> <def>Not
so much; in a smaller or lower degree; <as>as, <ex>less</ex> bright or
loud; <ex>less</ex> beautiful.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Less</ent><br/
<hw>Less</hw>, <pos>n.</pos> <sn>1.</sn> <def>A smaller portion or
quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The children of Israel did so, and gathered, some more, some
<qex>less</qex>.</q> <rj><qau>Ex. xvi. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The inferior, younger, or smaller.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>less</qex> is blessed of the better.</q> <rj><qau>Heb.
vii. 7. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Less</ent><br/
<hw>Less</hw>, <pos>v. t.</pos> <def>To make less; to lessen.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lessee</ent><br/
<hw>Les*see"</hw> <pr>(l<ecr/s*s<emac/")</pr>, <pos>n.</pos> <ety>[F.
<ets>laiss<eacute/</ets>, p. p. of <ets>laisser</ets>. See
<er>Lease</er>, <pos>v. t.</pos>]</ety> <fld>(Law)</fld> <def>The person
to whom a lease is given, or who takes an estate by lease.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lessen</ent><br/
<hw>Less"en</hw> <pr>(l<ecr/s"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lessened</conjf>
<pr>(-'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lessening</conjf>.]</vmorph> <ety>[From <er>Less</er>,
<pos>a.</pos>]</ety> <def>To make less; to reduce; to make smaller, or
fewer; to diminish; to lower; to degrade; <as>as, to <ex>lessen</ex> a
kingdom, or a population; to <ex>lessen</ex> speed, rank,
fortune.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Charity . . . shall <qex>lessen</qex> his punishment.</q>
<rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>St. Paul chose to magnify his office when ill men conspired to
<qex>lessen</qex> it.</q> <rj><qau>Atterbury.</qau></rj></p>

<p><syn><b>Syn.</b> -- To diminish; reduce; abate; decrease; lower;
impair; weaken; degrade.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lessen</ent><br/
<hw>Less"en</hw>, <pos>v. i.</pos> <def>To become less; to shrink; to
contract; to decrease; to be diminished; <as>as, the apparent magnitude
of objects <ex>lessens</ex> as we recede from them; his care, or his
wealth, <ex>lessened</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The objection <qex>lessens</qex> much, and comes to no more than
this: there was one witness of no good reputation.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lessener</ent><br/
<hw>Less"en*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who, or
that which, lessens.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His wife . . . is the <qex>lessener</qex> of his pain, and the
augmenter of his pleasure.</q> <rj><qau>J. Rogers (1839).
</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lessening</ent><br/
<hw>lessening</hw> <pos>adj.</pos> <def>becoming less in dimension or
degree; <as>as, the <ex>lessening</ex> distance between
us</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lessening</ent><br/
<hw>lessening</hw> <pos>n.</pos> <def>a change downward; a decrease; a
reduction.</def><br/
<syn><b>Syn. --</b> decrease, drop-off.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lesser</ent><br/
<hw>Less"er</hw> <pr>(l<ecr/s"<etil/r)</pr>, <pos>a.</pos> <ety>[This
word is formed by adding anew the compar. suffix <ets>-er</ets> (in
which <ets>r</ets> is from an original <ets>s</ets>) to <ets>less</ets>.
See <er>Less</er>, <pos>a.</pos>]</ety> <def>Less; smaller;
inferior.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God made . . . the <qex>lesser</qex> light to rule the night.</q>
<rj><qau>Gen. i. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Lesser</xex> is used for <xex>less</xex>, now the
compar. of <xex>little</xex>, in certain special instances in which its
employment has become established by custom; as, <xex>Lesser</xex> Asia
(i. e., Asia Minor), the <xex>lesser</xex> light, and some others; also
in poetry, for the sake of the meter, and in prose where its use renders
the passage more euphonious.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>The more my prayer, the <qex>lesser</qex> is my grace.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The larger here, and there the <qex>lesser</qex> lambs.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By the same reason may a man, in the state of nature, punish the
<qex>lesser</qex> breaches of the law.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lesser</ent><br/
<hw>Less"er</hw>, <pos>adv.</pos> <def>Less.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lesses</ent><br/
<hw>Les"ses</hw> <pr>(l<ecr/s"s<ecr/z)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>laiss<eacute/es</ets>, from <ets>laisser</ets> to leave. See
<er>Lease</er>, <pos>v. t.</pos>]</ety> <def>The leavings or dung of
beasts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lesson</ent><br/
<hw>Les"son</hw> <pr>(l<ecr/s"s'n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lessoun</ets>, F. <ets>le<cced/on</ets> lesson, reading, fr. L.
<ets>lectio</ets> a reading, fr. <ets>legere</ets> to read, collect. See
<er>Legend</er>, and cf. <er>Lection</er>.]</ety> <sn>1.</sn>
<def>Anything read or recited to a teacher by a pupil or learner;
something, as a portion of a book, assigned to a pupil to be studied or
learned at one time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is learned or taught by an express
effort; instruction derived from precept, experience, observation, or
deduction; a precept; a doctrine; <as>as, to take or give a
<ex>lesson</ex> in drawing</as>.</def><ldquo/ A smooth and pleasing
<xex>lesson</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Emprinteth well this <qex>lesson</qex> in your mind.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A portion of Scripture read in divine service for
instruction; <as>as, here endeth the first
<ex>lesson</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A severe lecture; reproof; rebuke;
warning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She would give her a <qex>lesson</qex> for walking so late.</q>
<rj><qau>Sir. P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <def> An exercise; a composition
serving an educational purpose; a study.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lesson</ent><br/
<hw>Les"son</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lessoned</conjf> <pr>(-s'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lessoning</conjf>.]</vmorph> <def>To teach; to instruct.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To rest the weary, and to soothe the sad,<br/
Doth <qex>lesson</qex> happier men, and shame at least the bad.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lessor</ent><br/
<hw>Les"sor</hw> <pr>(l<ecr/s"s<ocr/r <or/ l<ecr/s*s<ocir/r")</pr>,
<pos>n.</pos> <ety>[See <er>Lessee</er>, <er>Lease</er>, <pos>v.
t.</pos>]</ety> <fld>(Law)</fld> <def>One who leases; the person who
lets to farm, or gives a lease.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>less-traveled</ent><br/
<hw>less-traveled</hw> <pos>adj.</pos> <def>not visited by many
travelers; <as>as, the tourist's desire to visit <ex>less-traveled</ex>
countries</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lest</ent><br/
<hw>Lest</hw> <pr>(l<ecr/st)</pr>, <pos>v. i.</pos> <def>To
listen.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.
Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lest</ent><br/
<hw>Lest</hw>, <pos>n.</pos> <ety>[See List to choose.]</ety> <def>Lust;
desire; pleasure.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lest</ent><br/
<hw>Lest</hw>, <pos>a.</pos> <def>Last; least.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lest</ent><br/
<hw>Lest</hw>, <pos>conj.</pos> <ety>[OE. <ets>leste</ets>, fr. AS.
<ets><edh/<ymac/ l<aemac/s <edh/<emac/</ets> the less that, where
<ets><edh/<ymac/</ets> is the instrumental case of the definite article,
and <ets><edh/<emac/</ets> is an indeclinable relative particle,
<ets>that</ets>, <ets>who</ets>, <ets>which</ets>. See <er>The</er>,
<er>Less</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>For fear that; that
. . . not; in order that . . . not.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Love not sleep, <qex>lest</qex> thou come to poverty.</q>
<rj><qau>Prov. xx. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wherefore let him that thinketh he standeth take heed
<qex>lest</qex> he fall.</q> <rj><qau>1 Cor. x. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That (without the negative particle); -- after
certain expressions denoting <xex>fear</xex> or
<xex>apprehension</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I feared<br/
<qex>Lest</qex> I might anger thee.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lester</ent><br/
\'d8<hw>Les"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg., prob. fr.
Fr. <ets>l'est</ets> the east.]</ety> <fld>(Meteor.)</fld> <def>A dry
sirocco in the Madeira Islands.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>-let</ent><br/
<hw>-let</hw> <pr>(-l<ecr/t)</pr> <pos>suff.</pos> <ety>[From two French
dim. endings <ets>-el</ets> (L. <ets>-ellus</ets>) and <ets>-et</ets>,
as in brace<ets>let</ets>.]</ety> <def>A noun suffix having a diminutive
force; <as>as in stream<ex>let</ex>, wave<ex>let</ex>,
arm<ex>let</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let</ent><br/
<hw>Let</hw> <pr>(l<ecr/t)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>letten</ets>, AS. <ets>lettan</ets> to delay, to hinder, fr.
<ets>l<ae/t</ets> slow; akin to D. <ets>letten</ets> to hinder, G.
<ets>verletzen</ets> to hurt, Icel. <ets>letja</ets> to hold back, Goth.
<ets>latjan</ets>. See <er>Late</er>.]</ety> <def>To retard; to hinder;
to impede; to oppose.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was so strong that no man might him <qex>let</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He who now <qex>letteth</qex> will <qex>let</qex>, until he be
taken out of the way.</q> <rj><qau>2. Thess. ii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mine ancient wound is hardly whole,<br/
And <qex>lets</qex> me from the saddle.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let</ent><br/
<hw>Let</hw>, <pos>n.</pos> <sn>1.</sn> <def>A retarding; hindrance;
obstacle; impediment; delay; -- common in the phrase <xex>without let or
hindrance</xex>, but elsewhere archaic.</def>
<rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Consider whether your doings be to the <qex>let</qex> of your
salvation or not.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Lawn Tennis)</fld> <def>A stroke in which a ball
touches the top of the net in passing over.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let</ent><br/
<hw>Let</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Let</conjf> (<conjf>Letted</conjf> <pr>(l<ecr/t"t<ecr/d)</pr>,
<mark>[Obs]</mark>.); <pos>p. pr. & vb. n.</pos>
<conjf>Letting</conjf>.]</vmorph> <ety>[OE. <ets>leten</ets>,
<ets>l<ae/ten</ets> (past tense <ets>lat</ets>, <ets>let</ets>, p. p.
<ets>laten</ets>, <ets>leten</ets>, <ets>lete</ets>), AS.
<ets>l<aemac/tan</ets> (past tense <ets>l<emac/t</ets>, p. p.
<ets>l<aemac/ten</ets>); akin to OFries. <ets>l<emac/ta</ets>, OS.
<ets>l<amac/tan</ets>, D. <ets>laten</ets>, G. <ets>lassen</ets>, OHG.
<ets>l<amac/zzan</ets>, Icel. <ets>l<amac/ta</ets>, Sw.
<ets>l<aring/ta</ets>, Dan. <ets>lade</ets>, Goth.
<ets>l<emac/tan</ets>, and L. <ets>lassus</ets> weary. The original
meaning seems to have been, to let loose, let go, let drop. Cf.
<er>Alas</er>, <er>Late</er>, <er>Lassitude</er>, <er>Let</er> to
hinder.]</ety> <sn>1.</sn> <def>To leave; to relinquish; to
abandon.</def> <mark>[Obs. or Archaic, except when followed by
<xex>alone</xex> or <xex>be</xex>.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . prayed him his voyage for to <qex>let</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet neither spins nor cards, ne cares nor frets,<br/
But to her mother Nature all her care she <qex>lets</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Let</qex> me alone in choosing of my wife.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To consider; to think; to esteem.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause; to make; -- used with the infinitive in
the active form but in the passive sense; <as>as, <ex>let</ex> make,
<it>i. e.</it>, cause to be made; <ex>let</ex> bring, <it>i. e.</it>,
cause to be brought</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This irous, cursed wretch<br/
<qex>Let</qex> this knight's son anon before him fetch.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . thus <qex>let</qex> do slay hem all three.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Anon he <qex>let</qex> two coffers make.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To permit; to allow; to suffer; -- either
affirmatively, by positive act, or negatively, by neglecting to restrain
or prevent.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this sense, when followed by an infinitive, the
latter is commonly without the sign <xex>to</xex>; <as>as to
<ex>let</ex> us walk, <it>i. e.</it>, to permit or suffer us to
walk</as>. Sometimes there is entire omission of the verb; <as>as, to
<ex>let</ex> [to be or to go] loose</as>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Pharaoh said, I will <qex>let</qex> you go.</q> <rj><qau>Ex. viii.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If your name be Horatio, as I am <qex>let</qex> to know it is.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To allow to be used or occupied for a compensation;
to lease; to rent; to hire out; -- often with <ptcl>out</ptcl>; <as>as,
to <ex>let</ex> a farm; to <ex>let</ex> a house; to <ex>let</ex> out
horses.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To give, grant, or assign, as a work, privilege, or
contract; -- often with <ptcl>out</ptcl>; <as>as, to <ex>let</ex> the
building of a bridge; to <ex>let</ex> out the lathing and the
plastering.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The active form of the infinitive of <xex>let</xex>, as
of many other English verbs, is often used in a passive sense; as, a
house <xex>to let</xex> (<it>i. e.</it>, for letting, or to be let).
This form of expression conforms to the use of the Anglo-Saxon gerund
with <xex>to</xex> (dative infinitive) which was commonly so employed.
See <er>Gerund</er>, 2. <ldquo/ Your elegant house in Harley Street is
<xex>to let</xex>.<rdquo/ <au>Thackeray.</au> In the imperative mood,
before the first person plural, <xex>let</xex> has a hortative force.
<ldquo/ Rise up, <xex>let</xex> us go.<rdquo/ <au>Mark xiv. 42.</au>
<ldquo/ <xex>Let</xex> us seek out some desolate shade.<rdquo/
<au>Shak.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To let alone</b></col>, <cd>to leave; to withdraw from;
to refrain from interfering with.</cd> -- <col><b>To let
blood</b></col>, <cd>to cause blood to flow; to bleed.</cd> --
<col><b>To let down</b></col>. <sd>(a)</sd> <cd>To lower.</cd>
<sd>(b)</sd> <cd>To soften in tempering; as, <xex>to let down</xex>
tools, cutlery, and the like.</cd><-- to let (someone) down. to
disappoint (someone) by failing to perform as expected. --> --
<mcol><col><b>To let fly</b></col> <it>or</it> <col><b>To let
drive</b></col></mcol>, <cd>to discharge with violence, as a blow, an
arrow, or stone. See under <er>Drive</er>, and <er>Fly</er>.</cd> --
<mcol><col><b>To let in</b></col> <it>or</it> <col><b>To let
into</b></col></mcol>. <sd>(a)</sd> <cd>To permit or suffer to enter; to
admit.</cd> <sd>(b)</sd> <cd>To insert, or imbed, as a piece of wood, in
a recess formed in a surface for the purpose.</cd> -- <col><b>To let
loose</b></col>, <cd>to remove restraint from; to permit to wander at
large.</cd> -- <col><b>To let off</b></col>. <sd>(a)</sd> <cd>To
discharge; to let fly, as an arrow; to fire the charge of, as a
gun.</cd> <sd>(b)</sd> <cd>To release, as from an engagement or
obligation.</cd> <mark>[Colloq.]</mark> -- <col><b>To let out</b></col>.
<sd>(a)</sd> <cd>To allow to go forth; <as>as, <ex>to let out</ex> a
prisoner</as>.</cd> <sd>(b)</sd> <cd>To extend or loosen, as the folds
of a garment; to enlarge; to suffer to run out, as a cord.</cd>
<sd>(c)</sd> <cd>To lease; to give out for performance by contract, as a
job.</cd> <sd>(d)</sd> <cd>To divulge.</cd> -- <col><b>To let
slide</b></col>, <cd>to let go; to cease to care for.</cd>
<mark>[Colloq.]</mark> <ldquo/ <xex>Let</xex> the world
<xex>slide</xex>.<rdquo/ <au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let</ent><br/
<hw>Let</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To forbear.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be let or leased; <as>as, the farm <ex>lets</ex>
for $500 a year</as>. See note under <er>Let</er>, <pos>v.
t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To let on</b></col>, <cd>to tell; to tattle; to divulge
something.</cd> <mark>[Low]</mark> -- <col><b>To let up</b></col>,
<cd>to become less severe; to diminish; to cease; <as>as, when the storm
<ex>lets up</ex>.</as></cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let-alone</ent><br/
<hw>Let"-a*lone"</hw> <pr>(l<ecr/t"<adot/*l<omac/n")</pr>, <pos>a.</pos>
<def>Letting alone.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>The let-alone principle</b></col>, <col><b>The
let-alone doctrine</b></col>, <it>or</it> <col><b>The let-alone
policy</b></col></mcol>. <fld>(Polit. Econ.)</fld> <cd>See <er>Laissez
faire</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letch</ent><br/
<hw>Letch</hw> <pr>(l<ecr/ch)</pr>, <pos>v. & n.</pos> <def>See
<er>Leach</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letch</ent><br/
<hw>Letch</hw>, <pos>n.</pos> <ety>[See <er>Lech</er>,
<er>Lecher</er>.]</ety> <sn>1.</sn> <def>Strong desire; passion;
especially, lust.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some people have a <qex>letch</qex> for unmasking impostors, or
for avenging the wrongs of others.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A <er>lecher</er>.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Letchy</ent><br/
<hw>Letch"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <def>See
<er>Leachy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lete</ent><br/
<hw>Lete</hw> <pr>(l<ecr/t)</pr>, <pos>v. t.</pos> <def>To let; to
leave.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leten</ent><br/
<hw>Let"en</hw> <pr>(l<ecr/t"<eit/n)</pr>, <mark>obs.</mark>
<def><pos>p. p.</pos> of <er>Lete</er>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethal</ent><br/
<hw>Leth"al</hw> <pr>(l<ecr/th"<acr/l)</pr>, <pos>n.</pos>
<ety>[<ets>L</ets>auric + <ets>eth</ets>er + <ets>al</ets>cohol.]</ety>
<fld>(Chem.)</fld> <def>One of the higher alcohols of the paraffine
series obtained from spermaceti as a white crystalline solid. It is so
called because it occurs in the ethereal salt of lauric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 845 pr=VMG --></p>

<p><ent>Lethal</ent><br/
<hw>Le"thal</hw> <pr>(l<emac/"th<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>lethalis</ets>, <ets>letalis</ets>, fr. <ets>lethum</ets>,
<ets>letum</ets>, death: cf. F. <ets>l<eacute/thal</ets>.]</ety>
<def>Deadly; mortal; fatal.</def> <ldquo/The <xex>lethal</xex>
blow.<rdquo/ <au>W. Richardson.</au> -- <wordforms><wf>Le"thal*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethality</ent><br/
<hw>Le*thal"i*ty</hw> <pr>(l<esl/*th<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>l<eacute/thalit<eacute/</ets>.]</ety>
<def>The quality of being lethal; mortality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethargical</ent><br/
<ent>Lethargic</ent><br/
<mhw>{ <hw>Le*thar"gic</hw> <pr>(l<esl/*th<aum/r"j<icr/k)</pr>,
<hw>Le*thar"gic*al</hw> <pr>(-j<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>lethargicus</ets>, Gr.
<grk>lhqargiko`s</grk>: cf. F. <ets>l<eacute/thargique</ets>. See
<er>Lethargy</er>.]</ety> <def>Pertaining to, affected with, or
resembling, lethargy; morbidly drowsy; dull; heavy.</def> --
<wordforms><wf>Le*thar"gic*al*ly</wf>, <pos>adv.</pos> --
<wf>Le*thar"gic*al*ness</wf>, <pos>n.</pos> --
<wf>Le*thar"gic*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethargize</ent><br/
<hw>Leth"ar*gize</hw> <pr>(l<ecr/th"<adot/r*j<imac/z)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Lethargized</conjf>
<pr>(-j<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lethargizing</conjf> <pr>(-j<imac/`z<icr/ng)</pr>.]</vmorph>
<def>To make lethargic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All bitters are poison, and act by stilling, and depressing, and
<qex>lethargizing</qex> the irritability.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethargy</ent><br/
<hw>Leth"ar*gy</hw> <pr>(-j<ycr/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-gies</plw> <pr>(-j<icr/z)</pr>.</plu> <ety>[F.
<ets>l<eacute/thargie</ets>, L. <ets>lethargia</ets>, Gr.
<grk>lhqargi`a</grk>, fr. <grk>lh`qargos</grk> forgetful, fr.
<grk>lh`qh</grk> forgetfulness. See <er>Lethe</er>.]</ety> <sn>1.</sn>
<def>Morbid drowsiness; continued or profound sleep, from which a person
can scarcely be awaked.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of inaction or indifference.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Europe lay then under a deep <qex>lethargy</qex>.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethargy</ent><br/
<hw>Leth"ar*gy</hw>, <pos>v. t.</pos> <def>To lethargize.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethe</ent><br/
<hw>Le"the</hw> <pr>(l<emac/"th<esl/ <or/ l<emac/th)</pr>, <pos>n.</pos>
<ety>[See <er>Lethal</er>.]</ety> <def>Death.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethe</ent><br/
<hw>Le"the</hw> <pr>(l<emac/"th<esl/)</pr>, <pos>n.</pos> <ety>[L., fr.
Gr. <grk>lh`qh</grk>, prop., forgetfulness; akin to
<grk>lanqa`nesqai</grk> to forget, <grk>lanqa`nein</grk> to escape
notice.]</ety> <sn>1.</sn> <fld>(Class. Myth.)</fld> <def>A river of
Hades whose waters when drunk caused forgetfulness of the
past.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Oblivion; a draught of oblivion;
forgetfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethean</ent><br/
<hw>Le*the"an</hw> <pr>(l<esl/*th<emac/"<ait/n)</pr>, <pos>a.</pos>
<ety>[L. <ets>Lethaeus</ets>, Gr. <grk>lh`qaios</grk> or
<grk>lhqai^os</grk>.]</ety> <def>Of or pertaining to Lethe; resembling
in effect the water of Lethe.</def> <rj><au>Milton.
Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letheed</ent><br/
<hw>Le"theed</hw> <pr>(l<emac/"th<emac/d)</pr>, <pos>a.</pos>
<def>Caused by Lethe.</def> <ldquo/ <xex>Letheed</xex> dullness.<rdquo/
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letheon</ent><br/
<hw>Le"the*on</hw> <pr>(l<emac/"th<esl/*<ocr/n)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>lh`qh</grk>.]</ety> <fld>(Med.)</fld>
<def>Sulphuric ether used as an an<ae/sthetic agent.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letheonize</ent><br/
<hw>Le"the*on*ize</hw> <pr>(-<imac/z)</pr>, <pos>v. t.</pos> <def>To
subject to the influence of letheon.</def> <mark>[R. or Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethiferous</ent><br/
<hw>Le*thif"er*ous</hw> <pr>(l<esl/*th<icr/f"<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>lethifer</ets>, <ets>letifer</ets>, fr.
<ets>lethum</ets>, <ets>letum</ets>, death + <ets>ferre</ets> to bear,
to bring: cf. F. <ets>l<eacute/thif<egrave/re</ets>.]</ety> <def>Deadly;
bringing death or destruction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lethy</ent><br/
<hw>Le"thy</hw> <pr>(l<emac/"th<ycr/)</pr>, <pos>a.</pos>
<def>Lethean.</def> <mark>[Obs.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let-off</ent><br/
<hw>Let"-off`</hw> <pr>(l<ecr/t"<ocr/f`; 115)</pr>, <pos>n.</pos>
<fld>(Mach.)</fld> <def>A device for letting off, releasing, or giving
forth, as the warp from the cylinder of a loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lette</ent><br/
<hw>Let"te</hw> <pr>(l<ecr/t"t<eit/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Letted</conjf>.]</vmorph>
<def>To let; to hinder. See <er>Let</er>, to hinder.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letter</ent><br/
<hw>Let"ter</hw> <pr>(l<ecr/t"t<etil/r)</pr>, <pos>n.</pos> <ety>[From
<er>Let</er> to permit.]</ety> <def>One who lets or permits; one who
lets anything for hire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letter</ent><br/
<hw>Let"ter</hw>, <pos>n.</pos> <ety>[From <er>Let</er> to
hinder.]</ety> <def>One who retards or hinders.</def>
<mark>[Archaic.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letter</ent><br/
<hw>Let"ter</hw>, <pos>n.</pos> <ety>[OE. <ets>lettre</ets>, F.
<ets>lettre</ets>, OF. <ets>letre</ets>, fr. L. <ets>littera</ets>,
<ets>litera</ets>, a letter; pl., an epistle, a writing, literature, fr.
<ets>linere</ets>, <ets>litum</ets>, to besmear, to spread or rub over;
because one of the earliest modes of writing was by graving the
characters upon tablets smeared over or covered with wax. <au>Pliny,
xiii. 11.</au> See <er>Liniment</er>, and cf. <er>Literal</er>.]</ety>
<sn>1.</sn> <def>A mark or character used as the representative of a
sound, or of an articulation of the human organs of speech; a first
element of written language.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And a superscription also was written over him in
<qex>letters</qex> of Greek, and Latin, and Hebrew.</q> <rj><qau>Luke
xxiii. 38.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A written or printed communication; a message
expressed in intelligible characters on something adapted to conveyance,
as paper, parchment, etc.; an epistle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The style of <qex>letters</qex> ought to be free, easy, and
natural.</q> <rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A writing; an inscription.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>None could expound what this <qex>letter</qex> meant.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Verbal expression; literal statement or meaning;
exact signification or requirement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We must observe the <qex>letter</qex> of the law, without doing
violence to the reason of the law and the intention of the lawgiver.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I broke the <qex>letter</qex> of it to keep the sense.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Print.)</fld> <def>A single type; type,
collectively; a style of type.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Under these buildings . . . was the king's printing house, and
that famous <qex>letter</qex> so much esteemed.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <pluf>pl.</pluf> <def>Learning; erudition; <as>as, a man
of <ex>letters</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <def>A letter; an epistle.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Teleg.)</fld> <def>A telegram longer than an
ordinary message sent at rates lower than the standard message rate in
consideration of its being sent and delivered subject to priority in
service of regular messages. Such telegrams are called by the Western
Union Company <altname>day letters</altname>, <it>or</it> <altname>night
letters</altname> according to the time of sending, and by The Postal
Telegraph Company <altname>day lettergrams</altname>, <it>or</it>
<altname>night lettergrams</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<cs><p><mcol><col><b>Dead letter</b></col>, <col><b>Drop
letter</b></col></mcol>, <cd>etc. See under <er>Dead</er>,
<er>Drop</er>, etc.</cd> -- <col><b>Letter book</b></col>, <cd>a book in
which copies of letters are kept.</cd> -- <col><b>Letter box</b></col>,
<cd>a box for the reception of letters to be mailed or delivered.</cd>
-- <col><b>Letter carrier</b></col>, <cd>a person who carries letters; a
postman; specif., an officer of the post office who carries letters to
the persons to whom they are addressed, and collects letters to be
mailed.</cd> -- <col><b>Letter cutter</b></col>, <cd>one who engraves
letters or letter punches.</cd> -- <col><b>Letter lock</b></col>, <cd>a
lock that can not be opened when fastened, unless certain movable
lettered rings or disks forming a part of it are in such a position
(indicated by a particular combination of the letters) as to permit the
bolt to be withdrawn.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>A strange lock that opens with AMEN.</q> <rj><qau>Beau. &
Fl.</qau></rj></p>

<p>-- <col><b>Letter paper</b></col>, <cd>paper for writing letters on;
especially, a size of paper intermediate between note paper and
foolscap. See <er>Paper</er>.</cd> -- <col><b>Letter punch</b></col>,
<cd>a steel punch with a letter engraved on the end, used in making the
matrices for type.</cd> -- <col><b>Letters of administration</b></col>
<fld>(Law)</fld>, <cd>the instrument by which an administrator or
administratrix is authorized to administer the goods and estate of a
deceased person.</cd> -- <mcol><col><b>Letter of attorney</b></col>,
<col><b>Letter of credit</b></col></mcol>, etc. <cd>See under
<er>Attorney</er>, <er>Credit</er>, etc.</cd> -- <col><b>Letter of
license</b></col>, <cd>a paper by which creditors extend a debtor's time
for paying his debts.</cd> -- <mcol><col><b>Letters close</b></col>
<it>or</it> <col><b>Letters clause</b></col></mcol> <fld>(Eng.
Law.)</fld>, <cd>letters or writs directed to particular persons for
particular purposes, and hence <xex>closed</xex> or sealed on the
outside; -- distinguished from <contr>letters patent</contr>.</cd>
<au>Burrill.</au> -- <col><b>Letters of orders</b></col>
<fld>(Eccl.)</fld>, <cd>a document duly signed and sealed, by which a
bishop makes it known that he has regularly ordained a certain person as
priest, deacon, etc.</cd> -- <mcol><col><b>Letters patent</b></col>,
<col><b>Letters overt</b></col>, <it>or</it> <col><b>Letters
open</b></col></mcol> <fld>(Eng. Law)</fld>, <cd>a writing executed and
sealed, by which power and authority are granted to a person to do some
act, or enjoy some right; <as>as, <ex>letters patent</ex> under the seal
of England</as>. The common commercial <er>patent</er> is a derivative
form of such a right.</cd> -- <col><b>Letter-sheet envelope</b></col>,
<cd>a stamped sheet of letter paper issued by the government, prepared
to be folded and sealed for transmission by mail without an
envelope.</cd> -- <col><b>Letters testamentary</b></col>
<fld>(Law)</fld>, <cd>an instrument granted by the proper officer to an
executor after probate of a will, authorizing him to act as
executor.</cd> -- <col><b>Letter writer</b></col>. <sd>(a)</sd> <cd>One
who writes letters.</cd> <sd>(b)</sd> <cd>A machine for copying
letters.</cd> <sd>(c)</sd> <cd>A book giving directions and forms for
the writing of letters.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Letter</ent><br/
<hw>Let"ter</hw> <pr>(l<ecr/t"t<etil/r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lettered</conjf>
<pr>(-t<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lettering</conjf>.]</vmorph> <def>To impress with letters; to
mark with letters or words; <as>as, a book gilt and
<ex>lettered</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>letter-bomb</ent><br/
<ent>letter bomb</ent><br/
<mhw><hw>let"ter bomb`</hw>, <hw>let"ter-bomb`</hw></mhw> <pos>n.</pos>
<def>A bomb disguised as a letter and sent through the mail, usually
rigged to explode and kill or harm the recipient when opened.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>letter-bomb</ent><br/
<hw>letter-bomb</hw> <pos>v. t.</pos> <def>to send a letter-bomb
to.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lettercard</ent><br/
<hw>lettercard</hw> <pos>n.</pos> <def>a postcard that folds so that the
message is inside.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lettered</ent><br/
<hw>Let"tered</hw> <pr>(l<ecr/t"t<etil/rd)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Literate; educated; versed in literature.</def> <ldquo/
Are you not <xex>lettered</xex>?<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The unlettered barbarians willingly accepted the aid of the
<qex>lettered</qex> clergy, still chiefly of Roman birth, to reduce to
writing the institutes of their forefathers.</q>
<rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to learning or literature;
learned.</def> <ldquo/ A <xex>lettered</xex> education.<rdquo/
<rj><au>Collier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Inscribed or stamped with letters.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letterer</ent><br/
<hw>Let"ter*er</hw> <pr>(l<ecr/t"t<etil/r*<etil/r)</pr>, <pos>n.</pos>
<def>One who makes, inscribes, or engraves, alphabetical
letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lettergram</ent><br/
<hw>Let"ter*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Letter{8}</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lettering</ent><br/
<hw>Let"ter*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or business
of making, or marking with, letters, as by cutting or
painting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The letters made; <as>as, the <ex>lettering</ex> of
a sign</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letterless</ent><br/
<hw>Let"ter*less</hw> <pr>(l<ecr/t"t<etil/r*l<ecr/s)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Not having a letter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Illiterate.</def> <mark>[Obs.]</mark> <rj><au>E.
Waterhouse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lettern</ent><br/
<hw>Let"tern</hw> <pr>(l<ecr/t"t<etil/rn)</pr>, <pos>n.</pos> <def>See
<er>Lecturn</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>letter-perfect</ent><br/
<hw>letter-perfect</hw> <pos>adj.</pos> <def>correct to the last detail;
especially being in or following the exact words; <as>as, a
<ex>letter-perfect</ex> rendition of the soliloquy</as>.</def><br/
<syn><b>Syn. --</b> word-perfect.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Letterpress</ent><br/
<hw>Let"ter*press`</hw> <pr>(-t<etil/r*pr<ecr/s`)</pr>, <pos>n.</pos>
<def>Print; letters and words impressed on paper or other material by
types; -- often used of the reading matter in distinction from the
illustrations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Letterpress printing, printing directly from type, in distinction
from printing from plates.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letterure</ent><br/
<hw>Let"ter*ure</hw> <pr>(-<usl/r)</pr>, <pos>n.</pos> <def>Letters;
literature.</def> <mark>[Obs.]</mark> <ldquo/To teach him
<xex>letterure</xex> and courtesy.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letterwood</ent><br/
<hw>Let"ter*wood`</hw> <pr>(-w<oocr/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The beautiful and highly elastic wood of a tree
of the genus <gen>Brosimum</gen> (<spn>Brosimum Aubletii</spn>), found
in Guiana; -- so called from black spots in it which bear some
resemblance to hieroglyphics; also called <altname>snakewood</altname>,
and <altname>leopardwood</altname>. It is much used for bows and for
walking sticks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lettic</ent><br/
<hw>Let"tic</hw> <pr>(l<ecr/t"t<icr/k)</pr>, <pos>a.</pos> <sd>(a)</sd>
<def>Of or pertaining to the Letts; Lettish.</def> <sd>(b)</sd> <def>Of
or pertaining to a branch of the Slavic family, subdivided into Lettish,
Lithuanian, and Old Prussian.</def> -- <def2><pos>n.</pos> <sd>(a)</sd>
<def>The language of the Letts; Lettish.</def> <sd>(b)</sd> <def>The
language of the Lettic race, including Lettish, Lithuanian, and Old
Prussian.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lettish</ent><br/
<hw>Let"tish</hw> <pr>(l<ecr/t"t<icr/sh)</pr>, <pos>a.</pos> <def>Of or
pertaining to the Letts.</def> -- <def2><pos>n.</pos> <def>The language
spoken by the Letts. See <er>Lettic</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lettrure</ent><br/
<hw>Let"trure</hw> <pr>(-tr<usdot/r)</pr>, <pos>n.</pos> <def>See
<er>Letterure</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letts</ent><br/
<hw>Letts</hw> <pr>(l<ecr/ts)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Lett</singw> <pr>(l<ecr/t)</pr></sing>. <fld>(Ethnol.)</fld>
<def>An Indo-European people, allied to the Lithuanians and Old
Prussians, and inhabiting a part of the Baltic provinces of
Russia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lettuce</ent><br/
<hw>Let"tuce</hw> <pr>(l<ecr/t"t<icr/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>letuce</ets>, prob. through Old French from some Late Latin
derivative of L. <ets>lactuca</ets> lettuce, which, according to Varro,
is fr. <ets>lac</ets>, <ets>lactis</ets>, milk, on account of the milky
white juice which flows from it when it is cut: cf. F.
<ets>laitue</ets>. Cf. <er>Lacteal</er>, <er>Lactucic</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A composite plant of the genus
<gen>Lactuca</gen> (<spn>Lactuca sativa</spn>), the leaves of which are
used as salad. Plants of this genus yield a milky juice, from which
lactucarium is obtained. The commonest wild lettuce of the United States
is <spn>Lactuca Canadensis</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>United States currency; dollar bills;
greenbacks.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Hare's lettuce</b></col>, <col><b>Lamb's
lettuce</b></col></mcol>. <cd>See under <er>Hare</er>, and
<er>Lamb</er>.</cd> -- <col><b>Lettuce opium</b></col>. <cd>See
<er>Lactucarium</er>.</cd> -- <col><b>Sea lettuce</b></col>, <cd>certain
papery green seaweeds of the genus <gen>Ulva</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Letuary</ent><br/
<hw>Let"u*a*ry</hw> <pr>(l<ecr/t"<usl/*<asl/*r<ycr/)</pr>, <pos>n.</pos>
<def>Electuary.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Let-up</ent><br/
<hw>Let"-up`</hw> <pr>(l<ecr/t"<ucr/p`)</pr>, <pos>n.</pos> <ety>[See
<er>Let</er> to forbear.]</ety> <def>Abatement; also, cessation; <as>as,
it blew a gale for three days without any <ex>let-up</ex></as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leuc-</ent><br/
<hw>Leuc-</hw> <pr>(l<umac/k-)</pr> <pos>pref.</pos> <def>Same as
<er>Leuco-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucadendron</ent><br/
\'d8<hw>Leu`ca*den"dron</hw>
<pr>(l<umac/`k<adot/*d<ecr/n"dr<ocr/n)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>leyko`s</grk> white + <grk>de`ndron</grk> tree.]</ety>
<fld>(Bot.)</fld> <def>A genus of evergreen shrubs from the Cape of Good
Hope, having handsome foliage. <spn>Leucadendron argenteum</spn> is the
<stype>silverboom</stype> of the colonists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucaniline</ent><br/
<hw>Leu*can"i*line</hw> <pr>(l<usl/*k<acr/n"<icr/*l<icr/n <or/
-l<emac/n)</pr>, <pos>n.</pos> <ety>[<ets>Leuc-</ets> +
<ets>aniline</ets>.]</ety> <fld>(Chem.)</fld> <def>A colorless,
crystalline, organic base, obtained from rosaniline by reduction, and
also from other sources. It forms colorless salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leuchaemia</ent><br/
\'d8<hw>Leu*ch<ae/"mi*a</hw> <pr>(l<usl/*k<emac/"m<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>leyko`s</grk> white +
<grk>a"i^ma</grk> blood.]</ety> <fld>(Med.)</fld> <def>See
<er>Leukemia</er>.</def> <altsp>[Written also <asp>leukemia</asp>,
<asp>leukaemia</asp>,a nd <asp>leucemia</asp>.]</altsp><br/
-- <wordforms><wf>Leu*ch<ae/m"ic</wf> <pr>(l<usl/*k<ecr/m"<icr/k)</pr>,
<pos>a.</pos> <altsp>[Written also <asp>leukemic</asp> and
<asp>leukaemic</asp>.]</altsp></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucinic</ent><br/
<ent>Leucic</ent><br/
<mhw>{ <hw>Leu"cic</hw> <pr>(l<umac/"s<icr/k)</pr>, <hw>Leu*cin"ic</hw>
<pr>(l<usl/*s<icr/n"<icr/k)</pr>, }</mhw> <pos>a.</pos>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an acid obtained
from leucin, and called also <altname>oxycaproic
acid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucin</ent><br/
<ent>Leucine</ent><br/
<mhw><hw>Leu"cine</hw> <pr>(l<oomac/"s<emac/n)</pr>,
<hw>Leu"cin</hw></mhw> <pr>(l<umac/"s<icr/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>leyko`s</grk> white.]</ety> <fld>(Physiol. Chem.)</fld>
<def>a naturally occurring alpha-amino acid
(<chform>(CH3)2CH.CH2.CH(NH2)-COOH</chform>), one of the building units
of almost all proteins of living organisms, both animal and vegetable.
It is one of the essential amino acids (not synthesized by the human
body, a required component for proper nutrition), and is hydrophobic in
character when bound in proteins. In isolated form it is a white,
crystalline, zwitterionic substance formed, e. g. by the decomposition
of proteins by pancreatic digestion, by the action of boiling dilute
mineral acid, or by putrefaction. Chemically it is to be considered as
amido-caproic acid. It occurs as two optical isomers, the L- and
D-forms. The L-form, L-leucine, is the natural form, present in most
proteins.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Leuciscus</ent><br/
<hw>Leuciscus</hw> <pos>prop. n.</pos> <def>A genus of freshwater fishes
including the dace (<spn>Leuciscus leuciscus</spn>).</def><br/
<syn><b>Syn. --</b> genus <gen>Leuciscus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leucite</ent><br/
<hw>Leu"cite</hw> <pr>(l<umac/"s<imac/t)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>leyko`s</grk> white: cf. F. <ets>leucite</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Min.)</fld> <def>A mineral having a glassy
fracture, occurring in translucent trapezohedral crystals. It is a
silicate of alumina and potash <chform>KAlSi2O6</chform>. It is found in
the volcanic rocks of Italy, especially at Vesuvius.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A leucoplast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucitic</ent><br/
<hw>Leu*cit"ic</hw> <pr>(l<usl/*s<icr/t"<icr/k)</pr>, <pos>a.</pos>
<fld>(Min.)</fld> <def>Containing leucite; <as>as, <ex>leucitic</ex>
rocks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucitoid</ent><br/
<hw>Leu"ci*toid</hw> <pr>(l<umac/"s<icr/*toid)</pr>, <pos>n.</pos>
<ety>[<ets>Leucite</ets> + <ets>-oid</ets>.]</ety>
<fld>(Crystallog.)</fld> <def>The trapezohedron or tetragonal
trisoctahedron; -- so called as being the form of the mineral
leucite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leuc-</ent><br/
<ent>Leuco-</ent><br/
<mhw>{ <hw>Leu"co-</hw> <pr>(l<umac/"k<osl/-)</pr>, <hw>Leuc-</hw>
<pr>(l<umac/k-)</pr>. }</mhw> <pos>pref.</pos> <ety>[Gr.
<grk>leyko`s</grk> white.]</ety> <def>A combining form signifying
<xex>white</xex>, <xex>colorless</xex>; specif. <fld>(Chem.)</fld>,
denoting an extensive series of <xex>colorless</xex> organic compounds,
obtained by reduction from certain other <xex>colored</xex> compounds;
<as>as, <ex>leuc</ex>aniline, <ex>leuc</ex>aurin, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucocyte</ent><br/
<hw>Leu"co*cyte</hw> <pr>(l<umac/"k<osl/*s<imac/t)</pr>, <pos>n.</pos>
<ety>[<ets>Leuco-</ets> + Gr. <grk>ky`tos</grk> a hollow vessel.]</ety>
<fld>(Physiol.)</fld> <def>A colorless corpuscle, as one of the white
blood corpuscles, or those found in lymph, marrow of bone, connective
tissue, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They all consist of more or less spherical masses of
protoplasm, without any surrounding membrane or wall, and are capable of
motion.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucocythemia</ent><br/
<ent>Leucocythaemia</ent><br/
<mhw>{ \'d8<hw>Leu`co*cy*th<ae/"mi*a</hw>
\'d8<hw>Leu`co*cy*the"mi*a</hw> } </mhw>
<pr>(l<umac/`k<osl/*s<isl/*th<emac/"m<icr/*<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>leyko`s</grk> white + <grk>ky`tos</grk> a hollow
vessel + <grk>a"i^ma</grk> blood.]</ety> <fld>(Med.)</fld> <def>Same as
<er>leukemia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucocytogenesis</ent><br/
<hw>Leu`co*cy`to*gen"e*sis</hw>
<pr>(-s<imac/`t<osl/*j<ecr/n"<esl/*s<icr/s)</pr>, <pos>n.</pos>
<ety>[<ets>Leucocyte</ets> + <ets>genesis</ets>.]</ety>
<fld>(Physiol.)</fld> <def>The formation of leucocytes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoethiopic</ent><br/
<hw>Leu`co*e`thi*op"ic</hw> <pr>(-<emac/`th<icr/*<ocr/p"<icr/k)</pr>,
<pos>a.</pos> <ety>[<ets>Leuco-</ets> + <ets>Ethiopic</ets>.]</ety>
<def>White and black; -- said of a white animal of a black species, or
the albino of the negro race.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoethiops</ent><br/
<hw>Leu`co*e"thi*ops</hw> <pr>(-<emac/"th<icr/*<ocr/ps)</pr>,
<pos>n.</pos> <ety>[<ets>Leuco-</ets> + <ets>Aethiops</ets>.]</ety>
<def>An albino.</def> <altsp>[Also written
<asp>leuc<oe/thiops</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoline</ent><br/
<hw>Leu"co*line</hw> <pr>(l<umac/"k<osl/*l<icr/n <or/ -l<emac/n)</pr>,
<pos>n.</pos> <ety>[<ets>Leuc-</ets> + L. <ets>ol</ets>eum oil.]</ety>
<fld>(Chem.)</fld> <def>A nitrogenous organic base from coal tar, and
identical with quinoline. Cf. <er>Quinoline</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoma</ent><br/
\'d8<hw>Leu*co"ma</hw> <pr>(l<usl/*k<omac/"m<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>ley`kwma</grk>, fr. <grk>leyko`s</grk>
white.]</ety> <fld>(Med.)</fld> <def>A white opacity in the cornea of
the eye; -- called also <altname>albugo</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucomaine</ent><br/
<hw>Leu*co"ma*ine</hw> <pr>(l<usl/*k<omac/"m<adot/*<icr/n <or/
-<emac/n)</pr>, <pos>n.</pos> <ety>[<ets>Leuco-</ets> +
<ets>-maine</ets>, as in <ets>ptomaine</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>An animal base or alkaloid, appearing in the tissue
during life; hence, a vital alkaloid, as distinguished from a
<contr>ptomaine</contr> or cadaveric poison.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leuconic</ent><br/
<hw>Leu*con"ic</hw> <pr>(-k<ocr/n"<icr/k)</pr>, <pos>a.</pos>
<ety>[<ets>Leuc-</ets> + croc<ets>onic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a complex organic acid, obtained as
a yellowish white gum by the oxidation of croconic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucopathy</ent><br/
<hw>Leu*cop"a*thy</hw> <pr>(l<usl/*k<ocr/p"<adot/*th<ycr/)</pr>,
<pos>n.</pos> <ety>[<ets>Leuco-</ets> + Gr. <grk>pa`schein</grk>,
<grk>paqei^n</grk> to suffer.]</ety> <def>The state of an albino, or of
a white child of black parents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucophane</ent><br/
<hw>Leu"co*phane</hw> <pr>(l<umac/"k<osl/*f<amac/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>leykofanh`s</grk> appearing bright or white;
<grk>leyko`s</grk> white + <grk>fai`nein</grk> to show: cf. G.
<ets>leukophan</ets>.]</ety> <fld>(Min.)</fld> <def>A mineral of a
greenish yellow color; it is a silicate of glucina, lime, and soda with
fluorine. Called also <altname>leucophanite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucophlegmacy</ent><br/
<hw>Leu`co*phleg"ma*cy</hw>
<pr>(l<umac/`k<osl/*fl<ecr/g"m<adot/*s<ycr/)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>leykoflegmati`a</grk>; <grk>leyko`s</grk> white +
<grk>fle`gma</grk> phlegm: cf. F. <ets>leucophlegmasie</ets>.]</ety>
<fld>(Med.)</fld> <def>A dropsical habit of body, or the commencement of
anasarca; paleness, with viscid juices and cold sweats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucophlegmatic</ent><br/
<hw>Leu`co*phleg*mat"ic</hw> <pr>(-fl<ecr/g*m<acr/t"<icr/k)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>leucophlegmatique</ets>, Gr.
<grk>leykofle`gmatos</grk>.]</ety> <def>Having a dropsical habit of
body, with a white bloated skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucophyll</ent><br/
<hw>Leu"co*phyll</hw> <pr>(l<umac/"k<osl/*f<icr/l)</pr>, <pos>n.</pos>
<ety>[<ets>Leuco-</ets> + Gr. <grk>fy`llon</grk> a leaf.]</ety>
<fld>(Chem.)</fld> <def>A colorless substance isomeric with chlorophyll,
contained in parts of plants capable of becoming green.</def>
<rj><au>Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucophyllous</ent><br/
<hw>Leu*coph"yl*lous</hw> <pr>(l<usl/*k<ocr/f"<icr/l*l<ucr/s <or/
l<umac/`k<osl/*f<icr/l"l<ucr/s)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>leyko`fyllos</grk>; <grk>leyko`s</grk> white + <grk>fy`llon</grk> a
leaf.]</ety> <fld>(Bot.)</fld> <def>Having white or silvery
foliage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoplastid</ent><br/
<ent>Leucoplast</ent><br/
<mhw>{ <hw>Leu"co*plast</hw> <pr>(l<umac/"k<osl/*pl<acr/st)</pr>,
<hw>Leu`co*plas"tid</hw> <pr>(-pl<acr/s"t<icr/d)</pr>, }</mhw>
<pos>n.</pos> <ety>[<ets>Leuco-</ets> + Gr. <grk>pla`ssein</grk> to
mold.]</ety> <fld>(Bot.)</fld> <def>One of certain very minute whitish
or colorless granules occurring in the protoplasm of plants and supposed
to be the nuclei around which starch granules will form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucopyrite</ent><br/
<hw>Leu*cop"y*rite</hw> <pr>(l<usl/*k<ocr/p"<icr/*r<imac/t)</pr>,
<pos>n.</pos> <ety>[<ets>Leuco-</ets> + <ets>pyrites</ets>.]</ety>
<fld>(Min.)</fld> <def>A mineral of a color between white and
steel-gray, with a metallic luster, and consisting chiefly of arsenic
and iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucorrhoea</ent><br/
<hw>Leu`cor*rh<oe/"a</hw> <pr>(l<umac/`k<ocr/r*r<emac/"<adot/)</pr>,
<pos>n.</pos> <ety>[<ets>Leuco-</ets> + Gr. <grk>"rei^n</grk> to
flow.]</ety> <fld>(Med.)</fld> <def>A discharge of a white, yellowish,
or greenish, viscid mucus, resulting from inflammation or irritation of
the membrane lining the genital organs of the female; the
whites.</def><-- leukorrhea, leukorrhagia -->
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoryx</ent><br/
\'d8<hw>Leu"co*ryx</hw> <pr>(l<umac/"k<osl/*r<icr/ks)</pr>,
<pos>n.</pos> <ety>[NL., from Gr. <grk>leyko`s</grk> + <grk>'o`ryx</grk>
a kind of gazelle.]</ety> <fld>(Zool.)</fld> <def>A large antelope of
North Africa (<spn>Oryx leucoryx</spn>), allied to the
gemsbok.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoscope</ent><br/
<hw>Leu"co*scope</hw> <pr>(l<umac/"k<osl/*sk<omac/p)</pr>, <pos>n.</pos>
<ety>[<ets>Leuco-</ets> + <ets>-scope</ets>.]</ety> <fld>(Physics)</fld>
<def>An instrument, devised by Professor Helmholtz, for testing the
color perception of the eye, or for comparing different lights, as to
their constituent colors or their relative whiteness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucosoid</ent><br/
<hw>Leu"co*soid</hw> <pr>(-soid)</pr>, <pos>a.</pos> <ety>[NL.
<ets>Leucosia</ets>, the typical genus (fr. Gr. <grk>leyko`s</grk>
white) + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or
pertaining to the <fam>Leucosoidea</fam>, a tribe of marine crabs
including the box crab or <gen>Calappa</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucosphere</ent><br/
<hw>Leu"co*sphere</hw> <pr>(-sf<emac/r)</pr>, <pos>n.</pos>
<ety>[<ets>Leuco-</ets> + <ets>sphere</ets>.]</ety> <fld>(Astron.)</fld>
<def>The inner corona.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoturic</ent><br/
<hw>Leu`co*tu"ric</hw> <pr>(l<umac/`k<osl/*t<umac/"r<icr/k)</pr>,
<pos>a.</pos> <ety>[<ets>Leuco-</ets> + allan<ets>t</ets>oic +
<ets>uric</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, a nitrogenous organic substance of the uric acid group,
called <xex>leucoturic</xex> acid or <xex>oxalantin</xex>. See
<er>Oxalantin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucous</ent><br/
<hw>Leu"cous</hw> <pr>(l<umac/"k<ucr/s)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>leyko`s</grk>.]</ety> <def>White; -- applied to albinos, from the
whiteness of their skin and hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leucoxene</ent><br/
<hw>Leu*cox"ene</hw> <pr>(l<usl/*k<ocr/ks"<emac/n)</pr>, <pos>n.</pos>
<ety>[<ets>Leuco-</ets> + Gr. <grk>xe`nos</grk> stranger.]</ety>
<fld>(Min.)</fld> <def>A nearly opaque white mineral, in part identical
with titanite, observed in some igneous rocks as the result of the
alteration of titanic iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>leukaemia</ent><br/
<ent>leukemia</ent><br/
<hw>leu*k<ae/"mi*a</hw> <pr>(l<usl/*k<emac/"m<icr/*<adot/)</pr>,
<pos>n.</pos> <def>A disease in which the white corpuscles of the blood
are largely increased in number, and there is enlargement of the spleen,
or the lymphatic glands; formerly called
<altname>leucocythaemia</altname>. It is due to a cancer of the bone
marrow, and results in anemia and increased susceptibility to infectious
disease.</def> <altsp>[Also spelled <asp>leucemia</asp> and
<asp>leuchaemia</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Leukeness</ent><br/
<ent>Leuke</ent><br/
<mhw><hw>Leuke</hw> <pr>(l<umac/k)</pr>, <pos>a.</pos>,
<hw>Leuke"ness</hw>, <pos>n.</pos></mhw> <def>See <er>Luke</er>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leukoplast</ent><br/
<hw>Leu"ko*plast</hw> <pr>(l<umac/"k<osl/*pl<acr/st)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>See <er>Leucoplast</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levana</ent><br/
\'d8<hw>Le*va"na</hw> <pr>(l<esl/*v<amac/"n<adot/)</pr>, <pos>n.</pos>
<ety>[L., fr. <ets>levare</ets> to raise.]</ety> <fld>(Rom. Myth.)</fld>
<def>A goddess who protected newborn infants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levant</ent><br/
<hw>Le"vant</hw> <pr>(l<emac/"v<ait/nt)</pr>, <pos>a.</pos> <ety>[F., p.
pr. of <ets>lever</ets> to raise.]</ety> <fld>(Law)</fld> <def>Rising or
having risen from rest; -- said of cattle. See <cref>Couchant and
levant</cref>, under <er>Couchant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levant</ent><br/
<hw>Le*vant"</hw> <pr>(l<esl/*v<acr/nt")</pr>, <pos>n.</pos> <ety>[It.
<ets>levante</ets> the point where the sun rises, the east, the Levant,
fr. <ets>levare</ets> to raise, <ets>levarsi</ets> to rise: cf. F.
<ets>levant</ets>. See <er>Lever</er>.]</ety> <sn>1.</sn> <def>The
countries washed by the eastern part of the Mediterranean and its
contiguous waters.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A levanter (the wind so called).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levant</ent><br/
<hw>Le"vant</hw> <pr>(l<emac/"v<ait/nt; 277)</pr>, <pos>a.</pos>
<def>Eastern.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Forth rush the <qex>levant</qex> and the ponent winds.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levant</ent><br/
<hw>Le*vant"</hw> <pr>(l<esl/*v<acr/nt")</pr>, <pos>v. i.</pos>
<ety>[Cf. Sp. <ets>levantar</ets> to raise, go from one place to
another.]</ety> <def>To run away from one's debts; to decamp.</def>
<mark>[Colloq. Eng.]</mark> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 846 pr=VMG --></p>

<p><ent>Levanter</ent><br/
<hw>Le*vant"er</hw> <pr>(l<esl/*v<acr/nt"<etil/r)</pr>, <pos>n.</pos>
<ety>[From <er>Levant</er>, <pos>v.</pos>]</ety> <def>One who levants,
or decamps.</def> <mark>[Colloq. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levanter</ent><br/
<hw>Le*vant"er</hw>, <pos>n.</pos> <ety>[From <er>Levant</er>,
<pos>n.</pos>]</ety> <def>A strong easterly wind peculiar to the
Mediterranean.</def> <rj><au>W. H. Russell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levantine</ent><br/
<hw>Le*vant"ine</hw> <pr>(l<esl/*v<acr/nt"<icr/n <or/
l<ecr/v"<ait/nt*<imac/n; 277)</pr>, <pos>a.</pos> <ety>[F.
<ets>levantin</ets>, or It. <ets>levantino</ets>. See <er>Levant</er>,
<pos>n.</pos>]</ety> <def>Of or pertaining to the Levant.</def>
<rj><au>J. Spencer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levantine</ent><br/
<hw>Le*vant"ine</hw>, <pos>n.</pos> <sn>1.</sn> <def>A native or
inhabitant of the Levant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F. <ets>levantine</ets>, or It.
<ets>levantina</ets>.]</ety> <def>A stout twilled silk fabric, formerly
made in the Levant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levari facias</ent><br/
\'d8<hw>Le*va`ri fa"ci*as</hw> <pr>(l<esl/*v<amac/`r<isl/
f<amac/"sh<icr/*<acr/s)</pr> <pos>n.</pos> <ety>[Law L., cause to be
levied.]</ety> <def>A writ of execution at common law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levation</ent><br/
<hw>Le*va"tion</hw> <pr>(l<esl/*v<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>levatio</ets>.]</ety> <def>The act of raising; elevation;
upward motion, as that produced by the action of a <xex>levator</xex>
muscle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levator</ent><br/
<hw>Le*va"tor</hw> <pr>(l<esl/*v<amac/"t<ocr/r)</pr>, <pos>n.</pos>
<ety>[NL., fr. L. <ets>levare</ets> to raise. See <er>Lever</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>A muscle that
serves to raise some part, as the lip or the eyelid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surg.)</fld> <def>A surgical instrument used to
raise a depressed part of the skull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leve</ent><br/
<hw>Leve</hw> <pr>(l<emac/v)</pr>, <pos>a.</pos> <def>Dear. See
<er>Lief</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leve</ent><br/
<hw>Leve</hw>, <pos>n. & v.</pos> <def>Same as 3d & 4th
<er>Leave</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leve</ent><br/
<hw>Leve</hw>, <pos>v. i.</pos> <def>To live.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leve</ent><br/
<hw>Leve</hw>, <pos>v. t.</pos> <ety>[OE., fr. AS.
<ets>l<emac/fan</ets>, abbrev. fr. <ets>gel<emac/fan</ets>. See
<er>Believe</er>.]</ety> <def>To believe.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leve</ent><br/
<hw>Leve</hw>, <pos>v. t.</pos> <ety>[OE. <ets>leven</ets>, AS.
<ets>l<emac/fan</ets>, <ets>l<ymac/fan</ets>. See <er>Leave</er>
permission.]</ety> <def>To grant; -- used esp. in exclamations or
prayers followed by a dependent clause.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>leve</qex> all be well.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leveche</ent><br/
\'d8<hw>Le*ve"che</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. Cf.
<er>Lebeccio</er>.]</ety> <fld>(Meteor.)</fld> <def>A dry sirocco of
Spain.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Levee</ent><br/
<hw>Lev"ee</hw> <pr>(l<ecr/v"<esl/; <it>often</it> l<ecr/v*<emac/" in U.
S.)</pr>, <pos>n.</pos> <ety>[F. <ets>lever</ets>, fr. <ets>lever</ets>
to raise, <ets>se lever</ets> to rise. See <er>Lever</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>The act of rising.</def> <ldquo/
The sun's <xex>levee</xex>.<rdquo/ <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A morning assembly or reception of visitors, -- in
distinction from a <contr>soir<eacute/e</contr>, or evening assembly; a
<altname>matin<eacute/e</altname>; hence, also, any general or somewhat
miscellaneous gathering of guests, whether in the daytime or evening;
<as>as, the president's <ex>levee</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In England a ceremonious day reception, when attended by
both ladies and gentlemen, is called a
<stype>drawing-room</stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levee</ent><br/
<hw>Lev"ee</hw>, <pos>v. t.</pos> <def>To attend the levee or levees
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>levees</qex> all the great.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levee</ent><br/
<hw>Lev"ee</hw>, <pos>n.</pos> <ety>[F. <ets>lev<eacute/e</ets>, fr.
<ets>lever</ets> to raise. See <er>Lever</er>, and cf.
<er>Levy</er>.]</ety> <def>An embankment to prevent inundation; <as>as,
the <ex>levees</ex> along the Mississippi</as>; sometimes, the steep
bank of a river.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levee</ent><br/
<hw>Lev"ee</hw>, <pos>v. t.</pos> <def>To keep within a channel by means
of levees; <as>as, to <ex>levee</ex> a river</as>.</def> <mark>[U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levee en masse</ent><br/
\'d8<hw>Le*v<eacute/e" en` masse"</hw> <pr>(l<eit/*v<asl/" <aum/N`
m<adot/s")</pr> <pos>n.</pos> <ety>[F.]</ety> <def>See <cref>Levy in
mass</cref>, under <er>Levy</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leveful</ent><br/
<hw>Leve"ful</hw> <pr>(l<emac/v"f<usdot/l)</pr>, <pos>a.</pos>
<ety>[<ets>Leve</ets>, <pos>n.</pos> + <ets>-ful</ets>.]</ety>
<def>Allowable; permissible; lawful.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Level</ent><br/
<hw>Lev"el</hw> <pr>(l<ecr/v"<ecr/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>level</ets>, <ets>livel</ets>, OF. <ets>livel</ets>, F.
<ets>niveau</ets>, fr. L. <ets>libella</ets> level, water level, a plumb
level, dim. of <ets>libra</ets> pound, measure for liquids, balance,
water poise, level. Cf. <er>Librate</er>, <er>Libella</er>.]</ety>
<sn>1.</sn> <def>A line or surface to which, at every point, a vertical
or plumb line is perpendicular; a line or surface which is everywhere
parallel to the surface of still water; -- this is the <xex>true
level</xex>, and is a curve or surface in which all points are equally
distant from the center of the earth, or rather would be so if the earth
were an exact sphere.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A horizontal line or plane; that is, a straight line
or a plane which is tangent to a true level at a given point and hence
parallel to the horizon at that point; -- this is the <xex>apparent
level</xex> at the given point.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An approximately horizontal line or surface at a
certain degree of altitude, or distance from the center of the earth;
<as>as, to climb from the <ex>level</ex> of the coast to the
<ex>level</ex> of the plateau and then descend to the <ex>level</ex> of
the valley or of the sea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After draining of the <qex>level</qex> in Northamptonshire.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Shot from the deadly <qex>level</qex> of a gun.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence, figuratively, a certain position, rank,
standard, degree, quality, character, etc., conceived of as in one of
several planes of different elevation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Providence, for the most part, sets us on a <qex>level</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Somebody there of his own <qex>level</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be the fair <qex>level</qex> of thy actions laid<br/
As temperance wills and prudence may persuade.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A uniform or average height; a normal plane or
altitude; a condition conformable to natural law or which will secure a
level surface; <as>as, moving fluids seek a
<ex>level</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When merit shall find its <qex>level</qex>.</q> <rj><qau>F. W.
Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mech. & Surv.)</fld> <sd>(a)</sd> <def>An
instrument by which to find a horizontal line, or adjust something with
reference to a horizontal line.</def> <sd>(b)</sd> <def>A measurement of
the difference of altitude of two points, by means of a level; <as>as,
to take a <ex>level</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A horizontal passage, drift, or adit, in a
mine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Air level</b></col>, <col><b>a spirit
level</b></col></mcol>. <cd>See <cref>Spirit level</cref> (below).</cd>
-- <col><b>Box level</b></col>, <cd>a spirit level in which a
glass-covered box is used instead of a tube.</cd> --
<mcol><col><b>Carpenter's level</b></col>, <col><b>Mason's
level</b></col></mcol>, <cd>either the <xex>plumb level</xex> or a
straight bar of wood, in which is imbedded a small spirit level.</cd> --
<col><b>Level of the sea</b></col>, <cd>the imaginary level from which
heights and depths are calculated, taken at a mean distance between high
and low water.</cd> -- <col><b>Line of levels</b></col>, <cd>a connected
series of measurements, by means of a level, along a given line, as of a
railroad, to ascertain the profile of the ground.</cd> -- <col><b>Plumb
level</b></col>, <cd>one in which a horizontal bar is placed in true
position by means of a plumb line, to which it is at right angles.</cd>
-- <col><b>Spirit level</b></col>, <cd>one in which the adjustment to
the horizon is shown by the position of a bubble in alcohol or ether
contained in a nearly horizontal glass tube, or a circular box with a
glass cover.</cd> -- <col><b>Surveyor's level</b></col>, <cd>a
telescope, with a spirit level attached, and with suitable screws, etc.,
for accurate adjustment, the whole mounted on a tripod, for use in
leveling; -- called also <altname>leveling instrument</altname>.</cd> --
<col><b>Water level</b></col>, <cd>an instrument to show the level by
means of the surface of water in a trough, or in upright tubes connected
by a pipe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Level</ent><br/
<hw>Lev"el</hw> <pr>(l<ecr/v"<ecr/l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Even; flat; having no part higher than another; having, or
conforming to, the curvature which belongs to the undisturbed liquid
parts of the earth's surface; <as>as, a <ex>level</ex> field;
<ex>level</ex> ground; the <ex>level</ex> surface of a pond or
lake.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ample spaces o'er the smooth<br/
And <qex>level</qex> pavement.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Coinciding or parallel with the plane of the
horizon; horizontal; <as>as, the telescope is now
<ex>level</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Even with anything else; of the same height; on the
same line or plane; on the same footing; of equal importance; --
followed by <xex>with</xex>, sometimes by <xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Young boys and girls<br/
Are <qex>level</qex> now with men; the odds is gone.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Everything lies <qex>level</qex> to our wish.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Straightforward; direct; clear; open.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A very plain and <qex>level</qex> account.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Well balanced; even; just; steady; impartial;
<as>as, a <ex>level</ex> head; a <ex>level</ex> understanding.
<mark>[Colloq.]</mark> </as></def> <ldquo/ A <xex>level</xex>
consideration.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Phonetics)</fld> <def>Of even tone; without rising
or falling inflection.</def> <rj><au>H. Sweet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Level line</b></col> <fld>(Shipbuilding)</fld>, <cd>the
outline of a section which is horizontal crosswise, and parallel with
the rabbet of the keel lengthwise.</cd> -- <col><b>Level
surface</b></col> <fld>(Physics)</fld>, <cd>an equipotential surface at
right angles at every point to the lines of force.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Level</ent><br/
<hw>Lev"el</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Leveled</conjf> <pr>(-<ecr/ld)</pr> or <conjf>Levelled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Leveling</conjf> or
<conjf>Levelling</conjf>.]</vmorph> <sn>1.</sn> <def>To make level; to
make horizontal; to bring to the condition of a level line or surface;
hence, to make flat or even; <as>as, to <ex>level</ex> a road, a walk,
or a garden</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring to a lower level; to overthrow; to topple
down; to reduce to a flat surface; to lower.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And their proud structures <qex>level</qex> with the ground.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>levels</qex> mountains and he raises plains.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bring to a horizontal position, as a gun; hence,
to point in taking aim; to aim; to direct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bertram de Gordon, standing on the castle wall, <qex>leveled</qex>
a quarrel out of a crossbow.</q> <rj><qau>Stow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Figuratively, to bring to a common level or plane,
in respect of rank, condition, character, privilege, etc.; <as>as, to
<ex>level</ex> all the ranks and conditions of men</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To adjust or adapt to a certain level; <as>as, to
<ex>level</ex> remarks to the capacity of children</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For all his mind on honor fixed is,<br/
To which he <qex>levels</qex> all his purposes.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Level</ent><br/
<hw>Lev"el</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be level; to be on
a level with, or on an equality with, something; hence, to accord; to
agree; to suit.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With such accommodation and besort<br/
As <qex>levels</qex> with her breeding.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To aim a gun, spear, etc., horizontally; hence, to
aim or point a weapon in direct line with the mark; fig., to direct the
eye, mind, or effort, directly to an object; <as>as, he <ex>leveled</ex>
a gun at the bandit and fired</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The foeman may with as great aim <qex>level</qex> at the edge of a
penknife.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The glory of God and the good of his church . . . ought to be the
mark whereat we also <qex>level</qex>.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>leveled</qex> at our purposes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leveler</ent><br/
<hw>Lev"el*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <ety>[Written also
<ets>leveller</ets>.]</ety> <sn>1.</sn> <def>One who, or that which,
levels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who would remove social inequalities or
distinctions; a socialist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>levelheaded</ent><br/
<hw>lev"el*head"ed</hw> <pos>a.</pos> <def>exercising or showing good
judgment or common sense; sensible.</def><br/
<syn><b>Syn. --</b> healthy, intelligent, sound.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>lev"el*head"ed*ly</wf>, <pos>adv.</pos> --
<wf>lev"el*head"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>PJC</source>]</p>

<p><ent>Leveling</ent><br/
<hw>Lev"el*ing</hw>, <pos>n.</pos> <ety>[Written also
<ets>levelling</ets>.]</ety> <sn>1.</sn> <def>The act or operation of
making level.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surveying)</fld> <def>The art or operation of using
a leveling instrument for finding a horizontal line, for ascertaining
the differences of level between different points of the earth's surface
included in a survey, for establishing grades, etc., as in finding the
descent of a river, or locating a line of railroad.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leveling instrument</b></col>. <cd>See <cref>Surveyor's
level</cref>, under <er>Level</er>, <pos>n.</pos></cd> --
<col><b>Leveling staff</b></col>, <cd>a graduated rod or staff used in
connection with a leveling instrument for measuring differences of level
between points.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levelism</ent><br/
<hw>Lev"el*ism</hw> <pr>(-<icr/z'm)</pr>, <pos>n.</pos> <def>The
disposition or endeavor to level all distinctions of rank in
society.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levelly</ent><br/
<hw>Lev"el*ly</hw>, <pos>adv.</pos> <def>In an even or level
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levelness</ent><br/
<hw>Lev"el*ness</hw>, <pos>n.</pos> <def>The state or quality of being
level.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leven</ent><br/
<hw>Lev"en</hw> <pr>(l<ecr/v"<eit/n)</pr>, <pos>n.</pos> <ety>[See
<er>Levin</er>.]</ety> <def>Lightning.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wild thunder dint and fiery <qex>leven</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lever</ent><br/
<hw>Lev"er</hw> <pr>(l<emac/"v<etil/r)</pr>, <pos>a.</pos> <ety>[Old
compar. of <ets>leve</ets> or <ets>lief</ets>.]</ety> <def>More
agreeable; more pleasing.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be lever than</b></col>. <cd>See <cref>Had as
lief</cref>, under <er>Had</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lever</ent><br/
<hw>Lev"er</hw>, <pos>adv.</pos> <def>Rather.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For <qex>lever</qex> had I die than see his deadly face.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lever</ent><br/
<hw>Le"ver</hw> <pr>(l<emac/"v<etil/r <or/ l<ecr/v"<etil/r; 277)</pr>,
<pos>n.</pos> <ety>[OE. <ets>levour</ets>, OF. <ets>leveor</ets>, prop.,
a lifter, fr. F. <ets>lever</ets> to raise, L. <ets>levare</ets>; akin
to <ets>levis</ets> light in weight, E. <ets>levity</ets>, and perh. to
E. <ets>light</ets> not heavy: cf. F. <ets>levier</ets>. Cf.
<er>Alleviate</er>, <er>Elevate</er>, <er>Leaven</er>,
<er>Legerdemain</er>, <er>Levee</er>, <er>Levy</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <fld>(Mech.)</fld> <def>A rigid piece
which is capable of turning about one point, or axis (the fulcrum), and
in which are two or more other points where forces are applied; -- used
for transmitting and modifying force and motion. Specif., a bar of
metal, wood, or other rigid substance, used to exert a pressure, or
sustain a weight, at one point of its length, by receiving a force or
power at a second, and turning at a third on a fixed point called a
<xex>fulcrum</xex>. It is usually named as the first of the six
mechanical powers, and is of three kinds, according as either the
<xex>fulcrum</xex> F, the <xex>weight</xex> W, or the <xex>power</xex>
P, respectively, is situated between the other two, as in the
figures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>A bar, as a capstan
bar, applied to a rotatory piece to turn it.</def> <sd>(b)</sd> <def>An
arm on a rock shaft, to give motion to the shaft or to obtain motion
from it.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Compound lever</b></col>, <cd>a machine consisting of two
or more levers acting upon each other.</cd> -- <col><b>Lever
escapement</b></col>. <cd>See <er>Escapement</er>.</cd> -- <col><b>Lever
jack</b></col>. <cd>See <er>Jack</er>, <pos>n.</pos>, 5.</cd> --
<col><b>Lever watch</b></col>, <cd>a watch having a vibrating lever to
connect the action of the escape wheel with that of the balance.</cd> --
<col><b>Universal lever</b></col>, <cd>a machine formed by a combination
of a lever with the wheel and axle, in such a manner as to convert the
reciprocating motion of the lever into a continued rectilinear motion of
some body to which the power is applied.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leverage</ent><br/
<hw>Lev"er*age</hw> <pr>(l<ecr/v"<etil/r*<asl/j <or/
l<emac/"v<etil/r*<asl/j)</pr>, <pos>n.</pos> <def>The action of a lever;
mechanical advantage gained by the lever.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Leverage of a couple</b></col> <fld>(Mech.)</fld>,
<cd>the perpendicular distance between the lines of action of two forces
which act in parallel and opposite directions.</cd> -- <col><b>Leverage
of a force</b></col>, <cd>the perpendicular distance from the line in
which a force acts upon a body to a point about which the body may be
supposed to turn.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leveret</ent><br/
<hw>Lev"er*et</hw> <pr>(l<ecr/v"<etil/r*<ecr/t)</pr>, <pos>n.</pos>
<ety>[F. <ets>levraut</ets>, dim. of <ets>li<egrave/vre</ets> hare, L.
<ets>lepus</ets>. Cf. <er>Leporine</er>.]</ety> <fld>(Zool.)</fld>
<def>A hare in the first year of its age.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leverock</ent><br/
<hw>Lev"er*ock</hw> <pr>(-<ocr/k)</pr>, <pos>n.</pos> <ety>[See
<er>Lark</er>.]</ety> <def>A lark.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leverwood</ent><br/
<hw>Lev"er*wood`</hw> <pr>(l<ecr/v"<etil/r*w<oocr/d`)</pr>,
<pos>n.</pos> <fld>(Bot.)</fld> <def>The American hop hornbeam
(<spn>Ostrya Virginica</spn>), a small tree with very tough
wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levesel</ent><br/
<hw>Lev"e*sel</hw> <pr>(l<ecr/v"<esl/*s<ecr/l)</pr>, <pos>n.</pos>
<ety>[AS. <ets>le<aacute/f</ets> a leaf + <ets>s<ae/l</ets>,
<ets>sel</ets>, a room, a hall.]</ety> <def>A leafy shelter; a place
covered with foliage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Behind the mill, under a <qex>levesel</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levet</ent><br/
<hw>Lev"et</hw> <pr>(l<ecr/v"<ecr/t)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lever</ets> to raise.]</ety> <def>A trumpet call for rousing
soldiers; a reveille.</def> <mark>[Obs.]</mark>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leviable</ent><br/
<hw>Lev"i*a*ble</hw> <pr>(l<ecr/v"<icr/*<adot/*b'l)</pr>, <pos>a.</pos>
<ety>[From <er>Levy</er> to assess.]</ety> <def>Fit to be levied;
capable of being assessed and collected; <as>as, sums <ex>leviable</ex>
by course of law</as>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leviathan</ent><br/
<hw>Le*vi"a*than</hw> <pr>(l<esl/*v<imac/"<adot/*th<ait/n)</pr>,
<pos>n.</pos> <ety>[Heb. <ets>livy<amac/th<amac/n</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An aquatic animal, described in the book of Job, ch.
xli., and mentioned in other passages of Scripture.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is not certainly known what animal is intended,
whether the crocodile, the whale, or some sort of serpent.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The whale, or a great whale.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levier</ent><br/
<hw>Lev"i*er</hw> <pr>(l<ecr/v"<icr/*<etil/r)</pr>, <pos>n.</pos>
<def>One who levies.</def> <rj><au>Cartwright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levigable</ent><br/
<hw>Lev"i*ga*ble</hw> <pr>(l<ecr/v"<icr/*g<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[See <er>Levigate</er>, <pos>v. t.</pos>]</ety>
<def>Capable of being levigated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levigate</ent><br/
<hw>Lev"i*gate</hw> <pr>(-g<asl/t)</pr>, <pos>a.</pos> <ety>[L.
<ets>levigatus</ets>, p. p. of <ets>levigare</ets> to lighten, fr.
<ets>l<ecr/vis</ets> light.]</ety> <def>Made less harsh or burdensome;
alleviated.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levigate</ent><br/
<hw>Lev"i*gate</hw> <pr>(-g<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Levigated</conjf>
<pr>(-g<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Levigating</conjf>.]</vmorph> <ety>[L. <ets>levigatus</ets>, p.
p. of <ets>levigare</ets> to make smooth, fr. <ets>l<emac/vis</ets>
smooth; akin to Gr. <grk>lei^os</grk>.]</ety> <def>To make smooth in
various senses</def>: <sd>(a)</sd> <def>To free from grit; to reduce to
an impalpable powder or paste.</def> <sd>(b)</sd> <def>To mix
thoroughly, as liquids or semiliquids.</def> <sd>(c)</sd> <def>To
polish.</def> <sd>(d)</sd> <def>To make smooth in action.</def> <ldquo/
When use hath <xex>levigated</xex> the organs.<rdquo/ <au>Barrow.</au>
<sd>(e)</sd> <def>Technically, to make smooth by rubbing in a moist
condition between hard surfaces, as in grinding pigments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levigate</ent><br/
<hw>Lev"i*gate</hw> <pr>(-g<asl/t)</pr>, <pos>a.</pos> <ety>[L.
<ets>levigatus</ets>, <ets>p. p.</ets>]</ety> <def>Made smooth, as if
polished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levigation</ent><br/
<hw>Lev`i*ga"tion</hw> <pr>(l<ecr/v`<icr/*g<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>levigatio</ets> a smoothing: cf. F.
<ets>l<eacute/vigation</ets>.]</ety> <def>The act or operation of
levigating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levin</ent><br/
<hw>Lev"in</hw> <pr>(l<ecr/v"<icr/n)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain. Cf. <er>Leven</er>.]</ety> <def>Lightning.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Levin brand</b></col>, <cd>a thunderbolt.</cd>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leviner</ent><br/
<hw>Lev"in*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A swift hound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levir</ent><br/
<hw>Le"vir</hw> <pr>(l<emac/"v<etil/r)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <def>A husband's brother; -- used in reference to
levirate marriages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leviratical</ent><br/
<ent>Levirate</ent><br/
<mhw>{ <hw>Lev"i*rate</hw> <pr>(l<ecr/v"<icr/*r<asl/t)</pr>,
<hw>Lev`i*rat"ic*al</hw> <pr>(-r<acr/t"<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>levir</ets> a husband's brother,
brother-in-law; akin to Gr. <grk>dah`r</grk>: cf. F.
<ets>l<eacute/virat</ets> leviration.]</ety> <def>Of, pertaining to, or
in accordance with, a law of the ancient Israelites and other tribes and
races, according to which a woman, whose husband died without issue, was
married to the husband's brother.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The firstborn son of a <qex>leviratical</qex> marriage was
reckoned and registered as the son of the deceased brother.</q>
<rj><qau>Alford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leviration</ent><br/
<hw>Lev`i*ra"tion</hw> <pr>(l<ecr/v`<icr/*r<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>Levirate marriage or marriages.</def>
<rj><au>Kitto.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levirostres</ent><br/
\'d8<hw>Lev`i*ros"tres</hw> <pr>(-r<ocr/s"tr<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. L. <ets>levis</ets> light + <ets>rostrum</ets>
beak.]</ety> <fld>(Zool.)</fld> <def>A group of birds, including the
hornbills, kingfishers, and related forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levitate</ent><br/
<hw>Lev"i*tate</hw> <pr>(l<ecr/v"<icr/*t<amac/t)</pr>, <pos>v. i.</pos>
<ety>[L. <ets>levitas</ets>, <ets>-atis</ets>, lightness. See
<er>Levity</er>.]</ety> <def>To rise, or tend to rise, as if lighter
than the surrounding medium; to become buoyant; -- opposed to
<ant>gravitate</ant>.</def> <rj><au>Sir. J. Herschel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levitate</ent><br/
<hw>Lev"i*tate</hw>, <pos>v. t.</pos> <fld>(Spiritualism)</fld> <def>To
make buoyant; to cause to float in the air; <as>as, to <ex>levitate</ex>
a table</as>.</def> <mark>[Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levitation</ent><br/
<hw>Lev`i*ta"tion</hw> <pr>(-t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>levis</ets> light in weight.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Lightness; buoyancy; act of making light.</def>
<rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or process of making buoyant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levite</ent><br/
<hw>Le"vite</hw> <pr>(l<emac/"v<imac/t)</pr>, <pos>n.</pos> <ety>[L.
<ets>Levites</ets>, Gr. <grk>Leyi:`ths</grk>, fr. Heb. <ets>Levi</ets>,
one of the sons of Jacob.]</ety> <sn>1.</sn> <fld>(Bib. Hist.)</fld>
<def>One of the tribe or family of Levi; a descendant of Levi; esp., one
subordinate to the priests (who were of the same tribe) and employed in
various duties connected with the tabernacle first, and afterward the
temple, such as the care of the building, bringing of wood and other
necessaries for the sacrifices, the music of the services,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A priest; -- so called in contempt or
ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 847 pr=VMG --></p>

<p><ent>Levitical</ent><br/
<hw>Le*vit"ic*al</hw> <pr>(l<esl/*v<icr/t"<icr/*k<ait/l)</pr>,
<pos>a.</pos> <ety>[L. <ets>Leviticus</ets>, Gr.
<grk>Leyitiko`s</grk>.]</ety> <sn>1.</sn> <def>Of or pertaining to a
Levite or the Levites.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Priestly.</def> <ldquo/ <xex>Levitical</xex>
questions.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to, or designating, the law
contained in the book of Leviticus.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Levitical degrees</b></col>, <cd>degrees of relationship
named in Leviticus, within which marriage is forbidden.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levitically</ent><br/
<hw>Le*vit"ic*al*ly</hw>, <pos>adv.</pos> <def>After the manner of the
Levites; in accordance with the levitical law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leviticus</ent><br/
<hw>Le*vit"i*cus</hw> <pr>(-<icr/*k<ucr/s)</pr>, <pos>n.</pos> <ety>[See
<er>Levitical</er>.]</ety> <def>The third canonical book of the Old
Testament, containing the laws and regulations relating to the priests
and Levites among the Hebrews, or the body of the ceremonial
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levity</ent><br/
<hw>Lev"i*ty</hw> <pr>(l<ecr/v"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<ety>[L. <ets>levitas</ets>, fr. <ets>levis</ets> light in weight; akin
to <ets>levare</ets> to raise. See <er>Lever</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>The quality of weighing less than something else of
equal bulk; relative lightness, especially as shown by rising through,
or floating upon, a contiguous substance; buoyancy; -- opposed to
<ant>gravity</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He gave the form of <qex>levity</qex> to that which ascended; to
that which descended, the form of gravity.</q> <rj><qau>Sir. W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This bubble by reason of its comparative <qex>levity</qex> to the
fluidity that incloses it, would ascend to the top.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lack of gravity and earnestness in deportment or
character; trifling gayety; frivolity; sportiveness; vanity.</def>
<ldquo/ A spirit of <xex>levity</xex> and libertinism.<rdquo/
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He never employed his omnipotence out of <qex>levity</qex>.</q>
<rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lack of steadiness or constancy; disposition to
change; fickleness; volatility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>levity</qex> that is fatigued and disgusted with
everything of which it is in possession.</q>
<rj><qau>Burke.</qau></rj></p>

<p><syn><b>Syn.</b> -- Inconstancy; thoughtlessness; unsteadiness;
inconsideration; volatility; flightiness.</syn> <usage> --
<er>Levity</er>, <er>Volatility</er>, <er>Flightiness</er>. All these
words relate to outward conduct. <xex>Levity</xex> springs from a
lightness of mind which produces a disregard of the proprieties of time
and place.<xex>Volatility</xex> is a degree of levity which causes the
thoughts to fly from one object to another, without resting on any for a
moment. <xex>Flightiness</xex> is volatility carried to an extreme which
often betrays its subject into gross impropriety or weakness.
<xex>Levity</xex> of deportment, of conduct, of remark;
<xex>volatility</xex> of temper, of spirits; <xex>flightiness</xex> of
mind or disposition.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levo-</ent><br/
<hw>Le"vo-</hw> <pr>(l<emac/"v<osl/-)</pr> <pos>pref.</pos> <def>A
prefix from L. <ets>laevus</ets></def>, meaning: <sd>(a)</sd>
<def><it>Pertaining to, or toward, the left</it>; <as>as,
<ex>levo</ex>rotatory</as>.</def> <sd>(b)</sd> <fld>(Chem. & Opt.)</fld>
<def><it>Turning the plane of polarized light to the left</it>; <as>as,
<ex>levo</ex>tartaric acid; <ex>levo</ex>racemic acid;
<ex>levo</ex>gyratory crystals, etc.</as></def> <altsp>[Written also
<asp>l<ae/vo-</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>levodopa</ent><br/
<hw>le`vo*do"pa</hw> <pr>(l<emac/`v<osl/*d<omac/"p<adot/)</pr>,
<pos>a.</pos> <ety>[<ets>Levo-</ets> + <ets>DOPA</ets>,
<ets>d</ets>ihydr<ets>o</ets>xy<ets>p</ets>henyl<ets>a</ets>lanine.]</ety>
<fld>(Chem. & Biochem.)</fld> <def>A substance used as a therapy for
<er>Parkinson's Disease</er>; the L form of Dopa;
L-dihydroxyphenylalanine; L-hydroxytyrosine (<chform>C9H11NO4</chform>);
also called <altname>L-dopa</altname>. In the body it is converted by
the enzyme dopa-decarboxylase into <cnvto>dopamine</cnvto>, the form in
which it is active in the brain, affecting neural impulse
transmission.</def><br/
[<source>PJC</source>]</p>

<p><ent>Levogyrate</ent><br/
<hw>Le`vo*gy"rate</hw> <pr>(-j<imac/"r<asl/t)</pr>, <pos>a.</pos>
<ety>[<ets>Levo-</ets> + <ets>gyrate</ets>.]</ety> <fld>(Chem., Physics,
Biochem.)</fld> <def>Turning or twisting the plane of polarization of
light towards the left, as levulose, levotartaric acid, etc.;
levorotatory.</def> <altsp>[Written also
<asp>l<ae/vogyrate</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>levorotary</ent><br/
<hw>le`vo*ro"ta*ry</hw> <pr>(-r<omac/"t<adot/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[<ets>Levo-</ets> + <ets>rotary</ets>.]</ety>
<fld>(Chem. & Physics)</fld> <def>Same as
<er>levorotatory</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Levorotation</ent><br/
<hw>Le`vo*ro*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written
also <asp>l<ae/vorotation</asp>.]</altsp> <ety>[<ets>Levo-</ets> +
<ets>rotation</ets>.]</ety> <fld>(Physics & Chem.)</fld> <def>Rotation
in the direction of an outgoing right-handed screw; counter-clockwise
rotation; -- applied chiefly to the turning of the plane of polarization
of light.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Levorotatory</ent><br/
<hw>Le`vo*ro"ta*to*ry</hw> <pr>(-r<omac/"t<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[<ets>Levo-</ets> + <ets>rotatory</ets>.]</ety>
<fld>(Chem. & Physics)</fld> <def>Turning or rotating the plane of
polarization of light towards the left; -- applied to crystals and
compounds exhibiting optical activity, such as levulose, left-handed
quartz crystals, etc. Opposite of <ant>dextrorotatory</ant>.</def>
<altsp>[Written also <asp>l<ae/vorotatory</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Levulin</ent><br/
<hw>Lev"u*lin</hw> <pr>(l<ecr/v"<usl/*l<icr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A substance resembling dextrin, obtained from
the bulbs of the dahlia, the artichoke, and other sources, as a
colorless, spongy, amorphous material. It is so called because by
decomposition it yields <xex>levulose</xex>.</def> <altsp>[Written also
<asp>l<ae/vulin</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levulinic</ent><br/
<hw>Lev`u*lin"ic</hw> <pr>(-l<icr/n"<icr/k)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Pertaining to, or denoting, an acid (called also
<altname>acetyl-propionic</altname> <xex>acid</xex>),
<chform>C5H8O3</chform>, obtained by the action of dilute acids on
various sugars (as levulose).</def> <altsp>[Written also
<asp>laevulinic</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levulosan</ent><br/
<hw>Lev`u*lo"san</hw> <pr>(-l<omac/"s<ait/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>An unfermentable carbohydrate obtained by gently
heating levulose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levulose</ent><br/
<hw>Lev"u*lose`</hw> <pr>(l<ecr/v"<usl/*l<omac/s`)</pr>, <pos>n.</pos>
<ety>[See <er>Levo-</er>.]</ety> <fld>(Chem.)</fld> <def>A sirupy
variety of sugar, rarely obtained crystallized, occurring widely in
honey, ripe fruits, etc., and hence called also <altname>fruit
sugar</altname>; also called <altname>fructose</altname>. Chemical
formula: <chform>C6H12O6</chform>. It is called <xex>levulose</xex>,
because it rotates the plane of polarization of light to the left, in
contrast to <contr>dextrose</contr>, the other product of the hydrolysis
of sucrose.</def> <altsp>[Written also
<asp>laevulose</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ It is obtained, together with an equal quantity of
dextrose, by the inversion of ordinary cane or beet sugar, and hence, as
being an ingredient of <xex>invert sugar</xex>, is often so called. It
is fermentable, nearly as sweet as cane sugar, and is metameric with
dextrose. Cf. <er>Dextrose</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levy</ent><br/
<hw>Lev"y</hw> <pr>(-<ycr/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Levies</plw> <pr>(-<icr/z)</pr>.</plu> <ety>[A contr. of
<ets>elevenpence</ets> or <ets>elevenpenny bit</ets>.]</ety> <def>A name
formerly given in Pennsylvania, Maryland, and Virginia to the Spanish
real of one eighth of a dollar (or 12<frac12/ cents), valued at eleven
pence when the dollar was rated at 7s. 6d.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levy</ent><br/
<hw>Lev"y</hw>, <pos>n.</pos> <ety>[F. <ets>lev<eacute/e</ets>, fr.
<ets>lever</ets> to raise. See <er>Lever</er>, and cf.
<er>Levee</er>.]</ety> <sn>1.</sn> <def>The act of levying or collecting
by authority; <as>as, the <ex>levy</ex> of troops, taxes,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>levy</qex> of all the men left under sixty.</q>
<rj><qau>Thirlwall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is levied, as an army, force, tribute,
etc.</def> <ldquo/ The Irish <xex>levies</xex>.<rdquo/
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The taking or seizure of property
on executions to satisfy judgments, or on warrants for the collection of
taxes; a collecting by execution.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Levy in mass</b></col> <ety>[F. <ets>lev<eacute/e en
masse</ets>]</ety>, <cd>a requisition of all able-bodied men for
military service.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levy</ent><br/
<hw>Lev"y</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Levied</conjf> <pr>(l<ecr/v"<icr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Levying</conjf>.]</vmorph> <sn>1.</sn> <def>To raise, as
a siege.</def> <mark>[Obs.]</mark> <au>Holland.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To raise; to collect; said of troops, to form into
an army by enrollment, conscription, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Augustine . . . inflamed Ethelbert, king of Kent, to
<qex>levy</qex> his power, and to war against them.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To raise or collect by assessment; to exact by
authority; <as>as, to <ex>levy</ex> taxes, toll, tribute, or
contributions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If they do this . . . my ransom, then,<br/
Will soon be <qex>levied</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>To gather or exact;
<as>as, to <ex>levy</ex> money</as>.</def> <sd>(b)</sd> <def>To erect,
build, or set up; to make or construct; to raise or cast up; <as>as, to
<ex>levy</ex> a mill, dike, ditch, a nuisance, etc.</as></def>
<mark>[Obs.]</mark> <au>Cowell.</au> <au>Blackstone.</au> <sd>(c)</sd>
<def>To take or seize on execution; to collect by execution.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To levy a fine</b></col>, <cd>to commence and carry on a
suit for assuring the title to lands or tenements.</cd>
<au>Blackstone.</au> -- <col><b>To levy war</b></col>, <cd>to make or
begin war; to take arms for attack; to attack.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levy</ent><br/
<hw>Lev"y</hw>, <pos>v. i.</pos> <def>To seize property, real or
personal, or subject it to the operation of an execution; to make a
levy; <as>as, to <ex>levy</ex> on property; the usual mode of
<ex>levying</ex>, in England, is by seizing the goods.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To levy on goods and chattels</b></col>, <cd>to take into
custody or seize specific property in satisfaction of a
writ.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Levynite</ent><br/
<ent>Levyne</ent><br/
<mhw>{ <hw>Lev"yne</hw> <pr>(l<ecr/v"<icr/n)</pr>, <hw>Lev"yn*ite</hw>
<pr>(-<icr/n*<imac/t)</pr>, }</mhw> <pos>n.</pos> <ety>[From Mr.
<ets>Levy</ets>, an English mineralogist.]</ety> <fld>(Min.)</fld>
<def>A whitish, reddish, or yellowish, transparent or translucent
mineral, allied to chabazite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lew</ent><br/
<hw>Lew</hw> <pr>(l<umac/)</pr>, <pos>a.</pos> <ety>[Cf. <ets>lee</ets>
a calm or sheltered place, <ets>luke</ets>warm.]</ety> <def>Lukewarm;
tepid.</def> <mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lewd</ent><br/
<hw>Lewd</hw> <pr>(l<umac/d)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Lewder</adjf> <pr>(-<etil/r)</pr>;
<pos>superl.</pos> <adjf>Lewdest</adjf>.]</amorph> <ety>[<er>OE</er>.
<ets>lewed</ets>, <ets>lewd</ets>, lay, ignorant, vile, AS.
<ets>l<aemac/wed</ets> laical, belonging to the laity.]</ety>
<sn>1.</sn> <def>Not clerical; laic; laical; hence, unlearned;
simple.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For if a priest be foul, on whom we trust,<br/
No wonder is a <qex>lewed</qex> man to rust.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So these great clerks their little wisdom show<br/
To mock the <qex>lewd</qex>, as learn'd in this as they.</q>
<rj><qau>Sir. J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Belonging to the lower classes, or the rabble; idle
and lawless; bad; vicious.</def> <mark>[Archaic]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But the Jews, which believed not, . . . took unto them certain
<qex>lewd</qex> fellows of the baser sort, . . . and assaulted the house
of Jason.</q> <rj><qau>Acts xvii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Too <qex>lewd</qex> to work, and ready for any kind of
mischief.</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Given to the promiscuous indulgence of lust;
dissolute; lustful; libidinous.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Suiting, or proceeding from, lustfulness; involving
unlawful sexual desire; <as>as, <ex>lewd</ex> thoughts, conduct, or
language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Lustful; libidinous; licentious; profligate;
dissolute; sensual; unchaste; impure; lascivious; lecherous; rakish;
debauched.</syn></p>

<p>-- <wordforms><wf>Lewd"ly</wf>, <pos>adv.</pos> --
<wf>Lewd"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lewdster</ent><br/
<hw>Lewd"ster</hw> <pr>(-st<etil/r)</pr>, <pos>n.</pos> <def>A lewd
person.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lewisson</ent><br/
<ent>Lewis</ent><br/
<mhw>{ <hw>Lew"is</hw> <pr>(l<umac/"<icr/s)</pr>, <hw>Lew"is*son</hw>
<pr>(-s<ucr/n)</pr>, }</mhw> <pos>n.</pos> <sn>1.</sn> <def>An iron
dovetailed tenon, made in sections, which can be fitted into a dovetail
mortise; -- used in hoisting large stones, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of shears used in cropping woolen
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lewis hole</b></col>, <cd>a hole wider at the bottom than
at the mouth, into which a <xex>lewis</xex> is fitted.</cd> <rj><au>De
Foe.</au></rj></cs></p>

<p><-- Lewis acid (Chem) A compound without dissociable hydrogen which
acts as an acid (bonding with Lewis bases) in chemical reaction. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lex</ent><br/
\'d8<hw>Lex</hw> <pr>(l<ecr/ks)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Leges</plw> <pr>(l<emac/"j<emac/z)</pr>.</plu> <ety>[L. See
<er>Legal</er>.]</ety> <def>Law; <as>as, <ex>lex talionis</ex>, the law
of retaliation; <ex>lex terr<ae/</ex>, the law of the land; <ex>lex
fori</ex>, the law of the forum or court; <ex>lex loci</ex>, the law of
the place; <ex>lex mercatoria</ex>, the law or custom of
merchants.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lexical</ent><br/
<hw>lex"ic*al</hw> <pr>(l<ecr/ks"<icr/*k<ait/l)</pr>, <pos>a.</pos>
<def>Of or pertaining to a lexicon, to lexicography, or words; according
or conforming to a lexicon.</def> -- <wordforms><wf>Lex"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lexicalize</ent><br/
<hw>lex"i*cal*ize</hw> <pr>(l<ecr/ks"<icr/*k<ait/l*<imac/z)</pr>,
<pos>v. t.</pos> <sn>1.</sn> <def>To make into a word, coin into a word;
<as>as, The concept expressed by German "Gemuetlichkeit" is not
<ex>lexicalized</ex> in English</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>To increase the importance of, or emphasis on, words
as opposed to other parts of a theory or program; -- said of grammatical
theories and computer programs, especially programs for understanding
language; <as>as, <ex>lexicalized</ex> tree-adjoining
grammar</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lexicographer</ent><br/
<hw>Lex`i*cog"ra*pher</hw>
<pr>(l<ecr/ks`<icr/*k<ocr/g"r<adot/*f<etil/r)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>lexikogra`fos</grk>; <grk>lexiko`n</grk> dictionary +
<grk>gra`fein</grk> to write: cf. F. <ets>lexicographe</ets>. See
<er>Lexicon</er>.]</ety> <def>The author or compiler of a lexicon or
dictionary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every other author may aspire to praise; the
<qex>lexicographer</qex> can only hope to escape reproach; and even this
negative recompense has been yet granted to very few.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexicographical</ent><br/
<ent>Lexicographic</ent><br/
<mhw>{ <hw>Lex`i*co*graph"ic</hw>
<pr>(l<ecr/ks`<icr/*k<osl/*gr<acr/f"<icr/k)</pr>,
<hw>Lex`i*co*graph"ic*al</hw>
<pr>(l<ecr/ks`<icr/*k<osl/*gr<acr/f"<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[Cf. F. <ets>lexicographi</ets>que.]</ety> <def>Of or
pertaining to, or according to, lexicography.</def> --
<wordforms><wf>Lex`i*co*graph"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexicographist</ent><br/
<hw>Lex`i*cog"ra*phist</hw>
<pr>(l<ecr/ks`<icr/*k<ocr/g"r<adot/*f<icr/st)</pr>, <pos>n.</pos> <def>A
lexicographer.</def> <mark>[R.]</mark> <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexicography</ent><br/
<hw>Lex`i*cog"ra*phy</hw>
<pr>(l<ecr/ks`<icr/*k<ocr/g"r<adot/*f<ycr/)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>lexicographie</ets>.]</ety> <def>The art, process, or
occupation of making a lexicon or dictionary; the principles which are
applied in making dictionaries; <as>as, with so many words
<ex>lexicography</ex> can be interesting in parts but at length is
rather tedious labor</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lexicologist</ent><br/
<hw>Lex`i*col"o*gist</hw>
<pr>(l<ecr/ks`<icr/*k<ocr/l"<osl/*j<icr/st)</pr>, <pos>n.</pos> <def>One
versed in lexicology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexicology</ent><br/
<hw>Lex`i*col"o*gy</hw> <pr>(l<ecr/ks`<icr/*k<ocr/l"<osl/*j<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>lexiko`n</grk> lexicon + <ets>-logy</ets>:
cf. F. <ets>lexicologie</ets>.]</ety> <def>The science of the derivation
and signification of words; that branch of learning which treats of the
signification and application of words.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexicon</ent><br/
<hw>Lex"i*con</hw> <pr>(l<ecr/ks"<icr/*k<ocr/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>lexiko`n</grk> (sc. <grk>bibli`on</grk>), neut. of
<grk>lexiko`s</grk> of or belonging to words, fr. <grk>le`xis</grk> a
speaking, speech, a way of speaking, a single word or phrase, fr.
<grk>le`gein</grk> to say, to speak. See <er>Legend</er>.]</ety> <def>A
vocabulary, or book containing an alphabetical arrangement of the words
in a language or of a considerable number of them, with the definition
of each; a dictionary; especially, a dictionary of the Greek, Hebrew, or
Latin language.</def> <-- also, a dictionary for use in computational
linguistics --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexiconist</ent><br/
<hw>Lex"i*con*ist</hw>, <pos>n.</pos> <def>A writer of a lexicon.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexigraphic</ent><br/
<hw>Lex`i*graph"ic</hw> <pr>(l<ecr/ks"<icr/*gr<acr/f"<icr/k)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>lexigraphique</ets>.]</ety> <def>Of or
pertaining to lexigraphy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexigraphy</ent><br/
<hw>Lex*ig"ra*phy</hw> <pr>(l<ecr/ks*<icr/g"r<adot/*f<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>le`xis</grk> word + <ets>-graphy</ets>: cf.
F. <ets>lexigraphie</ets>.]</ety> <def>The art or practice of defining
words; definition of words.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexiphanic</ent><br/
<hw>Lex`i*phan"ic</hw> <pr>(l<ecr/ks`<icr/*f<acr/n"<icr/k)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>lexifa`nis</grk> a phrase monger;
<grk>le`xis</grk> speech + <grk>fai`nein</grk> to show.]</ety>
<def>Using, or interlarded with, pretentious words; bombastic; <as>as, a
<ex>lexiphanic</ex> writer or speaker; <ex>lexiphanic</ex>
writing.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexiphanicism</ent><br/
<hw>Lex`i*phan"i*cism</hw>
<pr>(l<ecr/ks`<icr/*f<acr/n"<icr/*s<icr/z'm)</pr>, <pos>n.</pos>
<def>The use of pretentious words, language, or style.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lexipharmic</ent><br/
<hw>Lex`i*phar"mic</hw> <pr>(l<ecr/ks`<icr/*f<aum/r"m<icr/k)</pr>,
<pos>a.</pos> <def>See <er>Alexipharmic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ley</ent><br/
<hw>Ley</hw> <pr>(l<amac/)</pr>, <pos>v. t. & i.</pos> <def>To lay; to
wager.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ley</ent><br/
<hw>Ley</hw>, <pos>n.</pos> <ety>[OF.]</ety> <def>Law.</def>
<rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ley</ent><br/
<hw>Ley</hw> <pr>(l<imac/)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Lye</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ley</ent><br/
<hw>Ley</hw> <pr>(l<emac/)</pr>, <pos>n.</pos> <def>Grass or meadow
land; a lea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ley</ent><br/
<hw>Ley</hw>, <pos>a.</pos> <def>Fallow; unseeded.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leyden phial</ent><br/
<ent>Leyden jar</ent><br/
<mhw>{ <hw>Ley"den jar"</hw> <pr>(l<imac/"d'n j<aum/r"; 277)</pr>
<hw>Ley"den phi"al</hw> <pr>(f<imac/"<ait/l)</pr>.}</mhw> <pos>n.</pos>
<fld>(Elec.)</fld> <def>A glass jar or bottle used to accumulate
electricity. It is coated with tin foil, within and without, nearly to
its top, and is surmounted by a brass knob which communicates with the
inner coating, for the purpose of charging it with electricity. It is so
named from having been invented in <etsep>Leyden</etsep>,
Holland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Leymus</ent><br/
<hw>Leymus</hw> <pos>prop. n.</pos> <def>A genus that in some
classifications overlaps the genus <gen>Elymus</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Leymus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leyte</ent><br/
<hw>Leyte</hw> <pos>prop. n.</pos> <def>The name of an island in the
Pacific Ocean and of a battle in World War II, at which the American
forces experienced the first use of Kamikaze aircraft by the Japanese.
The return of U. S. troops to the Philippines after their expulsion by
the Japanese began with landings on Leyte Island in October
1944.</def><br/
<syn><b>Syn. --</b> Leyte Island, Leyte invasion, Battle of Leyte
Gulf.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Leyser</ent><br/
<hw>Ley"ser</hw> <pr>(l<amac/"z<etil/r)</pr>, <pos>n.</pos>
<def>Leisure.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lese majesty</ent><br/
<ent>Leze majesty</ent><br/
<mhw><hw>Lese` maj"es*ty</hw>, <hw>Leze` maj"es*ty</hw></mhw>
<pr>(l<emac/z` m<acr/j"<ecr/s*t<ycr/)</pr> <pos>n.</pos> <ety>[F.
<ets>lese-majest<eacute/</ets>, fr. L. <ets>laesus</ets>, fem.
<ets>laesa</ets>, injured (see <er>Lesion</er>) + <ets>majestas</ets>
majesty; that is, <ets>crimen laesae majestatis</ets>.]</ety>
<altsp>[Written also <asp>l<egrave/se majesty</asp>.]</altsp>
<sn>1.</sn> <fld>(Law)</fld> <def>Any crime committed against the
sovereign power, or against a ruler.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any affront to the dignity of an eminent or
respected person.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>An attack against an institution or custom revered
by the majority in a society.</def><br/
[<source>PJC</source>]</p>

<p><ent>LF</ent><br/
<hw>LF</hw> <pos>n.</pos> <fld>(Electronics)</fld> <def>Low frequency, a
term used to refer to radio waves of a frequency from 30 to 300
kilohertz. Contrasted to <contr>HF</contr>, high frequency.</def>
<mark>[Acronym]</mark><br/
<syn><b>Syn. --</b> low frequency.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>LH</ent><br/
<hw>LH</hw> <pos>n.</pos> <fld>(Biochem.)</fld> <def>An abbreviation for
<sig>luteinizing hormone</sig>, a gonadotropic hormone that is secreted
by the pituitary and stimulates ovulation in female mammals, and
stimulates androgen release in male mammals.</def>
<mark>[Acronym]</mark> <br/
<syn><b>Syn. --</b> luteinizing hormone, interstitial cell-stimulating
hormone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lhasa</ent><br/
<hw>Lhasa</hw> <pos>n.</pos> <def>The capital city of Tibet; it is the
sacred city of Lamaism.</def><br/
<syn><b>Syn. --</b> Lassa, Lasa, capital of Tibet.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A breed of terrier having a long heavy coat raised
in Tibet as watchdogs; also called <altname>Lhasa
apso</altname>.</def><br/
<syn><b>Syn. --</b> Lhasa apso.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lherzolite</ent><br/
<hw>Lher"zo*lite</hw> <pr>(l<etil/r"z<osl/*l<imac/t)</pr>, <pos>n.</pos>
<ety>[From <ets>Lherz</ets>, a place in the Pyrenees +
<ets>-lite</ets>.]</ety> <fld>(Min.)</fld> <def>An igneous rock
consisting largely of chrysolite, with pyroxene and picotite (a variety
of spinel containing chromium).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Li</ent><br/
<hw>Li</hw> <pr>(l<emac/)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A Chinese
measure of distance, being a little more than one third of a
mile.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A Chinese copper coin; a cash. See
<er>Cash</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liability</ent><br/
<hw>Li`a*bil"i*ty</hw> <pr>(l<imac/`<adot/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Liabilities</plw>
<pr>(-t<icr/z)</pr>.</plu><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The state of being liable; <as>as, the
<ex>liability</ex> of an insurer; <ex>liability</ex> to accidents;
<ex>liability</ex> to the law.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which one is under obligation to pay, or for
which one is liable.</def> Specifically, in the <pluf>pl.</pluf>,
<def>the sum of one's pecuniary obligations; -- opposed to
<contr>assets</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Limited liability</b></col>. <cd>See <cref>Limited
company</cref>, under <er>Limited</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liable</ent><br/
<hw>Li"a*ble</hw> <pr>(l<imac/"<adot/*b'l)</pr>, <pos>a.</pos>
<ety>[From F. <ets>lier</ets> to bind, L. <ets>ligare</ets>. Cf.
<er>Ally</er>, <pos>v. t.</pos>, <er>Ligature</er>.]</ety> <sn>1.</sn>
<def>Bound or obliged in law or equity; responsible; answerable; <as>as,
the surety is <ex>liable</ex> for the debt of his
principal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exposed to a certain contingency or casualty, more
or less probable; -- with <ptcl>to</ptcl> and an infinitive or noun;
<as>as, <ex>liable</ex> to slip; <ex>liable</ex> to
accident.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Accountable; responsible; answerable; bound;
subject; obnoxious; exposed.</syn> <usage> -- <er>Liable</er>,
<er>Subject</er>. <xex>Liable</xex> refers to a future possible or
probable happening which may not actually occur; as, horses are
<xex>liable</xex> to slip; even the sagacious are <xex>liable</xex> to
make mistakes. <xex>Subject</xex> refers to any actual state or
condition belonging to the nature or circumstances of the person or
thing spoken of, or to that which often befalls one. One whose father
was <xex>subject</xex> to attacks of the gout is himself
<xex>liable</xex> to have that disease. Men are constantly
<xex>subject</xex> to the law, but <xex>liable</xex> to suffer by its
infraction.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Proudly secure, yet <qex>liable</qex> to fall.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All human things are <qex>subject</qex> to decay.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liableness</ent><br/
<hw>Li"a*ble*ness</hw>, <pos>n.</pos> <def>Quality of being liable;
liability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liage</ent><br/
<hw>Li"age</hw> <pr>(l<imac/"<asl/j)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>liage</ets> a bond. See <er>Liable</er>.]</ety> <def>Union by
league; alliance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>liaise</ent><br/
<hw>li*aise"</hw> <pr>(l<emac/*<amac/z")</pr>, <pos>v. i.</pos> <ety>[By
back-formation from <er>liaison</er>.]</ety> <sn>1.</sn> <def>To form or
maintain a liaison{3}.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act as a liaison{4}.</def><br/
[<source>PJC</source>]</p>

<p><ent>liaison</ent><br/
<hw>li`ai`son"</hw> <pr>(l<esl/`<asl/`z<ocir/N")</pr>, <pos>n.</pos>
<ety>[F., fr. L. <ets>ligatio</ets>, fr. <ets>ligare</ets> to bind. See
<er>Ligature</er>, and cf. <er>Ligation</er>.]</ety> <sn>1.</sn> <def>A
union, or bond of union; an intimacy; an interrelationship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically,</specif> <def>An illicit sexual
relation between a man and a woman; a sexual afffair.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Specifically</specif>: <def>A process of
communication between parts of an organization or between two
organizations acting together for a common purpose.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <def>A person whose function it
is to maintain such communication.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <fld>(Phonetics)</fld> <def>A pronunciation of a
consonant sound that would be otherwise silent, such as the final
consonant of certain French words, when the following word begins with a
vowel sound.</def><br/
[<source>PJC</source>]</p>

<p><ent>Liana</ent><br/
<ent>Liane</ent><br/
<mhw>{ <hw>Li*ane"</hw> <pr>(l<isl/*<amac/n")</pr>, <hw>Li*a"na</hw>
<pr>(l<isl/*<amac/"n<adot/)</pr>, }</mhw> <pos>n.</pos> <ety>[F.
<ets>liane</ets>; prob. akin to <ets>lien</ets> a band, fr. L.
<ets>ligamen</ets>, fr. <ets>ligare</ets> to bind. Cf. <er>Lien</er>,
<pos>n.</pos> ]</ety> <fld>(Bot.)</fld> <def>A luxuriant woody plant,
climbing high trees and having ropelike stems. The grapevine often has
the habit of a liane. Lianes are abundant in the forests of the Amazon
region.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liar</ent><br/
<hw>Li"ar</hw> <pr>(l<imac/"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>liere</ets>. See <er>Lie</er> to falsify.]</ety> <def>A person who
knowingly utters falsehood; one who lies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liard</ent><br/
<hw>Li"ard</hw> <pr>(l<imac/"<etil/rd)</pr>, <pos>a.</pos> <ety>[OF.
<ets>liart</ets>, LL. <ets>liardus</ets> gray, dapple.]</ety>
<def>Gray.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Used by Chaucer as an epithet of a gray or dapple gray
horse. Also used as a name for such a horse.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liard</ent><br/
\'d8<hw>Liard</hw> <pr>(ly<aum/r)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A French copper coin of one fourth the value of a sou.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lias</ent><br/
<hw>Li"as</hw> <pr>(l<imac/"<ait/s)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lias</ets>, fr. <ets>liais</ets> sort of limestone, OF. also
<ets>liois</ets>; perh. of Celtic origin, cf. Armor. <ets>liach</ets>,
<ets>leach</ets>, a stone, Gael. <ets>leac</ets>, W. <ets>llech</ets>.
Cf. <er>Cromlech</er>.]</ety> <fld>(Geol.)</fld> <def>The lowest of the
three divisions of the Jurassic period; a name given in England and
Europe to a series of marine limestones underlying the O<oum/lite. See
the Chart of <er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liassic</ent><br/
<hw>Li*as"sic</hw> <pr>(l<isl/*<acr/s"s<icr/k)</pr>, <pos>a.</pos>
<fld>(Geol.)</fld> <def>Of the age of the Lias; pertaining to the Lias
formation.</def> -- <def2><pos>n.</pos> <def>Same as
<er>Lias</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lib</ent><br/
<hw>Lib</hw> <pr>(l<icr/b)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Glib</er> to geld.]</ety> <def>To castrate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libament</ent><br/
<hw>Lib"a*ment</hw> <pr>(l<icr/b"<adot/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>libamentum</ets>.]</ety> <def>Libation.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libant</ent><br/
<hw>Li"bant</hw> <pr>(l<imac/"b<ait/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>libans</ets>, p. pr. of <ets>libare</ets> to taste, touch.]</ety>
<def>Sipping; touching lightly.</def> <mark>[R.]</mark>
<rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libation</ent><br/
<hw>Li*ba"tion</hw> <pr>(l<isl/*b<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>libatio</ets>, fr. <ets>libare</ets> to take a little from
anything, to taste, to pour out as an offering: cf. F.
<ets>libation</ets>.]</ety> <def>The act of pouring a liquid or liquor,
usually wine, either on the ground or on a victim in sacrifice, in honor
of some deity; also, the wine or liquid thus poured out.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A heathen sacrifice or <qex>libation</qex> to the earth.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libatory</ent><br/
<hw>Li"ba*to*ry</hw> <pr>(l<imac/"b<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Pertaining to libation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libbard</ent><br/
<hw>Lib"bard</hw> <pr>(l<icr/b"b<etil/rd)</pr>, <pos>n.</pos> <ety>[See
<er>Leopard</er>.]</ety> <def>A leopard.</def> <mark>[Obs. or
Poetic]</mark> <rj><au>Spenser. Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libbard's bane</ent><br/
<hw>Lib"bard's bane`</hw> <pr>(-b<etil/rdz b<amac/n`)</pr> <pos>n.</pos>
<def>Leopard's bane.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libel</ent><br/
<hw>Li"bel</hw> <pr>(l<imac/"b<ecr/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>libellus</ets> a little book, pamphlet, libel, lampoon, dim. of
<ets>liber</ets> the liber or inner bark of a tree; also (because the
ancients wrote on this bark), paper, parchment, or a roll of any
material used to write upon, and hence, a book or treatise: cf. F.
<ets>libelle</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A brief writing of any kind, esp. a declaration,
bill, certificate, request, supplication, etc.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>libel</qex> of forsaking [divorcement].</q> <rj><qau>Wyclif
(Matt. v. 31).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any defamatory writing; a lampoon; a
satire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A malicious publication expressed
either in print or in writing, or by pictures, effigies, or other signs,
tending to expose another to public hatred, contempt, or ridicule. Such
publication is indictable at common law.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term, in a more extended sense, includes the
publication of such writings, pictures, and the like, as are of a
blasphemous, treasonable, seditious, or obscene character. These also
are indictable at common law.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>The crime of issuing a malicious
defamatory publication.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Civil Law & Courts of Admiralty)</fld> <def>A
written declaration or statement by the plaintiff of his cause of
action, and of the relief he seeks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libel</ent><br/
<hw>Li"bel</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Libeled</conjf> <pr>(-b<ecr/ld)</pr> or <conjf>Libelled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Libeling</conjf> or
<conjf>Libelling</conjf>.]</vmorph> <sn>1.</sn> <def>To defame, or
expose to public hatred, contempt, or ridicule, by a writing, picture,
sign, etc.; to lampoon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some wicked wits have <qex>libeled</qex> all the fair.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To proceed against by filing a
libel, particularly against a ship or goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 848 pr=VMG --></p>

<p><ent>Libel</ent><br/
<hw>Li"bel</hw> <pr>(l<imac/"b<ecr/l)</pr>, <pos>v. i.</pos> <def>To
spread defamation, written or printed; -- with
<ptcl>against</ptcl>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What's this but <qex>libeling</qex> against the senate?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] <qex>libels</qex> now 'gainst each great man.</q>
<rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libelant</ent><br/
<hw>Li"bel*ant</hw> <pr>(-<ait/nt)</pr>, <pos>n.</pos> <def>One who
libels; one who institutes a suit in an ecclesiastical or admiralty
court.</def> <altsp>[Written also <asp>libellant</asp>.]</altsp>
<rj><au>Cranch.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libeler</ent><br/
<hw>Li"bel*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
libels.</def> <altsp>[Written also <asp>libeller</asp>.]</altsp> <ldquo/
<xex>Libelers</xex> of others.<rdquo/ <rj><au>Buckminster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libelist</ent><br/
<hw>Li"bel*ist</hw> <pr>(-<icr/st)</pr>, <pos>n.</pos> <def>A
libeler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Li bella</ent><br/
\'d8<hw>Li *bel"la</hw> <pr>(l<isl/*b<ecr/l"l<adot/)</pr>, <pos>n.</pos>
<ety>[L., dim. of <ets>libra</ets> balance. See <er>Level</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>A small balance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A level, or leveling instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libellee</ent><br/
<hw>Li`bel*lee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<sd>(a)</sd> <def>The party against whom a libel has been filed; --
corresponding to <altname>defendant</altname> in a common law
action.</def> <sd>(b)</sd> <def>The defendant in an action of
libel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>libellulid</ent><br/
<hw>li*bel"lu*lid</hw> <pr>(l<isl/*b<ecr/l"l<usl/*l<icr/d)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>A dragon fly; -- from
<gen>Libellula</gen>, the name of the typical genus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>libelluloid</ent><br/
<hw>li*bel"lu*loid</hw> <pr>(l<isl/*b<ecr/l"l<usl/*loid)</pr>,
<pos>a.</pos> <ety>[NL. <ets>Libellula</ets>, the name of the typical
genus + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or
pertaining to the dragon flies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libelous</ent><br/
<hw>Li"bel*ous</hw> <pr>(l<imac/"b<ecr/l*<ucr/s)</pr>, <pos>a.</pos>
<def>Containing or involving a libel; defamatory; containing that which
exposes some person to public hatred, contempt, or ridicule; <as>as, a
<ex>libelous</ex> pamphlet</as>.</def> <altsp>[Written also
<asp>libellous</asp>.]</altsp> -- <wordforms><wf>Li"bel*ous*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liber</ent><br/
\'d8<hw>Li"ber</hw> <pr>(l<imac/"b<etil/r)</pr>, <pos>n.</pos> <ety>[L.
See <er>Libel</er>.]</ety> <fld>(Bot.)</fld> <def>The inner bark of
plants, lying next to the wood. It usually contains a large proportion
of woody, fibrous cells, and is, therefore, the part from which the
fiber of the plant is obtained, as that of hemp, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Liber cells</b></col>, <cd>elongated woody cells found in
the liber.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberal</ent><br/
<hw>Lib"er*al</hw> <pr>(l<icr/b"<etil/r*<ait/l)</pr>, <pos>a.</pos>
<ety>[F. <ets>lib<eacute/ral</ets>, L. <ets>liberalis</ets>, from
<ets>liber</ets> free; perh. akin to <ets>libet</ets>, <ets>lubet</ets>,
it pleases, E. <ets>lief</ets>. Cf. <er>Deliver</er>.]</ety> <sn>1.</sn>
<def>Free by birth; hence, befitting a freeman or gentleman; refined;
noble; independent; free; not servile or mean; <as>as, a
<ex>liberal</ex> ancestry; a <ex>liberal</ex> spirit; <ex>liberal</ex>
arts or studies.</as></def> <ldquo/ <xex>Liberal</xex> education.<rdquo/
<au>Macaulay.</au> <ldquo/ A <xex>liberal</xex> tongue.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bestowing in a large and noble way, as a freeman;
generous; bounteous; open-handed; <as>as, a <ex>liberal</ex>
giver</as>.</def> <ldquo/ <xex>Liberal</xex> of praise.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Infinitely good, and of his good<br/
As <qex>liberal</qex> and free as infinite.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Bestowed in a large way; hence, more than
sufficient; abundant; bountiful; ample; profuse; <as>as, a
<ex>liberal</ex> gift; a <ex>liberal</ex> discharge of matter or of
water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>His wealth doth warrant a <qex>liberal</qex> dower.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not strict or rigorous; not confined or restricted
to the literal sense; free; <as>as, a <ex>liberal</ex> translation of a
classic, or a <ex>liberal</ex> construction of law or of
language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not narrow or contracted in mind; not selfish;
enlarged in spirit; catholic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Free to excess; regardless of law or moral
restraint; licentious.</def> <ldquo/ Most like a <xex>liberal</xex>
villain.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Not bound by orthodox tenets or established forms in
political or religious philosophy; independent in opinion; not
conservative; friendly to great freedom in the constitution or
administration of government; having tendency toward democratic or
republican, as distinguished from monarchical or aristocratic, forms;
<as>as, <ex>liberal</ex> thinkers; <ex>liberal</ex> Christians; the
<ex>Liberal</ex> party.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I confess I see nothing <qex>liberal</qex> in this <ldquo/ order
of thoughts,<rdquo/ as Hobbes elsewhere expresses it.</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Liberal</xex> has <xex>of</xex>, sometimes
<xex>with</xex>, before the thing bestowed, <xex>in</xex> before a word
signifying action, and <xex>to</xex> before a person or object on which
anything is bestowed; as, to be <xex>liberal of</xex> praise or censure;
<xex>liberal with</xex> money; <xex>liberal in</xex> giving;
<xex>liberal to</xex> the poor.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The liberal arts</b></col>. <cd>See under
<er>Art</er>.</cd> -- <col><b>Liberal education</b></col>, <cd>education
that enlarges and disciplines the mind and makes it master of its own
powers, irrespective of the particular business or profession one may
follow.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Generous; bountiful; munificent; beneficent;
ample; large; profuse; free.</syn> <usage> -- <er>Liberal</er>,
<er>Generous</er>. <xex>Liberal</xex> is <xex>freeborn</xex>, and
<xex>generous</xex> is <xex>highborn</xex>. The former is opposed to the
ordinary feelings of a servile state, and implies largeness of spirit in
giving, judging, acting, etc. The latter expresses that nobleness of
soul which is peculiarly appropriate to those of high rank, -- a spirit
that goes out of self, and finds its enjoyment in consulting the
feelings and happiness of others. <xex>Generosity</xex> is measured by
the extent of the sacrifices it makes; <xex>liberality</xex>, by the
warmth of feeling which it manifests.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberal</ent><br/
<hw>Lib"er*al</hw>, <pos>n.</pos> <def>One who favors greater freedom in
political or religious matters; an opponent of the established systems;
a reformer; in English politics, a member of the Liberal party, so
called. Cf. <er>Whig</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>liberalisation</ent><br/
<hw>liberalisation</hw> <pos>n.</pos> <def>Same as
liberalization.</def><br/
<syn><b>Syn. --</b> liberalization, relaxation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liberalism</ent><br/
<hw>Lib"er*al*ism</hw> <pr>(-<icr/z'm)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lib<eacute/ralisme</ets>.]</ety> <def>Liberal principles; the
principles and methods of the liberals in politics or religion;
specifically, the principles of the Liberal party.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberalist</ent><br/
<hw>Lib"er*al*ist</hw>, <pos>n.</pos> <def>A liberal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberalistic</ent><br/
<hw>Lib`er*al*is"tic</hw> <pr>(-<icr/s"t<icr/k)</pr>, <pos>a.</pos>
<def>Pertaining to, or characterized by, liberalism; <as>as,
<ex>liberalistic</ex> opinions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberality</ent><br/
<hw>Lib`er*al"i*ty</hw> <pr>(-<acr/l"<icr/*t<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Liberalities</plw> <pr>(-t<icr/z)</pr>.</plu>
<ety>[L. <ets>liberalitas</ets>: cf. F.
<ets>lib<eacute/ralit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The quality
or state of being liberal; liberal disposition or practice; freedom from
narrowness or prejudice; generosity; candor; charity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>liberality</qex> is but cast away<br/
Which makes us borrow what we can not pay.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A gift; a gratuity; -- sometimes in the plural;
<as>as, a prudent man is not impoverished by his
<ex>liberalities</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberalization</ent><br/
<hw>Lib`er*al*i*za"tion</hw> <pr>(-<ait/l*<icr/*z<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>The act of liberalizing; the act of making less
strict.</def><br/
<syn><b>Syn. --</b> liberalization, relaxation.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Liberalize</ent><br/
<hw>Lib"er*al*ize</hw> <pr>(l<icr/b"<etil/r*<ait/l*<imac/z)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Liberalized</conjf> <pr>(-<imac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Liberalizing</conjf>
<pr>(-<imac/`z<icr/ng)</pr>.]</vmorph> <ety>[Cf. F.
<ets>lib<eacute/raliser</ets>.]</ety> <def>To make liberal; to free from
narrow views or prejudices; to make less strict.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To open and to <qex>liberalize</qex> the mind.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberalizer</ent><br/
<hw>Lib"er*al*i`zer</hw> <pr>(-<imac/`z<etil/r)</pr>, <pos>n.</pos>
<def>One who, or that which, liberalizes.</def>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberally</ent><br/
<hw>Lib"er*al*ly</hw>, <pos>adv.</pos> <def>In a liberal
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberate</ent><br/
<hw>Lib"er*ate</hw> <pr>(-<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Liberated</conjf>
<pr>(-<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Liberating</conjf> <pr>(-<amac/`t<icr/ng)</pr>.]</vmorph>
<ety>[L. <ets>liberatus</ets>, p. p. of <ets>liberare</ets> to free, fr.
<ets>liber</ets> free. See <er>Liberal</er>, <pos>a.</pos>, and cf.
<er>Deliver</er>.]</ety> <def>To release from restraint or bondage; to
set at liberty; to free; to manumit; to disengage; <as>as, to
<ex>liberate</ex> a slave or prisoner; to <ex>liberate</ex> the mind
from prejudice; to <ex>liberate</ex> gases.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To deliver; free; release. See
<er>Deliver</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>liberated</ent><br/
<hw>liberated</hw> <pos>adj.</pos> <fld>(Chem.)</fld> <sn>1.</sn>
<def>released from chemical combination, or as a consequence of chemical
reaction; -- of a gas.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>freed from bondage; -- of people.</def><br/
<syn><b>Syn. --</b> emancipated, freed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>free from traditional social restraints; <as>as, a
<ex>liberated</ex> lifestyle</as>.</def><br/
<syn><b>Syn. --</b> emancipated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>stolen.</def> <mark>[jocose]</mark><br/
[<source>PJC</source>]</p>

<p><ent>liberating</ent><br/
<hw>liberating</hw> <pos>adj.</pos> <def>giving freedom from restriction
or restraint.</def><br/
<syn><b>Syn. --</b> emancipating, emancipative, freeing.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Liberation</ent><br/
<hw>Lib`er*a"tion</hw> <pr>(l<icr/b`<etil/r*<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>liberatio</ets>: cf. F.
<ets>lib<eacute/ration</ets>. Cf. <er>Livraison</er>.]</ety> <def>The
act of liberating or the state of being liberated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This mode of analysis requires perfect <qex>liberation</qex> from
all prejudged system.</q> <rj><qau>Pownall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberator</ent><br/
<hw>Lib"er*a`tor</hw> <pr>(l<icr/b"<etil/r*<amac/`t<etil/r)</pr>,
<pos>n.</pos> <ety>[L.]</ety> <def>One who, or that which, liberates; a
deliverer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberatory</ent><br/
<hw>Lib"er*a*to*ry</hw> <pr>(-<adot/*t<osl/*r<ycr/)</pr>, <pos>a.</pos>
<def>Tending, or serving, to liberate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberian</ent><br/
<hw>Liberian</hw> <pos>adj.</pos> <def>Of or pertaining to Liberia;
<as>as, <ex>Liberian</ex> ship owners; a ship of <ex>Liberian</ex>
registry</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to the inhabitants of Liberia;
<as>as, <ex>Liberian</ex> rebels</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liberian</ent><br/
<hw>Liberian</hw> <pos>n.</pos> <def>A native or inhabitant of
Liberia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Libertarian</ent><br/
<hw>Lib`er*ta"ri*an</hw> <pr>(-t<amac/"r<icr/*<ait/n)</pr>,
<pos>a.</pos> <ety>[See <er>Liberty</er>.]</ety> <def>Pertaining to
liberty, or to the doctrine of free will, as opposed to the doctrine of
necessity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libertarian</ent><br/
<hw>Lib`er*ta"ri*an</hw>, <pos>n.</pos> <def>One who holds to the
doctrine of free will.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libertarianism</ent><br/
<hw>Lib`er*ta"ri*an*ism</hw> <pr>(-<icr/z'm)</pr>, <pos>n.</pos>
<def>Libertarian principles or doctrines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberticide</ent><br/
<hw>Lib"er*ti*cide</hw> <pr>(l<icr/b"<etil/r*t<icr/*s<imac/d)</pr>,
<pos>n.</pos> <ety>[L. <ets>libertas</ets> liberty + <ets>caedere</ets>
to kill: cf. (for sense 2) F. <ets>liberticide</ets>.]</ety> <sn>1.</sn>
<def>The destruction of civil liberty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A destroyer of civil liberty.</def> <rj><au>B. F.
Wade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libertinage</ent><br/
<hw>Lib"er*tin*age</hw> <pr>(-t<icr/n*<asl/j)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>libertinage</ets>. See <er>Libertine</er>.]</ety>
<def>Libertinism; license.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libertine</ent><br/
<hw>Lib"er*tine</hw> <pr>(-t<icr/n)</pr>, <pos>n.</pos> <ety>[L.
<ets>libertinus</ets> freedman, from <ets>libertus</ets> one made free,
fr. <ets>liber</ets> free: cf. F. <ets>libertin</ets>. See
<er>Liberal</er>.]</ety> <sn>1.</sn> <fld>(Rom. Antiq.)</fld> <def>A
manumitted slave; a freedman; also, the son of a freedman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl. Hist.)</fld> <def>One of a sect of
Anabaptists, in the fifteenth and early part of the sixteenth century,
who rejected many of the customs and decencies of life, and advocated a
community of goods and of women.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One free from restraint; one who acts according to
his impulses and desires; now, specifically, one who gives rein to lust;
a rake; a debauchee.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a puffed and reckless <qex>libertine</qex>,<br/
Himself the primrose path of dalliance treads.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A defamatory name for a freethinker.</def>
<mark>[Obsolescent]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libertine</ent><br/
<hw>Lib"er*tine</hw>, <pos>a.</pos> <ety>[L. <ets>libertinus</ets> of a
freedman: cf. F. <ets>libertin</ets>. See <er>Libertine</er>,
<pos>n.</pos> ]</ety> <sn>1.</sn> <def>Free from restraint;
uncontrolled.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You are too much <qex>libertine</qex>.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dissolute; licentious; profligate; loose in morals;
<as>as, <ex>libertine</ex> principles or manners</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libertinism</ent><br/
<hw>Lib"er*tin*ism</hw> <pr>(-t<icr/n*<icr/z'm)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The state of a libertine or freedman.</def>
<mark>[R.]</mark> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Licentious conduct; debauchery; lewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Licentiousness of principle or opinion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That spirit of religion and seriousness vanished all at once, and
a spirit of liberty and <qex>libertinism</qex>, of infidelity and
profaneness, started up in the room of it.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liberty</ent><br/
<hw>Lib"er*ty</hw> <pr>(l<icr/b"<etil/r*t<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Liberties</plw> <pr>(-t<icr/z)</pr>.</plu>
<ety>[OE. <ets>liberte</ets>, F. <ets>libert<eacute/</ets>, fr. L.
<ets>libertas</ets>, fr. <ets>liber</ets> free. See
<er>Liberal</er>.]</ety> <sn>1.</sn> <def>The state of a free person;
exemption from subjection to the will of another claiming ownership of
the person or services; freedom; -- opposed to slavery, serfdom,
bondage, or subjection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But ye . . . caused every man his servant, and every man his
handmaid whom he had set at <qex>liberty</qex> at their pleasure, to
return, and brought them into subjection.</q> <rj><qau>Jer. xxxiv.
16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Delivered fro the bondage of corruption into the glorious
<qex>liberty</qex> of the sons of God.</q> <rj><qau>Bible, 1551. Rom.
viii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Freedom from imprisonment, bonds, or other restraint
upon locomotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Being pent from <qex>liberty</qex>, as I am now.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A privilege conferred by a superior power;
permission granted; leave; <as>as, <ex>liberty</ex> given to a child to
play, or to a witness to leave a court, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Privilege; exemption; franchise; immunity enjoyed by
prescription or by grant; <as>as, the <ex>liberties</ex> of the
commercial cities of Europe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His majesty gave not an entire county to any; much less did he
grant . . . any extraordinary <qex>liberties</qex>.</q> <rj><qau>Sir J.
Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The place within which certain immunities are
enjoyed, or jurisdiction is exercised.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Brought forth into some public or open place within the
<qex>liberty</qex> of the city, and there . . . burned.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A certain amount of freedom; permission to go freely
within certain limits; also, the place or limits within which such
freedom is exercised; <as>as, the <ex>liberties</ex> of a
prison</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A privilege or license in violation of the laws of
etiquette or propriety; <as>as, to permit, or take, a
<ex>liberty</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was repeatedly provoked into striking those who had taken
<qex>liberties</qex> with him.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The power of choice; freedom from necessity; freedom
from compulsion or constraint in willing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The idea of <qex>liberty</qex> is the idea of a power in any agent
to do or forbear any particular action, according to the determination
or thought of the mind, whereby either of them is preferred to the
other.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>liberty</qex> of judgment did not of necessity lead to
lawlessness.</q> <rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Manege)</fld> <def>A curve or arch in a bit to
afford room for the tongue of the horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Naut.)</fld> <def>Leave of absence; permission to
go on shore.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At liberty</b></col>. <sd>(a)</sd> <cd>Unconfined;
free.</cd> <sd>(b)</sd> <cd>At leisure.</cd> -- <col><b>Civil
liberty</b></col>, <cd>exemption from arbitrary interference with
person, opinion, or property, on the part of the government under which
one lives, and freedom to take part in modifying that government or its
laws.</cd> -- <col><b>Liberty bell</b></col>. <cd>See under
<er>Bell</er>.</cd> -- <col><b>Liberty cap</b></col>. <sd>(a)</sd>
<cd>The Roman <xex>pileus</xex> which was given to a slave at his
manumission.</cd> <sd>(b)</sd> <cd>A limp, close-fitting cap with which
the head of representations of the goddess of liberty is often decked.
It is sometimes represented on a spear or a liberty pole.</cd> --
<col><b>Liberty of the press</b></col>, <cd>freedom to print and publish
without official supervision.</cd> <col><b>Liberty party</b></col>,
<cd>the party, in the American Revolution, which favored independence of
England; in more recent usage, a party which favored the emancipation of
the slaves.</cd> -- <col><b>Liberty pole</b></col>, <cd>a tall flagstaff
planted in the ground, often surmounted by a liberty cap.</cd> <mark>[U.
S.]</mark> -- <col><b>Moral liberty</b></col>, <cd>that liberty of
choice which is essential to moral responsibility.</cd> --
<col><b>Religious liberty</b></col>, <cd>freedom of religious opinion
and worship.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Leave; permission; license.</syn> <usage> --
<er>Liberty</er>, <er>Freedom</er>. These words, though often
interchanged, are distinct in some of their applications.
<xex>Liberty</xex> has reference to previous restraint;
<xex>freedom</xex>, to the simple, unrepressed exercise of our powers. A
slave is set at <xex>liberty</xex>; his master had always been in a
state of <xex>freedom</xex>. A prisoner under trial may ask
<xex>liberty</xex> (exemption from restraint) to speak his sentiments
with <xex>freedom</xex> (the spontaneous and bold utterance of his
feelings). The <xex>liberty</xex> of the press is our great security for
<xex>freedom</xex> of thought.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libethenite</ent><br/
<hw>Li*beth"en*ite</hw> <pr>(l<icr/*b<ecr/th"<ecr/n*<imac/t)</pr>,
<pos>n.</pos> <ety>[From <ets>Libethen</ets>, in Hungary, where it was
first found.]</ety> <fld>(Min.)</fld> <def>A mineral of an olive-green
color, commonly in orthorhombic crystals. It is a hydrous phosphate of
copper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>libidinal</ent><br/
<hw>libidinal</hw> <pos>adj.</pos> <def>Of or pertaining to the libido;
caused by libido; <as>as, <ex>libidinal</ex> gratification;
<ex>libidinal</ex> impulses</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Libidinist</ent><br/
<hw>Li*bid"i*nist</hw> <pr>(l<icr/*b<icr/d"<icr/*n<icr/st)</pr>,
<pos>n.</pos> <ety>[See <er>Libidinous</er>.]</ety> <def>One given to
lewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libidinosity</ent><br/
<hw>Li*bid`i*nos"i*ty</hw> <pr>(-n<ocr/s"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The state or quality of being libidinous;
libidinousness.</def> <rj><qau>Skelton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libidinous</ent><br/
<hw>Li*bid"i*nous</hw> <pr>(-n<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>libidinosus</ets>, fr. <ets>libido</ets>, <ets>libidinis</ets>,
pleasure, desire, lust, fr. <ets>libet</ets>, <ets>lubet</ets>, it
pleases: cf. F. <ets>libidineux</ets>. See <er>Lief</er>.]</ety>
<def>Having lustful desires; characterized by lewdness; sensual;
lascivious.</def> -- <wordforms><wf>Li*bid"i*nous*ly</wf>,
<pos>adv.</pos> -- <wf>Li*bid"i*nous*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Lewd; lustful; lascivious; unchaste; impure;
sensual; licentious; lecherous; salacious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>libido</ent><br/
<hw>li*bi"do</hw> <pr>(l<icr/*b<emac/"d<osl/)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Sexual desire; the sexual instinct; the sex
drive.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Psychoanalysis)</fld> <def>Those desires and
instinctual energies which are derived from the id.</def><br/
[<source>PJC</source>]</p>

<p><ent>Libkin</ent><br/
<ent>Libken</ent><br/
<mhw>{ <hw>Lib"ken</hw> <pr>(l<icr/b"k<ecr/n)</pr>, <hw>Lib"kin</hw>
<pr>(l<icr/b"k<icr/n)</pr>, }</mhw> <pos>n.</pos> <ety>[AS.
<ets>libban</ets>, E. <ets>live</ets>, v. i. + <ets>-kin</ets>.]</ety>
<def>A house or lodging.</def> <mark>[Old Slang]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libocedrus</ent><br/
<hw>Libocedrus</hw> <pos>n.</pos> <def>A genus of cedarlike
cypresses.</def><br/
<syn><b>Syn. --</b> genus <gen>Libocedrus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Libra</ent><br/
<ent>Librae</ent><br/
\'d8<hw>Li"bra</hw> <pr>(l<imac/"br<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Libr<ae/</plw> <pr>(l<imac/"br<emac/)</pr>.</plu>
<ety>[L., a balance.]</ety> <fld>(Astron.)</fld> <sd>(a)</sd> <def>The
Balance; the seventh sign in the zodiac, which the sun enters at the
autumnal equinox in September, marked thus <Libra/ in almanacs,
etc.</def> <sd>(b )</sd> <def>A southern constellation between Virgo and
Scorpio.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libral</ent><br/
<hw>Li"bral</hw> <pr>(l<imac/"br<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>libralis</ets>, fr. <ets>libra</ets> the Roman pound.]</ety>
<def>Of a pound weight.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Librarian</ent><br/
<hw>Li*bra"ri*an</hw> <pr>(l<isl/*br<amac/"r<icr/*<ait/n)</pr>,
<pos>n.</pos> <ety>[See <er>Library</er>.]</ety> <sn>1.</sn> <def>One
who has the care or charge of a library.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who copies manuscript books.</def>
<mark>[Obs.]</mark> <rj><au>Broome.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Librarianship</ent><br/
<hw>Li*bra"ri*an*ship</hw>, <pos>n.</pos> <def>The office of a
librarian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Library</ent><br/
<hw>Li"bra*ry</hw> <pr>(l<imac/"br<asl/*r<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Libraries</plw> <pr>(-r<icr/z)</pr>.</plu>
<ety>[OE. <ets>librairie</ets>, F. <ets>librairie</ets> bookseller's
shop, book trade, formerly, a library, fr. <ets>libraire</ets>
bookseller, L. <ets>librarius</ets>, from <ets>liber</ets> book; cf.
<ets>libraria</ets> bookseller's shop, <ets>librarium</ets> bookcase,
It. <ets>libreria</ets>. See <er>Libel</er>.]</ety> <sn>1.</sn> <def>A
considerable collection of books kept for use, and not as merchandise;
<as>as, a private <ex>library</ex>; a public
<ex>library</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A building or apartment appropriated for holding
such a collection of books.</def> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Librate</ent><br/
<hw>Li"brate</hw> <pr>(l<imac/"br<amac/t)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Librated</conjf>
<pr>(l<imac/"br<asl/*t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Librating</conjf>.]</vmorph> <ety>[L. <ets>libratus</ets>, p. p.
of <ets>librare</ets> to balance, to make even, fr. <ets>libra</ets>.
Cf. <er>Level</er>, <er>Deliberate</er>, <er>Equilibrium</er>.]</ety>
<def>To vibrate as a balance does before resting in equilibrium; hence,
to be poised.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their parts all <qex>librate</qex> on too nice a beam.</q>
<rj><qau>Clifton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Librate</ent><br/
<hw>Li"brate</hw>, <pos>v. t.</pos> <def>To poise; to balance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libration</ent><br/
<hw>Li*bra"tion</hw> <pr>(l<isl/*br<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>libratio</ets>: cf. F. <ets>libration</ets>.]</ety>
<sn>1.</sn> <def>The act or state of librating.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>A real or apparent libratory
motion, like that of a balance before coming to rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Libration of the moon</b></col>, <cd>any one of those
small periodical changes in the position of the moon's surface
relatively to the earth, in consequence of which narrow portions at
opposite limbs become visible or invisible alternately. It receives
different names according to the manner in which it takes place; as:
<stype>(a)</stype> <xex>Libration in longitude</xex>, that which,
depending on the place of the moon in its elliptic orbit, causes small
portions near the eastern and western borders alternately to appear and
disappear each month. (<stype>b</stype>) <xex>Libration in
latitude</xex>, that which depends on the varying position of the moon's
axis in respect to the spectator, causing the alternate appearance and
disappearance of either pole. (<stype>c</stype>) <xex>Diurnal</xex> or
<xex>parallactic libration</xex>, that which brings into view on the
upper limb, at rising and setting, some parts not in the average visible
hemisphere.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libration point</ent><br/
<hw>Li*bra"tion point`</hw> <pr>(l<isl/*br<amac/"sh<ucr/n point`)</pr>,
<pos>n.</pos> <def>any one of five points in the plane of a system of
two large astronomical bodies orbiting each other, as the Earth-moon
system, where the gravitational pull of the two bodies on an object are
approximately equal, and in opposite directions. A solid object moving
in the same velocity and direction as such a <ex>libration point</ex>
will remain in gravitational equilibrium with the two bodies of the
system and not fall toward either body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libratory</ent><br/
<hw>Li"bra*to*ry</hw> <pr>(l<imac/"br<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Balancing; moving like a balance, as it tends to an
equipoise or level.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Librettist</ent><br/
<hw>Li*bret"tist</hw> <pr>(l<icr/*br<ecr/t"t<icr/st)</pr>, <pos>n.</pos>
<def>One who makes a libretto.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libretto</ent><br/
<hw>Li*bret"to</hw> <pr>(l<icr/*br<ecr/t"t<osl/; It.
l<esl/*br<asl/t"t<osl/)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Librettos</plw> <pr>(-t<omac/z)</pr>, It. <plw>Libretti</plw>
<pr>(-t<esl/)</pr>.</plu> <ety>[It., dim. of <ets>libro</ets> book, L.
<ets>liber</ets>. See <er>Libel</er>.]</ety> <fld>(Mus.)</fld>
<sd>(a)</sd> <def>A book containing the words of an opera or extended
piece of music.</def> <sd>(b)</sd> <def>The words themselves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libriform</ent><br/
<hw>Li"bri*form</hw> <pr>(l<imac/"br<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[<ets>Liber</ets> + <ets>-form</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having the form of liber, or resembling liber.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Libriform cells</b></col>, <cd>peculiar wood cells which
are very slender and relatively thick-walled, and occasionally are
furnished with bordered pits.</cd> <rj><au>Goodale.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Libya</ent><br/
<hw>Libya</hw> <pos>prop. n.</pos> <def>A country in Northern Africa,
between Egypt and Tunisia, bordering the Mediterranean Sea. It also
borders on Algeria, Chad, Niger, and Sudan. It is an Arabic-speaking
country with over 97% of the population Sunni Moslem. The population in
1995 was about 5,248,000. The capital is Tripoli.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><note><hand/ Until the formation of the modern nation of Libya in
1952, the name had been applied to the same territory that had been
ruled by Italy, and after World War II, by Britain and France. In
ancient times, Libya was the name given to all of that part of Africa
between Egypt and the Atlantic Ocean, and sometimes to Africa as a
whole.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Libyan</ent><br/
<hw>Lib"y*an</hw> <pr>(l<icr/b"<icr/*<ait/n)</pr>, <pos>a.</pos>
<def>Of, pertaining to, or characteristic of, the country Libya or its
inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lice</ent><br/
<hw>Lice</hw> <pr>(l<imac/s)</pr>, <pos>n.</pos>; <def><pos>pl.</pos> of
<er>Louse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>licencee</ent><br/
<ent>licenced</ent><br/
<ent>licence</ent><br/
<mhw><hw>licence</hw> <pr>(l<imac/"s<eit/ns)</pr>, <hw>licenced</hw>,
<hw>licencee</hw></mhw> <def>Same as <er>license</er>,
<er>licensed</er>, <er>licensee</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Licensable</ent><br/
<hw>Li"cens*a*ble</hw> <pr>(l<imac/"s<eit/ns*<adot/*b'l)</pr>,
<pos>a.</pos> <def>That can be licensed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>License</ent><br/
<hw>Li"cense</hw> <pr>(l<imac/"s<eit/ns)</pr>, <pos>n.</pos>
<altsp>[Written also <asp>licence</asp>.]</altsp> <ety>[F.
<ets>licence</ets>, L. <ets>licentia</ets>, fr. <ets>licere</ets> to be
permitted, prob. orig., to be left free to one; akin to
<ets>linquere</ets> to leave. See <er>Loan</er>, and cf.
<er>Illicit</er>, <er>Leisure</er>.]</ety> <sn>1.</sn> <def>Authority or
liberty given to do or forbear any act; especially, a formal permission
from the proper authorities to perform certain acts or to carry on a
certain business, which without such permission would be illegal; a
grant of permission; <as>as, a <ex>license</ex> to preach, to practice
medicine, to sell gunpowder or intoxicating liquors</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To have a <qex>license</qex> and a leave at London to dwell.</q>
<rj><qau>P. Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The document granting such permission.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Excess of liberty; freedom abused, or used in
contempt of law or decorum; disregard of law or propriety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>License</qex> they mean when they cry liberty.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That deviation from strict fact, form, or rule, in
which an artist or writer indulges, assuming that it will be permitted
for the sake of the advantage or effect gained; <as>as, poetic
<ex>license</ex>; grammatical <ex>license</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Leave; liberty; permission.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 849 pr=VMG --></p>

<p><ent>License</ent><br/
<hw>Li"cense</hw> <pr>(l<imac/"s<eit/ns)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Licensed</conjf>
<pr>(l<imac/"s<eit/nst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Licensing</conjf>.]</vmorph> <def>To permit or authorize by
license; to give license to; <as>as, to <ex>license</ex> a man to
preach</as>.</def> <rj><au>Milton.</au> <au>Shak.</au></rj><br/
<syn><b>Syn. --</b> licence, certify.</syn>
[<source>1913 Webster</source>]</p>

<p><ent>Licensed</ent><br/
<hw>Li"censed</hw> <pr>(l<imac/"s<eit/nst)</pr>, <pos>a.</pos>
<def>Having a license; permitted or authorized by license; <as>as, a
<ex>licensed</ex> victualer; a <ex>licensed</ex> traffic.</as></def><br/
<syn><b>Syn. --</b> accredited, commissioned, licenced.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Licensed victualer</b></col>, <cd>one who has a license
to keep an inn or eating house; esp., a victualer who has a license to
sell intoxicating liquors.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licensee</ent><br/
<hw>Li`cen*see"</hw> <pr>(l<imac/`s<eit/n*s<emac/")</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>The person to whom a license is given.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licenser</ent><br/
<hw>Li"cens*er</hw> <pr>(l<imac/"s<eit/ns*<etil/r)</pr>, <pos>n.</pos>
<def>One who gives a license; <as>as, a <ex>licenser</ex> of the
press</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licensure</ent><br/
<hw>Li"cen*sure</hw> <pr>(l<imac/"s<eit/n*sh<usl/r; 135)</pr>,
<pos>n.</pos> <def>A licensing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licentiate</ent><br/
<hw>Li*cen"ti*ate</hw> <pr>(l<isl/*s<ecr/n"sh<icr/*<asl/t <or/
-sh<asl/t; 106)</pr>, <pos>n.</pos> <ety>[LL. <ets>licentiatus</ets>,
fr. <ets>licentiare</ets> to allow to do anything, fr. L.
<ets>licentia</ets> license. See <er>License</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>One who has a license to exercise a profession; <as>as,
a <ex>licentiate</ex> in medicine or theology</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The college of physicians, in July, 1687, published an edict,
requiring all the fellows, candidates, and <qex>licentiates</qex>, to
give gratuitous advice to the neighboring poor.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A friar authorized to receive confessions and grant
absolution in all places, independently of the local clergy.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who acts without restraint, or takes a liberty,
as if having a license therefor.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>On the continent of Europe, a university degree
intermediate between that of bachelor and that of doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licentiate</ent><br/
<hw>Li*cen"ti*ate</hw> <pr>(-sh<icr/*<amac/t)</pr>, <pos>v. t.</pos>
<def>To give a license to.</def> <mark>[Obs.]</mark>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licentious</ent><br/
<hw>Li*cen"tious</hw> <pr>(-sh<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>licentiosus</ets>: cf. F. <ets>licencieux</ets>. See
<er>License</er>.]</ety> <sn>1.</sn> <def>Characterized by license;
passing due bounds; excessive; abusive of freedom; wantonly offensive;
<as>as, a <ex>licentious</ex> press</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A wit that no <qex>licentious</qex> pertness knows.</q>
<rj><qau>Savage.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unrestrained by law or morality; lawless; immoral;
dissolute; lewd; lascivious; <as>as, a <ex>licentious</ex> man; a
<ex>licentious</ex> life.</as></def> <ldquo/<xex>Licentious</xex>
wickedness.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Unrestrained; uncurbed; uncontrolled; unruly;
riotous; ungovernable; wanton; profligate; dissolute; lax; loose;
sensual; impure; unchaste; lascivious; immoral.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Li*cen"tious*ly</wf>, <pos>adv.</pos> --
<wf>Li*cen"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lich</ent><br/
<hw>Lich</hw> <pr>(l<icr/k)</pr>, <pos>a.</pos> <def>Like.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au> <au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lich</ent><br/
<hw>Lich</hw> <pr>(l<icr/ch)</pr>, <pos>n.</pos> <ety>[AS.
<ets>l<imac/c</ets> body. See <er>Like</er>, <pos>a.</pos>]</ety> <def>A
dead body; a corpse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lich fowl</b></col> <fld>(Zool.)</fld>, <cd>the European
goatsucker; -- called also <altname>lich owl</altname>.</cd> --
<col><b>Lich gate</b></col>, <cd>a covered gate through which the corpse
was carried to the church or burial place, and where the bier was placed
to await the clergyman; a corpse gate.</cd> <mark>[Prov. Eng.]</mark>
<au>Halliwell.</au> -- <col><b>Lich wake</b></col>, <cd>the wake, or
watching, held over a corpse before burial.</cd> <mark>[Prov
Eng.]</mark> <au>Chaucer.</au> -- <col><b>Lich wall</b></col>, <cd>the
wall of a churchyard or burying ground.</cd> -- <col><b>Lich
way</b></col>, <cd>the path by which the dead are carried to the
grave.</cd> <mark>[Prov. Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichanura</ent><br/
<hw>Lichanura</hw> <pos>n.</pos> <def>A genus of boas of western North
America.</def><br/
<syn><b>Syn. --</b> genus <gen>Lichanura</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lichee</ent><br/
<hw>lichee</hw> <pos>n.</pos> <sn>1.</sn> <def>A Chinese tree
(<spn>Litchi chinensis</spn>) cultivated especially in the Philippines
and India for its edible fruit, the <prod>litchi nut</prod>; sometimes
placed in the genus <gen>Nephelium</gen>.</def><br/
<syn><b>Syn. --</b> litchi, litchi tree, <spn>Litchi chinensis</spn>,
Nephelium litchi.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A Chinese fruit having a thin brittle shell
enclosing a sweet jellylike pulp and a single seed; often
dried.</def><br/
<syn><b>Syn. --</b> litchi, litchi nut, litchee, lichi, leechee,
lychee.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lichen</ent><br/
<hw>Li"chen</hw> <pr>(l<imac/"k<ecr/n; 277)</pr>, <pos>n.</pos>
<ety>[L., fr. Gr. <grk>leichh`n</grk>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>One of a class of cellular, flowerless plants,
(technically called <altname>Lichenes</altname>), having no distinction
of leaf and stem, usually of scaly, expanded, frond-like forms, but
sometimes erect or pendulous and variously branched. They derive their
nourishment from the air, and generate by means of spores. The species
are very widely distributed, and form irregular spots or patches,
usually of a greenish or yellowish color, upon rocks, trees, and various
bodies, to which they adhere with great tenacity. They are often
improperly called <altname>rock moss</altname> or <altname>tree
moss</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A favorite modern theory of lichens (called after its
inventor the <xex>Schwendener hypothesis</xex>), is that they are not
autonomous plants, but that they consist of ascigerous fungi, parasitic
on alg<ae/. Each lichen is composed of white filaments and green, or
greenish, rounded cells, and it is argued that the two are of different
nature, the one living at the expense of the other. See
<er>Hyph<ae/</er>, and <er>Gonidia</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A name given to several varieties
of skin disease, esp. to one characterized by the eruption of small,
conical or flat, reddish pimples, which, if unchecked, tend to spread
and produce great and even fatal exhaustion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichened</ent><br/
<hw>Li"chened</hw> <pr>(l<imac/"k<ecr/nd)</pr>, <pos>a.</pos>
<def>Belonging to, or covered with, lichens.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenic</ent><br/
<hw>Li*chen"ic</hw> <pr>(l<isl/*k<ecr/n"<icr/k)</pr>, <pos>a.</pos>
<def>Of, pertaining to, or obtained from, lichens.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lichenic acid</b></col>. <sd>(a)</sd> <cd>An organic
acid, <chform>C14H24O3</chform>, obtained from Iceland moss.</cd>
<sd>(b)</sd> <cd>An old name of fumaric acid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licheniform</ent><br/
<hw>Li*chen"i*form</hw> <pr>(-<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<def>Having the form of a lichen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenin</ent><br/
<hw>Li"chen*in</hw> <pr>(l<imac/"k<ecr/n*<icr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A substance isomeric with starch, extracted from
several species of moss and lichen, esp. from Iceland moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenographical</ent><br/
<ent>Lichenographic</ent><br/
<mhw>{ <hw>Li`chen*o*graph"ic</hw>
<pr>(l<imac/`k<ecr/n*<osl/*gr<acr/f"<icr/k)</pr>,
<hw>Li`chen*o*graph"ic*al</hw> <pr>(-<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[Cf. F. <ets>lich<eacute/nographique</ets>.]</ety>
<def>Of or pertaining to lichenography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenographist</ent><br/
<hw>Li`chen*og"ra*phist</hw> <pr>(-<ocr/g"r<adot/*f<icr/st)</pr>,
<pos>n.</pos> <def>One who describes lichens; one versed in
lichenography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenography</ent><br/
<hw>Li`chen*og"ra*phy</hw>
<pr>(l<imac/`k<ecr/n*<ocr/g"r<adot/*f<ycr/)</pr>, <pos>n.</pos>
<ety>[<ets>Lichen</ets> + <ets>-graphy</ets>: cf. F.
<ets>lich<eacute/nographie</ets>.]</ety> <def>A description of lichens;
the science which illustrates the natural history of lichens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenologist</ent><br/
<hw>Li`chen*ol"o*gist</hw> <pr>(-<ocr/l"<osl/*j<icr/st)</pr>,
<pos>n.</pos> <def>One versed in lichenology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenology</ent><br/
<hw>Li`chen*ol"o*gy</hw> <pr>(-j<ycr/)</pr>, <pos>n.</pos>
<ety>[<ets>Lichen</ets> + <ets>-logy</ets>.]</ety> <def>The science
which treats of lichens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichenous</ent><br/
<hw>Li"chen*ous</hw> <pr>(l<imac/"k<ecr/n*<ucr/s)</pr>, <pos>a.</pos>
<def>Of, pertaining to, or resembling, lichens; abounding in lichens;
covered with lichens.</def> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichi</ent><br/
<hw>Li"chi`</hw> <pr>(l<emac/"ch<emac/`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>See <er>Litchi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichwale</ent><br/
<hw>Lich"wale`</hw> <pr>(l<icr/ch"w<amac/l`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The gromwell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lichwort</ent><br/
<hw>Lich"wort`</hw> <pr>(-w<ucir/rt`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>An herb, the wall pellitory. See
<er>Pellitory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licit</ent><br/
<hw>Lic"it</hw> <pr>(l<icr/s"<icr/t)</pr>, <pos>a.</pos> <ety>[L.
<ets>licitus</ets> permitted, lawful, from <ets>licere</ets>: cf. F.
<ets>licite</ets>. See <er>License</er>.]</ety> <def>Lawful.</def>
<ldquo/<xex>Licit</xex> establishments.<rdquo/ <au>Carlyle.</au> --
<wordforms><wf>Lic"it*ly</wf>, <pos>adv.</pos> -- <wf>Lic"it*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licitation</ent><br/
<hw>Lic`i*ta"tion</hw> <pr>(l<icr/s`<icr/*t<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>licitatio</ets>, fr. <ets>licitari</ets>,
<ets>liceri</ets>, to bid, offer a price.]</ety> <def>The act of
offering for sale to the highest bidder.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lick</ent><br/
<hw>Lick</hw> <pr>(l<icr/k)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Licked</conjf> <pr>(l<icr/kt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Licking</conjf>.]</vmorph> <ety>[AS. <ets>liccian</ets>;
akin to OS. <ets>likk<omac/n</ets>, D. <ets>likken</ets>, OHG.
<ets>lecch<omac/n</ets>, G. <ets>lecken</ets>, Goth.
<ets>bi-laig<omac/n</ets>, Russ. <ets>lizate</ets>, L.
<ets>lingere</ets>, Gr. <grk>lei`chein</grk> , Skr. <ets>lih</ets>,
<ets>rih</ets>. <root/121. Cf. <er>Lecher</er>, <er>Relish</er>.]</ety>
<sn>1.</sn> <def>To draw or pass the tongue over; <as>as, a dog
<ex>licks</ex> his master's hand</as>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lap; to take in with the tongue; <as>as, a dog or
cat <ex>licks</ex> milk</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lick the dust</b></col>, <cd>to be slain; to fall in
battle.</cd> <ldquo/His enemies shall <xex>lick the dust</xex>.<rdquo/
<au>Ps. lxxii. 9.</au> -- <col><b>To lick into shape</b></col>, <cd>to
give proper form to; -- from a notion that the bear's cubs are born
shapeless and subsequently formed by licking.</cd> <au>Hudibras.</au> --
<col><b>To lick the spittle of</b></col>, <cd>to fawn upon.</cd>
<au>South.</au> -- <col><b>To lick up</b></col>, <cd>to take all of by
licking; to devour; to consume entirely.</cd> <au>Shak.</au> <au>Num.
xxii. 4.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lick</ent><br/
<hw>Lick</hw>, <pos>n.</pos> <ety>[See <er>Lick</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>A stroke of the tongue in
licking.</def> <ldquo/A <xex>lick</xex> at the honey pot.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A quick and careless application of anything, as if
by a stroke of the tongue, or of something which acts like a tongue;
<as>as, to put on colors with a <ex>lick</ex> of the brush</as>. Also, a
small quantity of any substance so applied.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>lick</qex> of court whitewash.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place where salt is found on the surface of the
earth, to which wild animals resort to lick it up; -- often, but not
always, near salt springs. Called also <altname>salt
lick</altname>.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lick</ent><br/
<hw>Lick</hw>, <pos>v. t.</pos> <ety>[Cf. OSw. <ets>l<aum/gga</ets> to
place, strike, prick.]</ety> <def>To strike with repeated blows for
punishment; to flog; to whip or conquer, as in a pugilistic
encounter.</def> <mark>[Colloq. or Low]</mark><-- to defeat in a
contest? --> <rj><au>Carlyle.</au> <au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lick</ent><br/
<hw>Lick</hw>, <pos>n.</pos> <def>A slap; a quick stroke.</def>
<mark>[Colloq.]</mark> <ldquo/A <xex>lick</xex> across the face.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licker</ent><br/
<hw>Lick"er</hw> <pr>(l<icr/k"<etil/r)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Lecher</er>.]</ety> <def>One who, or that which, licks.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Licker in</b></col> <fld>(Carding Machine)</fld>, <cd>the
drum, or cylinder, by which the lap is taken from the feed
rollers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lickerish</ent><br/
<hw>Lick"er*ish</hw>, <pos>a.</pos> <ety>[Cf. <er>Lecherous</er>.]</ety>
<sn>1.</sn> <def>Eager; craving; urged by desire; eager to taste or
enjoy; greedy.</def> <ldquo/The <xex>lickerish</xex> palate of the
glutton.<rdquo/ <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tempting the appetite; dainty.</def>
<ldquo/<xex>Lickerish</xex> baits, fit to insnare a brute.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lecherous; lustful.</def> <rj><au>Robert of
Brunne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Lick"er*ish*ly</wf>, <pos>adv.</pos> --
<wf>Lick"er*ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lickerous</ent><br/
<hw>Lick"er*ous</hw> <pr>(-<ucr/s)</pr>, <pos>a.</pos> <def>Lickerish;
eager; lustful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Lick"er*ous*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licking</ent><br/
<hw>Lick"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A lapping with the
tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flogging or castigation.</def> <mark>[Colloq. or
Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lickpenny</ent><br/
<hw>Lick"pen`ny</hw> <pr>(-p<ecr/n`n<ycr/)</pr>, <pos>n.</pos> <def>A
devourer or absorber of money.</def> <ldquo/Law is a
<xex>lickpenny</xex>.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lick-spigot</ent><br/
<hw>Lick"-spig`ot</hw> <pr>(-sp<icr/g`<ucr/t)</pr>, <pos>n.</pos> <def>A
tapster.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lick-spittle</ent><br/
<hw>Lick"-spit`tle</hw> <pr>(-sp<icr/t`t'l)</pr>, <pos>n.</pos> <def>An
abject flatterer or parasite.</def> <rj><au>Theodore Hook.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licorice</ent><br/
<hw>Lic"o*rice</hw> <pr>(l<icr/k"<osl/*r<icr/s)</pr>, <pos>n.</pos>
<ety>[OE. <ets>licoris</ets>, through old French, fr. L.
<ets>liquiritia</ets>, corrupted fr. <ets>glycyrrhiza</ets>, Gr.
<grk>glyky`rriza</grk>; <grk>glyky`s</grk> sweet + <grk>"ri`za</grk>
root. Cf. <er>Glycerin</er>, <er>Glycyrrhiza</er>, <er>Wort</er>.]</ety>
<altsp>[Written also <asp>liquorice</asp>.]</altsp> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A plant of the genus <gen>Glycyrrhiza</gen>
(<spn>Glycyrrhiza glabra</spn>), the root of which abounds with a sweet
juice, and is much used in demulcent compositions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The inspissated juice of licorice root, used as a
confection and for medicinal purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Licorice fern</b></col> <fld>(Bot.)</fld>, <cd>a name of
several kinds of polypody which have rootstocks of a sweetish
flavor.</cd> -- <col><b>Licorice sugar</b></col>. <fld>(Chem.)</fld>
<cd>See <er>Glycyrrhizin</er>.</cd> -- <col><b>Licorice weed</b></col>
<fld>(Bot.)</fld>, <cd>the tropical plant <spn>Scapania
dulcis</spn>.</cd> -- <col><b>Mountain licorice</b></col>
<fld>(Bot.)</fld>, <cd>a kind of clover (<spn>Trifolium alpinum</spn>),
found in the Alps. It has large purplish flowers and a sweetish
perennial rootstock.</cd> -- <col><b>Wild licorice</b></col>.
<fld>(Bot.)</fld> <sd>(a)</sd> <cd>The North American perennial herb
<spn>Glycyrrhiza lepidota</spn>.</cd> <sd>(b)</sd> <cd>Certain
broad-leaved cleavers (<spn>Galium circ<ae/zans</spn> and <spn>Galium
lanceolatum</spn>).</cd> <sd>(c)</sd> <cd>The leguminous climber
<spn>Abrus precatorius</spn>, whose scarlet and black seeds are called
<cref>black-eyed Susans</cref>. Its roots are used as a substitute for
those of true licorice (<spn>Glycyrrhiza glabra</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licorous</ent><br/
<hw>Lic"o*rous</hw> <pr>(l<icr/k"<osl/*r<ucr/s)</pr>, <pos>a.</pos>
<def>See <er>Lickerish</er>.</def> --
<wordforms><wf>Lic"o*rous*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Licour</ent><br/
<hw>Lic"our</hw> <pr>(l<icr/k"<ocr/r)</pr>, <pos>n.</pos>
<def>Liquor.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lictor</ent><br/
<hw>Lic"tor</hw> <pr>(l<icr/k"t<ocr/r)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <fld>(Rom. Antiq.)</fld> <def>An officer who bore an ax
and fasces or rods, as ensigns of his office. His duty was to attend the
chief magistrates when they appeared in public, to clear the way, and
cause due respect to be paid to them, also to apprehend and punish
criminals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lictors</qex> and rods, the ensigns of their power.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lid</ent><br/
<hw>Lid</hw> <pr>(l<icr/d)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hlid</ets>, fr. <ets>hl<imac/dan</ets> (in comp.) to cover, shut;
akin to OS. <ets>hl<imac/dan</ets> (in comp.), D. <ets>lid</ets> lid,
OHG. <ets>hlit</ets>, G. augen<ets>lid</ets> eyelid, Icel.
<ets>hli<edh/</ets> gate, gateway. <root/40.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>That which covers the opening of a vessel or box,
etc.; a movable cover; <as>as, the <ex>lid</ex> of a chest or
trunk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The cover of the eye; an eyelid.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tears, big tears, gushed from the rough soldier's
<qex>lid</qex>.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The cover of the
spore cases of mosses.</def> <sd>(b)</sd> <def>A calyx which separates
from the flower, and falls off in a single piece, as in the Australian
<fam>Eucalypti</fam>.</def> <sd>(c)</sd> <def>The top of an ovary which
opens transversely, as in the fruit of the purslane and the tree which
yields Brazil nuts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lidded</ent><br/
<hw>Lid"ded</hw> <pr>(l<icr/d"d<ecr/d)</pr>, <pos>a.</pos> <def>Covered
with a lid.</def> <rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lidge</ent><br/
<hw>Lidge</hw> <pr>(l<icr/j)</pr>, <pos>n.</pos> <def>Same as
<er>Ledge</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lidless</ent><br/
<hw>Lid"less</hw> <pr>(l<icr/d"l<ecr/s)</pr>, <pos>a.</pos> <def>Having
no lid, or not covered with the lids, as the eyes; hence, sleepless;
watchful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>lidless</qex> watcher of the public weal.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lido</ent><br/
<hw>lido</hw> <pos>n.</pos> <sn>1.</sn> <ety>[After the <ets>Lido</ets>,
a group of sandy barrier islands between the lagoon of Venice and the
Adriatic, a popular beach resort.]</ety> <def>A recreational facility,
especially one including a swimming pool for water sports.</def>
<mark>[British]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lie</ent><br/
<hw>Lie</hw> <pr>(l<imac/)</pr>, <pos>n.</pos> <def>See
<er>Lye</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lie</ent><br/
<hw>Lie</hw> <pr>(l<imac/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>lyge</ets>; akin to D. <ets>leugen</ets>, OHG. <ets>lugi</ets>, G.
<ets>l<uum/ge</ets>, <ets>lug</ets>, Icel. <ets>lygi</ets>, Dan. & Sw.
<ets>l<oum/gn</ets>, Goth. <ets>liugn</ets>. See <er>Lie</er> to utter a
falsehood.]</ety> <sn>1.</sn> <def>A falsehood uttered or acted for the
purpose of deception; an intentional violation of truth; an untruth
spoken with the intention to deceive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The proper notion of a <qex>lie</qex> is an endeavoring to deceive
another by signifying that to him as true, which we ourselves think not
to be so.</q> <rj><qau>S. Clarke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is willful deceit that makes a <qex>lie</qex>. A man may act a
<qex>lie</qex>, as by pointing his finger in a wrong direction when a
traveler inquires of him his road.</q> <rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fiction; a fable; an untruth.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything which misleads or disappoints.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wishing this <qex>lie</qex> of life was o'er.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To give the lie to</b></col>. <sd>(a)</sd> <cd>To charge
with falsehood; <as>as, the man <ex>gave <plain>him</plain> the
lie</ex></as>.</cd> <sd>(b)</sd> <cd>To reveal to be false; <as>as, a
man's actions may <ex>give the lie to</ex> his words</as>.</cd> --
<col><b>White lie</b></col>, <cd>a euphemism for such lies as one finds
it convenient to tell, and excuses himself for telling.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Untruth; falsehood; fiction; deception.</syn>
<usage> -- <er>Lie</er>, <er>Untruth</er>. A man may state what is
<xex>untrue</xex> from ignorance or misconception; hence, to impute an
<xex>untruth</xex> to one is not necessarily the same as charging him
with a <xex>lie</xex>. Every <xex>lie</xex> is an <xex>untruth</xex>,
but not every <xex>untruth</xex> is a <xex>lie</xex>. Cf.
<er>Falsity</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lie</ent><br/
<hw>Lie</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lied</conjf> <pr>(l<imac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lying</conjf> <pr>(l<imac/"<icr/ng)</pr>.]</vmorph> <ety>[OE.
<ets>lien</ets>, <ets>li<yogh/en</ets>, <ets>le<yogh/en</ets>,
<ets>leo<yogh/en</ets>, AS. <ets>le<oacute/gan</ets>; akin to D.
<ets>liegen</ets>, OS. & OHG. <ets>liogan</ets>, G.
<ets>l<uum/gen</ets>, Icel. <ets>lj<umac/ga</ets>, Sw. <ets>ljuga</ets>,
Dan. <ets>lyve</ets>, Goth. <ets>liugan</ets>, Russ.
<ets>lgate</ets>.]</ety> <def>To utter falsehood with an intention to
deceive; to say or do that which is intended to deceive another, when he
a right to know the truth, or when morality requires a just
representation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lie</ent><br/
<hw>Lie</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Lay</conjf> <pr>(l<amac/)</pr>; <pos>p. p.</pos>
<conjf>Lain</conjf> <pr>(l<amac/n)</pr>, (<conjf>Lien</conjf>
<pr>(l<imac/"<ecr/n)</pr>, <mark>Obs.</mark>); <pos>p. pr. & vb.
n.</pos> <conjf>Lying</conjf>.]</vmorph> <ety>[OE. <ets>lien</ets>,
<ets>liggen</ets>, AS. <ets>licgan</ets>; akin to D. <ets>liggen</ets>,
OHG. <ets>ligen</ets>, <ets>licken</ets>, G. <ets>liegen</ets>, Icel.
<ets>liggja</ets>, Sw. <ets>ligga</ets>, Dan. <ets>ligge</ets>, Goth.
<ets>ligan</ets>, Russ. <ets>lejate</ets>, L. <ets>lectus</ets> bed, Gr.
<grk>le`chos</grk> bed, <grk>le`xasqai</grk> to lie. Cf. <er>Lair</er>,
<er>Law</er>, <er>Lay</er>, <pos>v. t.</pos>, <er>Litter</er>,
<er>Low</er>, <pos>adj.</pos>]</ety> <sn>1.</sn> <def>To rest extended
on the ground, a bed, or any support; to be, or to put one's self, in an
horizontal position, or nearly so; to be prostate; to be stretched out;
-- often with <ptcl>down</ptcl>, when predicated of living creatures;
<as>as, the book <ex>lies</ex> on the table; the snow <ex>lies</ex> on
the roof; he <ex>lies</ex> in his coffin.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The watchful traveler . . . <br/
<qex>Lay</qex> down again, and closed his weary eyes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be situated; to occupy a certain place; <as>as,
Ireland <ex>lies</ex> west of England; the meadows <ex>lie</ex> along
the river; the ship <ex>lay</ex> in port.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To abide; to remain for a longer or shorter time; to
be in a certain state or condition; <as>as, to <ex>lie</ex> waste; to
<ex>lie</ex> fallow; to <ex>lie</ex> open; to <ex>lie</ex> hid; to
<ex>lie</ex> grieving; to <ex>lie</ex> under one's displeasure; to
<ex>lie</ex> at the mercy of the waves; the paper does not <ex>lie</ex>
smooth on the wall.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be or exist; to belong or pertain; to have an
abiding place; to consist; -- with <xex>in</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Envy <qex>lies</qex> between beings equal in nature, though
unequal in circumstances.</q> <rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that thinks that diversion may not <qex>lie</qex> in hard
labor, forgets the early rising and hard riding of huntsmen.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To lodge; to sleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whiles I was now trifling at home, I saw London, . . . where I
<qex>lay</qex> one night only.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mr. Quinion <qex>lay</qex> at our house that night.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To be still or quiet, like one lying down to
rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The wind is loud and will not <qex>lie</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Law)</fld> <def>To be sustainable; to be capable of
being maintained.</def> <ldquo/An appeal <xex>lies</xex> in this
case.<rdquo/ <rj><au>Parsons.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Through ignorance or carelessness speakers and writers
often confuse the forms of the two distinct verbs <xex>lay</xex> and
<xex>lie</xex>. <xex>Lay</xex> is a transitive verb, and has for its
preterit <xex>laid</xex>; as, he told me to <xex>lay</xex> it down, and
I <xex>laid</xex> it down. <xex>Lie</xex> is intransitive, and has for
its preterit <xex>lay</xex>; as, he told me to <xex>lie</xex> down, and
I <xex>lay</xex> down. Some persons blunder by using <xex>laid</xex> for
the preterit of <xex>lie</xex>; as, he told me to <xex>lie</xex> down,
and I <xex>laid</xex> down. So persons often say incorrectly, the ship
<xex>laid</xex> at anchor; they <xex>laid</xex> by during the storm; the
book was <xex>laying</xex> on the shelf, etc. It is only necessary to
remember, in all such cases, that <xex>laid</xex> is the preterit of
<xex>lay</xex>, and not of <xex>lie</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To lie along the shore</b></col> <fld>(Naut.)</fld>,
<cd>to coast, keeping land in sight.</cd> -- <col><b>To lie at the door
of</b></col>, <cd>to be imputable to; as, the sin, blame, etc.,
<xex>lies at your door</xex>.</cd> -- <col><b>To lie at the
heart</b></col>, <cd>to be an object of affection, desire, or
anxiety.</cd> <au>Sir W. Temple.</au> -- <col><b>To lie at the mercy
of</b></col>, <cd>to be in the power of.</cd> -- <col><b>To lie
by</b></col>. <sd>(a)</sd> <cd>To remain with; to be at hand; <as>as, he
has the manuscript <ex>lying by</ex> him</as>.</cd> <sd>(b)</sd> <cd>To
rest; to intermit labor; as, we <xex>lay by</xex> during the heat of the
day.</cd> -- <mcol><col><b>To lie hard</b></col> <it>or</it> <col><b>To
lie heavy</b></col></mcol>, <cd>to press or weigh; to bear hard.</cd> --
<col><b>To lie in</b></col>, <cd>to be in childbed; to bring forth
young.</cd> -- <col><b>To lie in one</b></col>, <cd>to be in the power
of; to belong to.</cd> <ldquo/As much as <xex>lieth in you</xex>, live
peaceably with all men.<rdquo/ <au>Rom. xii. 18.</au> -- <col><b>To lie
in the way</b></col>, <cd>to be an obstacle or impediment.</cd> --
<col><b>To lie in wait</b></col> , <cd>to wait in concealment; to lie in
ambush.</cd> -- <mcol><col><b>To lie on</b></col> <it>or</it> <col><b>To
lie upon</b></col></mcol>. <sd>(a)</sd> <cd>To depend on; <as>as, his
life <ex>lies on</ex> the result</as>.</cd> <sd>(b)</sd> <cd>To bear,
rest, press, or weigh on.</cd> -- <col><b>To lie low</b></col>, <cd>to
remain in concealment or inactive.</cd> <mark>[Slang]</mark> --
<col><b>To lie on hand</b></col>, <col><b>To lie on one's
hands</b></col>, <cd>to remain unsold or unused; <as>as, the goods are
still <ex>lying on his hands</ex>; they have too much time <ex>lying on
their hands</ex></as>.</cd> -- <col><b>To lie on the head of</b></col>,
<cd>to be imputed to.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>What he gets more of her than sharp words, let it <qex>lie on my
head</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To lie over</b></col>. <sd>(a)</sd> <cd>To remain unpaid
after the time when payment is due, as a note in bank.</cd> <sd>(b)</sd>
<cd>To be deferred to some future occasion, as a resolution in a public
deliberative body.</cd> -- <col><b>To lie to</b></col>
<fld>(Naut.)</fld>, <cd>to stop or delay; especially, to head as near
the wind as possible as being the position of greatest safety in a gale;
-- said of a ship. Cf. <cref>To bring to</cref>, under
<er>Bring</er>.</cd> -- <col><b>To lie under</b></col>, <cd>to be
subject to; to suffer; to be oppressed by.</cd> -- <col><b>To lie
with</b></col>. <sd>(a)</sd> <cd>To lodge or sleep with.</cd>
<sd>(b)</sd> <cd>To have sexual intercourse with.</cd> <sd>(c)</sd>
<cd>To belong to; <as>as, it <ex>lies with</ex> you to make
amends</as>.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><-- p. 850 pr=VMG --></p>

<p><ent>Lie</ent><br/
<hw>Lie</hw> <pr>(l<imac/)</pr>, <pos>n.</pos> <def>The position or way
in which anything lies; the lay, as of land or country.</def> <rj><au>J.
H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He surveyed with his own eyes . . . the <qex>lie</qex> of the
country on the side towards Thrace.</q> <rj><qau>Jowett
(Thucyd.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieberkuehn</ent><br/
<ent>Lieberkuhn</ent><br/
<hw>Lie"ber*k<uum/hn</hw> <pr>(l<emac/"b<etil/r*k<usdot/n)</pr>,
<pos>prop. n.</pos> <ety>[Named after a German physician and instrument
maker, <person>J. N. <etsep>Lieberk<uum/hn</etsep></person>.]</ety>
<fld>(Optics)</fld> <def>A concave metallic mirror attached to the
object-glass end of a microscope, to throw down light on opaque objects;
a reflector.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieberkuehn's glands</ent><br/
<hw>Lie"ber*k<uum/hn's glands`</hw> <pr>(l<emac/"b<etil/r*k<usdot/nz
gl<acr/ndz`)</pr> <pos>n.</pos> <ety>[See <er>Lieberkuehn</er>.]</ety>
<fld>(Anat.)</fld> <def>The simple tubular glands of the small
intestines; -- called also <altname>crypts of
Lieberkuehn</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>liebfraumilch</ent><br/
<hw>liebfraumilch</hw> <pos>n.</pos> <ety>[From the
<ets>liebfrau</ets>enstift, a convent in Worms where the wine was first
made. <au>RHUD</au>]</ety> <def>A white Rhenish-type wine produced
especially in Hesse in western Germany.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liechtenstein</ent><br/
<hw>Liechtenstein</hw> <pos>prop. n.</pos> <def>a small principality in
central Europe.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liechtensteiner</ent><br/
<hw>Liechtensteiner</hw> <pos>prop. a.</pos> <sn>1.</sn> <def>of or
pertaining to Liechtenstein; <as>as, <ex>Liechtensteiner</ex>
castles</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to the inhabitants of
Liechtenstein; <as>as, <ex>Liechtensteiner</ex> writers</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liechtensteiner</ent><br/
<hw>Liechtensteiner</hw> <pos>prop. n.</pos> <def>A native or inhabitant
of Leichtenstein.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lied</ent><br/
\'d8<hw>Lied</hw> <pr>(l<emac/t)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lieder</plw> <pr>(l<emac/"d<etil/r)</pr>.</plu> <ety>[G.]</ety>
<fld>(Mus.)</fld> <def>A lay; a German song. It differs from the French
<contr>chanson</contr>, and the Italian <contr>canzone</contr>, all
three being national.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The German <qex>Lied</qex> is perhaps the most faithful reflection
of the national sentiment.</q> <rj><qau>Grove.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liederkranz</ent><br/
\'d8<hw>Lie"der*kranz</hw>, <pos>n.</pos> <ety>[G. See <ets>Lied</ets>,
and <ets>Grants</ets>.]</ety> <fld>(Mus.)</fld> <def>Lit., wreath of
songs; -- used as the title of a group of songs, and esp. as the common
name for German vocal clubs of men.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Liedertafel</ent><br/
\'d8<hw>Lie"der*ta`fel</hw> <pr>(l<emac/"d<etil/r*t<aum/`f'l)</pr>,
<pos>n.</pos> <ety>[G., lit., a song table.]</ety> <fld>(Mus.)</fld>
<def>A popular name for any society or club which meets for the practice
of male part songs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lief</ent><br/
<hw>Lief</hw> <pr>(l<emac/f)</pr>, <pos>n.</pos> <def>Same as
<er>Lif</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lief</ent><br/
<hw>Lief</hw> <pr>(l<emac/f)</pr>, <pos>a.</pos> <altsp>[Written also
<asp>lieve</asp>.]</altsp> <ety>[OE. <ets>leef</ets>, <ets>lef</ets>,
<ets>leof</ets>, AS. <ets>le<iacute/f</ets>; akin to OS.
<ets>liof</ets>, OFries. <ets>liaf</ets>, D. <ets>lief</ets>, G.
<ets>lieb</ets>, OHG. <ets>liob</ets>, Icel. <ets>lj<?/fr</ets>, Sw.
<ets>ljuf</ets>, Goth. <ets>liubs</ets>, and E. <ets>love</ets>.
<root/124. See <er>Love</er>, and cf. <er>Believe</er>, <er>Leave</er>,
<pos>n.</pos>, <er>Furlough</er>, <er>Libidinous</er>.]</ety>
<sn>1.</sn> <def>Dear; beloved.</def> <mark>[Obs., except in
poetry.]</mark> <ldquo/My <xex>liefe</xex> mother.<rdquo/
<au>Chaucer.</au> <ldquo/My <xex>liefest</xex> liege.<rdquo/
<au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>As thou art <qex>lief</qex> and dear.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <note>(Used with a form of the verb <xex>to be</xex>, and
the dative of the personal pronoun.)</note> <def>Pleasing; agreeable;
acceptable; preferable.</def> <mark>[Obs.]</mark> <see>See
<er>Lief</er>, <pos>adv.</pos>, and <xex>Had as lief</xex>, under
<er>Had</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><q>Full <qex>lief</qex> me were this counsel for to hide.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Death me <qex>liefer</qex> were than such despite.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Willing; disposed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am not <qex>lief</qex> to gab.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He up arose, however <qex>lief</qex> or loth.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lief</ent><br/
<hw>Lief</hw>, <pos>n.</pos> <def>A dear one; a sweetheart.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lief</ent><br/
<hw>Lief</hw>, <pos>adv.</pos> <def>Gladly; willingly; freely; -- now
used only in the phrases, <ecol><b>had as lief</b></ecol>, and
<ecol><b>would as lief</b></ecol>; <as>as, I had, or would, as
<ex>lief</ex> go as not</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All women <qex>liefest</qex> would<br/
Be sovereign of man's love.</q> <rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I had as <qex>lief</qex> the town crier spoke my lines.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Far <qex>liefer</qex> by his dear hand had I die.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The comparative <xex>liefer</xex> with <xex>had or
would</xex>, and followed by the infinitive, either with or without the
sign <xex>to</xex>, signifies <xex>prefer</xex>, <xex>choose as
preferable</xex>, <xex>would</xex> or <xex>had rather</xex>. In the 16th
century <xex>rather</xex> was substituted for <xex>liefer</xex> in such
constructions in literary English, and has continued to be generally so
used. See <cref>Had as lief</cref>, <cref>Had rather</cref>, etc. ,
under <er>Had</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liefsome</ent><br/
<hw>Lief"some</hw> <pr>(l<emac/f"s<ucr/m)</pr>, <pos>a.</pos>
<def>Pleasing; delightful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liegance</ent><br/
<hw>Lieg"ance</hw> <pr>(l<emac/"j<ait/ns)</pr>, <pos>n.</pos> <def>Same
as <er>Ligeance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liege</ent><br/
<hw>Liege</hw> <pr>(l<emac/j)</pr>, <pos>a.</pos> <ety>[OE.
<ets>lige</ets>, <ets>lege</ets>, F. <ets>lige</ets>, LL.
<ets>ligius</ets>, <ets>legius</ets>, liege, unlimited, complete, prob.
of German origin; cf. G. <ets>ledig</ets> free from bonds and obstacles,
MHG. <ets>ledec</ets>, <ets>ledic</ets>, <ets>lidic</ets>, freed,
loosed, and Charta Ottonis de Benthem, ann. 1253, <ldquo/<ets>ligius
homo</ets> quod Teutonic<egrave/ dicitur <ets>ledigman</ets>,<rdquo/ i.
e., uni soli homagio obligatus, free from all obligations to others;
influenced by L. <ets>ligare</ets> to bind. G. <ets>ledig</ets> perh.
orig. meant, free to go where one pleases, and is perh. akin to E.
<ets>lead</ets> to conduct. Cf. <er>Lead</er> to guide.]</ety>
<sn>1.</sn> <def>Sovereign; independent; having authority or right to
allegiance; <as>as, a <ex>liege</ex> lord</as>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She looked as grand as doomsday and as grave;<br/
And he, he reverenced his <qex>liege</qex> lady there.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>serving an independent sovereign or master; bound by
a feudal tenure; obliged to be faithful and loyal to a superior, as a
vassal to his lord; faithful; loyal; <as>as, a <ex>liege</ex> man; a
<ex>liege</ex> subject.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Old Law)</fld> <def>Full; perfect; complete;
pure.</def> <au>Burrill.</au><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Liege homage</b></col> <fld>(Feudal Custom)</fld>,
<cd>that homage of one sovereign or prince to another which acknowledged
an obligation of fealty and services.</cd> -- <col><b>Liege
poustie</b></col> <ety>[L. <ets>legitima potestas</ets>]</ety>
<fld>(Scots Law)</fld>, <cd>perfect, <it>i. e.</it>, legal, power;
specif., having health requisite to do legal acts.</cd> -- <col><b>Liege
widowhood</b></col>, <cd>perfect, <it>i. e.</it>, pure, widowhood.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liege</ent><br/
<hw>Liege</hw> <pr>(l<emac/j)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
free and independent person; specif., a lord paramount; a
sovereign.</def> <au>Mrs. Browning.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>The anointed sovereign of sighs and groans,<br/
<qex>Liege</qex> of all loiterers and malcontents.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The subject of a sovereign or lord; a
liegeman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A liege lord seems to have been a lord of a free band; and his
<qex>lieges</qex>, though serving under him, were privileged men, free
from all other obligations, their name being due to their freedom, not
to their service.</q> <rj><qau>Skeat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liegeman</ent><br/
<hw>Liege"man</hw> <pr>(l<emac/j"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Liegemen</plw> <pr>(l<emac/j"m<eit/n)</pr>.</plu>
<def>Same as <er>Liege</er>, <pos>n.</pos>, 2.</def> <rj><au>Chaucer.
Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieger</ent><br/
<hw>Lie"ger</hw> <pr>(l<emac/"j<etil/r)</pr>, <pos>n.</pos> <ety>[See
<er>Leger</er>, <er>Ledger</er>.]</ety> <def>A resident
ambassador.</def> <mark>[Obs.]</mark> <see>See <er>Leger</er>.</see>
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liegiancy</ent><br/
<hw>Lie"gian*cy</hw> <pr>(l<emac/"j<ait/n*s<ycr/)</pr>, <pos>n.</pos>
<def>See <er>Ligeance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lien</ent><br/
<hw>Li"en</hw> <pr>(l<imac/"<ecr/n)</pr>, <mark>obs.</mark> <def><pos>p.
p.</pos> of <er>Lie</er>. See <er>lain</er>.</def> <rj><au>Ps. lxviii.
13.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lien</ent><br/
<hw>Lien</hw> <pr>(l<emac/n <or/ l<imac/"<ecr/n; 277)</pr>,
<pos>n.</pos> <ety>[F. <ets>lien</ets> band, bond, tie, fr. L.
<ets>ligamen</ets>, fr. <ets>ligare</ets> to bind. Cf. <er>League</er> a
union, <er>Leam</er> a string, <er>Leamer</er>,
<er>Ligament</er>.]</ety> <fld>(Law)</fld> <def>A legal claim; a charge
upon real or personal property for the satisfaction of some debt or
duty; a right in one to control or hold and retain the property of
another until some claim of the former is paid or satisfied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lienal</ent><br/
<hw>Li*e"nal</hw> <pr>(l<isl/*<emac/"n<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>lien</ets> the spleen.]</ety> <fld>(Anat.)</fld> <def>Of
or pertaining to the spleen; splenic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lienculus</ent><br/
\'d8<hw>Li*en"cu*lus</hw> <pr>(l<isl/*<ecr/<nsm/"k<usl/*l<ucr/s)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Lienculi</plw>
<pr>(l<isl/*<ecr/<nsm/"k<usl/*l<imac/)</pr>.</plu> <ety>[NL., dim. of L.
<ets>lien</ets> the spleen.]</ety> <fld>(Anat.)</fld> <def>One of the
small nodules sometimes found in the neighborhood of the spleen; an
accessory or supplementary spleen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieno-intestinal</ent><br/
<hw>Li*e`no-in*tes"ti*nal</hw>
<pr>(l<isl/*<emac/`n<osl/-<icr/n*t<ecr/s"t<icr/*n<ait/l)</pr>,
<pos>a.</pos> <ety>[l. <ets>lien</ets> the spleen + E.
<ets>intestinal</ets>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining
to the spleen and intestine; <as>as, the <ex>lieno-intestinal</ex> vein
of the frog</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lienteric</ent><br/
<hw>Li`en*ter"ic</hw> <pr>(l<imac/`<ecr/n*t<ecr/r"<icr/k)</pr>,
<pos>a.</pos> <ety>[L. <ets>lientericus</ets>, Gr.
<grk>leienteriko`s</grk>: cf. F. <ets>lient<eacute/rique</ets>. See
<er>Lientery</er>.]</ety> <fld>(Med.)</fld> <def>Of or pertaining to, or
of the nature of, a lientery.</def> -- <def2><pos>n.</pos>
<fld>(Med.)</fld> <def>A lientery.</def></def2>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lientery</ent><br/
<hw>Li"en*ter*y</hw> <pr>(l<imac/"<ecr/n*t<ecr/r*<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>leienteri`a</grk>; <grk>lei^os</grk>
smooth, soft + <grk>'e`nteron</grk> an intestine: cf. F.
<ets>lient<eacute/rie</ets>.]</ety> <fld>(Med.)</fld> <def>A diarrhea,
in which the food is discharged imperfectly digested, or with but little
change.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lier</ent><br/
<hw>Li"er</hw> <pr>(l<imac/"<etil/r)</pr>, <pos>n.</pos> <ety>[From
<er>Lie</er>. ]</ety> <def>One who lies down; one who rests or remains,
as in concealment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There were <qex>liers</qex> in a ambush against him.</q>
<rj><qau>Josh. viii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lierne rib</ent><br/
<hw>Lierne" rib`</hw> <pr>(ly<acir/rn" r<icr/b`)</pr> <pos>n.</pos>
<ety>[F. <ets>lierne</ets>.]</ety> <fld>(Arch.)</fld> <def>In Gothic
vaulting, any rib which does not spring from the impost and is not a
ridge rib, but passes from one boss or intersection of the principal
ribs to another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieu</ent><br/
<hw>Lieu</hw> <pr>(l<umac/)</pr>, <pos>n.</pos> <ety>[F., OF. also
<ets>liu</ets>, <ets>leu</ets>, <ets>lou</ets>, fr. L. <ets>locus</ets>
place. See <er>Local</er>, <er>Locus</er>.]</ety> <def>Place; room;
stead; -- used only in the phrase <ecol><b>in lieu of</b></ecol>, that
is, <xex>instead of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The plan of extortion had been adopted in <qex>lieu</qex> of the
scheme of confiscation.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieutenancy</ent><br/
<hw>Lieu*ten"an*cy</hw> <pr>(l<usl/*t<ecr/n"<ait/n*s<ycr/; 277)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>The office, rank, or commission, of a
lieutenant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The body of lieutenants or subordinates.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The list of the <qex>lieutenancy</qex> of our metropolis.</q>
<rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieutenant</ent><br/
<hw>Lieu*ten"ant</hw> <pr>(l<usl/*t<ecr/n"<ait/nt)</pr>, <pos>n.</pos>
<ety>[F., fr. <ets>lieu</ets> place + <ets>tenant</ets> holding, p. pr.
of <ets>tenir</ets> to hold, L. <ets>tenere</ets>. See <er>Lieu</er>,
and <er>Tenant</er>, and cf. <er>Locum tenens</er>.]</ety> <sn>1.</sn>
<def>An officer who supplies the place of a superior in his absence; a
representative of, or substitute for, another in the performance of any
duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lawful magistrate, who is the vicegerent or
<qex>lieutenant</qex> of God.</q> <rj><qau>Abp. Bramhall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <def>A commissioned officer in the army,
next below a captain.</def> <sd>(b)</sd> <def>A commissioned officer in
the British navy, in rank next below a commander.</def> <sd>(c)</sd>
<def>A commissioned officer in the United States navy, in rank next
below a lieutenant commander.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Lieutenant</xex> is often used, either adjectively
or in hyphened compounds, to denote an officer, in rank next below
another, especially when the duties of the higher officer may devolve
upon the lower one; as, <xex>lieutenant</xex> general, or
<xex>lieutenant-</xex>general; <xex>lieutenant</xex> colonel, or
<xex>lieutenant-</xex>colonel; <xex>lieutenant</xex> governor,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deputy lieutenant</b></col>, <cd>the title of any one of
the deputies or assistants of the lord lieutenant of a county.</cd>
<mark>[Eng.]</mark> -- <col><b>Lieutenant colonel</b></col>, <cd>an army
officer next in rank above major, and below colonel.</cd> --
<col><b>Lieutenant commander</b></col>, <cd>an officer in the United
States navy, in rank next below a commander and next above a
lieutenant.</cd> -- <col><b>Lieutenant general</b></col>. <cd>See in
Vocabulary.</cd> -- <col><b>Lieutenant governor</b></col>. <sd>(a)</sd>
<cd>An officer of a State, being next in rank to the governor, and in
case of the death or resignation of the latter, himself acting as
governor.</cd> <mark>[U. S.]</mark> <sd>(b)</sd> <cd>A deputy governor
acting as the chief civil officer of one of several colonies under a
governor general.</cd> <mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieutenant general</ent><br/
<hw>Lieu*ten"ant gen"er*al</hw> <pr>(l<usl/*t<ecr/n"<ait/nt
j<ecr/n"<etil/r*<ait/l)</pr> <pos>n.</pos> <def>An army officer in rank
next below a general and next above a major general.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the United States, before the civil war, this rank
had been conferred only on <person>George Washington</person> and (in
brevet) on <person>Winfield Scott</person>. In 1864 it was revived by
Congress and conferred on <person>Ulysses S. Grant</person>, and
subsequently, by promotion, on <person>William T. Sherman</person> and
<person>Philip H. Sheridan</person>, each of whom was advanced to the
rank of <cref>general of the army</cref>. When <person>Sheridan</person>
was made general (in 1888) the rank of lieutenant general was suffered
to lapse. See <er>General</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieutenantry</ent><br/
<hw>Lieu*ten"ant*ry</hw> <pr>(l<usl/*t<ecr/n"<ait/nt*r<ycr/)</pr>,
<pos>n.</pos> <def>See <er>Lieutenancy</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieutenantship</ent><br/
<hw>Lieu*ten"ant*ship</hw> <pr>(l<usl/*t<ecr/n"<ait/nt*sh<icr/p)</pr>,
<pos>n.</pos> <def>Same as <er>Lieutenancy</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lieve</ent><br/
<hw>Lieve</hw> <pr>(l<emac/v)</pr>, <pos>a.</pos> <def>Same as
<er>Lief</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lif</ent><br/
<hw>Lif</hw> <pr>(l<icr/f)</pr>, <pos>n.</pos> <ety>[Written also
<ets>lief</ets>.]</ety> <def>The fiber by which the petioles of the date
palm are bound together, from which various kinds of cordage are
made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Life</ent><br/
<hw>Life</hw> <pr>(l<imac/f)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lives</plw> <pr>(l<imac/vz)</pr>.</plu> <ety>[AS.
<ets>l<imac/f</ets>; akin to D. <ets>lijf</ets> body, G. <ets>leib</ets>
body, MHG. <ets>l<imac/p</ets> life, body, OHG. <ets>l<imac/b</ets>
life, Icel. <ets>l<imac/f</ets>, life, body, Sw. <ets>lif</ets>, Dan.
<ets>liv</ets>, and E. <ets>live</ets>, v. <root/119. See <er>Live</er>,
and cf. <er>Alive</er>.]</ety> <sn>1.</sn> <def>The state of being which
begins with generation, birth, or germination, and ends with death;
also, the time during which this state continues; that state of an
animal or plant in which all or any of its organs are capable of
performing all or any of their functions; -- used of all animal and
vegetable organisms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of human beings: The union of the soul and body;
also, the duration of their union; sometimes, the deathless quality or
existence of the soul; <as>as, man is a creature having an immortal
<ex>life</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She shows a body rather than a <qex>life</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Philos.)</fld> <def>The potential principle, or
force, by which the organs of animals and plants are started and
continued in the performance of their several and cooperative functions;
the vital force, whether regarded as physical or spiritual.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Figuratively: The potential or animating principle,
also, the period of duration, of anything that is conceived of as
resembling a natural organism in structure or functions; <as>as, the
<ex>life</ex> of a state, a machine, or a book; authority is the
<ex>life</ex> of government.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A certain way or manner of living with respect to
conditions, circumstances, character, conduct, occupation, etc.; hence,
human affairs; also, lives, considered collectively, as a distinct class
or type; <as>as, low <ex>life</ex>; a good or evil <ex>life</ex>; the
<ex>life</ex> of Indians, or of miners.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which before us lies in daily <qex>life</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By experience of <qex>life</qex> abroad in the world.</q>
<rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lives</qex> of great men all remind us<br/
We can make our <qex>lives</qex> sublime.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is from high <qex>life</qex> high characters are drawn.</q>
<rj><qau>Pope</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Animation; spirit; vivacity; vigor;
energy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No notion of <qex>life</qex> and fire in fancy and in words.</q>
<rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That gives thy gestures grace and <qex>life</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>That which imparts or excites spirit or vigor; that
upon which enjoyment or success depends; <as>as, he was the
<ex>life</ex> of the company, or of the enterprise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The living or actual form, person, thing, or state;
<as>as, a picture or a description from, the
<ex>life</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A person; a living being, usually a human being;
<as>as, many <ex>lives</ex> were sacrificed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>The system of animal nature; animals in general, or
considered collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full nature swarms with <qex>life</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>An essential constituent of life, esp: the
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The words that I speak unto you . . . they are
<qex>life</qex>.</q> <rj><qau>John vi. 63.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The warm <qex>life</qex> came issuing through the wound.</q>
<rj><qau>Pope</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>A history of the acts and events of a life; a
biography; <as>as, Johnson wrote the <ex>life</ex> of
Milton</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>Enjoyment in the right use of the powers;
especially, a spiritual existence; happiness in the favor of God;
heavenly felicity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>Something dear to one as one's existence; a
darling; -- used as a term of endearment.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Life</xex> forms the first part of many compounds,
for the most part of obvious meaning; as, <xex>life-</xex>giving,
<xex>life-</xex>sustaining, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Life annuity</b></col>, <cd>an annuity payable during
one's life.</cd> -- <mcol><col><b>Life arrow</b></col>, <col><b>Life
rocket</b></col>, <col><b>Life shot</b></col></mcol>, <cd>an arrow,
rocket, or shot, for carrying an attached line to a vessel in distress
in order to save life.</cd> -- <col><b>Life assurance</b></col>. <cd>See
<cref>Life insurance</cref>, below.</cd> <-- no life boat?--> --
<col><b>Life buoy</b></col>. <cd>See <er>Buoy</er>.</cd> -- <col><b>Life
car</b></col>, <cd>a water-tight boat or box, traveling on a line from a
wrecked vessel to the shore. In it person are hauled through the waves
and surf.</cd> -- <col><b>Life drop</b></col>, <cd>a drop of vital
blood.</cd> <au>Byron.</au> -- <col><b>Life estate</b></col>
<fld>(Law)</fld>, <cd>an estate which is held during the term of some
certain person's life, but does not pass by inheritance.</cd> --
<col><b>Life everlasting</b></col> <fld>(Bot.)</fld>, <cd>a plant with
white or yellow persistent scales about the heads of the flowers, as
<gen>Antennaria</gen>, and <gen>Gnaphalium</gen>; cudweed.</cd> --
<col><b>Life of an execution</b></col> <fld>(Law)</fld>, <cd>the period
when an execution is in force, or before it expires.</cd> --
<col><b>Life guard</b></col>. <fld>(Mil.)</fld> <cd>See under
<er>Guard</er>.</cd> -- <col><b>Life insurance</b></col>, <cd>the act or
system of insuring against death; a contract by which the insurer
undertakes, in consideration of the payment of a premium (usually at
stated periods), to pay a stipulated sum in the event of the death of
the insured or of a third person in whose life the insured has an
interest.</cd> -- <col><b>Life interest</b></col>, <cd>an estate or
interest which lasts during one's life, or the life of another person,
but does not pass by inheritance.</cd> -- <col><b>Life land</b></col>
<fld>(Law)</fld>, <cd>land held by lease for the term of a life or
lives.</cd> -- <col><b>Life line</b></col>. <sd>(a)</sd>
<fld>(Naut.)</fld> <cd>A line along any part of a vessel for the
security of sailors.</cd> <sd>(b)</sd> <cd>A line attached to a life
boat, or to any life saving apparatus, to be grasped by a person in the
water.</cd> -- <col><b>Life rate</b></col>, <cd>rate of premium for
insuring a life.</cd> -- <col><b>Life rent</b></col>, <cd>the rent of a
life estate; rent or property to which one is entitled during one's
life.</cd> -- <col><b>Life school</b></col>, <cd>a school for artists in
which they model, paint, or draw from living models.</cd> --
<col><b>Lifetable</b></col>, <cd>a table showing the probability of life
at different ages.</cd> -- <col><b>To lose one's life</b></col>, <cd>to
die.</cd> -- <col><b>To seek the life of</b></col>, <cd>to seek to
kill.</cd> -- <col><b>To the life</b></col>, <cd>so as closely to
resemble the living person or the subject; <as>as, the portrait was
drawn <ex>to the life</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifeblood</ent><br/
<hw>Life"blood`</hw> <pr>(l<imac/f"bl<ucr/d`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The blood necessary to life; vital blood.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: That which gives strength and
energy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Money [is] the <qex>lifeblood</qex> of the nation.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifeboat</ent><br/
<hw>Life"boat`</hw> <pr>(l<imac/f"b<omac/t`)</pr>, <pos>n.</pos> <def>A
strong, buoyant boat especially designed for saving the lives of
shipwrecked people.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifeful</ent><br/
<hw>Life"ful</hw> <pr>(l<imac/f"f<usdot/l)</pr>, <pos>a.</pos> <def>Full
of vitality.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>life-giving</ent><br/
<hw>life"-giv`ing</hw> <pr>(l<imac/f"g<icr/v`<icr/ng)</pr>,
<pos>a.</pos> <def>Giving life or spirit; having power to give life;
inspiriting; invigorating; <as>as, <ex>life-giving</ex> love and
praise</as>.</def><br/
<syn><b>Syn. --</b> vital, vitalizing.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>returning the <qex>life-giving</qex> humus to the land.</q>
<rj><qau>Louis Bromfield.</qau></rj><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lifehold</ent><br/
<hw>Life"hold`</hw> <pr>(l<imac/f"h<omac/ld`)</pr>, <pos>n.</pos>
<def>Land held by a life estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifeless</ent><br/
<hw>Life"less</hw>, <pos>a.</pos> <def>Destitute of life, or deprived of
life; not containing, or inhabited by, living beings or vegetation;
dead, or apparently dead; spiritless; powerless; dull; <as>as, a
<ex>lifeless</ex> carcass; <ex>lifeless</ex> matter; a <ex>lifeless</ex>
desert; a <ex>lifeless</ex> wine; a <ex>lifeless</ex> story.</as></def>
-- <wordforms><wf>Life"less*ly</wf>, <pos>adv.</pos> --
<wf>Life"less*ness</wf>, <pos>n.</pos></wordforms></p>

<p><syn><b>Syn.</b> -- Dead; soulless; inanimate; torpid; inert;
inactive; dull; heavy; unanimated; spiritless; frigid; pointless; vapid;
flat; tasteless.</syn> <usage> -- <er>Lifeless</er>, <er>Dull</er>,
<er>Inanimate</er>, <er>Dead</er>. In a moral sense, <xex>lifeless</xex>
denotes a lack of vital energy; <xex>inanimate</xex>, a lack of
expression as to any feeling that may be possessed; <xex>dull</xex>
implies a torpor of soul which checks all mental activity;
<xex>dead</xex> supposes a destitution of feeling. A person is said to
be <xex>lifeless</xex> who has lost the spirits which he once had; he is
said to be <xex>inanimate</xex> when he is naturally wanting in spirits;
one is <xex>dull</xex> from an original deficiency of mental power; he
who is <xex>dead</xex> to moral sentiment is wholly bereft of the
highest attribute of his nature.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>lifelessness</ent><br/
<hw>life"less*ness</hw> <pos>n.</pos> <def>not having life.</def><br/
<syn><b>Syn. --</b> inanimateness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lifelike</ent><br/
<hw>Life"like`</hw> <pr>(l<imac/f"l<imac/k`)</pr>, <pos>a.</pos>
<ety>[Cf. <er>Lively</er>.]</ety> <def>Like a living being; resembling
life; giving an accurate representation; <as>as, a <ex>lifelike</ex>
portrait</as>.</def> -- <wordforms><wf>Life"like`ness</wf>,
<pos>n.</pos></wordforms> <rj><au>Poe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lifeline</ent><br/
<hw>lifeline</hw> <pos>n.</pos> <sn>1.</sn> <def>The anem given to one
of the creases on the palm; its length is said by palmists to indicate
how long one will live.</def><br/
<syn><b>Syn. --</b> line of life, life line.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A line or rope which raises or lowers a deep-sea
diver.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>A line from a vessel that people in a body of water
can cling to to save themselves from drowning.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lifelong</ent><br/
<hw>Life"long</hw> <pr>(l<imac/f"l<ocr/ng`)</pr>, <pos>a.</pos>
<ety>[<ets>Life</ets> + <ets>long</ets>. Cf. <er>Livelong</er>.]</ety>
<def>Lasting or continuing through life.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifely</ent><br/
<hw>Life"ly</hw>, <pos>adv.</pos> <ety>[Cf. <er>Lively</er>,
<pos>a.</pos>]</ety> <def>In a lifelike manner.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifemate</ent><br/
<hw>Life"mate`</hw> <pr>(l<imac/f"m<amac/t`)</pr>, <pos>n.</pos>
<def>Companion for life.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifen</ent><br/
<hw>Lif"en</hw> <pr>(l<imac/f"'n)</pr>, <pos>v. t.</pos> <def>To
enliven.</def> <mark>[Obs.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>life-of-man</ent><br/
<hw>life-of-man</hw> <pos>n.</pos> <def>An unarmed woody rhizomatous
perennial plant (<spn>Aralia racemosa</spn>) distinguished from wild
sarsaparilla by more aromatic roots and panicled umbels; it grows from
Southeastern North America to Mexico.</def><br/
<syn><b>Syn. --</b> American spikenard, petty morel, <spn>Aralia
racemosa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Life-preserver</ent><br/
<hw>Life"-pre*serv`er</hw>
<pr>(l<imac/f"pr<esl/*z<etil/rv`<etil/r)</pr>, <pos>n.</pos> <def>An
apparatus, made in very various forms, and of various materials, for
saving one from drowning by buoying up the body while in the
water.</def> -- <wordforms><wf>Life"-pre*serv`ing</wf>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Life-saving</ent><br/
<hw>Life"-sav`ing</hw> <pr>(l<imac/f"s<amac/v`<icr/ng)</pr>,
<pos>a.</pos> <def>That saves life, or is suited to save life, esp. from
drowning; <as>as, the <ex>life-saving</ex> service; a
<ex>life-saving</ex> station.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>life-sized</ent><br/
<ent>life-size</ent><br/
<mhw><hw>life"-size`</hw>, <hw>life"-sized`</hw></mhw>
<pr>(l<imac/f"s<imac/z`)</pr>, <pos>a.</pos> <def>Of full size; of the
natural size; of the same size as an original; <as>as, a
<ex>life-size</ex> sculpture; a <ex>life-size</ex> portrait of the
general</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>life-sustaining</ent><br/
<hw>life-sustaining</hw> <pos>adj.</pos> <def>being the seat or source
of life; performing a necessary function in the living body; <as>as, the
need for <ex>life-sustaining</ex> air and water</as>.</def><br/
<syn><b>Syn. --</b> vital.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Lifesome</ent><br/
<hw>Life"some</hw> <pr>(l<imac/f"s<ucr/m)</pr>, <pos>a.</pos>
<def>Animated; sprightly.</def> <mark>[Poetic]</mark>
<au>Coleridge.</au> -- <wordforms><wf>Life"some*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifespring</ent><br/
<hw>Life"spring`</hw> <pr>(l<imac/f"spr<icr/ng`)</pr>, <pos>n.</pos>
<def>Spring or source of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifestring</ent><br/
<hw>Life"string"</hw> <pr>(l<imac/f"str<icr/ng`)</pr>, <pos>n.</pos>
<def>A nerve, or string, that is imagined to be essential to life.</def>
<rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifetime</ent><br/
<hw>Life"time`</hw> <pr>(l<imac/f"t<imac/m`)</pr>, <pos>n.</pos>
<def>The time that life continues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Life-weary</ent><br/
<hw>Life"-wea`ry</hw> <pr>(l<imac/f"w<emac/`r<ycr/)</pr>, <pos>a.</pos>
<def>Weary of living.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liflode</ent><br/
<hw>Lif"lode</hw> <pr>(l<imac/f"l<omac/d)</pr>, <pos>n.</pos>
<def>Livelihood.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lift</ent><br/
<hw>Lift</hw> <pr>(l<icr/ft)</pr>, <pos>n.</pos> <ety>[AS.
<ets>lyft</ets> air. See <er>Loft</er>.]</ety> <def>The sky; the
atmosphere; the firmament.</def> <mark>[Obs. or Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lift</ent><br/
<hw>Lift</hw> <pr>(l<icr/ft)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lifted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lifting</conjf>.]</vmorph> <ety>[Icel. <ets>lypta</ets>, fr.
<ets>lopt</ets> air; akin to Sw. <ets>lyfta</ets> to lift, Dan.
<ets>l<oum/fte</ets>, G. <ets>l<uum/ften</ets>; -- prop., to raise into
the air. See <er>Loft</er>, and cf. 1st <er>Lift</er>.]</ety>
<sn>1.</sn> <def>To move in a direction opposite to that of gravitation;
to raise; to elevate; to bring up from a lower place to a higher; to
upheave; sometimes implying a continued support or holding in the higher
place; -- said of material things; <as>as, to <ex>lift</ex> the foot or
the hand; to <ex>lift</ex> a chair or a burden</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 851 pr=VMG --></p>

<p><sn>2.</sn> <def>To raise, elevate, exalt, improve, in rank,
condition, estimation, character, etc.; -- often with
<xex>up</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Roman virtues <qex>lift</qex> up mortal man.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest, being <qex>lifted</qex> up with pride.</q> <rj><qau>1 Tim.
iii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bear; to support.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To collect, as moneys due; to raise.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[Perh. a different word, and akin to Goth.
<ets>hliftus</ets> thief, <ets>hlifan</ets> to steal, L.
<ets>clepere</ets>, Gr. <grk>kle`ptein</grk>. Cf.
<er>Shoplifter</er>.]</ety> <def>To steal; to carry off by theft (esp.
cattle); <as>as, to <ex>lift</ex> a drove of cattle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In old writers, <xex>lift</xex> is sometimes used for
<xex>lifted</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>He ne'er <qex>lift</qex> up his hand but conquered.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lift up</b></col>, <cd>to raise or elevate; in the
Scriptures, specifically, to elevate upon the cross.</cd> <au>John viii.
28.</au> -- <col><b>To lift up the eyes</b></col>. <cd>To look up; to
raise the eyes, as in prayer.</cd> <au>Ps. cxxi. 1.</au> -- <col><b>To
lift up the feet</b></col>, <cd>to come speedily to one's relief.</cd>
<au>Ps. lxxiv. 3.</au> -- <col><b>To lift up the hand</b></col>.
<sd>(a)</sd> <cd>To take an oath.</cd> <au>Gen. xiv. 22.</au>
<sd>(b)</sd> <cd>To pray.</cd> <au>Ps. xxviii. 2.</au> <sd>(c)</sd>
<cd>To engage in duty.</cd> <au>Heb. xii. 12.</au> -- <col><b>To lift up
the hand against</b></col>, <cd>to rebel against; to assault; to attack;
to injure; to oppress.</cd> <au>Job xxxi. 21.</au> -- <col><b>To lift up
one's head</b></col>, <cd>to cause one to be exalted or to rejoice.</cd>
<au>Gen. xl. 13.</au> <au>Luke xxi. 28.</au> -- <col><b>To lift up the
heel against</b></col>, <cd>to treat with insolence or unkindness.</cd>
<au>John xiii.18.</au> -- <col><b>To lift up the voice</b></col>, <cd>to
cry aloud; to call out.</cd> <au>Gen. xxi. 16.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lift</ent><br/
<hw>Lift</hw> <pr>(l<icr/ft)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
try to raise something; to exert the strength for raising or
bearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Strained by <qex>lifting</qex> at a weight too heavy.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rise; to become or appear raised or elevated;
<as>as, the fog <ex>lifts</ex>; the land <ex>lifts</ex> to a ship
approaching it.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[See <er>Lift</er>, <pos>v. t.</pos>, 5.]</ety>
<def>To steal; also, to live by theft.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lift</ent><br/
<hw>Lift</hw>, <pos>n.</pos> <sn>1.</sn> <def>Act of lifting; also, that
which is lifted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The space or distance through which anything is
lifted; <as>as, a long <ex>lift</ex></as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Help; assistance, as by lifting.</def>
<specif>Hence:</specif> <def>A ride in a vehicle, given by the vehicle's
owner to another person as a favor -- usually in <ldquo/give a
lift<rdquo/ or <ldquo/got a lift<rdquo/; <as>as, to give one a
<ex>lift</ex> in a wagon; Jack gave me a <ex>lift</ex> into
town</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The goat gives the fox a <qex>lift</qex>.</q>
<rj><qau>L'Estrange.</qau></rj></p>

<p><sn>4.</sn> <def>That by means of which a person or thing lifts or is
lifted</def>; <specif>as:</specif> <sd>(a)</sd> <def>A hoisting machine;
an elevator; a dumb waiter.</def> <mark>[Chiefly Brit.]</mark>
<sd>(b)</sd> <def>An exercising machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A rise; a degree of elevation; <as>as, the
<ex>lift</ex> of a lock in canals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A lift gate. See <cref>Lift gate</cref>,
below.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Naut.)</fld> <def>A rope leading from the masthead
to the extremity of a yard below; -- used for raising or supporting the
end of the yard.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mach.)</fld> <def>One of the steps of a cone
pulley.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Shoemaking)</fld> <def>A layer of leather in the
heel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Horology)</fld> <def>That portion of the vibration
of a balance during which the impulse is given.</def>
<rj><au>Saunier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>A brightening of the spirits; encouragement;
<as>as, the campaign workers got a <ex>lift</ex> from the President's
endorsement</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Dead lift</b></col>. <cd>See under <er>Dead</er>.</cd>
<au>Swift.</au> -- <col><b>Lift bridge</b></col>, <cd>a kind of
drawbridge, the movable part of which is lifted, instead of being drawn
aside.</cd> -- <col><b>Lift gate</b></col>, <cd>a gate that is opened by
lifting.</cd> -- <col><b>Lift hammer</b></col>. <cd>See <er>Tilt
hammer</er>.</cd> -- <col><b>Lift lock</b></col>, <cd>a canal lock.</cd>
-- <col><b>Lift pump</b></col>, <cd>a lifting pump.</cd> -- <col><b>Lift
tenter</b></col> <fld>(Windmills)</fld>, <cd>a governor for regulating
the speed by adjusting the sails, or for adjusting the action of
grinding machinery according to the speed.</cd> -- <col><b>Lift
wall</b></col> <fld>(Canal Lock)</fld>, <cd>the cross wall at the head
of the lock.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liftable</ent><br/
<hw>Lift"a*ble</hw> <pr>(l<icr/ft"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Such as can be lifted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lifted</ent><br/
<hw>lifted</hw> <pos>adj.</pos> <def>turned upward; <as>as, she left the
room with her face <ex>lifted</ex></as>.</def><br/
<syn><b>Syn. --</b> upraised.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lifter</ent><br/
<hw>Lift"er</hw> <pr>(l<icr/ft"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, lifts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Founding)</fld> <def>A tool for lifting loose sand
from the mold; also, a contrivance attached to a cope, to hold the sand
together when the cope is lifted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lifting</ent><br/
<hw>Lift"ing</hw>, <pos>a.</pos> <def>Used in, or for, or by,
lifting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lifting bridge</b></col>, <cd>a lift bridge.</cd> --
<col><b>Lifting jack</b></col>. <cd>See 2d <er>Jack</er>, 5.</cd> --
<col><b>Lifting machine</b></col>. <cd>See <cref>Health lift</cref>,
under <er>Health</er>.</cd> -- <col><b>Lifting pump</b></col>.
<fld>(Mach.)</fld> <sd>(a)</sd> <cd>A kind of pump having a bucket, or
valved piston, instead of a solid piston, for drawing water and lifting
it to a high level.</cd> <sd>(b)</sd> <cd>A pump which lifts the water
only to the top of the pump, or delivers it through a spout; a lift
pump.</cd> -- <col><b>Lifting rod</b></col>, <cd>a vertical rod lifted
by a rock shaft, and imparting motion to a puppet valve; -- used in the
engines of river steamboats.</cd> -- <col><b>Lifting sail</b></col>
<fld>(Naut.)</fld>, <cd>one which tends to lift a vessel's bow out of
water, as jibs and square foresails.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>liftoff</ent><br/
<hw>liftoff</hw> <pos>n.</pos> <fld>(Rocketry)</fld> <def>the initial
ascent of a rocket from its launching pad.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lig</ent><br/
<hw>Lig</hw> <pr>(l<icr/g)</pr>, <pos>v. i.</pos> <ety>[See <er>Lie</er>
to be prostrate.]</ety> <def>To recline; to lie still.</def> <mark>[Obs.
or Scot.]</mark> <rj><au>Chaucer. Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligament</ent><br/
<hw>Lig"a*ment</hw> <pr>(l<icr/g"<adot/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>ligamentum</ets>, fr. <ets>ligare</ets> to bind; cf. f.
<ets>ligament</ets>. Cf. <er>Lien</er>, <pos>n.</pos>,
<er>Ligature</er>.]</ety> <sn>1.</sn> <def>Anything that ties or unites
one thing or part to another; a bandage; a bond.</def>
<rj><au>Hawthorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Interwoven is the love of liberty with every <qex>ligament</qex>
of your hearts.</q> <rj><qau>Washington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <sd>(a)</sd> <def>A tough band or
plate of dense, fibrous, connective tissue or fibrocartilage serving to
unite bones or form joints.</def> <sd>(b)</sd> <def>A band of connective
tissue, or a membranous fold, which supports or retains an organ in
place; <as>as, the gastrophrenic <ex>ligament</ex>, connecting the
diaphragm and stomach</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligamentous</ent><br/
<ent>Ligamental</ent><br/
<mhw>{ <hw>Lig`a*men"tal</hw> <pr>(l<icr/g"<adot/*m<ecr/n"t<ait/l)</pr>,
<hw>Lig`a*men"tous</hw> <pr>(l<icr/g"<adot/*m<ecr/n"t<ucr/s)</pr>,
}</mhw> <pos>a.</pos> <ety>[Cf. F. <ets>ligamenteux</ets>.]</ety>
<def>Composing a ligament; of the nature of a ligament; binding; <as>as,
a strong <ex>ligamentous</ex> membrane</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligan</ent><br/
<hw>Li"gan</hw> <pr>(l<imac/"g<ait/n)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>ligare</ets> to bind, to tie, <ets>ligamen</ets> band, bandage, E.
<ets>ligament</ets>, or <ets>ligsam</ets>.]</ety> <fld>(Law)</fld>
<def>Goods sunk in the sea, with a buoy attached in order that they may
be found again. See <er>Jetsam</er> and <er>Flotsam</er>.</def>
<altsp>[Written also <asp>lagan</asp>.]</altsp>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>ligase</ent><br/
<hw>ligase</hw> <pos>n.</pos> <fld>(Biochem.)</fld> <def>An enzyme which
catalyzes creation of a covalent bond between two substrates, resulting
in a larger product which is a combination of the two starting
materials; especially, <stype>DNA ligase</stype>, an enzyme which
creates a phosphate bond between 5<prime/ and 3<prime/ ends of a DNA
chain, resulting in a longer chain of DNA. DNA ligase is important in
normal biosynthesis of DNA in the replication cycle of cells.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ligate</ent><br/
<hw>Li"gate</hw> <pr>(l<imac/"g<amac/t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>ligatus</ets>, p. p. of <ets>ligare</ets>.]</ety> <sn>1.</sn>
<def>To tie with a ligature; to bind around; to bandage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Molecular biology)</fld> <def>To concatenate two
strands of (nucleic acid, usually DNA), in an end-to-end fashion, using
a ligase.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ligation</ent><br/
<hw>Li*ga"tion</hw> <pr>(l<isl/*g<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>ligatio</ets>, fr. <ets>ligare</ets> to bind. Cf.
<er>Liaison</er>.]</ety> <sn>1.</sn> <def>The act of binding, or the
state of being bound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which binds; bond; connection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tied with tape, and sealed at each fold and
<qex>ligation</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligator</ent><br/
<hw>Li*ga"tor</hw> <pr>(l<isl/*g<amac/"t<ocr/r)</pr> <pos>n.</pos>
<ety>[See <er>Ligate</er>.]</ety> <fld>(Surg.)</fld> <def>An instrument
for ligating, or for placing and fastening a ligature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligature</ent><br/
<hw>Lig"a*ture</hw> <pr>(l<icr/g"<adot/*t<usl/r; 135)</pr>,
<pos>n.</pos> <ety>[L. <ets>ligatura</ets>, fr. <ets>ligare</ets>,
<ets>ligatum</ets>, to bind: cf. F. <ets>ligature</ets>. Cf.
<er>Ally</er>, <er>League</er>, <er>Legatura</er>, <er>Liable</er>,
<er>Ligament</er>.]</ety> <sn>1.</sn> <def>The act of binding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that binds; a band or bandage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <sd>(a)</sd> <def>A thread or string
for tying the blood vessels, particularly the arteries, to prevent
hemorrhage.</def> <sd>(b)</sd> <def>A thread or wire used to remove
tumors, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state of being bound or stiffened; stiffness;
<as>as, the <ex>ligature</ex> of a joint</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Impotence caused by magic or charms.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mus.)</fld> <def>A curve or line connecting notes;
a slur.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Print.)</fld> <def>A double character, or a type
consisting of two or more letters or characters united, as
<it><ae/</it>, <it><filig/</it>, <it><ffllig/</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligature</ent><br/
<hw>Lig"a*ture</hw> <pr>(l<icr/g"<adot/*t<usl/r)</pr>, <pos>v. t.</pos>
<fld>(Surg.)</fld> <def>To ligate; to tie.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lige</ent><br/
<hw>Lig"e</hw> <pr>(l<icr/g"<eit/)</pr>, <pos>v. t. & i.</pos> <def>To
lie; to tell lies.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligeance</ent><br/
<hw>Li"geance</hw> <pr>(l<emac/"j<ait/ns)</pr>, <pos>n.</pos> <ety>[OF.
<ets>ligeance</ets>, <ets>ligance</ets>. See <er>Liege</er>.]</ety>
<fld>(O. Eng. Law)</fld> <def>The connection between sovereign and
subject by which they were mutually bound, the former to protection and
the securing of justice, the latter to faithful service;
allegiance.</def> <altsp>[Written also <asp>ligeancy</asp> and
<asp>liegance</asp>.]</altsp> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligement</ent><br/
<hw>Lige"ment</hw> <pr>(l<icr/j"m<eit/nt)</pr>, <pos>n.</pos> <def>See
<er>Ledgment</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligge</ent><br/
<hw>Lig"ge</hw> <pr>(l<icr/g"g<eit/)</pr>, <pos>v. i.</pos> <def>To lie
or recline.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligger</ent><br/
<hw>Lig"ger</hw> <pr>(l<icr/g"g<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A baited line attached to a float, for night fishing. See
<er>Leger</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <er>Ledger</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light</ent><br/
<hw>Light</hw> <pr>(l<imac/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>light</ets>, <ets>liht</ets>, AS. <ets>le<iacute/ht</ets>; akin to
OS. <ets>lioht</ets>, D. & G. <ets>licht</ets>, OHG. <ets>lioht</ets>,
Goth. <ets>liuha<thorn/</ets>, Icel. <ets>lj<omac/s</ets>, L.
<ets>lux</ets> light, <ets>lucere</ets> to shine, Gr. <grk>leyko`s</grk>
white, Skr. <ets>ruc</ets> to shine. <root/122. Cf. <er>Lucid</er>,
<er>Lunar</er>, <er>Luminous</er>, <er>Lynx</er>.]</ety> <sn>1.</sn>
<def>That agent, force, or action in nature by the operation of which
upon the organs of sight, objects are rendered visible or
luminous.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Light</xex> was regarded formerly as consisting of
material particles, or corpuscules, sent off in all directions from
luminous bodies, and traversing space, in right lines, with the known
velocity of about 186,300 miles per second; but it is now generally
understood to consist, not in any actual transmission of particles or
substance, but in the propagation of vibrations or undulations in a
subtile, elastic medium, or ether, assumed to pervade all space, and to
be thus set in vibratory motion by the action of luminous bodies, as the
atmosphere is by sonorous bodies. This view of the nature of light is
known as the <xex>undulatory or wave theory</xex>; the other, advocated
by Newton (but long since abandoned), as the <xex>corpuscular</xex>,
<xex>emission</xex>, or <xex>Newtonian theory</xex>. A more recent
theory makes light to consist in electrical oscillations, and is known
as the <xex>electro-magnetic theory</xex> of light.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which furnishes, or is a source of, light, as
the sun, a star, a candle, a lighthouse, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then he called for a <qex>light</qex>, and sprang in.</q>
<rj><qau>Acts xvi. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And God made two great <qex>lights</qex>; the greater
<qex>light</qex> to rule the day, and the lesser <qex>light</qex> to
rule the night.</q> <rj><qau>Gen. i. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The time during which the light of the sun is
visible; day; especially, the dawn of day.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The murderer, rising with the <qex>light</qex>, killeth the poor
and needy.</q> <rj><qau>Job xxiv. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The brightness of the eye or eyes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He seemed to find his way without his eyes;<br/
For out o'door he went without their helps,<br/
And, to the last, bended their <qex>light</qex> on me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The medium through which light is admitted, as a
window, or window pane; a skylight; in architecture, one of the
compartments of a window made by a mullion or mullions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There were windows in three rows, and <qex>light</qex> was against
<qex>light</qex> in three ranks.</q> <rj><qau>I Kings
vii.4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Life; existence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, spring to <qex>light</qex>, auspicious Babe, be born !</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Open view; a visible state or condition; public
observation; publicity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The duke yet would have dark deeds darkly answered; he would never
bring them to <qex>light</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The power of perception by vision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My strength faileth me; as for the <qex>light</qex> of my eyes, it
also is gone from me.</q> <rj><qau>Ps. xxxviii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>That which illumines or makes clear to the mind;
mental or spiritual illumination; enlightenment; knowledge;
information.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall never know<br/
That I had any <qex>light</qex> of this from thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Prosperity; happiness; joy; felicity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then shall thy <qex>light</qex> break forth as the morning, and
thy health shall spring forth speedily.</q> <rj><qau>Is. lviii.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Paint.)</fld> <def>The manner in which the light
strikes upon a picture; that part of a picture which represents those
objects upon which the light is supposed to fall; the more illuminated
part of a landscape or other scene; -- opposed to <ant>shade</ant>. Cf.
<er>Chiaroscuro</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Appearance due to the particular facts and
circumstances presented to view; point of view; <as>as, to state things
fairly and put them in the right <ex>light</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Frequent consideration of a thing . . . shows it in its several
<qex>lights</qex> and various ways of appearance.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>One who is conspicuous or noteworthy; a model or
example; <as>as, the <ex>lights</ex> of the age or of
antiquity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Joan of Arc,<br/
A <qex>light</qex> of ancient France.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Pyrotech.)</fld> <def>A firework made by filling a
case with a substance which burns brilliantly with a white or colored
flame; <as>as, a Bengal <ex>light</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Light</xex> is used figuratively to denote that
which resembles physical light in any respect, as illuminating,
benefiting, enlightening, or enlivening mankind.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Ancient lights</b></col> <fld>(Law)</fld>,
<col><b>Calcium light</b></col>, <col><b>Flash light</b></col>,
etc.</mcol> <cd>See under <er>Ancient</er>, <er>Calcium</er>, etc.</cd>
-- <col><b>Light ball</b></col> <fld>(Mil.)</fld>, <cd>a ball of
combustible materials, used to afford light; -- sometimes made so as to
be fired from a cannon or mortar, or to be carried up by a rocket.</cd>
-- <col><b>Light barrel</b></col> <fld>(Mil.)</fld>, <cd>an empty power
barrel pierced with holes and filled with shavings soaked in pitch, used
to light up a ditch or a breach.</cd> -- <col><b>Light dues</b></col>
<fld>(Com.)</fld>, <cd>tolls levied on ships navigating certain waters,
for the maintenance of lighthouses.</cd> -- <col><b>Light
iron</b></col>, <cd>a candlestick.</cd> <mark>[Obs.]</mark> --
<col><b>Light keeper</b></col>, <cd>a person appointed to take care of a
lighthouse or light-ship.</cd> -- <col><b>Light money</b></col>,
<cd>charges laid by government on shipping entering a port, for the
maintenance of lighthouses and light-ships.</cd> -- <col><b>The light of
the countenance</b></col>, <cd>favor; kindness; smiles.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord, lift thou up <qex>the light of thy countenance</qex> upon
us.</q> <rj><qau>Ps. iv. 6.</qau></rj></p>

<p>-- <col><b>Northern lights</b></col>. <cd>See <cref>Aurora
borealis</cref>, under <er>Aurora</er>.</cd> -- <col><b>To bring to
light</b></col>, <cd>to cause to be disclosed.</cd> -- <col><b>To come
to light</b></col>, <cd>to be disclosed.</cd> -- <col><b>To see the
light</b></col>, <cd>to come into the light; hence, to come into the
world or into public notice; <as>as, his book never <ex>saw the
light</ex></as>.</cd><-- also, see the light of day; (b) to come to
understand (sometimes used ironically, said of a person who professes to
change his opinion after he has been convinced that it will be in his
own interest if the facts are different from his initial beliefs) --> --
<col><b>To stand in one's own light</b></col>, <cd>to take a position
which is injurious to one's own interest.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Light</ent><br/
<hw>Light</hw> <pr>(l<imac/t)</pr>, <pos>a.</pos> <ety>[AS.
<ets>le<iacute/ht</ets>. See <er>Light</er>, <pos>n.</pos>]</ety>
<amorph>[<pos>Compar</pos>. <adjf>Lighter</adjf>
<pr>(l<imac/t"<etil/r)</pr>; <pos>superl</pos>.
<adjf>Lightest</adjf>.]</amorph> <sn>1.</sn> <def>Having light; not dark
or obscure; bright; clear; <as>as, the apartment is
<ex>light</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>White or whitish; not intense or very marked; not of
a deep shade; moderately colored; <as>as, a <ex>light</ex> color; a
<ex>light</ex> brown; a <ex>light</ex> complexion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light</ent><br/
<hw>Light</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lighted</conjf> <pr>(l<imac/t"<ecr/d)</pr> or <conjf>Lit</conjf>
<pr>(l<icr/t)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lighting</conjf>.]</vmorph> <ety>[AS. <ets>l<ymac/htan</ets>,
<ets>l<imac/htan</ets>, to shine. <root/122. See <er>Light</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To set fire to; to cause to burn;
to set burning; to ignite; to kindle; <as>as, to <ex>light</ex> a candle
or lamp; to <ex>light</ex> the gas</as>; -- sometimes with
<ptcl>up</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a thousand candles be all <qex>lighted</qex> from one.</q>
<rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the largest lamp is <qex>lit</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Absence might cure it, or a second mistress<br/
<qex>Light</qex> up another flame, and put out this.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give light to; to illuminate; to fill with light;
to spread over with light; -- often with <xex>up</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ah, hopeless, lasting flames! like those that burn<br/
To <qex>light</qex> the dead.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One hundred years ago, to have <qex>lit</qex> this theater as
brilliantly as it is now <qex>lighted</qex> would have cost, I suppose,
fifty pounds.</q> <rj><qau>F. Harrison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sun has set, and Vesper, to supply<br/
His absent beams, has <qex>lighted</qex> up the sky.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To attend or conduct with a light; to show the way
to by means of a light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His bishops lead him forth, and <qex>light</qex> him on.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To light a fire</b></col>, <cd>to kindle the material of
a fire.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light</ent><br/
<hw>Light</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become ignited; to
take fire; <as>as, the match will not <ex>light</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be illuminated; to receive light; to brighten; --
with <xex>up</xex>; <as>as, the room <ex>light</ex> up very
well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light</ent><br/
<hw>Light</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lighter</adjf> <pr>(l<imac/t"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Lightest</adjf>.]</amorph> <ety>[OE. <ets>light</ets>,
<ets>liht</ets>, AS. <ets>l<imac/ht</ets>, <ets>le<iacute/ht</ets>; akin
to D. <ets>ligt</ets>, G. <ets>leicht</ets>, OHG. <ets>l<imac/hti</ets>,
Icel. <ets>l<emac/ttr</ets>, Dan. <ets>let</ets>, Sw.
<ets>l<aum/tt</ets>, Goth. <ets>leihts</ets>, and perh. to L.
<ets>levis</ets> (cf. <er>Levity</er>), Gr. <grk>'elachy`s</grk> small,
Skr. <ets>laghu</ets> light. <root/125.]</ety> <sn>1.</sn> <def>Having
little, or comparatively little, weight; not tending to be the center of
gravity with force; not heavy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These weights did not exert their natural gravity, . . . insomuch
that I could not guess which was <qex>light</qex> or heavy whilst I held
them in my hand.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not burdensome; easy to be lifted, borne, or carried
by physical strength; <as>as, a <ex>light</ex> burden, or
load</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye shall find rest unto your souls. For my yoke is easy, and my
burden is <qex>light</qex>.</q> <rj><qau>Matt. xi. 29,
30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Easy to be endured or performed; not severe; not
difficult; <as>as, a <ex>light</ex> affliction or task</as>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Light</qex> sufferings give us leisure to complain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Easy to be digested; not oppressive to the stomach;
<as>as, <ex>light</ex> food</as>; also, containing little
nutriment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not heavily armed; armed with light weapons; <as>as,
<ex>light</ex> troops; a troop of <ex>light</ex> horse.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not encumbered; unembarrassed; clear of impediments;
hence, active; nimble; swift.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unmarried men are best friends, best masters . . . but not always
best subjects, for they are <qex>light</qex> to run away.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Not heavily burdened; not deeply laden; not
sufficiently ballasted; <as>as, the ship returned
<ex>light</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Slight; not important; <as>as, a <ex>light</ex>
error</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Well leavened; not heavy; <as>as, <ex>light</ex>
bread</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Not copious or heavy; not dense; not
inconsiderable; <as>as, a <ex>light</ex> rain; a <ex>light</ex> snow;
<ex>light</ex> vapors.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Not strong or violent; moderate; <as>as, a
<ex>light</ex> wind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Not pressing heavily or hard upon; hence, having an
easy, graceful manner; delicate; <as>as, a <ex>light</ex> touch; a
<ex>light</ex> style of execution.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>Easy to admit influence; inconsiderate; easily
influenced by trifling considerations; unsteady; unsettled; volatile;
<as>as, a <ex>light</ex>, vain person; a <ex>light</ex>
mind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no greater argument of a <qex>light</qex> and
inconsiderate person than profanely to scoff at religion.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>Indulging in, or inclined to, levity; wanting
dignity or solemnity; trifling; gay; frivolous; airy;
unsubstantial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seneca can not be too heavy, nor Plautus too <qex>light</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Specimens of New England humor laboriously <qex>light</qex> and
lamentably mirthful.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>Not quite sound or normal; somewhat impaired or
deranged; dizzy; giddy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Are his wits safe? Is he not <qex>light</qex> of brain ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>Easily bestowed; inconsiderately
rendered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To a fair semblance doth <qex>light</qex> faith annex.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>Wanton; unchaste; <as>as, a woman of <ex>light</ex>
character</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>light</qex> wife doth make a heavy husband.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <def>Not of the legal, standard, or usual weight;
clipped; diminished; <as>as, <ex>light</ex> coin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>19.</sn> <def>Loose; sandy; easily pulverized; <as>as, a
<ex>light</ex> soil</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Light cavalry</b></col>, <col><b>Light
horse</b></col></mcol> <fld>(Mil.)</fld>, <cd>light-armed soldiers
mounted on strong and active horses.</cd> -- <col><b>Light
eater</b></col>, <cd>one who eats but little.</cd> -- <col><b>Light
infantry</b></col>, <cd>infantry soldiers selected and trained for rapid
evolutions.</cd> -- <col><b>Light of foot</b></col>. <sd>(a)</sd>
<cd>Having a light step.</cd> <sd>(b)</sd> <cd>Fleet.</cd> --
<col><b>Light of heart</b></col>, <cd>gay, cheerful.</cd> --
<col><b>Light oil</b></col> <fld>(Chem.)</fld>, <cd>the oily product,
lighter than water, forming the chief part of the first distillate of
coal tar, and consisting largely of benzene and toluene.</cd> --
<col><b>Light sails</b></col> <fld>(Naut.)</fld>, <cd>all the sails
above the topsails, with, also, the studding sails and flying jib.</cd>
<au>Dana.</au> -- <col><b>Light sleeper</b></col>, <cd>one easily
wakened.</cd> -- <col><b>Light weight</b></col>, <cd>a prize fighter,
boxer, wrestler, or jockey, who is below a standard medium weight. Cf.
<cref>Feather weight</cref>, under <er>Feather</er>.</cd>
<mark>[Cant]</mark> -- <col><b>To make light of</b></col>, <cd>to treat
as of little consequence; to slight; to disregard.</cd> -- <col><b>To
set light by</b></col>, <cd>to undervalue; to slight; to treat as of no
importance; to despise.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 852 pr=VMG --></p>

<p><ent>Light</ent><br/
<hw>Light</hw> <pr>(l<imac/t)</pr>, <pos>adv.</pos> <def>Lightly;
cheaply.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light</ent><br/
<hw>Light</hw>, <pos>v. t.</pos> <ety>[See <er>Light</er> not heavy, and
cf. <er>Light</er> to alight, and <er>Lighten</er> to make less
heavy.]</ety> <def>To lighten; to ease of a burden; to take off.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>From his head the heavy burgonet did <qex>light</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light</ent><br/
<hw>Light</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lighted</conjf> <pr>(l<imac/t"<ecr/d)</pr> <it>or</it>
<conjf>Lit</conjf> <pr>(l<icr/t)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lighting</conjf>.]</vmorph> <ety>[AS. <ets>l<imac/htan</ets> to
alight orig., to relieve (a horse) of the rider's burden, to make less
heavy, fr. <ets>l<imac/ht</ets> light. See <er>Light</er> not heavy, and
cf. <er>Alight</er>, <er>Lighten</er> to make light.]</ety> <sn>1.</sn>
<def>To dismount; to descend, as from a horse or carriage; to alight; --
with <ptcl>from</ptcl>, <ptcl>off</ptcl>, <ptcl>on</ptcl>,
<ptcl>upon</ptcl>, <ptcl>at</ptcl>, <ptcl>in</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When she saw Isaac, she <qex>lighted</qex> off the camel.</q>
<rj><qau>Gen. xxiv. 64.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Slowly rode across a withered heath,<br/
And <qex>lighted</qex> at a ruined inn.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To feel light; to be made happy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It made all their hearts to <qex>light</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To descend from flight, and rest, perch, or settle,
as a bird or insect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The bee] <qex>lights</qex> on that, and this, and tasteth
all.</q> <rj><qau>Sir. J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On the tree tops a crested peacock <qex>lit</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To come down suddenly and forcibly; to fall; -- with
<ptcl>on</ptcl> or <ptcl>upon</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On me, me only, as the source and spring<br/
Of all corruption, all the blame <qex>lights</qex> due.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To come by chance; to happen; -- with
<ptcl>on</ptcl> or <ptcl>upon</ptcl>; formerly with
<ptcl>into</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The several degrees of vision, which the assistance of glasses
(casually at first <qex>lit</qex> on) has taught us to conceive.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They shall <qex>light</qex> into atheistical company.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And here we <qex>lit</qex> on Aunt Elizabeth,<br/
And Lilia with the rest.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightable</ent><br/
<hw>Light"a*ble</hw> <pr>(l<imac/t"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Such as can be lighted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-armed</ent><br/
<hw>Light"-armed`</hw> <pr>(l<imac/t"<aum/rmd`)</pr>, <pos>a.</pos>
<def>Armed with light weapons or accouterments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-boat</ent><br/
<hw>Light"-boat`</hw> <pr>(l<imac/t"b<omac/t`)</pr>, <pos>n.</pos>
<def>Light-ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>light bulb</ent><br/
<ent>lightbulb</ent><br/
<mhw><hw>lightbulb</hw>, <hw>light bulb</hw></mhw> <pos>n.</pos> <def>A
glass bulb with metallic contacts on the outside connected to a wire
filament (usually tungsten) inside that emits light when heated by
passage of electricity through the filament; -- used as the replaceable
light-emitting component of an electric lamp, flashlight, lighting
fixture, etc.</def><br/
<syn><b>Syn. --</b> light bulb, bulb, incandescent lamp, electric light,
electric-light bulb.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>light-coloured</ent><br/
<hw>light-coloured</hw> <pos>adj.</pos> <def>having low color
saturation; pale-colored.</def><br/
<syn><b>Syn. --</b> pale, palish, pastel, whitish,
light-colored.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>light-duty</ent><br/
<hw>light-duty</hw> <pos>adj.</pos> <def>not designed for heavy or
demanding work; <as>as, a <ex>light-duty</ex> detergent</as>. Opposite
of <ant>heavy-duty</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lighte</ent><br/
<hw>Light"e</hw> <pr>(l<imac/t"<eit/)</pr>, <mark>obs.</mark>
<def><pos>imp.</pos> of <er>Light</er>, to alight.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lighted</ent><br/
<hw>lighted</hw> <pos>adj.</pos> <sn>1.</sn> <def>set afire or
burning.</def><br/
<syn><b>Syn. --</b> ignited, enkindled, kindled, lit.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Illuminated by artificial light; <as>as,
<ex>lighted</ex> by a high-powered searchligh</as>.</def><br/
<syn><b>Syn. --</b> illuminated, lit, well-lighted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lighten</ent><br/
<hw>Light"en</hw> <pr>(l<imac/t"'n)</pr>, <pos>v. i.</pos> <ety>[See
<er>Light</er> to alight.]</ety> <def>To descend; to light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O Lord, let thy mercy <qex>lighten</qex> upon us.</q>
<rj><qau>Book of Common Prayer [Eng. Ed.].</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighten</ent><br/
<hw>Light"en</hw> <pr>(l<imac/t"'n)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lightened</conjf>
<pr>(l<imac/t"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lightening</conjf>.]</vmorph> <ety>[OE. <ets>lightenen</ets>. See
<er>Light</er> to kindle, illuminate.]</ety> <sn>1.</sn> <def>To burst
forth or dart, as lightning; to shine with, or like, lightning; to
display a flash or flashes of lightning; to flash.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This dreadful night,<br/
That thunders, <qex>lightens</qex>, opens graves, and roars<br/
As doth the lion.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grow lighter; to become less dark or lowering; to
brighten; to clear, as the sky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighten</ent><br/
<hw>Light"en</hw>, <pos>v. t.</pos> <ety>[See <er>Light</er> to
illuminate.]</ety> <sn>1.</sn> <def>To make light or clear; to light; to
illuminate; <as>as, to <ex>lighten</ex> an apartment with lamps or gas;
to <ex>lighten</ex> the streets.</as></def> <mark>[In this sense less
common than <xex>light.</xex>]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A key of fire ran all along the shore,<br/
And <qex>lightened</qex> all the river with a blaze.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To illuminate with knowledge; to enlighten.</def>
<mark>[In this sense less common than <xex>enlighten</xex>.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lighten</qex> my spirit with one clear heavenly ray.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To emit or disclose in, or as in, lightning; to
flash out, like lightning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His eye . . . <qex>lightens</qex> forth<br/
Controlling majesty.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To free from trouble and fill with joy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They looked unto him, and were <qex>lightened</qex>.</q>
<rj><qau>Ps. xxxiv. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighten</ent><br/
<hw>Light"en</hw>, <pos>v. t.</pos> <ety>[See <er>Light</er> not
heavy.]</ety> <sn>1.</sn> <def>To make lighter, or less heavy; to reduce
in weight; to relieve of part of a load or burden; <as>as, to
<ex>lighten</ex> a ship by unloading; to <ex>lighten</ex> a load or
burden.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make less burdensome or afflictive; to alleviate;
<as>as, to <ex>lighten</ex> the cares of life or the burden of
grief</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cheer; to exhilarate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lightens</qex> my humor with his merry jests.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lightening</ent><br/
<hw>lightening</hw> <pos>n.</pos> <def>The process of changing to a
lighter color.</def><br/
<syn><b>Syn. --</b> whitening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lighter</ent><br/
<hw>Light"er</hw> <pr>(l<imac/t"<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, lights; <as>as, a <ex>lighter</ex> of
lamps</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>cigarette lighter</b></col> <cd>A small portable device
which produces a flame when a button is pushed, carried on the person to
allow one to light cigarettes conveniently, and taking the place of a
match. It may have a reservoir of liquid fuel conveyed by a wick, or may
contain compressed butane as the fuel.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Lighter</ent><br/
<hw>Light"er</hw>, <pos>n.</pos> <ety>[D. <ets>ligter</ets>, fr.
<ets>ligt</ets> light. See <er>Light</er> not heavy.]</ety>
<fld>(Naut.)</fld> <def>A large boat or barge, mainly used in unloading
or loading vessels which can not reach the wharves at the place of
shipment or delivery.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lighter screw</b></col> <fld>(Mach.)</fld>, <cd>a screw
for adjusting the distance between the stones in a grinding mill by
raising or lowering the bridgetree.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighter</ent><br/
<hw>Light"er</hw>, <pos>v. t.</pos> <def>To convey by a lighter, as to
or from the shore; <as>as, to <ex>lighter</ex> the cargo of a
ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighterage</ent><br/
<hw>Light"er*age</hw> <pr>(l<imac/t"<etil/r*<asl/j; 48)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>The price paid for conveyance of goods on
a lighter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of unloading into a lighter, or of conveying
by a lighter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighterman</ent><br/
<hw>Light"er*man</hw> <pr>(l<imac/t"<etil/r*m<acr/n)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Lightermen</plw>
<pr>(l<imac/t"<etil/r*m<eit/n)</pr>.</plu> <def>A person employed on, or
who manages, a lighter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-fingered</ent><br/
<hw>Light"-fin`gered</hw> <pr>(l<imac/t"f<icr/<nsm/`g<etil/rd)</pr>,
<pos>a.</pos> <def>Dexterous in taking and conveying away; thievish;
pilfering; addicted to petty thefts.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-footed</ent><br/
<ent>Light-foot</ent><br/
<mhw>{ <hw>Light"-foot`</hw> <pr>(l<imac/t"f<oocr/t`)</pr>,
<hw>Light"-foot`ed</hw>, }</mhw> <pos>a.</pos> <def>Having a light,
springy step; moving lightly and nimbly; nimble in running or dancing;
active; <as>as, <ex>light-foot</ex> Iris</as>. Opposite of
<ant>heavy-footed</ant>.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightful</ent><br/
<hw>Light"ful</hw> <pr>(l<imac/t"f<usdot/l)</pr>, <pos>a.</pos>
<def>Full of light; bright.</def> <mark>[R.]</mark>
<ldquo/<xex>Lightful</xex> presence.<rdquo/
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>light-green</ent><br/
<hw>light-green</hw> <pos>adj.</pos> <def>Having a light green color,
similar to the color of fresh grass.</def><br/
<syn><b>Syn. --</b> green, greenish, dark-green.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>light-haired</ent><br/
<hw>light-haired</hw> <pos>adj.</pos> <def>being or having light colored
skin and hair; <as>as, a certain <ex>light-haired</ex> girl</as>.
Contrasted to <ant>brunet</ant>.</def> [Narrower terms:
<stype>redheaded</stype>]<br/
<syn><b>Syn. --</b> blond, blonde.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Light-handed</ent><br/
<hw>Light"-hand`ed</hw> <pr>(l<imac/t"h<acr/nd`<ecr/d)</pr>,
<pos>a.</pos> <sn>1.</sn> <fld>(Naut.)</fld> <def>Not having a full
complement of men; <as>as, a vessel
<ex>light-handed</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>having a metaphorically delicate touch.</def>
<ant>heavy-handed</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><q>the translation is . . . <qex>light-handed</qex> . . . and
generally unobtrusive.</q> <rj><qau>New Yorker.</qau></rj></p>

<p><ent>Light-headed</ent><br/
<hw>Light"-head`ed</hw> <pr>(l<imac/t"h<ecr/d`<ecr/d)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Disordered in the head; dizzy; feeling
faint; delirious.</def> <wns>[wns=1]</wns>
<rj><au>Walpole.</au></rj><br/
<syn><b>Syn. --</b> faint, swooning, lightheaded.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Thoughtless; heedless; volatile; unsteady; fickle;
loose; lacking seriousness; given to frivolity; <as>as,
<ex>light-headed</ex> teenagers</as>.</def> <wns>[wns=2]</wns>
<ldquo/<xex>Light-headed</xex>, weak men.<rdquo/
<rj><au>Clarendon.</au></rj><br/
<syn><b>Syn. --</b> airheaded, dizzy, empty-headed, featherbrained,
giddy, lightheaded, silly.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>Light"-head`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-hearted</ent><br/
<hw>Light"-heart`ed</hw> <pr>(l<imac/t"h<aum/rt`<ecr/d)</pr>,
<pos>a.</pos> <def>Free from grief or anxiety; gay; cheerful;
merry.</def> -- <wordforms><wf>Light"-heart`ed*ly</wf>, <pos>adv.</pos>
-- <wf>Light"-heart`ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-heeled</ent><br/
<hw>Light"-heeled`</hw> <pr>(l<imac/t"h<emac/ld`)</pr>, <pos>a.</pos>
<def>Lively in walking or running; brisk; light-footed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-horseman</ent><br/
<hw>Light"-horse`man</hw> <pr>(l<imac/t"h<ocir/rs`m<ait/n)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>-men</plw>
<pr>(l<imac/t"h<ocir/rs`m<eit/n)</pr>.</plu> <sn>1.</sn> <def>A soldier
who serves in the light horse. See under 5th <er>Light</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A West Indian fish of the genus
<gen>Ephippus</gen>, remarkable for its high dorsal fin and brilliant
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighthouse</ent><br/
<hw>Light"house`</hw> <pr>(l<imac/t"hous`)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lighthouses</plw>
<pr>(l<imac/t"houz`<ecr/z)</pr>.</plu> <def>A tower or other building
with a powerful light at top, erected at the entrance of a port, or at
some important point on a coast, to serve as a guide to mariners at
night; a pharos.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighting</ent><br/
<hw>Light"ing</hw>, <pos>n.</pos> <fld>(Metal.)</fld> <def>A name
sometimes applied to the process of annealing metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-legged</ent><br/
<hw>Light"-legged`</hw> <pr>(l<imac/t"l<ecr/gd`)</pr>, <pos>a.</pos>
<def>Nimble; swift of foot.</def> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightless</ent><br/
<hw>Light"less</hw>, <pos>a.</pos> <def>Destitute of light; dark.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lightlessness</ent><br/
<hw>lightlessness</hw> <pos>n.</pos> <def>total absence of light;
blackness.</def><br/
<syn><b>Syn. --</b> total darkness, blackness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lightly</ent><br/
<hw>Light"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>With little weight;
with little force; <as>as, to tread <ex>lightly</ex>; to press
<ex>lightly</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet shall thy grave with rising flowers be drest,<br/
And the green turf lie <qex>lightly</qex> on thy breast.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Him thus intent Ithuriel with his spear<br/
Touched <qex>lightly</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Swiftly; nimbly; with agility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So mikle was that barge, it might not <qex>lightly</qex> sail.</q>
<rj><qau>R. of Brunne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Watch what thou seest and <qex>lightly</qex> bring me word.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Without deep impression.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soft ideas of the cheerful note,<br/
<qex>Lightly</qex> received, were easily forgot.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In a small degree; slightly; not severely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At the first he <qex>lightly</qex> afflicted the land of Zebulun .
. . and afterward did more grievously afflict her.</q> <rj><qau>Is. ix.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>With little effort or difficulty; easily;
readily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>lightly</qex> come, shall <qex>lightly</qex> go.</q>
<rj><qau>Old Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They come <qex>lightly</qex> by the malt, and need not spare
it.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Without reason, or for reasons of little
weight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Flatter not the rich, neither do thou willingly or
<qex>lightly</qex> appear before great personages.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Commonly; usually.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Fisher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The great thieves of a state are <qex>lightly</qex> the officers
of the crown.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Without dejection; cheerfully.</def> <ldquo/Seeming
to bear it <xex>lightly</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Without heed or care; with levity; gayly;
airily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Matrimony . . . is not by any to be enterprised, nor taken in
hand, unadvisedly, <qex>lightly</qex>, or wantonly.</q> <rj><qau>Book of
Common Prayer [Eng. Ed.].</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Not chastely; wantonly.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightman</ent><br/
<hw>Light"man</hw> <pr>(l<imac/t"m<acr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-men</plw> <pr>(l<imac/t"m<ecr/n)</pr>.</plu>
<def>A man who carries or takes care of a light.</def> <rj><au>T.
Brown.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-minded</ent><br/
<hw>Light"-mind`ed</hw> <pr>(l<imac/t"m<imac/nd`<ecr/d)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Unsettled; unsteady; volatile; not
considerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>showing inappropriate levity.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> flippant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p> -- <wordforms><wf>Light"-mind`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightness</ent><br/
<hw>Light"ness</hw>, <pos>n.</pos> <ety>[From <er>Light</er> not
heavy.]</ety> <def>The state, condition, or quality, of being light or
not heavy; buoyancy; levity; fickleness; nimbleness; delicacy;
grace.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Levity; volatility; instability; inconstancy;
unsteadiness; giddiness; flightiness; airiness; gayety; liveliness;
agility; nimbleness; sprightliness; briskness; swiftness; ease;
facility.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightness</ent><br/
<hw>Light"ness</hw>, <pos>n.</pos> <ety>[From <er>Light</er>
bright.]</ety> <sn>1.</sn> <def>Illumination, or degree of illumination;
<as>as, the <ex>lightness</ex> of a room</as>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Absence of depth or of duskiness in color; <as>as,
the <ex>lightness</ex> of a tint; <ex>lightness</ex> of
complexion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightning</ent><br/
<hw>Light"ning</hw> <pr>(l<imac/t"n<icr/ng)</pr>, <pos>n.</pos>
<ety>[For <ets>lightening</ets>, fr. <ets>lighten</ets> to flash.]</ety>
<sn>1.</sn> <def>A discharge of atmospheric electricity, accompanied by
a vivid flash of light, commonly from one cloud to another, sometimes
from a cloud to the earth. The sound produced by the electricity in
passing rapidly through the atmosphere constitutes thunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of making bright, or the state of being made
bright; enlightenment; brightening, as of the mental powers.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ball lightning</b></col>, <cd>a rare form of lightning
sometimes seen as a globe of fire moving from the clouds to the
earth.</cd> -- <col><b>Chain lightning</b></col>, <cd>lightning in
angular, zigzag, or forked flashes.</cd> -- <col><b>Heat
lightning</b></col>, <cd>more or less vivid and extensive flashes of
electric light, without thunder, seen near the horizon, esp. at the
close of a hot day.</cd> -- <col><b>Lightning arrester</b></col>
<fld>(Telegraphy)</fld>, <cd>a device, at the place where a wire enters
a building, for preventing injury by lightning to an operator or
instrument. It consists of a short circuit to the ground interrupted by
a thin nonconductor over which lightning jumps. Called also
<altname>lightning discharger</altname>.</cd> -- <col><b>Lightning
bug</b></col> <fld>(Zool.)</fld>, <cd>a luminous beetle. See
<er>Firefly</er>.</cd> -- <col><b>Lightning conductor</b></col>, <cd>a
lightning rod.</cd> -- <col><b>Lightning glance</b></col>, <cd>a quick,
penetrating glance of a brilliant eye.</cd> -- <col><b>Lightning
rod</b></col>, <cd>a metallic rod set up on a building, or on the mast
of a vessel, and connected with the earth or water below, for the
purpose of protecting the building or vessel from lightning.</cd> --
<col><b>Sheet lightning</b></col>, <cd>a diffused glow of electric light
flashing out from the clouds, and illumining their outlines. The
appearance is sometimes due to the reflection of light from distant
flashes of lightning by the nearer clouds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightning</ent><br/
<hw>Light"ning</hw> <pr>(l<imac/t"n<icr/ng)</pr>, <pos>vb. n.</pos>
<def>Lightening.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light-o'-love</ent><br/
<hw>Light"-o'-love`</hw> <pr>(l<imac/t"<osl/-l<ucr/v`)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>An old tune of a dance, the name of which
made it a proverbial expression of levity, especially in love
matters.</def> <au>Nares.</au> <ldquo/Best sing it to the tune of
<xex>light-o'-love</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: A light or wanton woman; a woman inconstant
in love. Called also <altname>light-of-love</altname>.</def>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightroom</ent><br/
<hw>Light"room`</hw> <pr>(l<imac/t"r<oomac/m`)</pr>, <pos>n.</pos>
<def>A small room from which the magazine of a naval vessel is lighted,
being separated from the magazine by heavy glass windows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lights</ent><br/
<hw>lights</hw> <pr>(l<imac/ts)</pr>, <pos>n. pl.</pos> <ety>[So called
from their <ets>lightness</ets>.]</ety> <def>The lungs of an animal or
bird; -- sometimes coarsely applied to the lungs of a human
being.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>light-sensitive</ent><br/
<hw>light-sensitive</hw> <pos>adj.</pos> <sn>1.</sn> <def>Affected by
light; <as>as, the <ex>light-sensitive</ex> pigments in the
retina</as>.</def><br/
<syn><b>Syn. --</b> photosensitive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <fld>(Chem.)</fld>
<def>Decomposing under the influence of light; unstable when exposed to
light; -- of chemical compounds.</def><br/
[<source>PJC</source>]</p>

<p><ent>Light-ship</ent><br/
<ent>lightship</ent><br/
<mhw><hw>light"ship`</hw>, <hw>Light"-ship`</hw></mhw>
<pr>(l<imac/t"sh<icr/p`)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
vessel equipped like a lighthouse, carrying at the masthead a brilliant
light, and moored off a shoal or place of dangerous navigation where a
permanent lighthouse would be impracticable, to serve as a guide for
mariners; <as>as, the Ambrose <ex>lightship</ex> off New York was rammed
and damaged in 1950 by the Santa Monica</as>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>light-skinned</ent><br/
<hw>light-skinned</hw> <pos>adj.</pos> <def>having skin of a light
colored hue.</def> [Narrower terms: <stype>white (vs. black) </stype>]
<source>WordNet 1.5</source>]</p>

<p><ent>Lightsome</ent><br/
<hw>Light"some</hw> <pr>(l<imac/t"s<ucr/m)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Having light; lighted; not dark or gloomy;
bright.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>White walls make rooms more <qex>lightsome</qex> than black.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Gay; airy; cheering; exhilarating.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>lightsome</qex> affection of joy.</q>
<rj><qau>Hooker.</qau></rj></p>

<p>-- <wordforms><wf>Light"some*ly</wf>, <pos>adv.</pos> --
<wf>Light"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Happiness may walk soberly in dark attire, as well as dance
<qex>lightsomely</qex> in a gala dress.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lights-out</ent><br/
<hw>lights-out</hw> <pos>n.</pos> <def>a signal to turn the lights
out.</def><br/
<syn><b>Syn. --</b> taps.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Light-struck</ent><br/
<hw>Light"-struck`</hw>, <pos>a.</pos> <fld>(Photog.)</fld> <def>Damaged
by accidental exposure to light; light-fogged; -- said of plates or
films.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lightweight</ent><br/
<hw>Light"weight`</hw> <pr>(l<imac/t"w<amac/t`)</pr>, <pos>n.</pos>
<def>One of less than average weight;</def> <specif>specif.:</specif>
<def>In boxing, wrestling, etc., one weighing not more than 133 pounds
(U. S. amateur rules 135 pounds, Eng. 140 pounds).</def>
<wns>[wns=1]</wns><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A person of small importance or mental ability,
especially one who is unimportant but cheeky and presumptuous.</def>
<wns>[wns=2]</wns> <mark>[Colloq., Chiefly U. S.]</mark><br/
<syn><b>Syn. --</b> whippersnapper, jackanapes.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a wrestler who weighs 139-154 pounds.</def>
<wns>[wns=3]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lightweight</ent><br/
<hw>Light"weight`</hw>, <pos>a.</pos> <sn>1.</sn> <def>Light in weight,
as a coin; specif., applied to a man or animal who is a
lightweight.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>made of thin cloth, of relatively little weight; --
of clothing or fabrics; <as>as, <ex>lightweight</ex> fabrics</as>.</def>
<wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Light-winged</ent><br/
<hw>Light"-winged`</hw> <pr>(l<imac/t"w<icr/ngd`)</pr>, <pos>a.</pos>
<def>Having light and active wings; volatile; fleeting.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lightwood</ent><br/
<hw>Light"wood`</hw> <pr>(l<imac/t"w<oocr/d`)</pr>, <pos>n.</pos>
<def>Pine wood abounding in pitch, used for torches in the Southern
United States; pine knots, dry sticks, and the like, for kindling a fire
quickly or making a blaze.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lighty</ent><br/
<hw>Light"y</hw> <pr>(l<imac/t"<ycr/)</pr>, <pos>a.</pos>
<def>Illuminated.</def> <mark>[Obs.]</mark>
<rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Light year</ent><br/
<ent>Light-year</ent><br/
<mhw><hw>Light-year</hw>, <hw>Light year</hw></mhw>.
<fld>(Astron.)</fld> <sn>1.</sn> <def>The distance over which light can
travel in a year's time in a vacuum, 5.88 trillion miles (9.46 trillion
kilometers); -- used as a unit in expressing stellar distances. It is
more than 63,000 times as great as the distance from the earth to the
sun. The star nearest to the earth's sun is about 4 light years
distant.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>a very large difference; -- used figuratively to
express great differences (of distance, quality, time) in
comparisons.</def> <ldquo/Although having the same rank and salary, they
were <ex>light-years</ex> apart in their ability to perform their
jobs.<rdquo/<br/
[<source>PJC</source>]</p>

<p><ent>Lign-aloes</ent><br/
<hw>Lign`-al"oes</hw> <pr>(l<imac/n`<acr/l"<omac/z <or/
l<icr/g*n<acr/l"<omac/z)</pr>, <pos>n.</pos> <ety>[OE. <ets>ligne
aloes</ets>, fr. L. <ets>lignum</ets> wood + <ets>aloe</ets>
aloe.]</ety> <sn>1.</sn> <def>Aloes wood, or agallochum. See
<er>Agallochum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fragrant tree mentioned in the Bible.</def>
<rj><au>Num. xxiv. 6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligneous</ent><br/
<hw>Lig"ne*ous</hw> <pr>(l<icr/g"n<esl/*<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>ligneus</ets>, fr. <ets>lignum</ets> wood. Cf.
<er>Lignous</er>.]</ety> <def>Made of wood; consisting of wood; of the
nature of, or resembling, wood; woody.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It should be tried with shoots of vines and roots of red roses;
for it may be they, being of a more<qex>ligneous</qex> nature, will
incorporate with the tree itself.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ligneous marble</b></col>, <cd>wood coated or prepared so
as to resemble marble.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligniferous</ent><br/
<hw>Lig*nif"er*ous</hw> <pr>(l<icr/g*n<icr/f"<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>lignifer</ets>; <ets>lignum</ets> wood +
<ets>ferre</ets> to bear: cf. F. <ets>lignif<egrave/re</ets>.]</ety>
<def>Yielding or producing wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignification</ent><br/
<hw>Lig`ni*fi*ca"tion</hw>
<pr>(l<icr/g`n<icr/*f<icr/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>lignification</ets>. See <er>Lignify</er>.]</ety>
<fld>(Bot.)</fld> <def>A change in the character of a cell wall, by
which it becomes harder. It is supposed to be due to an incrustation of
lignin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligniform</ent><br/
<hw>Lig"ni*form</hw> <pr>(l<icr/g"n<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[L. <ets>lignum</ets> wood + <ets>-form</ets>: cf. F.
<ets>ligniforme</ets>.]</ety> <def>Like wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignify</ent><br/
<hw>Lig"ni*fy</hw> <pr>(l<icr/g"n<icr/*f<imac/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lignified</conjf>
<pr>(l<icr/g"n<icr/*f<imac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lignifying</conjf>
<pr>(l<icr/g"n<icr/*f<imac/`<icr/ng)</pr>.]</vmorph> <ety>[L.
<ets>lignum</ets> wood + <ets>-fy</ets>: cf. F.
<ets>lignifier</ets>.]</ety> <fld>(Bot.)</fld> <def>To convert into wood
or into a ligneous substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignify</ent><br/
<hw>Lig"ni*fy</hw>, <pos>v. i.</pos> <fld>(Bot.)</fld> <def>To become
wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignin</ent><br/
<hw>Lig"nin</hw> <pr>(l<icr/g"n<icr/n)</pr>, <pos>n.</pos> <ety>[L.
<ets>lignum</ets> wood: cf. F. <ets>lignine</ets>.]</ety>
<fld>(Bot.)</fld> <def>A substance characterizing wood cells and
differing from cellulose in its conduct with certain chemical
reagents.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Recent authors have distinguished four forms of this
substance, naming them <xex>lignose</xex>, <xex>lignin</xex>,
<xex>lignone</xex>, and <xex>lignireose</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligniperdous</ent><br/
<hw>Lig`ni*per"dous</hw> <pr>(l<icr/g`n<icr/*p<etil/r"d<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>lignum</ets> wood + <ets>perdere</ets> to
destroy: cf. F. <ets>ligniperde</ets>.]</ety> <fld>(Zool.)</fld>
<def>Wood-destroying; -- said of certain insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignireose</ent><br/
<hw>Lig*nir"e*ose`</hw> <pr>(l<icr/g*n<icr/r"<esl/*<omac/s`)</pr>,
<pos>n.</pos> <fld>(Bot.)</fld> <def>See <er>Lignin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignite</ent><br/
<hw>Lig"nite</hw> <pr>(l<icr/g"n<imac/t)</pr>, <pos>n.</pos> <ety>[L.
<ets>lignum</ets> wood: cf. F. <ets>lignite</ets>.]</ety>
<fld>(Min.)</fld> <def>Mineral coal retaining the texture of the wood
from which it was formed, and burning with an empyreumatic odor. It is
of more recent origin than the anthracite and bituminous coal of the
proper coal series. Called also <altname>brown coal</altname>,
<altname>wood coal</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignitic</ent><br/
<hw>Lig*nit"ic</hw> <pr>(l<icr/g*n<icr/t"<icr/k)</pr>, <pos>a.</pos>
<def>Containing lignite; resembling, or of the nature of, lignite;
<as>as, <ex>lignitic</ex> clay</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lignitic group</b></col>. <cd>See <er>Laramie
Group</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignitiferous</ent><br/
<hw>Lig`ni*tif"er*ous</hw>
<pr>(l<icr/g`n<icr/*t<icr/f"<etil/r*<ucr/s)</pr>, <pos>a.</pos>
<ety>[<ets>Lignite</ets> + <ets>-ferous</ets>.]</ety> <def>Producing or
containing lignite; lignitic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignoceric</ent><br/
<hw>Lig`no*cer"ic</hw> <pr>(l<icr/g`n<osl/*s<ecr/r"<icr/k)</pr>,
<pos>a.</pos> <ety>[L. <ets>lignum</ets> wood + <ets>cera</ets>
wax.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or designating, an
acid of the formic acid series, found in the tar, wax, or paraffine
obtained by distilling certain kinds of wood, as the beech.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignone</ent><br/
<hw>Lig"none`</hw> <pr>(l<icr/g"n<omac/n`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>See <er>Lignin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lignotuber</ent><br/
<hw>Lig`no*tu"ber</hw> <pr>(l<icr/g`n<omac/*t<oomac/"b<etil/r)</pr>,
<pos>n.</pos> <fld>(Bot.)</fld> <def>A woody swelling on a tree or
shrub, usually contained entirely below or just above the surface of the
ground, and having buds which enable the plant to survive cutting or a
fire that destroys the portion of the plant above ground. After such
damage to the plant, sprouting commences from the lignotuber.</def><br/
[<source>Jeremy Lunn</source>]</p>

<p><ent>Lignous</ent><br/
<ent>Lignose</ent><br/
<mhw>{ <hw>Lig*nose"</hw> <pr>(l<icr/g*n<omac/s")</pr>,
<hw>Lig"nous</hw> <pr>(l<icr/g"n<ucr/s)</pr>, }</mhw> <pos>a.</pos>
<ety>[L. <ets>lignosus</ets>, fr. <ets>lignum</ets> wood: cf. F.
<ets>ligneux</ets>. Cf. <er>Ligneous</er>.]</ety> <def>Ligneous.</def>
<mark>[R.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignose</ent><br/
<hw>Lig"nose`</hw> <pr>(l<icr/g"n<omac/s`)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Bot.)</fld> <def>See <er>Lignin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>An explosive compound of wood
fiber and nitroglycerin. See <er>Nitroglycerin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignum rhodium</ent><br/
\'d8<hw>Lig"num rho"di*um</hw> <pr>(l<icr/g"n<ucr/m
r<omac/"d<icr/*<ucr/m)</pr>. <ety>[NL., fr. L. <ets>lignum</ets> wood +
Gr. <grk>"ro`don</grk> a rose.]</ety> <fld>(Bot.)</fld> <def>The
fragrant wood of several shrubs and trees, especially of species of
<gen>Rhodorhiza</gen> from the Canary Islands, and of the West Indian
<spn>Amyris balsamifera</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lignum-vitae</ent><br/
\'d8<hw>Lig"num-vi"tae</hw> <pr>(l<icr/g"n<ucr/m v<imac/"t<emac/)</pr>,
<pos>n.</pos> <ety>[L., wood of life; <ets>lignum</ets> wood +
<ets>vita</ets>, genitive <ets>vit<ae/</ets>, life.]</ety>
<fld>(Bot.)</fld> <def>A tree (<spn>Guaiacum officinale</spn>) found in
the warm latitudes of America, from which the <prod>guaiacum</prod> of
medicine is procured. Its wood is very hard and heavy, and is used for
various mechanical purposes, as for the wheels of ships' blocks, cogs,
bearings, and the like. See <er>Guaiacum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In New Zealand the <spn>Metrosideros buxifolia</spn> is
called lignum-vit<ae/, and in Australia a species of <gen>Acacia</gen>.
The bastard lignum-vit<ae/ is a West Indian tree (<spn>Sarcomphalus
laurinus</spn>).</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligroin</ent><br/
<hw>Lig"ro*in</hw> <pr>(l<icr/g"r<osl/*<icr/n)</pr>, <pos>n.</pos>
<def>A trade name applied somewhat indefinitely to some of the volatile
products obtained in refining crude petroleum. It is a complex and
variable mixture of several hydrocarbons, generally boils below 170<deg/
Fahr., and is more inflammable than safe kerosene. It is used as a
solvent, as a carburetant for air gas, and for illumination in special
lamps.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 853 pr=VMG --></p>

<p><ent>Ligsam</ent><br/
<hw>Lig"sam</hw> <pr>(l<icr/g"s<ait/m)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>liggen</ets> to lie, E. <ets>lie</ets> to be prostrate, and E.
<ets>flotsam</ets>, <ets>jetsam</ets>, or <ets>ligan</ets>.]</ety>
<def>Same as <er>Ligan</er>.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligula</ent><br/
<ent>Ligulae</ent><br/
\'d8<hw>Lig"u*la</hw> <pr>(l<icr/g"<usl/*l<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Ligul<ae/</plw> <pr>(-l<emac/)</pr>, E.
<plw>Ligulas</plw> <pr>(-l<adot/z)</pr>.</plu> <ety>[L., a little
tongue. See <er>Ligule</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>See <er>Ligule</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The central process,
or front edge, of the labium of insects. It sometimes serves as a tongue
or proboscis, as in bees.</def> <see>[See <xex>Illust.</xex> under
<er>Labium</er>, and <er>Hymenoptera</er>.]</see> <sd>(b)</sd> <def>A
tongue-shaped lobe of the parapodia of annelids. See
<er>Parapodium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligulated</ent><br/
<ent>Ligulate</ent><br/
<mhw>{ <hw>Lig"u*late</hw> <pr>(l<icr/g"<usl/*l<asl/t)</pr>,
<hw>Lig"u*la`ted</hw> <pr>(l<icr/g"<usl/*l<amac/`t<ecr/d)</pr>, }</mhw>
<pos>a.</pos> <ety>[Cf. F. <ets>ligul<eacute/</ets>. See
<er>Ligule</er>, and cf. <er>Lingulate</er>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Like a bandage, or strap; strap-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Composed of ligules.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ligulate flower</b></col>, <cd>a species of compound
flower, the florets of which have their corollets flat, spreading out
toward the end, with the base only tubular.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligule</ent><br/
<hw>Lig"ule</hw> <pr>(l<icr/g"<usl/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>ligula</ets>, <ets>lingula</ets>, little tongue, dim of
<ets>lingua</ets> tongue : cf. F. <ets>ligule</ets>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>The thin and scarious projection
from the upper end of the sheath of a leaf of grass.</def> <sd>(b)</sd>
<def>A strap-shaped corolla of flowers of Composit<ae/.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A band of white matter in the
wall of fourth ventricle of the brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liguliflorous</ent><br/
<hw>Lig`u*li*flo"rous</hw>
<pr>(l<icr/g`<usl/*l<icr/*fl<omac/"r<ucr/s)</pr>, <pos>a.</pos>
<ety>[<ets>Ligule</ets> + L. <ets>flos</ets>, <ets>floris</ets>, a
flower.]</ety> <fld>(Bot.)</fld> <def>Bearing only ligulate flowers; --
said of a large suborder of composite plants, such as the dandelion,
lettuce, hawkweed, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligure</ent><br/
<hw>Lig"ure</hw> <pr>(l<icr/g"<usl/r; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>ligurius</ets>, Gr. <grk>ligy`rion</grk>, <grk>liggoy`rion</grk>,
<grk>ligkoy`rion</grk>, <grk>lygkoy`rion</grk>, equiv. to Heb.
<ets>leshem</ets>.]</ety> <def>A kind of precious stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The third row a <qex>ligure</qex>, an agate, and an amethyst.</q>
<rj><qau>Ex. xxviii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ligustrin</ent><br/
<hw>Li*gus"trin</hw> <pr>(l<isl/*g<ucr/s"tr<icr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A bitter principle found in the bark of the
privet <spn>(Ligustrum vulgare)</spn>, and extracted as a white
crystalline substance with a warm, bitter taste; -- called also
<altname>ligustron</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likable</ent><br/
<hw>Lik"a*ble</hw> <pr>(l<imac/k"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Such as can be liked; such as to attract liking; easy to like;
evoking sympathy; <as>as, a <ex>likable</ex> person</as>.</def>
<rj><au>Thackeray.</au></rj> <wns>[wns=1+2]</wns><br/
<syn><b>Syn. --</b> appealing, likable.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>disposed to please.</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> amiable, agreeable, good-humored, good-humoured,
likable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Like</ent><br/
<hw>Like</hw> <pr>(l<imac/k)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Liker</adjf>
<pr>(l<imac/k"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Likest</adjf>.]</amorph> <ety>[OE. <ets>lik</ets>,
<ets>ilik</ets>, <ets>gelic</ets>, AS. <ets>gel<imac/c</ets>, fr. pref.
<ets>ge-</ets> + <ets>l<imac/c</ets> body, and orig. meaning, having the
same body, shape, or appearance, and hence, like; akin to OS.
<ets>gil<imac/k</ets>, D. <ets>gelijk</ets>, G. <ets>gleich</ets>, OHG.
<ets>gil<imac/h</ets>, Icel. <ets>l<imac/kr</ets>,
<ets>gl<imac/kr</ets>, Dan. <ets>lig</ets>, Sw. <ets>lik</ets>, Goth.
<ets>galeiks</ets>, OS. <ets>lik</ets> body, D. <ets>lijk</ets>, G.
<ets>leiche</ets>, Icel. <ets>l<imac/k</ets>, Sw. <ets>lik</ets>, Goth.
<ets>leik</ets>. The English adverbial ending<ets>-ly</ets> is from the
same adjective. Cf. <er>Each</er>, <er>Such</er>, <er>Which</er>.]</ety>
<sn>1.</sn> <def>Having the same, or nearly the same, appearance,
qualities, or characteristics; resembling; similar to; similar; alike;
-- often with <xex>in</xex> and the particulars of the resemblance;
<as>as, they are <ex>like</ex> each other in features, complexion, and
many traits of character</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is as <qex>like</qex> you<br/
As cherry is to cherry.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Like</qex> master, <qex>like</qex> man.</q> <rj><qau>Old
Prov.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He giveth snow <qex>like</qex> wool; he scattereth the hoar-frost
<qex>like</qex> ashes.</q> <rj><qau>Ps. cxlvii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>To</xex>, which formerly often followed
<xex>like</xex>, is now usually omitted.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Equal, or nearly equal; <as>as, fields of
<ex>like</ex> extent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More clergymen were impoverished by the late war than ever in the
<qex>like</qex> space before.</q> <rj><qau>Sprat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having probability; affording probability; probable;
likely.</def> <usage>[<xex>Likely</xex> is more used now.]</usage>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But it is <qex>like</qex> the jolly world about us will scoff at
the paradox of these practices.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Many were not easy to be governed, nor <qex>like</qex> to conform
themselves to strict rules.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Inclined toward; disposed to; <as>as, to feel
<ex>like</ex> taking a walk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Had like</b></col> (followed by the infinitive), <cd>had
nearly; came little short of.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Had like</qex> to have been my utter overthrow.</q>
<rj><qau>Sir W. Raleigh</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ramona <qex>had like</qex> to have said the literal truth, . . .
but recollected herself in time.</q> <rj><qau>Mrs. H. H.
Jackson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Like figures</b></col> <fld>(Geom.)</fld>, <cd>similar
figures.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Like</xex> is used as a suffix, converting nouns
into adjectives expressing resemblance to the noun; as,
man<xex>like</xex>, like a man; child<xex>like</xex>, like a child;
god<xex>like</xex>, like a god, etc. Such compounds are readily formed
whenever convenient, and several, as <xex>crescentlike</xex>,
<xex>serpentlike</xex>, <xex>hairlike</xex>, etc., are used in this
book, although, in some cases, not entered in the vocabulary. Such
combinations as <xex>bell-like</xex>, <xex>ball-like</xex>, etc., are
hyphened.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Like</ent><br/
<hw>Like</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is equal or
similar to another; the counterpart; an exact resemblance; a
copy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was a man, take him for all in all,<br/
I shall not look upon his <qex>like</qex> again.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A liking; a preference; inclination; -- usually in
<pluf>pl.</pluf>; <as>as, we all have <ex>likes</ex> and
dislikes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Golf)</fld> <def>The stroke which equalizes the
number of strokes played by the opposing player or side; <as>as, to play
the <ex>like</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Like</ent><br/
<hw>Like</hw>, <pos>adv.</pos> <ety>[AS. <ets>gel<imac/ce</ets>. See
<er>Like</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>In a manner like
that of; in a manner similar to; <as>as, do not act <ex>like</ex>
him</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He maketh them to stagger <qex>like</qex> a drunken man.</q>
<rj><qau>Job xii. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Like</xex>, as here used, is regarded by some
grammarians as a preposition.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a like or similar manner.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Like</qex> as a father pitieth his children, so the Lord
pitieth them that fear him.</q> <rj><qau>Ps. ciii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Likely; probably.</def> <ldquo/<xex>Like</xex>
enough it will.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Like</ent><br/
<hw>Like</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Liked</conjf> <pr>(l<imac/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Liking</conjf>.]</vmorph> <ety>[OE. <ets>liken</ets> to please,
AS. <ets>l<imac/cian</ets>, <ets>gel<imac/cian</ets>, fr.
<ets>gel<imac/c</ets>. See <er>Like</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>To suit; to please; to be agreeable to.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cornwall him <qex>liked</qex> best, therefore he chose there.</q>
<rj><qau>R. of Gloucester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I willingly confess that it <qex>likes</qex> me much better when I
find virtue in a fair lodging than when I am bound to seek it in an
ill-favored creature.</q> <rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be pleased with in a moderate degree; to approve;
to take satisfaction in; to enjoy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He proceeded from looking to <qex>liking</qex>, and from
<qex>liking</qex> to loving.</q> <rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To liken; to compare.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Like</qex> me to the peasant boys of France.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Like</ent><br/
<hw>Like</hw> <pr>(l<imac/k)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
be pleased; to choose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He may either go or stay, as he best <qex>likes</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have an appearance or expression; to look; to
seem to be (in a specified condition).</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>like</qex> well, and bear your years very well.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To come near; to avoid with difficulty; to escape
narrowly; <as>as, he <ex>liked</ex> to have been too late</as>. Cf.
<xex>Had like</xex>, under <er>Like</er>, <pos>a.</pos></def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He probably got his death, as he <qex>liked</qex> to have done two
years ago, by viewing the troops for the expedition from the wall of
Kensington Garden.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To like of</b></col>, <cd>to be pleased with.</cd>
<mark>[Obs.]</mark> <rj><au>Massinger.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likeable</ent><br/
<hw>Like"a*ble</hw> <pr>(l<imac/k"<adot/*b'l)</pr>, <pos>a.</pos>
<def>See <er>Likable.</er></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likehood</ent><br/
<hw>Like"hood</hw> <pr>(l<imac/k"h<oocr/d)</pr>, <pos>n.</pos>
<def>Likelihood.</def> <mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likelihood</ent><br/
<hw>Like"li*hood</hw> <pr>(l<imac/k"l<icr/*h<oocr/d)</pr>, <pos>n.</pos>
<ety>[<ets>Likely</ets> + <ets>-hood</ets>.]</ety> <sn>1.</sn>
<def>Appearance; show; sign; expression.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What of his heart perceive you in his face<br/
By any <qex>likelihood</qex> he showed to-day ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Likeness; resemblance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no <qex>likelihood</qex> between pure light and black
darkness, or between righteousness and reprobation.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Appearance of truth or reality; probability;
verisimilitude.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Statistical probability; probability of being true
or of occurring in the future; <as>as, the <ex>likelihood</ex> of being
abducted by aliens is close to zero.</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Likeliness</ent><br/
<hw>Like"li*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>Likelihood;
probability.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suitableness; agreeableness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likely</ent><br/
<hw>Like"ly</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Likelier</adjf> <pr>(l<imac/k"l<icr/*<etil/r)</pr>;
<pos>superl.</pos> <adjf>Likeliest</adjf>.]</amorph> <ety>[That is,
<ets>like-like</ets>. See <er>Like</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>Worthy of belief; probable; credible; <as>as, a
<ex>likely</ex> story</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It seems <qex>likely</qex> that he was in hope of being busy and
conspicuous.</q> <rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having probability; having or giving reason to
expect; -- followed by the infinitive; <as>as, it is <ex>likely</ex> to
rain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Similar; like; alike.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Such as suits; good-looking; pleasing; agreeable;
handsome.</def> <rj><au>Shak.</au> <au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having such qualities as make success probable; well
adapted to the place; promising; <as>as, a <ex>likely</ex> young man; a
<ex>likely</ex> servant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Improbable; unlikely; -- used ironically; <as>as, a
<ex>likely</ex> story</as>.</def> <mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Likely</ent><br/
<hw>Like"ly</hw>, <pos>adv.</pos> <def>In all probability;
probably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While man was innocent he was <qex>likely</qex> ignorant of
nothing that imported him to know.</q> <rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Like-minded</ent><br/
<hw>Like"-mind`ed</hw> <pr>(l<imac/k"m<imac/nd`<ecr/d)</pr>,
<pos>a.</pos> <def>Having a like disposition or purpose; of the same
mind.</def> <rj><au>Tillotson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liken</ent><br/
<hw>Lik"en</hw> <pr>(l<imac/k"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Likened</conjf>
<pr>(l<imac/k"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Likening</conjf>.]</vmorph> <ety>[OE. <ets>liknen</ets>. See
<er>Like</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To allege, or
think, to be like; to represent as like; to compare; <as>as, to
<ex>liken</ex> life to a pilgrimage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whosoever heareth these sayings of mine, and doeth them, I will
<qex>liken</qex> him unto a wise man which built his house upon a
rock.</q> <rj><qau>Matt. vii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make or cause to be like.</def> <mark>[R.]</mark>
<rj><au>Brougham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likeness</ent><br/
<hw>Like"ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>gel<imac/cnes</ets>.]</ety> <sn>1.</sn> <def>The state or quality
of being like; similitude; resemblance; similarity; <as>as, the
<ex>likeness</ex> of the one to the other is remarkable</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Appearance or form; guise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An enemy in the <qex>likeness</qex> of a friend.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which closely resembles; a portrait.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[How he looked] the <qex>likenesses</qex> of him which still
remain enable us to imagine.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A comparison; parable; proverb.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He said to them, Soothly ye shall say to me this
<qex>likeness</qex>, Leech, heal thyself.</q> <rj><qau>Wyclif (Luke iv.
23).</qau></rj></p>

<p><syn><b>Syn.</b> -- Similarity; parallel; similitude; representation;
portrait; effigy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likerousness</ent><br/
<ent>Likerous</ent><br/
<mhw>{<hw>Lik"er*ous</hw> <pr>(l<icr/k"<etil/r*<ucr/s)</pr>,
<pos>a.</pos>, <hw>Lik"er*ous*ness</hw>, <pos>n.</pos> }</mhw>
<mark>[Obs.]</mark> <def>See <er>Lickerish</er>,
<er>Lickerishness</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likewise</ent><br/
<hw>Like"wise`</hw> <pr>(l<imac/k"w<imac/z`)</pr>, <pos>adv. &
conj.</pos> <ety>[See <er>Wise</er>, <pos>n.</pos>]</ety> <def>In like
manner; also; moreover; too. See <er>Also</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go, and do thou <qex>likewise</qex>.</q> <rj><qau>Luke x.
37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For he seeth that wise men die; <qex>likewise</qex> the fool and
the brutish person perish.</q> <rj><qau>Ps. xlix. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Likin</ent><br/
\'d8<hw>Li"kin`</hw>, <pos>n.</pos> <altsp>[Written also
<asp>lekin</asp>.]</altsp> <ety>[ Chin. <ets>li kin</ets>; <ets>li</ets>
the thousandth part of a tael + <ets>kin</ets> money.]</ety> <def>A
Chinese provincial tax levied at many inland stations upon imports or
articles in transit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/<qex>Likin</qex>,<rdquo/ which used to be regarded as
illegal, as one of the many, <ldquo/squeezes<rdquo/ imposed by the
mandarins, is, in Jamieson's opinion, just as legal as any other form of
taxation.</q> <rj><qau>A. R. Colquhoun.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Liking</ent><br/
<hw>Lik"ing</hw> <pr>(l<imac/k"<icr/ng)</pr>, <pos>p. a.</pos>
<def>Looking; appearing; <as>as, better or worse <ex>liking</ex></as>.
See <er>Like</er>, to look.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why should he see your faces worse <qex>liking</qex> than the
children which are of your sort?</q> <rj><qau>Dan. i. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liking</ent><br/
<hw>Lik"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being
pleasing; a suiting. See <cref>On liking</cref>, below.</def>
<mark>[Obs. or Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being pleased with, or attracted
toward, some thing or person; hence, inclination; desire; pleasure;
preference; -- often with <ptcl>for</ptcl>, formerly with
<ptcl>to</ptcl>; <as>as, it is an amusement I have no <ex>liking</ex>
for</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the human intellect hath once taken a <qex>liking</qex> to any
doctrine, . . . it draws everything else into harmony with that
doctrine, and to its support.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Appearance; look; figure; state of body as to health
or condition.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall think the worse of fat men, as long as I have an eye to
make difference of men's <qex>liking</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their young ones are in good <qex>liking</qex>.</q> <rj><qau>Job.
xxxix. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>On liking</b></col>, <cd>on condition of being pleasing
to or suiting; also, on condition of being pleased with; as, to hold a
place of service <xex>on liking</xex>; to engage a servant <xex>on
liking</xex>.</cd> <mark>[Obs. or Prov. Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Would he be the degenerate scion of that royal line . . . to be a
king <xex>on liking</xex> and on sufferance?</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilac</ent><br/
<hw>Li"lac</hw> <pr>(l<imac/"l<ait/k)</pr>, <pos>n.</pos> <altsp>[Also
<asp>lilach</asp>.]</altsp> <ety>[Sp. <ets>lilac</ets>, <ets>lila</ets>,
Ar. <ets>l<imac/lak</ets>, fr. Per. <ets>l<imac/laj</ets>,
<ets>l<imac/lanj</ets>, <ets>l<imac/lang</ets>, <ets>n<imac/laj</ets>,
<ets>n<imac/l</ets>, the indigo plant, or from the kindred
<ets>l<imac/lak</ets> bluish, the flowers being named from the color.
Cf. <er>Anil</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A shrub of
the genus <gen>Syringa</gen>. There are six species, natives of Europe
and Asia. <spn>Syringa vulgaris</spn>, the common lilac, and
<spn>Syringa Persica</spn>, the Persian lilac, are frequently cultivated
for the fragrance and beauty of their purplish or white flowers. In the
British colonies various other shrubs have this name.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A light purplish color like that of the flower of
the purplish lilac.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>California lilac</b></col> <fld>(Bot.)</fld>, <cd>a low
shrub with dense clusters of purplish flowers (<spn>Ceanothus
thyrsiflorus</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilacin</ent><br/
<hw>Lil"a*cin</hw> <pr>(l<icr/l"<adot/*s<icr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>See <er>Syringin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liliaceous</ent><br/
<hw>Lil`i*a"ceous</hw> <pr>(l<icr/l`<icr/*<amac/"sh<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>liliaceus</ets>, fr. <ets>lilium</ets> lily.
See <er>Lily</er>.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Of or
pertaining to a natural order of which the lily, tulip, and hyacinth are
well-known examples.</def> <sd>(b)</sd> <def>Like the blossom of a lily
in general form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilial</ent><br/
<hw>Lil"i*al</hw> <pr>(l<icr/l"<icr/*<ait/l)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having a general resemblance to lilies or to
liliaceous plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilied</ent><br/
<hw>Lil"ied</hw> <pr>(l<icr/l"<icr/d)</pr>, <pos>a.</pos> <def>Covered
with, or having many, lilies.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By sandy Ladon's <qex>lilied</qex> banks.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liliidae</ent><br/
<hw>Liliidae</hw> <pos>prop. n.</pos> <def>one of four subclasses or
superorders of Monocotyledones; it comprises 17 families including:
<fam>Liliaceae</fam>; <fam>Alliaceae</fam>; <fam>Amaryllidaceae</fam>;
<fam>Iridaceae</fam>; <fam>Orchidaceae</fam>;
<fam>Trilliaceae</fam>.</def><br/
<syn><b>Syn. --</b> subclass <subclass>Liliidae</subclass>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>liliopsid</ent><br/
<hw>liliopsid</hw> <pos>n.</pos> <def>A flowering plant.</def><br/
<syn><b>Syn. --</b> monocot, monocotyledon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liliopsida</ent><br/
<hw>Liliopsida</hw> <pos>n.</pos> <def>A class comprising seed plants
that produce an embryo with a single cotyledon and parallel-veined
leaves. It includes the grasses; lilies; palms; and orchids. It is
divided into four subclasses or superorders: Alismatidae; Arecidae;
Commelinidae; and Liliidae.</def><br/
<syn><b>Syn. --</b> Monocotyledones, class Monocotyledones,
Monocotyledonae, class Monocotyledonae, class Liliopsida.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lilith</ent><br/
<hw>Lilith</hw> <pos>n.</pos> <def>a female demon who attacks
children.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lilium</ent><br/
<hw>Lilium</hw> <pos>n.</pos> <def>The type genus of the
<fam>Liliaceae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lilium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lill</ent><br/
<hw>Lill</hw> <pr>(l<icr/l)</pr>, <pos>v. i.</pos> <def>To loll.</def>
<mark>[Obs. or Prov.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilliputian</ent><br/
<hw>Lil`li*pu"tian</hw> <pr>(l<icr/l`l<icr/*p<umac/"sh<ait/n)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>One belonging to a very diminutive race
described in Swift's <ldquo/Voyage to Lilliput<rdquo/ or
<ldquo/Gulliver's Travels<rdquo/.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A person or thing of very
small size.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilliputian</ent><br/
<hw>Lil`li*pu"tian</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining
to the imaginary island of <etsep>Lilliput</etsep> described by Swift,
or to its inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Of very small size;
diminutive; insignificant; dwarfed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilly-pilly</ent><br/
<hw>Lil"ly-pil`ly</hw> <pr>(l<icr/l"l<ycr/-p<icr/l`l<ycr/)</pr>,
<pos>n.</pos> <fld>(Bot.)</fld> <def>An Australian myrtaceous tree
(<spn>Eugenia Smithii</spn>), having smooth ovate leaves, and panicles
of small white flowers. The wood is hard and fine-grained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilt</ent><br/
<hw>Lilt</hw> <pr>(l<icr/lt)</pr>, <pos>v. i.</pos> <ety>[Cf. Norw.
<ets>lilla</ets>, <ets>lirla</ets>, to sing in a high tone.]</ety>
<sn>1.</sn> <def>To do anything with animation and quickness, as to
skip, fly, or hop.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sing cheerfully.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilt</ent><br/
<hw>Lilt</hw>, <pos>v. t.</pos> <def>To utter with spirit, animation, or
gayety; to sing with spirit and liveliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A classic lecture, rich in sentiment,<br/
With scraps of thundrous epic <qex>lilted</qex> out<br/
By violet-hooded doctors.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lilt</ent><br/
<hw>Lilt</hw>, <pos>n.</pos> <sn>1.</sn> <def>Animated, brisk motion;
spirited rhythm; sprightliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The movement, the <qex>lilt</qex>, and the subtle charm of the
verse.</q> <rj><qau>F. Harrison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lively song or dance; a cheerful tune.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The housewife went about her work, or spun at her wheel, with a
<qex>lilt</qex> upon her lips.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lilting</ent><br/
<hw>lilting</hw> <pos>adj.</pos> <def>having a light rhythmical cadence;
<as>as, an easy <ex>lilting</ex> stride; a <ex>lilting</ex>
melody</as>.</def><br/
<syn><b>Syn. --</b> swinging, swingy, tripping.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lily</ent><br/
<hw>Lil"y</hw> <pr>(l<icr/l"<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lilies</plw> <pr>(l<icr/l"<icr/z)</pr>.</plu>
<ety>[AS. <ets>lilie</ets>, L. <ets>lilium</ets>, Gr.
<grk>lei`rion</grk>. Cf. <er>Flower-de-luce</er>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A plant and flower of the genus
<gen>Lilium</gen>, endogenous bulbous plants, having a regular perianth
of six colored pieces, six stamens, and a superior three-celled
ovary.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are nearly fifty species, all found in the North
Temperate zone. <spn>Lilium candidum</spn> and <spn>Lilium
longiflorum</spn> are the common white lilies of gardens; <spn>Lilium
Philadelphicum</spn> is the wild red lily of the Atlantic States.
<spn>Lilium Chalcedonicum</spn> is supposed to be the <ldquo/lily of the
field<rdquo/ in our Lord's parable; <spn>Lilium auratum</spn> is the
great gold-banded lily of Japan.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A name given to handsome flowering
plants of several genera, having some resemblance in color or form to a
true lily, as <gen>Pancratium</gen>, <gen>Crinum</gen>,
<gen>Amaryllis</gen>, <gen>Nerine</gen>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That end of a compass needle which should point to
the north; -- so called as often ornamented with the figure of a lily or
fleur-de-lis.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But sailing further, it veers its <qex>lily</qex> to the west.</q>
<rj><qau>Sir T. Browne. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Auction Bridge)</fld> <def>A royal spade; --
usually in <pluf>pl.</pluf> See <er>Royal spade</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>African lily</b></col> <fld>(Bot.)</fld>, <cd>the
blue-flowered <spn>Agapanthus umbellatus</spn>.</cd> -- <col><b>Atamasco
lily</b></col> <fld>(Bot.)</fld>, <cd>a plant of the genus
<gen>Zephyranthes</gen> (<spn>Zephyranthes Atamasco</spn>), having a
white and pink funnelform perianth, with six petal-like divisions
resembling those of a lily.</cd> <au>Gray.</au> -- <col><b>Blackberry
lily</b></col> <fld>(Bot.)</fld>, <cd>the <spn>Pardanthus
Chinensis</spn>, the black seeds of which form a dense mass like a
blackberry.</cd> -- <col><b>Bourbon lily</b></col> <fld>(Bot.)</fld>,
<cd><spn>Lilium candidum</spn>. See <xex>Illust.</xex></cd> --
<col><b>Butterfly lily</b></col>. <fld>(Bot.)</fld> <cd>Same as
<er>Mariposa lily</er>, in the Vocabulary.</cd> -- <col><b>Lily
beetle</b></col> <fld>(Zool.)</fld>, <cd>a European beetle
(<spn>Crioceris merdigera</spn>) which feeds upon the white lily.</cd>
-- <col><b>Lily daffodil</b></col> <fld>(Bot.)</fld>, <cd>a plant of the
genus <gen>Narcissus</gen>, and its flower.</cd> -- <col><b>Lily
encrinite</b></col> <fld>(Paleon.)</fld>, <cd>a fossil encrinite, esp.
<spn>Encrinus liliiformis</spn>. See <er>Encrinite</er>.</cd> --
<col><b>Lily hyacinth</b></col> <fld>(Bot.)</fld>, <cd>a plant of the
genus <gen>Hyacinthus</gen>.</cd> -- <col><b>Lily iron</b></col>, <cd>a
kind of harpoon with a detachable head of peculiar shape, used in
capturing swordfish.</cd> <-- illustration: Lily Iron --> --
<col><b>Lily of the valley</b></col> <fld>(Bot.)</fld>, <cd>a low
perennial herb (<spn>Convallaria majalis</spn>), having a raceme of
nodding, fragrant, white flowers.</cd> <-- illustration: Lily of the
valley --> -- <col><b>Lily pad</b></col>, <cd>the large floating leaf of
the water lily.</cd> <mark>[U. S.]</mark> <au>Lowell.</au> --
<col><b>Tiger lily</b></col> <fld>(Bot.)</fld>, <cd><spn>Lilium
tigrinum</spn>, the sepals of which are blotched with black.</cd> --
<col><b>Turk's-cap lily</b></col> <fld>(Bot.)</fld> <cd><spn>Lilium
Martagon</spn>, a red lily with recurved sepals; also, the similar
American lily, <spn>Lilium superbum</spn>.</cd> -- <col><b>Water
lily</b></col> <fld>(Bot.)</fld>, <cd>the <gen>Nymph<ae/a</gen>, a plant
with floating roundish leaves, and large flowers having many petals,
usually white, but sometimes pink, red, blue, or yellow. [See
<xex>Illust.</xex> of <er>Nymph<ae/a</er>.]</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lily-handed</ent><br/
<hw>Lil"y-hand`ed</hw> <pr>(l<icr/l"<ycr/-h<acr/nd`<ecr/d)</pr>,
<pos>a.</pos> <def>Having white, delicate hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lily-livered</ent><br/
<hw>Lil"y-liv`ered</hw> <pr>(l<icr/l"<ycr/-l<icr/v`<etil/rd)</pr>,
<pos>a.</pos> <def>White-livered; cowardly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lilyturf</ent><br/
<hw>lilyturf</hw> <pos>n.</pos> <def>Asiatic perennial tufted herb
(<spn>Liriope muscari</spn>) with grasslike evergreen foliage and
clusters of dark mauve grapelike flowers; grown as ground
cover.</def><br/
<syn><b>Syn. --</b> lily turf, <spn>Liriope muscari</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lilywort</ent><br/
<hw>Lil"y*wort`</hw> <pr>(l<icr/l"<ycr/*w<ucir/rt`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>Any plant of the Lily family or order.</def>
<rj><au>Lindley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lim</ent><br/
<hw>Lim</hw> <pr>(l<icr/m)</pr>, <pos>n.</pos> <ety>[See
<er>Limb</er>.]</ety> <def>A limb.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lima</ent><br/
<hw>Li"ma</hw> <pr>(l<emac/"m<adot/ <or/ l<imac/"m<adot/)</pr>,
<pos>n.</pos> <def>The capital city of Peru, in South America.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lima bean</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd> <cd>A
variety of climbing or pole bean (<spn>Phaseolus lunatus</spn>), which
has very large flattish seeds.</cd> <sd>(b)</sd> <cd>The seed of this
plant, much used for food.</cd> -- <col><b>Lima wood</b></col>
<fld>(Bot.)</fld>, <cd>the beautiful dark wood of the South American
tree <spn>C<ae/salpinia echinata</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 854 pr=VMG --></p>

<p><ent>Limaceous</ent><br/
<hw>Li*ma"ceous</hw> <pr>(l<isl/*m<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>limax</ets>, <ets>limacis</ets>, slug, snail: cf. F.
<ets>limac<eacute/</ets>.]</ety> <fld>(Zool.)</fld> <def>Pertaining to,
or like, Limax, or the slugs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limacina</ent><br/
\'d8<hw>Lim`a*ci"na</hw> <pr>(l<icr/m`<adot/*s<imac/"n<adot/)</pr>,
<pos>n.</pos> <ety>[NL., From L. <ets>limax</ets>, <ets>limacis</ets>, a
slug.]</ety> <fld>(Zool.)</fld> <def>A genus of small spiral pteropods,
common in the Arctic and Antarctic seas. It contributes to the food of
the right whales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limacon</ent><br/
\'d8<hw>Li`ma`<cced/on"</hw> <pr>(l<esl/`m<adot/`s<ocir/N")</pr>,
<pos>n.</pos> <ety>[F. <ets>lima<cced/on</ets>, lit., a snail.]</ety>
<fld>(Geom.)</fld> <def>A curve of the fourth degree, invented by
Pascal. Its polar equation is <mathex>r = a cos <theta/ +
b</mathex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limaille</ent><br/
<hw>Li"maille</hw> <pr>(l<imac/"m<amac/l; F. l<esl/`m<aum/"y')</pr>,
<pos>n.</pos> <ety>[F., fr. <ets>limer</ets> to file. See
<er>Limation</er>.]</ety> <def>Filings of metal.</def>
<mark>[Obs.]</mark> <ldquo/An ounce . . . of silver
<xex>lymaille</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liman</ent><br/
<hw>Li"man</hw> <pr>(l<imac/"m<ait/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>limon</ets>, fr. L. <ets>limus</ets> slime.]</ety> <def>The deposit
of slime at the mouth of a river; slime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limation</ent><br/
<hw>Li*ma"tion</hw> <pr>(l<isl/*m<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>limatus</ets>, p. p. of <ets>limare</ets> to file, fr.
<ets>lima</ets> file : cf. F. <ets>limation</ets>.]</ety> <def>The act
of filing or polishing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limature</ent><br/
<hw>Li"ma*ture</hw> <pr>(l<imac/"m<adot/*t<usl/r; 135)</pr>,
<pos>n.</pos> <ety>[L. <ets>limatura</ets>. See
<er>Limation</er>.]</ety> <sn>1.</sn> <def>The act of filing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is filed off; filings.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limax</ent><br/
\'d8<hw>Li"max</hw> <pr>(l<imac/"m<acr/ks)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <fld>(Zool.)</fld> <def>A genus of airbreathing
mollusks, including the common garden slugs. They have a small
rudimentary shell. The breathing pore is on the right side of the neck.
Several species are troublesome in gardens. See <er>Slug</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limb</ent><br/
<hw>Limb</hw> <pr>(l<icr/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lim</ets>, AS. <ets>lim</ets>; akin to Icel. <ets>limr</ets> limb,
<ets>lim</ets> branch of a tree, Sw. & Dan. <ets>lem</ets> limb; cf.
also AS. <ets>li<edh/</ets>, OHG. <ets>lid</ets>, <ets>gilid</ets>, G.
<ets>glied</ets>, Goth. <ets>li<thorn/us</ets>. Cf. <er>Lith</er>,
<er>Limber</er>.]</ety> <sn>1.</sn> <def>A part of a tree which extends
from the trunk and separates into branches and twigs; a large
branch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An arm or a leg of a human being; a leg, arm, or
wing of an animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A second Hector for his grim aspect,<br/
And large proportion of his strong-knit <qex>limbs</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A thing or person regarded as a part or member of,
or attachment to, something else.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That little <qex>limb</qex> of the devil has cheated the
gallows.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An elementary piece of the mechanism of a
lock.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Limb of the law</b></col>, <cd>a lawyer or an officer of
the law.</cd> <mark>[Colloq.]</mark> <au>Landor.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limb</ent><br/
<hw>Limb</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To supply with
limbs.</def> <mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dismember; to tear off the limbs of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limb</ent><br/
<hw>Limb</hw>, <pos>n.</pos> <ety>[L. <ets>limbus</ets> border. Cf.
<er>Limbo</er>, <er>Limbus</er>.]</ety> <def>A border or edge, in
certain special uses.</def> <sd>(a)</sd> <fld>(Bot.)</fld> <def>The
border or upper spreading part of a monopetalous corolla, or of a petal,
or sepal; blade.</def> <sd>(b)</sd> <fld>(Astron.)</fld> <def>The border
or edge of the disk of a heavenly body, especially of the sun and
moon.</def> <sd>(c)</sd> <def>The graduated margin of an arc or circle,
in an instrument for measuring angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbat</ent><br/
<hw>Lim"bat</hw> <pr>(l<icr/m"b<acr/t)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A cooling periodical wind in the Isle of Cyprus,
blowing from the northwest from eight o'clock, <sc>A. M.</sc>, to the
middle of the day or later.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbate</ent><br/
<hw>Lim"bate</hw> <pr>(l<icr/m"b<asl/t)</pr>, <pos>a.</pos> <ety>[L.
<ets>limbatus</ets>, fr. <ets>limbus</ets> border, edge. See
<er>Limbus</er>.]</ety> <fld>(Bot. & Zool.)</fld> <def>Bordered, as when
one color is surrounded by an edging of another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbec</ent><br/
<hw>Lim"bec</hw> <pr>(l<icr/m"b<ecr/k)</pr>, <pos>n.</pos> <ety>[Abbrev.
of <ets>alembic</ets>.]</ety> <def>An alembic; a still.</def>
<mark>[Obs.]</mark> <rj><au>Spenser. Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbec</ent><br/
<hw>Lim"bec</hw>, <pos>v. t.</pos> <def>To distill.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbed</ent><br/
<hw>Limbed</hw> <pr>(l<icr/md)</pr>, <pos>a.</pos> <def>Having limbs; --
much used in composition; <as>as, large<ex>-limbed</ex>;
short<ex>-limbed</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Innumerous living creatures, perfect forms,<br/
<qex>Limbed</qex> and full grown.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limber</ent><br/
<hw>Lim"ber</hw> <pr>(l<icr/m"b<etil/r)</pr>, <pos>n.</pos> <ety>[For
<ets>limmer</ets>, Icel. <ets>limar</ets> branches, boughs, pl. of
<ets>lim</ets>; akin to E. <ets>limb</ets>. See <er>Limb</er> a
branch.]</ety> <sn>1.</sn> <pluf>pl.</pluf> <def>The shafts or thills of
a wagon or carriage.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>The detachable fore part of a gun
carriage, consisting of two wheels, an axle, and a shaft to which the
horses are attached. On top is an ammunition box upon which the
cannoneers sit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <fld>(Naut.)</fld> <def>Gutters or
conduits on each side of the keelson to afford a passage for water to
the pump well.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Limber boards</b></col> <fld>(Naut.)</fld>, <cd>short
pieces of plank forming part of the lining of a ship's floor immediately
above the timbers, so as to prevent the limbers from becoming
clogged.</cd> -- <mcol><col><b>Limber box</b></col> <it>or</it>
<col><b>Limber chest</b></col></mcol> <fld>(Mil.)</fld>, <cd>a box on
the limber for carrying ammunition.</cd> -- <mcol><col><b>Limber
rope</b></col>, <col><b>Limber chain</b></col> <it>or</it>
<col><b>Limber clearer</b></col></mcol> <fld>(Naut.)</fld>, <cd>a rope
or chain passing through the limbers of a ship, by which they may be
cleared of dirt that chokes them.</cd> <au>Totten.</au> --
<col><b>Limber strake</b></col> <fld>(Shipbuilding)</fld>, <cd>the first
course of inside planking next the keelson.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limber</ent><br/
<hw>Lim"ber</hw> <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Limbered</conjf> <pr>(l<icr/m"b<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Limbering</conjf>.]</vmorph> <fld>(Mil.)</fld> <def>To
attach to the limber; <as>as, to <ex>limber</ex> a gun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To limber up</b></col>, <cd>to change a gun carriage into
a four-wheeled vehicle by attaching the limber.</cd></cs> <-- (b) to
render limber, esp. to perform light exercises so as to stretch the
muscles and tendons gently in preparation for vigorous activity (and
thus to avoid straining the muscles by too sudden exertion after
prolonged inactivity) --> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Limber</ent><br/
<hw>Lim"ber</hw>, <pos>a.</pos> <ety>[Akin to <ets>limp</ets>, a.
<root/125. See <er>Limp</er>, <pos>a.</pos>]</ety> <def>Easily bent;
flexible; pliant; yielding.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bargeman that doth row with long and <qex>limber</qex>
oar.</q> <rj><qau>Turbervile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limber</ent><br/
<hw>Lim"ber</hw>, <pos>v. t.</pos> <def>To cause to become limber; to
make flexible or pliant.</def> <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limberness</ent><br/
<hw>Lim"ber*ness</hw>, <pos>n.</pos> <def>The quality or state of being
limber; flexibleness.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>limbic</ent><br/
<hw>limbic</hw> <pos>adj.</pos> <def>of or pertaining to the limbic
system; <as>as, the <ex>limbic</ex> system</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>limbic system</ent><br/
<hw>limbic system</hw> <pos>n.</pos> <fld>(Anatomy,
Neurophysiology)</fld> <def>A group of neural structures in the brain
below the cerebral cortex, centered on the hypothalamus and including
the hippocampus and amygdala, involved with control of emotion,
motivation, memory, and some homeostatic regulatory processes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><q>At the most ancient part of the human brain lies the spinal cord;
the medulla and pons, which comprise the hindbrain; and the midbrain.
This cobination of spinal cord, hindbrain, and midbrain MacLean calls
the neural chassis. It contains the basic neural machinery for
reproduction and self-preservation, . . . MacLean has distinguished
three sorts of [more recent brain structures controlling] the neural
chassis. The most ancient of them surround the midbrain. . . . We share
it with the other mammals and the reptiles. It probably evolved several
hundred million years ago. MacLean calls it the reptilian or R-complex.
Surrounding the R-complex is the <ex>limbic system</ex>, so called
because it borders on the underlying brain. (Our arms and legs are
called limbs because they are peripheral to the rest of the body.) We
share the limbic system with other mammals, but not, in its full
elaboration, with the reptiles. It probably evolved more than one
hundred fifty million years ago. Finally, surrounding the rest of the
brain and clearly the most recent evolutionary accretion, is the
neocortex.</q> <rj><qau>Carl Sagan (The Dragons of Eden, New York,
Random House, 1977).</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>Limbless</ent><br/
<hw>Limb"less</hw> <pr>(l<icr/m"l<ecr/s)</pr>, <pos>a.</pos>
<def>Destitute of limbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbmeal</ent><br/
<hw>Limb"meal`</hw> <pr>(l<icr/m"m<emac/l`)</pr>, <pos>adv.</pos>
<ety>[See <er>Limb</er>, and <er>Piecemeal</er>.]</ety>
<def>Piecemeal.</def> <mark>[Obs.]</mark> <ldquo/To tear her
<xex>limbmeal</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbus</ent><br/
<ent>Limbo</ent><br/
<mhw>{ <hw>Lim"bo</hw> <pr>(l<icr/m"b<osl/)</pr>, <hw>Lim"bus</hw>
<pr>(l<icr/m"b<ucr/s)</pr>, }</mhw> <pos>n.</pos> <ety>[L.
<ets>limbus</ets> border, edge <ets>in limbo</ets> on the border. Cf.
<er>Limb</er> border.]</ety> <sn>1.</sn> <fld>(Scholastic Theol.)</fld>
<def>An spiritual region where certain classes of souls were supposed to
await the last judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As far from help as <qex>Limbo</qex> is from bliss.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>Limbo</qex> large and broad, since called<br/
The Paradise of fools.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>limbus patrum</xex> was considered as a place
for the souls of good men who lived before the coming of our Savior. The
<xex>limbus infantium</xex> was said to be a similar place for the souls
of unbaptized infants. To these was added, in the popular belief, the
<xex>limbus fatuorum</xex>, or fool's paradise, regarded as a receptacle
of all vanity and nonsense.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Any real or imaginary place of restraint or
confinement; a prison; <as>as, to put a man in
<ex>limbo</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>A state of waiting, or
uncertainty, in which final judgment concerning the outcome of a
decision is postponed, perhaps indefinitely; neglect for an indefinite
time; <as>as, the proposal was left in <ex>limbo</ex> while opponents
and proponents refused to compromise</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Anat.)</fld> <def>A border or margin; <as>as, the
<ex>limbus</ex> of the cornea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limbo</ent><br/
<hw>Lim"bo</hw> <pr>(l<icr/m"b<osl/)</pr>, <pos>n.</pos> <ety>[Jamaican
E. <ets>limba</ets> to bend, fr. E. <ets>limber</ets> (1950)
<au>MW10</au>]</ety> <def>A West Indian dance contest, in which
participants must dance under a pole which is lowered successively until
only one participant can successfully pass under, without falling. It is
often performed at celebrations, such as weddings.</def><br/
[<source>PJC</source>]</p>

<p><ent>Limbous</ent><br/
<hw>Lim"bous</hw> <pr>(l<icr/m"b<ucr/s)</pr>, <pos>a.</pos> <ety>[See
<er>Limbus</er>.]</ety> <fld>(Anat.)</fld> <def>With slightly
overlapping borders; -- said of a suture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limburger cheese</ent><br/
<ent>Limburger</ent><br/
<ent>Limburg cheese</ent><br/
<mhw>{<hw>Lim"burg cheese</hw>, <hw>Lim"burg*er</hw>, <pos>n.</pos>,
<hw>Lim"burg*er cheese</hw>}</mhw> <pr>(?)</pr> <pos>n.</pos> <def>A
soft cheese made in the Belgian province of Limburg (Limbourg), and
usually not eaten until the curing has developed a peculiar and, to most
people, unpleasant odor.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lime</ent><br/
<hw>Lime</hw> <pr>(l<imac/m)</pr>, <pos>n.</pos> <ety>[See <er>Leam</er>
a string.]</ety> <def>A thong by which a dog is led; a leash.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lime</ent><br/
<hw>Lime</hw>, <pos>n.</pos> <ety>[Formerly <ets>line</ets>, for earlier
<ets>lind</ets>. See <er>Linden</er>.]</ety> <fld>(Bot.)</fld> <def>The
linden tree. See <er>Linden</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lime</ent><br/
<hw>Lime</hw>, <pos>n.</pos> <ety>[F. <ets>lime</ets>; of Persian
origin. See <er>Lemon</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>The fruit of the <spn>Citrus aurantifolia</spn>, allied to the
lemon, but greener in color; also, the tree which bears it.</def>
<note>The term <ex>lime</ex> was formerly also applied to variants of
the closely related <contr>citron</contr>, of which there are two
varieties, <spn>Citrus Medica</spn>, var. <varn>acida</varn> which is
intensely sour, and the <col><b>sweet lime</b></col> (<spn>Citrus
Medica</spn>, var. <varn>Limetta</varn>) which is only slightly sour.
See <er>citron</er>.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The color of the lime{1}, a
yellowish-green.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lime</ent><br/
<hw>Lime</hw>, <pos>n.</pos> <ety>[AS. <ets>l<imac/m</ets>; akin to D.
<ets>lijm</ets>, G. <ets>leim</ets>, OHG. <ets>l<imac/m</ets>, Icel.
<ets>l<imac/m</ets>, Sw. <ets>lim</ets>, Dan. <ets>liim</ets>, L.
<ets>limus</ets> mud, <ets>linere</ets> to smear, and E.
<ets>loam</ets>. <root/126. Cf. <er>Loam</er>, <er>Liniment</er>.]</ety>
<sn>1.</sn> <def>Birdlime.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like the <qex>lime</qex><br/
That foolish birds are caught with.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Oxide of calcium,
<chform>CaO</chform>; the white or gray, caustic substance, usually
called <altname>quicklime</altname>, obtained by calcining limestone or
shells, the heat driving off carbon dioxide and leaving lime. It
develops great heat when treated with water, forming <er>slaked
lime</er>, and is an essential ingredient of cement, plastering, mortar,
etc.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ Lime is the principal constituent of limestone, marble,
chalk, bones, shells, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Caustic lime</b></col>, <cd>Calcium hydroxide or slaked
lime; also, in a less technical sense, calcium oxide or quicklime.</cd>
-- <col><b>Lime burner</b></col>, <cd>one who burns limestone, shells,
etc., to make lime.</cd> -- <col><b>Lime pit</b></col>, <cd>a limestone
quarry.</cd> -- <mcol><col><b>Lime rod</b></col>, <col><b>Lime
twig</b></col></mcol>, <cd>a twig smeared with birdlime; hence, that
which catches; a snare.</cd> <au>Chaucer.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lime</ent><br/
<hw>Lime</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Limed</conjf> <pr>(l<imac/md)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Liming</conjf>.]</vmorph> <ety>[Cf. AS. <ets>gel<imac/man</ets>
to glue or join together. See <er>Lime</er> a viscous substance.]</ety>
<sn>1.</sn> <def>To smear with a viscous substance, as
birdlime.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These twigs, in time, will come to be <qex>limed</qex>.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To entangle; to insnare.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We had <qex>limed</qex> ourselves<br/
With open eyes, and we must take the chance.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To treat with lime, or oxide or hydrate of calcium;
to manure with lime; <as>as, to <ex>lime</ex> hides for removing the
hair; to <ex>lime</ex> sails in order to whiten them; to <ex>lime</ex>
the lawn to decrease acidity of the soil.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Land may be improved by draining, marling, and
<qex>liming</qex>.</q> <rj><qau>Sir J. Child.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cement.</def> <ldquo/Who gave his blood to
<xex>lime</xex> the stones together.<rdquo/ <rj><au>Shak.</au></rj></p>

<p><ent>lime</ent><br/
<hw>lime</hw> <pr>(l<imac/m")</pr>, <pos>a.</pos> <def>having a
yellowish-green color like that of the lime (the fruit).</def><br/
[<source>PJC</source>]</p>

<p><ent>limeade</ent><br/
<hw>limeade</hw> <pos>n.</pos> <def>A sweetened beverage of lime juice
and water.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Limehound</ent><br/
<hw>Lime"hound`</hw> <pr>(l<imac/m"hound`)</pr>, <pos>n.</pos>
<ety>[<ets>Lime</ets> a leash + <ets>hound</ets>.]</ety> <def>A dog used
in hunting the wild boar; a leamer.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limekiln</ent><br/
<hw>Lime"kiln`</hw> <pr>(l<imac/m"k<icr/ln`)</pr>, <pos>n.</pos> <def>A
kiln or furnace in which limestone or shells are burned and reduced to
lime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>limelight</ent><br/
<ent>lime light</ent><br/
<mhw><hw>lime" light`</hw>, <hw>lime"light`</hw></mhw> <def>An intense
light produced by heating lime. See <cref>Calcium light</cref> under
<er>Calcium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>limelight</ent><br/
<hw>lime"light`</hw>, <pos>n.</pos> <fld>(Theat.)</fld> <def>That part
of the stage upon which the limelight is cast, usually where the most
important action is progressing or where the leading player or players
are placed and upon which the attention of the spectators is therefore
concentrated.</def> <specif>Hence,</specif> <def>a conspicuous position
before the public; the center of public attention; -- used mostly in the
phrase <ecol><b>in the limelight</b></ecol>; <as>as, politicians who are
never happy except in the <ex>limelight</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>limen</ent><br/
<hw>limen</hw> <pos>n.</pos> <fld>(Psychol.)</fld> <def>a threshhold,
especially the point where a psychological or physiological effect
begins to occur.</def><br/
[<source>PJC</source>]</p>

<p><ent>Limenean</ent><br/
<hw>Li*men"e*an</hw> <pr>(l<esl/*m<ecr/n"<esl/*<ait/n)</pr>,
<pos>a.</pos> <def>Of or pertaining to Lima, or to the inhabitants of
Lima, in Peru.</def> -- <def2><pos>n.</pos> <def>A native or inhabitant
of Lima.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limenitis</ent><br/
<hw>Limenitis</hw> <pos>n.</pos> <def>A genus comprising mainly dark
northern butterflies with white wing bars.</def><br/
<syn><b>Syn. --</b> genus <gen>Limenitis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Limer</ent><br/
<hw>Lim"er</hw> <pr>(l<imac/m"<etil/r)</pr>, <pos>n.</pos> <def>A
limehound; a limmer.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limerick</ent><br/
<hw>Lim"er*ick</hw> <pr>(l<icr/m"<etil/r*<icr/k)</pr>, <pos>n.</pos>
<ety>[Said to be from a song with the same verse construction, current
in Ireland, the refrain of which contains the place name
<ets>Limerick</ets>.]</ety> <def>A humorous, often nonsensical, and
sometimes risq<eacute/ poem of five anapestic lines, of which lines 1,
2, and 5 are of three feet, and rhyme, and lines 3 and 4 are of two
feet, and rhyme.</def> <note>It often begins with "There once was a . .
." or "There was a . . ."; as --</note></p>

<p><q>There was a young lady, Amanda,<br/
Whose <it>Ballades Lyriques</it> were quite <it>fin de</it><br/
<it>Si<egrave/cle</it>, I deem<br/
But her <it>Journal Intime</it><br/
Was what sent her papa to Uganda.</q><br/
<br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Limestone</ent><br/
<hw>Lime"stone`</hw> <pr>(l<imac/m"st<omac/n`)</pr>, <pos>n.</pos>
<def>A rock consisting chiefly of calcium carbonate or carbonate of
lime. It sometimes contains also magnesium carbonate, and is then called
<xex>magnesian</xex> or <xex>dolomitic limestone</xex>. Crystalline
limestone is called <xex>marble</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lime twig</ent><br/
<hw>Lime twig</hw>. <def>See under 4th <er>Lime</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lime-twigged</ent><br/
<hw>Lime"-twigged`</hw> <pr>(l<imac/m"tw<icr/gd`)</pr>, <pos>a.</pos>
<def>Beset with snares; insnared, as with birdlime.</def> <rj><au>L.
Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limewater</ent><br/
<hw>Lime"wa`ter</hw> <pr>(l<imac/m"w<add/`t<etil/r)</pr>, <pos>n.</pos>
<def>Water impregnated with lime; esp., an artificial solution of lime
for medicinal purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limicolae</ent><br/
\'d8<hw>Li*mic"o*l<ae/</hw> <pr>(l<isl/*m<icr/k"<osl/*l<emac/)</pr>,
<pos>n. pl.</pos> <ety>[L. <ets>limicola</ets> a dweller in the mud;
<ets>limus</ets> mud + <ets>colere</ets> to dwell.]</ety>
<fld>(Zool.)</fld> <def>A group of shore birds, embracing the plovers,
sandpipers, snipe, curlew, etc.; the Grall<ae/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limicoline</ent><br/
<hw>Li*mic"o*line</hw> <pr>(l<isl/*m<icr/k"<osl/*l<icr/n)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <def>Shore-inhabiting; of or pertaining
to the Limicol<ae/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>liminal</ent><br/
<hw>liminal</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining to a
limen, especially a sensory threshhold.</def> <see>See
<er>liminality</er>.</see><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>marginally perceptible.</def><br/
[<source>PJC</source>]</p>

<p><ent>liminality</ent><br/
<hw>liminality</hw> <pos>n.</pos> <fld>(Anthropology)</fld> <def>that
temporary state during a rite of passage when the participant lacks
social status or rank, is required to follow specified forms of conduct,
and is expected to show obedience and humility.</def> <au>RHU</au><br/
[<source>PJC</source>]</p>

<p><ent>Liminess</ent><br/
<hw>Lim"i*ness</hw> <pr>(l<imac/m"<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The state or quality of being limy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limit</ent><br/
<hw>Lim"it</hw> <pr>(l<icr/m"<icr/t)</pr>, <pos>n.</pos> <ety>[From L.
<ets>limes</ets>, <ets>limitis</ets>: cf. F. <ets>limite</ets>;
<ets>-or</ets> from E. <ets>limit</ets>, v. See <er>Limit</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>That which terminates, circumscribes,
restrains, or confines; the bound, border, or edge; the utmost extent;
<as>as, the <ex>limit</ex> of a walk, of a town, of a country; the
<ex>limits</ex> of human knowledge or endeavor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>As eager of the chase, the maid<br/
Beyond the forest's verdant <qex>limits</qex> strayed.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The space or thing defined by limits.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The archdeacon hath divided it<br/
Into three <qex>limits</qex> very equally.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which terminates a period of time; hence, the
period itself; the full time or extent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dateless <qex>limit</qex> of thy dear exile.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>limit</qex> of your lives is out.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A restriction; a check; a curb; a
hindrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I prithee, give no <qex>limits</qex> to my tongue.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Logic & Metaph.)</fld> <def>A determining feature;
a distinguishing characteristic; a differentia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <def>A determinate quantity, to which
a variable one continually approaches, and may differ from it by less
than any given difference, but to which, under the law of variation, the
variable can never become exactly equivalent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Elastic limit</b></col>. <cd>See under
<er>Elastic</er>.</cd> -- <col><b>Prison limits</b></col>, <cd>a
definite, extent of space in or around a prison, within which a prisoner
has liberty to go and come.</cd></cs></p>

<p><syn><b>Syn.</b> -- Boundary; border; edge; termination; restriction;
bound; confine.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limit</ent><br/
<hw>Lim"it</hw> <pr>(l<icr/m"<icr/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Limited</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Limiting</conjf>.]</vmorph> <ety>[F.
<ets>limiter</ets>, L. <ets>limitare</ets>, fr. <ets>limes</ets>,
<ets>limitis</ets>, limit; prob. akin to <ets>limen</ets> threshold, E.
<ets>eliminate</ets>; cf. L. <ets>limus</ets> sidelong.]</ety> <def>To
apply a limit to, or set a limit for; to terminate, circumscribe, or
restrict, by a limit or limits; <as>as, to <ex>limit</ex> the acreage of
a crop; to <ex>limit</ex> the issue of paper money; to <ex>limit</ex>
one's ambitions or aspirations; to <ex>limit</ex> the meaning of a
word.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Limiting parallels</b></col> <fld>(Astron.)</fld>,
<cd>those parallels of latitude between which only an occultation of a
star or planet by the moon, in a given case, can occur.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limit</ent><br/
<hw>Lim"it</hw>, <pos>v. i.</pos> <def>To beg, or to exercise functions,
within a certain limited region; <as>as, a <ex>limiting</ex>
friar</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitable</ent><br/
<hw>Lim"it*a*ble</hw> <pr>(l<icr/m"<icr/t*<adot/*b'l)</pr>,
<pos>a.</pos> <def>Capable of being limited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitaneous</ent><br/
<hw>Lim`i*ta"ne*ous</hw> <pr>(l<icr/m`<icr/*t<amac/"n<esl/*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>limitaneus</ets>. See <er>Limit</er>,
<pos>v. t.</pos>]</ety> <def>Of or pertaining to a limit.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitarian</ent><br/
<hw>Lim`i*ta"ri*an</hw> <pr>(l<icr/m`<icr/*t<amac/"r<icr/*<ait/n)</pr>,
<pos>a.</pos> <def>Tending to limit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitary</ent><br/
<hw>Lim"i*ta*ry</hw> <pr>(l<icr/m"<icr/*t<asl/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[L. <ets>limitaris</ets>. See <er>Limit</er> ,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>Placed at the limit, as a
guard.</def> <ldquo/Proud <xex>limitary</xex> cherub.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confined within limits; limited in extent,
authority, power, etc.</def> <ldquo/The <xex>limitary</xex>
ocean.<rdquo/ <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The poor, <qex>limitary</qex> creature calling himself a man of
the world.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Limiting, or tending to limit;
restrictive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Doctrines <qex>limitary</qex>, if not subversive of the papal
power.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitary</ent><br/
<hw>Lim"i*ta*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>limitaries</plw> <pr>(l<icr/m"<icr/*t<asl/*r<icr/z)</pr>.</plu>
<sn>1.</sn> <def>That which serves to limit; a boundary; border
land.</def> <mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A limiter. See <er>Limiter</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitate</ent><br/
<hw>Lim"i*tate</hw> <pr>(l<icr/m"<icr/*t<asl/t)</pr>, <pos>a.</pos>
<ety>[L. <ets>limitatus</ets>, p. p. of <ets>limitare</ets> to limit.
See <er>Limit</er>, <pos>v. t.</pos> ]</ety> <def>Bounded by a distinct
line.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitation</ent><br/
<hw>Lim`i*ta"tion</hw> <pr>(-t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>limitatio</ets>: cf. F. <ets>limitation</ets>. See
<er>Limit</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>The act of
limiting; the state or condition of being limited; <as>as, the
<ex>limitation</ex> of his authority was approved by the
council</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They had no right to mistake the <qex>limitation</qex> . . . of
their own faculties, for an inherent <qex>limitation</qex> of the
possible modes of existence in the universe.</q> <rj><qau>J. S.
Mill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which limits; a restriction; a qualification; a
restraining condition, defining circumstance, or qualifying conception;
<as>as, <ex>limitations</ex> of thought</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cause of error is ignorance what restraints and
<qex>limitations</qex> all principles have in regard of the matter
whereunto they are applicable.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A certain precinct within which friars were allowed
to beg, or exercise their functions; also, the time during which they
were permitted to exercise their functions in such a district.</def>
<rj><au>Chaucer. Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A limited time within or during which something is
to be done.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You have stood your <qex>limitation</qex>, and the tribunes<br/
Endue you with the people's voice.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A certain period
limited by statute after which the claimant shall not enforce his claims
by suit.</def> <sd>(b)</sd> <def>A settling of an estate or property by
specific rules.</def> <sd>(c)</sd> <def>A restriction of power; <as>as,
a constitutional <ex>limitation</ex></as>.</def> <rj><au>Wharton.
Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To know one's own limitations</b></col>, <cd>to know the
reach and limits of one's abilities.</cd> <rj><au>A. R.
Wallace.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limited</ent><br/
<hw>Lim"it*ed</hw> <pr>(l<icr/m"<icr/t*<ecr/d)</pr>, <pos>a.</pos>
<def>Confined within limits; narrow; circumscribed; restricted; <as>as,
our views of nature are very <ex>limited</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Limited company</b></col>, <cd>a company in which the
liability of each shareholder is limited by the number of shares he has
taken, so that he can not be called on to contribute beyond the amount
of his shares.</cd> <mark>[Eng.]</mark> <au>Mozley & W.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitedly</ent><br/
<hw>Lim"it*ed*ly</hw>, <pos>adv.</pos> <def>With limitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitedness</ent><br/
<hw>Lim"it*ed*ness</hw>, <pos>n.</pos> <def>The quality of being
limited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limiter</ent><br/
<hw>Lim"it*er</hw> <pr>(l<icr/m"<icr/t*<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who, or that which, limits.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A friar licensed to beg within certain bounds, or
whose duty was limited to a certain district.</def> <altsp>[Formerly
written also <asp>limitour</asp>.]</altsp>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>limitour</qex> of the Gray Friars, in the time of his
limitation, preached many times, and had but one sermon at all
times.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitive</ent><br/
<hw>Lim"it*ive</hw> <pr>(l<icr/m"<icr/t*<icr/v)</pr>, <pos>a.</pos>
<def>Involving a limit; <as>as, a <ex>limitive</ex> law, one designed to
limit existing powers</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitless</ent><br/
<hw>Lim"it*less</hw>, <pos>a.</pos> <def>Having no limits; unbounded;
boundless.</def> <rj><au>Davies (Wit's Pilgr.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limitour</ent><br/
<hw>Lim"it*our</hw> <pr>(l<icr/m"<icr/t*<oomac/r)</pr>, <pos>n.</pos>
<def>See <er>Limiter</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limmer</ent><br/
<hw>Lim"mer</hw> <pr>(l<icr/m"m<etil/r)</pr>, <pos>a.</pos>
<def>Limber.</def> <mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limmer</ent><br/
<hw>Lim"mer</hw>, <pos>n.</pos> <ety>[F. <ets>limier</ets>. See
<er>Leamer</er>.]</ety> <sn>1.</sn> <def>A limehound; a
leamer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A mongrel, as a cross between the
mastiff and hound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A low, base fellow; also, a prostitute.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thieves, <qex>limmers</qex>, and broken men of the Highlands.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>A man rope at the side of a
ladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limn</ent><br/
<hw>Limn</hw> <pr>(l<icr/m)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Limned</conjf> <pr>(l<icr/md)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Limning</conjf> <pr>(l<icr/m"n<icr/ng <or/
l<icr/m"<icr/ng)</pr>.]</vmorph> <ety>[OE. <ets>limnen</ets>, fr.
<ets>luminen</ets>, for <ets>enluminen</ets>, F. <ets>enluminer</ets> to
illuminate, to limn, LL. <ets>illuminare</ets> to paint. <root/122. See
<er>Illuminate</er>, <er>Luminous</er>.]</ety> <sn>1.</sn> <def>To draw
or paint; especially, to represent in an artistic way with pencil or
brush.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let a painter carelessly <qex>limn</qex> out a million of faces,
and you shall find them all different.</q> <rj><qau>Sir T. Browne.
</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>To picture in words; to
describe in graphic terms.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To illumine, as books or parchments, with ornamental
figures, letters, or borders.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 855 pr=VMG --></p>

<p><ent>Limnaea</ent><br/
\'d8<hw>Lim*n<ae/"a</hw> <pr>(l<icr/m*n<emac/"<adot/)</pr>, <pos>prop.
n.</pos> <ety>[NL., fr. Gr. <grk>limnai^os</grk> pertaining to a marsh,
fr. <grk>li`mh</grk> a marsh.]</ety> <fld>(Zool.)</fld> <def>A genus of
fresh-water air-breathing mollusks, abundant in ponds and streams; --
called also <altname>pond snail</altname>.</def> <altsp>[Written also
<asp>Lymn<ae/a</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limner</ent><br/
<hw>Lim"ner</hw> <pr>(l<icr/m"n<etil/r)</pr>, <pos>n.</pos> <ety>[F.
<ets>enlumineur</ets>, LL. <ets>illuminator</ets>. See <er>Limn</er>,
and cf. <er>Alluminor</er>.]</ety> <def>A painter; an artist</def>;
esp.: <sd>(a)</sd> <def>One who paints portraits.</def> <sd>(b)</sd>
<def>One who illuminates books.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limniad</ent><br/
<hw>Lim"ni*ad</hw> <pr>(l<icr/m"n<icr/*<acr/d)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>li`mh</grk> a pool.]</ety> <fld>(Myth.)</fld> <def>See
<er>Limoniad</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limning</ent><br/
<hw>Lim"ning</hw> <pr>(l<icr/m"n<icr/ng <or/ l<icr/m"<icr/ng)</pr>,
<pos>n.</pos> <def>The act, process, or art of one who limns; the
picture or decoration so produced.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adorned with illumination which we now call
<qex>limning</qex>.</q> <rj><qau>Wood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limnodromus</ent><br/
<hw>Limnodromus</hw> <pos>n.</pos> <def>A genus of shore birds including
the dowitchers.</def><br/
<syn><b>Syn. --</b> genus <gen>Limnodromus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>limnology</ent><br/
<hw>limnology</hw> <pos>n.</pos> <def>the scientific study of bodies of
fresh water for their biological and physical and geological
properties.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>limo</ent><br/
<hw>limo</hw> <pos>n.</pos> <def>Limousine; -- a shortened
form.</def><br/
<syn><b>Syn. --</b> limousine.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Limoges</ent><br/
<hw>Li*moges"</hw> <pr>(l<esl/*m<omac/zh")</pr>, <pos>prop. n.</pos>
<sn>1.</sn> <def>A city of Southern France.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A variety of fine porcelain manufactured at
Limoges{1}; also called <altname>Limoges ware</altname> or
<altname>Limoges China</altname>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Limoges enamel</b></col>, <cd>a kind of enamel ware in
which the enamel is applied to the whole surface of a metal plaque,
vase, or the like, and painted in enamel colors. The art was brought to
a high degree of perfection in Limoges in the 16th century.</cd> --
<col><b>Limoges ware</b></col>. <sd>(a)</sd> <cd>Articles decorated with
Limoges enamel.</cd> <sd>(b)</sd> <cd>Articles of porcelain, etc.,
manufactured at Limoges.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>limonene</ent><br/
<hw>limonene</hw> <pos>n.</pos> <def>a liquid terpene with a lemon odor;
found in lemons and oranges and other essential oils.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Limoniad</ent><br/
<hw>Li*mo"ni*ad</hw> <pr>(l<isl/*m<omac/"n<icr/*<acr/d)</pr>,
<pos>n.</pos> <ety>[L. <ets>limoniades</ets>, pl., Gr.
<grk>leimwnia`des</grk>, fr. <grk>leimw`n</grk> meadow.]</ety>
<fld>(Class. Myth.)</fld> <def>A nymph of the meadows; -- called also
<altname>Limniad</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limonin</ent><br/
<hw>Li*mo"nin</hw> <pr>(l<isl/*m<omac/"n<icr/n)</pr>, <pos>n.</pos>
<ety>[From NL. Citrus Medica, var. <ets>Limonum</ets>, the scientific
name of the lemon.]</ety> <fld>(Chem.)</fld> <def>A bitter, white,
crystalline substance found in orange and lemon seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limonite</ent><br/
<hw>Li"mon*ite</hw> <pr>(l<imac/"m<ocr/n*<imac/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>leimw`n</grk> any moist grassy place, a meadow: cf. F.
<ets>limonite</ets>, G. <ets>limonit</ets>.]</ety> <fld>(Min.)</fld>
<def>Hydrous sesquioxide of iron, an important ore of iron, occurring in
stalactitic, mammillary, or earthy forms, of a dark brown color, and
yellowish brown powder. It includes bog iron. Also called <altname>brown
hematite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limosis</ent><br/
\'d8<hw>Li*mo"sis</hw> <pr>(l<isl/*m<omac/"s<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>limo`s</grk> hunger.]</ety> <fld>(Med.)</fld>
<def>A ravenous appetite caused by disease; excessive and morbid
hunger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limous</ent><br/
<hw>Li"mous</hw> <pr>(l<imac/"m<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>limosus</ets>, fr. <ets>limus</ets> slime, mud.]</ety> <def>Muddy;
slimy; thick.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limousine</ent><br/
<hw>Li`mou*sine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>limousine</ets> a kind of cloak, fr. <etsep>Limousin</etsep>, an
old province in central France.]</ety> <def>an elongated, luxurious
automobile, designed to be driven by a chauffeur and often having a
glass partition between the driver's seat and the passengers'
compartment behind.</def> <note>When intended for use in transporting
businessmen, the limousine may be equipped with a telephone and other
conveniences to permit work during travel. Limousines are often rented
for travel to and from airports, and as a luxurious perquisite on
special occasions, as weddings or school prm nights. Originally (1913)
the term referred to an automobile body with seats and permanent top
like a coup<eacute/, and with the top projecting over the driver and a
projecting front, or an automobile with such a body.</note><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Limousine liberal</ent><br/
<hw>Li`mou*sine" lib`er*al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a
wealthy or well-to-do person of liberal political inclination. It is
sometimes used as a term of contempt for those espousing the cause of
poor people, without having to endure the discomfort that their policies
may inflict on others, such as the lower middle class.</def><br/
[<source>PJC</source>]</p>

<p><ent>Limp</ent><br/
<hw>Limp</hw> <pr>(l<icr/mp)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Limped</conjf> <pr>(l<icr/mt; 215)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Limping</conjf>.]</vmorph> <ety>[Cf. AS.
<ets>lemp</ets>healt lame, OHG. <ets>limphen</ets> to limp, be weak;
perh. akin to E. <ets>lame</ets>, or to <ets>limp</ets>, a
<root/120.]</ety> <def>To halt; to walk lamely. Also used
figuratively.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limp</ent><br/
<hw>Limp</hw>, <pos>n.</pos> <def>A manner of walking in which the
movement of one or both legs is noticeably abnormal, usually due to
injury or disease; a halt; the act of limping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limp</ent><br/
<hw>Limp</hw>, <pos>n.</pos> <fld>(Ore Washing)</fld> <def>A scraper for
removing poor ore or refuse from the sieve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limp</ent><br/
<hw>Limp</hw>, <pos>a.</pos> <ety>[Cf. Icel. <ets>limpa</ets> limpness,
weakness, and E. <ets>lap</ets>, <pos>n.</pos>, <ets>lop</ets>, <pos>v.
t.</pos> Cf. <er>Limber</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>Flaccid; flabby, as flesh.</def> <rj><au>Walton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lacking stiffness; flimsy; <as>as, a <ex>limp</ex>
cravat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpa</ent><br/
<hw>Limp"a</hw>, <pos>n.</pos> <ety>[Swedish]</ety> <def>a type of rye
bread, made using molasses or brown sugar.</def> <au>MW10</au><br/
[<source>PJC</source>]</p>

<p><ent>Limper</ent><br/
<hw>Limp"er</hw> <pr>(l<icr/mp"<etil/r)</pr>, <pos>n.</pos> <def>One who
limps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpet</ent><br/
<hw>Lim"pet</hw> <pr>(l<icr/m"p<ecr/t)</pr>, <pos>n.</pos> <ety>[Prob.
through French fr. L. <ets>lepas</ets>, <ets>-adis</ets>, Gr.
<grk>lepa`s</grk>, <grk>-a`dos</grk>.]</ety> <fld>(Zool.)</fld>
<sn>1.</sn> <def>In a general sense, any hatshaped, or conical,
gastropod shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any one of many species of marine shellfish of the
order <ord>Docoglossa</ord>, mostly found adhering to rocks, between
tides.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common European limpets of the genus
<gen>Patella</gen> (esp. <spn>Patella vulgata</spn>) are extensively
used as food. The common New England species is <spn>Acm<ae/a
testudinalis</spn>. Numerous species of limpets occur on the Pacific
coast of America, some of them of large size.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> Hence: <def>Somthing or someone that clings tenaciously
to another object or person;</def> <specif>specifically</specif> <def>a
military explosive device having magnets allowing it to cling to a
metallic target object, such as the hull of a ship.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Any species of <gen>Siphonaria</gen>, a genus of
limpet-shaped Pulmonifera, living between tides, on rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A keyhole limpet. See <er>Fissurella</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpid</ent><br/
<hw>Lim"pid</hw> <pr>(l<icr/m"p<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>limpidus</ets>; akin to Gr. <grk>la`mpein</grk> to shine: cf. F.
<ets>limpide</ets>. Cf. <er>Lamp</er>.]</ety> <sn>1.</sn>
<def>Characterized by clearness or transparency; clear; <as>as, a
<ex>limpid</ex> stream</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Springs which were clear, fresh, and <qex>limpid</qex>.</q>
<rj><qau>Woodward.</qau></rj></p>

<p><sn>2.</sn> <def>Clear and unambiguous; lucid; easy to understand; --
of speech and writing; <as>as, <ex>limpid</ex> prose</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Calm, untroubled, and without worry;
serene.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Clear; transparent; pellucid; lucid; pure;
crystal; translucent; bright.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpidity</ent><br/
<hw>Lim*pid"i*ty</hw> <pr>(l<icr/m*p<icr/d"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>limpiditas</ets>: cf. F.
<ets>limpidit<eacute/</ets>.]</ety> <def>The quality or state of being
limpid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpidness</ent><br/
<hw>Lim"pid*ness</hw> <pr>(l<icr/m"p<icr/d*n<ecr/s)</pr>, <pos>n.</pos>
<def>Quality of being limpid; limpidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpin</ent><br/
<hw>Lim"pin</hw> <pr>(l<icr/m"p<icr/n)</pr>, <pos>n.</pos> <def>A
limpet.</def> <mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpingly</ent><br/
<hw>Limp"ing*ly</hw> <pr>(l<icr/mp"<icr/ng*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a limping manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpitude</ent><br/
<hw>Limp"i*tude</hw> <pr>(l<icr/mp"<icr/*t<umac/d)</pr>, <pos>n.</pos>
<def>Limpidity.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpkin</ent><br/
<hw>Limp"kin</hw> <pr>(l<icr/mp"k<icr/n)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Either one of two species of wading birds of the
genus <gen>Aramus</gen>, intermediate between the cranes and rails. The
limpkins are remarkable for the great length of the toes. One species
(<spn>Aramus giganteus</spn>) inhabits Florida and the West Indies; the
other (<spn>Aramus scolopaceus</spn>) is found in South America. Called
also <altname>courlan</altname>, and <altname>crying
bird</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limpness</ent><br/
<hw>Limp"ness</hw>, <pos>n.</pos> <def>The quality or state of being
limp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limsy</ent><br/
<ent>Limpsy</ent><br/
<mhw>{ <hw>Limp"sy</hw> <pr>(l<icr/mp"s<ycr/)</pr>, <hw>Lim"sy</hw>
<pr>(l<icr/m"s<ycr/)</pr>, }</mhw> <pos>a.</pos> <ety>[See
<er>Limp</er>, <pos>a.</pos>, and cf. W. <ets>llymsi</ets> having a
fickle motion, weak. Cf. <er>Flimsy</er>.]</ety> <def>Limp; flexible;
flimsy.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limu</ent><br/
\'d8<hw>Li"mu</hw> <pr>(l<emac/"m<oomac/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The Hawaiian name for seaweeds. Over sixty kinds
are used as food, and have species names, as <spn>Limu Lipoa</spn>,
<spn>Limu palawai</spn>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limule</ent><br/
<hw>Lim"ule</hw> <pr>(l<icr/m"<usl/l)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <fld>(Zool.)</fld> <def>A limulus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limuloidea</ent><br/
\'d8<hw>Lim`u*loi"de*a</hw> <pr>(l<icr/m`<usl/*loi"d<esl/*<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL. See <er>Limulus</er>, and
<er>-oid</er>.]</ety> <fld>(Zool.)</fld> <def>An order of
<class>Merostomata</class>, including among living animals the genus
<gen>Limulus</gen>, with various allied fossil genera, mostly of the
Carboniferous period. Called also
<altname><ord>Xiphosura</ord></altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are six pairs of leglike organs, surrounding the
mouth, most of which terminate in claws; those of the first pair
(probably mandibles) are the smallest; the others have the basal joints
thickened and spinose, to serve as jaws, while the terminal joints serve
as legs. This group is intermediate, in some characteristics, between
crustaceans and certain arachnids (scorpions), but the respiration is by
means of lamellate gills borne upon the five posterior abdominal
appendages, which are flat and united in pairs by their inner edges, and
are protected by the lidlike anterior pair, which also bear the genital
orifices.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limulus</ent><br/
\'d8<hw>Lim"u*lus</hw> <pr>(l<icr/m"<usl/*l<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Limuli</plw> <pr>(-l<imac/)</pr>.</plu> <ety>[L.,
dim. of <ets>limus</ets> sidelong, askance.]</ety> <fld>(Zool.)</fld>
<def>The only existing genus of Merostomata. It includes only a few
species from the East Indies, and one (<spn>Limulus polyphemus</spn>)
from the Atlantic coast of North America. Called also <altname>Molucca
crab</altname>, <altname>king crab</altname>, <altname>horseshoe
crab</altname>, and <altname>horsefoot</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Limy</ent><br/
<hw>Lim"y</hw> <pr>(l<imac/m"<ycr/)</pr>, <pos>a.</pos> <ety>[See 4th
<er>Lime</er>.]</ety> <sn>1.</sn> <def>Smeared with, or consisting of,
lime; viscous.</def> <ldquo/<xex>Limy</xex> snares.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Containing lime; <as>as, a <ex>limy</ex>
soil</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Resembling lime; having the qualities of
lime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lin</ent><br/
<hw>Lin</hw> <pr>(l<icr/n)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>linnan</ets>. See <er>Lithe</er>.]</ety> <def>To yield; to stop; to
cease.</def> <mark>[Obs. or Scot.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lin</ent><br/
<hw>Lin</hw>, <pos>v. t.</pos> <def>To cease from.</def> <mark>[Obs. or
Scot.]</mark></p>

<p><ent>Lin</ent><br/
<hw>Lin</hw>, <pos>n.</pos> <ety>[Ir. <ets>linn</ets>, or Gael.
<ets>linne</ets>; akin to W. <ets>llyn</ets> a pool, pond, lake, but in
senses 2 and 3 prob. from AS. <ets>hlynn</ets> torrent. Cf.
<er>Dunlin</er>.]</ety> <sn>1.</sn> <def>A pool or collection of water,
particularly one above or below a fall of water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A waterfall, or cataract; <as>as, a roaring
<ex>lin</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A steep ravine.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Written also <xex>linn</xex> and
<xex>lyn</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linage</ent><br/
<hw>Lin"age</hw> <pr>(l<icr/n"<asl/j)</pr>, <pos>n.</pos> <def>See
<er>Lineage</er>.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linament</ent><br/
<hw>Lin"a*ment</hw> <pr>(l<icr/n"<adot/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>linamentum</ets>, fr. <ets>linum</ets> flax.]</ety>
<fld>(Surg.)</fld> <def>Lint; esp., lint made into a tent for insertion
into wounds or ulcers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linaria</ent><br/
<hw>Linaria</hw> <pos>n.</pos> <def>A genus of herbs and subshrubs
having showy flowers: spurred snapdragon.</def><br/
<syn><b>Syn. --</b> genus <gen>Linaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Linarite</ent><br/
<hw>Li*nar"ite</hw> <pr>(l<esl/*n<aum/r"<imac/t)</pr>, <pos>n.</pos>
<ety>[So called because formerly supposed to occur at
<etsep>Linares</etsep>, in Spain.]</ety> <fld>(Min.)</fld> <def>A
hydrous sulphate of lead and copper occurring in bright blue monoclinic
crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linch</ent><br/
<hw>Linch</hw> <pr>(l<icr/nch)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hlinc</ets> a hill.]</ety> <def>A ledge; a right-angled
projection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linchi</ent><br/
\'d8<hw>Lin"chi</hw> <pr>(l<icr/n"ch<icr/)</pr>, <pos>n.</pos>
<ety>[Native Chinese name.]</ety> <fld>(Zool.)</fld> <def>An esculent
swallow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linchpin</ent><br/
<hw>Linch"pin`</hw> <pr>(l<icr/nch"p<icr/n`)</pr>, <pos>n.</pos>
<ety>[AS. <ets>lynis</ets> the axletree; akin to D. <ets>luns</ets>
linchpin, OS. <ets>lunisa</ets>, LG. <ets>lunse</ets>, G.
<ets>l<uum/nse</ets>, OHG. <ets>lun</ets> peg, bolt.]</ety> <def>A pin
used to prevent the wheel of a vehicle from sliding off the
axletree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lincoln green</ent><br/
<hw>Lin"coln green"</hw> <pr>(l<icr/<nsm/"k<ucr/n gr<emac/n")</pr>
<pos>n.</pos> <def>A color of cloth formerly made in
<etsep>Lincoln</etsep>, England; the cloth itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lincolnian</ent><br/
<hw>Lincolnian</hw> <pos>adj.</pos> <def>of or pertaining to
<person>Abraham <etsep>Lincoln</etsep></person>.</def><br/
<syn><b>Syn. --</b> Lincolnesque.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lincomycin</ent><br/
<hw>lincomycin</hw> <pos>n.</pos> <def>An antibacterial antibiotic
obtained from the bacterium <spn>Streptomyces lincolnensis</spn> and
used in the treatment of certain penicillin-resistant
infections.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Linctus</ent><br/
<ent>Lincture</ent><br/
<mhw>{ <hw>Linc"ture</hw> <pr>(l<icr/<nsm/k"t<usl/r; 135)</pr>,
<hw>Linc"tus</hw> <pr>(l<icr/<nsm/k"t<ucr/s)</pr>, }</mhw> <pos>n.</pos>
<ety>[L. <ets>lingere</ets>, <ets>linctum</ets>, to lick.]</ety>
<def>Medicine taken by licking with the tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lind</ent><br/
<hw>Lind</hw> <pr>(l<icr/nd)</pr>, <pos>n.</pos> <def>The linden. See
<er>Linden</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lindane</ent><br/
<hw>lindane</hw> <pos>n.</pos> <def>A chemical substance
(<chform>C6H6Cl6</chform>) used as an agricultural
insecticide.</def><br/
<syn><b>Syn. --</b> hexachlorocyclohexane, gamma benzene
hexachloride.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Linden</ent><br/
<hw>Lin"den</hw> <pr>(l<icr/n"d<eit/n)</pr>, <pos>n.</pos> <ety>[Orig.
an adj. from <ets>lind</ets> linden tree, AS. <ets>lind</ets>; akin to
D. & G. <ets>linde</ets>, OHG. <ets>linta</ets>, Icel., Sw., & Dan.
<ets>lind</ets>. Cf. <er>Lime</er> linden.]</ety> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A handsome tree (<spn>Tilia Europ<ae/a</spn>), having
cymes of light yellow flowers, and large cordate leaves. The tree is
common in Europe.</def> <sd>(b)</sd> <def>In America, the basswood, or
<spn>Tilia Americana</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lindera</ent><br/
<hw>Lindera</hw> <pos>n.</pos> <def>A genus of aromatic evergreen or
deciduous dioecious shrubs or trees of eastern Asia and North
America.</def><br/
<syn><b>Syn. --</b> genus <gen>Lindera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lindheimera</ent><br/
<hw>Lindheimera</hw> <pos>n.</pos> <def>A genus having only one species,
the Texas star.</def><br/
<syn><b>Syn. --</b> genus <gen>Lindheimera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lindia</ent><br/
\'d8<hw>Lin"di*a</hw> <pr>(l<icr/n"d<icr/*<adot/)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A peculiar genus of rotifers,
remarkable for the absence of ciliated disks. By some Zoologists it is
thought to be like the ancestral form of the Arthropoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lindiform</ent><br/
<hw>Lin"di*form</hw> <pr>(l<icr/n"d<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[<ets>Lindia</ets> + <ets>-form</ets>.]</ety> <fld>(Zool.)</fld>
<def>Resembling the genus Lindia; -- said of certain apodous insect
larv<ae/.</def> <mark>[See Illust. under <er>Larva</er>.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>lindy</ent><br/
<hw>lin"dy</hw> <pos>n.</pos> <def>an energetic American dance that was
popular in the 1930s (probably named for the aviator <person>Charles
Lindbergh</person>).</def><br/
<syn><b>Syn. --</b> lindy hop.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Line</ent><br/
<hw>Line</hw> <pr>(l<imac/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lin</ets>. See <er>Linen</er>.]</ety> <sn>1.</sn> <def>Flax;
linen.</def> <mark>[Obs.]</mark> <ldquo/Garments made of
<xex>line</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The longer and finer fiber of flax.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Line</ent><br/
<hw>Line</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lined</conjf> <pr>(l<imac/nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lining</conjf>.]</vmorph> <ety>[See <er>Line</er> flax.]</ety>
<sn>1.</sn> <def>To cover the inner surface of; <as>as, to <ex>line</ex>
a cloak with silk or fur; to <ex>line</ex> a box with paper or
tin.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The inside <qex>lined</qex> with rich carnation silk.</q>
<rj><qau>W. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put something in the inside of; to fill; to
supply, as a purse with money.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The charge amounteth very high for any one man's purse, except
<qex>lined</qex> beyond ordinary, to reach unto.</q>
<rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Till coffee has her stomach <qex>lined</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To place persons or things along the side of for
security or defense; to strengthen by adding anything; to fortify;
<as>as, to <ex>line</ex> works with soldiers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Line</qex> and new repair our towns of war<br/
With men of courage and with means defendant.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To impregnate; -- applied to brute animals.</def>
<rj><au>Creech.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lined gold</b></col>, <cd>gold foil having a lining of
another metal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Line</ent><br/
<hw>Line</hw>, <pos>n.</pos> <ety>[OE. <ets>line</ets>, AS.
<ets>l<imac/ne</ets> cable, hawser, prob. from L. <ets>linea</ets> a
linen thread, string, line, fr. <ets>linum</ets> flax, thread, linen,
cable; but the English word was influenced by F. <ets>ligne</ets> line,
from the same L. word <ets>linea</ets>. See <er>Linen</er>.]</ety>
<sn>1.</sn> <def>A linen thread or string; a slender, strong cord; also,
a cord of any thickness; a rope; a hawser; <as>as, a fishing
<ex>line</ex>; a <ex>line</ex> for snaring birds; a
clothes<ex>line</ex>; a tow<ex>line</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who so layeth <qex>lines</qex> for to latch fowls.</q>
<rj><qau>Piers Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A more or less threadlike mark of pen, pencil, or
graver; any long mark; <as>as, a chalk <ex>line</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The course followed by anything in motion; hence, a
road or route; <as>as, the arrow descended in a curved <ex>line</ex>;
the place is remote from <ex>lines</ex> of travel.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Direction; <as>as, the <ex>line</ex> of sight or
vision</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A row of letters, words, etc., written or printed;
esp., a row of words extending across a page or column.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A short letter; a note; <as>as, a <ex>line</ex> from
a friend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Poet.)</fld> <def>A verse, or the words which form
a certain number of feet, according to the measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the preceding <qex>line</qex> Ulysses speaks of Nausicaa.</q>
<rj><qau>Broome.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Course of conduct, thought, occupation, or policy;
method of argument; department of industry, trade, or intellectual
activity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is uncommonly powerful in his own <qex>line</qex>, but it is
not the <qex>line</qex> of a first-rate man.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Math.)</fld> <def>That which has length, but not
breadth or thickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>The exterior limit of a figure, plat, or territory;
boundary; contour; outline.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eden stretched her <qex>line</qex><br/
From Auran eastward to the royal towers<br/
Of great Seleucia.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>A threadlike crease marking the face or the hand;
hence, characteristic mark.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though on his brow were graven <qex>lines</qex> austere.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He tipples palmistry, and dines<br/
On all her fortune-telling <qex>lines</qex>.</q>
<rj><qau>Cleveland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Lineament; feature; figure.</def> <ldquo/The
<xex>lines</xex> of my boy's face.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>A straight row; a continued series or rank; <as>as,
a <ex>line</ex> of houses, or of soldiers; a <ex>line</ex> of
barriers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unite thy forces and attack their <qex>lines</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>A series or succession of ancestors or descendants
of a given person; a family or race; <as>as, the ascending or descending
<ex>line</ex>; the <ex>line</ex> of descent; the male <ex>line</ex>; a
<ex>line</ex> of kings.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of his lineage am I, and his offspring<br/
By very <qex>line</qex>, as of the stock real.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>A connected series of public conveyances, and
hence, an established arrangement for forwarding merchandise, etc.;
<as>as, a <ex>line</ex> of stages; an express
<ex>line</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <fld>(Geog.)</fld> <sd>(a)</sd> <def>A circle of
latitude or of longitude, as represented on a map.</def> <sd>(b)</sd>
<def>The equator; -- usually called <xex>the line</xex>, or
<xex>equinoctial line</xex>; <as>as, to cross <ex>the
line</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>A long tape, or a narrow ribbon of steel, etc.,
marked with subdivisions, as feet and inches, for measuring; a
tapeline.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <fld>(Script.)</fld> <sd>(a)</sd> <def>A measuring line
or cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He marketh it out with a <qex>line</qex>.</q> <rj><qau>Is. xliv.
13.</qau></rj></p>

<p><sd>(b)</sd> <def>That which was measured by a line, as a field or
any piece of land set apart; hence, allotted place of abode.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lines</qex> are fallen unto me in pleasant places; yea, I
have a goodly heritage.</q> <rj><qau>Ps. xvi. 6.</qau></rj></p>

<p><sd>(c)</sd> <def>Instruction; doctrine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their <qex>line</qex> is gone out through all the earth.</q>
<rj><qau>Ps. xix. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>19.</sn> <fld>(Mach.)</fld> <def>The proper relative position or
adjustment of parts, not as to design or proportion, but with reference
to smooth working; <as>as, the engine is in <ex>line</ex> or out of
<ex>line</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>20.</sn> <def>The track and roadbed of a railway;
railroad.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>21.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>A row of men who are
abreast of one another, whether side by side or some distance apart; --
opposed to <contr>column</contr>.</def> <sd>(b)</sd> <def>The regular
infantry of an army, as distinguished from militia, guards, volunteer
corps, cavalry, artillery, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>22.</sn> <fld>(Fort.)</fld> <sd>(a)</sd> <def>A trench or
rampart.</def> <sd>(b)</sd> <pluf>pl.</pluf> <def>Dispositions made to
cover extended positions, and presenting a front in but one direction to
an enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>23.</sn> <pluf>pl.</pluf> <fld>(Shipbuilding)</fld> <def>Form of
a vessel as shown by the outlines of vertical, horizontal, and oblique
sections.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>24.</sn> <fld>(Mus.)</fld> <def>One of the straight horizontal
and parallel prolonged strokes on and between which the notes are
placed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>25.</sn> <fld>(Stock Exchange)</fld> <def>A number of shares
taken by a jobber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>26.</sn> <fld>(Trade)</fld> <def>A series of various qualities
and values of the same general class of articles; <as>as, a full
<ex>line</ex> of hosiery; a <ex>line</ex> of merinos, etc.</as></def>
<rj><au>McElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>27.</sn> <def>The wire connecting one telegraphic station with
another, or the whole of a system of telegraph wires under one
management and name.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>28.</sn> <pluf>pl.</pluf> <def>The reins with which a horse is
guided by his driver.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>29.</sn> <def>A measure of length; one twelfth of an
inch.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hard lines</b></col>, <cd>hard lot.</cd> <au>C.
Kingsley.</au> [See Def. 18.] -- <col><b>Line breeding</b></col>
<fld>(Stockbreeding)</fld>, <cd>breeding by a certain family line of
descent, especially in the selection of the dam or mother.</cd> --
<col><b>Line conch</b></col> <fld>(Zool.)</fld>, <cd>a spiral marine
shell (<spn>Fasciolaria distans</spn>), of Florida and the West Indies.
It is marked by narrow, dark, revolving lines.</cd> -- <col><b>Line
engraving</b></col>. <sd>(a)</sd> <cd>Engraving in which the effects are
produced by lines of different width and closeness, cut with the burin
upon copper or similar material; also, a plate so engraved.</cd>
<sd>(b)</sd> <cd>A picture produced by printing from such an
engraving.</cd> -- <col><b>Line of battle</b></col>. <sd>(a)</sd>
<fld>(Mil. Tactics)</fld> <cd>The position of troops drawn up in their
usual order without any determined maneuver.</cd> <sd>(b)</sd>
<fld>(Naval)</fld> <cd>The line or arrangement formed by vessels of war
in an engagement.</cd> -- <col><b>Line of battle ship</b></col>. <cd>See
<cref>Ship of the line</cref>, below.</cd> -- <col><b>Line of
beauty</b></col> <fld>(Fine Arts)</fld>,<cd>an abstract line supposed to
be beautiful in itself and absolutely; -- differently represented by
different authors, often as a kind of elongated <it>S</it> (like the one
drawn by Hogarth).</cd> -- <col><b>Line of centers</b></col>.
<fld>(Mach.)</fld> <sd>(a)</sd> <cd>A line joining two centers, or
fulcra, as of wheels or levers.</cd> <sd>(b)</sd> <cd>A line which
determines a dead center. See <cref>Dead center</cref>, under
<er>Dead</er>.</cd> -- <col><b>Line of dip</b></col> <fld>(Geol.)</fld>,
<cd>a line in the plane of a stratum, or part of a stratum,
perpendicular to its intersection with a horizontal plane; the line of
greatest inclination of a stratum to the horizon.</cd> -- <col><b>Line
of fire</b></col> <fld>(Mil.)</fld>, <cd>the direction of fire.</cd> --
<col><b>Line of force</b></col> <fld>(Physics)</fld>, <cd>any line in a
space in which forces are acting, so drawn that at every point of the
line its tangent is the direction of the resultant of all the forces. It
cuts at right angles every equipotential surface which it meets.
Specifically <fld>(Magnetism)</fld>, a line in proximity to a magnet so
drawn that any point in it is tangential with the direction of a short
compass needle held at that point.</cd> <au>Faraday.</au> --
<col><b>Line of life</b></col> <fld>(Palmistry)</fld>, <cd>a line on the
inside of the hand, curving about the base of the thumb, supposed to
indicate, by its form or position, the length of a person's life.</cd>
-- <col><b>Line of lines</b></col>. <cd>See <er>Gunter's line</er>.</cd>
-- <col><b>Line of march</b></col>. <fld>(Mil.)</fld> <sd>(a)</sd>
<cd>Arrangement of troops for marching.</cd> <sd>(b)</sd> <cd>Course or
direction taken by an army or body of troops in marching.</cd> --
<col><b>Line of operations</b></col>, <cd>that portion of a theater of
war which an army passes over in attaining its object.</cd> <au>H. W.
Halleck.</au> -- <col><b>Line of sight</b></col> <fld>(Firearms)</fld>,
<cd>the line which passes through the front and rear sight, at any
elevation, when they are sighted at an object.</cd> -- <col><b>Line
tub</b></col> <fld>(Naut.)</fld>, <cd>a tub in which the line carried by
a whaleboat is coiled.</cd> -- <mcol><col><b>Mason and Dixon's
line</b></col>, <col><b>Mason-Dixon line</b></col></mcol>, <cd>the
boundary line between Pennsylvania and Maryland, as run before the
Revolution (1764-1767) by two English astronomers named <person>Charles
Mason</person> and <person>Jeremiah Dixon</person>. In an extended
sense, the line between the free and the slave States; <as>as, below the
<ex>Mason-Dixon line</ex>, i.e. in the South</as>.</cd> -- <col><b>On
the line</b></col>, <sd>(a)</sd> <cd>on a level with the eye of the
spectator; -- said of a picture, as hung in an exhibition of
pictures.</cd> <sd>(b)</sd> <cd>at risk (dependent upon success) in a
contest or enterprise; <as>as, the survival of the company is <ex>on the
line</ex> in this project</as>.</cd> -- <col><b>Right line</b></col>,
<cd>a straight line; the shortest line that can be drawn between two
points.</cd> -- <col><b>Ship of the line</b></col>, <cd>formerly, a ship
of war large enough to have a place in the line of battle; a vessel
superior to a frigate; usually, a seventy-four, or three-decker; --
called also <altname>line of battle ship</altname> or
<altname>battleship</altname>.</cd> <au>Totten.</au> -- <col><b>To cross
the line</b></col>, <cd>to cross the equator, as a vessel at sea.</cd>
-- <col><b>To give a person line</b></col>, <cd>to allow him more or
less liberty until it is convenient to stop or check him, like a hooked
fish that swims away with the line.</cd> -- <col><b>Water line</b></col>
<fld>(Shipbuilding)</fld>, <cd>the outline of a horizontal section of a
vessel, as when floating in the water.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 856 pr=VMG --></p>

<p><ent>Line</ent><br/
<hw>Line</hw> <pr>(l<imac/n)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
mark with a line or lines; to cover with lines; <as>as, to <ex>line</ex>
a copy book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had a healthy color in his cheeks, and his face, though
<qex>lined</qex>, bore few traces of anxiety.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To represent by lines; to delineate; to
portray.</def> <mark>[R.]</mark> <ldquo/Pictures fairest
<xex>lined</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To read or repeat line by line; <as>as, to
<ex>line</ex> out a hymn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This custom of reading or <qex>lining</qex>, or, as it was
frequently called <ldquo/deaconing<rdquo/ the hymn or psalm in the
churches, was brought about partly from necessity.</q> <rj><qau>N. D.
Gould.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To form into a line; to align; <as>as, to
<ex>line</ex> troops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To line bees</b></col>, <cd>to track wild bees to their
nest by following their line of flight.</cd> -- <col><b>To line
up</b></col> <fld>(Mach.)</fld>, <cd>to put in alignment; to put in
correct adjustment for smooth running. See 3d <er>Line</er>,
19.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineage</ent><br/
<hw>Lin"e*age</hw> <pr>(l<icr/n"<esl/*<asl/j; 48)</pr>, <pos>n.</pos>
<ety>[OE. <ets>linage</ets>, F. <ets>lignage</ets>, fr. L.
<ets>linea</ets> line. See 3d <er>Line</er>.]</ety> <def>Descent in a
line from a common progenitor; progeny; race; descending line of
offspring or ascending line of parentage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both the <qex>lineage</qex> and the certain sire<br/
From which I sprung, from me are hidden yet.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineal</ent><br/
<hw>Lin"e*al</hw> <pr>(l<icr/n"<esl/*<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>linealis</ets> belonging to a line, fr. <ets>linea</ets>
line: cf. F. <ets>lin<eacute/al</ets>. See 3d <er>Line</er>.]</ety>
<sn>1.</sn> <def>Descending in a direct line from an ancestor;
hereditary; derived from ancestors; -- opposed to
<contr>collateral</contr>; <as>as, a <ex>lineal</ex> descent or a
<ex>lineal</ex> descendant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The prime and ancient right of <qex>lineal</qex> succession.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inheriting by direct descent; having the right by
direct descent to succeed (<ptcl>to</ptcl>).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For only you are <qex>lineal</qex> to the throne.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Composed of lines; delineated; <as>as,
<ex>lineal</ex> designs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In the direction of a line; of or pertaining to a
line; measured on, or ascertained by, a line; linear; <as>as,
<ex>lineal</ex> magnitude</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lineal measure</b></col>, <cd>the measure of length; --
usually written <altname>linear measure</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineality</ent><br/
<hw>Lin`e*al"i*ty</hw> <pr>(l<icr/n`<esl/*<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The quality of being lineal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineally</ent><br/
<hw>Lin"e*al*ly</hw> <pr>(l<icr/n"<esl/*<ait/l*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a lineal manner; <as>as, the prince is
<ex>lineally</ex> descended from the Conqueror</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineament</ent><br/
<hw>Lin"e*a*ment</hw> <pr>(l<icr/n"<esl/*<adot/*m<eit/nt)</pr>,
<pos>n.</pos> <ety>[L. <ets>lineamentum</ets>, fr. <ets>linea</ets>
line: cf. F. <ets>lin<eacute/ament</ets>. See 3d <er>Line</er>.]</ety>
<def>One of the outlines, exterior features, or distinctive marks, of a
body or figure, particularly of the face; feature; form; mark; --
usually in the <xex>plural</xex>.</def> <ldquo/The <xex>lineaments</xex>
of the body.<rdquo/ <au>Locke.</au> <ldquo/<xex>Lineaments</xex> in the
character.<rdquo/ <au>Swift.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Man he seems<br/
In all his <qex>lineaments</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linear</ent><br/
<hw>Lin"e*ar</hw> <pr>(l<icr/n"<esl/*<etil/r)</pr>, <pos>a.</pos>
<ety>[L. <ets>linearis</ets>, <ets>linearius</ets>, fr. <ets>linea</ets>
line: cf. F. <ets>lin<eacute/aire</ets>. See 3d <er>Line</er>.]</ety>
<sn>1.</sn> <def>Of or pertaining to a line; consisting of lines; in a
straight direction; lineal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Like a line; narrow; of the same
breadth throughout, except at the extremities; <as>as, a <ex>linear</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Thinking in a step-by-step analytical and logical
fashion; contrasted with <contr>holistic</contr>, i.e. thinking in terms
of complex interrelated patterns; <as>as, <ex>linear</ex>
thinkers</as>.</def><br/
[<source>PJC</source>]</p>

<p><q><qex>Linear</qex> thinkers concluded that by taking the world
apart, the actions of people were more predictable and controllable.</q>
<rj><qau>David Morris (Conference presentation, Fairfield University,
October 31, 1997)</qau></rj></p>

<p><cs><col><b>Linear differential equation</b></col>
<fld>(Math.)</fld>, <cd>an equation which is of the first degree, when
the expression which is equated to zero is regarded as a function of the
dependent variable and its differential coefficients.</cd> --
<col><b>Linear equation</b></col> <fld>(Math.)</fld>, <cd>an equation of
the first degree between two variables; -- so called because every such
equation may be considered as representing a right line.<-- = straight
line! --></cd> -- <col><b>Linear measure</b></col>, <cd>the measurement
of length.</cd> -- <col><b>Linear numbers</b></col> <fld>(Math.)</fld>,
<cd>such numbers as have relation to length only: such is a number which
represents one side of a plane figure. If the plane figure is square,
the linear figure is called a <xex>root</xex>.</cd> -- <col><b>Linear
problem</b></col> <fld>(Geom.)</fld>, <cd>a problem which may be solved
geometrically by the use of right lines alone.</cd> -- <col><b>Linear
transformation</b></col> <fld>(Alg.)</fld>, <cd>a change of variables
where each variable is replaced by a function of the first degree in the
new variable.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linearensate</ent><br/
<hw>Lin`e*ar*en"sate</hw>
<pr>(l<icr/n`<esl/*<etil/r*<ecr/n"s<asl/t)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having the form of a sword, but very long and
narrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linearly</ent><br/
<hw>Lin"e*ar*ly</hw>, <pos>adv.</pos> <def>In a linear manner; with
lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linear-shaped</ent><br/
<hw>Lin"e*ar-shaped`</hw> <pr>(l<icr/n"<esl/*<etil/r*sh<amac/pt`)</pr>,
<pos>a.</pos> <def>Of a linear shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineary</ent><br/
<hw>Lin"e*a*ry</hw> <pr>(l<icr/n"<esl/*<asl/*r<ycr/)</pr>, <pos>a.</pos>
<def>Linear.</def> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineated</ent><br/
<ent>Lineate</ent><br/
<mhw>{ <hw>Lin"e*ate</hw> <pr>(l<icr/n"<esl/*<asl/t)</pr>,
<hw>Lin"e*a`ted</hw> <pr>(l<icr/n"<esl/*<amac/`t<ecr/d)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>lineatus</ets>, p. p. of <ets>lineare</ets>
to reduce to a straight line, fr. <ets>linea</ets> line.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>Marked with lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Marked longitudinally with
depressed parallel lines; <as>as, a <ex>lineate</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineation</ent><br/
<hw>Lin`e*a"tion</hw> <pr>(l<icr/n`<esl/*<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>lineatio</ets> the drawing of a line, fr.
<ets>lineare</ets>.]</ety> <def>Delineation; a line or lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineature</ent><br/
<hw>Lin"e*a*ture</hw> <pr>(l<icr/n"<esl/*<adot/*t<usl/r; 135)</pr>,
<pos>n.</pos> <def>Anything having an outline.</def> <mark>[R.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>linecut</ent><br/
<hw>linecut</hw> <pos>n.</pos> <def>a print obtained from a line
drawing.</def><br/
<syn><b>Syn. --</b> line engraving.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a block that has been etched or engraved.</def><br/
<syn><b>Syn. --</b> line block, line engraving.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lined</ent><br/
<hw>lined</hw> <pos>adj.</pos> <sn>1.</sn> <def>furnished with items in
a line or as if in a line.</def> <note>Often used in hyphenated form,
prefixed by the item arranged in a line; <as>as, tree-<ex>lined</ex>
streets</as>.</note><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>having visible lines; -- used especially of skin;
<as>as, their <ex>lined</ex> faces were immeasurably sad</as>.
Contrasted to <ant>smooth</ant>.</def><br/
<syn><b>Syn. --</b> furrowed, seamed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>having a lining or a liner; often used in
combination; <as>as, a <ex>lined</ex> skirt; a silk-<ex>lined</ex>
jacket</as>. Opposite of <ant>unlined</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>linelike</ent><br/
<hw>linelike</hw> <pos>adj.</pos> <def>resembling a line; long, thin,
and narrow.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lineman</ent><br/
<hw>Line"man</hw> <pr>(l<imac/n"m<acr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Linemen</plw> <pr>(l<imac/n"m<ecr/n)</pr>.</plu>
<sn>1.</sn> <def>One who carries the line in surveying, etc.; the
surveyor who marks positions with a range pole.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man employed to examine the rails of a railroad to
see if they are in good condition; also, a man employed to install or
repair telegraph, telephone, television cable, or power lines. Also
called <altname>linesman</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Football)</fld> <def>A player whose position is in
the first (forward) line, as opposed to a <contr>back</contr>; one who
plays on the line of scrimmage.</def> <specif>specifically:</specif>
<def>a center, guard, or tackle.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A ladies' man who is especially adept at inventing
effective introductory phrases (<ecol><b>pick-up lines</b></ecol>) to
gain a woman's attention.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>the position of a player on a football team who is
stationed on the line of scrimmage.</def> <wns>[wns=4]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>linemen</ent><br/
<hw>linemen</hw> <pos>n. pl.</pos> <sing><singw>lineman</singw></sing>.
<def>the football players who line up on the line of scrimmage.</def>
<wnote>WN hypen is odd for this def.</wnote><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Linen</ent><br/
<hw>Lin"en</hw> <pr>(l<icr/n"<ecr/n)</pr>, <pos>a.</pos> <ety>[OE., fr.
<ets>lin</ets> linen. See <er>Linen</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>Made of linen; <as>as, <ex>linen</ex> cloth; a
<ex>linen</ex> stocking.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling linen cloth; white; pale.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linen</ent><br/
<hw>Lin"en</hw>, <pos>n.</pos> <ety>[Prop. an adj. from OE.
<ets>lin</ets> flax, AS. <ets>l<imac/n</ets> flax, whence
<ets>l<imac/nen</ets> made of flax; akin to OS., Icel., & MHG.
<ets>l<imac/n</ets> flax and linen, G. <ets>lein</ets>,
<ets>leinen</ets>, linen, Sw. <ets>lin</ets> flax, Goth. <ets>lein</ets>
linen, L. <ets>linum</ets> flax, linen, Gr. <grk>li`non</grk>. Cf.
<er>Line</er>, <er>Linseed</er>.]</ety> <sn>1.</sn> <def>Thread or cloth
made of flax or (rarely) of hemp; -- used in a general sense to include
cambric, shirting, sheeting, towels, tablecloths, etc.; <as>as, bed
<ex>linens</ex></as></def> <ldquo/In <xex>linen</xex> white as
milk.<rdquo/ <rj><au>Robert of Brunne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Underclothing, esp. the shirt, as being, in former
times, chiefly made of linen.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- 3. pl. bed linens --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Linen draper</b></col>, <cd>a dealer in linen.</cd> --
<col><b>Linen prover</b></col>, <cd>a small microscope for counting the
threads in a given space in linen fabrics.</cd> -- <mcol><col><b>Linen
scroll</b></col>, <col><b>Linen pattern</b></col></mcol>
<fld>(Arch.)</fld>, <cd>an ornament for filling panels, copied from the
folds of a piece of stuff symmetrically disposed.</cd></cs> <-- bed
linens, sheets and pillowcases for a bed. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linener</ent><br/
<hw>Lin"en*er</hw> <pr>(l<icr/n"<ecr/n*<etil/r)</pr>, <pos>n.</pos>
<def>A dealer in linen; a linen draper.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lineolate</ent><br/
<hw>Lin"e*o*late</hw> <pr>(l<icr/n"<esl/*<osl/*l<asl/t)</pr>,
<pos>a.</pos> <ety>[L. <ets>lineola</ets>, dim. of <ets>linea</ets>
line.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>Marked with little
lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Marked longitudinally with fine
lines.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liner</ent><br/
<hw>Lin"er</hw> <pr>(l<imac/n"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who lines, <as>as, a <ex>liner</ex> of shoes or
clothing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An airplane or ship belonging to a transportation
company;</def> <specif>also,</specif> <def>a line-of-battle ship; a ship
of the line.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>A thin piece placed between two
parts to hold or adjust them, fill a space, etc.; a shim.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A <er>lining</er>{2}.</def>
<specif>Specifically:</specif> <fld>(Steam Engine)</fld> <def>A lining
within the cylinder, in which the piston works and between which and the
outer shell of the cylinder a space is left to form a steam
jacket.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A slab on which small pieces of marble, tile, etc.,
are fastened for grinding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Baseball)</fld> <def>A ball which, when struck,
flies through the air in a nearly straight line not far from the ground;
also called <altname>line drive</altname>; <as>as, he hit a sharp
<ex>liner</ex> to right</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A protective envelope for a phonograph record or
other object.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>A <er>lining</er>; <as>as, a removable coat
<ex>liner</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <def>Same as <er>eyeliner</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>line-shooter</ent><br/
<hw>line-shooter</hw> <pos>n.</pos> <def>a very boastful and talkative
person.</def><br/
<syn><b>Syn. --</b> braggart, boaster, blowhard, vaunter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>linesman</ent><br/
<hw>linesman</hw> <pos>n.</pos> <sn>1.</sn> <def>the official (in tennis
or soccer) who watches the lines.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a person who installs or repairs electrical or
telephone lines.</def><br/
<syn><b>Syn. --</b> electrician, lineman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lineup</ent><br/
<ent>Line-up</ent><br/
<mhw>{ <hw>Line"-up`</hw>, <hw>Line"up`</hw> }</mhw>
<pr>(l<imac/n"<ucr/p)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The members
of a team who are scheduled to play a game.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>The formation of
football players before the start or a restart of play.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Specifically:</specif> <fld>(baseball)</fld>
<def>a list of batters in the order in which they will bat.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> batting order, card, lineup.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <def>any arrangement of persons
(rarely, of things), esp. when having a common purpose or sentiment;
<as>as, the <ex>line-up</ex> at a ticket-office window; the
<ex>line-up</ex> of political factions</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>A group of persons including a suspect in a police
investigation, arranged so as to be observed by a witness, who is
requested to identify the perpetrator, if he/she is present in the
group. Such an identification may be used as evidence of guilt of the
suspect. Also called a <altname>police lineup</altname>.</def>
<wns>[wns=2]</wns><br/
[<source>PJC</source>]</p>

<p><ent>-ling</ent><br/
<hw>-ling</hw> <pr>(-l<icr/ng)</pr> <pos>suff.</pos> <ety>[AS.
<ets>-ling</ets>.]</ety> <def>A noun suffix, commonly having a
<xex>diminutive</xex> or a <xex>depreciatory</xex> force; as in
duck<xex>ling</xex>, gos<xex>ling</xex>, hire<xex>ling</xex>,
foster<xex>ling</xex>, first<xex>ling</xex>,
under<xex>ling</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-ling</ent><br/
<hw>-ling</hw>. <def>An adverbial suffix; <as>as, dark<ex>ling</ex>,
flat<ex>ling</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ling</ent><br/
<hw>Ling</hw> <pr>(l<icr/ng)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lenge</ets>; akin to D. <ets>leng</ets>, G. <ets>l<aum/nge</ets>,
Dan. <ets>lange</ets>, Sw. <ets>l<aring/nga</ets>, Icel.
<ets>langa</ets>. So named from its being <ets>long</ets>. See
<er>Long</er>, <pos>a.</pos>]</ety> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>A large, marine, gadoid fish (<spn>Molva vulgaris</spn>) of
Northern Europe and Greenland. It is valued as a food fish and is
largely salted and dried. Called also <altname>drizzle</altname>.</def>
<sd>(b)</sd> <def>The burbot of Lake Ontario.</def> <sd>(c)</sd> <def>An
American hake of the genus <gen>Phycis</gen>.</def>
<mark>[Canada]</mark> <sd>(d)</sd> <def>A New Zealand food fish of the
genus <gen>Genypterus</gen>. The name is also locally applied to other
fishes, as the cultus cod, the mutton fish, and the cobia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ling</ent><br/
<hw>Ling</hw>, <pos>n.</pos> <ety>[Icel. <ets>lyng</ets>; akin to Dan.
<ets>lyng</ets>, Sw. <ets>ljung</ets>.]</ety> <fld>(Bot.)</fld>
<def>Heather (<spn>Calluna vulgaris</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ling honey</b></col>, <cd>a sort of wild honey, made from
the flowers of the heather.</cd> <rj><au>Holland.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingam</ent><br/
<ent>Linga</ent><br/
<mhw>{ \'d8<hw>Lin"ga</hw> <pr>(l<icr/<nsm/"g<adot/)</pr>,
<hw>Lin"gam</hw> <pr>(l<icr/<nsm/"g<acr/m)</pr>, }</mhw> <pos>n.</pos>
<ety>[Skr. <ets>li<ndot/ga</ets>.]</ety> <def>The phallic symbol under
which Siva is principally worshiped in his character of the creative and
reproductive power.</def> <rj><au>Whitworth. E. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ling-bird</ent><br/
<hw>Ling"-bird`</hw> <pr>(l<icr/ng"b<etil/rd`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The European meadow pipit; -- called also
<altname>titling</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lingcod</ent><br/
<hw>lingcod</hw> <pos>n.</pos> <sn>1.</sn> <def>The flesh of a
lean-fleshed fish caught off the U.S. Pacific coast.</def>
<wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A food fish (<spn>Ophiodon elongatus</spn>) of
Northern Pacific waters related to greenlings.</def>
<wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> Ophiodon elongatus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lingel</ent><br/
<hw>Lin"gel</hw> <pr>(l<icr/<nsm/"g<ecr/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>ligneul</ets>, dim. of L. <ets>linea</ets> a linen thread.]</ety>
<sn>1.</sn> <def>A shoemaker's thread.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little tongue or thong of leather; a lacing for
belts.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lingenberry</ent><br/
<hw>lingenberry</hw> <pos>n.</pos> <def>low evergreen shrub
(<spn>Vaccinium vitis-idaea</spn>) of high north temperate regions of
Europe and Asia and America bearing red edible berries.</def><br/
<syn><b>Syn. --</b> cowberry, mountain cranberry, lingonberry,
lingberry, foxberry, <spn>Vaccinium vitis-idaea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lingence</ent><br/
<hw>Lin"gence</hw> <pr>(l<icr/n"j<eit/ns)</pr>, <pos>n.</pos> <ety>[L.
<ets>lingere</ets> to lick.]</ety> <def>A linctus.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linger</ent><br/
<hw>Lin"ger</hw> <pr>(l<icr/<nsm/"g<etil/r)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lingered</conjf>
<pr>(l<icr/<nsm/"g<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lingering</conjf>.]</vmorph> <ety>[OE. <ets>lengen</ets> to
tarry, AS. <ets>lengan</ets> to prolong, put off, fr. <ets>lang</ets>
long. <root/125. See <er>Long</er>, <pos>a.</pos>]</ety> <def>To delay;
to loiter; to remain or wait long; to be slow or reluctant in parting or
moving; to be slow in deciding; to be in suspense; to
hesitate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor cast one longing, <qex>lingering</qex> look behind.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Perhaps thou <qex>linger'st</qex>, in deep thoughts detained.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To loiter; lag; saunter; delay; tarry; stop;
hesitate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linger</ent><br/
<hw>Lin"ger</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To protract; to draw
out.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>lingers</qex> my desires.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spend or pass in a lingering manner; -- with
<xex>out</xex>; <as>as, to <ex>linger</ex> out one's days on a sick
bed</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingerer</ent><br/
<hw>Lin"ger*er</hw> <pr>(l<icr/<nsm/"g<etil/r*<etil/r)</pr>,
<pos>n.</pos> <def>One who lingers.</def>
<rj><au>Guardian.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingerie</ent><br/
\'d8<hw>Lin`ge*rie"</hw> <pr>(l<acr/N`zh<eit/`r<esl/")</pr>,
<pos>n.</pos> <ety>[F.]</ety> <def>Linen goods collectively; linen
underwear or nightclothes, esp. of women; the clothing of linen and
cotton with its lace, etc., worn by a women.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lingering</ent><br/
<hw>Lin"ger*ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Delaying.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Drawn out in time; remaining long; protracted;
<as>as, a <ex>lingering</ex> disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To die is the fate of man; but to die with <qex>lingering</qex>
anguish is generally his folly.</q> <rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingeringly</ent><br/
<hw>Lin"ger*ing*ly</hw>, <pos>adv.</pos> <def>With delay; slowly;
tediously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linget</ent><br/
<hw>Lin"get</hw> <pr>(l<icr/<nsm/"g<ecr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>lingot</ets>, perh. fr. L. <ets>lingua</ets> tongue (see
<er>Tongue</er>). Cf. <er>Ingot</er>.]</ety> <def>An ingot.</def>
<altsp>[Written also <asp>lingot</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingism</ent><br/
<hw>Ling"ism</hw> <pr>(l<icr/ng"<icr/z'm)</pr>, <pos>n.</pos> <def>A
mode of treating certain diseases, as obesity, by gymnastics; --
proposed by <person>Pehr Henrik <etsep>Ling</etsep></person>, a Swede.
See <er>Kinesiatrics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingle</ent><br/
<hw>Lin"gle</hw> <pr>(l<icr/<nsm/"g'l)</pr>, <pos>n.</pos> <def>See
<er>Lingel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingo</ent><br/
<hw>Lin"go</hw> <pr>(l<icr/<nsm/"g<osl/)</pr>, <pos>n.</pos> <ety>[L.
<ets>lingua</ets> tongue, language. See <er>Lingual</er>.]</ety>
<def>Language; speech; dialect.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingoa wood</ent><br/
<hw>Lin*go"a wood`</hw> <pr>(l<icr/<nsm/*g<omac/"<adot/ w<oocr/d`)</pr>
<pos>n.</pos> <def>Amboyna wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingot</ent><br/
<hw>Lin"got</hw> <pr>(l<icr/<nsm/"g<ocr/t)</pr>, <pos>n.</pos> <def>A
linget or ingot; also, a mold for casting metals. See
<er>Linget</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingua</ent><br/
<ent>Linguae</ent><br/
\'d8<hw>Lin"gua</hw> <pr>(l<icr/<nsm/"gw<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lingu<ae/</plw>
<pr>(l<icr/<nsm/"gw<emac/)</pr>.</plu> <ety>[L., the tongue.]</ety>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A tongue.</def> <sd>(b)</sd> <def>A
median process of the labium, at the under side of the mouth in insects,
and serving as a tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguacious</ent><br/
<hw>Lin*gua"cious</hw> <pr>(l<icr/<nsm/*gw<amac/"sh<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>linguax</ets>, <ets>-acis</ets>, loquacious,
fr. <ets>lingua</ets> tongue.]</ety> <def>Given to the use of the
tongue; loquacious.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguadental</ent><br/
<hw>Lin`gua*den"tal</hw>
<pr>(l<icr/<nsm/`gw<adot/*d<ecr/n"t<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>lingua</ets> tongue + E. <ets>dental</ets>.]</ety>
<fld>(Phonetics)</fld> <def>Formed or uttered by the joint use of the
tongue and teeth, or rather that part of the gum just above the front
teeth; dentolingual, as the letters <xex>d</xex> and
<xex>t</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguadental</ent><br/
<hw>Lin`gua*den"tal</hw>, <pos>n.</pos> <fld>(Phonetics)</fld> <def>An
articulation pronounced by the aid or use of the tongue and
teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingua Franca</ent><br/
<hw>Lin"gua Fran"ca</hw> <pr>(l<icr/<nsm/"gw<adot/
fr<acr/<nsm/"k<adot/)</pr> <pos>n.</pos> <ety>[It., prop., language of
the Franks.]</ety> <sn>1.</sn> <def>The commercial language of the
Levant, -- a mixture of the languages of the people of the region and of
foreign traders.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any hybrid or other language used over a wide area
as a common or commercial tongue among peoples of different
speech.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lingual</ent><br/
<hw>Lin"gual</hw> <pr>(l<icr/<nsm/"gw<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>lingua</ets> tongue: cf. F. <ets>lingual</ets>. See
<er>Tongue</er>, and cf. <er>Language</er>.]</ety> <sn>1.</sn> <def>Of
or pertaining to the tongue; uttered by the aid of the tongue; glossal;
<as>as, the <ex>lingual</ex> nerves; a <ex>lingual</ex>
letter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>lying near the tongue; especially, in dentistry, on
the surface of the tooth next to the tongue. Contrasted with
<contr>buccal</contr>, the side of a tooth touching the cheek, i. e. the
side opposite to the <ex>lingual</ex> side.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Lingual ribbon</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Odontophore</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingual</ent><br/
<hw>Lin"gual</hw>, <pos>n.</pos> <def>A consonant sound formed by the
aid of the tongue; -- a term especially applied to certain articulations
(as those of <xex>t</xex>, <xex>d</xex>, <xex>th</xex>, and
<xex>n</xex>) and to the letters denoting them.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In Sanskrit grammar certain letters, as
<xex><tsdot/</xex>, <xex><tsdot/h</xex>, <xex><dsdot/</xex>,
<xex><dsdot/h</xex>, <xex><nsdot/</xex>, are called linguals, cerebrals,
or cacuminals. They are uttered with the tip of the tongue turned up and
drawn back into the dome of the palate.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguality</ent><br/
<hw>Lin*gual"i*ty</hw> <pr>(l<icr/<nsm/*gw<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The quality of being lingual.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguatulida</ent><br/
\'d8<hw>Lin`gua*tu"li*da</hw>
<pr>(l<icr/<nsm/`gw<adot/*t<umac/"l<icr/*d<adot/)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. L. <ets>lingua</ets> tongue.]</ety>
<fld>(Zool.)</fld> <def>Same as <er>Linguatulina</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguatulina</ent><br/
\'d8<hw>Lin*guat`u*li"na</hw>
<pr>(l<icr/<nsm/*gw<acr/t`<usl/*l<imac/"n<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. L. <ets>lingua</ets> tongue.]</ety> <fld>(Zool.)</fld>
<def>An order of wormlike, degraded, parasitic arachnids. They have two
pairs of retractile hooks, near the mouth. Called also
<altname>Pentastomida</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The adults of some species inhabit the nostrils and
nasal sinuses of dogs and other carnivores. The young, after being
swallowed by sheep, rabbits, etc., find their way to the lungs and liver
and become encysted. These, when eaten by carnivores, develop into the
adult forms.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguidental</ent><br/
<hw>Lin`gui*den"tal</hw> <pr>(l<icr/<nsm/`gw<icr/*d<ecr/n"t<ait/l)</pr>,
<pos>a. & n.</pos> <def>Linguadental.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguiform</ent><br/
<hw>Lin"gui*form</hw> <pr>(l<icr/<nsm/"gw<icr/*f<ocir/rm)</pr>,
<pos>a.</pos> <ety>[L. <ets>lingua</ets> tongue + <ets>-form</ets>: cf.
F. <ets>linguiforme</ets>.]</ety> <def>Having the form of the tongue;
tongue-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguist</ent><br/
<hw>Lin"guist</hw> <pr>(l<icr/<nsm/"gw<icr/st)</pr>, <pos>n.</pos>
<ety>[L. <ets>lingua</ets> tongue, speech, language: cf. F.
<ets>linguiste</ets>.]</ety> <sn>1.</sn> <def>A master of the use of
language; a talker.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll dispute with him;<br/
He's a rare <qex>linguist</qex>.</q> <rj><qau>J. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person skilled in languages.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There too were Gibbon, the greatest historian, and Jones, the
greatest <qex>linguist</qex>, of the age.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguistical</ent><br/
<ent>Linguistic</ent><br/
<mhw>{ <hw>Lin*guis"tic</hw> <pr>(l<icr/<nsm/*gw<icr/s"t<icr/k)</pr>,
<hw>Lin*guis"tic*al</hw> <pr>(l<icr/<nsm/*gw<icr/s"t<icr/*k<ait/l)</pr>,
}</mhw> <pos>a.</pos> <ety>[Cf. F. <ets>linguistique.</ets>]</ety>
<def>Of or pertaining to language; relating to linguistics, or to the
affinities of languages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguistically</ent><br/
<hw>Lin*guis"tic*al*ly</hw>, <pos>adv.</pos> <def>In a linguistic
manner; from the point of view of a linguist.</def>
<rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linguistics</ent><br/
<hw>Lin*guis"tics</hw> <pr>(l<icr/<nsm/*gw<icr/s"t<icr/ks)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>linguistique</ets>.]</ety> <def>The
science of languages, or of the origin, signification, and application
of words; glossology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lingula</ent><br/
<ent>lingulae</ent><br/
\'d8<hw>lin"gu*la</hw> <pr>(l<icr/<nsm/"g<usl/*l<adot/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>lin"gu*l<ae/</plw>
<pr>(l<icr/<nsm/"g<usl/*l<emac/)</pr>.</plu> <ety>[L., a little
tongue.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>A tonguelike process
or part.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any one of numerous species of
brachiopod shells belonging to the genus <gen>Lingula</gen>, and related
genera. See <er>Brachiopoda</er>, and <xex>Illustration</xex> in
Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lingula flags</b></col> <fld>(Geol.)</fld>, <cd>a group
of strata in the lower Silurian or Cambrian system of Wales, in which
some of the layers contain vast numbers of a species of
Lingula.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lingulate</ent><br/
<hw>Lin"gu*late</hw> <pr>(l<icr/<nsm/"g<usl/*l<asl/t)</pr>,
<pos>a.</pos> <ety>[L. <ets>lingulatus</ets>, fr. <ets>lingula</ets> a
little tongue. Cf. <er>Ligulate</er>.]</ety> <def>Shaped like the tongue
or a strap; ligulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linigerous</ent><br/
<hw>Li*nig"er*ous</hw> <pr>(l<icr/*n<icr/j"<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>linum</ets> flax +
<ets>-gerous</ets>.]</ety> <def>Bearing flax; producing linen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liniment</ent><br/
<hw>Lin"i*ment</hw> <pr>(l<icr/n"<icr/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>linimentum</ets>, fr. <ets>linire</ets>,
<ets>linere</ets>, to besmear, anoint : cf. F. <ets>liniment</ets>. Cf.
<er>Letter</er>, <er>Lime</er> a viscous substance.]</ety> <def>A liquid
or semiliquid preparation of a consistence thinner than an ointment,
applied to the skin by friction, esp. one used as a sedative or a
stimulant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lining</ent><br/
<hw>Lin"ing</hw> <pr>(l<imac/n"<icr/ng)</pr>, <pos>n.</pos> <ety>[See
<er>Line</er> to cover the in side.]</ety> <sn>1.</sn> <def>The act of
one who lines; the act or process of making lines, or of inserting a
lining.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which covers the inner surface of anything, as
of a garment or a box; also, the contents of anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lining</qex> of his coffers shall make coats<br/
To deck our soldiers.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Link</ent><br/
<hw>Link</hw> <pr>(l<icr/<nsm/k)</pr>, <pos>n.</pos> <ety>[Prob.
corrupted from <ets>lint</ets> and this for <ets>lunt</ets> a torch,
match, D. <ets>lont</ets> match; akin to G. <ets>lunte</ets>, cf. MHG.
<ets>l<uum/nden</ets> to burn. Cf. <er>Lunt</er>,
<er>Linstock</er>.]</ety> <def>A torch made of tow and pitch, or the
like.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Link</ent><br/
<hw>Link</hw>, <pos>n.</pos> <ety>[OE. <ets>linke</ets>, AS.
<ets>hlence</ets>; akin to Sw. <ets>l<aum/nk</ets> ring of a chain, Dan.
<ets>l<ae/nke</ets> chain, Icel. <ets>hlekkr</ets>; cf. G.
<ets>gelenk</ets> joint, link, ring of a chain, <ets>lenken</ets> to
bend.]</ety> <sn>1.</sn> <def>A single ring or division of a
chain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Anything, whether material or not, which
binds together, or connects, separate things; a part of a connected
series; a tie; a bond.</def> <ldquo/<xex>Links</xex> of iron.<rdquo/
<au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 857 pr=VMG --></p>

<p><q>The <qex>link</qex> of brotherhood, by which<br/
One common Maker bound me to the kind.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And so by double <qex>links</qex> enchained themselves in lover's
life.</q> <rj><qau>Gascoigne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything doubled and closed like a link; <as>as, a
<ex>link</ex> of horsehair</as>.</def> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Kinematics)</fld> <def>Any one of the several
elementary pieces of a mechanism, as the fixed frame, or a rod, wheel,
mass of confined liquid, etc., by which relative motion of other parts
is produced and constrained.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mach.)</fld> <def>Any intermediate rod or piece for
transmitting force or motion, especially a short connecting rod with a
bearing at each end; specifically <fld>(Steam Engine)</fld>, the slotted
bar, or connecting piece, to the opposite ends of which the eccentric
rods are jointed, and by means of which the movement of the valve is
varied, in a <xex>link motion</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Surveying)</fld> <def>The length of one joint of
Gunter's chain, being the hundredth part of it, or 7.92 inches, the
chain being 66 feet in length. Cf. <er>Chain</er>, <pos>n.</pos>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Chem.)</fld> <def>A bond of affinity, or a unit of
valence between atoms; -- applied to a unit of chemical force or
attraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <pluf>pl.</pluf> <def>Sausages; -- because linked
together.</def> <mark>[Colloq.]</mark></p>

<p><ent>Link</ent><br/
<hw>Link</hw> <pr>(l<icr/<nsm/k)</pr>, <pos>n.</pos> <ety>[See
<er>Linch</er>.]</ety> <sn>1.</sn> <def>A hill or ridge, as a sand hill,
or a wooded or turfy bank between cultivated fields, etc.</def>
<mark>[Scot. & Prov. Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A winding of a river; also, the ground along such a
winding; a meander; -- usually in <pluf>pl.</pluf></def>
<mark>[Scot.]</mark></p>

<p><q>The windings or <ldquo/<qex>links</qex><rdquo/ of the Forth above
and below Stirling are extremely tortuous.</q> <rj><qau>Encyc.
Brit.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>Sand hills with the surrounding
level or undulating land, such as occur along the seashore, a river
bank, etc.</def> <mark>[Scot.]</mark></p>

<p><q>Golf may be played on any park or common, but its original home is
the <ldquo/<qex>links</qex><rdquo/ or common land which is found by the
seashore, where the short close tuft, the sandy subsoil, and the many
natural obstacles in the shape of bents, whins, sand holes, and banks,
supply the conditions which are essential to the proper pursuit of the
game.</q> <rj><qau>Encyc. of Sport.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>Hence, any such piece of ground
where golf is played; a golf course.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Link</ent><br/
<hw>Link</hw> <pr>(l<icr/<nsm/k)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Linked</conjf>
<pr>(l<icr/<nsm/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Linking</conjf>.]</vmorph> <def>To connect or unite with a link
or as with a link; to join; to attach; to unite; to couple.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the tribes and nations that composed it [the Roman Empire]
were <qex>linked</qex> together, not only by the same laws and the same
government, but by all the facilities of commodious intercourse, and of
frequent communication.</q> <rj><qau>Eustace.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Link</ent><br/
<hw>Link</hw>, <pos>v. i.</pos> <def>To be connected.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No one generation could <qex>link</qex> with the other.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linkage</ent><br/
<hw>Link"age</hw> <pr>(l<icr/<nsm/k"<asl/j; 48)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of linking; the state of being linked; also, a
system of links.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Manner of linking or of being
linked; -- said of the union of atoms or radicals in the
molecule.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geom.)</fld> <def>A system of straight lines or
bars, fastened together by joints, and having certain of their points
fixed in a plane. It is used to describe straight lines and curves in
the plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any object, factor, or relationship that creates a
bond or association between two other objects.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <specif>Specifically:</specif> <fld>(Genetics)</fld>
<def>The proximity of two or more genes on the genome of an organism
that causes those genes to be inherited, transferred, or moved together
with a frequency greater than for genes not associated. The linkage is a
continuous variable, and is inversely related to the distance between
genes on the genome.</def><br/
[<source>PJC</source>]</p>

<p><ent>linked</ent><br/
<hw>linked</hw> <pr>(l<icr/<nsm/kt)</pr>, <pos>a.</pos> <sn>1.</sn>
<sn>1.</sn> <def>Associated.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Genetics)</fld> <def>Exhibiting
<er>linkage</er>{5}.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Having a connection.</def><br/
[<source>PJC</source>]</p>

<p><ent>Linkman</ent><br/
<ent>Linkboy</ent><br/
<mhw>{ <hw>Link"boy`</hw> <pr>(l<icr/<nsm/k"boi`)</pr>,
<hw>Link"man</hw> <pr>(l<icr/<nsm/k"m<acr/n)</pr>, }</mhw> <pos>n.</pos>
<ety>[See 1st <er>Link</er>.]</ety> <def>A boy or man that carried a
link or torch to light passengers.</def><-- sic --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Link motion</ent><br/
<hw>Link" mo"tion</hw> <pr>(l<icr/<nsm/k" m<omac/"sh<ucr/n)</pr>
<pos>n.</pos> <fld>(Steam Engine)</fld> <def>A valve gear, consisting of
two eccentrics with their rods, giving motion to a slide valve by an
adjustable connecting bar, called the <xex>link</xex>, in such a way
that the motion of the engine can be reversed, or the cut-off varied, at
will; -- used very generally in locomotives and marine
engines.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The illustration shows a link motion for a vertical
engine, <iref>c</iref> representing the shaft carrying two eccentrics,
<iref>a</iref> and <iref>b</iref>, for making the engine run forward and
backward, respectively, their rods <iref>e</iref> and <iref>d</iref>
being jointed to opposite ends of the slotted link <iref>f</iref>, in
the opening of which is a pin <iref>g</iref> which is attached to the
valve rod <iref>h</iref>. The valve will receive the motion of the
forward eccentric when the link is in the position shown, and the motion
of the backward eccentric when the link is shifted so far to the right
as to bring <iref>e</iref> in line with <iref>h</iref>, or a compound
motion derived from both eccentrics when the link is shifted to
intermediate positions, the compound motion causing the valve to cut off
the steam at a point determined by the position to which the link may
have been shifted.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Links</ent><br/
<hw>Links</hw> <pr>(l<icr/<nsm/ks)</pr>, <pos>n.</pos> <ety>[The pl.
form of <er>Link</er>, but often construed as a singular.]</ety> <def>A
tract of ground laid out for the game of golf; a golfing
green.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A second <qex>links</qex> has recently been opened at Prestwick,
and another at Troon, on the same coast.</q> <rj><qau>P. P.
Alexander.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>linkup</ent><br/
<hw>linkup</hw> <pos>n.</pos> <def>something that serves to join or
link.</def><br/
<syn><b>Syn. --</b> link, tie, tie-in.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Linkwork</ent><br/
<hw>Link"work`</hw> <pr>(l<icr/<nsm/k"w<ucir/rk`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A fabric consisting of links made of metal or other
material fastened together; also, a chain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And thou shalt make hooks of gold, and two chains of fine gold;
<qex>linkwork</qex> and wreathed.</q> <rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mechanism in which links, or intermediate connecting
pieces, are employed to transmit motion from one part to
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linnaea</ent><br/
<hw>Linnaea</hw> <pos>n.</pos> <def>A genus with only one species, the
twinflower.</def><br/
<syn><b>Syn. --</b> genus <gen>Linnaea</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Linnaeus</ent><br/
<hw>Linnaeus</hw> <pr>(l<icr/*n<emac/"<ucr/s)</pr> <pos>n.</pos>
<def><person>Carolus Linnaeus</person>, also called <altname>Karl von
Linn<eacute/</altname>. Born at R<aring/shult, Sm<aring/land, Sweden,
May 13, 1707: died at Upsala, Sweden, Jan. 10, 1778. A celebrated
Swedish botanist and naturalist, founder of the <er>Linnean system</er>
in botany. He made a journey to Lapland in 1732; resided in the
Netherlands 1735-38; and became professor of medicine (later of botany)
at Upsala in 1741. Among his works are <ldquo/Systema natur<ae/<rdquo/
(1735), <ldquo/Fundamenta botanica<rdquo/ (1736), <ldquo/Genera
plantarum<rdquo/ (1737), <ldquo/Flora lapponica<rdquo/ (1737),
<ldquo/Philosophia botanica<rdquo/ (1751), and <ldquo/Species
plantarum<rdquo/ (1753).</def><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Linnaea borealis</ent><br/
\'d8<hw>Lin*n<ae/"a bo`re*a"lis</hw> <pr>(l<icr/n*n<emac/"<adot/
b<omac/`r<esl/*<amac/"l<icr/s)</pr> <pos>n.</pos> <ety>[NL.
<ets>Linnaeus</ets> Linn<ae/an + L. <ets>borealis</ets> northern.]</ety>
<fld>(Bot.)</fld> <def>The twin flower which grows in cold northern
climates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linnaean</ent><br/
<ent>Linnean</ent><br/
<mhw>{ <hw>Lin*n<ae/"an</hw>, <hw>Lin*ne"an</hw> }</mhw>
<pr>(l<icr/n*n<emac/"<ait/n)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to <etsep>Linn<ae/us</etsep>, the celebrated Swedish
botanist.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Linnaean system</b></col>, <col><b>Linnean
system</b></col></mcol> <fld>(Bot.)</fld>, <cd>the system in which the
classes of plants are founded mainly upon the number of stamens, and the
orders upon the pistils; the artificial or sexual system.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linnaeite</ent><br/
<hw>Lin*n<ae/"ite</hw> <pr>(l<icr/n*n<emac/"<imac/t)</pr>, <pos>n.</pos>
<ety>[See <er>Linn<ae/an</er>.]</ety> <fld>(Min.)</fld> <def>A mineral
of pale steel-gray color and metallic luster, occurring in isometric
crystals, and also massive. It is a sulphide of cobalt containing some
nickel or copper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linne</ent><br/
<hw>Linne</hw> <pr>(l<icr/n)</pr>, <pos>n.</pos> <def>Flax. See
<er>Linen</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linnet</ent><br/
<hw>Lin"net</hw> <pr>(l<icr/n"n<ecr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>linot</ets>, <ets>linotte</ets>, from L. <ets>linum</ets> flax; or
perh. shortened from AS. <ets>l<imac/netwige</ets>, fr. AS.
<ets>l<imac/n</ets> flax; -- so called because it feeds on the seeds of
flax and hemp. See <er>Linen</er>.]</ety> <fld>(Zool.)</fld> <def>Any
one of several species of fringilline birds of the genera
<gen>Linota</gen>, <gen>Acanthis</gen>, and allied genera, esp. the
common European species (<spn>Linota cannabina</spn>), which, in full
summer plumage, is chestnut brown above, with the breast more or less
crimson. The feathers of its head are grayish brown, tipped with
crimson. Called also <altname>gray linnet</altname>, <altname>red
linnet</altname>, <altname>rose linnet</altname>, <altname>brown
linnet</altname>, <altname>lintie</altname>,
<altname>lintwhite</altname>, <altname>gorse thatcher</altname>,
<altname>linnet finch</altname>, and <altname>greater redpoll</altname>.
The American redpoll linnet (<spn>Acanthis linaria</spn>) often has the
crown and throat rosy. See <er>Redpoll</er>, and
<er>Twite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Green linnet</b></col> <fld>(Zool.)</fld>, <cd>the
European green finch.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linoleate</ent><br/
<hw>Li*no"le*ate</hw> <pr>(l<icr/*n<omac/"l<esl/*<asl/t)</pr>,
<pos>n.</pos> <fld>(Chem.)</fld> <def>A salt of linoleic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linoleic</ent><br/
<hw>Li*no"le*ic</hw> <pr>(l<icr/*n<omac/"l<esl/*<icr/k)</pr>,
<pos>a.</pos> <def>Pertaining to, or derived from, linoleum, or linseed
oil; specifically <fld>(Chem.)</fld>, designating an organic acid, a
thin yellow oil, found combined as a salt of glycerin in oils of
linseed, poppy, hemp, and certain nuts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linoleum</ent><br/
<hw>Li*no"le*um</hw> <pr>(l<icr/*n<omac/"l<esl/*<ucr/m)</pr>,
<pos>n.</pos> <ety>[L. <ets>lin</ets>um flax + <ets>oleum</ets>
oil.]</ety> <sn>1.</sn> <def>Linseed oil brought to various degrees of
hardness by some oxidizing process, as by exposure to heated air, or by
treatment with chloride of sulphur. In this condition it is used for
many of the purposes to which India rubber has been applied.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of floor cloth made by laying hardened
linseed oil mixed with ground cork on a canvas backing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linotype</ent><br/
<hw>Lin"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Line</er>;
<er>Type</er>.]</ety> <fld>(Print.)</fld> <sd>(a)</sd> <def>A kind of
typesetting machine which produces castings, each of which corresponds
to a line of separate types. By pressing the keys of a keyboard like one
on a typewriter, the matrices for one line are properly arranged; the
entire line, or stereotype, or slug, is then cast and planed, and the
matrices are returned to their proper places, the whole process being
automatic.</def> <sd>(b)</sd> <def>The slug produced by the machine, or
matter composed in such lines.</def> --
<wordforms><wf>Lin"o*typ`ist</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Linoxin</ent><br/
<hw>Li*nox"in</hw> <pr>(l<icr/*n<ocr/ks"<icr/n)</pr>, <pos>n.</pos>
<ety>[<ets>Lino</ets>leic + <ets>ox</ets>ygen.]</ety> <fld>(Chem.)</fld>
<def>A resinous substance obtained as an oxidation product of linoleic
acid.</def> <altsp>[Written also <asp>linoxyn</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linsang</ent><br/
<hw>Lin*sang"</hw> <pr>(l<icr/n*s<aum/ng")</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any viverrine mammal of the genus
<gen>Prionodon</gen>, inhabiting the East Indies and Southern Asia. The
common East Indian linsang (<spn>Prionodon gracilis</spn>) is white,
crossed by broad, black bands. The Guinea linsang (<spn>Porana
Richardsonii</spn>) is brown with black spots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linseed</ent><br/
<hw>Lin"seed`</hw> <pr>(l<icr/n"s<emac/d`)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lin</ets> flax + <ets>seed</ets>. See <er>Linen</er>.]</ety>
<fld>(Bot.)</fld> <def>The seeds of flax, from which linseed oil is
obtained.</def> <altsp>[Written also <asp>lintseed</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Linseed cake</b></col>, <cd>the solid mass or cake which
remains when oil is expressed from flaxseed.</cd> -- <col><b>Linseed
meal</b></col>, <cd>linseed cake reduced to powder.</cd> --
<col><b>Linseed oil</b></col>, <cd>oil obtained by pressure from
flaxseed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linsey</ent><br/
<hw>Lin"sey</hw> <pr>(l<icr/n"s<ycr/)</pr>, <pos>n.</pos> <ety>[See
<er>Linen</er>.]</ety> <def>Linsey-woolsey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linsey-woolsey</ent><br/
<hw>Lin"sey-wool"sey</hw> <pr>(l<icr/n"s<ycr/*w<oocr/l"s<ycr/;
277)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Cloth made of linen and wool,
mixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Jargon.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linsey-woolsey</ent><br/
<hw>Lin"sey-wool"sey</hw>, <pos>a.</pos> <def>Made of linen and wool;
hence, of different and unsuitable parts; mean.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linstock</ent><br/
<hw>Lin"stock</hw> <pr>(l<icr/n"st<ocr/k)</pr>, <pos>n.</pos>
<ety>[Corrupt. fr. <ets>luntstock</ets>, D. <ets>lontstok</ets>;
<ets>lont</ets> lunt + <ets>stok</ets> stock, stick. See <er>Link</er> a
torch, <er>Lunt</er>, and <er>Stock</er>.]</ety> <def>A pointed forked
staff, shod with iron at the foot, to hold a lighted match for firing
cannon.</def> <altsp>[Written also <asp>lintstock</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lint</ent><br/
<hw>Lint</hw> <pr>(l<icr/nt)</pr>, <pos>n.</pos> <ety>[AS.
<ets>l<imac/net</ets> flax, hemp, fr. <ets>l<imac/n</ets> flax; or,
perh. borrowed fr. L. <ets>linteum</ets> a linen cloth, linen, from
<ets>linteus</ets> linen, a., fr. <ets>linum</ets> flax, lint. See
<er>Linen</er>.]</ety> <sn>1.</sn> <def>Flax.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Linen scraped or otherwise made into a soft, downy
or fleecy substance for dressing wounds and sores; also, fine ravelings,
down, fluff, or loose short fibers from yarn or fabrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lint doctor</b></col> <fld>(Calico-printing Mach.)</fld>,
<cd>a scraper to remove lint from a printing cylinder.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lintel</ent><br/
<hw>Lin"tel</hw> <pr>(l<icr/n"t<ecr/l)</pr>, <pos>n.</pos> <ety>[OF.
<ets>lintel</ets>, F. <ets>linteau</ets>, LL. <ets>lintellus</ets>, for
<ets>limitellus</ets>, a dim. fr. L. <ets>limes</ets> limit. See
<er>Limit</er>.]</ety> <fld>(Arch.)</fld> <def>A horizontal member
spanning an opening, and carrying the superincumbent weight by means of
its strength in resisting crosswise fracture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lintwhite</ent><br/
<ent>Lintie</ent><br/
<mhw>{ <hw>Lin"tie</hw> <pr>(l<icr/n"t<icr/)</pr>, <hw>Lint"white`</hw>
<pr>(l<icr/nt"hw<imac/t`)</pr> }</mhw>, <pos>n.</pos> <ety>[AS.
<ets>l<imac/netwige</ets>. See <er>Linnet</er>.]</ety>
<fld>(Zool.)</fld> <def>See <er>Linnet</er>.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lintseed</ent><br/
<hw>Lint"seed`</hw> <pr>(l<icr/nt"s<emac/d`)</pr>, <pos>n.</pos>
<def>See <er>Linseed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Linum</ent><br/
\'d8<hw>Li"num</hw> <pr>(l<imac/"n<ucr/m)</pr>, <pos>n.</pos> <ety>[L.,
flax.]</ety> <fld>(Bot.)</fld> <def>A genus of herbaceous plants
including the flax (<spn>Linum usitatissimum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion</ent><br/
<hw>Li"on</hw> <pr>(l<imac/"<ucr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>lion</ets>, L. <ets>leo</ets>, <ets>-onis</ets>, akin to Gr.
<grk>le`wn</grk>. Cf. <er>Chameleon</er>, <er>Dandelion</er>,
<er>Leopard</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A large
carnivorous feline mammal (<spn>Panthera leo</spn>, formerly <spn>Felis
leo</spn>), found in Southern Asia and in most parts of Africa, distinct
varieties occurring in the different countries. The adult male, in most
varieties, has a thick mane of long shaggy hair that adds to his
apparent size, which is less than that of the largest tigers. The
length, however, is sometimes eleven feet to the base of the tail. The
color is a tawny yellow or yellowish brown; the mane is darker, and the
terminal tuft of the tail is black. In one variety, called the
<stype>maneless lion</stype>, the male has only a slight mane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>A sign and a constellation;
Leo.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An object of interest and curiosity, especially a
person who is so regarded; <as>as, he was quite a <ex>lion</ex> in
London at that time</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such society was far more enjoyable than that of Edinburgh, for
here he was not a <qex>lion</qex>, but a man.</q> <rj><qau>Prof.
Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>American lion</b></col> <fld>(Zool.)</fld>, <cd>the puma
or cougar.</cd> -- <col><b>Lion ant</b></col> <fld>(Zool.)</fld>,
<cd>the ant-lion.</cd> -- <col><b>Lion dog</b></col> <fld>(Zool.)</fld>,
<cd>a fancy dog with a flowing mane, usually clipped to resemble a
lion's mane.</cd> -- <col><b>Lion lizard</b></col> <fld>(Zool.)</fld>,
<cd>the basilisk.</cd> -- <col><b>Lion's share</b></col>, <cd>all, or
nearly all; the best or largest part; -- from Aesop's fable of the lion
hunting in company with certain smaller beasts, and appropriating to
himself all the prey.</cd> -- <col><b>Lion of Lucerne</b></col>, <cd>a
famous sculptured lion at Lucerne, Switzerland, designed by Thorwaldsen
and dedicated in 1821 as a memorial to the Swiss Guards who fell
defending Louis XVI. in the attack of the mob on the Tuileries, Aug. 10,
1792. The animal, which is hewn out of the face of a rock, is
represented as transfixed with a broken spear and dying, but still
trying to protect with its paw a shield bearing the fleur-de-lis of
France.</cd> -- <col><b>Lion of St. Mark</b></col>, <cd>a winged lion,
the emblem of the evangelist Mark, especially that of bronze surmounting
a granite column in the Piazzetta at Venice, and holding in its fore
paws an open book representing St. Mark's Gospel.</cd> -- <col><b>Lion
of the North</b></col>, <cd>Gustavus Adolphus (1594-1632), King of
Sweden, the hero of the Protestant faith in the Thirty Years'
War.</cd></cs><br/
[<source>1913 Webster</source> + <source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lionced</ent><br/
<hw>Li"onced</hw> <pr>(l<imac/"<ucr/nst)</pr>, <pos>a.</pos>
<fld>(Her.)</fld> <def>Adorned with lions' heads; having arms
terminating in lions' heads; -- said of a cross.</def> <altsp>[Written
also <asp>leonced</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lioncel</ent><br/
<hw>Li"on*cel</hw> <pr>(l<imac/"<ucr/n*s<ecr/l)</pr>, <pos>n.</pos>
<ety>[OF., F. <ets>lionceau</ets>, dim. of <ets>lion</ets>.]</ety>
<fld>(Her.)</fld> <def>A small lion, especially one of several borne in
the same coat of arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionel</ent><br/
<hw>Li"on*el</hw> <pr>(l<imac/"<ucr/n*<ecr/l)</pr>, <pos>n.</pos>
<ety>[OF., dim. of <ets>lion</ets>.]</ety> <fld>(Zool.)</fld> <def>The
whelp of a lioness; a young lion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lioness</ent><br/
<hw>Li"on*ess</hw> <pr>(l<imac/"<ucr/n*<ecr/s)</pr>, <pos>n.</pos>
<ety>[OF. <ets>lionesse</ets>.]</ety> <fld>(Zool.)</fld> <def>A female
lion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionet</ent><br/
<hw>Li"on*et</hw> <pr>(l<imac/"<ucr/n*<ecr/t)</pr>, <pos>n.</pos>
<ety>[OF., dim. of <ets>lion</ets>.]</ety> <fld>(Zool.)</fld> <def>A
young or small lion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion-heart</ent><br/
<hw>Li"on-heart`</hw> <pr>(l<imac/"<ucr/n*h<aum/rt`)</pr>, <pos>n.</pos>
<def>A very brave person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion-hearted</ent><br/
<hw>Li"on-heart`ed</hw> <pr>(l<imac/"<ucr/n*h<aum/rt`<ecr/d)</pr>,
<pos>a.</pos> <def>Very brave; brave and magnanimous.</def> <rj><au>Sir
W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionhood</ent><br/
<hw>Li"on*hood</hw> <pr>(l<imac/"<ucr/n*h<oocr/d)</pr>, <pos>n.</pos>
<def>State of being a lion.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lion-hunter</ent><br/
<hw>lion-hunter</hw> <pos>n.</pos> <sn>1.</sn> <def>someone who tries to
attract social lions as guests.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>someone who hunts lions.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lionism</ent><br/
<hw>Li"on*ism</hw> <pr>(l<imac/"<ucr/n*<icr/z'm)</pr>, <pos>n.</pos>
<def>An attracting of attention, as a lion; also, the treating or
regarding as a lion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionize</ent><br/
<hw>Li"on*ize</hw> <pr>(l<imac/"<ucr/n*<imac/z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lionized</conjf>
<pr>(l<imac/"<ucr/n*<imac/zd)</pr>, <pos>p. pr. & vb. n.</pos>
<conjf>Lionizing</conjf>
<pr>(l<imac/"<ucr/n*<imac/`z<icr/ng)</pr>.]</vmorph> <sn>1.</sn> <def>To
treat or regard as a lion or object of great interest.</def> <rj><au>J.
D. Forbes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To show the lions or objects of interest to; to
conduct about among objects of interest.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionlike</ent><br/
<hw>Li"on*like`</hw> <pr>(l<imac/"<ucr/n*l<imac/k`)</pr>, <pos>a.</pos>
<def>Like a lion; brave as a lion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionly</ent><br/
<hw>Li"on*ly</hw>, <pos>a.</pos> <def>Like a lion; fierce.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion's ear</ent><br/
<hw>Li"on's ear`</hw> <pr>(l<imac/"<ucr/nz <emac/r`)</pr> <pos>n.</pos>
<fld>(Bot.)</fld> <def>A name given in Western South America to certain
plants with shaggy tomentose leaves, as species of <gen>Culcitium</gen>,
and <gen>Espeletia</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion's foot</ent><br/
<hw>Li"on's foot`</hw> <pr>(l<imac/"<ucr/nz f<oocr/t`)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <sd>(a)</sd> <def> A composite plant of
the genus <gen>Prenanthes</gen>, of which several species are found in
the United States.</def> <sd>(b)</sd> <def>The edelweiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lionship</ent><br/
<hw>Li"on*ship</hw> <pr>(l<imac/"<ucr/n*sh<icr/p)</pr>, <pos>n.</pos>
<def>The state of being a lion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion's leaf</ent><br/
<hw>Li"on's leaf`</hw> <pr>(l<imac/"<ucr/nz l<emac/f`)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>A South European plant of the genus
<gen>Leontice</gen> (<spn>Leontice leontopetalum</spn>), the tuberous
roots of which contain so much alkali that they are sometimes used as a
substitute for soap.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion's tail</ent><br/
<hw>Li"on's tail`</hw> <pr>(l<imac/"<ucr/nz t<amac/l`)</pr>
<pos>n.</pos> <fld>(Bot.)</fld> <def>A genus of labiate plants
(<gen>Leonurus</gen>); -- so called from a fancied resemblance of its
flower spikes to the tuft of a lion's tail. <spn>Leonurus Cardiaca</spn>
is the common <stype>motherwort</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lion's tooth</ent><br/
<hw>Li"on's tooth`</hw> <pr>(l<imac/"<ucr/nz t<oomac/th`)</pr>;
<plu><it>pl.</it> <plw>Lions' teeth</plw> <pr>(l<imac/"<ucr/nz
t<emac/th`)</pr>.</plu> <fld>(Bot.)</fld> <def>See
<er>Leontodon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lip</ent><br/
<hw>Lip</hw> <pr>(l<icr/p)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lippe</ets>, AS. <ets>lippa</ets>; akin to D. <ets>lip</ets>, G.
<ets>lippe</ets>, <ets>lefze</ets>, OHG. <ets>lefs</ets>, Dan.
<ets>l<ae/be</ets>, Sw. <ets>l<aum/pp</ets>, L. <ets>labium</ets>,
<ets>labrum</ets>. Cf. <er>Labial</er>.]</ety> <sn>1.</sn> <def>One of
the two fleshy folds which surround the orifice of the mouth in man and
many other animals. In man the lips are organs of speech essential to
certain articulations. Hence, by a figure they denote the mouth, or all
the organs of speech, and sometimes speech itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thine own <qex>lips</qex> testify against thee.</q> <rj><qau>Job
xv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An edge of an opening; a thin projecting part of
anything; a kind of short open spout; <as>as, the <ex>lip</ex> of a
vessel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The sharp cutting edge on the end of an
auger.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>One of the two
opposite divisions of a labiate corolla.</def> (b) <def>The odd and
peculiar petal in the <gen>Orchis</gen> family. See
<er>Orchidaceous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>One of the edges of the aperture
of a univalve shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Impudent or abusive talk; <as>as, don't give me any
of your <ex>lip</ex></as>.</def> <mark>[Slang]</mark><br/
<syn><b>Syn. --</b> jaw.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lip bit</b></col>, <cd>a pod auger. See
<er>Auger</er>.</cd> -- <col><b>Lip comfort</b></col>, <cd>comfort that
is given with words only.</cd> -- <col><b>Lip comforter</b></col>,
<cd>one who comforts with words only.</cd> -- <col><b>Lip
labor</b></col>, <cd>unfelt or insincere speech; hypocrisy.</cd>
<au>Bale.</au> -- <col><b>Lip reading</b></col>, <cd>the catching of the
words or meaning of one speaking by watching the motion of his lips
without hearing his voice.</cd> <au>Carpenter.</au> -- <col><b>Lip
salve</b></col>, <cd>a salve for sore lips.</cd> -- <col><b>Lip
service</b></col>, <cd>expression by the lips of obedience and devotion
without the performance of acts suitable to such sentiments.</cd> --
<col><b>Lip wisdom</b></col>, <cd>wise talk without practice, or
unsupported by experience.</cd> -- <col><b>Lip work</b></col>.
<sd>(a)</sd> <cd>Talk.</cd> <sd>(b)</sd> <cd>Kissing.</cd>
<mark>[Humorous]</mark> <au>B. Jonson.</au> -- <col><b>To make a
lip</b></col>, <cd>to drop the under lip in sullenness or contempt.</cd>
<au>Shak.</au> -- <col><b>To shoot out the lip</b></col>
<fld>(Script.)</fld>, <cd>to show contempt by protruding the
lip.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lip</ent><br/
<hw>Lip</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lipped</conjf> <pr>(l<icr/pt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lipping</conjf> <pr>(-p<icr/ng)</pr>.]</vmorph> <sn>1.</sn>
<def>To touch with the lips; to put the lips to; hence, to
kiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bubble on the wine which breaks<br/
Before you <qex>lip</qex> the glass.</q> <rj><qau>Praed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A hand that kings<br/
Have <qex>lipped</qex> and trembled kissing.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter; to speak.</def> <mark>[R.]</mark>
<rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lip</ent><br/
<hw>Lip</hw>, <pos>v. t.</pos> <def>To clip; to trim.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lipaemia</ent><br/
<ent>lipemia</ent><br/
\'d8<hw>Li*p<ae/"mi*a</hw> <pr>(l<icr/*p<emac/"m<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>li`pos</grk> fat +
<grk>a"i^ma</grk> blood.]</ety> <fld>(Med.)</fld> <def>A condition in
which fat occurs in the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipans</ent><br/
<hw>Li*pans"</hw> <pr>(l<esl/*p<aum/nz")</pr>, <pos>n. pl.</pos>;
<sing>sing. <singw>Lipan</singw> <pr>(l<esl/*p<aum/n")</pr>.</sing>
<fld>(Ethnol.)</fld> <def>A tribe of North American Indians, inhabiting
the northern part of Mexico. They belong to the Tinneh stock, and are
closely related to the Apaches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liparian</ent><br/
<hw>Li*pa"ri*an</hw> <pr>(l<icr/*p<amac/"r<icr/*<ait/n)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>Any species of a family
(<fam>Liparid<ae/</fam>) of destructive bombycid moths, as the tussock
moths.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liparididae</ent><br/
<ent>Liparidae</ent><br/
<mhw><hw>Liparidae</hw>, <hw>Liparididae</hw></mhw> <pos>n.</pos> <def>A
natural family including the snailfishes.</def><br/
<syn><b>Syn. --</b> family <fam>Liparididae</fam>, family
<fam>Liparidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>liparis</ent><br/
<hw>liparis</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>an orchid of the
genus <gen>Liparis</gen> having few leaves and usually fairly small
yellow-green or dull purple flowers in terminal racemes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The type genus of the
<fam>Liparididae</fam>, consisting of certain of the
snailfishes.</def><br/
<syn><b>Syn. --</b> genus <gen>Liparis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liparite</ent><br/
<hw>Lip"a*rite</hw> <pr>(l<icr/p"<adot/*r<imac/t)</pr>, <pos>n.</pos>
<ety>[So called from <ets>Lipari</ets>, the island.]</ety>
<fld>(Min.)</fld> <def>A quartzose trachyte; rhyolite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lipemia</ent><br/
<hw>lip*e"mi*a</hw> <pr>(l<icr/p*<emac/"m<esl/*<adot/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>li`pos</grk> fat + <grk>'ai^ma</grk>
blood.]</ety> <fld>(Med.)</fld> <def>The presence of an abnormally high
concentration of lipid in the blood. Called also
<altname>hyperlipemia</altname>, <altname>hyperlipidemia</altname>,
<altname>hyperlipoidemia</altname>, <altname>lipidemia</altname>,
<altname>lipoidemia</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>lip fern</ent><br/
<ent>lipfern</ent><br/
<mhw><hw>lipfern</hw>, <hw>lip fern</hw></mhw> <pos>n.</pos>
<fld>(Bot.)</fld> <def>any of various terrestrial ferns of the genus
<gen>Cheilanthes</gen>; they are cosmopolitan in arid and semi-arid
temperate or tropical regions.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lipic</ent><br/
<hw>Lip"ic</hw> <pr>(l<icr/p"<icr/k)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>li`pos</grk> fat.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
derived from, fat. The word was formerly used specifically to designate
a supposed acid obtained by the oxidation of oleic acid, tallow, wax,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lipid</ent><br/
<hw>lip"id</hw> <pos>n.</pos> <ety>[Gr. <grk>li`pos</grk> fat.]</ety>
<fld>(Chem., Biochem.)</fld> <def>Any of a variety of oily or greasy
organic compounds found as major structural components of living cells;
they are insoluble in water but soluble in organic solvents such as
alcohol and ether, and include the common <stype>fats</stype>,
<stype>cholesterol</stype> and other steroids,
<stype>phospholipids</stype>, <stype>sphingolipids</stype>,
<stype>waxes</stype>, and <stype>fatty acids</stype>; some of the
lipids, together with proteins and carbohydrates, form an essential
structural component of living cells, as in the cell walls and
membranes. The term <ex>lipid</ex> refers to its solubility in nonpolar
solvents, and has no significance with regard to chemical
structure.</def><br/
<syn><b>Syn. --</b> lipide, lipoid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lipide</ent><br/
<hw>lipide</hw> <pos>n.</pos> <def>Same as <er>lipid</er>.</def><br/
<syn><b>Syn. --</b> lipid, lipoid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lipidemia</ent><br/
<hw>lip`id*e"mi*a</hw> <pr>(l<icr/p`<icr/d*<emac/"m<esl/*<adot/)</pr>,
<pos>n.</pos> <fld>(Med.)</fld> <def>Same as <er>lipemia</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>lipid-lowering</ent><br/
<hw>lipid-lowering</hw> <pos>a.</pos> <fld>(Med.)</fld> <def>Serving to
reduce the concentration of lipid, such as cholesterol, in the blood; --
of medications, such as <er>Mevinolin</er>, that are used especially to
reduce blood cholesterol, as a preventive measure against heart
disease.</def><br/
[<source>PJC</source>]</p>

<p><ent>lipidosis</ent><br/
<hw>lip`id*o"sis</hw> <pr>(l<icr/p`<icr/d*<omac/"s<icr/s)</pr>,
<pos>n.</pos> <fld>(Med.)</fld> <def>A disorder of lipid metabolism,
whether congenital or acquired.</def><br/
[<source>PJC</source>]</p>

<p><-- p. 858 pr=VMG --></p>

<p><ent>Lipinic</ent><br/
<hw>Li*pin"ic</hw> <pr>(l<icr/*p<icr/n"<icr/k)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Lipic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipless</ent><br/
<hw>Lip"less</hw> <pr>(l<icr/p"l<ecr/s)</pr>, <pos>a.</pos> <def>Having
no lips.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liplet</ent><br/
<hw>Lip"let</hw> <pr>(l<icr/p"l<ecr/t)</pr>, <pos>n.</pos> <def>A little
lip.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipocephala</ent><br/
\'d8<hw>Lip`o*ceph"a*la</hw>
<pr>(l<icr/p`<osl/*s<ecr/f"<adot/*l<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>lei`pesqai</grk> to be lacking +
<grk>kefalh`</grk> head.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Lamellibranchia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipochrin</ent><br/
<hw>Lip"o*chrin</hw> <pr>(l<icr/p"<osl/*kr<icr/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>li`pos</grk> fat + <grk>chro`a</grk> color.]</ety>
<fld>(Physiol. Chem.)</fld> <def>A yellow coloring matter, soluble in
ether, contained in the small round fat drops in the retinal epithelium
cells. It is best obtained from the eyes of frogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipogram</ent><br/
<hw>Lip"o*gram</hw> <pr>(l<icr/p"<osl/*gr<acr/m; 277)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>lei`pein</grk>, <grk>lipei^n</grk>, to
leave, omit + <ets>-gram</ets>.]</ety> <def>A writing composed of words
not having a certain letter or letters; -- as in the Odyssey of
Tryphiodorus there was no A in the first book, no B in the second, and
so on.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipogrammatic</ent><br/
<hw>Lip`o*gram*mat"ic</hw>
<pr>(l<icr/p`<osl/*gr<acr/m*m<acr/t"<icr/k)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>lipogra`mmatos</grk>: cf. F.
<ets>lipogrammatique</ets>.]</ety> <def>Omitting a letter; composed of
words not having a certain letter or letters; <as>as,
<ex>lipogrammatic</ex> writings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipogrammatist</ent><br/
<hw>Lip`o*gram"ma*tist</hw> <pr>(-gr<acr/m"m<adot/*t<icr/st)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>lipogrammatiste</ets>.]</ety> <def>One
who makes a lipogram.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lipoidemia</ent><br/
<hw>lip`oi*de"mi*a</hw> <pr>(l<icr/p`oi*d<emac/"m<esl/*<adot/)</pr>,
<pos>n.</pos> <fld>(Med.)</fld> <def>Same as <er>lipemia</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lipoma</ent><br/
\'d8<hw>Li*po"ma</hw> <pr>(l<icr/*p<omac/"m<adot/)</pr>, <pos>n.</pos>
<ety>[NL., from Gr. <grk>li`pos</grk> fat + <ets>-oma</ets>.]</ety>
<fld>(Med.)</fld> <def>A tumor consisting of fat or adipose
tissue.</def> -- <wordforms><wf>Li*pom"a*tous</wf>
<pr>(-p<ocr/m"<adot/*t<ucr/s)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lipophilic</ent><br/
<hw>lipophilic</hw> <pos>adj.</pos> <fld>(Chem.)</fld> <def>having an
affinity for lipids; -- of chemical substances or parts of molecules.
Contrasted to <contr>lipophobic</contr> or
<contr>polar</contr>.</def><br/
<syn><b>Syn. --</b> lipotropic, nonpolar.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lipophobic</ent><br/
<hw>lipophobic</hw> <pos>adj.</pos> <fld>(Chem.)</fld> <def>Not soluble
in lipids, or in non-polar solvents; -- of chemical substances or parts
of molecules; <as>as, the <ex>lipophobic</ex> end of a detergent is
solvated in water</as>. Contrasted to <contr>lipophilic</contr> or
<contr>nonpolar</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lipothymic</ent><br/
<hw>Li`po*thym"ic</hw> <pr>(l<imac/`p<osl/*th<icr/m"<icr/k)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>leipoqymiko`s</grk>,
<grk>lipoqymiko`s</grk>.]</ety> <def>Tending to swoon; fainting.</def>
<altsp>[Written also <asp>leipothymic</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipothymous</ent><br/
<hw>Li*poth"y*mous</hw> <pr>(l<isl/*p<ocr/th"<icr/*m<ucr/s)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>lei`pein</grk> to leave, to lack +
<grk>qymo`s</grk> soul, life.]</ety> <def>Pertaining, or given, to
swooning; fainting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipothymy</ent><br/
<hw>Li*poth"y*my</hw> <pr>(l<isl/*p<ocr/th"<icr/*m<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>lipoqymi`a</grk>: cf. F.
<ets>lipothymie</ets>.]</ety> <def>A fainting; a swoon.</def>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lipotropic</ent><br/
<hw>lipotropic</hw> <pos>adj.</pos> <fld>(Chem.)</fld> <def>having an
affinity for lipids.</def><br/
<syn><b>Syn. --</b> lipophilic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lipotyphla</ent><br/
<hw>Lipotyphla</hw> <pos>n.</pos> <def>A suborder of mammals including
the moles; hedgehogs; and true shrews.</def><br/
<syn><b>Syn. --</b> suborder Lipotyphla.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lipped</ent><br/
<hw>Lipped</hw> <pr>(l<icr/pt)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a lip or lips; having a raised or rounded edge resembling
the lip; -- often used in composition; <as>as, thick<ex>-lipped</ex>,
thin<ex>-lipped</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Labiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lippitude</ent><br/
<hw>Lip"pi*tude</hw> <pr>(l<icr/p"p<icr/*t<umac/d)</pr>, <pos>n.</pos>
<ety>[L. <ets>lippitudo</ets>, fr. <ets>lippus</ets> blear-eyed: cf. F.
<ets>lippitude</ets>.]</ety> <def>Soreness of eyes; the state of being
blear-eyed; blearedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipse</ent><br/
<hw>Lipse</hw> <pr>(l<icr/ps)</pr>, <pos>v. i.</pos> <def>To lisp.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lipyl</ent><br/
<hw>Lip"yl</hw> <pr>(l<icr/p"<icr/l)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>li`pos</grk> fat + <ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A
hypothetical radical of glycerin.</def> <mark>[Obs.]</mark>
<rj><au>Berzelius.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquable</ent><br/
<hw>Liq"ua*ble</hw> <pr>(l<icr/k"w<adot/*b'l)</pr>, <pos>a.</pos>
<ety>[L. <ets>liquabilis</ets>. See <er>Liquate</er>, <pos>v.
i.</pos>]</ety> <def>Capable of being melted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquate</ent><br/
<hw>Li"quate</hw> <pr>(l<imac/"kw<amac/t)</pr>, <pos>v. i.</pos>
<ety>[L. <ets>liquatus</ets>, p. p. of <ets>liquare</ets> to
melt.]</ety> <def>To melt; to become liquid.</def> <mark>[Obs.]</mark>
<rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquate</ent><br/
<hw>Li"quate</hw>, <pos>v. t.</pos> <fld>(Metal.)</fld> <def>To separate
by fusion, as a more fusible from a less fusible material.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquation</ent><br/
<hw>Li*qua"tion</hw> <pr>(l<isl/*kw<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>liquatio</ets>: cf. F. <ets>liquation</ets>.]</ety>
<sn>1.</sn> <def>The act or operation of making or becoming liquid;
also, the capacity of becoming liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal.)</fld> <def>The process of separating, by
heat, an easily fusible metal from one less fusible;
eliquation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquefacient</ent><br/
<hw>Liq`ue*fa"cient</hw> <pr>(l<icr/k`w<esl/*f<amac/"sh<eit/nt)</pr>,
<pos>n.</pos> <ety>[L. <ets>liquefaciens</ets>, p. pr. of
<ets>liquefacere</ets>. See <er>Liquefy</er>.]</ety> <sn>1.</sn>
<def>That which serves to liquefy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>An agent, as mercury, iodine,
etc., which promotes the liquefying processes of the system, and
increases the secretions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquefaction</ent><br/
<hw>Liq`ue*fac"tion</hw> <pr>(l<icr/k`w<esl/*f<acr/k"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>liquefactio</ets>: cf. F.
<ets>liqu<eacute/faction</ets>. See <er>Liquefy</er>.]</ety> <sn>1.</sn>
<def>The act or operation of making or becoming liquid; especially, the
conversion of a solid into a liquid by the sole agency of
heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem. Physics)</fld> <def>The act, process, or
method, of reducing a gas or vapor to a liquid by means of cold or
pressure; <as>as, the <ex>liquefaction</ex> of oxygen or
hydrogen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquefiable</ent><br/
<hw>Liq"ue*fi`a*ble</hw> <pr>(l<icr/k"w<esl/*f<imac/`<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>liqu<eacute/fiable</ets>. See
<er>Liquefy</er>.]</ety> <def>Capable of being changed from a solid to a
liquid state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>liquefied</ent><br/
<hw>liquefied</hw> <pos>adj.</pos> <sn>1.</sn> <def>converted to a
liquid; <as>as, <ex>liquified</ex> natural gas; <ex>liquified</ex>
coal</as>.</def>.<br/
<syn><b>Syn. --</b> liquified.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>rendered liquid by heating; changed from a solid to
a liquid state; melted.</def><br/
<syn><b>Syn. --</b> molten, liquified.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>rendered liquid by dissolution in a solvent; -- of
solids.</def><br/
<syn><b>Syn. --</b> dissolved, liquified.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Liquefier</ent><br/
<hw>Liq"ue*fi`er</hw> <pr>(l<icr/k"w<esl/*f<imac/`<etil/r)</pr>,
<pos>n.</pos> <def>That which liquefies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquefy</ent><br/
<hw>Liq"ue*fy</hw> <pr>(l<icr/k"w<esl/*f<imac/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Liquefied</conjf>
<pr>(-f<imac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Liquefying</conjf> <pr>(-f<imac/`<icr/ng)</pr>.]</vmorph>
<ety>[F. <ets>liqu<eacute/fier</ets>, L. <ets>liquere</ets> to be liquid
+ <ets>facere</ets>, <ets>-ficare</ets> (in comp.), to make. See
<er>Liquid</er>, and <er>-fy</er>.]</ety> <sn>1.</sn> <def>To convert
from a solid form to that of a liquid; to melt; to dissolve; and
technically, to melt by the sole agency of heat.</def>
<wns>[wns=1]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To convert from a gaseous form into a liquid;
<as>as, to liquefy natural gas</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Liquefy</ent><br/
<hw>Liq"ue*fy</hw>, <pos>v. i.</pos> <def>To become liquid.</def>
<wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquescency</ent><br/
<hw>Li*ques"cen*cy</hw> <pr>(l<isl/*kw<ecr/s"s<eit/n*s<ycr/)</pr>,
<pos>n.</pos> <ety>[See <er>Liquescent</er>.]</ety> <def>The quality or
state of being liquescent.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquescent</ent><br/
<hw>Li*ques"cent</hw> <pr>(l<isl/*kw<ecr/s"s<eit/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>liquescens</ets>, p. pr. of <ets>liquescere</ets> to
become liquid, incho. fr. <ets>liquere</ets> to be liquid.]</ety>
<def>Tending to become liquid; inclined to melt; melting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liqueur</ent><br/
\'d8<hw>Li`queur"</hw> <pr>(l<esl/`k<etil/r")</pr>, <pos>n.</pos>
<ety>[F. See <er>Liquor</er>.]</ety> <def>An aromatic alcoholic
cordial.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some <xex>liqueurs</xex> are prepared by infusing
certain woods, fruits, or flowers, in either water or alcohol, and
adding sugar, etc. Others are distilled from aromatic or flavoring
agents.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquid</ent><br/
<hw>Liq"uid</hw> <pr>(l<icr/k"w<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>liquidus</ets>, fr. <ets>liquere</ets> to be fluid or liquid; cf.
Skr. <ets>r<imac/</ets> to ooze, drop, <ets>l<imac/</ets> to
melt.]</ety> <sn>1.</sn> <def>Flowing freely like water; fluid; not
solid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yea, though he go upon the plane and <qex>liquid</qex> water which
will receive no step.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>Being in such a state that the
component molecules move freely among themselves, but have a definite
volume changing only slightly with changes of pressure, and do not tend
to separate from each other as the particles of gases and vapors do when
the volume of the container is increased; neither solid nor gaseous;
<as>as, <ex>liquid</ex> mercury, in distinction from mercury solidified
or in a state of vapor</as>.</def> <note>Liquid substances may form a
definite interface with gases, whereas the molecules of different gases
freely intermingle with each other.</note><br/
[<source>1913 Webster</source> <source>+PJC</source> ]</p>

<p><sn>3.</sn> <def>Flowing or sounding smoothly or without abrupt
transitions or harsh tones.</def> <ldquo/<xex>Liquid</xex>
melody.<rdquo/ <rj><au>Crashaw.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Pronounced without any jar or harshness; smooth;
<as>as, <ex>l</ex> and <ex>r</ex> are <ex>liquid</ex>
letters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Fluid and transparent; <as>as, the <ex>liquid</ex>
air</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Clear; definite in terms or amount.</def>
<mark>[Obs.]</mark> <ldquo/Though the debt should be entirely
<xex>liquid</xex>.<rdquo/ <rj><au>Ayliffe.</au></rj></p>

<p><sn>7.</sn> <fld>(Finance)</fld> <def>In cash or readily convertible
into cash without loss of principle; -- said of assets, such as bank
accounts, or short-term bonds tradable on a major stock
exchange.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Liquid glass</b></col>. <cd>See <cref>Soluble
glass</cref>, under <er>Glass</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquid</ent><br/
<hw>Liq"uid</hw>, <pos>n.</pos> <sn>1.</sn> <def>A substance whose parts
change their relative position on the slightest pressure, and therefore
retain no definite form; any substance in the state of liquidity; a
fluid that is not gaseous and has a definite volume independent, of the
container in which it is held. Liquids have a fixed volume at any given
pressure, but their shape is determined by the container in which it is
contained. Liquids, in contrast to gases, cannot expand indefinitely to
fill an expanding container, and are only slightly compressible by
application of pressure.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Liquid</xex> and <xex>fluid</xex> are terms often
used synonymously, but <xex>fluid</xex> has the broader signification.
All liquids are fluids, but many fluids, as air and the gases, are not
liquids.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phon.)</fld> <def>A letter which has a smooth,
flowing sound, or which flows smoothly after a mute; <as>as, <ex>l</ex>
and <ex>r</ex>, in <ex>bla</ex>, <ex>bra</ex></as>. <xex>M</xex> and
<xex>n</xex> also are called <xex>liquids</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Liquid measure</b></col>, <cd>a measure, or system of
measuring, for liquids, by the gallon, quart, pint, gill,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquid air</ent><br/
<hw>Liq"uid air</hw>. <fld>(Physics)</fld> <def>A transparent limpid
liquid, slightly blue in color, consisting of a mixture of liquefied
oxygen and nitrogen. It is prepared by subjecting air to great pressure
and then cooling it by its own expansion to a temperature below the
boiling point of its constituents (N: -194<deg/ C; O: -183<deg/
C.).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Liquidambar</ent><br/
<hw>Liq"uid*am`bar</hw> <pr>(l<icr/k"w<icr/d*<acr/m`b<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Liquid</ets> + <ets>amber</ets>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A genus consisting of two species of
tall trees having star-shaped leaves, and woody burlike fruit.
<spn>Liquidambar styraciflua</spn> is the North American <stype>sweet
qum</stype>, and <spn>Liquidambar Orientalis</spn> is found in Asia
Minor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The balsamic juice which is obtained from these
trees by incision. The liquid balsam of the Oriental tree is <xex>liquid
storax</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidamber</ent><br/
<hw>Liq"uid*am`ber</hw>, <pos>n.</pos> <def>See
<er>Liquidambar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidate</ent><br/
<hw>Liq"ui*date</hw> <pr>(l<icr/k"w<icr/*d<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Liquidated</conjf>
<pr>(-d<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Liquidating</conjf>.]</vmorph> <ety>[LL. <ets>liquidatus</ets>,
p. p. of <ets>liquidare</ets> to liquidate, fr. L. <ets>liquidus</ets>
liquid, clear. See <er>Liquid</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld>
<def>To determine by agreement or by litigation the precise amount of
(indebtedness); or, where there is an indebtedness to more than one
person, to determine the precise amount of (each indebtedness); to make
the amount of (an indebtedness) clear and certain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A debt or demand is <qex>liquidated</qex> whenever the amount due
is agreed on by the parties, or fixed by the operation of law.</q>
<rj><qau>15 Ga. Rep. 321.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If our epistolary accounts were fairly <qex>liquidated</qex>, I
believe you would be brought in considerable debtor.</q>
<rj><qau>Chesterfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In an extended sense: To ascertain the amount, or
the several amounts, of, and apply assets toward the discharge of (an
indebtedness).</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To discharge; to pay off or settle, as an
indebtedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Friburg was ceded to Zurich by Sigismund to <qex>liquidate</qex> a
debt of a thousand florins.</q> <rj><qau>W. Coxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make clear and intelligible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time only can <qex>liquidate</qex> the meaning of all parts of a
compound system.</q> <rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make liquid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To convert (assets) into cash.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>To kill; -- used mostly of governments or
organizations killing their enemies; <as>as, Stalin <ex>liquidated</ex>
many of the Kulaks</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>To dissolve (an organization); to terminate (an
activity).</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Liquidated damages</b></col> <fld>(Law)</fld>,
<cd>damages the amount of which is fixed or ascertained.</cd>
<rj><au>Abbott.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidation</ent><br/
<hw>Liq`ui*da"tion</hw> <pr>(l<icr/k`w<icr/*d<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>liquidation</ets>.]</ety> <def>The act
or process of liquidating; the state of being liquidated.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To go into liquidation</b></col> <fld>(Law)</fld>, <cd>to
turn over to a trustee one's assets and accounts, in order that the
several amounts of one's indebtedness may be authoritatively
ascertained, and that the assets may be applied toward their
discharge.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidator</ent><br/
<hw>Liq"ui*da`tor</hw> <pr>(l<icr/k"w<icr/*d<amac/`t<etil/r)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>liquidateur</ets>.]</ety> <sn>1.</sn>
<def>One who, or that which, liquidates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An officer appointed to conduct the winding up of a
company, to bring and defend actions and suits in its name, and to do
all necessary acts on behalf of the company.</def> <mark>[Eng.]</mark>
<rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>liquidise</ent><br/
<hw>liquidise</hw> <pos>v. t.</pos> <def>Same as
<er>liquidize</er>.</def><br/
<syn><b>Syn. --</b> liquefy, liquify, make liquid, liquidize, make
fluid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liquidity</ent><br/
<hw>Li*quid"i*ty</hw> <pr>(l<icr/*kw<icr/d"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>liquiditas</ets>, fr. <ets>liquidus</ets>
liquid: cf. F. <ets>liquidit<eacute/</ets>.]</ety> <def>The state or
quality of being liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- (Finance) the quality of being readily convertible to cash.
--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidize</ent><br/
<hw>Liq"uid*ize</hw> <pr>(l<icr/k"w<icr/d*<imac/z)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Liquidized</conjf>
<pr>(-<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Liquidizing</conjf> <pr>(-<imac/`z<icr/ng)</pr>.]</vmorph>
<def>To render liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidly</ent><br/
<hw>Liq"uid*ly</hw>, <pos>adv.</pos> <def>In a liquid manner;
flowingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquidness</ent><br/
<hw>Liq"uid*ness</hw>, <pos>n.</pos> <def>The quality or state of being
liquid; liquidity; fluency.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>liquified</ent><br/
<hw>liquified</hw> <pos>adj.</pos> <def>Same as
<er>liquefied</er>.</def>.<br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>liquify</ent><br/
<hw>liquify</hw> <pos>v. t. & i.</pos> <sn>1.</sn> <def>Same as
<er>liquefy</er>.</def><br/
<syn><b>Syn. --</b> , make liquid, liquidize, liquidise, make
fluid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liquor</ent><br/
<hw>Liq"uor</hw> <pr>(l<icr/k"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>licour</ets>, <ets>licur</ets>, OF. <ets>licur</ets>, F.
<ets>liqueur</ets>, fr. L. <ets>liquor</ets>, fr. <ets>liquere</ets> to
be liquid. See <er>Liquid</er>, and cf. <er>Liqueur</er>.]</ety>
<sn>1.</sn> <def>Any liquid substance, as water, milk, blood, sap,
juice, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, alcoholic or spirituous fluid, either
distilled or fermented, as brandy, wine, whisky, beer, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Pharm.)</fld> <def>A solution of a medicinal
substance in water; -- distinguished from <contr>tincture</contr> and
<contr>aqua</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The U. S. Pharmacopoeia includes, in this class of
preparations, all <xex>aqueous</xex> solutions without sugar, in which
the substance acted on is wholly soluble in water, excluding those in
which the dissolved matter is gaseous or very volatile, as in the
aqu<ae/ or waters.</note> <rj><au>U. S. Disp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Labarraque's liquor</b></col> <fld>(Old Chem.)</fld>,
<cd>a solution of an alkaline hypochlorite, as sodium hypochlorite, used
in bleaching and as a disinfectant.</cd> -- <mcol><col><b>Liquor of
flints</b></col>, <it>or</it> <col><b>Liquor silicum</b></col></mcol>
<fld>(Old Chem.)</fld>, <cd>soluble glass; -- so called because formerly
made from powdered flints. See <cref>Soluble glass</cref>, under
<er>Glass</er>.</cd> -- <col><b>Liquor of Libavius</b></col>. <fld>(Old
Chem.)</fld> <cd>See <cref>Fuming liquor of Libavius</cref>, under
<er>Fuming</er>.</cd> -- <col><b>Liquor sanguinis</b></col>
<pr>(s<acr/n"gw<icr/n*<icr/s)</pr>, <fld>(Physiol.)</fld>, <cd>the blood
plasma.</cd> -- <col><b>Liquor thief</b></col>, <cd>a tube for taking
samples of liquor from a cask through the bung hole.</cd> -- <col><b>To
be in liquor</b></col>, <cd>to be intoxicated.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquor</ent><br/
<hw>Liq"uor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Liquored</conjf> <pr>(l<icr/k"<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Liquoring</conjf>.]</vmorph> <sn>1.</sn> <def>To supply
with liquor.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grease.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Liquor</qex> fishermen's boots.</q>
<rj><qau>Shak.</qau></rj></p>

<p><-- liquored up. intoxicated by liquor --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquorice</ent><br/
<hw>Liq"uor*ice</hw> <pr>(l<icr/k"<etil/r*<icr/s)</pr>, <pos>n.</pos>
<def>See <er>Licorice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquorish</ent><br/
<hw>Liq"uor*ish</hw>, <pos>a.</pos> <def>See <er>Lickerish</er>.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liquorous</ent><br/
<hw>Liq"uor*ous</hw> <pr>(l<icr/k"<etil/r*<ucr/s)</pr>, <pos>a.</pos>
<def>Eagerly desirous. See <er>Lickerish</er>.</def> <mark>[Obs.]</mark>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lira</ent><br/
\'d8<hw>Li"ra</hw> <pr>(l<emac/"r<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lire</plw> <pr>(l<emac/"r<asl/)</pr>.</plu>
<ety>[It., fr. L. <ets>libra</ets> the Roman pound. Cf.
<er>Livre</er>.]</ety> <def>An Italian coin equivalent in value to the
French franc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lirella</ent><br/
\'d8<hw>Li*rel"la</hw> <pr>(l<isl/*r<ecr/l"l<adot/)</pr>, <pos>n.</pos>
<ety>[NL., dim. of L. <ets>lira</ets> a furrow.]</ety> <fld>(Bot.)</fld>
<def>A linear apothecium furrowed along the middle; the fruit of certain
lichens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lirelliform</ent><br/
<hw>Li*rel"li*form</hw> <pr>(l<isl/*r<ecr/l"l<icr/*f<ocir/rm)</pr>,
<pos>a.</pos> <ety>[<ets>Lirella</ets> + <ets>-form</ets>.]</ety>
<fld>(Bot.)</fld> <def>Like a lirella.</def> <altsp>[Written also
<asp>lirell<ae/form</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liriodendron</ent><br/
\'d8<hw>Lir`i*o*den"dron</hw>
<pr>(l<icr/r`<icr/*<osl/*d<ecr/n"dr<ocr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Liriodendra</plw> <pr>(-dr<adot/)</pr>.</plu>
<ety>[NL., fr. Gr. <grk>lei`rion</grk> lily + <grk>de`ndron</grk>
tree.]</ety> <fld>(Bot.)</fld> <def>A genus of large and very beautiful
trees of North America, having smooth, shining leaves, and handsome,
tuliplike flowers; tulip tree; whitewood; -- called also
<altname>canoewood</altname>. <spn>Liriodendron tulipifera</spn> is the
only extant species, but there were several others in the Cretaceous
epoch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liripipe</ent><br/
<hw>Lir"i*pipe</hw> <pr>(l<icr/r"<icr/*p<imac/p)</pr>, <pos>n.</pos>
<mark>[Obs.]</mark> <def>See <er>Liripoop</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liripoop</ent><br/
<hw>Lir"i*poop</hw> <pr>(l<icr/r"<icr/*p<oomac/p)</pr>, <pos>n.</pos>
<ety>[OF. <ets>liripipion</ets>, <ets>liripion</ets>, LL.
<ets>liripipium</ets>. Said to be corrupted from L. <ets>cleri
ephippium</ets>, lit., the clergy's caparison.]</ety> <sn>1.</sn> <def>A
pendent part of the old clerical tippet; afterwards, a tippet; a scarf;
-- worn also by doctors, learned men, etc.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Acuteness; smartness; also, a smart trick or
stratagem.</def> <mark>[Obs.]</mark> <rj><au>Stanihurst.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A silly person.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>liripoop</qex>, vel <qex>lerripoop</qex>, a silly, empty
creature; an old dotard.</q> <rj><qau>Milles. MS. Devon
Gloss.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liroconite</ent><br/
<hw>Li*roc"o*nite</hw> <pr>(l<isl/*r<ocr/k"<osl/*n<imac/t)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>leiro`s</grk> pale + <grk>koni`a</grk>
powder.]</ety> <fld>(Min.)</fld> <def>A hydrated arseniate of copper,
occurring in obtuse pyramidal crystals of a sky-blue or verdigris-green
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lisbon</ent><br/
<hw>Lis"bon</hw> <pr>(l<icr/z"b<ocr/n)</pr>, <pos>n.</pos> <def>A sweet,
light-colored species of wine, produced in the province of Estremadura,
and so called as being shipped from Lisbon, in Portugal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lisle</ent><br/
<hw>Lisle</hw> <pr>(l<imac/l)</pr>, <pos>n.</pos> <def>A city of France
celebrated for certain manufactures.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lisle glove</b></col>, <cd>a fine summer glove, made of
Lisle thread.</cd> -- <col><b>Lisle lace</b></col>, <cd>a fine handmade
lace, made at Lisle.</cd> -- <col><b>Lisle thread</b></col>, <cd>a hard
twisted cotton thread, originally produced at Lisle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lisne</ent><br/
<hw>Lisne</hw> <pr>(l<imac/n)</pr>, <pos>n.</pos> <ety>[Prov. E.
<ets>lissen</ets>, <ets>lisne</ets>, a cleft in a rock.]</ety> <def>A
cavity or hollow.</def> <mark>[Obs.]</mark> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lisp</ent><br/
<hw>Lisp</hw> <pr>(l<icr/sp)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lisped</conjf> <pr>(l<icr/spt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Lisping</conjf>.]</vmorph> <ety>[OE.
<ets>lispen</ets>, <ets>lipsen</ets>, AS. <ets>wlisp</ets> stammering,
lisping; akin to D. & OHG. <ets>lispen</ets> to lisp, G.
<ets>lispeln</ets>, Sw. <ets>l<aum/spa</ets>, Dan.
<ets>lespe</ets>.]</ety> <sn>1.</sn> <def>To pronounce the sibilant
letter <xex>s</xex> imperfectly; to give <xex>s</xex> and <xex>z</xex>
the sound of <xex>th</xex>; -- a defect common among children.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To speak with imperfect articulation; to
mispronounce, as a child learning to talk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As yet a child, nor yet a fool to fame,<br/
I <qex>lisped</qex> in numbers, for the numbers came.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To speak hesitatingly with a low voice, as if
afraid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest when my <qex>lisping</qex>, guilty tongue should halt.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lisp</ent><br/
<hw>Lisp</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To pronounce with a
lisp.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter with imperfect articulation; to express
with words pronounced imperfectly or indistinctly, as a child speaks;
hence, to express by the use of simple, childlike language.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To speak unto them after their own capacity, and to
<qex>lisp</qex> the words unto them according as the babes and children
of that age might sound them again.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To speak with reserve or concealment; to utter
timidly or confidentially; <as>as, to <ex>lisp</ex>
treason</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lisp</ent><br/
<hw>Lisp</hw>, <pos>n.</pos> <def>The habit or act of lisping. See
<er>Lisp</er>, <pos>v. i.</pos>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I overheard her answer, with a very pretty <qex>lisp</qex>,
<ldquo/O! Strephon, you are a dangerous creature.<rdquo/</q>
<rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>LISP</ent><br/
<hw>LISP</hw> <pr>(l<icr/sp)</pr>, <pos>n.</pos> <fld>(Computers)</fld>
<ety>[<ets>Lis</ets>t <ets>P</ets>rocessing.]</ety> <def>a high-level
computer programming language in which statements and data are in the
form of lists, enclosed in parentheses; -- used especially for rapid
development of prototype programs in artificial intelligence
applications .</def><br/
[<source>PJC</source>]</p>

<p><ent>Lisper</ent><br/
<hw>Lisp"er</hw> <pr>(l<icr/sp"<etil/r)</pr>, <pos>n.</pos> <def>One who
lisps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lispingly</ent><br/
<hw>Lisp"ing*ly</hw>, <pos>adv.</pos> <def>With a lisp; in a lisping
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liss</ent><br/
<hw>Liss</hw> <pr>(l<icr/s)</pr>, <pos>n.</pos> <ety>[AS.
<ets>liss</ets>.]</ety> <def>Release; remission; ease; relief.</def>
<mark>[Obs.]</mark> <ldquo/Of penance had a <xex>lisse</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liss</ent><br/
<hw>Liss</hw>, <pos>v. t.</pos> <ety>[AS. <ets>lissan</ets>.]</ety>
<def>To free, as from care or pain; to relieve.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Lissed</xex> of his care.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lissencephala</ent><br/
\'d8<hw>Lis`sen*ceph"a*la</hw>
<pr>(l<icr/s`s<ecr/n*s<ecr/f"<adot/*l<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>lisso`s</grk> smooth + <grk>'egke`falos</grk>
the brain.]</ety> <fld>(Zool.)</fld> <def>A general name for all those
placental mammals that have a brain with few or no cerebral
convolutions, as Rodentia, Insectivora, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lissome</ent><br/
<ent>Lissom</ent><br/
<mhw>{ <hw>Lis"som</hw>, <hw>Lis"some</hw> }</mhw>
<pr>(l<icr/s"s<ucr/m)</pr>, <pos>a.</pos> <ety>[For
<ets>lithesome</ets>.]</ety> <sn>1.</sn> <def>Limber; supple; flexible;
lithe; lithesome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Straight, but as <qex>lissome</qex> as a hazel wand.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Light; nimble; active.</def>
<rj><au>Halliwell.</au></rj></p>

<p>-- <wordforms><wf>Lis"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw> <pr>(l<icr/st)</pr>, <pos>n.</pos> <ety>[F.
<ets>lice</ets>, LL. <ets>liciae</ets>, pl., from L. <ets>licium</ets>
thread, girdle.]</ety> <def>A line inclosing or forming the extremity of
a piece of ground, or field of combat; hence, in the plural
(<xex>lists</xex>), the ground or field inclosed for a race or
combat.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In measured <qex>lists</qex> to toss the weighty lance.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To enter the lists</b></col>, <cd>to accept a challenge,
or engage in contest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>v. t.</pos> <def>To inclose for combat; <as>as, to
<ex>list</ex> a field</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>v. i.</pos> <ety>[See <er>Listen</er>.]</ety>
<def>To hearken; to attend; to listen.</def> <mark>[Obs. <plain>except
in poetry</plain>.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Stand close, and <qex>list</qex> to him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>v. t.</pos> <def>To listen or hearken to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then weigh what loss your honor may sustain,<br/
If with too credent ear you <qex>list</qex> his songs.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>v. i.</pos> <ety>[OE. <ets>listen</ets>,
<ets>lusten</ets>, AS. <ets>lystan</ets>, from <ets>lust</ets> pleasure.
See <er>Lust</er>.]</ety> <sn>1.</sn> <def>To desire or choose; to
please.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The wind bloweth where it <qex>listeth</qex>.</q> <rj><qau>John
iii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Them that add to the Word of God what them <qex>listeth</qex>.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let other men think of your devices as they <qex>list</qex>.</q>
<rj><qau>Whitgift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To lean; to incline; <as>as, the
ship <ex>lists</ex> to port</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>n.</pos> <sn>1.</sn> <def>Inclination; desire.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>An inclination to one side;
<as>as, the ship has a <ex>list</ex> to starboard</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>n.</pos> <ety>[AS. <ets>l<imac/st</ets> a list of
cloth; akin to D. <ets>lijst</ets>, G. <ets>leiste</ets>, OHG.
<ets>l<imac/sta</ets>, Icel. <ets>lista</ets>, <ets>listi</ets>, Sw.
<ets>list</ets>, Dan. <ets>liste</ets>. In sense 5 from F.
<ets>liste</ets>, of German origin, and thus ultimately the same
word.]</ety> <sn>1.</sn> <def>A strip forming the woven border or
selvedge of cloth, particularly of broadcloth, and serving to strengthen
it; hence, a strip of cloth; a fillet.</def> <ldquo/Gartered with a red
and blue <xex>list</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 859 --></p>

<p><sn>2.</sn> <def>A limit or boundary; a border.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The very <qex>list</qex>, the very utmost bound,<br/
Of all our fortunes.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The lobe of the ear; the ear itself.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A stripe.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A roll or catalogue, that is, row or line; a record
of names; <as>as, a <ex>list</ex> of names, books, articles; a
<ex>list</ex> of ratable estate.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was the ablest emperor of all the <qex>list</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Arch.)</fld> <def>A little square molding; a
fillet; -- called also <altname>listel</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Carp.)</fld> <def>A narrow strip of wood, esp.
sapwood, cut from the edge of a plank or board.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Rope Making)</fld> <def>A piece of woolen cloth
with which the yarns are grasped by a workman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Tin-plate Manuf.)</fld> <sd>(a)</sd> <def>The first
thin coat of tin.</def> <sd>(b)</sd> <def>A wirelike rim of tin left on
an edge of the plate after it is coated.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Civil list</b></col> (<mark>Great Britain & U.S.</mark>),
<cd>the civil officers of government, as judges, ambassadors,
secretaries, etc. Hence, the revenues or appropriations of public money
for the support of the civil officers. More recently, the <xex>civil
list</xex>, in England, embraces only the expenses of the reigning
monarch's household.</cd> -- <col><b>Free list</b></col>. <sd>(a)</sd>
<cd>A list of articles admitted to a country free of duty.</cd>
<sd>(b)</sd> <cd>A list of persons admitted to any entertainment, as a
theater or opera, without payment, or to whom a periodical, or the like,
is furnished without cost.</cd></cs></p>

<p><syn><b>Syn.</b> -- Roll; catalogue; register; inventory;
schedule.</syn> <usage> -- <er>List</er>, <er>Roll</er>,
<er>Catalogue</er>, <er>Register</er>, <er>Inventory</er>,
<er>Schedule</er>. A <xex>list</xex> is properly a simple series of
names, etc., in a brief form, such as might naturally be entered in a
narrow strip of paper. A <xex>roll</xex> was originally a list
containing the names of persons belonging to a public body (as
Parliament, etc.), which was <xex>rolled</xex> up and laid aside among
its archives. A <xex>catalogue</xex> is a list of persons or things
arranged in order, and usually containing some description of the same,
more or less extended. A <xex>register</xex> is designed for record or
preservation. An <xex>inventory</xex> is a list of articles, found on
hand in a store of goods, or in the estate of a deceased person, or
under similar circumstances. A <xex>schedule</xex> is a formal list or
inventory prepared for legal or business purposes.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw> <pr>(l<icr/st)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Listed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Listing</conjf>.]</vmorph> <ety>[From <ets>list</ets> a
roll.]</ety> <sn>1.</sn> <def>To sew together, as strips of cloth, so as
to make a show of colors, or form a border.</def> <rj><au>Sir H.
Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover with list, or with strips of cloth; to put
list on; <as>as, to <ex>list</ex> a door</as>; to stripe as if with
list.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The tree that stood white-<qex>listed</qex> through the gloom.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To enroll; to place or register in a list.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Listed</qex> among the upper serving men.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To engage, as a soldier; to enlist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>list</qex> you for my soldier.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Carp.)</fld> <def>To cut away a narrow strip, as of
sapwood, from the edge of; <as>as, to <ex>list</ex> a
board</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To list a stock</b></col> <fld>(Stock Exchange)</fld>,
<cd>to put it in the list of stocks called at the meeting of the
board.</cd></cs><-- to put it on a list of stocks which may be traded on
a specific stock exchange --><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw>, <pos>v. i.</pos> <def>To engage in public service by
enrolling one's name; to enlist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>List</ent><br/
<hw>List</hw> <pr>(l<icr/st)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
plow and plant with a lister.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>In cotton culture, to prepare, as land, for the crop
by making alternating beds and alleys with the hoe.</def>
<mark>[Southern U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>listed</ent><br/
<hw>listed</hw> <pos>adj.</pos> <sn>1.</sn> <def>placed on a list.
Opposite of <ant>unlisted</ant>.</def> [Narrower terms:
<stype>catalogued</stype>; <stype>recorded </stype>; <stype>traded
</stype>]<br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>officially entered in a roll or list; <as>as,
<ex>listed</ex> on a stock exchange; a <ex>listed</ex> securities
trader</as>.</def><br/
<syn><b>Syn. --</b> enrolled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Listel</ent><br/
<hw>List"el</hw> <pr>(l<icr/s"t<ecr/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>listel</ets>, dim. of <ets>liste</ets> fillet, list. See
<er>List</er> the edge.]</ety> <fld>(Arch.)</fld> <def>Same as
<er>List</er>, <pos>n.</pos>, 6.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listen</ent><br/
<hw>Lis"ten</hw> <pr>(l<icr/s"'n)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Listened</conjf>
<pr>(l<icr/s"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Listening</conjf>.]</vmorph> <ety>[OE. <ets>listnen</ets>,
<ets>listen</ets>, <ets>lustnen</ets>, <ets>lusten</ets>, AS.
<ets>hlystan</ets>; akin to <ets>hlyst</ets> hearing, OS.
<ets>hlust</ets>, Icel. <ets>hlusta</ets> to listen, <ets>hlust</ets>
ear, AS. <ets>hlosnian</ets> to wait in suspense, OHG.
<ets>hlos<emac/n</ets> to listen, Gr. <grk>kly`ein</grk>, and E.
<ets>loud</ets>. <root/41. See <er>Loud</er>, and cf. <er>List</er> to
listen.]</ety> <sn>1.</sn> <def>To give close attention with the purpose
of hearing; to give ear; to hearken; to attend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When we have occasion to <qex>listen</qex>, and give a more
particular attention to some sound, the tympanum is drawn to a more than
ordinary tension.</q> <rj><qau>Holder.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give heed; to yield to advice; to follow
admonition; to obey.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Listen</qex> to me, and by me be ruled.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To listen after</b></col>, <cd>to take an interest
in.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Soldiers note forts, armories, and magazines; scholars <qex>listen
after</qex> libraries, disputations, and professors.</q>
<rj><qau>Fuller.</qau></rj></p>

<p><syn><b>Syn.</b> -- To attend; hearken. See
<er>Attend</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listen</ent><br/
<hw>Lis"ten</hw>, <pos>v. t.</pos> <def>To attend to.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listener</ent><br/
<hw>Lis"ten*er</hw> <pr>(l<icr/s"'n*<etil/r)</pr>, <pos>n.</pos>
<def>One who listens; a hearkener.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>listening</ent><br/
<hw>listening</hw> <pos>n.</pos> <def>the act of hearing
attentively.</def><br/
<syn><b>Syn. --</b> hearing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lister</ent><br/
<hw>List"er</hw> <pr>(l<icr/st"<etil/r)</pr>, <pos>n.</pos> <def>One who
makes a list or roll.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lister</ent><br/
<hw>Lis"ter</hw> <pr>(l<icr/s"t<etil/r)</pr>, <pos>n.</pos> <def>Same as
<er>Leister</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lister</ent><br/
<hw>List"er</hw> <pr>(l<icr/st"<etil/r)</pr>, <pos>n.</pos> <ety>[Cf.
<er>List</er> a strip, border, prob. applied to the furrow or the ridge
of earth along the furrow.]</ety> <def>A double-moldboard plow which
throws a deep furrow, and at the same time plants and covers grain in
the bottom of the furrow.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Listerian</ent><br/
<hw>Lis*te"ri*an</hw> <pr>(l<icr/s*t<emac/"r<icr/*<ait/n)</pr>,
<pos>a.</pos> <fld>(Med.)</fld> <def>Of or pertaining to
listerism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listerism</ent><br/
<hw>Lis"ter*ism</hw> <pr>(l<icr/s"t<etil/r*<icr/z'm)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>The systematic use of antiseptics in the
performance of operations and the treatment of wounds; -- so called from
<person>Joseph <etsep>Lister</etsep></person>, an English
surgeon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listerize</ent><br/
<hw>Lis"ter*ize</hw> <pr>(l<icr/s"t<etil/r*<imac/z)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Listerized</conjf>
<pr>(l<icr/s"t<etil/r*<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Listerizing</conjf>
<pr>(l<icr/s"t<etil/r*<imac/z*<icr/ng)</pr>.]</vmorph> <fld>(Med.)</fld>
<def>To make antiseptic.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Listful</ent><br/
<hw>List"ful</hw> <pr>(l<icr/st"f<usdot/l)</pr>, <pos>a.</pos>
<def>Attentive.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listing</ent><br/
<hw>List"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or process of
one who lists (in any sense of the verb); <as>as, the <ex>listing</ex>
of a door; the <ex>listing</ex> of a stock at the Stock
Exchange.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The selvedge of cloth; list.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Carp.)</fld> <def>The sapwood cut from the edge of
a board.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Agric.)</fld> <def>The throwing up of the soil into
ridges, -- a method adopted in the culture of beets and some garden
crops.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Listless</ent><br/
<hw>List"less</hw>, <pos>a.</pos> <ety>[OE. <ets>listles</ets>,
<ets>lustles</ets>. See <er>Lust</er>.]</ety> <def>Having no desire or
inclination; indifferent; heedless; spiritless.</def> <ldquo/ A
<xex>listless</xex> unconcern.<rdquo/ <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Benumbed with cold, and <qex>listless</qex> of their gain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I was <qex>listless</qex>, and desponding.</q>
<rj><qau>Swift.</qau></rj></p>

<p><syn><b>Syn.</b> -- Heedless; careless; indifferent; vacant;
uninterested; languid; spiritless; supine; indolent.</syn></p>

<p>-- <wordforms><wf>List"less*ly</wf>, <pos>adv.</pos> --
<wf>List"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lit</ent><br/
<hw>Lit</hw> <pr>(l<icr/t)</pr>, <sn>1.</sn> <def>a form of the
<pos>imp. & p. p.</pos> of <er>Light</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Under the influence of alcohol; intoxicated;
inebriated; drunk; -- often used with <ptcl>up</ptcl>.</def>
<mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Litany</ent><br/
<hw>Lit"a*ny</hw> <pr>(l<icr/t"<adot/*n<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Litanies</plw>
<pr>(l<icr/t"<adot/*n<icr/z)</pr>.</plu> <ety>[OE. <ets>letanie</ets>,
OF. <ets>letanie</ets>, F. <ets>litanie</ets>, L. <ets>litania</ets>,
Gr. <grk>litanei`a</grk>, fr. <grk>litaney`ein</grk> to pray, akin to
<grk>li`tesqai</grk>, <grk>li`ssesqai</grk>, to pray, <grk>lith`</grk>
prayer.]</ety> <def>A solemn form of supplication in the public worship
of various churches, in which the clergy and congregation join, the
former leading and the latter responding in alternate sentences. It is
usually of a penitential character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Supplications . . . for the appeasing of God's wrath were of the
Greek church termed <qex>litanies</qex>, and rogations of the Latin.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litarge</ent><br/
<hw>Lit"arge</hw> <pr>(l<icr/t"<adot/rj)</pr>, <pos>n.</pos>
<def>Litharge.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litchi</ent><br/
<hw>Li"tchi`</hw> <pr>(l<emac/"ch<emac/`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The fruit of a tree native to China
(<spn>Nephelium Litchi</spn>). It is nutlike, having a rough but tender
shell, containing an aromatic pulp, and a single large seed. In the
dried fruit which is exported the pulp somewhat resembles a raisin in
color and form.</def> <altsp>[Written also <asp>lichi</asp>, and
<asp>lychee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A genus of East Indian
sapindaceous trees consisting of a single species (<spn>Litchi
Chinensis</spn>, syn. <spn>Nephelium Litchi</spn>) which bears the
litchi nut.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>-lite</ent><br/
<hw>-lite</hw> <pr>(-l<imac/t)</pr> <pos>suff.</pos> <def>See
<er>-lith</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lite</ent><br/
<hw>Lite</hw> <pr>(l<imac/t)</pr>, <pos>a., adv., & n.</pos>
<def>Little.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litre</ent><br/
<ent>Liter</ent><br/
<mhw>{ <hw>Li"ter</hw>, <hw>Li"tre</hw> }</mhw> <pr>(l<emac/"t<etil/r;
277)</pr>, <pos>n.</pos> <ety>[F. <ets>litre</ets>, Gr.
<grk>li`tra</grk> a silver coin.]</ety> <def>A measure of capacity in
the metric system, being a cubic decimeter, equal to 61.022 cubic
inches, or 2.113 American pints, or 1.76 English pints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literacy</ent><br/
<hw>Lit"er*a*cy</hw> <pr>(l<icr/t"<etil/r*<adot/*s<ycr/)</pr>,
<pos>n.</pos> <def>State of being literate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literal</ent><br/
<hw>Lit"er*al</hw> <pr>(l<icr/t"<etil/r*<ait/l)</pr>, <pos>a.</pos>
<ety>[F. <ets>lit<eacute/ral</ets>, <ets>litt<eacute/ral</ets>, L.
<ets>litteralis</ets>, <ets>literalis</ets>, fr. <ets>littera</ets>,
<ets>litera</ets>, a letter. See <er>Letter</er>.]</ety> <sn>1.</sn>
<def>According to the letter or verbal expression; real; not figurative
or metaphorical; <as>as, the <ex>literal</ex> meaning of a
phrase</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It hath but one simple <qex>literal</qex> sense whose light the
owls can not abide.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Following the letter or exact words; not
free.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A middle course between the rigor of <qex>literal</qex>
translations and the liberty of paraphrasts.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Consisting of, or expressed by, letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>literal</qex> notation of numbers was known to Europeans
before the ciphers.</q> <rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Giving a strict or literal construction;
unimaginative; matter-of-fact; -- applied to persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Literal contract</b></col> <fld>(Law)</fld>, <cd>a
contract of which the whole evidence is given in writing.</cd>
<au>Bouvier.</au> -- <col><b>Literal equation</b></col>
<fld>(Math.)</fld>, <cd>an equation in which known quantities are
expressed either wholly or in part by means of letters; -- distinguished
from a <contr>numerical equation</contr>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literal</ent><br/
<hw>Lit"er*al</hw>, <pos>n.</pos> <def>Literal meaning.</def>
<mark>[Obs.]</mark> <au>Sir T. Browne.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literalism</ent><br/
<hw>Lit"er*al*ism</hw> <pr>(l<icr/t"<etil/r*<ait/l*<icr/z'm)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>That which accords with the letter; a
mode of interpreting literally; adherence to the letter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fine Arts)</fld> <def>The tendency or disposition
to represent objects faithfully, without abstraction, conventionalities,
or idealization.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literalist</ent><br/
<hw>Lit"er*al*ist</hw>, <pos>n.</pos> <def>One who adheres to the letter
or exact word; an interpreter according to the letter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literality</ent><br/
<hw>Lit`er*al"i*ty</hw> <pr>(l<icr/t`<etil/r*<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>litt<eacute/ralit<eacute/</ets>.]</ety>
<def>The state or quality of being literal.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literalization</ent><br/
<hw>Lit`er*al*i*za"tion</hw>
<pr>(l<icr/t`<etil/r*<ait/l*<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The act of literalizing; reduction to a literal meaning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literalize</ent><br/
<hw>Lit"er*al*ize</hw> <pr>(l<icr/t"<etil/r*<ait/l*<imac/z)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Literalized</conjf> <pr>(l<icr/t"<etil/r*<ait/l*<imac/zd)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Literalizing</conjf>
<pr>(l<icr/t"<etil/r*<ait/l*<imac/*z<icr/ng)</pr>.]</vmorph> <def>To
make literal; to interpret or put in practice according to the strict
meaning of the words; -- opposed to <contr>spiritualize</contr>; <as>as,
to <ex>literalize</ex> Scripture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literalizer</ent><br/
<hw>Lit"er*al*i`zer</hw>
<pr>(l<icr/t"<etil/r*<ait/l*<imac/*z<etil/r)</pr>, <pos>n.</pos> <def>A
literalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literally</ent><br/
<hw>Lit"er*al*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>According to the
primary and natural import of words; not figuratively; <as>as, a man and
his wife can not be <ex>literally</ex> one flesh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With close adherence to words; word by
word.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So wild and ungovernable a poet can not be translated
<qex>literally</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literalness</ent><br/
<hw>Lit"er*al*ness</hw>, <pos>n.</pos> <def>The quality or state of
being literal; literal import.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literary</ent><br/
<hw>Lit"er*a*ry</hw> <pr>(l<icr/t"<etil/r*<asl/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[L. <ets>litterarius</ets>, <ets>literarius</ets>,
fr. <ets>littera</ets>, <ets>litera</ets>, a letter: cf. F.
<ets>litt<eacute/raire</ets>. See <er>Letter</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of or pertaining to letters or literature;
pertaining to learning or learned men; <as>as, <ex>literary</ex> fame; a
<ex>literary</ex> history; <ex>literary</ex>
conversation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has long outlived his century, the term commonly fixed as the
test of <qex>literary</qex> merit.</q> <rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Versed in, or acquainted with, literature; occupied
with literature as a profession; connected with literature or with men
of letters; <as>as, a <ex>literary</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>literary</qex> as well as fashionable world.</q>
<rj><qau>Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Literary property</b></col>. <sd>(a)</sd> <cd>Property
which consists in written or printed compositions.</cd> <sd>(b)</sd>
<cd>The exclusive right of publication as recognized and limited by
law.</cd></cs><--- e.g. a copyright --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literate</ent><br/
<hw>Lit"er*ate</hw> <pr>(l<icr/t"<etil/r*<asl/t)</pr>, <pos>a.</pos>
<ety>[L. <ets>litteratus</ets>, <ets>literatus</ets>. See
<er>Letter</er>.]</ety> <def>Instructed in learning, science, or
literature; learned; lettered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>literate</qex> now chose their emperor, as the military
chose theirs.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literate</ent><br/
<hw>Lit"er*ate</hw>, <pos>n.</pos> <sn>1.</sn> <def>One educated, but
not having taken a university degree; especially, such a person who is
prepared to take holy orders.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A literary man.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literati</ent><br/
\'d8<hw>Lit`e*ra"ti</hw> <pr>(l<icr/t`<esl/*r<aum/"t<emac/;
l<icr/t`<esl/*r<amac/"t<imac/)</pr>, <pos>n. pl.</pos> <ety>[See
<er>Literatus</er>.]</ety> <def>Learned or literary men. See
<er>Literatus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shakespearean commentators, and other <qex>literati</qex>.</q>
<rj><qau>Craik.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literatim</ent><br/
\'d8<hw>Lit`e*ra"tim</hw> <pr>(l<icr/t`<esl/*r<aum/"t<icr/m)</pr>,
<pos>adv.</pos> <ety>[LL., fr. L. <ets>littera</ets>, <ets>litera</ets>,
letter.]</ety> <def>Letter for letter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literation</ent><br/
<hw>Lit`er*a"tion</hw> <pr>(l<icr/t`<etil/r*<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>littera</ets>, <ets>litera</ets>,
letter.]</ety> <def>The act or process of representing by
letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literator</ent><br/
<hw>Lit"er*a`tor</hw> <pr>(l<icr/t"<etil/r*<amac/`t<etil/r)</pr>,
<pos>n.</pos> <ety>[L. <ets>litterator</ets>, <ets>literator</ets>. See
<er>Letter</er>.]</ety> <sn>1.</sn> <def>One who teaches the letters or
elements of knowledge; a petty schoolmaster.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person devoted to the study of literary trifles,
esp. trifles belonging to the literature of a former age.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That class of subjects which are interesting to the regular
<qex>literator</qex> or black-letter <ldquo/ bibliomane,<rdquo/ simply
because they have once been interesting.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A learned person; a literatus.</def> <rj><au>Sir W.
Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literature</ent><br/
<hw>Lit"er*a*ture</hw> <pr>(l<icr/t"<etil/r*<adot/*t<usl/r; 135)</pr>,
<pos>n.</pos> <ety>[F. <ets>litt<eacute/rature</ets>, L.
<ets>litteratura</ets>, <ets>literatura</ets>, learning, grammar,
writing, fr. <ets>littera</ets>, <ets>litera</ets>, letter. See
<er>Letter</er>.]</ety> <sn>1.</sn> <def>Learning; acquaintance with
letters or books.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The collective body of literary productions,
embracing the entire results of knowledge and fancy preserved in
writing; also, the whole body of literary productions or writings upon a
given subject, or in reference to a particular science or branch of
knowledge, or of a given country or period; <as>as, the
<ex>literature</ex> of Biblical criticism; the <ex>literature</ex> of
chemistry.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The class of writings distinguished for beauty of
style or expression, as poetry, essays, or history, in distinction from
scientific treatises and works which contain positive knowledge;
belles-lettres.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The occupation, profession, or business of doing
literary work.</def> <rj><au>Lamb.</au></rj></p>

<p><syn><b>Syn.</b> -- Science; learning; erudition;
belles-lettres.</syn> <usage> See <er>Science</er>. --
<er>Literature</er>, <er>Learning</er>, <er>Erudition</er>.
<xex>Literature</xex>, in its widest sense, embraces all compositions in
writing or print which preserve the results of observation, thought, or
fancy; but those upon the positive sciences (mathematics, etc.) are
usually excluded. It is often confined, however, to
<xex>belles-lettres</xex>, or works of taste and sentiment, as poetry,
eloquence, history, etc., excluding abstract discussions and mere
erudition. A man of <xex>literature</xex> (in this narrowest sense) is
one who is versed in <xex>belles-lettres</xex>; a man of
<xex>learning</xex> excels in what is taught in the schools, and has a
wide extent of knowledge, especially, in respect to the past; a man of
<xex>erudition</xex> is one who is skilled in the more recondite
branches of learned inquiry.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>The origin of all positive science and philosophy, as well as of
all <qex>literature</qex> and art, in the forms in which they exist in
civilized Europe, must be traced to the Greeks.</q> <rj><qau>Sir G. C.
Lewis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Learning</qex> thy talent is, but mine is sense.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some gentlemen, abounding in their university
<qex>erudition</qex>, fill their sermons with philosophical terms.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Literatus</ent><br/
\'d8<hw>Lit`e*ra"tus</hw> <pr>(l<icr/t`<esl/*r<aum/"t<ucr/s;
l<icr/t`<esl/*r<amac/"t<ucr/s)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Literati</plw> <pr>(l<icr/t`<esl/*r<aum/"t<emac/;
l<icr/t`<esl/*r<amac/"t<imac/)</pr>.</plu> <ety>[L.
<ets>litteratus</ets>, <ets>literatus</ets>.]</ety> <def>A learned man;
a man acquainted with literature; -- chiefly used in the
<xex>plural</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now we are to consider that our bright ideal of a
<qex>literatus</qex> may chance to be maimed.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-lite</ent><br/
<ent>-lith</ent><br/
<mhw>{ <hw>-lith</hw> <pr>(-l<icr/th)</pr>, <hw>-lite</hw>
<pr>(-l<imac/t)</pr>. }</mhw> <pos>suff.</pos> <def>Combining forms fr.
Gr. <grk>li`qos</grk> <xlati>a stone</xlati>; -- used chiefly in naming
minerals and rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lith</ent><br/
<hw>Lith</hw> <pr>(l<imac/th)</pr>, <mark>obs.</mark> <def><pos>3d pers.
sing. pres.</pos> of <er>Lie</er>, to recline, for
<xex>lieth</xex>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lith</ent><br/
<hw>Lith</hw> <pr>(l<icr/th)</pr>, <pos>n.</pos> <ety>[AS.
<ets>li<edh/</ets>.]</ety> <def>A joint or limb; a division; a member; a
part formed by growth, and articulated to, or symmetrical with, other
parts.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithaemia</ent><br/
<ent>lithemia</ent><br/
\'d8<hw>li*th<ae/"mi*a</hw> <pr>(l<isl/*th<emac/"m<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>li`qos</grk> stone +
<grk>a"i^ma</grk> blood.]</ety> <fld>(Med.)</fld> <def>A condition in
which uric (lithic) acid is present in the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithagogue</ent><br/
<hw>Lith"a*gogue</hw> <pr>(l<icr/th"<adot/*g<ocr/g)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>li`qos</grk> stone + <grk>'agwgo`s</grk> leading.]</ety>
<fld>(Med.)</fld> <def>A medicine having, or supposed to have, the power
of expelling calculous matter with the urine.</def>
<rj><au>Hooper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litharge</ent><br/
<hw>Lith"arge</hw> <pr>(l<icr/th"<adot/rj)</pr>, <pos>n.</pos> <ety>[OE.
<ets>litarge</ets>, F. <ets>litharge</ets>, L. <ets>lithargyrus</ets>,
Gr. <grk>liqa`rgyros</grk> the scum or foam of silver; <grk>li`qos</grk>
stone + <grk>'a`rgyros</grk> silver. Litharge is found in silverbearing
lead ore.]</ety> <fld>(Chem.)</fld> <def>Lead monoxide; a yellowish red
substance, obtained as an amorphous powder, or crystallized in fine
scales, by heating lead moderately in a current of air or by calcining
lead nitrate or carbonate. It is used in making flint glass, in glazing
earthenware, in making red lead or minium, etc. Called also
<altname>massicot</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithargyrum</ent><br/
\'d8<hw>Li*thar"gy*rum</hw> <pr>(l<icr/*th<aum/r"j<icr/*r<ucr/m)</pr>,
<pos>n.</pos> <ety>[NL. See <er>Litharge</er>.]</ety> <fld>(Old
Chem.)</fld> <def>Crystallized litharge, obtained by fusion in the form
of fine yellow scales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithate</ent><br/
<hw>Lith"ate</hw> <pr>(l<icr/th"<asl/t)</pr>, <pos>n.</pos> <fld>(Old
Med. Chem.)</fld> <def>A salt of lithic or uric acid; a urate.</def>
<mark>[Obs.]</mark> <altsp>[Written also
<asp>lithiate</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithe</ent><br/
<hw>Lithe</hw> <pr>(l<imac/<th/)</pr>, <pos>v. t. & i.</pos> <ety>[Icel
<ets>hl<ymac/<edh/a</ets>. See <er>Listen</er>.]</ety> <def>To listen or
listen to; to hearken to.</def> <mark>[Obs.]</mark> <rj><au>P.
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithe</ent><br/
<hw>Lithe</hw>, <pos>a.</pos> <ety>[AS. <ets>l<imac/<edh/e</ets>, for
<ets>lin<edh/e</ets> tender, mild, gentle; akin to G. <ets>lind</ets>,
<ets>gelind</ets>, OHG. <ets>lindi</ets>, Icel. <ets>linr</ets>, L.
<ets>lenis</ets> soft, mild, <ets>lentus</ets> flexible, and AS.
<ets>linnan</ets> to yield. Cf. <er>Lenient</er>.]</ety> <sn>1.</sn>
<def>Mild; calm; <as>as, <ex>lithe</ex> weather</as>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being easily bent; pliant; flexible;
limber; <as>as, the elephant's <ex>lithe</ex> proboscis</as>.</def>
<rj><au>Milton.</au></rj><br/
<syn><b>Syn. --</b> lithesome.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithe</ent><br/
<hw>Lithe</hw>, <pos>v. t.</pos> <ety>[AS. <ets>l<imac/<edh/ian</ets>.
See <er>Lithe</er>, <pos>a.</pos>]</ety> <def>To smooth; to soften; to
palliate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithely</ent><br/
<hw>Lithe"ly</hw>, <pos>adv.</pos> <def>In a lithe, pliant, or flexible
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litheness</ent><br/
<hw>Lithe"ness</hw>, <pos>n.</pos> <def>The quality or state of being
lithe; flexibility; limberness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lither</ent><br/
<hw>Li"ther</hw> <pr>(l<imac/"<th/<etil/r)</pr>, <pos>a.</pos> <ety>[AS.
<ets>l<ymac/<edh/er</ets> bad, wicked.]</ety> <def>Bad; wicked; false;
worthless; slothful.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>lither</qex> in business, fervent in spirit.</q>
<rj><qau>Bp. Woolton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Professor Skeat thinks <ldquo/ the <xex>lither</xex>
sky<rdquo/ as found in Shakespeare's Henry VI. ((Part I. IV. VII., 21)
means the stagnant or pestilential sky.</note></p>

<p>-- <wordforms><wf>Li"ther*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark>. -- <wf>Li"ther*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litherly</ent><br/
<hw>Li"ther*ly</hw>, <pos>a.</pos> <def>Crafty; cunning; mischievous;
wicked; treacherous; lazy.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He [the dwarf] was waspish, arch, and <qex>litherly</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithesome</ent><br/
<hw>Lithe"some</hw> <pr>(l<imac/<th/"s<ucr/m)</pr>, <pos>a.</pos>
<ety>[See <er>Lithe</er>, <pos>a.</pos>, and cf. <er>Lissom</er>.]</ety>
<def>Pliant; limber; flexible; supple; nimble; lissom.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Lithe"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithia</ent><br/
<hw>Lith"i*a</hw> <pr>(l<icr/th"<icr/*<adot/)</pr>, <pos>n.</pos>
<ety>[NL., from Gr. <grk>li`qos</grk> stone.]</ety> <fld>(Chem.)</fld>
<def>The oxide of lithium; a strong alkaline caustic similar to potash
and soda, but weaker. See <er>Lithium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lithia emerald</b></col>. <cd>See
<er>Hiddenite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithiasis</ent><br/
\'d8<hw>Li*thi"a*sis</hw> <pr>(l<icr/*th<imac/"<adot/*s<icr/s)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>liqi`asis</grk>, fr.
<grk>li`qos</grk> stone.]</ety> <fld>(Med.)</fld> <def>The formation of
stony concretions or calculi in any part of the body, especially in the
bladder and urinary passages.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithic</ent><br/
<hw>Lith"ic</hw> <pr>(l<icr/th"<icr/k)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>liqiko`s</grk> of or belonging to stones, fr. <grk>li`qos</grk>
stone: cf. F. <ets>lithique</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to stone; <as>as, <ex>lithic</ex>
architecture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Pertaining to the formation of
uric-acid concretions (stone) in the bladder and other parts of the
body; <as>as, <ex>lithic</ex> diathesis</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lithic acid</b></col> <fld>(Old Med. Chem.)</fld>,
<cd>uric acid. See <cref>Uric acid</cref>, under
<er>Uric</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithic</ent><br/
<hw>Lith"ic</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A medicine which
tends to prevent stone in the bladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithic</ent><br/
<hw>Lith"ic</hw>, <pos>a.</pos> <ety>[From <er>Lithium</er>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to or denoting lithium or some of its
compounds.</def> <rj><au>Frankland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithiophilite</ent><br/
<hw>Lith`i*oph"i*lite</hw>
<pr>(l<icr/th`<icr/*<ocr/f"<icr/*l<imac/t)</pr>, <pos>n.</pos>
<ety>[<ets>Lithium</ets> + Gr. <grk>fi`los</grk> friend.]</ety>
<fld>(Min.)</fld> <def>A phosphate of manganese and lithium; a variety
of triphylite.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 860 --></p>

<p><ent>Lithium</ent><br/
<hw>Lith"i*um</hw> <pr>(l<icr/th"<icr/*<ucr/m)</pr>, <pos>n.</pos>
<ety>[NL., from Gr. <grk>li`qeios</grk> of stone, fr. <grk>li`qos</grk>
stone.]</ety> <fld>(Chem.)</fld> <def>A metallic element of the alkaline
group, occurring in several minerals, as petalite, spodumene,
lepidolite, triphylite, etc., and otherwise widely disseminated, though
in small quantities.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When isolated it is a soft, silver white metal,
tarnishing and oxidizing very rapidly in the air. It is the lightest
solid element known, specific gravity being 0.59. Symbol Li. Atomic
weight 7.0 So called from having been discovered in a
mineral.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litho</ent><br/
<hw>Lith"o</hw> <pr>(l<icr/th"<osl/)</pr> <def>A combining form from Gr.
<grk>li`qos</grk>, <xlati>stone</xlati>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithobilic</ent><br/
<hw>Lith`o*bil"ic</hw> <pr>(-b<icr/l"<icr/k)</pr>, <pos>a.</pos>
<ety>[<ets>Litho</ets> + <ets>bile</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to or designating an organic acid of the tartaric acid
series, distinct from lithofellic acid, but, like it, obtained from
certain bile products, as bezoar stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithocarp</ent><br/
<hw>Lith"o*carp</hw> <pr>(l<icr/th"<osl/*k<aum/rp)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <grk>karpo`s</grk> fruit: cf. F.
<ets>lithocarpe</ets>.]</ety> <fld>(Paleon.)</fld> <def>Fossil fruit; a
fruit petrified; a carpolite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithochromatics</ent><br/
<hw>Lith`o*chro*mat"ics</hw> <pr>(-kr<osl/*m<acr/t"<icr/ks)</pr>,
<pos>n.</pos> <def>See <er>Lithochromics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithochromics</ent><br/
<hw>Lith`o*chro"mics</hw> <pr>(-kr<omac/"m<icr/ks)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <grk>chrw^ma</grk> color.]</ety> <def>The
art of printing colored pictures on canvas from oil paintings on
stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithoclast</ent><br/
<hw>Lith"o*clast</hw> <pr>(l<icr/th"<osl/*kl<acr/st)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <grk>kla^n</grk> to break.]</ety>
<fld>(Surg.)</fld> <def>An instrument for crushing stones in the
bladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithocyst</ent><br/
<hw>Lith"o*cyst</hw> <pr>(l<icr/th"<osl/*s<icr/st)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>cyst</ets>.]</ety> <fld>(Zool.)</fld>
<def>A sac containing small, calcareous concretions
(<xex>otoliths</xex>). They are found in many Medus<ae/, and other
invertebrates, and are supposed to be auditory organs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithodome</ent><br/
<hw>Lith"o*dome</hw> <pr>(-d<omac/m)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <grk>do`mos</grk> house: cf. F.
<ets>lithodome</ets>.]</ety> <fld>(Zool.)</fld> <def>Any one of several
species of bivalves, which form holes in limestone, in which they live;
esp., any species of the genus <gen>Lithodomus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithodomous</ent><br/
<hw>Li*thod"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like, or pertaining to, Lithodomus; lithophagous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithodomus</ent><br/
\'d8<hw>Li*thod"o*mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Lithodome</er>.]</ety> <fld>(Zool.)</fld> <def>A genus of elongated
bivalve shells, allied to the mussels, and remarkable for their ability
to bore holes for shelter, in solid limestone, shells, etc. Called also
<altname>Lithophagus</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ These holes are at first very small and shallow, but are
enlarged with the growth of the shell, sometimes becoming two or three
inches deep and nearly an inch diameter.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithofellic</ent><br/
<hw>Lith"o*fel"lic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Litho-</ets> + L. <ets>fel</ets>, <ets>fellis</ets>,
gall.]</ety> <fld>(Physiol. Chem.)</fld> <def>Pertaining to, or
designating, a crystalline, organic acid, resembling cholic acid, found
in the biliary intestinal concretions (bezoar stones) common in certain
species of antelope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithofracteur</ent><br/
\'d8<hw>Lith`o*frac"teur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<grk>li`qos</grk> stone + L. <ets>frangere</ets>, <ets>fractum</ets>, to
break.]</ety> <def>An explosive compound of nitroglycerin. See
<er>Nitroglycerin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithogenesy</ent><br/
<hw>Lith`o*gen"e*sy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> Gr. <grk>ge`nesis</grk> origin, generation: cf.
F. <ets>lithog<eacute/n<eacute/sie</ets>. See <er>Genesis</er>.]</ety>
<def>The doctrine or science of the origin of the minerals composing the
globe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithogenous</ent><br/
<hw>li*thog"e*nous</hw> <pr>(l<icr/*th<ocr/j"<esl/*n<ucr/s)</pr>,
<pos>a.</pos> <ety>[<ets>Litho-</ets> + <ets>-genous</ets>.]</ety>
<def>Stone-producing; -- said of polyps which form coral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithoglyph</ent><br/
<hw>lith"o*glyph</hw> <pr>(l<icr/th"<osl/*gl<icr/f)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>liqoglyfi`a</grk>; <grk>li`qos</grk> stone +
<grk>gly`fein</grk> to engrave.]</ety> <def>An engraving on a
gem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithoglypher</ent><br/
<hw>li*thog"ly*pher</hw> <pr>(l<icr/*th<ocr/g"r<adot/*f<etil/r)</pr>,
<pos>n.</pos> <def>One who curs or engraves precious stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithoglyphic</ent><br/
<hw>lith`o*glyph"ic</hw> <pr>(l<icr/th`<osl/*gl<icr/f"<icr/k)</pr>,
<pos>a.</pos> <def>Of or pertaining to the art of cutting and engraving
precious stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithoglyptics</ent><br/
<hw>lith`o*glyp"tics</hw> <pr>(l<icr/th`<osl/*gl<icr/p"t<icr/ks)</pr>,
<pos>n.</pos> <def>The art of cutting and engraving gems.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithograph</ent><br/
<hw>lith"o*graph</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>lithographed</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>lithographing</conjf> <pr>(?)</pr>.]</vmorph>
<ety>[<ets>litho-</ets> + <ets>-graph</ets>: cf. F.
<ets>lithographier</ets>.]</ety> <def>To trace on stone by the process
of lithography so as to transfer the design to paper by printing;
<as>as, to <ex>lithograph</ex> a design; to <ex>lithograph</ex> a
painting. See <er>lithography</er>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithograph</ent><br/
<hw>lith"o*graph</hw>, <pos>n.</pos> <def>A print made by
lithography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithographer</ent><br/
<hw>li*thog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
lithographs; one who practices lithography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lithographical</ent><br/
<ent>lithographic</ent><br/
<mhw>{ <hw>lith`o*graph"ic</hw> <pr>(?)</pr>,
<hw>lith`o*graph"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Cf. F. <ets>lithographique</ets>.]</ety> <def>Of or pertaining to
lithography; made by lithography; <as>as, the <ex>lithographic</ex> art;
a <ex>lithographic</ex> picture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lithographic limestone</b></col> <fld>(Min.)</fld>, <cd>a
compact, fine-grained limestone, obtained largely from the Lias and
O<oum/lite, esp. of Bavaria, and extensively used in
lithography.</cd></cs></p>

<p>-- <wordforms><wf>Lith`o*graph"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithography</ent><br/
<hw>Li*thog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lithographie</ets>.]</ety> <sn>1.</sn> <def>The art or process of
putting designs or writing, with a greasy material, on stone, and of
producing printed impressions therefrom. The process depends, in the
main, upon the antipathy between grease and water, which prevents a
printing ink containing oil from adhering to wetted parts of the stone
not covered by the design. See <cref>Lithographic limestone</cref>,
under <er>Lithographic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a printing process for reproducing images, using any
flat surface, such as a metal plate, in a manner similar to
<er>lithography{1}</er>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>The process of producing patterns on semiconductor
crystals by exposing photosensitive coatings on a matrix, such as
silicon, to light patterns in the form desired for the circuit, and
subsequently treating (e.g., chemically) the patterns thus formed in
such a way as to create integrated semiconductor circuits with the
desired properties. This is the principle method (1990's) to create the
high-density integrated circuits used in the digital computers on which
you are reading this.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lithoidal</ent><br/
<ent>Lithoid</ent><br/
<mhw>{ <hw>Lith"oid</hw> <pr>(?)</pr> <hw>Li*thoid"al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[<ets>Litho-</ets> + <ets>-oid</ets>: cf. F.
<ets>litho<ium/de</ets>.]</ety> <def>Like a stone; having a stony
structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litholatry</ent><br/
<hw>Li*thol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <?/ worship.]</ety> <def>The worship of a
stone or stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithological</ent><br/
<ent>Lithologic</ent><br/
<mhw>{ <hw>Lith`o*log"ic</hw> <pr>(?)</pr>, <hw>Lith`o*log"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>lithologique</ets>.]</ety> <sn>1.</sn> <fld>(Geol.)</fld> <def>Of
or pertaining to the character of a rock, as derived from the nature and
mode of aggregation of its mineral contents.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to lithology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithologically</ent><br/
<hw>Lith`o*log"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>From a
lithological point of view; <as>as, to consider a stratum
<ex>lithologically</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithologist</ent><br/
<hw>Li*thol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
skilled in lithology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithology</ent><br/
<hw>Li*thol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>-logy</ets>: cf. F.
<ets>lithologie</ets>.]</ety> <sn>1.</sn> <def>The science which treats
of rocks, as regards their mineral constitution and classification, and
their mode of occurrence in nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A treatise on stones found in the
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithomancy</ent><br/
<hw>Lith"o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>-mancy</ets>: cf. F.
<ets>lithomancie</ets>.]</ety> <def>Divination by means of
stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithomarge</ent><br/
<hw>Lith"o*marge</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + L. <ets>marga</ets> marl.]</ety> <def>A clay
of a fine smooth texture, and very sectile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithonthryptic</ent><br/
<ent>Lithonthriptic</ent><br/
<mhw>{ <hw>Lith`on*thrip"tic</hw>, <hw>Lith`on*thryp"tic</hw> }</mhw>
<pr>(?)</pr>, <pos>a. & n.</pos> <ety>[<ets>Litho-</ets> + Gr. <?/ to
crush.]</ety> <def>Same as <er>Lithontriptic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithontriptic</ent><br/
<hw>Lith`on*trip"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>li`qos</grk>, acc. <?/, a stone + <?/ to rub, grind: cf. F.
<ets>lithontriptique</ets>.]</ety> <fld>(Med.)</fld> <def>Having the
quality of, or used for, dissolving or destroying stone in the bladder
or kidneys; <as>as, <ex>lithontriptic</ex> forc<eacute/ps</as>.</def> --
<def2><pos>n.</pos> <def>A lithontriptic remedy or agent, as distilled
water.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithontriptist</ent><br/
<hw>Lith"on*trip"tist</hw>, <pos>n.</pos> <def>Same as
<er>Lithotriptist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithontriptor</ent><br/
<hw>Lith"on*trip`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Surg.)</fld>
<def>See <er>Lithotriptor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophagous</ent><br/
<hw>Li*thoph"a*gous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Litho-</ets> + Gr. <?/ to eat.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>Eating or swallowing stones or gravel, as the
ostrich.</def> <sd>(b)</sd> <def>Eating or destroying stone; -- applied
to various animals which make burrows in stone, as many bivalve
mollusks, certain sponges, annelids, and sea urchins. See
<er>Lithodomus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophane</ent><br/
<hw>Lith"o*phane</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <grk>fai`nein</grk> to show,
reveal.]</ety> <def>Porcelain impressed with figures which are made
distinct by transmitted light, as in a lamp shade or when hung in a
window.</def> -- <wordforms><wf>Lith`o*phan"ic</wf> <pr>(#)</pr>,
<pos>a.</pos> -- <wf>Li*thoph"a*ny</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lithophosphor</ent><br/
<hw>Lith"o*phos`phor</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>phosphor</ets>.]</ety> <def>A stone that
becomes phosphoric by heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophosphoric</ent><br/
<hw>Lith`o*phos*phor"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to lithophosphor; becoming phosphoric by heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophotography</ent><br/
<hw>Lith`o*pho*tog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>photography</ets>.]</ety> <def>Same as
<er>Photolithography</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophyll</ent><br/
<hw>Lith"o*phyll</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>li`qos</grk> a stone + <?/ a leaf: cf. F.
<ets>lithophylle</ets>.]</ety> <def>A fossil leaf or impression of a
leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophyse</ent><br/
<hw>Lith"o*physe</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <?/ a flatus, air bubble.]</ety>
<fld>(Min.)</fld> <def>A spherulitic cavity often with concentric
chambers, observed in some volcanic rocks, as in rhyolitic lavas. It is
supposed to be produced by expanding gas, whence the name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophyte</ent><br/
<hw>Lith"o*phyte</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + Gr. <?/ plant: cf. F.
<ets>lithophyte</ets>.]</ety> <fld>(Zool.)</fld> <def>A hard, or stony,
plantlike organism, as the gorgonians, corals, and corallines, esp.
those gorgonians having a calcareous axis. All the lithophytes except
the corallines are animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophytic</ent><br/
<hw>Lith`o*phyt"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to lithophytes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithophytous</ent><br/
<hw>Li*thoph"y*tous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Lithophytic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithosian</ent><br/
<hw>Li*tho"sian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From NL.
<ets>Lithosia</ets>, the typical genus, fr. Gr. <grk>li`qos</grk> a
stone, a rock.]</ety> <fld>(Zool.)</fld> <def>Any one of various species
of moths belonging to the family <fam>Lithosid<ae/</fam>. Many of them
are beautifully colored.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithosphere</ent><br/
<hw>Lith"o*sphere</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>sphere</ets>.]</ety> <fld>(Phys.
Geog.)</fld> <sd>(a)</sd> <def>The solid earth as distinguished from its
fluid envelopes, the hydrosphere and atmosphere.</def> <sd>(b)</sd>
<def>The outer part of the solid earth, the portion undergoing change
through the gradual transfer of material by volcanic eruption, the
circulation of underground water, and the process of erosion and
deposition. It is, therefore, regarded as a third mobile envelope
comparable with the hydrosphere and atmosphere.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lithotint</ent><br/
<hw>Lith"o*tint</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Litho-</ets>
+ <ets>tint</ets>.]</ety> <sn>1.</sn> <def>A kind of lithography by
which the effect of a tinted drawing is produced, as if made with India
ink.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A picture produced by this process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotome</ent><br/
<hw>Lith"o*tome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ cutting
stones; <grk>li`qos</grk> stone + <?/ to cut: cf. F.
<ets>lithotome</ets>.]</ety> <sn>1.</sn> <def>A stone so formed by
nature as to appear as if cut by art.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surg.)</fld> <def>An instrument used for cutting
the bladder in operations for the stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotomical</ent><br/
<ent>Lithotomic</ent><br/
<mhw>{ <hw>Lith`o*tom"ic</hw> <pr>(?)</pr>, <hw>Lith`o*tom"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <grk>li`qos</grk> stone
cutting: cf. F. <ets>lithotomique</ets>.]</ety> <def>Pertaining to, or
performed by, lithotomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotomist</ent><br/
<hw>Li*thot"o*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lithotomiste</ets>.]</ety> <def>One who performs the operation of
cutting for stone in the bladder, or one who is skilled in the
operation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotomy</ent><br/
<hw>Li*thot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lithotomia</ets>, Gr. <?/: cf. F. <ets>lithotomie</ets>.]</ety>
<fld>(Surg.)</fld> <def>The operation, art, or practice of cutting for
stone in the bladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotripsy</ent><br/
<hw>Lith"o*trip`sy</hw> <pr>(l<icr/th"<osl/*tr<icr/p`s<ycr/)</pr>,
<pos>n.</pos> <ety>[<ets>Litho-</ets> + Gr. <grk>tri`bein</grk> to rub,
grind: cf. F. <ets>lithotripsie</ets>.]</ety> <fld>(Surg.)</fld>
<def>The operation of crushing a stone in the bladder or urethra to
reduce it to particles small enough to be voided; lithotrity. It may be
performed with an instrument called <xex>lithotriptor</xex> or
<xex>lithotrite</xex> (also called a lithoclast); or, more recently, may
be accomplished by devices using ultrasonic waves to fragment the
stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotriptic</ent><br/
<hw>Lith`o*trip"tic</hw> <pr>(l<icr/th`<osl/*tr<icr/p"t<icr/k)</pr>,
<pos>a. & n.</pos> <def>Same as <er>Lithontriptic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotriptist</ent><br/
<hw>Lith"o*trip`tist</hw> <pr>(l<icr/th"<osl/*tr<icr/p`t<icr/st)</pr>,
<pos>n.</pos> <def>One skilled in breaking and extracting stone in the
bladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotriptor</ent><br/
<hw>Lith"o*trip`tor</hw> <pr>(l<icr/th"<osl/*tr<icr/p`t<etil/r)</pr>,
<pos>n.</pos> <fld>(Surg.)</fld> <def>An instrument for triturating the
stone in the bladder; a lithotrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotritor</ent><br/
<ent>Lithotrite</ent><br/
<mhw>{ <hw>Lith"o*trite</hw> <pr>(?)</pr>, <hw>Lith"o*tri"tor</hw>
<pr>(?)</pr>, }</mhw> <ety>[See <er>Lithotrity</er>.]</ety>
<fld>(Surg.)</fld> <def>A lithotriptor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotritist</ent><br/
<hw>Li*thot"ri*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
lithotriptist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotrity</ent><br/
<hw>Li*thot"ri*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + L. <ets>terere</ets>, <ets>tritum</ets>, to
rub, grind.]</ety> <fld>(Surg.)</fld> <def>The operation of breaking a
stone in the bladder or urethrea into small pieces capable of being
voided; lithotripsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotype</ent><br/
<hw>Lith"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
etched stone surface for printing, having the design in relief; also,
the process of printing from such a surface, or that which is printed
from it.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A machine, with a keyboard like that of a
typewriter, for making a lithographic transfer sheet. It produces a
perforated strip of paper which controls the printing.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lithotype</ent><br/
<hw>Lith"o*type</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lithotyped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lithotyping</conjf> <pr>(?)</pr>.]</vmorph> <def>To prepare for
printing with plates made by the process of lithotypy. See
<er>Lithotypy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotypic</ent><br/
<hw>Lith`o*typ"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of, pertaining
to, or produced by, lithotypy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithotypy</ent><br/
<hw>Li*thot"y*py</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Litho-</ets> + <ets>-typy</ets>.]</ety> <def>The art or
process of making a kind of hard, stereotype plate, by pressing into a
mold, taken from a page of type or other matter, a composition of gum
shellac and sand of a fine quality, together with a little tar and
linseed oil, all in a heated state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithoxyl</ent><br/
<hw>Li*thox`yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>lithoxyle</ets>.]</ety> <ety>[<ets>Litho-</ets> + Gr. <?/ wood: cf.
F. <ets>lithoxyle</ets>.]</ety> <def>Petrified wood.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithuanian</ent><br/
<hw>Lith`u*a"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to Lithuania (formerly a principality united with Poland,
then part of the Soviet Union, but since 1992 an independent
nation).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithuanian</ent><br/
<hw>Lith`u*a"ni*an</hw>, <pos>n.</pos> <def>A native, or one of the
people, of Lithuania; also, the language of the Lithuanian
people.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lithy</ent><br/
<hw>Lith"y</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[See
<er>Lithe</er>.]</ety> <def>Easily bent; pliable.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lithy tree</b></col> <fld>(Bot.)</fld>, <cd>a European
shrub (<spn>Viburnum Lantana</spn>); -- so named from its tough and
flexible stem.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigable</ent><br/
<hw>Lit"i*ga*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
litigated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigant</ent><br/
<hw>Lit"i*gant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>litigans</ets>, <ets>-antis</ets>, p. pr. of <ets>litigare</ets>:
cf. F. <ets>litigant</ets>. See <er>Litigate</er>.]</ety> <def>Disposed
to litigate; contending in law; engaged in a lawsuit; <as>as, the
parties <ex>litigant</ex></as>.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigant</ent><br/
<hw>Lit"i*gant</hw>, <pos>n.</pos> <def>A person engaged in a
lawsuit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigate</ent><br/
<hw>Lit"i*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Litigated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Litigating</conjf>.]</vmorph> <ety>[See
<er>Litigation</er>.]</ety> <def>To make the subject of a lawsuit; to
contest in law; to prosecute or defend by pleadings, exhibition of
evidence, and judicial debate in a court; <as>as, to <ex>litigate</ex> a
cause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigate</ent><br/
<hw>Lit"i*gate</hw>, <pos>v. i.</pos> <def>To carry on a suit by
judicial process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigation</ent><br/
<hw>Lit`i*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>litigatio</ets>, fr. <ets>litigare</ets> to dispute, litigate;
<ets>lis</ets>, <ets>litis</ets>, dispute, lawsuit (OL.
<ets>stlis</ets>) + <ets>agere</ets> to carry on. See
<er>Agent</er>.]</ety> <def>The act or process of litigating; a suit at
law; a judicial contest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>litigatious</ent><br/
<hw>litigatious</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining
to litigation.</def><br/
<syn><b>Syn. --</b> litiginous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>prone to initiate litigation.</def><br/
<syn><b>Syn. --</b> litiginous.</syn><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>same as <er>contentious</er>.</def><br/
<syn><b>Syn. --</b> litigatious, litiginous, contentious, disputatious;
quarrelsome; argumentative.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Litigator</ent><br/
<hw>Lit"i*ga`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who litigates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>litiginous</ent><br/
<hw>litiginous</hw> <pos>adj.</pos> <def>same as
<er>litigatious</er>.</def><br/
<syn><b>Syn. --</b> litigatious.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Litigious</ent><br/
<hw>Li*ti"gious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>litigiosus</ets>, fr. <ets>litigium</ets> dispute, quarrel, fr.
<ets>litigare</ets>: cf. F. <ets>litigieux</ets>. See
<er>Litigation</er>.]</ety> <sn>1.</sn> <def>Inclined to initiate
lawsuits; given to the practice of contending in law; fond of
litigation.</def> <ldquo/ A pettifogging attorney or a
<xex>litigious</xex> client.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Soldiers find wars, and lawyers find out still<br/
<qex>Litigious</qex> men, who quarrels move.</q>
<rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Quarrelsome; contentious;
argumentative.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Subject to contention; disputable; controvertible;
debatable; doubtful; precarious.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No fences, parted fields, nor marks, nor bounds,<br/
Distinguished acres of <qex>litigious</qex> grounds.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of or pertaining to legal disputes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor brothers cite to the <qex>litigious</qex> bar.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigiously</ent><br/
<hw>Li*ti"gious*ly</hw>, <pos>adv.</pos> <def>In a litigious
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litigiousness</ent><br/
<hw>Li*ti"gious*ness</hw>, <pos>n.</pos> <def>The state of being
litigious; disposition to engage in or carry on lawsuits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litmus</ent><br/
<hw>Lit"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>lakmoes</ets>; <ets>lak</ets> lacker + <ets>moes</ets> a thick
preparation of fruit, pap, prob. akin to E. <ets>meat</ets>: cf. G.
<ets>lackmus</ets>. See <er>Lac</er> a resinous substance.]</ety>
<fld>(Chem.)</fld> <def>A dyestuff extracted from certain lichens
(<spn>Roccella tinctoria</spn>, <spn>Lecanora tartarea</spn>, etc.), as
a blue amorphous mass which consists of a compound of the alkaline
carbonates with certain coloring matters related to orcin and
orcein.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Litmus is used as a dye, and being turned red by acids
and restored to its blue color by alkalies, is a common indicator or
test for acidity and alkalinity.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Litmus paper</b></col> <fld>(Chem.)</fld>, <cd>unsized
paper saturated with blue or red litmus, -- used in testing for acids or
alkalies.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>litmus test</ent><br/
<hw>litmus test</hw>, <sn>1.</sn> <fld>(Chem.)</fld> <def>A test to
determine acidity or alkalinity, using litmus as an
inddicator.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>(Fig.)</mark> <def>A test
for a single factor, which has only two outcomes, positive or
negative;</def> <specif>specifically:</specif> <fld>(Politics)</fld>
<def>the question of whether a candidate for office is for or against a
particular position on an issue; -- used, e.g. by voters concerned
predominantly with a single issue, to decide whether to vote for or
against a candidate; <as>as, many voters take a candidate's position on
abortion as their <ex>litmus test</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Litocranius</ent><br/
<hw>Litocranius</hw> <pos>n.</pos> <def>A genus of East African
antelopes including the gerenuks.</def><br/
<syn><b>Syn. --</b> genus <gen>Litocranius</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>litoral</ent><br/
<hw>litoral</hw> <pos>n.</pos> <def>See <er>Littoral</er>.</def><br/
<syn><b>Syn. --</b> littoral, littoral zone, sands.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Litotes</ent><br/
\'d8<hw>Li"to*tes</hw> <pr>(l<imac/"t<osl/*t<emac/z)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>lito`ths</grk>, from <grk>lito`s</grk> plain,
simple.]</ety> <fld>(Rhet.)</fld> <def>A diminution or softening of
statement for the sake of avoiding censure or increasing the effect by
contrast with the moderation shown in the form of expression; a form of
<isa>understatement</isa>; <as>as, <ldquo/ a citizen of no mean
city,<rdquo/ that is, of an illustrious city; or, <ldquo/not bad<rdquo/,
meaning <ldquo/good<rdquo/</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Litraneter</ent><br/
<hw>Li*tran"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>li`tra</grk> + <ets>-meter</ets>. See <er>Liter</er>]</ety> <def>An
instrument for ascertaining the specific gravity of liquids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litre</ent><br/
<hw>Li"tre</hw> <pr>(l<emac/"t<etil/r; 277)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>Same as <er>Liter</er>.</def> <mark>[Chiefly
Brit.]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Litter</ent><br/
<hw>Lit"ter</hw> <pr>(l<icr/t"t<etil/r)</pr>, <pos>n.</pos> <ety>[F.
<ets>liti<egrave/re</ets>, LL. <ets>lectaria</ets>, fr. L.
<ets>lectus</ets> couch, bed. See <er>Lie</er> to be prostrated, and cf.
<er>Coverlet</er>.]</ety> <sn>1.</sn> <def>A bed or stretcher so
arranged that a person, esp. a sick or wounded person, may be easily
carried in or upon it.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a <qex>litter</qex> ready; lay him in 't.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Straw, hay, etc., scattered on a floor, as bedding
for animals to rest on; also, a covering of straw for plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To crouch in <qex>litter</qex> of your stable planks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Take off the <qex>litter</qex> from your kernel beds.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Things lying scattered about in a manner indicating
slovenliness; scattered rubbish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Strephon, who found the room was void.<br/
Stole in, and took a strict survey<br/
Of all the <qex>litter</qex> as it lay.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Disorder or untidiness resulting from scattered
rubbish, or from thongs lying about uncared for; <as>as, a room in a
state of <ex>litter</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The young brought forth at one time, by a cat, dog,
sow or other multiparous animal, taken collectively. Also Fig.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A wolf came to a sow, and very kindly offered to take care of her
<qex>litter</qex>.</q> <rj><qau>D. Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Reflect upon that numerous <qex>litter</qex> of strange, senseless
opinions that crawl about the world.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litter</ent><br/
<hw>Lit"ter</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Littered</conjf> <pr>(l<icr/t"t<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Littering</conjf>.]</vmorph> <sn>1.</sn> <def>To supply
with litter, as cattle; to cover with litter, as the floor of a
stall.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tell them how they <qex>litter</qex> their jades.</q> <rj><qau>Bp.
Hackett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For his ease, well <qex>littered</qex> was the floor.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put into a confused or disordered condition; to
strew with scattered articles; <as>as, to <ex>litter</ex> a
room</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The room with volumes <qex>littered</qex> round.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give birth to; to bear; -- said of brutes, esp.
those which produce more than one at a birth, and also of human beings,
in abhorrence or contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We might conceive that dogs were created blind, because we observe
they were <qex>littered</qex> so with us.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The son that she did <qex>litter</qex> here,<br/
A freckled whelp hagborn.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 861 --></p>

<p><ent>Litter</ent><br/
<hw>Lit"ter</hw> <pr>(l<icr/t"t<etil/r)</pr>, <pos>v. i.</pos>
<sn>1.</sn> <def>To be supplied with litter as bedding; to sleep or make
one's bed in litter.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The inn<br/
Where he and his horse <qex>littered</qex>.</q>
<rj><qau>Habington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To produce a litter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A desert . . . where the she-wolf still <qex>littered</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Litterateur</ent><br/
\'d8<hw>Lit`te`ra`teur"</hw> <pr>(l<esl/`t<asl/`r<adot/`t<etil/r")</pr>,
<pos>n.</pos> <ety>[F.]</ety> <def>One who occupies himself with
literature; a literary man; a literatus.</def> <ldquo/ Befriended by one
kind-hearted <xex>litt<eacute/rateur</xex> after another.<rdquo/
<rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>litter-bearer</ent><br/
<hw>litter-bearer</hw> <pos>n.</pos> <def>one who helps carry a
stretcher.</def><br/
<syn><b>Syn. --</b> stretcher-bearer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>litterbin</ent><br/
<hw>lit"ter*bin`</hw> <pr>(l<icr/t"t<etil/r*b<icr/n`)</pr>,
<pos>n.</pos> <def>a bin (usually in or outside a public building) into
which the public can put rubbish.</def><br/
<syn><b>Syn. --</b> litterbasket.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>litterbug</ent><br/
<hw>lit"ter*bug`</hw> <pr>(l<icr/t"t<etil/r*b<ucr/g)</pr>, <pos>n.</pos>
<def>a person who litters public places with refuse.</def><br/
<syn><b>Syn. --</b> litterer, litter lout.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>littered</ent><br/
<hw>lit"tered</hw> <pr>(l<icr/t"t<etil/rd)</pr>, <pos>adj.</pos>
<def>having articles scattered about in a disorderly fashion.</def><br/
<syn><b>Syn. --</b> cluttered, messy, mussy, untidy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>litterer</ent><br/
<hw>lit"ter*er</hw> <pr>(l<icr/t"t<etil/r*<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>a person who litters public places with
refuse.</def><br/
<syn><b>Syn. --</b> litterbug, litter lout.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>littermate</ent><br/
<hw>lit"ter*mate`</hw> <pr>(l<icr/t"t<etil/r*m<amac/t`)</pr>,
<pos>n.</pos> <def>One of two or more animals born into the same
litter.</def><br/
[<source>PJC</source>]</p>

<p><ent>Littery</ent><br/
<hw>Lit"ter*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered or
encumbered with litter; consisting of or constituting litter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Little</ent><br/
<hw>Lit"tle</hw> <pr>(l<icr/t"t'l)</pr>, <pos>a.</pos> <amorph>[The
regular comparative and superlative of this word, <it>littler</it> and
<it>littlest</it>, are often used as comparatives of the sense
<it>small</it>; but in the sense <it>few</it>, <it>less</it>, or,
rarely, <it>lesser</it> is the proper comparative and <it>least</it> is
the superlative. See <er>Lesser</er>. The regular form,
<it>littlest</it>, occurs also in some of the English provinces, and
occasionally in colloquial language. <ldquo/ Where love is great, the
<qex>littlest</qex> doubts are fear.<rdquo/ <au>Shak.</au>]</amorph>
<ety>[OE. <ets>litel</ets>, <ets>lutel</ets>, AS. <ets>l<ymac/tel</ets>,
<ets>l<imac/tel</ets>, <ets>l<ymac/t</ets>; akin to OS.
<ets>littil</ets>, D. <ets>luttel</ets>, LG. <ets>l<uum/tt</ets>, OHG.
<ets>luzzil</ets>, MHG. <ets>l<uum/tzel</ets>; and perh. to AS.
<ets>lytig</ets> deceitful, <ets>lot</ets> deceit, Goth.
<ets>liuts</ets> deceitful, <ets>lut<omac/n</ets> to deceive; cf. also
Icel. <ets>l<imac/till</ets> little, Sw. <ets>liten</ets>, Dan.
<ets>liden</ets>, <ets>lille</ets>, Goth. <ets>leitils</ets>, which
appear to have a different root vowel.]</ety> <sn>1.</sn> <def>Small in
size or extent; not big; diminutive; -- opposed to <ant>big</ant> or
<ant>large</ant>; <as>as, a <ex>little</ex> body; a <ex>little</ex>
animal; a <ex>little</ex> piece of ground; a <ex>little</ex> hill; a
<ex>little</ex> distance; a <ex>little</ex> child.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He sought to see Jesus who he was; and could not for the press,
because he was <qex>little</qex> of stature.</q> <rj><qau>Luke xix.
3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Short in duration; brief; <as>as, a <ex>little</ex>
sleep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Best him enough: after a <qex>little</qex> time,<br/
I'll beat him too.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Small in quantity or amount; not much; <as>as, a
<ex>little</ex> food; a <ex>little</ex> air or water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Conceited of their <qex>little</qex> wisdoms, and doting upon
their own fancies.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Small in dignity, power, or importance; not great;
insignificant; contemptible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When thou wast <qex>little</qex> in thine own sight, wast thou not
made the head of the tribes?</q> <rj><qau>I Sam. xv. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Small in force or efficiency; not strong; weak;
slight; inconsiderable; <as>as, <ex>little</ex> attention or
exertion;<ex>little</ex> effort; <ex>little</ex> care or
diligence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>By sad experiment I know<br/
How <qex>little</qex> weight my words with thee can find.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Small in extent of views or sympathies; narrow;
shallow; contracted; mean; illiberal; ungenerous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The long-necked geese of the world that are ever hissing
dispraise,<br/
Because their natures are <qex>little</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Little chief</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Chief hare</er>.</cd> -- <col><b>Little Englander</b></col>, <cd>an
Englishman opposed to territorial expansion of the British Empire. See
<er>Antiimperialism</er>, above.</cd> Hence: <col><b>Little
Englandism</b></col>. -- <col><b>Little finger</b></col>, <cd>the fourth
and smallest finger of the hand.</cd> -- <col><b>Little go</b></col>
<fld>(Eng. Universities)</fld>, <cd>a public examination about the
middle of the course, which is less strict and important than the final
one; -- called also <altname>smalls</altname>. Cf. <cref>Great
go</cref>, under <er>Great</er>.</cd> <au>Thackeray.</au> --
<col><b>Little hours</b></col> <fld>(R. C. Ch.)</fld>, <cd>the offices
of prime, tierce, sext, and nones. Vespers and compline are sometimes
included.</cd> -- <mcol><col><b>Little-neck clam</b></col>, <it>or</it>
<col><b>Little neck</b></col></mcol> <fld>(Zool.)</fld>, <cd>the quahog,
or round clam.</cd> -- <col><b>Little ones</b></col>, <cd>young
children.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>The men, and the women, and the <qex>little ones</qex>.</q>
<rj><qau>Deut. ii. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Little peach</b></col>, <cd>a disease of peaches in which
the fruit is much dwarfed, and the leaves grow small and thin. The cause
is not known.</cd> -- <col><b>Little Rhod"y</b></col> <pr>(<?/)</pr>,
<cd>Rhode Island; -- a nickname alluding to its small size. It is the
smallest State of the United States.</cd> -- <col><b>Little Sisters of
the Poor</b></col> <fld>(R. C. Ch.)</fld>, <cd>an order of women who
care for old men and women and infirm poor, for whom special houses are
built. It was established at St. Servan, Britany, France, in 1840, by
the <person>Abb<eacute/ Le Pailleur</person>.</cd> -- <col><b>Little
slam</b></col> <fld>(Bridge Whist)</fld>, <cd>the winning of 12 out of
the 13 tricks. It counts 20 points on the honor score. Contrasted with
<contr>grand slam</contr>.</cd><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Little</ent><br/
<hw>Lit"tle</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is little; a
small quantity, amount, space, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Much was in <qex>little</qex> writ.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There are many expressions, which carrying with them no clear
ideas, are like to remove but <qex>little</qex> of my ignorance.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small degree or scale; miniature.</def> <ldquo/
His picture in <xex>little</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A little, to or in a small degree; to a limited extent; somewhat;
for a short time. <ldquo/ Stay a <qex>little</qex>.<rdquo/</q>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The painter flattered her a <qex>little</qex>.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <mcol><col><b>By little and little</b></col>, <it>or</it>
<col><b>Little by little</b></col></mcol>, <cd>by slow degrees;
piecemeal; gradually.</cd><br/
[<source>1913 Webster</source>]</p>

<p><ent>Little</ent><br/
<hw>Lit"tle</hw>, <pos>adv.</pos> <def>In a small quantity or degree;
not much; slightly; somewhat; -- often with a preceding it.</def>
<ldquo/ The poor sleep <xex>little</xex>.<rdquo/
<rj><au>Otway.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Little-ease</ent><br/
<hw>Lit"tle-ease`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An old slang
name for the pillory, stocks, etc., of a prison.</def>
<mark>[Eng.]</mark> <rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>littleneck</ent><br/
<hw>littleneck</hw> <pos>n.</pos> <sn>1.</sn> <def>a quahog when young
and small; frequently eaten raw.</def><br/
<syn><b>Syn. --</b> littleneck clam.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a young quahog suitable to be eaten raw.</def><br/
<syn><b>Syn. --</b> littleneck clam.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Littleness</ent><br/
<hw>Lit"tle*ness</hw>, <pos>n.</pos> <def>The state or quality of being
little; <as>as, <ex>littleness</ex> of size, thought, duration, power,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Smallness; slightness; inconsiderableness;
narrowness; insignificance; meanness; penuriousness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>littler</ent><br/
<hw>littler</hw> <pos>adj.</pos> <ety>[<pos>compar.</pos> of
<er>little</er>.]</ety> <def>small or little relative to something
else.</def><br/
<syn><b>Syn. --</b> smaller.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>littlest</ent><br/
<hw>littlest</hw> <pos>adj.</pos> <ety>[<pos>superl.</pos> of
<er>little</er>.]</ety> <def>having or being distinguished by diminutive
size.</def><br/
<syn><b>Syn. --</b> least, smallest.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Littoral</ent><br/
<hw>Lit"to*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>littoralis</ets>, <ets>litoralis</ets>, from <ets>littus</ets>,
<ets>litus</ets>, the seashore: cf. F. <ets>littoral</ets>.]</ety>
<sn>1.</sn> <def>Of or pertaining to a shore, as of the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Inhabiting the seashore, esp. the
zone between high-water and low-water mark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Littorina</ent><br/
\'d8<hw>Lit"to*ri"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Littoral</er>.]</ety> <fld>(Zool.)</fld> <def>A genus of small
pectinibranch mollusks, having thick spiral shells, abundant between
tides on nearly all rocky seacoasts. They feed on seaweeds. The common
periwinkle is a well-known example. See <er>Periwinkle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Littress</ent><br/
<hw>Lit"tress</hw> <pr>(l<icr/t"tr<ecr/s)</pr>, <pos>n.</pos> <def>A
smooth kind of cartridge paper used for making cards.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lituate</ent><br/
<hw>Lit"u*ate</hw> <pr>(l<icr/t"u*<asl/t; 135)</pr>, <pos>a.</pos>
<ety>[See <er>Lituus</er>.]</ety> <fld>(Bot.)</fld> <def>Forked, with
the points slightly curved outward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lituiform</ent><br/
<hw>Lit"u*i*form</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lituus</ets> + <ets>-form</ets>.]</ety> <def>Having the form
of a lituus; like a lituite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lituite</ent><br/
<hw>Lit"u*ite</hw> <pr>(l<icr/t"u*<isl/t; 135)</pr>, <pos>n.</pos>
<ety>[See <er>Lituus</er>.]</ety> <fld>(Paleon.)</fld> <def>Any species
of ammonites of the genus <gen>Lituites</gen>. They are found in the
Cretaceous formation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturate</ent><br/
<hw>Lit"u*rate</hw> <pr>(l<icr/t"u*r<asl/t)</pr>, <pos>a.</pos> <ety>[L.
<ets>lituratus</ets>, p. p. of <ets>liturare</ets> to erase, fr.
<ets>litura</ets> a blur.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>Having indistinct spots, paler at their margins.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Spotted, as if from abrasions of
the surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgical</ent><br/
<ent>Liturgic</ent><br/
<mhw>{ <hw>Li*tur"gic</hw> <pr>(?)</pr>, <hw>Li*tur"gic*al</hw>
<pr>(?)</pr>, }</mhw> <ety>[Gr. <?/: cf. F.
<ets>liturgique</ets>.]</ety> <def>Pertaining to, of or the nature of, a
liturgy; of or pertaining to public prayer and worship.</def> <rj><au>T.
Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgically</ent><br/
<hw>Li*tur"gic*al*ly</hw>, <pos>adv.</pos> <def>In the manner of a
liturgy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgics</ent><br/
<hw>Li*tur"gics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The science of
worship; history, doctrine, and interpretation of liturgies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgiologist</ent><br/
<hw>Li*tur`gi*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed
in liturgiology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgiology</ent><br/
<hw>Li*tur`gi*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Liturgy</ets> + <ets>-logy</ets>.]</ety> <def>The science
treating of liturgical matters; a treatise on, or description of,
liturgies.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgist</ent><br/
<hw>Lit"ur*gist</hw> <pr>(l<icr/t"<ucr/r*j<icr/st)</pr>, <pos>n.</pos>
<def>One who favors or adheres strictly to a liturgy.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liturgy</ent><br/
<hw>Lit"ur*gy</hw> <pr>(l<icr/t"<ucr/r*j<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Liturgies</plw>
<pr>(l<icr/t"<ucr/r*j<icr/z)</pr>.</plu> <ety>[F. <ets>liturgie</ets>,
LL. <ets>liturgia</ets>, Gr. <grk>leitoyrgi`a</grk> a public service,
the public service of God, public worship; (assumed)
<grk>le`i:tos</grk>, <grk>lei^tos</grk>, belonging to the people, public
(fr. <grk>lao`s</grk>, <grk>lew`s</grk>, the people) + the root of
<grk>'e`rgon</grk> work. See <er>Lay</er>, <pos>a.</pos>, and
<er>Work</er>.]</ety> <def>An established formula for public worship, or
the entire ritual for public worship in a church which uses prescribed
forms; a formulary for public prayer or devotion. In the Roman Catholic
Church it includes all forms and services in any language, in any part
of the world, for the celebration of Mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lituus</ent><br/
\'d8<hw>Lit"u*us</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Litui</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <sn>1.</sn>
<fld>(Rom. Antig.)</fld> <sd>(a)</sd> <def>A curved staff used by the
augurs in quartering the heavens.</def> <sd>(b)</sd> <def>An instrument
of martial music; a kind of trumpet of a somewhat curved form and shrill
note.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>A spiral whose polar equation is
<mathex>r<exp>2</exp><theta/ = a</mathex>; that is, a curve the square
of whose radius vector varies inversely as the angle which the radius
vector makes with a given line.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livable</ent><br/
<hw>Liv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Such as
can be lived.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Such as is pleasant to live in; fit or suitable to
live in.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A more delightful or <qex>livable</qex> region is not easily to be
found.</q> <rj><qau>T. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Live</ent><br/
<hw>Live</hw> <pr>(l<icr/v)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lived</conjf> <pr>(l<icr/vd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Living</conjf>.]</vmorph> <ety>[OE. <ets>liven</ets>,
<ets>livien</ets>, AS. <ets>libban</ets>, <ets>lifian</ets>; akin to OS.
<ets>libbian</ets>, D. <ets>leven</ets>, G. <ets>leben</ets>, OHG.
<ets>leb<emac/n</ets>, Dan. <ets>leve</ets>, Sw. <ets>lefva</ets>, Icel.
<ets>lifa</ets> to live, to be left, to remain, Goth. <ets>liban</ets>
to live; akin to E. <ets>leave</ets> to forsake, and <ets>life</ets>,
Gr. <grk>liparei^n</grk> to persist, <grk>liparo`s</grk> oily, shining,
sleek, <grk>li`pos</grk> fat, lard, Skr. <ets>lip</ets> to anoint,
smear; -- the first sense prob. was, to cleave to, stick to; hence, to
remain, stay; and hence, to live.]</ety> <sn>1.</sn> <def>To be alive;
to have life; to have, as an animal or a plant, the capacity of
assimilating matter as food, and to be dependent on such assimilation
for a continuance of existence; <as>as, animals and plants that
<ex>live</ex> to a great age are long in reaching
maturity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus saith the Lord God unto these bones; Behold, I will . . . lay
sinews upon you, and will bring up flesh upon you, and cover you with
skin, and put breath in you, and ye shall <qex>live</qex>.</q>
<rj><qau>Ezek. xxxvii. 5, 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pass one's time; to pass life or time in a
certain manner, as to habits, conduct, or circumstances; <as>as, to
<ex>live</ex> in ease or affluence; to <ex>live</ex> happily or
usefully.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>O death, how bitter is the remembrance of thee to a man that
<qex>liveth</qex> at rest in his possessions!</q> <rj><qau>Ecclus. xli.
1. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make one's abiding place or home; to abide; to
dwell; to reside; <as>as, to <ex>live</ex> in a cottage by the
sea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jacob <qex>lived</qex> in the land of Egypt seventeen years.</q>
<rj><qau>Gen. xlvii. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be or continue in existence; to exist; to remain;
to be permanent; to last; -- said of inanimate objects, ideas,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men's evil manners <qex>live</qex> in brass; their virtues<br/
We write in water.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To enjoy or make the most of life; to be in a state
of happiness; <as>as, people want not just to exist, but to
<ex>live</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What greater curse could envious fortune give<br/
Than just to die when I began to <qex>live</qex>?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To feed; to subsist; to be nourished or supported;
-- with <xex>on</xex>; <as>as, horses <ex>live</ex> on grass and
grain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To have a spiritual existence; to be quickened,
nourished, and actuated by divine influence or faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The just shall <qex>live</qex> by faith.</q> <rj><qau>Gal. iii.
ll.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To be maintained in life; to acquire a livelihood;
to subsist; -- with <xex>on</xex> or <xex>by</xex>; <as>as, to
<ex>live</ex> on spoils</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those who <qex>live</qex> by labor.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To outlast danger; to float; -- said of a ship,
boat, etc.; <as>as, no ship could <ex>live</ex> in such a
storm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A strong mast that <qex>lived</qex> upon the sea.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To live out</b></col>, <cd>to be at service; to live away
from home as a servant.</cd> <mark>[U. S.]</mark> -- <col><b>To live
with</b></col>. <sd>(a)</sd> <cd>To dwell or to be a lodger with.</cd>
<sd>(b)</sd> <cd>To cohabit with; to have intercourse with, as male with
female.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Live</ent><br/
<hw>Live</hw> <pr>(l<icr/v)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
spend, as one's life; to pass; to maintain; to continue in, constantly
or habitually; <as>as, to <ex>live</ex> an idle or a useful
life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act habitually in conformity with; to
practice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>live</qex> the Gospel.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To live down</b></col>, <cd>to live so as to subdue or
refute; as, <xex>to live down</xex> slander.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Live</ent><br/
<hw>Live</hw> <pr>(l<imac/v)</pr>, <pos>a.</pos> <ety>[Abbreviated from
<ets>alive</ets>. See <er>Alive</er>, <er>Life</er>.]</ety> <sn>1.</sn>
<def>Having life; alive; living; not dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If one man's ox hurt another's, that he die; then they shall sell
the <qex>live</qex> ox, and divide the money of it.</q> <rj><qau>Ex.
xxi. 35.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Being in a state of ignition; burning; having active
properties; <as>as, a <ex>live</ex> coal; <ex>live</ex>
embers.</as></def> <ldquo/ The <xex>live</xex> ether.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Full of earnestness; active; wide awake; glowing;
<as>as, a <ex>live</ex> man, or orator</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Vivid; bright.</def> <ldquo/ The <xex>live</xex>
carnation.<rdquo/ <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Engin.)</fld> <def>Imparting power; having motion;
<as>as, the <ex>live</ex> spindle of a lathe; <ex>live</ex>
steam</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Elec.)</fld> <def>Connected to a voltage source;
<as>as, a <ex>live</ex> wire</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <fld>(Broadcasting)</fld> <def>Being transmitted
instantaneously, as events occur, in contrast to
<contr>recorded</contr>.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <fld>(Sport)</fld> <def>Still in active play; -- of a
ball being used in a game; <as>as, a <ex>live</ex> ball</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <def>Pertaining to an entertainment event which was
performed (and possibly recorded) in front of an audience; contrasted to
performances recorded in a studio without an audience.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Live birth</b></col>, <cd>the condition of being born in
such a state that acts of life are manifested after the extrusion of the
whole body.</cd> <au>Dunglison.</au> -- <col><b>Live box</b></col>,
<cd>a cell for holding living objects under microscopical
examination.</cd> <au>P. H. Gosse.</au> -- <col><b>Live
feathers</b></col>, <cd>feathers which have been plucked from the living
bird, and are therefore stronger and more elastic.</cd> -- <col><b>Live
gang</b></col>. <fld>(Sawing)</fld> <cd>See under <er>Gang</er>.</cd> --
<col><b>Live grass</b></col> <fld>(Bot.)</fld>, <cd>a grass of the genus
<gen>Eragrostis</gen>.</cd> -- <col><b>Live load</b></col>
<fld>(Engin.)</fld>, <cd>a suddenly applied load; a varying load; a
moving load; as a moving train of cars on a bridge, or wind pressure on
a roof.</cd> <col><b>Live oak</b></col> <fld>(Bot.)</fld>, <cd>a species
of oak (<spn>Quercus virens</spn>), growing in the Southern States, of
great durability, and highly esteemed for ship timber. In California the
<spn>Quercus chrysolepis</spn> and some other species are also called
<ex>live oaks</ex>.</cd> -- <col><b>Live ring</b></col>
<fld>(Engin.)</fld>, <cd>a circular train of rollers upon which a swing
bridge, or turntable, rests, and which travels around a circular track
when the bridge or table turns.</cd> -- <col><b>Live steam</b></col> ,
<cd>steam direct from the boiler, used for any purpose, in distinction
from <contr>exhaust steam</contr>.</cd> -- <col><b>Live stock</b></col>,
<cd>horses, cattle, and other domestic animals kept on a farm. whole
body.</cd> -- <col><b>live wire</b></col> <sd>(a)</sd>
<fld>(Elec.)</fld> <cd>a wire connected to a power source, having a
voltage potential; -- used esp. of a power line with a high potential
relative to ground, capable of harming a person who touches it.</cd>
<sd>(b)</sd> <mark>(Fig.)</mark> <cd>a person who is unusually active,
alert, or aggressive.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Live</ent><br/
<hw>Live</hw> <pr>(l<imac/v)</pr>, <pos>n.</pos> <def>Life.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>On live</b></col>, <cd>in life; alive.</cd>
<mark>[Obs.]</mark> <see>See <er>Alive</er>.</see>
<rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>liveable</ent><br/
<hw>liveable</hw> <pos>a.</pos> <def>Same as <er>livable</er>; <as>as,
<ex>liveable</ex> conditions</as>. Opposite of
<ant>unlivable</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>live-bearer</ent><br/
<hw>live-bearer</hw> <pos>n.</pos> <def>Any fish of the family
<fam>Poeciliiidae</fam>, small usually brightly-colored viviparous
surface-feeding fishes of fresh or brackish warm waters, often used in
mosquito control.</def><br/
<syn><b>Syn. --</b> topminnow, poeciliid fish, poeciliid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lived</ent><br/
<hw>Lived</hw> <pr>(l<imac/vd)</pr>, <pos>a.</pos> <def>Having life; --
used only in composition; <as>as, long-<ex>lived</ex>;
short-<ex>lived</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lived-in</ent><br/
<hw>lived-in</hw> <pos>adj.</pos> <def>having residents; <as>as, a house
with a <ex>lived-in</ex> look</as>.</def><br/
<syn><b>Syn. --</b> inhabited, tenanted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Live-forever</ent><br/
<hw>Live"-for*ev`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A plant (<spn>Sedum Telephium</spn>) with fleshy leaves, which has
extreme powers of resisting drought; garden ox-pine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livelihed</ent><br/
<hw>Live"li*hed</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Livelihood</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livelihood</ent><br/
<hw>Live"li*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>livelode</ets>, <ets>liflode</ets>, prop., course of life, life's
support, maintenance, fr. AS. <ets>l<imac/f</ets> life +
<ets>l<amac/d</ets> road, way, maintenance. Confused with
<ets>livelihood</ets> liveliness. See <er>Life</er>, and
<er>Lode</er>.]</ety> <def>Subsistence or living, as dependent on some
means of support; the means for support of life; maintenance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The opportunities of gaining an honest <qex>livelihood</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is their profession and <qex>livelihood</qex> to get their
living by practices for which they deserve to forfeit their lives.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livelihood</ent><br/
<hw>Live"li*hood</hw>, <pos>n.</pos> <ety>[<ets>Lively</ets> +
<ets>-hood</ets>.]</ety> <def>Liveliness; appearance of life.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livelily</ent><br/
<hw>Live"li*ly</hw>, <pos>adv.</pos> <def>In a lively manner.</def>
<mark>[Obs.]</mark> <rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liveliness</ent><br/
<hw>Live"li*ness</hw>, <pos>n.</pos> <ety>[From <er>Lively</er>.]</ety>
<sn>1.</sn> <def>The quality or state of being lively or animated;
sprightliness; vivacity; animation; spirit; <as>as, the
<ex>liveliness</ex> of youth, contrasted with the gravity of
age</as>.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An appearance of life, animation, or spirit; <as>as,
the <ex>liveliness</ex> of the eye or the countenance in a
portrait</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Briskness; activity; effervescence, as of
liquors.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Sprightliness; gayety; animation; vivacity;
smartness; briskness; activity. -- <er>Liveliness</er>, <er>Gayety</er>,
<er>Animation</er>, <er>Vivacity</er>. <xex>Liveliness</xex> is an
habitual feeling of life and interest; <xex>gayety</xex> refers more to
a temporary excitement of the animal spirits; <xex>animation</xex>
implies a warmth of emotion and a corresponding vividness of expressing
it, awakened by the presence of something which strongly affects the
mind; <xex>vivacity</xex> is a feeling between liveliness and animation,
having the permanency of the one, and, to some extent, the warmth of the
other. <xex>Liveliness</xex> of imagination; <xex>gayety</xex> of heart;
<xex>animation</xex> of countenance; <xex>vivacity</xex> of gesture or
conversation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livelode</ent><br/
<hw>Live"lode`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Livelihood</er>.]</ety> <def>Course of life; means of support;
livelihood.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livelong</ent><br/
<hw>Live"long`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[For
<ets>lifelong</ets>. Cf. <er>Lifelong</er>.]</ety> <sn>1.</sn>
<def>Whole; entire; long in passing; -- used of time, as day or night,
in adverbial phrases, and usually with a sense of tediousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The obscure bird<br/
Clamored the <qex>livelong</qex> night.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How could she sit the <qex>livelong</qex> day,<br/
Yet never ask us once to play?</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lasting; durable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou hast built thyself a <qex>livelong</qex> monument.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lively</ent><br/
<hw>Live"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Livelier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Liveliest</adjf>.]</amorph> <ety>[For <ets>lifely</ets>. Cf.
<er>Lifelike</er>.]</ety> <sn>1.</sn> <def>Endowed with or manifesting
life; living.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Chaplets of gold and silver resembling <qex>lively</qex> flowers
and leaves.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Brisk; vivacious; active; <as>as, a <ex>lively</ex>
youth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But wherefore comes old Manoa in such haste,<br/
With youthful steps ? Much <qex>livelier</qex> than erewhile<br/
He seems.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Gay; airy; animated; spirited.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From grave to gay, from <qex>lively</qex> to severe.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Representing life; lifelike.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I spied the <qex>lively</qex> picture of my father.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Bright; vivid; glowing; strong; vigorous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The colors of the prism are manifestly more full, intense, and
<qex>lively</qex> that those of natural bodies.</q> <rj><qau>Sir I.
Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His faith must be not only living, but <qex>lively</qex> too.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lively stones</b></col> <fld>(Script.)</fld>, <cd>saints,
as being quickened by the Spirit, and active in holiness.</cd></cs></p>

<p><syn><b>Syn.</b> -- Brisk; vigorous; quick; nimble; smart; active;
alert; sprightly; animated; spirited; prompt; earnest; strong;
energetic; vivid; vivacious; blithe; gleeful; airy; gay;
jocund.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lively</ent><br/
<hw>Live"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a brisk, active,
or animated manner; briskly; vigorously.</def>
<rj><au>Hayward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With strong resemblance of life.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou counterfeitest most <qex>lively</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>liven</ent><br/
<hw>liven</hw> <pos>v. t.</pos> <def>to make lively; -- sometimes used
with <ptcl>up</ptcl>; <as>as, to <ex>liven</ex> up the party with some
music</as>.</def><br/
<syn><b>Syn. --</b> enliven, liven up, make lively, invigorate,
animate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>liveness</ent><br/
<hw>liveness</hw> <pos>n.</pos> <def>The quality of having animal life
as distinguished from plant life.</def><br/
<syn><b>Syn. --</b> animateness, aliveness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liver</ent><br/
<hw>Liv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or
that which, lives.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And try if life be worth the <qex>liver's</qex> care.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A resident; a dweller; <as>as, a <ex>liver</ex> in
Brooklyn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One whose course of life has some marked
characteristic (expressed by an adjective); <as>as, a free
<ex>liver</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fast liver</b></col>, <cd>one who lives in an extravagant
and dissipated way.</cd> -- <mcol><col><b>Free liver</b></col>,
<col><b>Good liver</b></col></mcol>, <cd>one given to the pleasures of
the table.</cd> -- <col><b>Loose liver</b></col>, <cd>a person who lives
a somewhat dissolute life.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liver</ent><br/
<hw>Liv"er</hw>, <pos>n.</pos> <ety>[AS. <ets>lifer</ets>; akin to D.
<ets>liver</ets>, G. <ets>leber</ets>, OHG. <ets>lebara</ets>, Icel.
<ets>lifr</ets>, Sw. <ets>lefver</ets>, and perh. to Gr. <?/ fat, E.
<ets>live</ets>, v.]</ety> <fld>(Anat.)</fld> <def>A very large
glandular and vascular organ in the visceral cavity of all
vertebrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Most of the venous blood from the alimentary canal
passes through it on its way back to the heart; and it secretes the
bile, produces glycogen, and in other ways changes the blood which
passes through it. In man it is situated immediately beneath the
diaphragm and mainly on the right side. See <er>Bile</er>,
<er>Digestive</er>, and <er>Glycogen</er>. The liver of invertebrate
animals is usually made up of c<ae/cal tubes, and differs materially, in
form and function, from that of vertebrates.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Floating liver</b></col>. <cd>See <cref>Wandering
liver</cref>, under <er>Wandering</er>.</cd> -- <mcol><col><b>Liver of
antimony</b></col>, <col><b>Liver of sulphur</b></col></mcol>. <fld>(Old
Chem.)</fld> <cd>See <er>Hepar</er>.</cd> -- <mcol><col><b>Liver
brown</b></col>, <col><b>Liver color</b></col></mcol>, <cd>the color of
liver, a dark, reddish brown.</cd> -- <col><b>Liver shark</b></col>
<fld>(Zool.)</fld>, <cd>a very large shark (<spn>Cetorhinus
maximus</spn>), inhabiting the northern coasts both of Europe and North
America. It sometimes becomes forty feet in length, being one of the
largest sharks known; but it has small simple teeth, and is not
dangerous. It is captured for the sake of its liver, which often yields
several barrels of oil. It has gill rakers, resembling whalebone, by
means of which it separates small animals from the sea water. Called
also <altname>basking shark</altname>, <altname>bone shark</altname>,
<altname>hoemother</altname>, <altname>homer</altname>, and
<altname>sailfish</altname>; it is sometimes referred to as
<altname>whale shark</altname>, but that name is more commonly used for
the <spn>Rhincodon typus</spn>, which grows even larger</cd>. --
<col><b>Liver spots</b></col>, <cd>yellowish brown patches on the skin,
or spots of chloasma.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 862 --></p>

<p><ent>Liver</ent><br/
<hw>Liv"er</hw> <pr>(l<icr/v"<etil/r)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The glossy ibis (<spn>Ibis falcinellus</spn>);
-- said to have given its name to the city of Liverpool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liver-colored</ent><br/
<hw>Liv"er-col`ored</hw> <pr>(l<icr/v"<etil/r-k<ucr/l`<etil/rd)</pr>,
<pos>a.</pos> <def>Having a color like liver; dark reddish
brown.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livered</ent><br/
<hw>Liv"ered</hw> <pr>(l<icr/v"<etil/rd)</pr>, <pos>a.</pos> <def>Having
(such) a liver; used in composition; <as>as,
white-<ex>livered</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liver-grown</ent><br/
<hw>Liv"er-grown`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having an
enlarged liver.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liveried</ent><br/
<hw>Liv"er*ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wearing a livery.
See <er>Livery</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>liveried</qex> servants wait.</q>
<rj><qau>Parnell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livering</ent><br/
<hw>Liv"er*ing</hw>, <pos>n.</pos> <def>A kind of pudding or sausage
made of liver or pork.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liverleaf</ent><br/
<hw>Liv"er*leaf`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Same as <er>Liverwort</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liverpudlian</ent><br/
<hw>Liverpudlian</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining
to the inhabitants of Liverpool; <as>as, <ex>Liverpudlian</ex> street
urchins</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to Liverpool; <as>as,
<ex>Liverpudlian</ex> streets</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liverpudlian</ent><br/
<hw>Liverpudlian</hw> <pos>n.</pos> <def>A resident of
Liverpool.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Liverwort</ent><br/
<hw>Liv"er*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sn>1.</sn> <def>A ranunculaceous plant (<spn>Anemone Hepatica</spn>)
with pretty white or bluish flowers and a three-lobed leaf; -- called
also <altname>squirrel cups</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flowerless plant (<spn>Marchantia
polymorpha</spn>), having an irregularly lobed, spreading, and forking
frond.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ From this plant many others of the same order
(<ord>Hepatic<ae/</ord>) have been vaguely called liverworts, esp. those
of the tribe <fam>Marchantiace<ae/</fam>. See <xex>Illust.</xex> of
<er>Hepatica</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livery</ent><br/
<hw>Liv"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Liveries</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>livere</ets>, F.
<ets>livr<eacute/e</ets>, formerly, a gift of clothes made by the master
to his servants, prop., a thing delivered, fr. <ets>livrer</ets> to
deliver, L. <ets>liberare</ets> to set free, in LL., to deliver up. See
<er>Liberate</er>.]</ety> <sn>1.</sn> <fld>(Eng. Law)</fld> <sd>(a)</sd>
<def>The act of delivering possession of lands or tenements.</def>
<sd>(b)</sd> <def>The writ by which possession is obtained.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is usual to say, <altname>livery of seizin</altname>,
which is a feudal investiture, made by the delivery of a turf, of a rod,
a twig, or a key from the feoffor to the feoffee as a symbol of delivery
of the whole property. There was a distinction of <stype>livery in
deed</stype> when this ceremony was performed on the property being
transferred, and <stype>livery in law</stype> when performed in sight of
the property, but not on it. In the United States, and now in Great
Britain, no such ceremony is necessary, the delivery of a deed being
sufficient as a <ex>livery of seizin</ex>, regardless of where
performed.</note> <au>Black's 4th Ed.</au><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Release from wardship; deliverance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It concerned them first to sue out their <qex>livery</qex> from
the unjust wardship of his encroaching prerogative.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is delivered out statedly or formally, as
clothing, food, etc.</def>; especially: <sd>(a)</sd> <def>The uniform
clothing issued by feudal superiors to their retainers and serving as a
badge when in military service.</def> <sd>(b)</sd> <def>The peculiar
dress by which the servants of a nobleman or gentleman are
distinguished; <as>as, a claret-colored <ex>livery</ex></as>.</def>
<sd>(c)</sd> <def>Hence, also, the peculiar dress or garb appropriated
by any association or body of persons to their own use; <as>as, the
<ex>livery</ex> of the London tradesmen, of a priest, of a charity
school, etc.</as>; also, the whole body or company of persons wearing
such a garb, and entitled to the privileges of the association; <as>as,
the whole <ex>livery</ex> of London</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A Haberdasher and a Carpenter,<br/
A Webbe, a Dyer, and a Tapicer,<br/
And they were clothed all in one <qex>livery</qex><br/
Of a solempne and a gret fraternite.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From the periodical deliveries of these characteristic articles of
servile costume (blue coats) came our word <qex>livery</qex>.</q>
<rj><qau>De Quincey.</qau></rj></p>

<p><sd>(d)</sd> <def>Hence, any characteristic dress or outward
appearance.</def> <ldquo/ April's <xex>livery</xex>.<rdquo/ <au>Sir P.
Sidney.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Now came still evening on, and twilight gray<br/
Had in her sober <qex>livery</qex> all things clad.</q>
<rj><qau>Milton.</qau></rj></p>

<p><sd>(e)</sd> <def>An allowance of food statedly given out; a ration,
as to a family, to servants, to horses, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The emperor's officers every night went through the town from
house to house whereat any English gentleman did repast or lodge, and
served their <qex>liveries</qex> for all night: first, the officers
brought into the house a cast of fine manchet [white bread], and of
silver two great pots, and white wine, and sugar.</q>
<rj><qau>Cavendish.</qau></rj></p>

<p><sd>(f)</sd> <def>The feeding, stabling, and care of horses for
compensation; boarding; <as>as, to keep one's horses at
<ex>livery</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>livery</qex> is, we by common use in England know well
enough, namely, that is, allowance of horse meat, as to keep horses at
<qex>livery</qex>, the which word, I guess, is derived of livering or
delivering forth their nightly food.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It need hardly be observed that the explanation of
<qex>livery</qex> which Spenser offers is perfectly correct, but . . .
it is no longer applied to the ration or stated portion of food
delivered at stated periods.</q> <rj><qau>Trench.</qau></rj></p>

<p><sd>(g)</sd> <def>The keeping of horses in readiness to be hired
temporarily for riding or driving; the state of being so kept; also, the
place where horses are so kept, also called a <altname>livery
stable</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pegasus does not stand at <qex>livery</qex> even at the largest
establishment in Moorfields.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A low grade of wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Livery gown</b></col>, <cd>the gown worn by a liveryman
in London.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livery</ent><br/
<hw>Liv"er*y</hw>, <pos>v. t.</pos> <def>To clothe in, or as in,
livery.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liveryman</ent><br/
<hw>Liv"er*y*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Liverymen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>One who
wears a livery, as a servant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A freeman of the city, in London, who, having paid
certain fees, is entitled to wear the distinguishing dress or
<xex>livery</xex> of the company, guild, or district to which he
belongs, and also to enjoy certain other privileges, as the right of
voting in an election for the lord mayor, sheriffs, chamberlain,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who keeps a livery stable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livery stable</ent><br/
<hw>Liv"er*y sta`ble</hw> <pr>(?)</pr> <pos>n.</pos> <def>A stable where
horses are kept for hire, and where stabling is provided. See
<er>Livery</er>, <pos>n.</pos>, 3 <sd>(e)</sd> <sd>(f)</sd> &
<sd>(g)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lives</ent><br/
<hw>Lives</hw> <pr>(l<imac/vz)</pr>, <pos>n.</pos>; <def><pos>pl.</pos>
of <er>Life</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lives</ent><br/
<hw>Lives</hw> <pr>(l<imac/vz)</pr>, <pos>a. & adv.</pos> <ety>[Orig. a
genitive sing. of <ets>life</ets>.]</ety> <def>Alive; living; with
life.</def> <mark>[Obs.]</mark> <ldquo/ Any <xex>lives</xex>
creature.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livid</ent><br/
<hw>Liv"id</hw> <pr>(l<icr/v"<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>lividus</ets>, from <ets>livere</ets> to be of a blush color, to be
black and blue: cf. F. <ets>livide</ets>.]</ety> <sn>1.</sn> <def>Black
and blue; grayish blue; of a lead color; discolored, as flesh may be
from a contusion.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There followed no carbuncles, no purple or <qex>livid</qex> spots,
the mass of the blood not being tainted.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extremely angry; enraged; infuriated.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Pallid; ashen; -- of the skin.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lividity</ent><br/
<hw>Li*vid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lividit<eacute/</ets>.]</ety> <def>The state or quality of being
livid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lividness</ent><br/
<hw>Liv"id*ness</hw> <pr>(l<icr/v"<icr/d*n<ecr/s)</pr>, <pos>n.</pos>
<def>Lividity.</def> <rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Living</ent><br/
<hw>Liv"ing</hw> <pr>(l<icr/v"<icr/ng)</pr>, <pos>a.</pos> <ety>[From
<er>Live</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>Being alive;
having life; <as>as, a <ex>living</ex> creature</as>. Opposed to
<ant>dead</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Active; lively; vigorous; -- said esp. of states of
the mind, and sometimes of abstract things; <as>as, a <ex>living</ex>
faith; a <ex>living</ex> principle.</as></def> <ldquo/ <xex>Living</xex>
hope. <rdquo/ <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Issuing continually from the earth; running;
flowing; <as>as, a <ex>living</ex> spring</as>; -- opposed to
<ant>stagnant</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Producing life, action, animation, or vigor;
quickening.</def> <ldquo/<xex>Living</xex> light.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Ignited; glowing with heat; burning; live.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then on the <qex>living</qex> coals wine they pour.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Living force</b></col>. <cd>See <cref>Vis viva</cref>,
under <er>Vis</er>.</cd> -- <col><b>Living gale</b></col>
<fld>(Naut.)</fld>, <cd>a heavy gale.</cd> -- <mcol><col><b>Living
rock</b></col> <it>or</it> <col><b>Living stone</b></col></mcol>,
<cd>rock in its native or original state or location; rock not
quarried.</cd> <ldquo/ I now found myself on a rude and narrow stairway,
the steps of which were cut out of the <xex>living rock</xex>.<rdquo/
<au>Moore.</au> -- <col><b>The living</b></col>, <cd>those who are
alive, or one who is alive.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Living</ent><br/
<hw>Liv"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of one who,
or that which, lives; lives; life; existence.</def> <ldquo/Health and
<xex>living</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Manner of life; <as>as, riotous <ex>living</ex>;
penurious <ex>living</ex>; earnest <ex>living</ex>.</as></def> <ldquo/ A
vicious <xex>living</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Means of subsistence; sustenance; estate; <as>as, to
make a comfortable <ex>living</ex> from writing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She can spin for her <qex>living</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He divided unto them his <qex>living</qex>.</q> <rj><qau>Luke xv.
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Power of continuing life; the act of living, or
living comfortably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no <qex>living</qex> without trusting somebody or other
in some cases.</q> <rj><qau>L' Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The benefice of a clergyman; an ecclesiastical
charge which a minister receives.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He could not get a deanery, a prebend, or even a
<qex>living</qex></q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livingly</ent><br/
<hw>Liv"ing*ly</hw>, <pos>adv.</pos> <def>In a living state.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livingness</ent><br/
<hw>Liv"ing*ness</hw>, <pos>n.</pos> <def>The state or quality of being
alive; possession of energy or vigor; animation; quickening.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Living picture</ent><br/
<hw>Liv"ing pic"ture</hw>. <def>A tableau in which persons take part;
also, specif., such a tableau as imitating a work of art.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>living room</ent><br/
<hw>liv"ing room`</hw>. <def>A room in a house used by all or most of
the family, where the family entertain guests or relax together for
leisure activities. It usually contains at least one couch, and does not
contain a dining table.</def><br/
[<source>PJC</source>]</p>

<p><ent>living wage</ent><br/
<hw>liv"ing wage"</hw>. <def>A wage or salary that permits a worker to
live at least with minimal customary amenities, and above conditions of
poverty.</def><br/
[<source>PJC</source>]</p>

<p><ent>living will</ent><br/
<hw>liv"ing will</hw>. <def>A document signed by an individual
expressing his/her desire that, in the event of an illness from which
there is no reasonable expectation of recovery, aggressive or
extraordinary measures to prolong life, such as resuscitation and
life-support equipment, should not be used.</def><br/
[<source>PJC</source>]</p>

<p><ent>Livistona</ent><br/
<hw>Livistona</hw> <pos>n.</pos> <def>A genus of fan palms of Asia and
Australia and Malaysia.</def><br/
<syn><b>Syn. --</b> genus <gen>Livistona</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Livonian</ent><br/
<hw>Li*vo"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Livonia, a district on the Baltic Sea formerly part of Russia, now
part of Latvia and Estonia.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Livonian</ent><br/
<hw>Li*vo"ni*an</hw>, <pos>n.</pos> <def>A native or an inhabitant of
Livonia; the language (allied to the Finnish) of the
Livonians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livor</ent><br/
\'d8<hw>Li"vor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Malignity.</def> <mark>[R.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livraison</ent><br/
\'d8<hw>Li`vrai`son"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>liberatio</ets> a setting free, in LL., a delivering up. See
<er>Liberation</er>.]</ety> <def>A part of a book or literary
composition printed and delivered by itself; a number; a part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Livre</ent><br/
<hw>Li"vre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>libra</ets> a pound of twelve ounces. Cf. <er>Lira</er>.]</ety>
<def>A French money of account, afterward a silver coin equal to 20
sous. It is not now in use, having been superseded by the
franc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixivial</ent><br/
<hw>Lix*iv"i*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lixivius</ets>, fr. <ets>lix</ets> ashes, lye ashes, lye: cf. F.
<ets>lixiviel</ets>.]</ety> <sn>1.</sn> <def>Impregnated with, or
consisting of, alkaline salts extracted from wood ashes; impregnated
with a salt or salts like a lixivium.</def>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of the color of lye; resembling lye.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having the qualities of alkaline salts extracted
from wood ashes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lixivial salts</b></col> <fld>(Old Chem.)</fld>,
<cd>salts which are obtained by passing water through ashes, or by
pouring it on them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixivited</ent><br/
<ent>Lixiviate</ent><br/
<mhw>{ <hw>Lix*iv"i*ate</hw> <pr>(?)</pr>, <hw>Lix*iv"i*`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[From <er>Lixivium</er>.]</ety>
<sn>1.</sn> <def>Of or pertaining to lye or lixivium; of the quality of
alkaline salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Impregnated with salts from wood ashes.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixiviate</ent><br/
<hw>Lix*iv"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Lixiviated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lixiviating</conjf> <pr>(?)</pr>.]</vmorph> <def>To
subject to a washing process for the purpose of separating soluble
material from that which is insoluble; to leach, as ashes, for the
purpose of extracting the alkaline substances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixiviation</ent><br/
<hw>Lix*iv`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lixiviation</ets>.]</ety> <def>Lixiviating; the process of
separating a soluble substance from one that is insoluble, by washing
with some solvent, as water; leaching.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixivious</ent><br/
<hw>Lix*iv"i*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Lixivial</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixivium</ent><br/
<hw>Lix*iv"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lixivium</ets>, <ets>lixivia</ets>. See <er>Lixivial</er>.]</ety>
<def>A solution of alkaline salts extracted from wood ashes; hence, any
solution obtained by lixiviation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lixt</ent><br/
<hw>Lixt</hw> <pr>(l<icr/kst)</pr>, <mark>obs.</mark> <def><pos>2d pers.
sing. pres.</pos> of <er>Lige</er>, to lie, to tell lies, -- contracted
for <xex>ligest</xex>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Liza</ent><br/
\'d8<hw>Li"za</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The American white mullet (<spn>Mugil curema</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lizard</ent><br/
<hw>Liz"ard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lesarde</ets>, OF. <ets>lesarde</ets>, F. <ets>l<eacute/zard</ets>,
L. <ets>lacerta</ets>, <ets>lacertus</ets>. Cf. <er>Alligator</er>,
<er>Lacerta</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Zool.)</fld> <def>Any one of the numerous species
of reptiles belonging to the order <ord>Lacertilia</ord>; sometimes,
also applied to reptiles of other orders, as the
<ord>Hatteria</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Most lizards have an elongated body, with four legs, and
a long tail; but there are some without legs, and some with a short,
thick tail. Most have scales, but some are naked; most have eyelids, but
some do not. The tongue is varied in form and structure. In some it is
forked, in others, as the chameleons, club-shaped, and very extensible.
See <er>Amphisb<ae/na</er>, <er>Chameleon</er>, <er>Gecko</er>, <er>Gila
monster</er>, <er>Horned toad</er>, <er>Iguana</er>, and
<er>Dragon</er>, 6.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A piece of rope with thimble or
block spliced into one or both of the ends.</def> <rj><au>R. H. Dana,
Ir.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A piece of timber with a forked end, used in
dragging a heavy stone, a log, or the like, from a field.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lizard snake</b></col> <fld>(Zool.)</fld>, <cd>the garter
snake (<spn>Eut<ae/nia sirtalis</spn>).</cd> -- <col><b>Lizard
stone</b></col> <fld>(Min.)</fld>, <cd>a kind of serpentine from near
Lizard Point, Cornwall, England, -- used for ornamental
purposes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lizard fish</ent><br/
<ent>lizardfish</ent><br/
<mhw><hw>lizardfish</hw>, <hw>lizard fish</hw></mhw> <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any of several mostly tropical marine scopeloid
fish of the family <fam>Synodontidae</fam> having large mouths in
lizardlike heads, especially the <stype>inshore lizardfish</stype>
(<spn>Synodus foetens</spn> syn. <spn>Synodus poeyi</spn>) of Mideastern
and Southern United States and West Indies; -- sometimes called
<altname>sand pike</altname>.</def> <note>A freshwater perch, the
sauger, a different fish, is also called the <it>sand
pike</it>.</note><br/
<syn><b>Syn. --</b> snakefish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lizard's tail</ent><br/
<hw>Liz"ard's tail`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Bot.)</fld>
<def>A perennial plant of the genus <gen>Saururus</gen> (<spn>Saururus
cernuus</spn>), growing in marshes, and having white flowers crowded in
a slender terminal spike, somewhat resembling in form a lizard's tail;
whence the name.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Llama</ent><br/
<hw>Lla"ma</hw>, <pos>n.</pos> <ety>[Peruv.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A South American ruminant (<spn>Auchenia
llama</spn>), allied to the camels, but much smaller and without a hump.
It is supposed to be a domesticated variety of the guanaco. It was
formerly much used as a beast of burden in the Andes, and is also kept
on some ranches in the United States.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fleece of the llama{1}, a fine, soft wool-like
hair.</def><br/
[<source>PJC</source>]</p>

<p><ent>Llandeilo group</ent><br/
<hw>Llan*dei"lo group`</hw>. <fld>(Geol.)</fld> <def>A series of strata
in the lower Silurian formations of Great Britain; -- so named from
<ets>Llandeilo</ets> in Southern Wales. See <xex>Chart</xex> of
<er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Llanero</ent><br/
\'d8<hw>Lla*ne"ro</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
Amer.]</ety> <def>One of the inhabitants of the llanos of South
America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Llano</ent><br/
<hw>Lla"no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Llanos</plw> <pr>(#)</pr>.</plu> <ety>[Sp., plain even, level. See
<er>Plain</er>.]</ety> <def>An extensive plain with or without
vegetation.</def> <mark>[Spanish America]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lloyd's</ent><br/
<hw>Lloyd's</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
association of underwriters and others in London, for the collection and
diffusion of marine intelligence, the insurance, classification,
registration, and certifying of vessels, and the transaction of business
of various kinds connected with shipping.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A part of the Royal Exchange, in London,
appropriated to the use of underwriters and insurance brokers; -- called
also <altname>Lloyd's Rooms</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is derived from <xex>Lloyd's</xex> Coffee
House, in Lombard Street, where there were formerly rooms for the same
purpose. The name <xex>Lloyd</xex> or <xex>Lloyd's</xex> has been taken
by several associations, in different parts of Europe, established for
purposes similar to those of the original association.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lloyd's agents</b></col>, <cd>persons employed in various
parts of the world, by the association called Lloyd's, to serve its
interests.</cd> -- <col><b>Lloyd's list</b></col>, <cd>a publication of
the latest news respecting shipping matters, with lists of vessels,
etc., made under the direction of Lloyd's.</cd> <au>Brande & C.</au> --
<col><b>Lloyd's register</b></col>, <cd>a register of vessels rated
according to their quality, published yearly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Llullaillaco</ent><br/
<hw>Llullaillaco</hw> <pos>prop. n.</pos> <def>A mountain in Argentina
and Chile, 22,057 feet high.</def> <mark>proper name</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Llyr</ent><br/
<hw>Llyr</hw> <pos>prop. n.</pos> <fld>(Welsh mythology)</fld> <def>the
sea personified, father of <persfn>Manawydan</persfn>; corresponds to
the Irish <altname>Ler</altname>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lo</ent><br/
<hw>Lo</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[OE. <ets>lo</ets>,
<ets>low</ets>; perh. akin to E. <ets>look</ets>, v.]</ety> <def>Look;
see; behold; observe.</def> <ldquo/<xex>Lo</xex>, here is Christ.<rdquo/
<au>Matt. xxiv. 23.</au> <ldquo/<xex>Lo</xex>, we turn to the
Gentiles.<rdquo/ <au>Acts xiii. 46.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loach</ent><br/
<hw>Loach</hw> <pr>(l<omac/ch)</pr>, <pos>n.</pos> <ety>[OE.
<ets>loche</ets>, F. <ets>loche</ets>.]</ety> <fld>(Zool.)</fld>
<def>Any one of several small, fresh-water, cyprinoid fishes of the
genera <gen>Cobitis</gen>, <gen>Nemachilus</gen>, and allied genera,
having six or more barbules around the mouth. They are found in Europe
and Asia. The common European species (<spn>Nemachilus barbatulus</spn>)
is used as a food fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Load</ent><br/
<hw>Load</hw> <pr>(l<omac/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lode</ets> load, way; properly the same word as <ets>lode</ets>,
but confused with <ets>lade</ets>, <ets>load</ets>, v. See
<er>Lade</er>, <er>Lead</er>, <pos>v.</pos>, <er>Lode</er>.]</ety>
<sn>1.</sn> <def>A burden; that which is laid on or put in anything for
conveyance; that which is borne or sustained; a weight; <as>as, a heavy
<ex>load</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He might such a <qex>load</qex><br/
To town with his ass carry.</q> <rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quantity which can be carried or drawn in some
specified way; the contents of a cart, barrow, or vessel; that which
will constitute a cargo; lading.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which burdens, oppresses, or grieves the mind
or spirits; <as>as, a <ex>load</ex> of care</as>.</def> <ldquo/ A . . .
<xex>load</xex> of guilt.<rdquo/ <au>Ray.</au> <ldquo/ Our life's a
<xex>load</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A particular measure for certain articles, being as
much as may be carried at one time by the conveyance commonly used for
the article measured; <as>as, a <ex>load</ex> of wood; a <ex>load</ex>
of hay</as>; specifically, five quarters.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The charge of a firearm; <as>as, a <ex>load</ex> of
powder</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Weight or violence of blows.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mach.)</fld> <def>The work done by a steam engine
or other prime mover when working.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The amount of work that a person, group, or machine
is assigned to perform; <as>as, the boss distributed the <ex>load</ex>
evenly among his employees</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <fld>(Elec.)</fld> <def>The device or devices that
consume power from a power supply.</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <fld>(Engineering)</fld> <def>The weight or force that a
structural support bears or is designed to bear; the object that creates
that force.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Load line</b></col>, <it>or</it> <col><b>Load water
line</b></col></mcol> <fld>(Naut.)</fld>, <cd>the line on the outside of
a vessel indicating the depth to which it sinks in the water when
loaded.</cd></cs></p>

<p><syn><b>Syn.</b> -- Burden; lading; weight; cargo. See
<er>Burden</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Load</ent><br/
<hw>Load</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Loaded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Loading</conjf>. <xex>Loaden</xex> is obsolete, and
<xex>laden</xex> belongs to <xex>lade</xex>.]</vmorph> <sn>1.</sn>
<def>To lay a load or burden on or in, as on a horse or in a cart; to
charge with a load, as a gun; to furnish with a lading or cargo, as a
ship; hence, to add weight to, so as to oppress or embarrass; to heap
upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I strive all in vain to <qex>load</qex> the cart.</q>
<rj><qau>Gascoigne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>loaden</qex> me with many spoils.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those honors deep and broad, wherewith<br/
Your majesty <qex>loads</qex> our house.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 863 --></p>

<p><sn>2.</sn> <def>To adulterate or drug; <as>as, to <ex>load</ex>
wine</as>.</def> <mark>[Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To magnetize.</def> <mark>[Obs.]</mark>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Loaded dice</b></col>, <cd>dice with one side made
heavier than the others, so that the number on the opposite side will
come up oftenest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>load-bearing</ent><br/
<hw>load-bearing</hw> <pos>adj.</pos> <fld>(Arch.)</fld> <def>Supporting
a load{10} from parts of a structure above; <as>as, a
<ex>load-bearing</ex> wall</as>.</def> <mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> supporting(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loaded</ent><br/
<hw>loaded</hw> <pos>adj.</pos> <sn>1.</sn> <def>containing as much or
as many as is possible; -- of containers, vehicles, trays, etc.; <as>as,
a tray <ex>loaded</ex> with dishes</as></def><br/
<syn><b>Syn. --</b> laden.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>containing a shell or an explosive charge ready for
firing; -- of firearms. Opposite of <ant>unloaded</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>charged with associative significance and often
meant to mislead or influence; -- of statements or questions; <as>as, a
<ex>loaded</ex> question</as>.</def><br/
<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>having an abundant supply of money or possessions of
value; <as>as, She was not merely rich but
<ex>loaded</ex></as>.</def><br/
<syn><b>Syn. --</b> affluent, flush, moneyed, wealthy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>5.</sn> <def>very drunk.</def> <mark>[slang]</mark><br/
<syn><b>Syn. --</b> blotto, crocked, fuddled, pissed, pixilated,
plastered, potty, slopped, sloshed, smashed, soused, sozzled, squiffy,
stiff, tiddly, tiddley, tight, tipsy, wet.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loader</ent><br/
<hw>Load"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, loads; a mechanical contrivance for loading, as a gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loading</ent><br/
<hw>Load"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of putting a
load on or into.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A load; cargo; burden.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodemanage</ent><br/
<ent>Loadmanage</ent><br/
<mhw>{ <hw>Load"man*age</hw>, <hw>Lode"man*age</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>Pilotage; skill of a pilot or
loadsman.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loads</ent><br/
<hw>loads</hw> <pos>n.</pos> <def>A large quantity; a lot; <as>as,
<ex>loads</ex> of fun</as>.</def> <mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>load-shedding</ent><br/
<hw>load-shedding</hw> <pos>n.</pos> <def>The act or process of
disconnecting the electric current on certain lines when the demand
becomes greater than the supply.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lodesman</ent><br/
<ent>Loadsman</ent><br/
<mhw>{ <hw>Loads"man</hw>, <hw>Lodes"man</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[<ets>Load</ets>, <ets>lode</ets> + <ets>man.</ets>
See <er>Lode</er>.]</ety> <def>A pilot.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodestar</ent><br/
<ent>Loadstar</ent><br/
<mhw>{ <hw>Load"star`</hw>, <hw>Lode"star`</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[<ets>Load</ets>, <ets>lode</ets> + <ets>star.</ets>
See <er>Lode</er>.]</ety> <sn>1.</sn> <def>A star that leads; a guiding
star; esp., the polestar, Polaris; also, the constellation containing
the pole star, the cynosure (Ursa Minor).</def> <au>Chaucer.</au>
<ldquo/ Your eyes are <xex>lodestars</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The pilot can no <qex>loadstar</qex> see.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something that serves as a guide or provides
direction; a cynosure{2}.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Something that attracts attention or on which the
atention is fixed; a cynosure{3}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lodestone</ent><br/
<ent>Loadstone</ent><br/
<mhw>{ <hw>Load"stone`</hw>, <hw>Lode"stone</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[<ets>Load</ets>, <ets>lode</ets> +
<ets>stone</ets>.]</ety> <fld>(Min.)</fld> <def>A piece of magnetite, a
magnetic iron ore, possessing polarity like a magnetic needle, having
the power to attract as well as to be attracted magnetically. See
<er>Magnetite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loaf</ent><br/
<hw>Loaf</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Loaves</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>lof</ets>,
<ets>laf</ets>, AS. <ets>hl<amac/f</ets>; akin to G. <ets>laib</ets>,
OHG. <ets>hleip</ets>, Icel. <ets>hleifr</ets>, Goth. <ets>hlaifs</ets>,
Russ. <ets>khlieb'</ets>, Lith. <ets>kl<eum/pas</ets>. Cf.
<er>Lady</er>, <er>Lammas</er>, <er>Lord</er>.]</ety> <def>Any thick
lump, mass, or cake; especially, a large regularly shaped or molded
mass, as of bread, sugar, or cake.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Loaf sugar</b></col>, <cd>refined sugar that has been
formed into a conical loaf in a mold.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loaf</ent><br/
<hw>Loaf</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Loafed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loafing</conjf>.]</vmorph> <ety>[G. <ets>laufen</ets> to run,
Prov. G. <ets>loofen</ets>. See <er>Leap</er>.]</ety> <def>To spend time
in idleness; to lounge or loiter about.</def> <ldquo/ <xex>Loafing</xex>
vagabonds.<rdquo/ <rj><au>W. Black.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loaf</ent><br/
<hw>Loaf</hw>, <pos>v. t.</pos> <def>To spend in idleness; -- with
<ptcl>away</ptcl>; <as>as, to <ex>loaf</ex> time away</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loafer</ent><br/
<hw>Loaf"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>l<aum/ufer</ets> a runner, Prov. G. <ets>laufer</ets>,
<ets>lofer</ets>, fr. <ets>laufen</ets> to run. See
<er>Leap</er>.]</ety> <sn>1.</sn> <def>One who loafs; a lazy
lounger.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A type of shoe without laces which can be easily
slipped on or off; -- originally a trademark; <as>as, he bought a new
pair of <ex>loafers</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>loafing</ent><br/
<hw>loaf"ing</hw> <pos>n.</pos> <def>having no employment; being idle
intentionally.</def><br/
<syn><b>Syn. --</b> idleness, idling.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loam</ent><br/
<hw>Loam</hw> <pr>(l<omac/m)</pr>, <pos>n.</pos> <ety>[AS.
<ets>l<amac/m</ets>; akin to D. <ets>leem</ets>, G. <ets>lehm</ets>, and
E. <ets>lime</ets>. See 4th <er>Lime</er>.]</ety> <sn>1.</sn> <def>A
kind of soil; an earthy mixture of clay and sand, with organic matter to
which its fertility is chiefly due.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We wash a wall of <qex>loam</qex>; we labor in vain.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Founding)</fld> <def>A mixture of sand, clay, and
other materials, used in making molds for large castings, often without
a pattern.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Loam mold</b></col> <fld>(Founding)</fld>, <cd>a mold
made with loam. See <er>Loam</er>, <pos>n.</pos>, 2.</cd> --
<col><b>Loam molding</b></col>, <cd>the process or business of making
loam molds.</cd> <col><b>Loam plate</b></col>, <cd>an iron plate upon
which a section of a loam mold rests, or from which it is
suspended.</cd> -- <col><b>Loam work</b></col>, <cd>loam molding or loam
molds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loam</ent><br/
<hw>Loam</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Loamed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loaming</conjf>.]</vmorph> <def>To cover, smear, or fill with
loam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>loamless</ent><br/
<hw>loamless</hw> <pos>adj.</pos> <def>having no loam; -- of soil;
<as>as, a stony <ex>loamless</ex> yard</as>. Contrasted with
<ant>loamy</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loamy</ent><br/
<hw>Loam"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of loam;
partaking of the nature of loam; resembling loam.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loan</ent><br/
<hw>Loan</hw> <pr>(l<omac/n)</pr>, <pos>n.</pos> <ety>[See
<er>Lawn</er>.]</ety> <def>A loanin.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loan</ent><br/
<hw>Loan</hw>, <pos>n.</pos> <ety>[OE. <ets>lone</ets>, <ets>lane</ets>,
AS. <ets>l<amac/n</ets>, <ets>l<ae/n</ets>, fr. <ets>le<iacute/n</ets>
to lend; akin to D. <ets>leen</ets> loan, fief, G. <ets>lehen</ets>
fief, Icel. <ets>l<amac/n</ets>, G. <ets>leihen</ets> to lend, OHG.
<ets>l<imac/han</ets>, Icel. <ets>lj<imac/</ets>, Goth.
<ets>leihwan</ets>, L. <ets>linquere</ets> to leave, Gr.
<grk>lei`pein</grk>, Skr. <ets>ric</ets>. <root/119. Cf.
<er>Delinquent</er>, <er>Eclipse</er>, <er>Eleven</er>,
<er>Ellipse</er>, <er>Lend</er>, <er>License</er>,
<er>Relic</er>.]</ety> <sn>1.</sn> <def>The act of lending; a lending;
permission to use; <as>as, the <ex>loan</ex> of a book, money,
services</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which one lends or borrows, especially a sum of
money lent at interest; <as>as, he repaid the
<ex>loan</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Loan office</b></col>. <sd>(a)</sd> <cd>An office at
which loans are negotiated, or at which the accounts of loans are kept,
and the interest paid to the lender.</cd> <sd>(b)</sd> <cd>A
pawnbroker's shop.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loan</ent><br/
<hw>Loan</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Loaned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loaning</conjf>.]</vmorph> <def>To lend; -- sometimes with
<ptcl>out</ptcl>.</def> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By way of location or <qex>loaning</qex> them out.</q> <rj><qau>J.
Langley (1644).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loanable</ent><br/
<hw>Loan"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
lent; available for lending; <as>as, <ex>loanable</ex> funds</as>; --
used mostly in financial business and writings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>loanblend</ent><br/
<hw>loan"blend</hw> <pos>n.</pos> <def>a word that is composed of parts
from different languages; e.g. <examp>monolingual</examp> has a Greek
prefix and a Latin root.</def><br/
<syn><b>Syn. --</b> hybrid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loaner</ent><br/
<hw>loaner</hw> <pos>n.</pos> <sn>1.</sn> <def>someone who lends money
or gives credit in business matters.</def><br/
<syn><b>Syn. --</b> lender.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Something borrowed or lent.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Loaning</ent><br/
<ent>Loanin</ent><br/
<mhw>{ <hw>Loan"in</hw> <pr>(?)</pr>, <hw>Loan"ing</hw>, }</mhw>
<pos>n.</pos> <ety>[From Scotch <ets>loan</ets>, E.
<ets>lawn</ets>.]</ety> <def>An open space between cultivated fields
through which cattle are driven, and where the cows are sometimes
milked; also, a lane.</def> <mark>[Scot.]</mark> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loanmonger</ent><br/
<hw>Loan"mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dealer in, or
negotiator of, loans.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The millions of the <qex>loanmonger</qex>.</q>
<rj><qau>Beaconsfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loanword</ent><br/
<hw>loanword</hw> <pos>n.</pos> <def>a word borrowed from another
language; e.g. <examp>blitz</examp> is a German word borrowed into
modern English.</def><br/
<syn><b>Syn. --</b> loan.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loasa</ent><br/
<hw>loasa</hw> <pos>n.</pos> <def>any of various perennial South
American plants of the genus <gen>Loasa</gen> having stinging hairs and
showy white or yellow or reddish-orange flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loasaceae</ent><br/
<hw>Loasaceae</hw> <pos>n.</pos> <def>A natural family of bristly hairy
sometimes climbing plants; America and Africa and Southern
Arabia.</def><br/
<syn><b>Syn. --</b> family <fam>Loasaceae</fam>, loasa family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loath</ent><br/
<hw>Loath</hw> <pr>(l<omac/th)</pr>, <pos>a.</pos> <ety>[OE.
<ets>looth</ets>, <ets>loth</ets>, AS. <ets>l<amac/<edh/</ets> hostile,
odious; akin to OS. <ets>l<amac/<edh/</ets>, G. <ets>leid</ets>, Icel.
<ets>lei<edh/r</ets>, Sw. <ets>led</ets>, G. <ets>leiden</ets> to
suffer, OHG. <ets>l<imac/dan</ets> to suffer, go, cf. AS.
<ets>l<imac/<edh/an</ets> to go, Goth. <ets>leipan</ets>, and E.
<ets>lead</ets> to guide.]</ety> <sn>1.</sn> <def>Hateful; odious;
disliked.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Filled with disgust or aversion; averse; unwilling;
reluctant; <as>as, <ex>loath</ex> to part</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full <qex>loth</qex> were him to curse for his tithes.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why, then, though <qex>loath</qex>, yet must I be content.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathe</ent><br/
<hw>Loathe</hw> <pr>(l<omac/<th/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Loathed</conjf>
<pr>(l<omac/<th/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loathing</conjf>.]</vmorph> <ety>[AS. <ets>l<amac/<edh/ian</ets>
to hate. See <er>Loath</er>.]</ety> <sn>1.</sn> <def>To feel extreme
disgust at, or aversion for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Loathing</qex> the honeyed cakes, I Ionged for bread.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dislike greatly; to abhor; to hate; to
detest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The secret which I <qex>loathe</qex>.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>loathes</qex> the vital sir.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To hate; abhor; detest; abominate. See
<er>Hate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathe</ent><br/
<hw>Loathe</hw>, <pos>v. i.</pos> <def>To feel disgust or nausea.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loather</ent><br/
<hw>Loath"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
loathes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathful</ent><br/
<hw>Loath"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
loathing; hating; abhorring.</def> <ldquo/<xex>Loathful</xex>
eyes.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Causing a feeling of loathing; disgusting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Above the reach of <qex>loathful</qex>, sinful lust.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathing</ent><br/
<hw>Loath"ing</hw>, <pos>n.</pos> <def>Extreme disgust; a feeling of
aversion, nausea, abhorrence, or detestation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mutual fear and <qex>loathing</qex> of the hostile races.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathingly</ent><br/
<hw>Loath"ing*ly</hw>, <pos>adv.</pos> <def>With loathing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathliness</ent><br/
<hw>Loath"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Loathsomeness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathly</ent><br/
<hw>Loath"ly</hw> <pr>(l<omac/<th/"l<ycr/)</pr>, <pos>a.</pos> <ety>[AS.
<ets>l<amac/<edh/lic</ets>.]</ety> <def>Loathsome.</def>
<mark>[Obs.]</mark> <ldquo/ <xex>Loathly</xex> mouth.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathly</ent><br/
<hw>Loath"ly</hw> <pr>(l<omac/th"l<ycr/)</pr>, <pos>adv.</pos>
<sn>1.</sn> <def>Unwillingly; reluctantly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This shows that you from nature <qex>loathly</qex> stray.</q>
<rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pr>(l<omac/<th/"l<ycr/)</pr> <def>So as to cause
loathing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With dust and blood his locks were <qex>loathly</qex> dight.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathness</ent><br/
<hw>Loath"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Unwillingness;
reluctance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A general silence and <qex>loathness</qex> to speak.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathsome</ent><br/
<hw>Loath"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fitted to cause
loathing; exciting disgust; disgusting; <as>as, a <ex>loathsome</ex>
disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most <qex>loathsome</qex> and deadly forms of infection.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p>-- <wordforms><wf>Loath"some*ly</wf>. <pos>adv.</pos> --
<wf>Loath"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loathy</ent><br/
<hw>Loath"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Loathsome.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loaves</ent><br/
<hw>Loaves</hw> <pr>(?)</pr>, <pos>n.</pos>; <def><pos>pl.</pos> of
<er>Loaf</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lob</ent><br/
<hw>Lob</hw> <pr>(l<ocr/b)</pr>, <pos>n.</pos> <ety>[W. <ets>llob</ets>
an unwieldy lump, a dull fellow, a blockhead. Cf. <er>Looby</er>,
<er>Lubber</er>.]</ety> <sn>1.</sn> <def>A dull, heavy person.</def>
<ldquo/ Country <xex>lobs</xex>.<rdquo/ <rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something thick and heavy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lob</ent><br/
<hw>Lob</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lobbed</conjf> <pr>(l<ocr/bd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lobbing</conjf>.]</vmorph> <sn>2.</sn> <def>To let fall heavily
or lazily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And their poor jades<br/
<qex>Lob</qex> down their heads.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to propel (relatively slowly) in a high arcing
trajectory; <as>as, to <ex>lob</ex> a grenade at the
enemy</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To lob a ball</b></col> <fld>(Lawn Tennis)</fld>, <cd>to
strike a ball so as to send it up into the air.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lob</ent><br/
<hw>Lob</hw>, <pos>v. t.</pos> <fld>(Mining)</fld> <def>See
<er>Cob</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lob</ent><br/
<hw>Lob</hw>, <pos>n.</pos> <ety>[Dan. <ets>lubbe</ets>.]</ety>
<fld>(Zool.)</fld> <def>The European pollock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lob</ent><br/
<hw>Lob</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of lobbing;</def>
<specif>specif.,</specif> <def>an (often gentle) stroke which sends a
ball up into the air, as in tennis to avoid a player at the
net.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lobar</ent><br/
<hw>Lo"bar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to a
lobe; characterized by, or like, a lobe or lobes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobated</ent><br/
<ent>Lobate</ent><br/
<mhw>{ <hw>Lo"bate</hw> <pr>(?)</pr>, <hw>Lo"ba*ted</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[See <er>Lobe</er>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Consisting of, or having, lobes; lobed; <as>as, a
<ex>lobate</ex> leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Having lobes; --
said of the tails of certain fishes having the integument continued to
the bases of the fin rays.</def> <sd>(b)</sd> <def>Furnished with
membranous flaps, as the toes of a coot. See <xex>Illust.</xex>
<iref>(m)</iref> under <er>Aves</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobately</ent><br/
<hw>Lo"bate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>As a lobe; so as
to make a lobe; in a lobate manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobbish</ent><br/
<hw>Lob"bish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a lob;
consisting of lobs.</def> <rj><au>Sir. P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobby</ent><br/
<hw>Lob"by</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lobbies</plw> <pr>(#)</pr>.</plu> <ety>[LL. <ets>lobium</ets>,
<ets>lobia</ets>, <ets>laubia</ets>, a covered portico fit for walking,
fr. OHG. <ets>louba</ets>, G. <ets>laube</ets>, arbor. See
<er>Lodge</er>.]</ety> <sn>1.</sn> <fld>(Arch.)</fld> <def>A passage or
hall of communication, especially when large enough to serve also as a
waiting room. It differs from an <xex>antechamber</xex> in that a
<xex>lobby</xex> communicates between several rooms, an
<xex>antechamber</xex> to one only; but this distinction is not
carefully preserved.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That part of a hall of legislation not appropriated
to the official use of the assembly; hence, the persons, collectively,
who frequent such a place to transact business with the
legislators;</def> <specif>hence:</specif> <def>any persons, not members
of a legislative body, who strive to influence its proceedings by
personal agency; a group of lobbyists for a particular cause; <as>as,
the drug industry <ex>lobby</ex></as>.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>An apartment or passageway in the
fore part of an old-fashioned cabin under the quarter-deck.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Agric.)</fld> <def>A confined place for cattle,
formed by hedges. trees, or other fencing, near the farmyard.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lobby member</b></col>, <cd>a lobbyist.</cd>
<mark>[Humorous cant, U. S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobby</ent><br/
<hw>Lob"by</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lobbied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lobbying</conjf>.]</vmorph> <def>To address or solicit members of
a legislative body in the lobby or elsewhere, with the purpose to
influence their votes; in an extended sense, to try to influence
decision-makers in any circumstance.</def> <mark>[U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobby</ent><br/
<hw>Lob"by</hw>, <pos>v. t.</pos> <def>To urge the adoption or passage
of by soliciting members of a legislative body; <as>as, to
<ex>lobby</ex> a bill</as>; -- also used with the legislators as object;
<as>as, to lobby the state legislatuire for protection</as>.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobbyist</ent><br/
<hw>Lob"by*ist</hw>, <pos>n.</pos> <def>A member of the lobby; a person
who solicits members of a legislature for the purpose of influencing
legislation.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobcock</ent><br/
<hw>Lob"cock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dull, sluggish
person; a lubber; a lob.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobe</ent><br/
<hw>Lobe</hw> <pr>(l<omac/b)</pr>, <pos>n.</pos> <ety>[F.
<ets>lobe</ets>, Gr. <grk>lobo`s</grk>.]</ety> <def>Any projection or
division, especially one of a somewhat rounded form</def>; as:
<sd>(a)</sd> <fld>(Bot.)</fld> <def>A rounded projection or division of
a leaf.</def> <au>Gray.</au> <sd>(b)</sd><fld>(Zool.)</fld> <def>A
membranous flap on the sides of the toes of certain birds, as the
coot.</def> <sd>(c)</sd> <fld>(Anat.)</fld> <def>A round projecting part
of an organ, as of the liver, lungs, brain, etc. See <xex>Illust.</xex>
of <er>Brain</er>.</def> <sd>(b)</sd> <fld>(Mach.)</fld> <def>The
projecting part of a cam wheel or of a non-circular gear
wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lobe of the ear</b></col>, <cd>the soft, fleshy
prominence in which the human ear terminates below, also called the
<altname>earlobe</altname>. See. <xex>Illust.</xex> of
<er>Ear</er>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>lobectomy</ent><br/
<hw>lobectomy</hw> <pos>n.</pos> <def>surgical removal of a lobe from
any organ of the body (such as the lung or brain).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lobed</ent><br/
<hw>Lobed</hw> <pr>(l<omac/bd)</pr>, <pos>a.</pos> <def>Having lobes;
lobate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobefoot</ent><br/
<hw>Lobe"foot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A bird having lobate toes; esp., a phalarope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobe-footed</ent><br/
<hw>Lobe"-foot`ed</hw>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Lobiped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobelet</ent><br/
<hw>Lobe"let</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
small lobe; a lobule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobelia</ent><br/
<hw>Lo*be"li*a</hw> <pr>(?; 106)</pr>, <pos>n.</pos> <ety>[NL. So called
from <etsep>Lobel</etsep>, botanist to King James I.]</ety>
<fld>(Bot.)</fld> <def>A genus of plants, including a great number of
species. <spn>Lobelia inflata</spn>, or Indian tobacco, is an annual
plant of North America, whose leaves contain a poisonous white viscid
juice, of an acrid taste. It has often been used in medicine as an
emetic, expectorant, etc. <spn>Lobelia cardinalis</spn> is the cardinal
flower, remarkable for the deep and vivid red color of its
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobeliaceae</ent><br/
<hw>Lobeliaceae</hw> <pos>n.</pos> <def>A natural family of plants not
recognized in all classification systems; in some classifications
lobeliaceous plants are included in family
<fam>Campanulaceae</fam>.</def><br/
<syn><b>Syn. --</b> family <fam>Lobeliaceae</fam>, lobelia
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lobeliaceous</ent><br/
<hw>Lo*be`li*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Of or pertaining to a natural order of plants of which the genus
<gen>Lobelia</gen> is the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobelin</ent><br/
<hw>Lo*be"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld> <def>A
yellowish green resin from <gen>Lobelia</gen>, used as an emetic and
diaphoretic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobeline</ent><br/
<hw>Lo*be"line</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A poisonous narcotic alkaloid extracted from the leaves of Indian
tobacco (<spn>Lobelia inflata</spn>) as a yellow oil, having a
tobaccolike taste and odor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobiped</ent><br/
<hw>Lo"bi*ped</hw>, <pos>a.</pos> <ety>[<ets>Lobe</ets> + L.
<ets>pes</ets>, <ets>pedis</ets>, foot.]</ety> <fld>(Zool.)</fld>
<def>Having lobate toes, as a coot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loblolly</ent><br/
<hw>Lob"lol`ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>Gruel; porridge; -- so called among
seamen.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Loblolly bay</b></col> <fld>(Bot.)</fld>, <cd>an elegant
white-flowered evergreen shrub or small tree, of the genus
<gen>Gordonia</gen> (<spn>Gordonia Lasianthus</spn>), growing in the
maritime parts of the Southern United States. Its bark is sometimes used
in tanning. Also, a similar West Indian tree (<spn>Laplacea
h<ae/matoxylon</spn>).</cd> -- <col><b>Loblolly boy</b></col>, <cd>a
surgeon's attendant on shipboard.</cd> <au>Smollett.</au> --
<col><b>Loblolly pine</b></col> <fld>(Bot.)</fld>, <cd>a kind of pitch
pine found from Delaware southward along the coast; old field pine
(<spn>Pinus T<ae/da</spn>). Also, <spn>Pinus Bahamensis</spn>, of the
West Indies.</cd> -- <col><b>Loblolly tree</b></col> <fld>(Bot.)</fld>,
<cd>a name of several West Indian trees, having more or less leathery
foliage, but alike in no other respect; as <spn>Pisonia
subcordata</spn>, <spn>Cordia alba</spn>, and <spn>Cupania
glabra</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobosa</ent><br/
\'d8<hw>Lo*bo"sa</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Lobe</er>.]</ety> <fld>(Zool.)</fld> <def>An order of Rhizopoda, in
which the pseudopodia are thick and irregular in form, as in the
<it>Am<oe/ba</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobotes</ent><br/
<hw>Lobotes</hw> <pos>n.</pos> <def>The type genus of the
<fam>Lobotidae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lobotes</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lobotidae</ent><br/
<hw>Lobotidae</hw> <pos>n.</pos> <def>A natural family of fishes
including the tripletails.</def><br/
<syn><b>Syn. --</b> family <fam>Lobotidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lobotomy</ent><br/
<hw>lobotomy</hw> <pos>n.</pos> <fld>(Med., Surgery)</fld> <def>The
surgical interruption of nerve tracts to and from the frontal lobe of
the brain, by cutting into the brain.</def><br/
<syn><b>Syn. --</b> prefrontal lobotomy, prefrontal leucotomy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lobscouse</ent><br/
<hw>Lob"scouse`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>lobscourse</ets> from which <ets>lobscouse</ets> is
corrupted.]</ety> <ety>[<ets>Lob</ets> + <ets>course</ets>.]</ety>
<fld>(Naut.)</fld> <def>A combination of meat with vegetables, bread,
etc., usually stewed, sometimes baked; an olio.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobsided</ent><br/
<hw>Lob"sid`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Lopsided</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobspound</ent><br/
<hw>Lobs"pound`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lob</ets> +
<ets>pound</ets> a prison.]</ety> <def>A prison.</def>
<mark>[Obs.]</mark> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobster</ent><br/
<hw>Lob"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>loppestre</ets>, <ets>lopystre</ets> prob., corrupted fr. L.
<ets>locusta</ets> a marine shellfish, a kind of lobster, a locust. Cf.
<er>Locust</er>.]</ety> <fld>(Zool.)</fld> <sn>1.</sn> <def>Any large
macrurous crustacean used as food, esp. those of the genus
<gen>Homarus</gen>; as the American lobster (<spn>Homarus
Americanus</spn>), and the European lobster (<spn>Homarus
vulgaris</spn>). The Norwegian lobster (<spn>Nephrops Norvegicus</spn>)
is similar in form. All these have a pair of large unequal claws. The
spiny lobsters of more southern waters, belonging to
<gen>Palinurus</gen>, <gen>Panulirus</gen>, and allied genera, have no
large claws. The fresh-water crayfishes are sometimes called
<ex>lobsters</ex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>As a term of opprobrium or contempt: A gullible,
awkward, bungling, or undesirable person.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Lobster caterpillar</b></col> <fld>(Zool.)</fld>, <cd>the
caterpillar of a European bombycid moth (<spn>Stauropus fagi</spn>); --
so called from its form.</cd> <col><b>Lobster louse</b></col>
<fld>(Zool.)</fld>, <cd>a copepod crustacean (<spn>Nicotho<eum/
astaci</spn>) parasitic on the gills of the European
lobster.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lobsterback</ent><br/
<hw>lobsterback</hw> <pos>n.</pos> <fld>(American History)</fld> <def>A
British soldier in the 1700's; -- so-called because of his red coat,
esp. during the American Revolutionary War.</def><br/
<syn><b>Syn. --</b> redcoat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lobster-backed</ent><br/
<hw>lobster-backed</hw> <pos>adj.</pos> <fld>(American History)</fld>
<def>Of or pertaining to British soldiers during the Revolutionary War
in America; -- so called because of their red coats.</def><br/
<syn><b>Syn. --</b> red-coated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lobster pot</ent><br/
<hw>Lob"ster pot</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a device used to
trap lobsters, consisting of a semi-cylindrical structure made of wooden
slats, with openings formed of funnel-shaped nets allowing lobsters to
enter, but impeding their exit. It is also called a <altname>lobster
trap</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lobsters thermidor</ent><br/
<ent>Lobster thermidor</ent><br/
<mhw><hw>Lob"ster ther"mi*dor</hw>, <hw>Lob"sters ther"mi*dor</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <def>a dish of lobster meat cooked with a
rich creamy wine sauce, stuffed back into the lobster shell, sprinkled
with grated cheese, and browned.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lobster trap</ent><br/
<hw>Lob"ster trap</hw> <pr>(?)</pr>, <pos>n.</pos> <def>same as
<er>lobster pot</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lobular</ent><br/
<hw>Lob"u*lar</hw>, <pos>a.</pos> <ety>[Cf. F.
<ets>lobulaire</ets>.]</ety> <def>Like a lobule; pertaining to a lobule
or lobules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lobularity</ent><br/
<hw>lobularity</hw> <pos>n.</pos> <def>the property of having
lobules.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lobulated</ent><br/
<ent>Lobulate</ent><br/
<mhw>{ <hw>Lob"u*late</hw> <pr>(?)</pr>, <hw>Lob"u*la`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Made up of, or divided into,
lobules; <as>as, a <ex>lobulated</ex> gland</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobule</ent><br/
<hw>Lob"ule</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>lobule</ets>, dim. of
<ets>lobe</ets>. See <er>Lobe</er>.]</ety> <def>A small lobe; a
subdivision of a lobe.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lobule of the ear</b></col>. <fld>(Anat.)</fld> <cd>Same
as <cref>Lobe of the ear</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobulette</ent><br/
<hw>Lob`u*lette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>lobule</ets>.]</ety> <fld>(Anat.)</fld> <def>A little lobule, or
subdivision of a lobule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lobworm</ent><br/
<hw>Lob"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The lugworm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Local</ent><br/
<hw>Lo"cal</hw> <pr>(l<omac/"k<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>localis</ets>, fr. <ets>locus</ets> place: cf. F. <ets>local</ets>.
See <er>Lieu</er>, <er>Locus</er>.]</ety> <def>Of or pertaining to a
particular place, or to a definite region or portion of space;
restricted to one place or region; <as>as, a <ex>local</ex>
custom</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gives to airy nothing<br/
A <qex>local</qex> habitation and a name.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Local actions</b></col> <fld>(Law)</fld>, <cd>actions
such as must be brought in a particular county, where the cause arises;
-- distinguished from <contr>transitory actions</contr>.</cd> --
<col><b>Local affection</b></col> <fld>(Med.)</fld>, <cd>a disease or
ailment confined to a particular part or organ, and not directly
affecting the system.</cd> -- <col><b>Local attraction</b></col>
<fld>(Magnetism)</fld>, <cd>an attraction near a compass, causing its
needle to deviate from its proper direction, especially on
shipboard.</cd> -- <col><b>Local battery</b></col> <fld>(Teleg.)</fld>,
<cd>the battery which actuates the recording instruments of a
telegraphic station, as distinguished from the battery furnishing a
current for the line.</cd> -- <col><b>Local circuit</b></col>
<fld>(Teleg.)</fld>, <cd>the circuit of the local battery.</cd> --
<col><b>Local color</b></col>. <sd>(a)</sd> <fld>(Paint.)</fld> <cd>The
color which belongs to an object, and is not caused by accidental
influences, as of reflection, shadow, etc.</cd> <sd>(b)</sd>
<fld>(Literature)</fld> <cd>Peculiarities of the place and its
inhabitants where the scene of an action or story is laid.</cd> --
<col><b>Local option</b></col>, <cd>the right or obligation of
determining by popular vote within certain districts, as in each county,
city, or town, whether the sale of alcoholic beverages within the
district shall be allowed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Local</ent><br/
<hw>Lo"cal</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Railroad)</fld> <def>A
train which receives and deposits passengers or freight along the line
of the road; a train for the accommodation of a certain district.</def>
<mark>[U.S.]</mark></p>

<p><sn>2.</sn> <def>In newspaper cant, an item of news relating to the
place where the paper is published.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A train or bus which stops at all stations along a
line, as contrasted with an <contr>express</contr>, which stops only at
certain stations designated as express stops.</def><br/
[<source>PJC</source>]</p>

<p><ent>Locale</ent><br/
\'d8<hw>Lo`cale"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>local</ets>.]</ety> <sn>1.</sn> <def>A place, spot, or
location.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A principle, practice, form of speech, or other
thing of local use, or limited to a locality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>localisation</ent><br/
<hw>localisation</hw> <pos>n.</pos> <def>Same as
<er>localization</er>.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> , location, locating, fix.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>localise</ent><br/
<hw>localise</hw> <pos>v. t.</pos> <def>Same as <er>localize</er>.</def>
<mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> localize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Localism</ent><br/
<hw>Lo"cal*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state or quality of being local; affection for a particular
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A method of speaking or acting peculiar to a certain
district; a local idiom or phrase.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locality</ent><br/
<hw>Lo*cal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Localitiees</plw> <pr>(<?/)</pr>.</plu> <ety>[L.
<ets>localitas</ets>: cf. F. <ets>localit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The state, or condition, of belonging to a definite
place, or of being contained within definite limits.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is thought that the soul and angels are devoid of quantity<br/
and dimension, and that they have nothing to do with grosser
<qex>locality</qex>.</q> <rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 864 --></p>

<p><sn>2.</sn> <def>Position; situation; a place; a spot; esp., a
geographical place or situation, as of a mineral or plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Limitation to a county, district, or place; <as>as,
<ex>locality</ex> of trial</as>.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Phren.)</fld> <def>The perceptive faculty concerned
with the ability to remember the relative positions of places.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Localization</ent><br/
<hw>Lo`cal*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>localisation</ets>.]</ety> <def>Act of localizing, or state of
being localized.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cerebral localization</b></col> <fld>(Physiol.)</fld>,
<cd>the localization of the control of special functions, as of sight or
of the various movements of the body, in special regions of the
brain.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Localize</ent><br/
<hw>Lo"cal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Localized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Localizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>localiser</ets>. See <er>Local</er>.]</ety> <def>To make local; to
fix in, or assign to, a definite place.</def> <rj><au>H. Spencer.</au>
<au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>localized</ent><br/
<hw>localized</hw> <pos>adj.</pos> <sn>1.</sn> <fld>(Medicine)</fld>
<def>confined or restricted to a particular location; <as>as, the
<ex>localized</ex> infection formed a definite abscess</as>. Contrasted
with <contr>disseminated</contr> or <contr>systemic</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>made local or oriented locally; <as>as, a
decentralized and <ex>localized</ex> political authority</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Locally</ent><br/
<hw>Lo"cal*ly</hw>, <pos>adv.</pos> <def>With respect to place; in
place; <as>as, to be <ex>locally</ex> separated or
distant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locate</ent><br/
<hw>Lo"cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Located</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Locating</conjf>.]</vmorph> <ety>[L. <ets>locatus</ets>, p. p. of
<ets>locare</ets> to place, fr. <ets>locus</ets> place. See
<er>Local</er>.]</ety> <sn>1.</sn> <def>To place; to set in a particular
spot or position.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The captives and emigrants whom he brought with him were
<qex>located</qex> in the trans-Tiberine quarter.</q> <rj><qau>B. F.
Westcott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To designate the site or place of; to define the
limits of; <as>as, to <ex>locate</ex> a public building; to
<ex>locate</ex> a mining claim; to <ex>locate</ex> (the land granted by)
a land warrant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>That part of the body in which the sense of touch is
<qex>located</qex>.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To discover the location or site of; <as>as, to
<ex>locate</ex> the source of a radio transmission; to <ex>locate</ex> a
leak; to <ex>locate</ex> the malfunction in a system</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Locate</ent><br/
<hw>Lo"cate</hw>, <pos>v. i.</pos> <def>To place one's self; to take up
one's residence; to settle; <as>as, to <ex>locate</ex> in
Seattle</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>located</ent><br/
<hw>located</hw> <pos>adj.</pos> <sn>1.</sn> <def>situated in a
particular spot or position; <as>as, valuable centrally <ex>located</ex>
urban land</as>.</def><br/
<syn><b>Syn. --</b> placed, set, situated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>situated: often used in combination; <as>as, a
well-<ex>located</ex> business</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>locating</ent><br/
<hw>locating</hw> <pos>n.</pos> <sn>1.</sn> <def>the act of putting
something in a certain place or location.</def><br/
<syn><b>Syn. --</b> location, placement, position, positioning,
emplacement, situating.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a determination of the location of
something.</def><br/
<syn><b>Syn. --</b> localization, localisation, location, fix.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Location</ent><br/
<hw>Lo*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>locatio</ets>, fr. <ets>locare</ets>.]</ety> <sn>1.</sn> <def>The
act or process of locating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Situation; place; locality.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is located; a tract of land designated in
place.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <sd>(a)</sd> <fld>(Civil Law)</fld>
<def>A leasing on rent.</def> <sd>(b)</sd> <fld>(Scots Law)</fld> <def>A
contract for the use of a thing, or service of a person, for hire.</def>
<au>Wharton.</au> <sd>(c)</sd> <fld>(Amer. Law)</fld> <def>The marking
out of the boundaries, or identifying the place or site of, a piece of
land, according to the description given in an entry, plan, map,
etc.</def> <rj><au>Burrill. Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locative</ent><br/
<hw>Loc"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Gram.)</fld>
<def>Indicating place, or the place where, or wherein; <as>as, a
<ex>locative</ex> adjective; <ex>locative</ex> case of a
noun.</as></def> -- <def2><pos>n.</pos> <def>The locative
case.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locator</ent><br/
<hw>Lo"ca*tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who locates, or
is entitled to locate, land or a mining claim.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locellate</ent><br/
<hw>Lo*cel"late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>locellus</ets> a compartment, dim. of <ets>locus</ets> a
place.]</ety> <fld>(Bot.)</fld> <def>Divided into secondary compartments
or cells, as where one cavity is separated into several smaller
ones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loch</ent><br/
<hw>Loch</hw> <pr>(l<ocr/k)</pr>, <pos>n.</pos> <ety>[Gael. & Olr.
<ets>loch</ets>. See <er>Lake</er> of water.]</ety> <def>A lake; a bay
or arm of the sea.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loch</ent><br/
<hw>Loch</hw> <pr>(l<ocr/k)</pr>, <pos>n.</pos> <ety>[F.
<ets>looch</ets>, Ar. <ets>la'<umac/g</ets>, an electuary, or any
medicine which may be licked or sucked, fr. <ets>la'<umac/q</ets> to
lick.]</ety> <fld>(Med.)</fld> <def>A kind of medicine to be taken by
licking with the tongue; a lambative; a lincture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lochaber axe</ent><br/
<ent>Lochaber ax</ent><br/
<mhw>{ <hw>Loch*a"ber ax"</hw>, <hw>Loch*a"ber axe"</hw> }</mhw>
<pr>(?)</pr> <pos>n.</pos> <ety>[So called from <etsep>Lochaber</etsep>,
in Scotland.]</ety> <def>A weapon of war, consisting of a pole armed
with an axhead at its end, formerly used by the Scotch
Highlanders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lochage</ent><br/
<hw>Loch"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.<?/.]</ety>
<fld>(Gr. Antiq.)</fld> <def>An officer who commanded a company; a
captain.</def> <rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lochan</ent><br/
<hw>Loch"an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gael. See 1st
<er>Loch</er>.]</ety> <def>A small lake; a pond.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A pond or <qex>lochan</qex> rather than a lake.</q> <rj><qau>H.
Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loche</ent><br/
<hw>Loche</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Loach</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lochia</ent><br/
\'d8<hw>Lo*chi"a</hw> <pr>(l<omac/"k<icr/*<adot/ <it>or</it>
l<osl/*k<imac/"<adot/)</pr>, <pos>n. pl.</pos> <ety>[NL., from Gr. <?/,
pl., fr. <?/ belonging to childbirth, <?/ a lying in, childbirth.]</ety>
<fld>(Med.)</fld> <def>The discharge from the womb and vagina which
follows childbirth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lochial</ent><br/
<hw>Lo"chi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lochial</ets>.]</ety> <def>Of or pertaining to the
lochia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lock</ent><br/
<hw>Lock</hw> <pr>(l<ocr/k)</pr>, <pos>n.</pos> <ety>[AS.
<ets>locc</ets>; akin to D. <ets>lok</ets>, G. <ets>locke</ets>, OHG.
loc, Icel. <ets>lokkr</ets>, and perh. to Gr. <?/ to bend, twist.]</ety>
<def>A tuft of hair; a flock or small quantity of wool, hay, or other
like substance; a tress or ringlet of hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These gray <qex>locks</qex>, the pursuivants of death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lock</ent><br/
<hw>Lock</hw>, <pos>n.</pos> <ety>[AS. <ets>loc</ets> inclosure, an
inclosed place, the fastening of a door, fr. <ets>l<umac/can</ets> to
lock, fasten; akin to OS. <ets>l<umac/kan</ets> (in comp.), D.
<ets>luiken</ets>, OHG. <ets>l<umac/hhan</ets>, Icel.
<ets>l<umac/ka</ets>, Goth. <ets>l<umac/kan</ets> (in comp.); cf. Skr.
<ets>ruj</ets> to break. Cf. <er>Locket</er>.]</ety> <sn>1.</sn>
<def>Anything that fastens; specifically, a fastening, as for a door, a
lid, a trunk, a drawer, and the like, in which a bolt is moved by a key
so as to hold or to release the thing fastened.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fastening together or interlacing; a closing of
one thing upon another; a state of being fixed or immovable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Albemarle Street closed by a <qex>lock</qex> of carriages.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place from which egress is prevented, as by a
lock.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The barrier or works which confine the water of a
stream or canal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An inclosure in a canal with gates at each end, used
in raising or lowering boats as they pass from one level to another; --
called also <altname>lift lock</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That part or apparatus of a firearm by which the
charge is exploded; <as>as, a match<ex>lock</ex>, flint<ex>lock</ex>,
percussion <ex>lock</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A device for keeping a wheel from turning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A grapple in wrestling.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Detector lock</b></col>, <cd>a lock containing a
contrivance for showing whether it as has been tampered with.</cd> --
<col><b>Lock bay</b></col> <fld>(Canals)</fld>, <cd>the body of water in
a lock chamber.</cd> -- <col><b>Lock chamber</b></col>, <cd>the inclosed
space between the gates of a canal lock.</cd> -- <col><b>Lock
nut</b></col>. <cd>See <cref>Check nut</cref>, under
<er>Check</er>.</cd> -- <col><b>Lock plate</b></col>, <cd>a plate to
which the mechanism of a gunlock is attached.</cd> -- <col><b>Lock
rail</b></col> <fld>(Arch.)</fld>, <cd>in ordinary paneled doors, the
rail nearest the lock.</cd> <col><b>Lock rand</b></col>
<fld>(Masonry)</fld>, <cd>a range of bond stone.</cd> <au>Knight.</au>
-- <col><b>Mortise lock</b></col>, <cd>a door lock inserted in a
mortise.</cd> -- <col><b>Rim lock</b></col>, <cd>a lock fastened to the
face of a door, thus differing from a <cref>mortise
lock</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lock</ent><br/
<hw>Lock</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Locked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Locking</conjf>.]</vmorph> <sn>1.</sn> <def>To fasten with a
lock, or as with a lock; to make fast; to prevent free movement of;
<as>as, to <ex>lock</ex> a door, a carriage wheel, a river,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To prevent ingress or access to, or exit from, by
fastening the lock or locks of; -- often with <ptcl>up</ptcl>; <as>as,
to <ex>lock</ex> or <ex>lock up</ex>, a house, jail, room, trunk</as>.
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fasten in or out, or to make secure by means of,
or as with, locks; to confine, or to shut in or out -- often with
<ptcl>up</ptcl>; <as>as, to <ex>lock</ex> one's self in a room; to
<ex>lock</ex> up the prisoners; to <ex>lock</ex> up one's silver; to
<ex>lock</ex> intruders out of the house; to <ex>lock</ex> money into a
vault; to <ex>lock</ex> a child in one's arms; to <ex>lock</ex> a secret
in one's breast.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To link together; to clasp closely; <as>as, to
<ex>lock</ex> arms</as>.</def> <ldquo/ <xex>Lock</xex> hand in
hand.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Canals)</fld> <def>To furnish with locks; also, to
raise or lower (a boat) in a lock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Fencing)</fld> <def>To seize, as the sword arm of
an antagonist, by turning the left arm around it, to disarm
him.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lock</ent><br/
<hw>Lock</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To become fast, as by
means of a lock or by interlacing; <as>as, the door <ex>locks</ex>
close</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When it <qex>locked</qex> none might through it pass.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lock into</b></col>, <cd>to fit or slide into; <as>as,
they <ex>lock into</ex> each other</as>.</cd>
<rj><au>Boyle.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lockage</ent><br/
<hw>Lock"age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Materials
for locks in a canal, or the works forming a lock or locks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Toll paid for passing the locks of a
canal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Amount of elevation and descent made by the locks of
a canal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The entire <qex>lock</qex> will be about fifty feet.</q>
<rj><qau>De Witt Clinton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lockbox</ent><br/
<hw>lock"box`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A box of strong and
durable construction, fitted with a lock, used for the purpose of
protecting valuable items, such as money or jewelry; a
strongbox.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lock-down</ent><br/
<hw>Lock"-down`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A contrivance to
fasten logs together in rafting; -- used by lumbermen.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locked-jaw</ent><br/
<hw>Locked"-jaw`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lockjaw</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locken</ent><br/
<hw>Lock"en</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos>
of <er>Lock</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locken</ent><br/
<hw>Lock"en</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The globeflower
(<gen>Trollius</gen>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locker</ent><br/
<hw>Lock"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, locks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A drawer, cupboard, compartment, or chest, esp. one
in a ship, that may be closed with a lock.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chain locker</b></col> <fld>(Naut.)</fld>, <cd>a
compartment in the hold of a vessel, for holding the chain cables.</cd>
-- <mcol><col><b>Davy Jones's locker</b></col>, <it>or</it>
<col><b>Davy's locker</b></col></mcol>. <cd>See <er>Davy
Jones</er>.</cd> -- <col><b>Shot locker</b></col>, <cd>a compartment
where shot are deposited.</cd> <rj><au>Totten.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locket</ent><br/
<hw>Lock"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>loquet</ets>
latch, dim. of OF. <ets>loc</ets> latch, lock; of German origin. See
<er>Lock</er> a fastening.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A small lock; a catch or spring to fasten a necklace
or other ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little case for holding a miniature picture or
lock of hair, usually suspended from a necklace or watch
chain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lock-gate</ent><br/
<hw>lock-gate</hw> <pos>n.</pos> <def>a gate that can be
locked.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lock hospital</ent><br/
<hw>Lock" hos"pi*tal</hw> <pr>(?)</pr> <pos>n.</pos> <def>A hospital for
the treatment of venereal diseases.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lockjaw</ent><br/
<hw>Lock"jaw`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld> <def>A
contraction of the muscles of the jaw by which its motion is suspended;
a variety of tetanus; trismus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lockless</ent><br/
<hw>Lock"less</hw>, <pos>a.</pos> <def>Destitute of a lock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lockman</ent><br/
<hw>Lock"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A public
executioner.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>lockmaster</ent><br/
<hw>lockmaster</hw> <pos>n.</pos> <def>a worker in charge of a lock (on
a canal).</def><br/
<syn><b>Syn. --</b> lockman, lockkeeper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lock nut</ent><br/
<ent>locknut</ent><br/
<mhw><hw>locknut</hw>, <hw>lock nut</hw></mhw> <pos>n.</pos> <def>a
supplementary nut that is screwed down on a primary nut to prevent it
from loosening; a check nut.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lockout</ent><br/
<hw>Lock"out`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The closing of a
factory or workshop by an employer, usually in order to bring the
workmen to satisfactory terms by a suspension of wages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lockram</ent><br/
<hw>Lock"ram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>locrenan</ets>, <ets>locronan</ets>; from <ets>Locronan</ets>, in
Brittany, where it is said to have been made.]</ety> <def>A kind of
linen cloth anciently used in England, originally imported from
Brittany.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locksmith</ent><br/
<hw>Lock"smith`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person whose
occupation is to make, mend, or install locks, or to make keys for
locks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lock step</ent><br/
<hw>Lock" step`</hw> <pr>(?)</pr> <pos>n.</pos> <sn>1.</sn> <def>A mode
of marching by a body of men going one after another as closely as
possible, in which the leg of each moves at the same time with the
corresponding leg of the person before him.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>(fig.)</mark> <def>The
slavish copying of one person's actions by another; <as>as, party
members who vote in <ex>lockstep</ex> with the
leadership</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lock stitch</ent><br/
<hw>Lock" stitch`</hw> <pr>(?)</pr> <pos>n.</pos> <def>A peculiar sort
of stitch formed by the locking of two threads together, as in the work
done by some sewing machines. See <er>Stitch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lockup</ent><br/
<hw>Lock"up`</hw> <pr>(?)</pr>, <sn>1.</sn> <pos>n.</pos> <def>A place
where persons under arrest are temporarily locked up; a watchhouse; a
jail.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or state of temporary imprisonment in a
lockup{1}.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A malfunction in a machine having moving parts, such
that the moving part cannot move; a seizure.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lock washer</ent><br/
<hw>Lock" wash`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A washer that is
not completely smooth or flat, designed to prevent a nut from loosening,
placed under the nut on a screw or bolt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lock-weir</ent><br/
<hw>Lock"-weir`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A waste weir for a
canal, discharging into a lock chamber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locky</ent><br/
<hw>Lock"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having locks or
tufts.</def> <mark>[R.]</mark> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loco</ent><br/
\'d8<hw>Lo"co</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>A direction in written or printed music to return
to the proper pitch after having played an octave higher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loco</ent><br/
<hw>Lo"co</hw>, <pos>n.</pos> <ety>[Sp. <ets>loco</ets> insane.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A plant (<spn>Astragalus
Hornii</spn>) growing in the Southwestern United States, which is said
to poison horses and cattle, first making them insane. The name is also
given vaguely to several other species of the same genus. Called also
<altname>loco weed</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Any one of various leguminous
plants or weeds besides <gen>Astragalus</gen>, whose herbage is
poisonous to cattle, as <spn>Spiesia Lambertii</spn>, syn.
<spn>Oxytropis Lambertii</spn>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Loco</ent><br/
<hw>Lo"co</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Locoed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Locoing</conjf>.]</vmorph> <def>To poison with loco; to affect
with the loco disease; hence (<mark>Colloq.</mark>), to render insane or
mad.</def> <ldquo/The <xex>locoed</xex> novelist.<rdquo/ <rj><au>W. D.
Howells.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Loco</ent><br/
<hw>Lo"co</hw>, <pos>n.</pos> <def>A locomotive.</def>
<mark>[Colloq.]</mark> <rj><au>Kipling.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>loco</ent><br/
<hw>lo"co</hw>, <pos>a.</pos> <ety>[Sp. <ets>loco</ets> insane.]</ety>
<def>Insane; crazy.</def> <mark>[Originally Southwestern U. S., now
slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Loco disease</ent><br/
<hw>Loco disease</hw>. <fld>(Veter.)</fld> <def>A chronic nervous
affection of cattle, horses, and sheep, caused by eating the loco weed
and characterized by a slow, measured gait, high step, glassy eyes with
defective vision, delirium, and gradual emaciation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Locofoco</ent><br/
<hw>Lo`co*fo"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of uncertain
etymol.; perh. for L. <ets>loco foci</ets> instead of fire; or,
according to Bartlett, it was called so from a self-lighting cigar, with
a match composition at the end, invented in 1834 by <person>John
Marck</person> of New York, and called by him <ets>locofoco cigar</ets>,
in imitation of the word <ets>locomotive</ets>, which by the uneducated
was supposed to mean, self-moving.]</ety> <sn>1.</sn> <def>A friction
match.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A nickname formerly given to a member of the
Democratic party.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name was first applied, in 1834, to a portion of the
Democratic party, because, at a meeting in Tammany Hall, New York, in
which there was great diversity of sentiment, the chairman left his
seat, and the lights were extinguished, for the purpose of dissolving
the meeting; when those who were opposed to an adjournment produced
<xex>locofoco</xex> matches, rekindled the lights, continued the
meeting, and accomplished their object.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>locoism</ent><br/
<hw>locoism</hw> <pos>n.</pos> <def>a disease of livestock caused by
locoweed poisoning; characterized by weakness and lack of coordination
and trembling and partial paralysis.</def><br/
<syn><b>Syn. --</b> loco disease.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>locomote</ent><br/
<hw>locomote</hw> <pos>v. i.</pos> <ety>[by back-formation from
<ets>locomotion</ets>.]</ety> <def>To change location; move, travel, or
proceed.</def><br/
<syn><b>Syn. --</b> travel, go, move.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Locomotion</ent><br/
<hw>Lo`co*mo"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>locus</ets> place + <ets>motio</ets> motion: cf. F.
<ets>locomotion</ets>. See <er>Local</er>, and <er>Motion</er>.]</ety>
<sn>1.</sn> <def>The act of moving from place to place.</def> <ldquo/
Animal <xex>locomotion</xex>.<rdquo/ <au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power of moving from place to place,
characteristic of the higher animals and some of the lower forms of
plant life.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The name of a song and a dance, briefly popular in
the 1960's; <as>as, do the <ex>locomotion</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Locomotive</ent><br/
<hw>Lo"co*mo`tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>locomotif</ets>. See <er>Locomotion</er>.]</ety> <sn>1.</sn>
<def>Moving from place to place; changing place, or able to change
place; <as>as, a <ex>locomotive</ex> animal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Used in producing motion; <as>as, the
<ex>locomotive</ex> organs of an animal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locomotive</ent><br/
<hw>Lo"co*mo`tive</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A locomotive
engine; a self-propelling wheel carriage, especially one which bears a
steam boiler and one or more steam engines which communicate motion to
the wheels and thus propel the carriage, -- used to convey goods or
passengers, or to draw wagons, railroad cars, etc. See
<xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Consolidation locomotive</b></col>, <cd>a locomotive
having four pairs of connected drivers.</cd> -- <col><b>Locomotive
car</b></col>, <cd>a locomotive and a car combined in one vehicle; a
dummy engine.</cd> <mark>[U.S.]</mark> -- <col><b>Locomotive
engine</b></col>. <cd>Same as <er>Locomotive</er>, above.</cd> --
<col><b>Mogul locomotive</b></col>. <cd>See
<er>Mogul</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locomotivity</ent><br/
<ent>Locomotiveness</ent><br/
<mhw>{ <hw>Lo"co*mo`tive*ness</hw> <pr>(?)</pr>,
<hw>Lo`co*mo*tiv"i*ty</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf.
F. <ets>locomotivit<eacute/</ets>.]</ety> <def>The power of changing
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locomotor</ent><br/
<hw>Lo`co*mo"tor</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Locomotion</er>.]</ety> <def>Of or pertaining to movement or
locomotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Locomotor ataxia</b></col>, <it>or</it>
<col><b>Progressive locomotor ataxy</b></col></mcol> <fld>(Med.)</fld>,
<cd>a disease of the spinal cord characterized by peculiar disturbances
of gait, and difficulty in coordinating voluntary
movements.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loculament</ent><br/
<hw>Loc"u*la*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>loculamentum</ets> case, box, fr. <ets>loculus</ets> a compartment,
dim. of <ets>locus</ets> place.]</ety> <fld>(Bot.)</fld> <def>The cell
of a pericarp in which the seed is lodged.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locular</ent><br/
<hw>Loc"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>locularis</ets>.]</ety> <fld>(Bot.)</fld> <def>Of or relating to
the cell or compartment of an ovary, etc.; in composition, having cells;
as tri<xex>locular</xex>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loculate</ent><br/
<hw>Loc"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>loculatus</ets>.]</ety> <fld>(Bot.)</fld> <def>Divided into
compartments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locule</ent><br/
<hw>Loc"ule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>locule</ets>. See <er>Loculus</er>.]</ety> <fld>(Zool.)</fld>
<def>A little hollow; a loculus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loculicidal</ent><br/
<hw>Loc"u*li*ci`dal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>loculus</ets> cell + <ets>caedere</ets> to cut: cf. F.
<ets>loculicide</ets>.]</ety> <fld>(Bot.)</fld> <def>Dehiscent through
the middle of the back of each cell; -- said of capsules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loculous</ent><br/
<ent>Loculose</ent><br/
<mhw>{ <hw>Loc"u*lose`</hw> <pr>(?)</pr>, <hw>Loc"u*lous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>loculosus</ets>. See
<er>Loculament</er>.]</ety> <fld>(Bot.)</fld> <def>Divided by internal
partitions into cells, as the pith of the pokeweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loculus</ent><br/
<hw>Loc"u*lus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Loculi</plw> <pr>(#)</pr>.</plu> <ety>[L., little place, a
compartment.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>One of the
spaces between the septa in the Anthozoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>One of the compartments of a
several-celled ovary; loculament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locum tenens</ent><br/
\'d8<hw>Lo"cum te"nens</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L., holding
the place; <ets>locus</ets> place + <ets>tenens</ets>, p. pr. of
<ets>tenere</ets> to hold. Cf. <er>Lieutenant</er>.]</ety> <def>A
substitute or deputy; one filling an office for a time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locus</ent><br/
<hw>Lo"cus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Loci</plw> <pr>(#)</pr>, & <plw>Loca</plw> <pr>(#)</pr>.</plu>
<ety>[L., place. Cf. <er>Allow</er>, <er>Couch</er>, <er>Lieu</er>,
<er>Local</er>.]</ety> <sn>1.</sn> <def>A place; a locality.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>The line traced by a point which
varies its position according to some determinate law; the surface
described by a point or line that moves according to a given
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Plane locus</b></col>, <cd>a locus that is a straight
line, or a circle.</cd> -- <col><b>Solid locus</b></col>, <cd>a locus
that is one of the conic sections.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locust</ent><br/
<hw>Lo"cust</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>locusta</ets>
locust, grasshopper. Cf. <er>Lobster</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Any one of numerous species of long-winged,
migratory, orthopterous insects, of the family <fam>Acridid<ae/</fam>,
allied to the grasshoppers; esp., (<spn>Edipoda migratoria</spn>, syn.
<spn>Pachytylus migratoria</spn>, and <spn>Acridium perigrinum</spn>, of
Southern Europe, Asia, and Africa. In the United States the related
species with similar habits are usually called
<altname>grasshoppers</altname>. See <er>Grasshopper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ These insects are at times so numerous in Africa and the
south of Asia as to devour every green thing; and when they migrate,
they fly in an immense cloud. In the United States the harvest flies are
improperly called <xex>locusts</xex>. See <er>Cicada</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Locust beetle</b></col> <fld>(Zool.)</fld>, <cd>a
longicorn beetle (<spn>Cyllene robini<ae/</spn>), which, in the larval
state, bores holes in the wood of the locust tree. Its color is brownish
black, barred with yellow. Called also <altname>locust
borer</altname>.</cd> -- <col><b>Locust bird</b></col>
<fld>(Zool.)</fld> <cd>the rose-colored starling or pastor of India. See
<er>Pastor</er>.</cd> -- <col><b>Locust hunter</b></col>
<fld>(Zool.)</fld>, <cd>an African bird; the beefeater.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Etymol. uncertain.]</ety> <fld>(Bot.)</fld>
<def>The locust tree. See <er>Locust Tree</er> (definition, note, and
phrases).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Locust bean</b></col> <fld>(Bot.)</fld>, <cd>a commercial
name for the sweet pod of the carob tree.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locusta</ent><br/
<hw>Lo*cus"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf.
<ets>locuste</ets>.]</ety> <fld>(Bot.)</fld> <def>The spikelet or flower
cluster of grasses.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locustella</ent><br/
<hw>Lo`cus*tel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>locusta</ets> a locust.]</ety> <fld>(Zool.)</fld> <def>The European
cricket warbler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locustic</ent><br/
<hw>Lo*cus"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, the locust; -- formerly used to
designate a supposed acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locusting</ent><br/
<hw>Lo"cust*ing</hw> <pr>(?)</pr>, <pos>p. a.</pos> <def>Swarming and
devastating like locusts.</def> <mark>[R.]</mark>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locust tree</ent><br/
<hw>Lo"cust tree`</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Bot.)</fld> <def>A large North American tree of
the genus <gen>Robinia</gen> (<spn>Robinia Pseudacacia</spn>), producing
large slender racemes of white, fragrant, papilionaceous flowers, and
often cultivated as an ornamental tree. In England it is called
<altname>acacia</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also applied to other trees of different
genera, especially to those of the genus <gen>Hymen<ae/a</gen>, of which
<spn>Hymen<ae/a Courbaril</spn> is a lofty, spreading tree of South
America; also to the carob tree (<spn>Ceratonia siliqua</spn>), a tree
growing in the Mediterranean region.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Honey locust tree</b></col> <fld>(Bot.)</fld>, <cd>a tree
of the genus <gen>Gleditschia</gen> ) <spn>Gleditschia
triacanthus</spn>), having pinnate leaves and strong branching thorns;
-- so called from a sweet pulp found between the seeds in the pods.
Called also simply <altname>honey locust</altname>.</cd> --
<col><b>Water locust tree</b></col> <fld>(Bot.)</fld>, <cd>a small swamp
tree (<spn>Gleditschia monosperma</spn>), of the Southern United
States.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 865 --></p>

<p><ent>Locution</ent><br/
<hw>Lo*cu"tion</hw> <pr>(l<osl/*k<umac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>locutio</ets>, fr. <ets>loqui</ets> to speak: cf. F.
<ets>locution</ets>. ]</ety> <def>Speech or discourse; a phrase; a form
or mode of expression.</def> <ldquo/ Stumbling
<xex>locutions</xex>.<rdquo/ <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I hate these figures in <qex>locution</qex>,<br/
These about phrases forced by ceremony.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Locutory</ent><br/
<hw>Loc"u*to*ry</hw> <pr>(l<ocr/k"<usl/*t<osl/*r<ycr/)</pr>,
<pos>n.</pos> <def>A room for conversation; especially, a room in
monasteries, where the monks were allowed to converse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodde</ent><br/
<hw>Lod"de</hw> <pr>(l<ocr/d'd<esl/)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The capelin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lode</ent><br/
<hw>Lode</hw> <pr>(l<omac/d)</pr>, <pos>n.</pos> <ety>[AS.
<ets>l<amac/d</ets> way, journey, fr. <ets>l<imac/<edh/an</ets> to go.
See <er>Lead</er> to guide, and cf. <er>Load</er> a burden.]</ety>
<sn>1.</sn> <def>A water course or way; a reach of water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Down that long, dark <qex>lode</qex> . . . he and his brother
skated home in triumph.</q> <rj><qau>C. Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A body of ore visibly separated
from adjacent rock.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Especially:</specif> <fld>(Mining)</fld> <def>Any
regular vein or course of valuable mineral, whether metallic or
not.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <def>A concentrated supply or
source of something valuable.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>mother lode</b></col> <cd>a large concentrated source of
mineral or other valuable thing, from which lesser sources have been
derived; -- often used figuratively. The term may have been originally
applied to real or imagined large deposits of gold from which smaller
granules were washed downstream, there constituting a diluted source of
gold, and hinting at the richer source from which they were derived;
<as>as, to hit the <ex>mother lode</ex></as>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Lodemanage</ent><br/
<hw>Lode"man*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lodemenage</ets>. <ets>Chaucer</ets>.]</ety> <def>Pilotage.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lode-ship</ent><br/
<hw>Lode"-ship`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An old name for a
pilot boat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodesman</ent><br/
<hw>Lodes"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Loadsman</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodestar</ent><br/
<hw>Lode"star`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Loadstar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodestone</ent><br/
<hw>Lode"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Same as <er>Loadstone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodge</ent><br/
<hw>Lodge</hw> <pr>(l<ocr/j)</pr>, <pos>n.</pos> <ety>[OE.
<ets>loge</ets>, <ets>logge</ets>, F. <ets>loge</ets>, LL.
<ets>laubia</ets> porch, gallery, fr. OHG. <ets>louba</ets>, G.
<ets>laube</ets>, arbor, bower, fr. <ets>lab</ets> foliage. See
<er>Leaf</er>, and cf. <er>Lobby</er>, <er>Loggia</er>.]</ety>
<sn>1.</sn> <def>A shelter in which one may rest;</def>
<specif>as:</specif> <sd>(a)</sd> <def>A shed; a rude cabin; a hut;
<as>as, an Indian's <ex>lodge</ex></as>.</def> <au>Chaucer.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Their <qex>lodges</qex> and their tentis up they gan bigge [to
build].</q> <rj><qau>Robert of Brunne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O for a <qex>lodge</qex> in some vast wilderness!</q>
<rj><qau>Cowper.</qau></rj></p>

<p><sd>(b)</sd> <def>A small dwelling house, as for a gamekeeper or
gatekeeper of an estate.</def> <au>Shak.</au> <sd>(c)</sd> <def>A den or
cave.</def> <sd>(d)</sd> <def>The meeting room of an association; hence,
the regularly constituted body of members which meets there; <as>as, a
masonic <ex>lodge</ex></as>.</def> <sd>(c)</sd> <def>The chamber of an
abbot, prior, or head of a college.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>The space at the mouth of a
level next the shaft, widened to permit wagons to pass, or ore to be
deposited for hoisting; -- called also <altname>platt</altname>.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A collection of objects lodged together.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Maldives, a famous <qex>lodge</qex> of islands.</q>
<rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A family of North American Indians, or the persons
who usually occupy an Indian lodge, -- as a unit of enumeration,
reckoned from four to six persons; <as>as, the tribe consists of about
two hundred <ex>lodges</ex>, that is, of about a thousand
individuals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lodge gate</b></col>, <cd>a park gate, or entrance gate,
near the lodge. See <er>Lodge</er>, <pos>n.</pos>, 1
<sd>(b)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodge</ent><br/
<hw>Lodge</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lodged</conjf> <pr>(l<ocr/jd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lodging</conjf> <pr>(l<ocr/j"<icr/ng)</pr>.]</vmorph> <sn>1.</sn>
<def>To rest or remain a lodge house, or other shelter; to rest; to
stay; to abide; esp., to sleep at night; <as>as, to <ex>lodge</ex> in
York Street</as>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Stay and <qex>lodge</qex> by me this night.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Something holy <qex>lodges</qex> in that breast.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall or lie down, as grass or grain, when
overgrown or beaten down by the wind.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To come to a rest; to stop and remain; to become
stuck or caught; <as>as, the bullet <ex>lodged</ex> in the bark of a
tree; a piece of meat <ex>lodged</ex> in his throat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodge</ent><br/
<hw>Lodge</hw>, <pos>v. t.</pos> <ety>[OE. <ets>loggen</ets>, OF.
<ets>logier</ets>, F. <ets>loger</ets>. See <er>Lodge</er>,
<pos>n.</pos> ]</ety> <sn>1.</sn> <def>To give shelter or rest to;
especially, to furnish a sleeping place for; to harbor; to shelter;
hence, to receive; to hold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every house was proud to <qex>lodge</qex> a knight.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The memory can <qex>lodge</qex> a greater store of images than all
the senses can present at one time.</q> <rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drive to shelter; to track to covert.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The deer is <qex>lodged</qex>; I have tracked her to her
covert.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deposit for keeping or preservation; <as>as, the
men <ex>lodged</ex> their arms in the arsenal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cause to stop or rest in; to implant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>lodged</qex> an arrow in a tender breast.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To lay down; to prostrate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though bladed corn be <qex>lodged</qex>, and trees blown down.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To present or bring (information, a complaint)
before a court or other authority; <as>as, to <ex>lodge</ex> a
complaint</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To lodge an information</b></col>, <cd>to enter a formal
complaint.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodgeable</ent><br/
<hw>Lodge"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>logeable</ets>.]</ety> <sn>1.</sn> <def>That may be or can be
lodged; <as>as, so many persons are not <ex>lodgeable</ex> in this
village</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of affording lodging; fit for lodging
in.</def> <mark>[R.]</mark> <ldquo/ The <xex>lodgeable</xex> area of the
earth.<rdquo/ <rj><au>Jeffrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodged</ent><br/
<hw>Lodged</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Her.)</fld> <def>Lying
down; -- used of beasts of the chase, as <contr>couchant</contr> is of
beasts of prey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodgement</ent><br/
<hw>Lodge"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lodgment</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lodgepole</ent><br/
<hw>lodgepole</hw> <pos>n.</pos> <def>The lodgepole pine..</def><br/
<syn><b>Syn. --</b> shore pine, , spruce pine, Pinus contorta.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lodgepole pine</ent><br/
<hw>lodgepole pine</hw> <pos>n.</pos> <def>A tall, narrow 2-needled pine
(<spn>Pinus contorta</spn>) of the coastal Northwestern U. S., having a
red to yellow-brown bark fissured into small squares and bearing
egg-shaped cones.</def><br/
<syn><b>Syn. --</b> shore pine, lodgepole pine, spruce pine, <spn>Pinus
contorta</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lodger</ent><br/
<hw>Lodg"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, lodges; one who occupies a hired room in another's
house.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodging</ent><br/
<hw>Lodg"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who, or
that which, lodges.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place of rest, or of temporary habitation; esp., a
sleeping apartment; -- often in the plural with a singular
meaning.</def> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wits take <qex>lodgings</qex> in the sound of Bow.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Abiding place; harbor; cover.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair bosom . . . the <qex>lodging</qex> of delight.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lodging house</b></col>, <cd>a house where lodgings are
provided and let.</cd> -- <col><b>Lodging room</b></col>, <cd>a room in
which a person lodges, esp. a hired room.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>lodgings</ent><br/
<hw>lodgings</hw> <pos>n.</pos> <ety>[pl. of <er>lodging</er>{2}.]</ety>
<def>temporary living quarters.</def><br/
<syn><b>Syn. --</b> diggings, digs, domiciliation, pad.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lodgment</ent><br/
<hw>Lodg"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>lodgement</asp>.]</altsp> <ety>[Cf. F. <ets>logement</ets>. See
<er>Lodge</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>The act of
lodging, or the state of being lodged.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any particle which is of size enough to make a <qex>lodgment</qex>
afterwards in the small arteries.</q> <rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lodging place; a room.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An accumulation or collection of something deposited
in a place or remaining at rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>The occupation and holding of a
position, as by a besieging party; an instrument thrown up in a captured
position; <as>as, to effect a <ex>lodgment</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lodicule</ent><br/
<hw>Lod"i*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lodicula</ets>. dim, of <ets>lodix</ets>, <ets>lodicis</ets>, a
coverlet: cf. F. <ets>lodicule</ets>.]</ety> <fld>(Bot.)</fld> <def>One
of the two or three delicate membranous scales which are next to the
stamens in grasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loellingite</ent><br/
<hw>Loel"ling*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from
<etsep>L<oum/lling</etsep>, in Austria.]</ety> <fld>(Min.)</fld> <def>A
tin-white arsenide of iron, isomorphous with arsenopyrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loess</ent><br/
<hw>Loess</hw> <pr>(l<etil/e)</pr>, <pos>n.</pos> <ety>[G.
<ets>l<oum/ss</ets>.]</ety> <fld>(Geol.)</fld> <def>A quaternary
deposit, usually consisting of a fine yellowish earth, on the banks of
the Rhine and other large rivers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loeven's larva</ent><br/
<hw>Loev"en's lar"va</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[Named after
the Swedish Zoologist, <person>S. F. <etsep>L<oum/ven</etsep></person>,
who discovered it.]</ety> <fld>(Zool.)</fld> <def>The peculiar larva of
Polygordius. See <er>Polygordius</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loffe</ent><br/
<hw>Loffe</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To laugh.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loft</ent><br/
<hw>Loft</hw> <pr>(l<ocr/ft)</pr>, <pos>n.</pos> <ety>[Icel.
<ets>lopt</ets> air, heaven, loft, upper room; akin to AS.
<ets>lyft</ets> air, G. <ets>luft</ets>, Dan. <ets>loft</ets> loft,
Goth. <ets>luftus</ets> air. Cf. <er>Lift</er>, <pos>v.</pos> &
<pos>n.</pos> ]</ety> <sn>1.</sn> <def>That which is lifted up; an
elevation.</def> <specif>Hence, especially:</specif> <sd>(a)</sd>
<def>The room or space under a roof and above the ceiling of the
uppermost story.</def> <sd>(b)</sd> <def>A gallery or raised apartment
in a church, hall, etc.; <as>as, an organ <ex>loft</ex></as>.</def>
<sd>(c)</sd> <def>A floor or room placed above another; a story.</def>
<specif>especially</specif>, <def>an upper story located in a building
with a business below, often having no partitions, and in cities
sometimes converted into living quarters, or used as studios for
artists.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Eutychus . . . fell down from the third <qex>loft</qex>.</q>
<rj><qau>Acts xx. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Golf)</fld> <def>Pitch or slope of the face of a
club (tending to drive the ball upward).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>On loft</b></col>, <cd>aloft; on high. Cf.
<er>Onloft</er>.</cd> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loft</ent><br/
<hw>Loft</hw>, <pos>a.</pos> <def>Lofty; proud.</def> <mark>[R. &
Obs.]</mark> <rj><au>Surrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loft</ent><br/
<hw>Loft</hw>, <pos>v. t.</pos> <def>To make or furnish with a loft; to
cause to have loft; <as>as, a <ex>lofted</ex> house; a <ex>lofted</ex>
golf-club head</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A wooden club with a <qex>lofted</qex> face.</q> <rj><qau>Encyc.
of Sport.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Loft</ent><br/
<hw>Loft</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lofted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lofting</conjf>.]</vmorph> <def>To raise aloft; to send into the
air;</def> <specif>esp.</specif> <fld>(Golf)</fld>, <def>to strike (the
ball) so that it will go over an obstacle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lofter</ent><br/
<hw>Loft"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Golf)</fld> <def>An
iron club with a sloped face, used in lofting the ball; -- called also
<altname>lofting iron</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Loftily</ent><br/
<hw>Loft"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Lofty</er>.]</ety> <def>In a lofty manner or position;
haughtily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loftiness</ent><br/
<hw>Loft"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
lofty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lofting iron</ent><br/
<hw>Loft"ing iron</hw>. <fld>(Golf)</fld> <def>Same as
<er>Lofter</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lofty</ent><br/
<hw>Loft"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Loftier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Loftiest</adjf>.]</amorph> <ety>[From <er>Loft</er>.]</ety>
<sn>1.</sn> <def>Lifted high up; having great height; towering;
high.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>See <qex>lofty</qex> Lebanon his head advance.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: Elevated in character, rank, dignity, spirit,
bearing, language, etc.; exalted; noble; stately; characterized by
pride; haughty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The high and <qex>lofty</qex> One, that inhabiteth eternity.</q>
<rj><qau>Is. lvii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lofty</qex> and sour to them that loved him not</q>.
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Himself to sing, and build the <qex>lofty</qex> rhyme.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Tall; high; exalted; dignified; stately;
majestic; sublime; proud; haughty. See <er>Tall</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Log</ent><br/
<hw>Log</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Heb.
<ets>l<omac/g</ets>.]</ety> <def>A Hebrew measure of liquids, containing
2.37 gills.</def> <rj><au>W. H. Ward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Log</ent><br/
<hw>Log</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Icel. <ets>l<amac/g</ets>
a felled tree, log; akin to E. <ets>lie</ets>. See <er>Lie</er> to lie
prostrate.]</ety> <sn>1.</sn> <def>A bulky piece of wood which has not
been shaped by hewing or sawing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Prob. the same word as in sense 1; cf. LG.
<ets>log</ets>, <ets>lock</ets>, Dan. <ets>log</ets>, Sw.
<ets>logg</ets>.]</ety> <fld>(Naut.)</fld> <def>An apparatus for
measuring the rate of a ship's motion through the water.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>common log</xex> consists of the
<xex>log-chip</xex>, or <xex>logship</xex>, often exclusively called the
<xex>log</xex>, and the <xex>log line</xex>, the former being commonly a
thin wooden quadrant of five or six inches radius, loaded with lead on
the arc to make it float with the point up. It is attached to the log
line by cords from each corner. This line is divided into equal spaces,
called <xex>knots</xex>, each bearing the same proportion to a mile that
half a minute does to an hour. The line is wound on a reel which is so
held as to let it run off freely. When the log is thrown, the log-chip
is kept by the water from being drawn forward, and the speed of the ship
is shown by the number of knots run out in half a minute. There are
improved logs, consisting of a piece of mechanism which, being towed
astern, shows the distance actually gone through by the ship, by means
of the revolutions of a fly, which are registered on a dial
plate.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>The record of the rate of
speed of a ship or airplane, and of the course of its progress for the
duration of a voyage; also, the full nautical record of a ship's cruise
or voyage; a log slate; a log book.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <specif>Hence, generally:</specif> <def>A record and
tabulated statement of the person(s) operating, operations performed,
resources consumed, and the work done by any machine, device, or
system.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>5.</sn> <fld>(Mining)</fld> <def>A weight or block near the free
end of a hoisting rope to prevent it from being drawn through the
sheave.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(computers)</fld> <def>A record of activities
performed within a program, or changes in a database or file on a
computer, and typically kept as a file in the computer.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Log board</b></col> <fld>(Naut.)</fld>, <cd>a board
consisting of two parts shutting together like a book, with columns in
which are entered the direction of the wind, course of the ship, etc.,
during each hour of the day and night. These entries are transferred to
the log book. A folding slate is now used instead.</cd> --
<mcol><col><b>Log book</b></col>, <it>or</it>
<col><b>Logbook</b></col></mcol> <fld>(Naut.)</fld>, <sd>(a)</sd> <cd>a
book in which is entered the daily progress of a ship at sea, as
indicated by the log, with notes on the weather and incidents of the
voyage; the contents of the log board.</cd> <sd>(b)</sd> <cd>a book in
which a log{4} is recorded.</cd> -- <mcol><col><b>Log cabin</b></col>,
<col><b>Log house</b></col></mcol>, <cd>a cabin or house made of
logs.</cd> -- <col><b>Log canoe</b></col>, <cd>a canoe made by shaping
and hollowing out a single log; a dugout canoe.</cd> -- <col><b>Log
glass</b></col> <fld>(Naut.)</fld>, <cd>a small sandglass used to time
the running out of the log line.</cd> -- <col><b>Log line</b></col>
<fld>(Naut.)</fld>, <cd>a line or cord about a hundred and fifty fathoms
long, fastened to the log-chip. See Note under 2d <er>Log</er>,
<pos>n.</pos>, 2.</cd> -- <col><b>Log perch</b></col>
<fld>(Zool.)</fld>, <cd>an ethiostomoid fish, or darter (<spn>Percina
caprodes</spn>); -- called also <altname>hogfish</altname> and
<altname>rockfish</altname>.</cd> -- <col><b>Log reel</b></col>
<fld>(Naut.)</fld>, <cd>the reel on which the log line is wound.</cd> --
<col><b>Log slate</b></col>. <fld>(Naut.)</fld> <cd>See <cref>Log
board</cref> (above).</cd> -- <col><b>Rough log</b></col>
<fld>(Naut.)</fld>, <cd>a first draught of a record of the cruise or
voyage.</cd> -- <col><b>Smooth log</b></col> <fld>(Naut.)</fld>, <cd>a
clean copy of the rough log. In the case of naval vessels this copy is
forwarded to the proper officer of the government.</cd> -- <col><b>To
heave the log</b></col> <fld>(Naut.)</fld>, <cd>to cast the log-chip
into the water; also, the whole process of ascertaining a vessel's speed
by the log.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Log</ent><br/
<hw>Log</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Logged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Logging</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<fld>(Naut.)</fld>, <def>To enter in a ship's log book; <as>as, to
<ex>log</ex> the miles run</as>.</def> <rj><au>J. F.
Cooper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To record any event in a logbook, especially an
event relating to the operation of a machine or device.</def><br/
[<source>PJC</source>]</p>

<p><ent>Log</ent><br/
<hw>Log</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To engage in the
business of cutting or transporting logs for timber; to get out
logs.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move to and fro; to rock.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logan</ent><br/
<hw>Log"an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rocking or balanced
stone.</def> <rj><au>Gwill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logania</ent><br/
<hw>Logania</hw> <pos>prop. n.</pos> <def>The type genus of the
<fam>Loganiaceae</fam>; Australian and New Zealand shrubs sometimes
cultivated for their flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Logania</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Logaoedic</ent><br/
<hw>Log`a*<oe/d"ic</hw> <pr>(l<ocr/g`<adot/*<ecr/d"<icr/k)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>logaoidiko`s</grk>; <grk>lo`gos</grk>
discourse, prose + <grk>'aoidh`</grk> song.]</ety> <fld>(Gr.
Pros.)</fld> <def>Composed of dactyls and trochees so arranged as to
produce a movement like that of ordinary speech.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logarithm</ent><br/
<hw>Log"a*rithm</hw> <pr>(l<ocr/g"<adot/*r<icr/<th/'m)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>lo`gos</grk> word, account, proportion +
<grk>'ariqmo`s</grk> number: cf. F. <ets>logarithme</ets>.]</ety>
<fld>(Math.)</fld> <def>One of a class of auxiliary numbers, devised by
<person>John Napier</person>, of Merchiston, Scotland (1550-1617), to
abridge arithmetical calculations, by the use of addition and
subtraction in place of multiplication and division.</def> <note>The
relation of <ex>logarithms</ex> to common numbers is that of numbers in
an arithmetical series to corresponding numbers in a geometrical series,
so that sums and differences of the former indicate respectively
products and quotients of the latter; thus,<br/
<br/
<table><pre><br/
<row>0    1    2     3      4       Indices or logarithms</row><br/
<row>1   10   100  1000  10,000     Numbers in geometrical progression</row><br/
</pre></table><br/
<br/
Hence, the logarithm of any given number is the exponent of a power to
which another given invariable number, called the <xex>base</xex>, must
be raised in order to produce that given number. Thus, let 10 be the
base, then 2 is the logarithm of 100, because <mathex>10<exp>2</exp> =
100</mathex>, and 3 is the logarithm of 1,000, because
<mathex>10<exp>3</exp> = 1,000</mathex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Arithmetical complement of a logarithm</b></col>, <cd>the
difference between a logarithm and the number ten.</cd> --
<col><b>Binary logarithms</b></col>. <cd>See under <er>Binary</er>.</cd>
-- <mcol><col><b>Common logarithms</b></col>, <it>or</it>
<col><b>Brigg's logarithms</b></col></mcol>, <cd>logarithms of which the
base is 10; -- so called from <person>Henry
<etsep>Briggs</etsep></person>, who invented them.</cd> --
<col><b>Gauss's logarithms</b></col>, <cd>tables of logarithms
constructed for facilitating the operation of finding the logarithm of
the sum of difference of two quantities from the logarithms of the
quantities, one entry of those tables and two additions or subtractions
answering the purpose of three entries of the common tables and one
addition or subtraction. They were suggested by the celebrated German
mathematician <person>Karl Friedrich <etsep>Gauss</etsep></person> (died
in 1855), and are of great service in many astronomical
computations.</cd> -- <mcol><col><b>Hyperbolic logarithm</b></col>
<it>or</it> <col><b>Napierian logarithm</b></col> <it>or</it>
<col><b>Natural logarithm</b></col></mcol>, <cd>a logarithm (devised by
John Speidell, 1619) of which the base is <it>e</it>
(2.718281828459045...); -- so called from
<persfn><etsep>Napier</etsep></persfn>, the inventor of logarithms.</cd>
-- <mcol><col><b>Logistic logarithms</b></col> <it>or</it>
<col><b>Proportional logarithms</b></col></mcol>, <cd>See under
<er>Logistic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logarithmetical</ent><br/
<ent>Logarithmetic</ent><br/
<mhw>{ <hw>Log`a*rith*met"ic</hw> <pr>(?)</pr>,
<hw>Log"a*rith*met"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>See <er>Logarithmic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logarithmetically</ent><br/
<hw>Log`a*rith*met"ic*al*ly</hw>, <pos>adv.</pos>
<def>Logarithmically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logarithmical</ent><br/
<ent>Logarithmic</ent><br/
<mhw>{ <hw>Log`a*rith"mic</hw> <pr>(?)</pr>, <hw>Log`a*rith"mic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>logarithmique</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to
logarithms; consisting of logarithms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Using logarithms; <as>as, <ex>logarithmic</ex> graph
paper; a <ex>logarithmic</ex> scale</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Having a logarithm in one or more of the unknowns;
-- of an equation.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Logarithmic curve</b></col> <fld>(Math.)</fld>, <cd>a
curve which, referred to a system of rectangular coordinate axes, is
such that the ordinate of any point will be the logarithm of its
abscissa.</cd> -- <col><b>Logarithmic spiral</b></col>, <cd>a spiral
curve such that radii drawn from its pole or eye at equal angles with
each other are in continual proportion. See
<er>Spiral</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logarithmically</ent><br/
<hw>Log`a*rith"mic*al*ly</hw>, <pos>adv.</pos> <def>By the use of
logarithms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Log-chip</ent><br/
<hw>Log"-chip`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A thin, flat piece of board in the form of a quadrant of a circle
attached to the log line; -- called also <altname>log-ship</altname>.
See 2d <er>Log</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logcock</ent><br/
<hw>Log"cock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The pileated
woodpecker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loge</ent><br/
<hw>Loge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Lodge</er>.]</ety> <def>A lodge; a habitation.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loggan</ent><br/
<hw>Log"gan</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Logan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loggat</ent><br/
<hw>Log"gat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Also written
<ets>logget</ets>.]</ety> <sn>1.</sn> <def>A small log or piece of
wood.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>An old game in England, played by
throwing pieces of wood at a stake set in the ground.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logge</ent><br/
<hw>Logge</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Lodge</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logged</ent><br/
<hw>Logged</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Made slow
and heavy in movement; water-logged.</def>
<rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Entered in a logbook.</def><br/
[<source>PJC</source>]</p>

<p><ent>Logger</ent><br/
<hw>Log"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One engaged in
logging. See <er>Log</er>, <pos>v. i.</pos></def> <mark>[U.S.]</mark>
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loggerhead</ent><br/
<hw>Log"ger*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Log</ets>
+ <ets>head</ets>.]</ety> <sn>1.</sn> <def>A blockhead; a dunce; a
numskull.</def> <rj><au>Shak. Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A spherical mass of iron, with a long handle, used
to heat tar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>An upright piece of round timber,
in a whaleboat, over which a turn of the line is taken when it is
running out too fast.</def> <rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A very large marine turtle
(<spn>Thalassochelys caretta</spn> syn. <spn>Thalassochelys
caouana</spn>), common in the warmer parts of the Atlantic Ocean, from
Brazil to Cape Cod; -- called also <altname>logger-headed
turtle</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>An American shrike (<spn>Lanius
Ludovicianus</spn>), similar to the butcher bird, but smaller. See
<er>Shrike</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To be at loggerheads</b></col>, <col><b>To fall to
loggerheads</b></col>, <it>or</it> <col><b>To go to
loggerheads</b></col></mcol>, <cd>to quarrel; to be at strife.</cd>
<au>L' Estrange.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loggerheaded</ent><br/
<hw>Log"ger*head`ed</hw>, <pos>a.</pos> <def>Dull; stupid.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A rabble of <qex>loggerheaded</qex> physicians.</q>
<rj><qau>Urquhart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loggerheads</ent><br/
<hw>Log"ger*heads`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The knapweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loggia</ent><br/
\'d8<hw>Log"gia</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Lodge</er>.]</ety> <fld>(Arch.)</fld> <def>A roofed open gallery. It
differs from a <contr>veranda</contr> in being more architectural, and
in forming more decidedly a part of the main edifice to which it is
attached; from a <contr>porch</contr>, in being intended not for
entrance but for an out-of-door sitting-room.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logging</ent><br/
<hw>Log"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The business of
felling trees, cutting them into logs, and transporting the logs to
sawmills or to market.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logic</ent><br/
<hw>Log"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>logike</ets>,
F. <ets>logique</ets>, L. <ets>logica</ets>, <ets>logice</ets>, Gr.
<grk>logikh`</grk> (sc. <grk>te`chnh</grk>), fr. <grk>logiko`s</grk>
belonging to speaking or reason, fr. <grk>lo`gos</grk> speech, reason,
<grk>le`gein</grk> to say, speak. See <er>Legend</er>.]</ety>
<sn>1.</sn> <def>The science or art of exact reasoning, or of pure and
formal thought, or of the laws according to which the processes of pure
thinking should be conducted; the science of the formation and
application of general notions; the science of generalization, judgment,
classification, reasoning, and systematic arrangement; the science of
correct reasoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 866 --></p>

<p><q><qex>Logic</qex> is the science of the laws of thought, as
thought; that is, of the necessary conditions to which thought,
considered in itself, is subject.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Logic</xex> is distinguished as <xex>pure</xex> and
<xex>applied</xex>. <ldquo/<xex>Pure logic</xex> is a science of the
form, or of the formal laws, of thinking, and not of the matter.
<xex>Applied logic</xex> teaches the application of the forms of
thinking to those objects about which men do think.<rdquo/ <rj><au>Abp.
Thomson.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A treatise on logic; <as>as, Mill's
<ex>Logic</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>correct reasoning; <as>as, I can't see any
<ex>logic</ex> in his argument</as>; also, sound judgment; <as>as, the
<ex>logic</ex> of surrender was uncontestable</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>The path of reasoning used in any specific argument;
<as>as, his <ex>logic</ex> was irrefutable</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <fld>(Electronics, Computers)</fld> <def>A function of an
electrical circuit (called a gate) that mimics certain elementary binary
logical operations on electrical signals, such as AND, OR, or NOT;
<as>as, a <ex>logic</ex> circuit; the arithmetic and <ex>logic</ex>
unit</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Logical</ent><br/
<hw>Log"ic*al</hw> <pr>(l<ocr/j"<icr/*k<ait/l)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>logique</ets>, L. <ets>logicus</ets>, Gr.
<grk>logiko`s</grk>.]</ety> <sn>1.</sn> <def>Of or pertaining to logic;
used in logic; <as>as, <ex>logical</ex> subtilties</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>According to the rules of logic; <as>as, a
<ex>logical</ex> argument or inference; the reasoning is
<ex>logical</ex>; a <ex>logical</ex> argument; a <ex>logical</ex>
impossibility.</as></def> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Skilled in logic; versed in the art of thinking and
reasoning; <as>as, he is a <ex>logical</ex> thinker</as>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logicality</ent><br/
<hw>Log`i*cal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Logicalness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logically</ent><br/
<hw>Log"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a logical
manner; <as>as, to argue <ex>logically</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logicalness</ent><br/
<hw>Log"ic*al*ness</hw>, <pos>n.</pos> <def>The quality of being
logical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logician</ent><br/
<hw>Lo*gi"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>logicien</ets>.]</ety> <def>A person skilled in logic.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Each fierce <qex>logician</qex> still expelling Locke.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logics</ent><br/
<hw>Log"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Logic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>log on</ent><br/
<ent>log in</ent><br/
<mhw><hw>log in</hw>, <hw>log on</hw></mhw>, <pos>v. i.</pos>
<fld>(Computers)</fld> <def>To establish communication with a host
computer from a terminal or remote computer.</def><br/
[<source>PJC</source>]</p>

<p><ent>Logistical</ent><br/
<ent>Logistic</ent><br/
<mhw>{ <hw>Lo*gis"tic</hw> <pr>(?)</pr>, <hw>Lo*gis"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ skilled in
calculating, <?/ to calculate, fr. <grk>lo`gos</grk> word, number,
reckoning: cf. F. <ets>logistique</ets>.]</ety> <sn>1.</sn>
<def>Logical.</def> <mark>[Obs.]</mark> <rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>Sexagesimal, or made on the scale
of 60; <as>as, <ex>logistic</ex>, <ex>or sexagesimal</ex>,
arithmetic</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to logistics; <as>as,
<ex>logistic</ex> requirements; <ex>logistical</ex> problems; a
<ex>logistical</ex> nightmare</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Logistic logarithms</b></col>, <it>or</it>
<col><b>Proportional logarithms</b></col></mcol>, <cd>certain
logarithmic numbers used to shorten the calculation of the fourth term
of a proportion of which one of the terms is a given constant quantity,
commonly one hour, while the other terms are expressed in minutes and
seconds; -- not now used.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>logistician</ent><br/
<hw>logistician</hw> <pos>n.</pos> <def>a person skilled at symbolic
logic.</def><br/
<syn><b>Syn. --</b> logician.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Logistics</ent><br/
<hw>Lo*gis"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Mil.)</fld> <def>That branch of the military art which embraces
the details of moving and supplying armies. The meaning of the word is
by some writers extended to include <xex>strategy</xex>.</def>
<rj><au>H. L. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>By extension:</specif> <def>The planning and
coordination of the movement of materials, and other details of any
large activity, such as a business or a political campaign.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>A system of arithmetic, in which
numbers are expressed in a scale of 60; logistic arithmetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logman</ent><br/
<hw>Log"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Logmen</plw> <pr>(<?/)</pr>.</plu> <def>A man who carries
logs.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logodaedaly</ent><br/
<hw>Log`o*d<ae/d"a*ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/.
See <er>Logos</er>, and <er>D<ae/dal</er>.]</ety> <def>Verbal
legerdemain; a playing with words.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logogram</ent><br/
<hw>Log"o*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lo`gos</grk> word + <ets>-gram</ets>.]</ety> <def>A word letter; a
phonogram, that, for the sake of brevity, represents a word; <as>as, |,
i. e., <it>t</it>, for <it>it</it></as>. Cf.
<er>Grammalogue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logographer</ent><br/
<hw>Lo*gog"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
chronicler; one who writes history in a condensed manner with short
simple sentences.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One skilled in logography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logographical</ent><br/
<ent>Logographic</ent><br/
<mhw>{ <hw>Log`o*graph"ic</hw> <pr>(?)</pr>, <hw>Log`o*graph"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ of writing speeches:
cf. F. <ets>logographique</ets>.]</ety> <def>Of or pertaining to
logography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logography</ent><br/
<hw>Lo*gog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
writing of speeches; <grk>lo`gos</grk> word, speech + <?/ to write: cf.
F. <ets>logographie</ets>.]</ety> <sn>1.</sn> <def>A method of printing
in which whole words or syllables, cast as single types, are
used.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mode of reporting speeches without using
shorthand, -- a number of reporters, each in succession, taking down
three or four words.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logogriph</ent><br/
<hw>Log"o*griph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lo`gos</grk> word + <grk>gri^fos</grk> a fishing net, a dark
saying, a riddle: F. <ets>logogriphe</ets>.]</ety> <def>A sort of riddle
in which it is required to discover a chosen word from various
combinations of its letters, or of some of its letters, which form other
words; -- thus, to discover the chosen word <xex>chatter</xex> form
<xex>cat</xex>, <xex>hat</xex>, <xex>rat</xex>, <xex>hate</xex>,
<xex>rate</xex>, etc.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logomachist</ent><br/
<hw>Lo*gom"a*chist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Logomachy</er>.]</ety> <def>One who contends about words.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logomachy</ent><br/
<hw>Lo*gom"a*chy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>lo`gos</grk> word + <?/ fight, battle, contest: cf. F.
<ets>logomachie</ets>.]</ety> <sn>1.</sn> <def>Contention in words
merely, or a contention about words; a war of words.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The discussion concerning the meaning of the word
<ldquo/justification<rdquo/ . . . has largely been a mere
<qex>logomachy</qex>.</q> <rj><qau>L. Abbott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A game of word making.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logometric</ent><br/
<hw>Log`o*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>lo`gos</grk> word, ratio + <grk>me`tron</grk> measure.]</ety>
<fld>(Chem.)</fld> <def>Serving to measure or ascertain chemical
equivalents; stoichiometric.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logos</ent><br/
\'d8<hw>Log"os</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>lo`gos</grk> the word or form which expresses a thought, also, the
thought, fr. <?/ to speak.]</ety> <sn>1.</sn> <def>A word; reason;
speech.</def> <rj><au>H. Bushell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The divine Word; Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logothete</ent><br/
<hw>Log"o*thete</hw> <pr>(?)</pr>, <ety>[LL. <ets>logotheta</ets>, fr.
Gr. <?/; <grk>lo`gos</grk> word, account + <?/ to put.]</ety> <def>An
accountant; under Constantine, an officer of the empire; a receiver of
revenue; an administrator of a department.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logotype</ent><br/
<hw>Log"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lo`gos</grk> word + <ets>-type</ets>.]</ety> <fld>(Print.)</fld>
<def>A single type, containing two or more letters; <as>as,
<ex><ae/</ex>, <ex>\<oe/</ex>, <ex><AE/</ex>, <ex><filig/</ex>,
<ex><fllig/</ex>, <ex><ffllig/</ex>, etc.</as>; -- called also
<altname>ligature</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logroll</ent><br/
<hw>Log"roll`</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <def>To engage in
logrolling; to accomplish by logrolling.</def> <mark>[Political cant, U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logroller</ent><br/
<hw>Log"roll`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who engages in
logrolling.</def> <mark>[Political cant, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The jobbers and <qex>logrollers</qex> will all be against it.</q>
<rj><qau>The. Nation.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logrolling</ent><br/
<hw>Log"roll`ing</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Logging)</fld>
<def>The act or process of rolling logs from the place where they were
felled to the stream which floats them to the sawmill or to market. In
this labor neighboring camps of loggers combine to assist each other in
turn.</def> <au>Longfellow.</au> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A combining or mutual
agreement in which one politician supports or assists another in
consideration of receiving assistance in return; wheeling and dealing;
-- sometimes used of a disreputable mode of accomplishing political
schemes or ends.</def> <mark>[Cant, U.S.]</mark><-- "You scratch my
back, I'll scratch yours." --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Log-ship</ent><br/
<hw>Log"-ship</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
part of the log. See <er>Log-chip</er>, and 2d <er>Log</er>,
<pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logwood</ent><br/
<hw>Log"wood`</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[So called from being
imported in <ets>logs</ets>.]</ety> <def>The heartwood of a tree
(<spn>H<ae/matoxylon Campechianum</spn>), a native of South America, It
is a red, heavy wood, containing a crystalline substance called
<part>h<ae/matoxylin</part>, and is used largely in dyeing. An extract
from this wood is used in medicine as an astringent. Also called
<altname>Campeachy wood</altname>, and
<altname>bloodwood</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-logy</ent><br/
<hw>-lo*gy</hw> <pr>(?)</pr> <pos>suff.</pos> <ety>[Gr. <?/, fr.
<grk>lo`gos</grk> word, discourse, fr. <grk>le`gein</grk> to speak. See
<er>Logic</er>.]</ety> <def>A combining form denoting a
<sig>discourse</sig>, <sig>treatise</sig>, <sig>doctrine</sig>,
<sig>theory</sig>, <sig>science</sig>; <as>as, theo<ex>logy</ex>,
geo<ex>logy</ex>, bio<ex>logy</ex>, minera<ex>logy</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Logy</ent><br/
<hw>Lo"gy</hw> <pr>(l<omac/"g<emac/)</pr> , <pos>a.</pos> <ety>[From D.
<ets>log</ets>.]</ety> <def>Heavy or dull in respect to motion or
thought; <as>as, a <ex>logy</ex> horse; feeling
<ex>logy</ex></as>.</def> <mark>[U.S.]</mark><br/
<syn><b>Syn. --</b> sluggish; dull; lethargic.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Porcupines are . . . <qex>logy</qex>, sluggish creatures.</q>
<rj><qau>C. H. Merriam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lohock</ent><br/
<hw>Lo"hock</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld> <def>See
<er>Loch</er>, a medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loimic</ent><br/
<hw>Loi"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, fr. <?/
plague.]</ety> <def>Of or pertaining to the plague or contagious
disorders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loin</ent><br/
<hw>Loin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>loine</ets>,
OF. <ets>logne</ets>, F. <ets>longe</ets>, from (assumed) LL.
<ets>lumbea</ets>, L. <ets>lumbus</ets> join. Cf. <er>Lends</er>,
<er>Lumbar</er>, <er>Nombles</er>.]</ety> <sn>1.</sn> <def>That part of
a human being or quadruped, which extends on either side of the spinal
column between the hip bone and the false ribs. In human beings the
loins are also called the reins. See <xex>Illust.</xex> of
<er>Beef</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cut of meat taken from this part of a food animal,
as from cattle or hogs.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The pubic area; the genitalia,
especially in women; <as>as, receptive <ex>loins</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>loincloth</ent><br/
<hw>loincloth</hw> <pos>n.</pos> <def>A cloth covering for the loins,
worn around the hips; -- sometimes worn in tropical areas as the only
article of clothing.</def><br/
<syn><b>Syn. --</b> breechcloth, breechclout, G-string.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loir</ent><br/
\'d8<hw>Loir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>glis</ets>, <ets>gliris</ets>.]</ety> <fld>(Zool.)</fld> <def>A
large European dormouse (<spn>Myoxus glis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loire</ent><br/
<hw>Loire</hw> <pos>prop. n.</pos> <def>a French river which flows into
the North Atlantic.</def><br/
<syn><b>Syn. --</b> Loire River.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loiseleuria</ent><br/
<hw>Loiseleuria</hw> <pos>prop. n.</pos> <def>A genus of plants having
only one species, the alpine azalea.</def><br/
<syn><b>Syn. --</b> genus <gen>Loiseleuria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loiter</ent><br/
<hw>Loi"ter</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Loitered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Loitering</conjf>.]</vmorph> <ety>[D.
<ets>leuteren</ets> to delay, loiter; cf; Prov. G. <ets>lottern</ets> to
be louse, <ets>lotter</ets> louse, slack, unsettled, vagrant, OHG.
<ets>lotar</ets>.]</ety> <sn>1.</sn> <def>To be slow in moving; to
delay; to linger; to be dilatory; to spend time idly; to saunter; to lag
behind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir John, you <qex>loiter</qex> here too long.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If we have <qex>loitered</qex>, let us quicken our pace.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wander as an idle vagrant.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj></p>

<p><syn><b>Syn.</b> -- To linger; delay; lag; saunter; tarry.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loiterer</ent><br/
<hw>Loi"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
loiters; an idler.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An idle vagrant; a tramp.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Sanderson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loiteringly</ent><br/
<hw>Loi"ter*ing*ly</hw>, <pos>adv.</pos> <def>In a loitering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loki</ent><br/
<ent>Lok</ent><br/
<mhw>{ <hw>Lok</hw> <pr>(l<ocr/k)</pr>, <hw>Lo"ki</hw>
<pr>(l<omac/"k)</pr>, }</mhw> <pos>n.</pos> <ety>[Icel. <ets>Loki</ets>,
perh. akin to <ets>lokka</ets>, <ets>locka</ets> to allure,
entice.]</ety> <fld>(Scandinavian Myth.)</fld> <def>The evil deity, the
author of all calamities and mischief, answering to the
<xex>Ahriman</xex> of the Persians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lokao</ent><br/
\'d8<hw>Lo*ka"o</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A green vegetable
dye imported from China.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loke</ent><br/
<hw>Loke</hw> <pr>(l<omac/k)</pr>, <pos>n.</pos> <ety>[See <er>Lock</er>
a fastening.]</ety> <def>A private path or road; also, the wicket or
hatch of a door.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lokorys</ent><br/
<hw>Lok"o*rys</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Liquorice.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loligo</ent><br/
\'d8<hw>Lo*li"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., cuttle
fish.]</ety> <fld>(Zool.)</fld> <def>A genus of cephalopods, including
numerous species of squids, common on the coasts of America and Europe.
They are much used for fish bait.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lolium</ent><br/
<hw>Lolium</hw> <pos>n.</pos> <def>A genus of plants including the
darnel and ryegrass.</def><br/
<syn><b>Syn. --</b> genus <gen>Lolium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loll</ent><br/
<hw>Loll</hw> <pr>(l<ocr/l)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lolled</conjf> <pr>(l<ocr/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lolling</conjf>.]</vmorph> <ety>[Cf. Icel.
<ets>lolla</ets> to act lazily, <ets>loll</ets>, <ets>lolla</ets>,
laziness, OD. <ets>lollen</ets> to sit over the fire, and E.
<ets>lull</ets>. Cf. <er>Lill</er>, <er>Lull</er>.]</ety> <sn>1.</sn>
<def>To act lazily or indolently; to recline; to lean; to throw one's
self down; to lie at ease; <as>as, to <ex>loll</ex> around the house on
a lazy summer day</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Void of care, he <qex>lolls</qex> supine in state.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hand extended from the mouth, as the tongue of an
ox or a log when heated with labor or exertion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The triple porter of the Stygian seat,<br/
With <qex>lolling</qex> tongue, lay fawning at thy feet.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To let the tongue hang from the mouth, as an ox,
dog, or other animal, when heated by labor; <as>as, the ox stood
<ex>lolling</ex> in the furrow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loll</ent><br/
<hw>Loll</hw>, <pos>v. t.</pos> <def>To let hang from the mouth, as the
tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fierce tigers couched around and <qex>lolled</qex> their fawning
tongues.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lollard</ent><br/
<hw>Lol"lard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>Lollardi</ets>, <ets>Lullardi</ets>, from Walter
<ets>Lolhardus</ets>, a German; cf. LG. & D. <ets>lollen</ets> to
mumble, to hum, sing in a murmuring strain; hence, OD.
<ets>lollaerd</ets> a mumbler, <it>i. e.</it>, of prayers or psalms,
which was prob. the origin of the name. See <er>Loll</er>,
<er>Lull</er>.]</ety> <fld>(Eccl. Hist.)</fld> <sd>(a)</sd> <def>One of
a sect of early reformers in Germany.</def> <sd>(b)</sd> <def>One of the
followers of Wyclif in England.</def> <altsp>[Called also
<asp>Loller</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>Lollards</qex> all know the Wyclifities are meant, so
called from <person>Walter Lollardus</person>, one of their teachers in
Germany.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lollardy</ent><br/
<ent>Lollardism</ent><br/
<mhw>{ <hw>Lol"lard*ism</hw> <pr>(?)</pr>, <hw>Lol"lard*y</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The doctrines or principles of
the Lollards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loller</ent><br/
<hw>Loll"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Loll</er>.]</ety> <sn>1.</sn> <def>One who lolls.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An idle vagabond.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A Lollard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lollingly</ent><br/
<hw>Loll"ing*ly</hw>, <pos>adv.</pos> <def>In a lolling manner.</def>
<rj><au>Buckle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lollipop</ent><br/
<hw>Lol"li*pop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perhaps fr. Prov.
E. <ets>loll</ets> to soothe + <ets>pope</ets> a mixed liquor.]</ety>
<sn>1.</sn> <def>A kind of sugar confection which dissolves easily in
the mouth.</def> <mark>[Archaic]</mark> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A piece of hard candy, often
of discoid shape, attached to the end of a handle of wood or hard paper
by which it is held in the hand while being licked; -- it is popular
with small children.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lollop</ent><br/
<hw>Lol"lop</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[From
<er>Loll</er>.]</ety> <def>To move heavily; to lounge or idle; to
loll.</def> <mark>[Low.]</mark> <rj><au>Charles Reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loma</ent><br/
\'d8<hw>lo"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>lomata</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/, <?/, a
fringe.]</ety> <fld>(Zool.)</fld> <def>A lobe; a membranous fringe or
flap.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lomatia</ent><br/
<hw>lomatia</hw> <pos>n.</pos> <def>any of various ornamental evergreens
of the genus <gen>Lomatia</gen> having attractive fragrant
flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lomatinous</ent><br/
<hw>lo*mat"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Loma</er>.]</ety> <fld>(Zool.)</fld> <def>Furnished with lobes or
flaps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lombard</ent><br/
<hw>Lom"bard</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to Lombardy, or the inhabitants of Lombardy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lombard</ent><br/
<hw>Lom"bard</hw>, <pos>prop. n.</pos> <ety>[F. <ets>lombard</ets>, fr.
the <ets>Longobardi</ets> or <ets>Langobardi</ets>, i. e., Longbeards, a
people of Northern Germany, west of the Elbe, and afterward in Northern
Italy. See <er>Long</er>, and <er>Beard</er>, and cf.
<er>Lumber</er>.]</ety> <sn>1.</sn> <def>A native or inhabitant of
Lombardy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A money lender or banker; -- so called because the
business of banking was first carried on in London by
<ets>Lombards</ets>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Same as <er>Lombard-house</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>Lombard</qex> unto this day signifying a bank for usury or
pawns.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>A form of cannon formerly in
use.</def> <rj><au>Prescott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lombard Street</b></col>, <cd>the principal street in
London for banks and the offices of note brokers; hence, the money
market and interest of London.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lombardeer</ent><br/
<hw>Lom`bard*eer"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <def>A
pawnbroker.</def> <mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lombar-house</ent><br/
<ent>Lombard-house</ent><br/
<mhw>{ <hw>Lom"bard-house</hw> <pr>(?)</pr>, <hw>Lom"bar-house`</hw>
<pr>(?)</pr>, }</mhw> <ety>[F. or D. <ets>lombard</ets>. See
<er>Lombard</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>A bank or a
pawnbroker's shop.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A public institution for lending money to the poor
at a moderate interest, upon articles deposited and pledged; -- called
also <altname>mont de pi<eacute/t<eacute/</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lombardic</ent><br/
<hw>Lom*bar"dic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Lombardy of the Lombards.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lombardic alphabet</b></col>, <cd>the ancient alphabet
derived from the Roman, and employed in the manuscript of Italy.</cd> --
<col><b>Lombardic architecture</b></col>, <cd>the debased Roman style of
architecture as found in parts of Northern Italy.</cd> <au>F. G.
Lee.</au> <col><b>Lombardy poplar</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Poplar</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loment</ent><br/
<hw>Lo"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lomentum</ets> a mixture of bean meal and rice, used as a cosmetic
wash, bean meal, fr. <ets>lavare</ets>, <ets>lotum</ets>, to
wash.]</ety> <fld>(Bot.)</fld> <def>An elongated pod, consisting, like
the legume, of two valves, but divided transversely into small cells,
each containing a single seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lomentaceous</ent><br/
<hw>Lo`men*ta"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Loment</er>.]</ety> <fld>(Bot.)</fld> <def>Of the nature of a
loment; having fruits like loments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lomonite</ent><br/
<hw>Lom"o*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Laumontite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lompish</ent><br/
<hw>Lomp"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lumpish.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lonchocarpus</ent><br/
<hw>Lonchocarpus</hw> <pos>prop. n.</pos> <def>A genus of chiefly
tropical American shrubs and trees having pinnate leaves and red or
white flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Lonchocarpus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lond</ent><br/
<hw>Lond</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Land.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>London</ent><br/
<hw>Lon"don</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The capital city of
England.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>London paste</b></col> <fld>(Med.)</fld>, <cd>a paste
made of caustic soda and unslacked lime; -- used as a caustic to destroy
tumors and other morbid enlargements.</cd> -- <col><b>London
pride</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd> <cd>A garden name for
<spn>Saxifraga umbrosa</spn>, a hardy perennial herbaceous plant, a
native of high lands in Great Britain.</cd> <sd>(b)</sd> <cd>A name
anciently given to the Sweet William.</cd> <au>Dr. Prior.</au> --
<col><b>London rocket</b></col> <fld>(Bot.)</fld>, <cd>a cruciferous
plant (<spn>Sisymbrium Irio</spn>) which sprung up in London abundantly
on the ruins of the great fire of 1667.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Londoner</ent><br/
<hw>Lon"don*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>A native or
inhabitant of London.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Londonism</ent><br/
<hw>Lon"don*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A characteristic
of Londoners; a mode of speaking peculiar to London.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Londonize</ent><br/
<hw>Lon"don*ize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To impart to
(one) a manner or character like that which distinguishes
Londoners.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Londonize</ent><br/
<hw>Lon"don*ize</hw>, <pos>v. i.</pos> <def>To imitate the manner of the
people of London.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>London smoke</ent><br/
<hw>Lon"don smoke</hw>. <def>A neutral tint given to spectacles, shade
glasses for optical instruments, etc., which reduces the intensity
without materially changing the color of the transmitted
light.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>London tuft</ent><br/
<hw>London tuft</hw>. <fld>(Bot.)</fld> <def>The Sweet William
(<spn>Dianthus barbatus</spn>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lone</ent><br/
<hw>Lone</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lane. See
<er>Loanin</er>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lone</ent><br/
<hw>Lone</hw>, <pos>a.</pos> <ety>[Abbrev. fr. <ets>alone</ets>.]</ety>
<sn>1.</sn> <def>Being without a companion; being by one's self; also,
sad from lack of companionship; lonely; <as>as, a <ex>lone</ex> traveler
or watcher</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When I have on those pathless wilds a appeared,<br/
And the <qex>lone</qex> wanderer with my presence cheered.</q>
<rj><qau>Shenstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Single; unmarried, or in widowhood.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Queen Elizabeth being a <qex>lone</qex> woman.</q>
<rj><qau>Collection of Records (1642).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A hundred mark is a long one for a poor <qex>lone</qex> woman to
bear.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Being apart from other things of the kind; being by
itself; also, apart from human dwellings and resort; <as>as, a
<ex>lone</ex> house</as>.</def> <ldquo/ A <xex>lone</xex> isle.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By a <qex>lone</qex> well a <qex>lonelier</qex> column rears.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Unfrequented by human beings; solitary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus vanish scepters, coronets, and balls,<br/
And leave you on <qex>lone</qex> woods, or empty walls.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loneliness</ent><br/
<hw>Lone"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
condition of being lonely; solitude; seclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being unfrequented by human beings;
<as>as, the <ex>loneliness</ex> of a road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Love of retirement; disposition to
solitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I see<br/
The mystery of your <qex>loneliness</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A feeling of depression resulting from being
alone.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Solitude; seclusion. See
<er>Solitude</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lonely</ent><br/
<hw>Lone"ly</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lonelier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Loneliest</adjf>.]</amorph> <ety>[Shortened fr.
<ets>alonely</ets>.]</ety> <sn>1.</sn> <def>Sequestered from company or
neighbors; solitary; retired; <as>as, a <ex>lonely</ex> situation; a
<ex>lonely</ex> cell.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Alone, or in want of company; forsaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To the misled and <qex>lonely</qex> traveler.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not frequented by human beings; <as>as, a
<ex>lonely</ex> wood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Having a feeling of depression or sadness resulting
from the consciousness of being alone; lonesome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am very often alone. I don't mean I am <qex>lonely</qex>.</q>
<rj><qau>H. James.</qau></rj></p>

<p><syn><b>Syn.</b> -- Solitary; lone; lonesome; retired; unfrequented;
sequestered; secluded.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loneness</ent><br/
<hw>Lone"ness</hw>, <pos>n.</pos> <def>Solitude; seclusion.</def>
<mark>[Obs.]</mark> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lonesome</ent><br/
<hw>Lone"some</hw> <pr>(?)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Lonesomer</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Lonesomest</adjf>.]</amorph> <sn>1.</sn>
<def>Secluded from society; not frequented by human beings;
solitary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like one that on a <qex>lonesome</qex> road<br/
Doth walk in fear and dread.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conscious of, and somewhat depressed by, solitude;
<as>as, to feel <ex>lonesome</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Lone"some*ly</wf>, <pos>adv.</pos> --
<wf>Lone"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lonesomeness</ent><br/
<hw>lone"some*ness</hw> <pos>n.</pos> <sn>1.</sn> <def>a disposition
toward being alone.</def><br/
<syn><b>Syn. --</b> aloneness, loneliness, solitude.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The condition of being alone; the feeling of sadness
resulting from being alone.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lone-Star State</ent><br/
<hw>Lone-Star State</hw> <pos>prop. n.</pos> <def>Texas; -- a nickname
alluding to the single star on its coat of arms, being the device used
on its flag and seal when it was a republic.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Long</ent><br/
<hw>Long</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Longer</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Longest</adjf> <pr>(?)</pr>.]</amorph> <ety>[AS. <ets>long</ets>,
<ets>lang</ets>; akin to OS, OFries., D., & G. <ets>lang</ets>, Icel.
<ets>langr</ets>, Sw. <ets>l<aring/ng</ets>, Dan. <ets>lang</ets>, Goth.
<ets>laggs</ets>, L. <ets>longus</ets>. <root/125. Cf. <er>Length</er>,
<er>Ling</er> a fish, <er>Linger</er>, <er>Lunge</er>,
<er>Purloin</er>.]</ety> <sn>1.</sn> <def>Drawn out in a line, or in the
direction of length; protracted; extended; <as>as, a <ex>long</ex> line;
-- opposed to <ex>short</ex>, and distinguished from <ex>broad</ex> or
<ex>wide</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 867 --></p>

<p><sn>2.</sn> <def>Drawn out or extended in time; continued through a
considerable tine, or to a great length; <as>as, a <ex>long</ex> series
of events; a <ex>long</ex> debate; a <ex>long</ex> drama; a
<ex>long</ex> history; a <ex>long</ex> book.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Slow in passing; causing weariness by length or
duration; lingering; <as>as, <ex>long</ex> hours of
watching</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Occurring or coming after an extended interval;
distant in time; far away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The we may us reserve both fresh and strong<br/
Against the tournament, which is not <qex>long</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having a length of the specified measure; of a
specified length; <as>as, a span <ex>long</ex>; a yard <ex>long</ex>; a
mile <ex>long</ex>, that is, extended to the measure of a mile,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Far-reaching; extensive.</def> <ldquo/
<xex>Long</xex> views.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Phonetics)</fld> <def>Prolonged, or relatively more
prolonged, in utterance; -- said of vowels and syllables. See
<er>Short</er>, <pos>a.</pos>, 13, and <xex>Guide to
Pronunciation</xex>, <sect/<sect/ 22, 30.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Finance & Com.)</fld> <def>Having a supply of
stocks or goods; prepared for, or depending for a profit upon, advance
in prices; <as>as, <ex>long</ex> of cotton</as>. Hence, the phrases:
<xex>to be</xex>, or <xex>go</xex>, <xex>long of the market</xex>,
<xex>to be on the long side of the market</xex>, to hold products or
securities for a rise in price, esp. when bought on a margin. Contrasted
to <contr>short</contr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ <xex>Long</xex> is used as a prefix in a large number of
compound adjectives which are mostly of obvious meaning; as,
<xex>long-</xex>armed, <xex>long-</xex>beaked, <xex>long-</xex>haired,
<xex>long-</xex>horned, <xex>long-</xex>necked, <xex>long-</xex>sleeved,
<xex>long-</xex>tailed, <xex>long-</xex> worded, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In the long run</b></col>, <cd>in the whole course of
things taken together; in the ultimate result; eventually.</cd> --
<col><b>Long clam</b></col> <fld>(Zool.)</fld>, <cd>the common clam
(<spn>Mya arenaria</spn>) of the Northern United States and Canada; --
called also <altname>soft-shell clam</altname> and <altname>long-neck
clam</altname>. See <er>Mya</er>.</cd> -- <col><b>Long cloth</b></col>,
<cd>a kind of cotton cloth of superior quality.</cd> -- <col><b>Long
clothes</b></col>, <cd>clothes worn by a young infant, extending below
the feet.</cd> -- <col><b>Long division</b></col>. <fld>(Math.)</fld>
<cd>See <er>Division</er>.</cd> -- <col><b>Long dozen</b></col>, <cd>one
more than a dozen; thirteen.</cd> -- <col><b>Long home</b></col>,
<cd>the grave.</cd> -- <mcol><col><b>Long measure</b></col>,
<col><b>Long meter</b></col></mcol>. <cd>See under <er>Measure</er>,
<er>Meter</er>.</cd> -- <col><b>Long Parliament</b></col> <fld>(Eng.
Hist.)</fld>, <cd>the Parliament which assembled Nov. 3, 1640, and was
dissolved by Cromwell, April 20, 1653.</cd> -- <col><b>Long
price</b></col>, <cd>the full retail price.</cd> -- <col><b>Long
purple</b></col> <fld>(Bot.)</fld>, <cd>a plant with purple flowers,
supposed to be the <spn>Orchis mascula</spn>.</cd> <au>Dr. Prior.</au>
-- <col><b>Long suit</b></col> <sd>(a)</sd> <fld>(Whist)</fld>, <cd>a
suit of which one holds originally more than three cards.</cd> <au>R. A.
Proctor.</au> <sd>(b)</sd> <cd>One's most important resource or source
of strength; <as>as, as an entertainer, her voice was her <ex>long
suit</ex></as>.</cd> -- <col><b>Long tom</b></col>. <sd>(a)</sd> <cd>A
pivot gun of great length and range, on the dock of a vessel.</cd>
<sd>(b)</sd> <cd>A long trough for washing auriferous earth.</cd>
<mark>[Western U.S.]</mark> <sd>(c)</sd> <fld>(Zool.)</fld> <cd>The
long-tailed titmouse.</cd> -- <col><b>Long wall</b></col> <fld>(Coal
Mining)</fld>, <cd>a working in which the whole seam is removed and the
roof allowed to fall in, as the work progresses, except where passages
are needed.</cd> -- <col><b>Of long</b></col>, <cd>a long time.</cd>
<mark>[Obs.]</mark> <au>Fairfax.</au> -- <mcol><col><b>To be long of the
market</b></col>, <it>or</it> <col><b>To go long of the
market</b></col>, <col><b>To be on the long side of the
market</b></col>, etc.</mcol> <fld>(Stock Exchange)</fld>, <cd>to hold
stock for a rise in price, or to have a contract under which one can
demand stock on or before a certain day at a stipulated price; --
opposed to <ant>short</ant> in such phrases as, <xex>to be short of
stock</xex>, <xex>to sell short</xex>, etc.</cd> <mark>[Cant]</mark>
<see>See <er>Short</er>.</see> -- <col><b>To have a long head</b></col>,
<cd>to have a farseeing or sagacious mind.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long</ent><br/
<hw>Long</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <fld>(Mus.)</fld>
<def>A note formerly used in music, one half the length of a large,
twice that of a breve.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phonetics)</fld> <def>A long sound, syllable, or
vowel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The longest dimension; the greatest extent; -- in
the phrase, <xex>the long and the short of it</xex>, that is, the sum
and substance of it.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long</ent><br/
<hw>Long</hw>, <pos>adv.</pos> <ety>[AS. <ets>lance</ets>.]</ety>
<sn>1.</sn> <def>To a great extent in space; <as>as, a <ex>long</ex>
drawn out line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To a great extent in time; during a long
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They that tarry <qex>long</qex> at the wine.</q> <rj><qau>Prov.
xxiii. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When the trumpet soundeth <qex>long</qex>.</q> <rj><qau>Ex. xix.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>At a point of duration far distant, either prior or
posterior; <as>as, not <ex>long</ex> before; not <ex>long</ex> after;
<ex>long</ex> before the foundation of Rome; <ex>long</ex> after the
Conquest.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Through the whole extent or duration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bird of dawning singeth all night <qex>long</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Through an extent of time, more or less; -- only in
question; <as>as, how <ex>long</ex> will you be gone?</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long</ent><br/
<hw>Long</hw>, <pos>prep.</pos> <ety>[Abbreviated fr. <ets>along</ets>.
See 3d <er>Along</er>.]</ety> <def>By means of; by the fault of; because
of.</def> <mark>[Obs.]</mark> <see>See <cref>Along of</cref>, under 3d
<er>Along</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long</ent><br/
<hw>Long</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Longed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Longing</conjf>.]</vmorph> <ety>[AS. <ets>langian</ets> to
increase, to lengthen, to stretch out the mind after, to long, to crave,
to belong to, fr. <ets>lang</ets> long. See <er>Long</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To feel a strong or morbid desire
or craving; to wish for something with eagerness; -- followed by an
infinitive, or by <ptcl>for</ptcl> or <ptcl>after</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>long</qex> to see you.</q> <rj><qau>Rom. i.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>longed</qex> after thy precepts.</q> <rj><qau>Ps.
cxix. 40.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>longed</qex> for thy salvation.</q> <rj><qau>Ps. cxix.
174.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nicomedes, <qex>longing</qex> for herrings, was supplied with
fresh ones . . . at a great distance from the sea.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To belong; -- used with <ptcl>to</ptcl>,
<ptcl>unto</ptcl>, or <ptcl>for</ptcl>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The labor which that <qex>longeth</qex> unto me.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-acting</ent><br/
<hw>long-acting</hw> <pos>adj.</pos> <def>active over a relatively long
period of time.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longan</ent><br/
<hw>Lon"gan</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
pulpy fruit related to the litchi, and produced by an evergreen East
Indian <altname>longanberry</altname> (<spn>Nephelium
Longan</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>longanberry</ent><br/
<hw>longanberry</hw> <pos>n.</pos> <def>A tree (<spn>Dimocarpus
longan</spn>) of Southeastern Asia to Australia grown primarily for its
sweet translucent-fleshed edible fruit (the <prod>longan</prod>)
resembling litchi nuts; -- it is sometimes placed in genera
<gen>Euphoria</gen> or <gen>Nephelium</gen>.</def><br/
<syn><b>Syn. --</b> longan, lungen, <spn>Dimocarpus longan</spn>,
<spn>Euphoria litchi</spn>, <gen>Nephelium longana</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Asian fruit similar to litchi.</def><br/
<syn><b>Syn. --</b> dragon's eye.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longanimity</ent><br/
<hw>Lon`ga*nim"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>longanimitas</ets>; <ets>longus</ets> long + <ets>animus</ets>
mind: cf. F. <ets>longanimit<eacute/</ets>.]</ety> <def>Disposition to
bear injuries patiently; forbearance; patience.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-armed</ent><br/
<hw>Long"-armed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having long arms;
<as>as, the <ex>long-armed</ex> ape or gibbon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longbeak</ent><br/
<hw>Long"beak`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The American redbellied snipe (<spn>Macrorhamphus
scolopaceus</spn>); -- called also <altname>long-billed
dowitcher</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>longbeard</ent><br/
<hw>longbeard</hw> <pos>n.</pos> <def>a fat-bellied stoneware drinking
jug with a long neck; decorated with a caricature of <person>Cardinal
Bellarmine</person> (17th century).</def><br/
<syn><b>Syn. --</b> bellarmine, graybeard.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longboat</ent><br/
<hw>Long"boat`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>Formerly, the largest boat carried by a merchant vessel,
corresponding to the launch of a naval vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longbow</ent><br/
<hw>Long"bow`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The ordinary bow,
not mounted on a stock; -- so called in distinction from the
<contr>crossbow</contr> when both were used as weapons of war. Also,
sometimes, such a bow of about the height of a man, as distinguished
from a much shorter one.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To draw the longbow</b></col>, <cd>to tell large
stories.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-breathed</ent><br/
<hw>Long"-breathed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
power of retaining the breath for a long time; long-winded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-dated</ent><br/
<hw>long-dated</hw> <pos>adj.</pos> <fld>(Finance)</fld> <def>of a
gilt-edged security: having more than 15 years to run before
redemption.</def> <mark>[British]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-distance</ent><br/
<hw>long-distance</hw> <pos>adj.</pos> <def>covering long distances;
<as>as, a <ex>long-distance</ex> runner; a <ex>long-distance</ex>
telephone call</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Long-drawn</ent><br/
<hw>Long"-drawn`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Extended to a
great length.</def><br/
<syn><b>Syn. --</b> long-drawn-out.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>The cicadae hushed their <qex>long-drawn</qex>, ear-splitting
strains.</q> <rj><qau>G. W. Cable.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-drawn-out</ent><br/
<hw>long-drawn-out</hw> <pos>adj.</pos> <sn>1.</sn> <def>relatively long
in duration; <as>as, a <ex>long-drawn-out</ex> visit from my
mother-in-law</as>.</def><br/
<syn><b>Syn. --</b> drawn-out, extended, prolonged,
protracted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longe</ent><br/
<hw>Longe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Abbrev. fr.
<ets>allonge</ets>. See <er>Lunge</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A thrust. See <er>Lunge</er>.</def>
<rj><au>Smollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The training ground for a horse.</def>
<rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longe</ent><br/
<hw>Longe</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as 4th
<er>Lunge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longer</ent><br/
<hw>Long"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who longs for
anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longeval</ent><br/
<hw>Lon*ge"val</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Long-loved;
longevous.</def> <mark>[R.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longevity</ent><br/
<hw>Lon*gev"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>longaevitas</ets>. See <er>Longevous</er>.]</ety> <def>Long
duration of life; length of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The instances of <qex>longevity</qex> are chiefly amongst the
abstemious.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longevous</ent><br/
<hw>Lon*ge"vous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>longaevus</ets>; <ets>longus</ets> long + <ets>aevum</ets>
lifetime, age. See <er>Long</er>, and <er>Age</er>.]</ety> <def>Living a
long time; of great age.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-faced</ent><br/
<hw>long-faced</hw> <pos>adj.</pos> <sn>1.</sn> <def>filled with or
reflecting gloom.</def><br/
<syn><b>Syn. --</b> glum, gloomy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having a face longer than the usual.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-familiar</ent><br/
<hw>long-familiar</hw> <pos>adj.</pos> <def>frequently seen or
experienced; <as>as, a <ex>long-familiar</ex> face</as>.</def><br/
<syn><b>Syn. --</b> well-known(prenominal), well
known(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-haired</ent><br/
<hw>long-haired</hw> <pos>adj.</pos> <def>having long hair; <as>as,
<ex>long-haired</ex> hippies</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longhand</ent><br/
<hw>Long"hand`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The written
characters used in the common method of writing; -- opposed to
<contr>shorthand</contr>; <as>as, took it down in
<ex>longhand</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longheaded</ent><br/
<hw>Long"head"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having unusual foresight or sagacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>having a relatively long head with a cephalic index
of under 75. Opposite of <ant>brachycephalic</ant>.</def><br/
<syn><b>Syn. --</b> dolichocephalic, dolichocranal,
dolichocranic.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p> -- <wordforms><wf>Long"-head`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longhorn</ent><br/
<hw>Long"horn`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A long-horned animal, as a cow, goat, or beetle.
See <er>Long-horned</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The <er>Texas longhorn</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Long-horned</ent><br/
<hw>Long"-horned`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<mark>[Obs.]</mark> <def>Having a long horn or horns; <as>as, a
<ex>long-horned</ex> goat, or cow</as>; having long antenn<ae/, as
certain beetles (<fam>Longicornia</fam>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longicorn</ent><br/
<hw>Lon"gi*corn</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>longus</ets> long + <ets>cornu</ets> horn: cf. F.
<ets>longicorne</ets>.]</ety> <fld>(Zool.)</fld> <def>Long-horned;
pertaining to the <fam>Longicornia</fam>.</def> -- <def2><pos>n.</pos>
<def>One of the Longicornia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longicornia</ent><br/
\'d8<hw>Lon`gi*cor"ni*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>longus</ets> long + <ets>cornu</ets> horn.]</ety>
<fld>(Zool.)</fld> <def>A division of beetles, including a large number
of species, in which the antenn<ae/ are very long. Most of them, while
in the larval state, bore into the wood or beneath the bark of trees,
and some species are very destructive to fruit and shade trees. See
<stype>Apple borer</stype>, under <er>Apple</er>, and <stype>Locust
beetle</stype>, under <er>Locust</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longilateral</ent><br/
<hw>Lon`gi*lat"er*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>longus</ets> long + <ets>lateralis</ets> lateral, fr.
<ets>latus</ets> side.]</ety> <def>Having long sides; especially, having
the form of a long parallelogram.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nineveh . . . was of a <qex>longilateral</qex> figure, ninety-five
furlongs broad, and a hundred and fifty long.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longiloquence</ent><br/
<hw>Lon*gil"o*quence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>langus</ets> long + <ets>loquentia</ets> a talking.]</ety>
<def>Long-windedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>American <qex>longiloquence</qex> in oratory.</q> <rj><qau>Fitzed.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longimanous</ent><br/
<hw>Lon*gim"a*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>longus</ets> long + <ets>manus</ets> hand.]</ety> <def>Having long
hands.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longimetry</ent><br/
<hw>Lon*gim"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>longus</ets> long + <ets>-metry</ets>: cf. F.
<ets>longim<eacute/trie</ets>.]</ety> <def>The art or practice of
measuring distances or lengths.</def> <rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longing</ent><br/
<hw>Long"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An eager desire; a
craving; a morbid appetite; an earnest wish; an aspiration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Put on my crown; I have<br/
immortal <qex>longings</qex> in me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longingly</ent><br/
<hw>Long"ing*ly</hw>, <pos>adv.</pos> <def>With longing.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longinquity</ent><br/
<hw>Lon*gin"qui*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>longinquitas</ets>, fr. <ets>longinquus</ets> extensive, remote,
fr. <ets>longus</ets> long.]</ety> <def>Greatness of distance;
remoteness.</def> <mark>[R.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longipalp</ent><br/
<hw>Lon"gi*palp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>longipalpe</ets>, fr. L. <ets>longus</ets> long + F.
<ets>palpe</ets> a feeler, a palp.]</ety> <fld>(Zool.)</fld> <def>One of
a tribe of beetles, having long maxillary palpi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longipennate</ent><br/
<hw>Lon"gi*pen"nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>longus</ets> long + E. <ets>pennate</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having long wings, or quills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longipennes</ent><br/
\'d8<hw>Lon`gi*pen"nes</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from L. <ets>longus</ets> long + <ets>penna</ets> wing.]</ety>
<fld>(Zool.)</fld> <def>A group of longwinged sea birds, including the
gulls, petrels, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longipennine</ent><br/
<hw>Lon`gi*pen"nine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Longipennes; longipennate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longiroster</ent><br/
<hw>Lon`gi*ros"ter</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
L. <plw>Longirostres</plw> <pr>(#)</pr>, E. <plw>Longirosters</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>longus</ets> long + <ets>rostrum</ets>
beak: cf. F. <ets>longirostre</ets>.]</ety> <fld>(Zool.)</fld> <def>One
of the Longirostres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longirostral</ent><br/
<hw>Lon`gi*ros"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a long bill; of or pertaining to the Longirostres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longirostres</ent><br/
\'d8<hw>Lon`gi*ros"tres</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>longus</ets> long + <ets>rostrum</ets> beak.]</ety>
<fld>(Zool.)</fld> <def>A group of birds characterized by having long
slender bills, as the sandpipers, curlews, and ibises. It is now
regarded as an artificial division.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longish</ent><br/
<hw>Long"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat long;
moderately long.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longitude</ent><br/
<hw>Lon"gi*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>longitudo</ets>, fr. <ets>longus</ets> long.]</ety> <sn>1.</sn>
<def>Length; measure or distance along the longest line; --
distinguished from <contr>breadth</contr> or <contr>thickness</contr>;
<as>as, the <ex>longitude</ex> of a room</as>; rare now, except in a
humorous sense.</def> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>longitude</qex> of their cloaks.</q> <rj><qau>Sir. W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mine [shadow] spindling into <qex>longitude</qex> immense.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geog.)</fld> <def>The arc or portion of the equator
intersected between the meridian of a given place and the meridian of
some other place from which longitude is reckoned, as from Greenwich,
England, or sometimes from the capital of a country, as from Washington
or Paris. The longitude of a place is expressed either in degrees or in
time; <as>as, that of New York is 74<deg/ or 4 h. 56 min. west of
Greenwich.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>The distance in degrees,
reckoned from the vernal equinox, on the ecliptic, to a circle at right
angles to the ecliptic passing through the heavenly body whose longitude
is designated; <as>as, the <ex>longitude</ex> of Capella is
79<deg/</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Geocentric longitude</b></col> <fld>(Astron.)</fld>,
<cd>the longitude of a heavenly body as seen from the earth.</cd> --
<col><b>Heliocentric longitude</b></col>, <cd>the longitude of a
heavenly body, as seen from the sun's center.</cd> -- <col><b>Longitude
stars</b></col>, <cd>certain stars whose position is known, and the data
in regard to which are used in observations for finding the longitude,
as by lunar distances.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longitudinal</ent><br/
<hw>Lon`gi*tu"di*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>longitudinal</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to
longitude or length; <as>as, <ex>longitudinal</ex>
distance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extending in length; in the direction of the length;
running lengthwise, as distinguished from <contr>transverse</contr>;
<as>as, the <ex>longitudinal</ex> diameter of a body</as>.</def>
<rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longitudinal</ent><br/
<hw>Lon`gi*tu"di*nal</hw>, <pos>n.</pos> <def>A railway sleeper lying
parallel with the rail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longitudinally</ent><br/
<hw>Lon`gi*tu"di*nal*ly</hw>, <pos>adv.</pos> <def>In the direction of
length.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-lasting</ent><br/
<hw>long-lasting</hw> <pos>adj.</pos> <def>Existing or persisting for a
long time; <as>as, a <ex>long-lasting</ex> friendship</as>.</def><br/
<syn><b>Syn. --</b> durable, lasting, long-lived.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-legged</ent><br/
<hw>long-legged</hw> <pos>adj.</pos> <def>having long legs.</def><br/
<syn><b>Syn. --</b> leggy, long-shanked.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longlegs</ent><br/
<hw>Long"legs`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A <er>daddy longlegs</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-lived</ent><br/
<hw>Long"-lived`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a long life; having constitutional peculiarities which make
long life probable; lasting long; <as>as, a <ex>long-lived</ex> tree;
they are a <ex>long-lived</ex> family; <ex>long-lived</ex>
prejudices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>same as <er>long-lasting</er>.</def><br/
<syn><b>Syn. --</b> durable, lasting, long-lasting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longly</ent><br/
<hw>Long"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>With longing
desire.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>For a long time; hence, wearisomely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longmynd rocks</ent><br/
<hw>Long"mynd rocks"</hw> <pr>(?)</pr> <pos>n. pl.</pos>
<fld>(Geol.)</fld> <def>The sparingly fossiliferous conglomerates,
grits, schists, and slates of Great Britain, which lie at the base of
the Cambrian system; -- so called, because typically developed in the
<etsep>Longmynd</etsep> Hills, Shropshire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longness</ent><br/
<hw>Long"ness</hw>, <pos>n.</pos> <def>Length.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longnose</ent><br/
<hw>Long"nose`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European garfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-play</ent><br/
<hw>long-play</hw> <pos>adj.</pos> <def>same as
<er>long-playing</er>.</def><br/
<syn><b>Syn. --</b> long-playing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-playing</ent><br/
<hw>long-playing</hw> <pos>adj.</pos> <def>playing at a slower speed and
for a longer time than earlier records; -- used of phonograph
records.</def><br/
<syn><b>Syn. --</b> long-play, LP.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Long primer</ent><br/
<hw>Long" prim"er</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Print.)</fld>
<def>A kind of type, in size between small pica and bourgeois.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <longprimertype>This line is printed in <it>long
primer</it>.</longprimertype></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-range</ent><br/
<hw>long-range</hw> <pos>adj.</pos> <sn>1.</sn> <def>involving an
extended span of time; -- of plans, goals, or predictions; <as>as,
<ex>long-range</ex> goals; a <ex>long-range</ex> weather
forecast</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>suitable for or reaching long distances; <as>as, a
<ex>long-range</ex> missile; <ex>long-range</ex> nuclear
capability</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-run</ent><br/
<hw>long-run</hw> <pos>adj.</pos> <sn>1.</sn> <def>relating to or
extending over a relatively long time; <as>as, the <ex>long-run</ex>
significance of the elections</as>.</def><br/
<syn><b>Syn. --</b> long-term.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>long-shanked</ent><br/
<hw>long-shanked</hw> <pos>adj.</pos> <def>having long legs.</def><br/
<syn><b>Syn. --</b> leggy, long-legged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Longshanks</ent><br/
<hw>Long"shanks`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The stilt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longshore</ent><br/
<hw>Long"shore`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Abbrev. from
<ets>alongshore</ets>.]</ety> <def>Belonging to the seashore or a
seaport; along and on the shore.</def> <ldquo/<xex>Longshore</xex>
thieves.<rdquo/ <rj><au>R. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longshoreman</ent><br/
<hw>Long"shore`man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Longshoremen</plw> <pr>(#)</pr>.</plu> <ety>[Abbrev. fr.
<ets>alongshoreman</ets>.]</ety> <def>One of a class of laborers
employed about the wharves of a seaport, especially in loading and
unloading vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-sight</ent><br/
<hw>Long"-sight</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Long-sightedness.</def> <rj><au>Good.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-sighted</ent><br/
<hw>Long"-sight`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Able to see objects at a great distance; hence, having great
foresight; sagacious; farseeing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Able to see objects distinctly at a distance, but
not close at hand; hypermetropic.</def><-- = farsighted, hyperopic?
--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-sightedness</ent><br/
<hw>Long"-sight`ed*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state
or condition of being long-sighted; hence, sagacity;
shrewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>See
<er>Hypermetropia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longsome</ent><br/
<hw>Long"some</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[AS.
<ets>langsum</ets>.]</ety> <def>Extended in length; tiresome.</def>
<mark>[Obs.]</mark> <au>Bp. Hall.</au> <au>Prior.</au> --
<wordforms><wf>Long"some*ness</wf>, <pos>n.</pos> <mark>[Obs.]</mark>
<au>Fuller.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longspun</ent><br/
<hw>Long"spun`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Spun out, or
extended, to great length; hence, long-winded; tedious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>longspun</qex> allegories fulsome grow,<br/
While the dull moral lies too plain below.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longspur</ent><br/
<hw>Long"spur`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from the
length of the hind claw.]</ety> <fld>(Zool.)</fld> <def>Any one of
several species of fringilline birds of the genus <gen>Calcarius</gen>
(or <gen>Plectrophanes</gen>), and allied genera. The Lapland longspur
(<spn>Calcarius Lapponicus</spn>), the chestnut-colored longspur
(<spn>Calcarius ornatus</spn>), and other species, inhabit the United
States.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-standing</ent><br/
<hw>long-standing</hw> <pos>adj.</pos> <def>existing since a time in the
distant past; <as>as, <ex>long-standing</ex> policies</as>.</def>
<mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> longtime(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Long-stop</ent><br/
<hw>Long"-stop`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Cricket)</fld>
<def>One who is set to stop balls which pass the wicket
keeper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-sufferance</ent><br/
<hw>Long"-suf`fer*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Forbearance to punish or resent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>patient endurance of pain or unhappiness.</def><br/
<syn><b>Syn. --</b> long-suffering.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Long-suffering</ent><br/
<hw>Long"-suf`fer*ing</hw>, <pos>n.</pos> <def>Bearing injuries or
provocation for a long time; patient endurance of pain or unhappiness;
patient; not easily provoked.</def><br/
<syn><b>Syn. --</b> long-sufferance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord God, merciful and gracious, <qex>long-suffering</qex>,
and abundant in goodness and truth.</q> <rj><qau>Ex. xxxiv.
6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-suffering</ent><br/
<hw>Long"-suf`fer*ing</hw>, <pos>n.</pos> <def>disposed to bear
inconvenience or injury patiently; long patience of offense; <as>as, a
<ex>long-suffering</ex> and uncomplaining wife</as>.</def><br/
<syn><b>Syn. --</b> enduring, forbearing, longanimous, meek.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>Despisest thou the riches of his goodness and forbearance and
<qex>long-suffering</qex>?</q> <rj><qau>Rom. ii. 4. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longtail</ent><br/
<hw>Long"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An animal,
particularly a log, having an uncut tail. Cf. <er>Curtail</er>.
<er>Dog</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>longtail</xex> was a gentleman's dog, or the dog
of one qualified to bunt, other dogs being required to have their tails
cut.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cut and longtail</b></col>, <cd>all, gentlefolks and
others, as they might come.</cd> <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-term</ent><br/
<hw>long-term</hw> <pos>adj.</pos> <def>same as <er>long-run</er>;
<as>as, the <ex>long-term</ex> consequences</as>.</def><br/
<syn><b>Syn. --</b> long-run.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Long-tongue</ent><br/
<hw>Long"-tongue`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The wryneck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-tongued</ent><br/
<hw>Long"-tongued`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a long tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Talkative; babbling; loquacious.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longulite</ent><br/
<hw>Lon"gu*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>longus</ets> long + <ets>-lie</ets>.]</ety> <fld>(Min.)</fld>
<def>A kind of crystallite having a (slender) acicular form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Long-waisted</ent><br/
<hw>Long"-waist`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a long waist; long from the armpits to the bottom of the
waist; -- said of persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Long from the part about the neck or shoulder, or
from the armpits, to the bottom of the weist, or to the skirt; -- said
of garments; <as>as, a <ex>long-waisted</ex> coat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longways</ent><br/
<hw>Long"ways`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Lengthwise.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>long-wearing</ent><br/
<hw>long-wearing</hw> <pos>adj.</pos> <def>withstanding long use without
deterioration; resistant to damage.</def><br/
<syn><b>Syn. --</b> durable.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Long-winded</ent><br/
<hw>Long"-wind"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Long-breathed; hence, tediously long in speaking; consuming much
time; <as>as, a <ex>long-winded</ex> talker</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A tedious, <qex>long-winded</qex> harangue.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>using or containing too many words; <as>as,
<ex>long-winded</ex> (or windy) speakers</as>.</def><br/
<syn><b>Syn. --</b> tedious, verbose, windy, wordy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p> -- <wordforms><wf>Long"-wind"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Longwise</ent><br/
<hw>Long"wise`</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Lengthwise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lonicera</ent><br/
<hw>Lonicera</hw> <pos>n.</pos> <def>A genus of vines including the
woodbine, <spn>Lonicera periclymenum</spn>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lonicera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lontar</ent><br/
<hw>lontar</hw> <pos>n.</pos> <def>A tall fan palm (<spn>Borassus
flabellifer</spn>) of Africa and India and Malaysia yielding a hard wood
and sweet sap that is a source of palm wine and sugar; the
<altname>palmyra</altname>; -- its leaves are used for thatching and
weaving.</def><br/
<syn><b>Syn. --</b> palmyra, palmyra palm, toddy palm, wine palm, longar
palm, <spn>Borassus flabellifer</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loo</ent><br/
<hw>Loo</hw> <pr>(l<oomac/)</pr>, <pos>n.</pos> <ety>[For older
<ets>lanterloo</ets>, F. <ets>lanturelu</ets>, <ets>lanturlu</ets>, name
of the game; orig., the refrain of a vaudeville.]</ety> <sd>(a)</sd>
<def>An old game played with five, or three, cards dealt to each player
from a full pack. When five cards are used the highest card is the knave
of clubs or (if so agreed upon) the knave of trumps; -- formerly called
<altname>lanterloo</altname>.</def> <sd>(b)</sd> <def>A modification of
the game of <ldquo/all fours<rdquo/ in which the players replenish their
hands after each round by drawing each a card from the pack.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 868 --></p>

<p><cs><col><b>Loo table</b></col>, <cd>a round table adapted for a
circle of persons playing loo.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loo</ent><br/
<hw>Loo</hw> <pr>(l<oomac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Looed</conjf> <pr>(l<oomac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Looing</conjf>.]</vmorph> <def>To beat in the game of
loo by winning every trick.</def> <altsp>[Written also
<asp>lu</asp>.]</altsp> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loob</ent><br/
<hw>Loob</hw> <pr>(l<oomac/b)</pr>, <pos>n.</pos> <ety>[Corn., slime,
sludge.]</ety> <fld>(Mining)</fld> <def>The clay or slimes washed from
tin ore in dressing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loobily</ent><br/
<hw>Loo"bi*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Looby</er>.]</ety> <def>Loobylike; awkward.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loobily</ent><br/
<hw>Loo"bi*ly</hw>, <pos>adv.</pos> <def>Awkwardly.</def>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looby</ent><br/
<hw>Loo"by</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Loobies</plw> <pr>(#)</pr>.</plu> <ety>[Cf. <er>Lob</er>.]</ety>
<def>An awkward, clumsy fellow; a lubber.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looch</ent><br/
<hw>Looch</hw> <pr>(l<oomac/ch)</pr>, <pos>n.</pos> <def>See 2d
<er>Loch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loof</ent><br/
<hw>Loof</hw> <pr>(l<oomac/f)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The spongelike fibers of the fruit of a cucurbitaceous plant
(<spn>Luffa Aegyptiaca</spn>); called also <altname>vegetable
sponge</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loof</ent><br/
<hw>Loof</hw> <pr>(l<oomac/f <it>or</it> l<ucr/f; 277)</pr>,
<pos>n.</pos> <ety>[See <er>Luff</er>.]</ety> <altsp>[Also written
<asp>luff</asp>.]</altsp> <fld>(Naut.)</fld> <sd>(a)</sd> <def>Formerly,
some appurtenance of a vessel which was used in changing her course; --
probably a large paddle put over the lee bow to help bring her head
nearer to the wind.</def> <sd>(b)</sd> <def>The part of a ship's side
where the planking begins to curve toward bow and stern.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loof</ent><br/
<hw>Loof</hw>, <pos>v. i.</pos> <fld>(Naut.)</fld> <def>See
<er>Luff</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Look</ent><br/
<hw>Look</hw> <pr>(l<oocr/k)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Looked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Looking</conjf>.]</vmorph> <ety>[OE. <ets>loken</ets>,
AS. <ets>l<omac/cian</ets>; akin to G. <ets>lugen</ets>, OHG.
<ets>luog<emac/n</ets>.]</ety> <sn>1.</sn> <def>To direct the eyes for
the purpose of seeing something; to direct the eyes toward an object; to
observe with the eyes while keeping them directed; -- with various
prepositions, often in a special or figurative sense. See Phrases
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To direct the attention (to something); to consider;
to examine; <as>as, to <ex>look</ex> at an action</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To seem; to appear; to have a particular appearance;
<as>as, the patient <ex>looks</ex> better; the clouds <ex>look</ex>
rainy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>It would <qex>look</qex> more like vanity than gratitude.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Observe how such a practice <qex>looks</qex> in another
person.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To have a particular direction or situation; to
face; to front.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The inner gate that <qex>looketh</qex> to north.</q>
<rj><qau>Ezek. viii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The east gate . . . which <qex>looketh</qex> eastward.</q>
<rj><qau>Ezek. xi. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>In the imperative: see; behold; take notice; take
care; observe; -- used to call attention.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Look</qex>, how much we thus expel of sin, so much we expel
of virtue.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Look</xex>, in the imperative, may be followed by a
dependent sentence, but <xex>see</xex> is oftener so used.</note><-- See
spot run? in 1990, the reverse is true --><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Look</qex> that ye bind them fast.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Look</qex> if it be my daughter.</q>
<rj><qau>Talfourd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To show one's self in looking, as by leaning out of
a window; <as>as, <ex>look</ex> out of the window while I speak to
you</as>. Sometimes used figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My toes <qex>look</qex> through the overleather.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To await the appearance of anything; to expect; to
anticipate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Looking</qex> each hour into death's mouth to fall.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To look about</b></col>, <cd>to look on all sides, or in
different directions.</cd> -- <col><b>To look about one</b></col>,
<cd>to be on the watch; to be vigilant; to be circumspect or
guarded.</cd> -- <col><b>To look after</b></col>. <sd>(a)</sd> <cd>To
attend to; to take care of; <as>as, <ex>to look after</ex>
children</as>.</cd> <sd>(b)</sd> <cd>To expect; to be in a state of
expectation.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Men's hearts failing them for fear, and for <qex>looking
after</qex> those things which are coming on the earth.</q>
<rj><qau>Luke xxi. 26.</qau></rj></p>

<p><sd>(c)</sd> <cd>To seek; to search.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>My subject does not oblige me <qex>to look after</qex> the water,
or point forth the place where to it is now retreated.</q>
<rj><qau>Woodward.</qau></rj></p>

<p>-- <col><b>To look at</b></col>, <cd>to direct the eyes toward so
that one sees, or as if to see; <as>as, <ex>to look at</ex> a star</as>;
hence, to observe, examine, consider; <as>as, <ex>to look at</ex> a
matter without prejudice</as>.</cd> -- <col><b>To look black</b></col>,
<cd>to frown; to scowl; to have a threatening appearance.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The bishops thereat repined, and <qex>looked black</qex>.</q>
<rj><qau>Holinshed.</qau></rj></p>

<p>-- <mcol><col><b>To look down on</b></col> <it>or</it> <col><b>To
look down upon</b></col></mcol>, <cd>to treat with indifference or
contempt; to regard as an inferior; to despise.</cd> -- <col><b>To look
for</b></col>. <sd>(a)</sd> <cd>To expect; <as>as, <ex>to look for</ex>
news by the arrival of a ship</as>.</cd> <ldquo/<xex>Look</xex> now
<xex>for</xex> no enchanting voice.<rdquo/ <au>Milton.</au> <sd>(b)</sd>
<cd>To seek for; to search for; <as>as, <ex>to look for</ex> lost money,
or lost cattle</as>.</cd> -- <col><b>To look forth</b></col>.
<sd>(a)</sd> <cd>To look out of something, as from a window.</cd>
<sd>(b)</sd> <cd>To threaten to come out.</cd> <au>Jer. vi. 1. (Rev.
Ver.).</au> -- <col><b>To look forward to</b></col>. <cd>To anticipate
with an expectation of pleasure; to be eager for; <as>as, I am
<ex>looking forward to</ex> your visit</as>.</cd> -- <col><b>To look
into</b></col>, <cd>to inspect closely; to observe narrowly; to examine;
<as>as, <ex>to look into</ex> the works of nature; <ex>to look into</ex>
one's conduct or affairs</as>.</cd> -- <col><b>To look on</b></col>.
<sd>(a)</sd> <cd>To regard; to esteem.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Her friends would <qex>look on</qex> her the worse.</q>
<rj><qau>Prior.</qau></rj></p>

<p><sd>(b)</sd> <cd>To consider; to view; to conceive of; to think
of.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>looked on</qex> Virgil as a succinct, majestic writer.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><sd>(c)</sd> <cd>To be a mere spectator.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll be a candleholder, and <qex>look on</qex>.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <col><b>To look out</b></col>, <cd>to be on the watch; to be
careful; as, the seaman <xex>looks out</xex> for breakers.</cd> --
<col><b>To look through</b></col>. <sd>(a)</sd> <cd>To see through.</cd>
<sd>(b)</sd> <cd>To search; to examine with the eyes.</cd> --
<mcol><col><b>To look to</b></col> <it>or</it> <col><b>To look
unto</b></col></mcol>. <sd>(a)</sd> <cd>To watch; to take care of.</cd>
<ldquo/<xex>Look</xex> well <xex>to</xex> thy herds.<rdquo/ <au>Prov.
xxvii. 23.</au> <sd>(b)</sd> <cd>To resort to with expectation of
receiving something; to expect to receive from; as, the creditor may
<xex>look to</xex> surety for payment.</cd> <ldquo/<xex>Look unto</xex>
me, and be ye saved.<rdquo/ <au>Is. xlv. 22.</au> -- <col><b>To look
up</b></col>, <cd>to search for or find out by looking; as, <xex>to look
up</xex> the items of an account.</cd> -- <col><b>To look up
to</b></col>, <cd>to respect; to regard with deference.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Look</ent><br/
<hw>Look</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To look at; to turn the
eyes toward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To seek; to search for.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Looking</qex> my love, I go from place to place.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To expect.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To influence, overawe, or subdue by looks or
presence as, to <xex>look</xex> down opposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A spirit fit to start into an empire,<br/
And <qex>look</qex> the world to law.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To express or manifest by a look.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soft eyes <qex>looked</qex> love to eyes which spake again.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To look daggers</b></col>. <cd>See under
<er>Dagger</er>.</cd> -- <col><b>To look in the face</b></col>, <cd>to
face or meet with boldness or confidence; hence, sometimes, to meet for
combat.</cd> -- <col><b>To look out</b></col>, <cd>to seek for; to
search out; <as>as, prudent persons <ex>look out</ex> associates of good
reputation</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Look</ent><br/
<hw>Look</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of
looking; a glance; a sight; a view; -- often in certain phrases; <as>as,
to have, get, take, throw, or cast, a <ex>look</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Threw many a northward <qex>look</qex> to see his father<br/
Bring up his powers; but he did long in vain.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expression of the eyes and face; manner; <as>as, a
proud or defiant <ex>look</ex></as>.</def> <ldquo/Gentle
<xex>looks</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Up ! up! my friends, and clear your <qex>looks</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence;</specif> <def>Appearance; aspect; <as>as,
the house has a gloomy <ex>look</ex>; the affair has a bad
<ex>look</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pain, disgrace, and poverty have frighted <qex>looks</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There was something that reminded me of Dante's Hell in the
<qex>look</qex> of this.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>look-down</ent><br/
<ent>lookdown</ent><br/
<mhw><hw>look"down`</hw>, <hw>look"-down`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>A fish (<spn>Selene vomer</spn>)
similar to the moonfish but with eyes high on the truncated forehead; it
was also called moonfish at one time.</def><br/
<syn><b>Syn. --</b> <spn>Selene vomer</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>looked-for</ent><br/
<hw>looked-for</hw> <pos>adj.</pos> <def>same as <er>anticipated</er>,
2; <as>as, his <ex>looked-for</ex> advancement</as>.</def>
<mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> anticipated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Looker</ent><br/
<hw>Look"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
looks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who is physically very attractive,
especially a beautiful woman.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Looker-on</b></col>, <cd>a spectator; an onlooker; one
that looks on, but has no agency or part in an affair.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Did not this fatal war affront thy coast,<br/
Yet sattest thou an idle <qex>looker-on</qex> ?</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looking</ent><br/
<hw>Look"ing</hw>, <pos>a.</pos> <def>Having a certain look or
appearance; -- often compounded with adjectives; <as>as,
good<ex>-looking</ex>, grand<ex>-looking</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looking</ent><br/
<hw>Look"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
looks; a glance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manner in which one looks; appearance;
countenance; face.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All dreary was his cheer and his <qex>looking</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Looking for</b></col>, <cd>anticipation;
expectation.</cd> <ldquo/A certain fearful <xex>looking for</xex> of
judgment.<rdquo/ <rj><au>Heb. x. 27.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looking-glass</ent><br/
<hw>Look"ing-glass`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mirror made
of glass on which has been placed a backing of some reflecting
substance, as quicksilver.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is none so homely but loves a <qex>looking-glass</qex>.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lookout</ent><br/
<hw>Look"out`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
careful looking or watching for any object or event.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place from which such observation is
made.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person engaged in watching; a sentinel; a
sentry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Object or duty of forethought and care;
responsibility.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>on the lookout for</b></col> <cd>in search of; looking
for.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>look-over</ent><br/
<hw>look-over</hw> <pos>n.</pos> <def>a swift cursory examination or
inspection; <as>as, I gave the car a quick
<ex>look-over</ex></as>.</def><br/
<syn><b>Syn. --</b> once-over.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lookup</ent><br/
<hw>look"up</hw> <pos>n.</pos> <fld>(Computers)</fld> <def>an operation
that determines whether one or more of a set of items has a specified
property; <as>as, they wrote a program to do a table
<ex>lookup</ex></as>.</def><br/
<syn><b>Syn. --</b> search.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lool</ent><br/
<hw>Lool</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Metal.)</fld> <def>A
vessel used to receive the washings of ores of metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loom</ent><br/
<hw>Loom</hw> <pr>(l<oomac/m)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Loon</er>, the bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loom</ent><br/
<hw>Loom</hw> <pr>(l<oomac/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lome</ets>, AS. <ets>gel<omac/ma</ets> utensil,
implement.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A frame or machine of wood or other material, in
which a weaver forms cloth out of thread; a machine for interweaving
yarn or threads into a fabric, as in knitting or lace making.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hector, when he sees Andromache overwhelmed with terror, sends her
for consolation to the <qex>loom</qex> and the distaff.</q>
<rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>That part of an oar which is near
the grip or handle and inboard from the rowlock.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loom</ent><br/
<hw>Loom</hw> <pr>(l<oomac/m)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Loomed</conjf> <pr>(l<oomac/md)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Looming</conjf>.]</vmorph> <ety>[OE.
<ets>lumen</ets> to shine, Icel. <ets>ljoma</ets>; akin to AS.
<ets>le<iacute/ma</ets> light, and E. <ets>light</ets>; or cf. OF.
<ets>lumer</ets> to shine, L. <ets>luminare</ets> to illumine,
<ets>lumen</ets> light; akin to E. <ets>light</ets>. <root/122. See
<er>Light</er> not dark.]</ety> <sn>1.</sn> <def>To appear above the
surface either of sea or land, or to appear enlarged, or distorted and
indistinct, as a distant object, a ship at sea, or a mountain, esp. from
atmospheric influences; <as>as, the ship <ex>looms</ex> large; the land
<ex>looms</ex> high.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Awful she <qex>looms</qex>, the terror of the main.</q>
<rj><qau>H. J. Pye.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rise and to be eminent; to be elevated or
ennobled, in a moral sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On no occasion does he [Paul] <qex>loom</qex> so high, and shine
so gloriously, as in the context.</q> <rj><qau>J. M.
Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To become imminent; to impend.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loom</ent><br/
<hw>Loom</hw>, <pos>n.</pos> <def>The state of looming; esp., an
unnatural and indistinct appearance of elevation or enlargement of
anything, as of land or of a ship, seen by one at sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loom-gale</ent><br/
<hw>Loom"-gale`</hw> <pr>(l<oomac/m"g<amac/l)</pr>, <pos>n.</pos> <def>A
gentle gale of wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looming</ent><br/
<hw>Loom"ing</hw>, <pos>n.</pos> <def>The appearance above the horizon
of a distant object that would normally be hidden below it, due to
unusually large atmospheric refraction.  See <er>Mirage</er>.</def><br/
[<source>A.T.Young</source>]</p>

<p><ent>Loon</ent><br/
<hw>Loon</hw> <pr>(l<oomac/n)</pr>, <pos>n.</pos> <ety>[Scot.
<ets>loun</ets>, <ets>lown</ets>, <ets>loon</ets>; akin to OD.
<ets>loen</ets> a stupid man; prob. for an older <ets>lown</ets>, and
akin to E. <ets>lame</ets>.]</ety> <def>A sorry fellow; a worthless
person; a rogue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loon</ent><br/
<hw>Loon</hw>, <pos>n.</pos> <ety>[For older <ets>loom</ets>, Icel.
<ets>l<omac/mr</ets>; akin to Dan. & Sw. <ets>lom</ets>.]</ety>
<fld>(Zool.)</fld> <def>Any one of several aquatic, wed-footed, northern
birds of the genus <gen>Urinator</gen> (formerly <gen>Colymbus</gen>),
noted for their expertness in diving and swimming under water. The
common loon, or great northern diver (<spn>Urinator imber</spn>, or
<spn>Colymbus torquatus</spn>), and the red-throated loon or diver
(<spn>Urinator septentrionalis</spn>), are the best known species. See
<er>Diver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>looney</ent><br/
<hw>looney</hw> <pr>(l<oomac/n"<ycr/)</pr> <pos>n.</pos> <def>someone
deranged and possibly dangerous.</def><br/
<syn><b>Syn. --</b> crazy, loony, weirdo.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loony</ent><br/
<hw>loon"y</hw> <pr>(l<oomac/n"<ycr/)</pr>, <pos>a.</pos>
<ety>[Shortened fr. <ets>lunatic</ets>.]</ety> <sn>1.</sn> <def>Crazy;
insane; lunatic; mentally unsound.</def> <mark>[Low, U.S.]</mark>
<altsp>[Written also <asp>loony</asp>, <asp>luny</asp> and
<asp>looney</asp>.]</altsp> <def>See <er>Luny</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Very foolish; very impractical; <as>as,
<ex>loony</ex> ideas</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>loony</ent><br/
<hw>loony</hw> <pr>(l<oomac/n"<ycr/)</pr> <pos>n.</pos> <def>someone
mentally deranged and possibly dangerous.</def><br/
<syn><b>Syn. --</b> crazy, looney, weirdo, psycho.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loony bin</ent><br/
<hw>loony bin</hw> <pr>(l<oomac/n"<ycr/ b<icr/n)</pr> <pos>n.</pos>
<def>An institution for the confinement or treatment of insane persons,
such as an insane asylum or the psychiatric ward of a hospital.</def>
<mark>[slang]</mark> <br/
<syn><b>Syn. --</b> mental institution.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Loop</ent><br/
<hw>Loop</hw> <pr>(l<oomac/p)</pr>, <pos>n.</pos> <ety>[G.
<ets>luppe</ets> an iron lump. Cf. <er>Looping</er>.]</ety> <fld>(Iron
Works)</fld> <def>A mass of iron in a pasty condition gathered into a
ball for the tilt hammer or rolls.</def> <altsp>[Written also
<asp>loup</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loop</ent><br/
<hw>Loop</hw>, <pos>n.</pos> <ety>[Cf. Ir. & Gael. <ets>lub</ets> loop,
noose, fold, thong, bend, <ets>lub</ets> to bend, incline.]</ety>
<sn>1.</sn> <def>A fold or doubling of a thread, cord, rope, etc.,
through which another thread, cord, etc., can be passed, or which a hook
can be hooked into; an eye, as of metal; a staple; a noose; a
bight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That the probation bear no hinge, nor <qex>loop</qex><br/
To hang a doubt on.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small, narrow opening; a loophole.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And stop all sight-holes, every <qex>loop</qex> from whence<br/
The eye of Reason may pry in upon us.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A curve of any kind in the form of a loop.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Telegraphy)</fld> <def>A wire forming part of a
main circuit and returning to the point from which it starts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Acoustics)</fld> <def>The portion of a vibrating
string, air column, etc., between two nodes; -- called also
<altname>ventral segment</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Loop knot</b></col>, <cd>a single knot tied in a doubled
cord, etc. so as to leave a loop beyond the knot. See <xex>Illust.</xex>
of <er>Knot</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loop</ent><br/
<hw>Loop</hw> <pr>(l<oomac/p)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Looped</conjf> <pr>(l<oomac/pt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Looping</conjf>.]</vmorph> <def>To make a loop of or
in; to fasten with a loop or loops; -- often with <xex>up</xex>; <as>as,
to <ex>loop</ex> a string; to <ex>loop</ex> up a curtain.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looped</ent><br/
<hw>Looped</hw> <pr>(l<oomac/pt)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Bent, folded, or tied, so as to make a loop; <as>as, a
<ex>looped</ex> wire or string</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Full of holes.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looper</ent><br/
<hw>Loop"er</hw> <pr>(l<oomac/p"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>An instrument, as a bodkin, for forming a loop in yarn, a cord,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The larva of any species of
geometrid moths. See <er>Geometrid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loophole</ent><br/
<hw>Loop"hole`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Mil.)</fld> <def>A small opening, as in the walls of
fortification, or in the bulkhead of a ship, through which small arms or
other weapons may be discharged at an enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hole or aperture that gives a passage, or the
means of escape or evasion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An amibiguity or unintended omission in a law, rule,
regulation, or contract which allows a party to circumvent the intent of
the text and avoid its obligations under certain circumstances. -- used
usually in a negative sense; -- distinguished from <contr>escape
clause</contr> in that the latter usually is included to deliberately
allow evasion of obligation under certain specified and foreseen
circumstances; <as>as, a <ex>loophole</ex> in the law big enough to
drive a truck through</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loopholed</ent><br/
<hw>Loop"holed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Provided with
loopholes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loopie</ent><br/
<hw>Loop"ie</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deceitful; cunning;
sly.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looping</ent><br/
<hw>Loop"ing</hw>, <pos>n.</pos> <ety>[Cf. D. <ets>loopen</ets> to run.
Cf. <er>Loop</er> a mass of iron, <er>Leap</er>.]</ety>
<fld>(Metal.)</fld> <def>The running together of the matter of an ore
into a mass, when the ore is only heated for calcination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looping</ent><br/
<hw>Loop"ing</hw>, <pos>p. pr. & vb. n.</pos> <def>of
<er>Loop</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Looping snail</b></col> <fld>(Zool.)</fld>, <cd>any
species of land snail of the genus <gen>Truncatella</gen>; -- so called
because it creeps like the measuring worms.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looplight</ent><br/
<hw>Loop"light`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small narrow
opening or window in a tower or fortified wall; a loophole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>loop-line</ent><br/
<hw>loop-line</hw> <pos>n.</pos> <def>a railway line that branches from
the trunk line and then rejoins it at another point.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loord</ent><br/
<hw>Loord</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>lourd</ets>
heavy, dull.]</ety> <def>A dull, stupid fellow; a drone.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loos</ent><br/
<hw>Loos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>los</ets>, fr.
OF. <ets>los</ets>, <ets>laus</ets>.]</ety> <def>Praise; fame;
reputation.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Good conscience and good <qex>loos</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loose</ent><br/
<hw>Loose</hw> <pr>(l<oomac/s)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Looser</adjf>
<pr>(l<oomac/s"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Loosest</adjf>.]</amorph> <ety>[OE. <ets>loos</ets>,
<ets>lous</ets>, <ets>laus</ets>, Icel. <ets>lauss</ets>; akin to OD.
<ets>loos</ets>, D. los, AS. <ets>le<aacute/s</ets> false, deceitful, G.
<ets>los</ets>, loose, Dan. & Sw. <ets>l<oum/s</ets>, Goth.
<ets>laus</ets>, and E. <ets>lose</ets>. <root/127. See <er>Lose</er>,
and cf. <er>Leasing</er> falsehood.]</ety> <sn>1.</sn> <def>Unbound;
untied; unsewed; not attached, fastened, fixed, or confined; <as>as, the
<ex>loose</ex> sheets of a book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her hair, nor <qex>loose</qex>, nor tied in formal plat.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free from constraint or obligation; not bound by
duty, habit, etc.; -- with <xex>from or of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now I stand<br/
<qex>Loose</qex> of my vow; but who knows Cato's thoughts ?</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not tight or close; <as>as, a <ex>loose</ex>
garment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not dense, close, compact, or crowded; <as>as, a
cloth of <ex>loose</ex> texture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With horse and chariots ranked in <qex>loose</qex> array.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not precise or exact; vague; indeterminate; <as>as,
a <ex>loose</ex> style, or way of reasoning</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The comparison employed . . . must be considered rather as a
<qex>loose</qex> analogy than as an exact scientific explanation.</q>
<rj><qau>Whewel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not strict in matters of morality; not rigid
according to some standard of right.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>loose</qex> morality which he had learned.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Unconnected; rambling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vario spends whole mornings in running over <qex>loose</qex> and
unconnected pages.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Lax; not costive; having lax bowels.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Dissolute; unchaste; <as>as, a <ex>loose</ex> man or
woman</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Loose</qex> ladies in delight.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Containing or consisting of obscene or unchaste
language; <as>as, a <ex>loose</ex> epistle</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At loose ends</b></col>, <cd>not in order; in confusion;
carelessly managed.</cd> -- <col><b>Fast and loose</b></col>. <cd>See
under <er>Fast</er>.</cd> -- <col><b>To break loose</b></col>. <cd>See
under <er>Break</er>.</cd> -- <col><b>Loose pulley</b></col>.
<fld>(Mach.)</fld> <cd>See <cref>Fast and loose pulleys</cref>, under
<er>Fast</er>.</cd> -- <col><b>To let loose</b></col>, <cd>to free from
restraint or confinement; to set at liberty.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loose</ent><br/
<hw>Loose</hw>, <pos>n.</pos> <sn>1.</sn> <def>Freedom from
restraint.</def> <mark>[Obs.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A letting go; discharge.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To give a loose</b></col>, <cd>to give
freedom.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Vent all its griefs, and <qex>give a loose</qex> to sorrow.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loose</ent><br/
<hw>Loose</hw> <pr>(l<oomac/s)</pr>, <pos>v. n.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Loosed</conjf> <pr>(l<oomac/st)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Loosing</conjf>.]</vmorph> <ety>[From
<er>Loose</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To untie or
unbind; to free from any fastening; to remove the shackles or fastenings
of; to set free; to relieve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Canst thou . . . <qex>loose</qex> the bands of Orion ?</q>
<rj><qau>Job. xxxviii. 31.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye shall find an ass tied, and a colt with her; <qex>loose</qex>
them, and bring them unto me.</q> <rj><qau>Matt. xxi. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To release from anything obligatory or burdensome;
to disengage; hence, to absolve; to remit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Art thou <qex>loosed</qex> from a wife ? seek not a wife.</q>
<rj><qau>1 Cor. vii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whatsoever thou shalt <qex>loose</qex> on earth shall be
<qex>loosed</qex> in heaven.</q> <rj><qau>Matt. xvi. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To relax; to loosen; to make less strict.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The joints of his loins were <qex>loosed</qex>.</q> <rj><qau>Dan.
v. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To solve; to interpret.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loose</ent><br/
<hw>Loose</hw>, <pos>v. i.</pos> <def>To set sail.</def>
<mark>[Obs.]</mark> <rj><au>Acts xiii. 13.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loose-fitting</ent><br/
<hw>loose-fitting</hw> <pos>adj.</pos> <def>large enough to leave space
for movement over the skin; not tight-fitting; -- of clothing. Opposite
of <ant>close-fitting</ant>, <ant>tight</ant>, and
<ant>tight-fitting</ant>.</def><br/
<syn><b>Syn. --</b> loose.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>loose-jowled</ent><br/
<hw>loose-jowled</hw> <pos>adj.</pos> <def>having sagging folds of flesh
beneath the chin or lower jaw.</def><br/
<syn><b>Syn. --</b> double-chinned, jowly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loose-leaf</ent><br/
<ent>looseleaf</ent><br/
<mhw><hw>loose"leaf`</hw>, <hw>loose"-leaf`</hw></mhw>
<pr>(l<oomac/s"l<emac/f`)</pr>, <pos>adj.</pos> <def>having rings that
open and close permitting insertion and removal of pages; -- of
notebooks and binders and the paper used in them; <as>as, a
<ex>looseleaf</ex> notebook; <ex>looseleaf</ex> paper</as>.</def><br/
<syn><b>Syn. --</b> loose-leaf.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>looseleaf notebook</ent><br/
<ent>looseleaf binder</ent><br/
<mhw><hw>looseleaf binder</hw>, <hw>looseleaf notebook</hw></mhw>
<pos>n.</pos> <def>A type of notebook with hard covers attached to metal
rings which open, allowing sheets of writing paper to be conveniently
inserted into it and removed from it.</def><br/
[<source>PJC</source>]</p>

<p><ent>looseleaf paper</ent><br/
<hw>looseleaf paper</hw> <pos>n.</pos> <def>Sheets of writing paper
having holes at the edge permitting insertion into and removal from a
looseleaf binder.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loosely</ent><br/
<hw>Loose"ly</hw>, <pos>adv.</pos> <def>In a loose manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loosen</ent><br/
<hw>Loos"en</hw> <pr>(l<oomac/s"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Loosened</conjf>
<pr>(l<oomac/s"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loosening</conjf>.]</vmorph> <ety>[See <er>Loose</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>To make loose; to free from tightness,
tension, firmness, or fixedness; to make less dense or compact; <as>as,
to <ex>loosen</ex> a string, or a knot; to <ex>loosen</ex> a rock in the
earth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>After a year's rooting, then shaking doth the tree good by
<qex>loosening</qex> of the earth.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To free from restraint; to set at
liberty..</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>loosens</qex> his hands, and assists his
understanding.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To remove costiveness from; to facilitate or
increase the alvine discharges of.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loosen</ent><br/
<hw>Loos"en</hw>, <pos>v. i.</pos> <def>To become loose; to become less
tight, firm, or compact.</def> <rj><au>S. Sharp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loosened</ent><br/
<hw>loosened</hw> <pos>adj.</pos> <sn>1.</sn> <def>having constraints
removed.</def><br/
<syn><b>Syn. --</b> freed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>straightened out; untangled.</def><br/
<syn><b>Syn. --</b> disentangled, unsnarled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loosener</ent><br/
<hw>Loos"en*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, loosens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Looseness</ent><br/
<hw>Loose"ness</hw>, <pos>n.</pos> <def>The state, condition, or
quality, of being loose; <as>as, the <ex>looseness</ex> of a cord;
<ex>looseness</ex> of style; <ex>looseness</ex> of morals or of
principles.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loosestrife</ent><br/
<hw>Loose"strife`</hw> <pr>(l<oomac/s"str<imac/f`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>The name of several species of
plants of the genus <gen>Lysimachia</gen>, having small star-shaped
flowers, usually of a yellow color.</def> <sd>(b)</sd> <def>Any species
of the genus <gen>Lythrum</gen>, having purple, or, in some species,
crimson flowers.</def> <au>Gray.</au><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 869 --></p>

<p><cs><col><b>False loosestrife</b></col>, <cd>a plant of the genus
<gen>Ludwigia</gen>, which includes several species, most of which are
found in the United States.</cd> -- <col><b>Tufted
loosestrife</b></col>, <cd>the plant <spn>Lysimachia thyrsiflora</spn>,
found in the northern parts of the United States and in Europe.</cd>
<rj><au>Gray.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loosish</ent><br/
<hw>Loos"ish</hw> <pr>(l<oomac/s"<icr/sh)</pr>, <pos>a.</pos>
<def>Somewhat loose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loot</ent><br/
<hw>Loot</hw> <pr>(l<oomac/t)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>l<umac/<tsdot/</ets>, Skr. <ets>l<omac/tra</ets>,
<ets>l<omac/ptra</ets>, booty, <ets>lup</ets> to break, spoil; prob.
akin to E. <ets>rob</ets>.]</ety> <sn>1.</sn> <def>The act of
plundering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Plunder; booty; especially, the booty taken in a
conquered or sacked city.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>Anything stolen or obtained
by dishonesty.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Broadly:</specif> <def>Valuable objects; <as>as,
the child was delighted with all the <ex>loot</ex> he got for his
birthday</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>Money; <as>as, you shouldn't carry all that
<ex>loot</ex> around with you in the city; she made a pile of
<ex>loot</ex> from trading in cattle futures</as>.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Loot</ent><br/
<hw>Loot</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Looted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Looting</conjf>.]</vmorph> <def>To plunder; to carry off as
plunder or a prize lawfully obtained by war.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Looting</qex> parties . . . ransacking the houses.</q>
<rj><qau>L. Oliphant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>looted</ent><br/
<hw>looted</hw> <pos>adj.</pos> <def>wrongfully emptied or stripped of
anything of value; <as>as, the robbers left the <ex>looted</ex>
train</as>.</def><br/
<syn><b>Syn. --</b> pillaged, plundered, ransacked.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Looter</ent><br/
<hw>Loot"er</hw> <pr>(l<oomac/t"<etil/r)</pr>, <pos>n.</pos> <def>A
plunderer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loover</ent><br/
<hw>Loo"ver</hw> <pr>(l<oomac/"v<etil/r)</pr>, <pos>n.</pos> <def>See
<er>Louver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop</ent><br/
<hw>Lop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>loppe</ets>.]</ety> <def>A flea.</def> <mark>[Obs.]</mark>
<rj><au>Cleveland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop</ent><br/
<hw>Lop</hw> <pr>(l<ocr/p)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lopped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lopping</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Prov. G.
<ets>luppen</ets>, <ets>lubben</ets>, to cut, geld, or OD.
<ets>luppen</ets>, D. <ets>lubben</ets>.]</ety> <sn>1.</sn> <def>To cut
off as the top or extreme part of anything; to shorten by cutting off
the extremities; to cut off, or remove, as superfluous parts; <as>as, to
<ex>lop</ex> a tree or its branches</as>.</def> <ldquo/With branches
<xex>lopped</xex>, in wood or mountain felled.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Expunge the whole, or <qex>lop</qex> the excrescent parts.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut partly off and bend down; <as>as, to
<ex>lop</ex> bushes in a hedge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop</ent><br/
<hw>Lop</hw>, <pos>n.</pos> <def>That which is lopped from anything, as
branches from a tree.</def> <rj><au>Shak. Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop</ent><br/
<hw>Lop</hw>, <pos>v. i.</pos> <def>To hang downward; to be pendent; to
lean to one side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop</ent><br/
<hw>Lop</hw>, <pos>v. t.</pos> <def>To let hang down; <as>as, to
<ex>lop</ex> the head</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop</ent><br/
<hw>Lop</hw>, <pos>a.</pos> <def>Hanging down; <as>as, <ex>lop</ex>
ears</as>; -- used also in compound adjectives; <as>as,
<ex>lop</ex>eared; <ex>lop</ex>sided.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lope</ent><br/
<hw>Lope</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of <er>Leap</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And, laughing, <qex>lope</qex> into a tree.
<qex>Spenser</qex>.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lope</ent><br/
<hw>Lope</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Loped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loping</conjf>.]</vmorph> <ety>[See <er>Leap</er>.]</ety>
<sn>1.</sn> <def>To leap; to dance.</def> <mark>[Prov. Eng.]</mark>
<ldquo/He that <xex>lopes</xex> on the ropes.<rdquo/
<rj><au>Middleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move with a leaping or bounding stride, as a
horse.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To run with an easy, bounding stride; -- of
people.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lope</ent><br/
<hw>Lope</hw>, <pos>n.</pos> <sn>1.</sn> <def>A leap; a long step.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An easy gait, consisting of long running strides or
leaps.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The mustang goes rollicking ahead, with the eternal
<qex>lope</qex>, . . . a mixture of two or three gaits, as easy as the
motions of a cradle.</q> <rj><qau>T. B. Thorpe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lop-eared</ent><br/
<ent>Lopeared</ent><br/
<mhw><hw>Lop"eared`</hw>, <hw>Lop"-eared`</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Having ears which droop or hang down; <as>as, a
<ex>lop-eared</ex> hound</as>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Lopeman</ent><br/
<hw>Lope"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Leaper;
ropedancer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loper</ent><br/
<hw>Lop"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or
that which, lopes; esp., a horse that lopes.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rope Making)</fld> <def>A swivel at one end of a
ropewalk, used in laying the strands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophine</ent><br/
<hw>Loph"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a tuft or
crest of feathers.]</ety> <fld>(Chem.)</fld> <def>A nitrogenous organic
base obtained by the oxidation of amarine, and regarded as a derivative
of benzoic aldehyde. It is obtained in long white crystalline tufts, --
whence its name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophiomys</ent><br/
\'d8<hw>Lo*phi"o*mys</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>lofia`</grk> a mane, bristly ridge + <grk>my^s</grk> a
mouse.]</ety> <fld>(Zool.)</fld> <def>A very singular rodent
(<spn>Lophiomys Imhausi</spn>) of Northeastern Africa. It is the only
known representative of a special family (<fam>Lophiomyid<ae/</fam>),
remarkable for the structure of the skull. It has handlike feet, and the
hair is peculiar in structure and arrangement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophobranch</ent><br/
<hw>Loph"o*branch</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>lofia`</grk> crest or tuft + <grk>bra`gchion</grk> gill.]</ety>
<fld>(Zool.)</fld> <def>Of or pertaining to the
<ord>Lophobranchii</ord>.</def> -- <def2><pos>n.</pos> <def>One of the
<ord>Lophobranchii</ord>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophobranchiate</ent><br/
<hw>Loph`o*bran"chi*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the
<ord>Lophobranchii</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophobranchii</ent><br/
\'d8<hw>Loph`o*bran"chi*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>lo`fos</grk> a crest or tuft +
<grk>bra`gchion</grk> gill.]</ety> <fld>(Zool.)</fld> <def>An order of
teleostean fishes, having the gills arranged in tufts on the branchial
arches, as the Hippocampus and pipefishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophophore</ent><br/
<hw>Loph"o*phore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>lo`fos</grk> a crest or tuft + <grk>fe`rein</grk> to bear.]</ety>
<fld>(Zool.)</fld> <def>A disk which surrounds the mouth and bears the
tentacles of the Bryozoa. See <er>Phylactolemata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophopoda</ent><br/
\'d8<hw>Lo*phop"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <grk>lo`fos</grk> a crest or tuft + <ets>-poda</ets>.]</ety>
<fld>(Zool.)</fld> <def>Same as <er>Phylactolemata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lophosteon</ent><br/
\'d8<hw>Lo*phos"te*on</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Lophostea</plw> <pr>(#)</pr>, E.
<plw>Lophosteons</plw> <pr>(#)</pr>.</plu> <ety>[NL., from Gr.
<grk>lo`fos</grk> a crest + <?/ a bone.]</ety> <fld>(Anat.)</fld>
<def>The central keel-bearing part of the sternum in birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loppard</ent><br/
<hw>Lop"pard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lop</ets> +
<ets>-ard</ets>.]</ety> <def>A tree, the top of which has been lopped
off.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lopper</ent><br/
<hw>Lop"per</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who lops or cuts
off.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lopper</ent><br/
<hw>Lop"per</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Loppered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loppering</conjf>.]</vmorph> <ety>[Cf. Prov. G.
<ets>l<uum/bbern</ets>, <ets>levern</ets>, OHG.
<ets>giliber<omac/n</ets>, G. <ets>luppe</ets>, <ets>lab</ets>,
rennet.]</ety> <def>To turn sour and coagulate from too long standing,
as milk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lopping</ent><br/
<hw>Lop"ping</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cutting off, as of
branches; that which is cut off; leavings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>loppings</qex> made from that stock whilst it stood.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loppy</ent><br/
<hw>Lop"py</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat lop; inclined
to lop.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lopseed</ent><br/
<hw>Lop"seed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
perennial herb (<spn>Phryma Leptostachya</spn>), having slender seedlike
fruits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lopsided</ent><br/
<hw>Lop"sid`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Lop</ets> +
<ets>side.</ets> Cf. <er>Lobsided</er>.]</ety> <sn>1.</sn> <def>Leaning
to one side because of some defect of structure; <as>as, a
<ex>lopsided</ex> ship</as>.</def> <rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unbalanced; poorly proportioned; having much more on
one side than the other; -- also used metaphorically; <as>as, a
<ex>lopsided</ex> victory</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>Full of idiosyncrasies.</def> <rj><au>J. S.
Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lopsided victory</ent><br/
<hw>lop"sid`ed victory</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A victory
in a contest in which one side defeats the other overwhelmingly; -- in
sports, meaning one side scores much more than the other; in war,
meaning one side has many more casualties than the other.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loquacious</ent><br/
<hw>Lo*qua"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>loquax</ets>, <ets>-acis</ets>, talkative, fr. <ets>loqui</ets> to
speak; cf. Gr. <?/ to rattle, shriek, shout.]</ety> <sn>1.</sn>
<def>Given to continual talking; talkative; garrulous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Loquacious</qex>, brawling, ever in the wrong.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Speaking; expressive.</def> <mark>[R.]</mark>
<rj><au>J. Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Apt to blab and disclose secrets.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Garrulous; talkative. See
<er>Garrulous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loquaciously</ent><br/
<hw>Lo*qua"cious*ly</hw>, <pos>adv.</pos> <def>In a loquacious
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loquaciousness</ent><br/
<hw>Lo*qua"cious*ness</hw>, <pos>n.</pos> <def>Loquacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loquacity</ent><br/
<hw>Lo*quac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>loquacitas</ets>: cf. F. <ets>loquacit<eacute/</ets>.]</ety>
<def>The habit or practice of talking continually or excessively;
inclination to talk too much; talkativeness; garrulity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Too great <qex>loquacity</qex> and too great taciturnity by
fits.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loquat</ent><br/
<hw>Lo"quat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chinese name.]</ety>
<fld>(Bot.)</fld> <def>The fruit of the Japanese medlar (<spn>Photinia
Japonica</spn>). It is as large as a small plum, but grows in clusters,
and contains four or five large seeds. Also, the tree itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loral</ent><br/
<hw>Lo"ral</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Of or pertaining to the lores.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to lore{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loran</ent><br/
<hw>Lor"an</hw> <pr>(l<ocir/r"<acr/n <it>or</it> l<omac/r"<acr/n)</pr>,
<pos>n.</pos> <ety>[Acronym, from <ets>LO</ets>ng <ets>RA</ets>nge
<ets>N</ets>avigation]</ety> <fld>(Naut., aviation)</fld> <def>A system
of electronic navigation in which a vessel or aircraft determines its
latitude and longitude by measuring the time differences between low
frequency radio transmissions from two stationary transmitters (slaves)
and a stationary master transmitter. Contrary to the name, Loran is a
medium range system, usually effective for no more than a few hundred
miles from shore. The first commercial system was called Loran A; the
latest (and final) development is Loran C.</def> <mark>[acronym]</mark>
<br/
[<source>RDH</source>]</p>

<p><ent>Lorate</ent><br/
<hw>Lo"rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>loratus</ets>, fr. <ets>lorum</ets> thong.]</ety> <fld>(Bot.)</fld>
<def>Having the form of a thong or strap; ligulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorcha</ent><br/
<hw>Lor"cha</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg.]</ety>
<fld>(Naut.)</fld> <def>A kind of light vessel used on the coast of
China, having the hull built on a European model, and the rigging like
that of a Chinese junk.</def> <rj><au>Admiral Foote.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lord</ent><br/
<hw>Lord</hw> <pr>(l<ocir/rd)</pr>, <pos>n.</pos> <ety>[Cf. Gr. <?/ bent
so as to be convex in front.]</ety> <def>A hump-backed person; -- so
called sportively.</def> <mark>[Eng.]</mark> <rj><au>Richardson
(Dict.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lord</ent><br/
<hw>Lord</hw>, <pos>n.</pos> <ety>[OE. <ets>lord</ets>,
<ets>laverd</ets>, <ets>loverd</ets>, AS. <ets>hl<amac/ford</ets>, for
<ets>hl<amac/fweard</ets>, i. e., bread keeper; <ets>hl<amac/f</ets>
bread, loaf + <ets>weardian</ets> to look after, to take care of, to
ward. See <er>Loaf</er>, and <er>Ward</er> to guard, and cf.
<er>Laird</er>, <er>Lady</er>.]</ety> <sn>1.</sn> <def>One who has power
and authority; a master; a ruler; a governor; a prince; a proprietor, as
of a manor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But now I was the <qex>lord</qex><br/
Of this fair mansion.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Man over men<br/
He made not <qex>lord</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A titled nobleman., whether a peer of the realm or
not; a bishop, as a member of the House of Lords; by courtesy; the son
of a duke or marquis, or the eldest son of an earl; in a restricted
sense, a baron, as opposed to noblemen of higher rank.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A title bestowed on the persons above named; and
also, for honor, on certain official persons; <as>as, <ex>lord</ex>
advocate, <ex>lord</ex> chamberlain, <ex>lord</ex> chancellor,
<ex>lord</ex> chief justice, etc.</as></def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A husband.</def> <ldquo/My <xex>lord</xex> being old
also.<rdquo/ <rj><au>Gen. xviii. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou worthy <qex>lord</qex><br/
Of that unworthy wife that greeteth thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Feudal Law)</fld> <def>One of whom a fee or estate
is held; the male owner of feudal land; <as>as, the <ex>lord</ex> of the
soil; the <ex>lord</ex> of the manor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The Supreme Being; Jehovah.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When <xex>Lord</xex>, in the Old Testament, is printed
in small capitals, it is usually equivalent to <xex>Jehovah</xex>, and
might, with more propriety, be so rendered.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Christianity)</fld> <def>The Savior; Jesus
Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>House of Lords</b></col>, <cd>one of the constituent
parts of the British Parliament, consisting of the lords spiritual and
temporal.</cd> -- <mcol><col><b>Lord high chancellor</b></col>,
<col><b>Lord high constable</b></col></mcol>, <cd>etc. See
<er>Chancellor</er>, <er>Constable</er>, etc.</cd> -- <col><b>Lord
justice clerk</b></col>, <cd>the second in rank of the two highest
judges of the Supreme Court of Scotland.</cd> -- <mcol><col><b>Lord
justice general</b></col>, <it>or</it> <col><b>Lord
president</b></col></mcol>, <cd>the highest in rank of the judges of the
Supreme Court of Scotland.</cd> -- <col><b>Lord keeper</b></col>, <cd>an
ancient officer of the English crown, who had the custody of the king's
great seal, with authority to affix it to public documents. The office
is now merged in that of the chancellor.</cd> -- <col><b>Lord
lieutenant</b></col>, <cd>a representative of British royalty: the
<stype>lord lieutenant of Ireland</stype> being the representative of
royalty there, and exercising supreme administrative authority; the
<stype>lord lieutenant of a county</stype> being a deputy to manage its
military concerns, and also to nominate to the chancellor the justices
of the peace for that county.</cd> -- <col><b>Lord of misrule</b></col>,
<cd>the master of the revels at Christmas in a nobleman's or other great
house.</cd> <au>Eng. Cyc.</au> -- <col><b>Lords spiritual</b></col>,
<cd>the archbishops and bishops who have seats in the House of
Lords.</cd> -- <col><b>Lords temporal</b></col>, <cd>the peers of
England; also, sixteen representative peers of Scotland, and
twenty-eight representatives of the Irish peerage.</cd> -- <col><b>Our
lord</b></col>, <cd>Jesus Christ; the Savior.</cd> -- <col><b>The Lord's
Day</b></col>, <cd>Sunday; the Christian Sabbath, on which the Lord
Jesus rose from the dead.</cd> -- <col><b>The Lord's Prayer</b></col>,
<fld>(Christianity)</fld> <cd>the prayer which Jesus taught his
disciples, also called the <altname>Our Father</altname>.</cd> <au>Matt.
vi. 9-13.</au> -- <col><b>The Lord's Supper</b></col>. <sd>(a)</sd>
<cd>The paschal supper partaken of by Jesus the night before his
crucifixion.</cd> <sd>(b)</sd> <cd>The sacrament of the eucharist; the
holy communion.</cd> -- <col><b>The Lord's Table</b></col>. <sd>(a)</sd>
<cd>The altar or table from which the sacrament is dispensed.</cd>
<sd>(b)</sd> <cd>The sacrament itself.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lord</ent><br/
<hw>Lord</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To invest with the
dignity, power, and privileges of a lord.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rule or preside over as a lord.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lord</ent><br/
<hw>Lord</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lorded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lording</conjf>.]</vmorph> <def>To play the lord; to domineer; to
rule with arbitrary or despotic sway; -- sometimes with
<ptcl>over</ptcl>; and sometimes with <ptcl>it</ptcl> in the manner of a
transitive verb; <as>as, rich students <ex>lording</ex> it over their
classmates</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whiles she <qex>lordeth</qex> in licentious bliss.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I see them <qex>lording</qex> it in London streets.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>lorded</qex> over them whom now they serve.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lording</ent><br/
<hw>Lord"ing</hw>, <pos>n.</pos> <ety>[<ets>Lord</ets> +
<ets>-ing</ets>, 3.]</ety> <sn>1.</sn> <def>The son of a lord; a person
of noble lineage.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little lord; a lordling; a lord, in contempt or
ridicule.</def> <mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the plural, a common ancient mode of address
equivalent to <ldquo/Sirs<rdquo/ or <ldquo/My masters.<rdquo/</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore, <qex>lordings</qex> all, I you beseech.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordkin</ent><br/
<hw>Lord"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little lord.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lordless</ent><br/
<hw>lordless</hw> <pos>adj.</pos> <sn>1.</sn> <def>having no lord or
master; <as>as, the <ldquo/ronin<rdquo/ of Japan were <ex>lordless</ex>
samurai</as>.</def><br/
<syn><b>Syn. --</b> masterless, ungoverned.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Lordlike</ent><br/
<hw>Lord"like`</hw>, <pos>a.</pos> <ety>[2d <ets>lord</ets> +
<ets>like</ets>. Cf. <er>Lordly</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Befitting or like a lord; lordly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Haughty; proud; insolent; arrogant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordliness</ent><br/
<hw>Lord"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Lordly</er>.]</ety> <def>The state or quality of being lordly.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordling</ent><br/
<hw>Lord"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lord</ets> +
<ets>-ling</ets>.]</ety> <def>A little or insignificant lord.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordly</ent><br/
<hw>Lord"ly</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lordlier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Lordliest</adjf>.]</amorph> <ety>[<ets>Lord</ets> +
<ets>-ly</ets>. Cf. <er>Lordlike</er>.]</ety> <sn>1.</sn> <def>Suitable
for a lord; of or pertaining to a lord; resembling a lord; hence, grand;
noble; dignified; honorable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She brought forth butter in a <qex>lordly</qex> dish.</q>
<rj><qau>Judges v. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lordly</qex> sins require <qex>lordly</qex> estates to
support them.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The maidens gathered strength and grace<br/
And presence, <qex>lordlier</qex> than before.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proud; haughty; imperious; insolent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lords are <qex>lordliest</qex> in their wine.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Imperious; haughty; overbearing; tyrannical;
despotic; domineering; arrogant. See <er>Imperious</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordly</ent><br/
<hw>Lord"ly</hw>, <pos>adv.</pos> <def>In a lordly manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordolatry</ent><br/
<hw>Lord*ol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lord</ets>
+ <ets>-olatry</ets>, as in <ets>idolatry</ets>.]</ety> <def>Worship of,
or reverence for, a lord as such.</def> <mark>[Jocose]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But how should it be otherwise in a country where
<qex>lordolatry</qex> is part of our creed?</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordosis</ent><br/
\'d8<hw>Lor*do"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ , fr. <?/ bent so as to be convex in front.]</ety> <fld>(Med.)</fld>
<sd>(a)</sd> <def>A curvature of the spine forwards, usually in the
lumbar region.</def> <sd>(b)</sd> <def>Any abnormal curvature of the
bones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lords and Ladies</ent><br/
<hw>Lords" and La"dies</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Bot.)</fld>
<def>The European wake-robin (<spn>Arum maculatum</spn>), -- those with
purplish spadix the lords, and those with pale spadix the ladies.</def>
<rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lordship</ent><br/
<hw>Lord"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state or condition of being a lord; hence (with <xex>his</xex> or
<xex>your</xex>), a title applied to a lord (except an archbishop or
duke, who is called <xex>Grace</xex>) or a judge (in Great Britain),
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Seigniory; domain; the territory over which a lord
holds jurisdiction; a manor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What lands and <qex>lordships</qex> for their owner know<br/
My quondam barber.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Dominion; power; authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They which are accounted to rule over the Gentiles exercise
<qex>lordship</qex> over them.</q> <rj><qau>Mark x. 42.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lore</ent><br/
<hw>Lore</hw> <pr>(l<omac/r)</pr>, <pos>n.</pos> <ety>[F.
<ets>lore</ets>, L. <ets>lorum</ets> thong.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The space between the eye and bill, in birds, and the
corresponding region in reptiles and fishes.</def> <sd>(b)</sd> <def>The
anterior portion of the cheeks of insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lore</ent><br/
<hw>Lore</hw>, <mark>obs.</mark> <pos>imp. & p. p.</pos> <mord>of
<er>Lose</er>.</mord> <ety>[See <er>Lose</er>.]</ety>
<def>Lost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither of them she found where she them <qex>lore</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lore</ent><br/
<hw>Lore</hw>, <pos>n.</pos> <ety>[OE. <ets>lore</ets>, <ets>lare</ets>,
AS. <ets>l<amac/r</ets>, fr. <ets>l<aemac/ran</ets> to teach; akin to D.
<ets>leer</ets> teaching, doctrine, G. <ets>lehre</ets>, Dan.
<ets>l<ae/re</ets>, Sw. <ets>l<aum/ra</ets>. See <er>Learn</er>, and cf.
<er>Lere</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>That which is or
may be learned or known; the knowledge gained from tradition, books, or
experience; often, the whole body of knowledge possessed by a people or
class of people, or pertaining to a particular subject; <as>as, the
<ex>lore</ex> of the Egyptians; priestly <ex>lore</ex>; legal
<ex>lore</ex>; folk<ex>lore</ex>.</as></def> <ldquo/The <xex>lore</xex>
of war.<rdquo/ <rj><au>Fairfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His fair offspring, nursed in princely <qex>lore</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is taught; hence, instruction; wisdom;
advice; counsel.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If please ye, listen to my <qex>lore</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Workmanship.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loral</ent><br/
<ent>Loreal</ent><br/
<mhw>{ <hw>Lor"e*al</hw> <pr>(?)</pr>, <hw>Lor"al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Of or pertaining to the
lore; -- said of certain feathers of birds, scales of reptiles,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorel</ent><br/
<hw>Lor"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<?/. Cf.
<er>Losel</er>.]</ety> <def>A good for nothing fellow; a vagabond.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loren</ent><br/
<hw>Lor"en</hw> <pr>(?)</pr>, <mark>obs.</mark> <def>strong <pos>p.
p.</pos> of <er>Lose</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loresman</ent><br/
<hw>Lores"man</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lore</ets>
learning + <ets>man</ets>.]</ety> <def>An instructor.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loretto nuns</ent><br/
<ent>Loreto nuns</ent><br/
<mhw>{ <hw>Lo*ret"o nuns</hw> <pr>(?)</pr>, <it>or</it> <hw>Lo*ret"to
nuns</hw> <pr>(?)</pr> }</mhw>. <ety>[From <etsep>Loreto</etsep>, a city
in Italy famous for its Holy House, said to be that in which Jesus
lived, brought by angels from Nazareth.]</ety> <fld>(R. C. Ch.)</fld>
<def>Members of a congregation of nuns founded by <person>Mrs. Mary
Teresa Ball</person>, near Dublin, Ireland, in 1822, and now spread over
Ireland, India, Canada, and the United States. The nuns are called also
<altname>Ladies of Loreto</altname>. They are engaged in teaching
girls.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lorette</ent><br/
\'d8<hw>Lo`rette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>In France, a name for a woman who is supported by her lovers, and
devotes herself to idleness, show, and pleasure; -- so called from the
church of Notre Dame de <etsep>Lorette</etsep>, in Paris, near which
many of them resided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorettine</ent><br/
<hw>Lo`ret*tine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Loreto</ets> in Italy.]</ety> <fld>(R. C. Ch.)</fld> <sd>(a)</sd>
<def>One of an order of nuns founded in 1812 at Loretto, in Kentucky.
The members of the order (called also <membof>Sisters of
Loretto</membof>, or <membof>Friends of Mary at the Foot of the
Cross</membof>) devote themselves to the cause of education and the care
of destitute orphans, their labors being chiefly confined to the western
United States.</def> <sd>(b)</sd> <def>A Loreto nun.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lorgnette</ent><br/
<hw>Lor`gnette"</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[F.]</ety> <def>An
opera glass</def>; <pluf>pl.</pluf> <def>elaborate double
eyeglasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lori</ent><br/
<hw>Lo"ri</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same
as <er>Lory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorica</ent><br/
<hw>Lo*ri"ca</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Loric<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., lit., a corselet of
thongs, fr. <ets>lorum</ets> thong.]</ety> <sn>1.</sn> <fld>(Anc.
Armor)</fld> <def>A cuirass, originally of leather, afterward of plates
of metal or horn sewed on linen or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Lute{1} for protecting vessels
from the fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The protective case or shell of
an infusorian or rotifer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loricata</ent><br/
\'d8<hw>Lor`i*ca"ta</hw> <pr>(l<ocr/r`<icr/*k<amac/"t<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL. See <er>Loricate</er>.]</ety>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A suborder of edentates, covered
with bony plates, including the armadillos.</def> <sd>(b)</sd> <def>The
crocodilia.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 870 --></p>

<p><ent>Loricate</ent><br/
<hw>Lor"i*cate</hw> <pr>(l<ocr/r"<icr/*k<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Loricated</conjf>
<pr>(l<ocr/r"<icr/*k<amac/t`<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Loricating</conjf>
<pr>(l<ocr/r"<icr/*k<amac/`t<icr/ng)</pr>.]</vmorph> <ety>[L.
<ets>loricatus</ets>, p. p. of <ets>loricare</ets> to clothe in mail, to
cover with plastering, fr. <ets>lorica</ets> a leather cuirass, a
plastering, fr. <ets>lorum</ets> thong.]</ety> <def>To cover with some
protecting substance, as with lute{1}, a crust, coating, or
plates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loricate</ent><br/
<hw>Lor"i*cate</hw> <pr>(l<ocr/r"<icr/*k<asl/t)</pr>, <pos>a.</pos>
<ety>[See <er>Loricate</er>, <pos>v.</pos>]</ety> <def>Covered with a
shell or exterior made of plates somewhat like a coat of mail, as in the
armadillo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loricate</ent><br/
<hw>Lor"i*cate</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>An animal
covered with bony scales, as crocodiles among reptiles, and the
pangolins among mammals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorication</ent><br/
<hw>Lor`i*ca"tion</hw> <pr>(l<ocr/r`<icr/*k<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>loricatio</ets>.]</ety> <def>The act of
loricating; the protecting substance put on; a covering of scales or
plates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorikeet</ent><br/
<hw>Lor"i*keet</hw> <pr>(l<ocr/r"<icr/*k<emac/t)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any one numerous species of small brush-tongued
parrots or lories, found mostly in Australia, New Guinea and the
adjacent islands, with some forms in the East Indies. They are arboreal
in their habits and feed largely upon the honey of flowers. They belong
to <gen>Trichoglossus</gen>, <gen>Loriculus</gen>, and several allied
genera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loriner</ent><br/
<ent>Lorimer</ent><br/
<mhw>{ <hw>Lor"i*mer</hw> <pr>(?)</pr>, <hw>Lor"i*ner</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[OF. <ets>lormier</ets>, <ets>loremier</ets>,
fr. LL. <ets>loranum</ets> bridle, L. <ets>lorum</ets> thong, the rein
of a bridle.]</ety> <def>A maker of bits, spurs, and metal mounting for
bridles and saddles; hence, a saddler.</def> <mark>[Obs.]</mark>
<rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loring</ent><br/
<hw>Lor"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 3d
<er>Lore</er>.]</ety> <def>Instructive discourse.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loriot</ent><br/
<hw>Lo"ri*ot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. OF.
<ets>loriou</ets>, for <ets>l'oriol</ets>, <ets>oriol</ets>,
<ets>l'</ets> being the article. The same word as <ets>oriole</ets>. See
<er>Oriole</er>.]</ety> <fld>(Zool.)</fld> <def>The golden oriole of
Europe. See <er>Oriole</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loris</ent><br/
<hw>Lo"ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Loris</ets>, or
<ets>lori</ets>, the indigenous East Indian name.]</ety>
<fld>(Zool.)</fld> <def>Any one of several species of small lemurs of
the genus <gen>Stenops</gen>. They have long, slender limbs and large
eyes, and are arboreal in their habits. The slender loris (<spn>Stenops
gracilis</spn>), of Ceylon, in one of the best known species.</def>
<altsp>[Written also <asp>lori</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lorn</ent><br/
<hw>Lorn</hw> <pr>(l<ocir/rn)</pr>, <pos>a.</pos> <ety>[Strong p. p. of
<er>Lose</er>. See <er>Lose</er>, <er>Forlorn</er>.]</ety> <sn>1.</sn>
<def>Lost; undone; ruined.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou readest, thou art <qex>lorn</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Forsaken; abandoned; solitary; bereft; <as>as, a
lone, <ex>lorn</ex> woman</as>.</def><br/
[<source>1913 Webster</source>]</p>


<p><ent>Lorry</ent><br/
<ent>Lorrie</ent><br/
<mhw>{ <hw>Lor"rie</hw>, <hw>Lor"ry</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Lorries</plw> <pr>(#)</pr>.</plu>
<ety>[Prob. from <ets>lurry</ets> to pull or lug.]</ety> <sn>1.</sn>
<def>A small cart or wagon moving on rails, as those used on the
tramways in mines to carry coal or rubbish; also, a barrow or truck for
shifting baggage, as at railway stations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A motorized wheeled land vehicle, esp. a large one,
with a cab for the driver and a separate rear compartment for
transporting freight; called <altname>truck</altname> in the U. S.</def>
<mark>[Brit.]</mark><br/
<syn><b>Syn. --</b> camion.</syn><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>a large low horse-drawn wagon without sides.</def>
<wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lory</ent><br/
<hw>Lo"ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lories</plw> <pr>(#)</pr>.</plu> <ety>[Hind. & Malay.
<ets>l<umac/r<imac/</ets>, <ets>n<umac/r<imac/</ets>.]</ety>
<fld>(Zool.)</fld> <def>Any one of many species of small parrots of the
family <fam>Trichoglossid<ae/</fam>, generally having the tongue
papillose at the tip, and the mandibles straighter and less toothed than
in common parrots. They are found in the East Indies, Australia, New
Guinea, and the adjacent islands. They feed mostly on soft fruits and on
the honey of flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The lory, or louri, of South Africa is the white-crested
plantain eater or turacou. See <er>Turacou</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Los</ent><br/
<hw>Los</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Praise. See
<er>Loos</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losable</ent><br/
<hw>Los"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Such as can be
lost.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losange</ent><br/
<hw>Los"ange</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lozenge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lose</ent><br/
<hw>Lose</hw> <pr>(l<oomac/z)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Lost</conjf> <pr>(l<ocr/st; 115)</pr> <pos>p. pr. &
vb. n.</pos> <conjf>Losing</conjf>
<pr>(l<oomac/z"<icr/ng)</pr>.]</vmorph> <ety>[OE. <ets>losien</ets> to
loose, be lost, lose, AS. <ets>losian</ets> to become loose; akin to OE.
<ets>leosen</ets> to lose, p. p. <ets>loren</ets>, <ets>lorn</ets>, AS.
<ets>le<iacute/san</ets>, <ets>p. p. loren</ets> (in comp.), D.
ver<ets>liezen</ets>, G. ver<ets>lieren</ets>, Dan. for<ets>lise</ets>,
Sw. f<oum/r<ets>lisa</ets>, f<oum/r<ets>lora</ets>, Goth.
fra<ets>liusan</ets>, also to E. <ets>loose</ets>, a & v., L.
<ets>luere</ets> to loose, Gr. <grk>ly`ein</grk>, Skr.
<ets>l<umac/</ets> to cut. <root/127. Cf. <er>Analysis</er>,
<er>Palsy</er>, <er>Solve</er>, <er>Forlorn</er>, <er>Leasing</er>,
<er>Loose</er>, <er>Loss</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To part with unintentionally or unwillingly, as by
accident, misfortune, negligence, penalty, forfeit, etc.; to be deprived
of; <as>as, to <ex>lose</ex> money from one's purse or pocket, or in
business or gaming; to <ex>lose</ex> an arm or a leg by amputation; to
<ex>lose</ex> men in battle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair Venus wept the sad disaster<br/
Of having <qex>lost</qex> her favorite dove.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cease to have; to possess no longer; to suffer
diminution of; <as>as, to <ex>lose</ex> one's relish for anything; to
<ex>lose</ex> one's health.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the salt hath <qex>lost</qex> his savor, wherewith shall it be
salted?</q> <rj><qau>Matt. v. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not to employ; to employ ineffectually; to throw
away; to waste; to squander; <as>as, to <ex>lose</ex> a day; to
<ex>lose</ex> the benefits of instruction.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The unhappy have but hours, and these they <qex>lose</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To wander from; to miss, so as not to be able to
and; to go astray from; <as>as, to <ex>lose</ex> one's
way</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath <qex>lost</qex> his fellows.</q>
<rj><qau>Shak</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To ruin; to destroy; as destroy; <as>as, the ship
was <ex>lost</ex> on the ledge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The woman that deliberates is <qex>lost</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To be deprived of the view of; to cease to see or
know the whereabouts of; <as>as, he <ex>lost</ex> his companion in the
crowd</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like following life thro' creatures you dissect,<br/
You <qex>lose</qex> it in the moment you detect.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To fail to obtain or enjoy; to fail to gain or win;
hence, to fail to catch with the mind or senses; to miss; <as>as, I
<ex>lost</ex> a part of what he said</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall in no wise <qex>lose</qex> his reward.</q> <rj><qau>Matt.
x. 42.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I fought the battle bravely which I <qex>lost</qex>,<br/
And <qex>lost</qex> it but to Macedonians.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To cause to part with; to deprive of.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How should you go about to <qex>lose</qex> him a wife he loves
with so much passion?</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To prevent from gaining or obtaining.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O false heart! thou hadst almost betrayed me to eternal flames,
and <qex>lost</qex> me this glory.</q> <rj><qau>Baxter.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To lose ground</b></col>, <cd>to fall behind; to suffer
gradual loss or disadvantage.</cd> -- <col><b>To lose heart</b></col>,
<cd>to lose courage; to become timid.</cd> <ldquo/The mutineers
<xex>lost heart</xex>.<rdquo/ <au>Macaulay.</au> -- <col><b>To lose
one's head</b></col>, <cd>to be thrown off one's balance; to lose the
use of one's good sense or judgment, through fear, anger, or other
emotion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>In the excitement of such a discovery, many scholars <qex>lost
their heads</qex>.</q> <rj><qau>Whitney.</qau></rj></p>

<p>-- <col><b>To lose one's self</b></col>. <sd>(a)</sd> <cd>To forget
or mistake the bearing of surrounding objects; <as>as, <ex>to lose one's
self</ex> in a great city</as>.</cd> <sd>(b)</sd> <cd>To have the
perceptive and rational power temporarily suspended; <as>as, we <ex>lose
ourselves</ex> in sleep</as>.</cd> -- <col><b>To lose sight
of</b></col>. <sd>(a)</sd> <cd>To cease to see; <as>as, <ex>to lose
sight of</ex> the land</as>.</cd> <sd>(b)</sd> <cd>To overlook; to
forget; to fail to perceive; <as>as, he <ex>lost sight of</ex> the
issue</as>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lose</ent><br/
<hw>Lose</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To suffer loss,
disadvantage, or defeat; to be worse off, esp. as the result of any kind
of contest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We 'll . . . hear poor rogues<br/
Talk of court news; and we'll talk with them too,<br/
Who <qex>loses</qex> and who wins; who's in, who's out.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losel</ent><br/
<hw>Los"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the root of
<ets>lose</ets>, <ets>loss</ets>. <root/127. Cf. <er>Lorel</er>.]</ety>
<def>One who loses by sloth or neglect; a worthless person; a
lorel.</def> <mark>[Archaic]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One sad <qex>losel</qex> soils a name for aye.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losel</ent><br/
<hw>Los"el</hw>, <pos>a.</pos> <def>Wasteful; slothful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losenger</ent><br/
<hw>Los"en*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>losengier</ets>, <ets>losengeor</ets>, fr. <ets>losengier</ets> to
deceive, flatter, <ets>losenge</ets>, flattery, Pr. <ets>lauzenga</ets>,
fr. L. <ets>laus</ets> praise. Cf. <er>Lozenge</er>.]</ety> <def>A
flatterer; a deceiver; a cozener.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To a fair pair of gallows, there to end their lives with shame, as
a number of such other <qex>losengers</qex> had done.</q>
<rj><qau>Holinshed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losengerie</ent><br/
<hw>Los"en*ger*ie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.]</ety>
<def>Flattery; deceit; trickery.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loser</ent><br/
<hw>Los"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
loses; <as>as, the <ex>loser</ex> pays for a round of beer</as>.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who is habitually unsuccessful at some
endeavor, such as employment or personal relationships.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A plan or strategy unlikely to succeed.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Losing</ent><br/
<hw>Lo"sing</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Losenger</er>.]</ety> <def>Given to flattery or deceit; flattering;
cozening.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Amongst the many simoniacal that swarmed in the land, Herbert,
Bishop of Thetford, must not be forgotten; nick-named <qex>Losing</qex>,
that is, the Flatterer.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losing</ent><br/
<hw>Los"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Lose</er>,
<pos>v. t.</pos>]</ety> <def>Causing or likely to cause a loss; <as>as,
a <ex>losing</ex> game or business; a <ex>losing</ex>
strategy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who strive to sit out <qex>losing</qex> hands are lost.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Losingly</ent><br/
<hw>Los"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a manner to
incur loss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>losings</ent><br/
<hw>losings</hw> <pos>n.</pos> <def>something lost, especially money
lost at gambling. Inverse of <inv>winnings</inv>.</def><br/
<syn><b>Syn. --</b> losses.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loss</ent><br/
<hw>Loss</hw> <pr>(l<ocr/s; 115)</pr>, <pos>n.</pos> <ety>[AS.
<ets>los</ets> loss, losing, fr. <ets>le<iacute/san</ets> to lose.
<root/127. See <er>Lose</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<def>The act of losing; failure; destruction; privation; <as>as, the
<ex>loss</ex> of property; <ex>loss</ex> of money by gaming;
<ex>loss</ex> of health or reputation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Assured <qex>loss</qex> before the match be played.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of losing or having lost; the privation,
defect, misfortune, harm, etc., which ensues from losing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though thou repent, yet I have still the <qex>loss</qex>.</q>
<rj><qau>Shak</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is lost or from which one has parted;
waste; -- opposed to <ant>gain</ant> or <ant>increase</ant>; <as>as, the
<ex>loss</ex> of liquor by leakage was considerable</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state of being lost or destroyed; especially,
the wreck or foundering of a ship or other vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Failure to gain or win; <as>as, <ex>loss</ex> of a
race or battle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Failure to use advantageously; <as>as, <ex>loss</ex>
of time</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mil.)</fld> <def>Killed, wounded, and captured
persons, or captured property.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Insurance)</fld> <def>Destruction or diminution of
value, if brought about in a manner provided for in the insurance
contract (as destruction by fire or wreck, damage by water or smoke), or
the death or injury of an insured person; also, the sum paid or payable
therefor; <as>as, the <ex>losses</ex> of the company this year amount to
a million of dollars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To bear a loss</b></col>, <cd>to make a loss good; also,
to sustain a loss without sinking under it.</cd> -- <col><b>To be at a
loss</b></col>, <cd>to be in a state of uncertainty.</cd></cs></p>

<p><syn><b>Syn.</b> -- Privation; detriment; injury; damage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>losses</ent><br/
<hw>losses</hw> <pos>n.</pos> <def>something lost, especially money lost
at gambling. Inverse of <inv>winnings</inv>.</def><br/
<syn><b>Syn. --</b> losings.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lossful</ent><br/
<hw>Loss"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Detrimental.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loss leader</ent><br/
<hw>loss leader</hw> <pos>n.</pos> <def>an article of merchandise sold
at a loss in order to draw customers.</def><br/
<syn><b>Syn. --</b> drawing card, loss leader, leader.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lossless</ent><br/
<hw>Loss"less</hw>, <pos>a.</pos> <def>Free from loss.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lossy compression</ent><br/
<hw>los"sy com*pres"sion</hw>, <pos>n.</pos> <fld>(Computers)</fld>
<def>The compression of binary data into a form which, when it is
re-expanded, has most, but not all, of the original information. It is
used primarily for compression of images and sounds, and is designed to
provide a high degree of compression at the cost of a slight loss of
data. It is expemplified by the JPEG compression standard. Images
compressed by a lossy compression algorithm are re-expanded into an
image close, but not identical to the original image; the difference
between the original and the reconstructed image may be imperceptible to
normal viewing by the eye.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lost</ent><br/
<hw>Lost</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prop. p. p. of OE.
<ets>losien</ets>. See <er>Lose</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>Parted with unwillingly or unintentionally; not to be
found; missing; <as>as, a <ex>lost</ex> book or sheep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Parted with; no longer held or possessed; <as>as, a
<ex>lost</ex> limb; <ex>lost</ex> honor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not employed or enjoyed; thrown away; employed
ineffectually; wasted; squandered; <as>as, a <ex>lost</ex> day; a
<ex>lost</ex> opportunity or benefit.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having wandered from, or unable to find, the way;
bewildered; perplexed; <as>as, a child <ex>lost</ex> in the woods; a
stranger <ex>lost</ex> in London.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Ruined or destroyed, either physically or morally;
past help or hope; <as>as, a ship <ex>lost</ex> at sea; a woman
<ex>lost</ex> to virtue; a <ex>lost</ex> soul.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Hardened beyond sensibility or recovery; alienated;
insensible; <as>as, <ex>lost</ex> to shame; <ex>lost</ex> to all sense
of honor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Not perceptible to the senses; no longer visible;
<as>as, an island <ex>lost</ex> in a fog; a person <ex>lost</ex> in a
crowd.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Occupied with, or under the influence of, something,
so as to be insensible of external things; <as>as, to be <ex>lost</ex>
in thought</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lost motion</b></col> <fld>(Mach.)</fld>, <cd>the
difference between the motion of a driver and that of a follower, due to
the yielding of parts or looseness of joints.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lot</ent><br/
<hw>Lot</hw> <pr>(l<ocr/t)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hlot</ets>; akin to <ets>hle<iacute/tan</ets> to cast lots, OS.
<ets>hl<omac/t</ets> lot, D. <ets>lot</ets>, G. <ets>loos</ets>, OHG.
<ets>l<omac/z</ets>, Icel. <ets>hlutr</ets>, Sw. <ets>lott</ets>, Dan.
<ets>lod</ets>, Goth. <ets>hlauts</ets>. Cf. <er>Allot</er>,
<er>Lotto</er>, <er>Lottery</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>That which happens without human design or
forethought; chance; accident; hazard; fortune; fate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But save my life, which <qex>lot</qex> before your foot doth
lay.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything (as a die, pebble, ball, or slip of paper)
used in determining a question by chance, or without man's choice or
will; <as>as, to cast or draw <ex>lots</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lot</qex> is cast into the lap, but the whole disposing
thereof is of the Lord.</q> <rj><qau>Prov. xvi. 33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If we draw <qex>lots</qex>, he speeds.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The part, or fate, which falls to one, as it were,
by chance, or without his planning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O visions ill foreseen! Each day's <qex>lot's</qex><br/
Enough to bear.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was but born to try<br/
The <qex>lot</qex> of man -- to suffer and to die.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A separate portion; a number of things taken
collectively; all objects sold in a single purchase transaction; <as>as,
a <ex>lot</ex> of stationery</as>; -- colloquially, sometimes of people;
<as>as, a sorry <ex>lot</ex>; a bad <ex>lot</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I, this winter, met with a very large <qex>lot</qex> of English
heads, chiefly of the reign of James I.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A distinct portion or plot of land, usually smaller
than a field; <as>as, a building <ex>lot</ex> in a city</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The defendants leased a house and <qex>lot</qex> in the city of
New York.</q> <rj><qau>Kent.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A large quantity or number; a great deal; <as>as, to
spend a <ex>lot</ex> of money; to waste a <ex>lot</ex> of time on line;
<ex>lots</ex> of people think so.</as></def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He wrote to her . . . he might be detained in London by a
<qex>lot</qex> of business.</q> <rj><qau>W. Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A prize in a lottery.</def> <mark>[Obs.]</mark>
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To cast in one's lot with</b></col>, <cd>to share the
fortunes of.</cd> -- <col><b>To cast lots</b></col>, <cd>to use or throw
a die, or some other instrument, by the unforeseen turn or position of
which, an event is by previous agreement determined.</cd> -- <col><b>To
draw lots</b></col>, <cd>to determine an event, or make a decision, by
drawing one thing from a number whose marks are concealed from the
drawer.</cd> -- <col><b>To pay scot and lot</b></col>, <cd>to pay taxes
according to one's ability. See <er>Scot</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lot</ent><br/
<hw>Lot</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lotted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lotting</conjf> <pr>(?)</pr>.]</vmorph> <def>To allot; to sort;
to portion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To lot on</b></col> <it>or</it> <col><b>To lot
upon</b></col></mcol>, <cd>to count or reckon upon; to expect with
pleasure.</cd> <mark>[Colloq. U. S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lote</ent><br/
<hw>Lote</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lotus</ets>, Gr.
<?/. Cf. <er>Lotus</er>.]</ety> <fld>(Bot.)</fld> <def>A large tree
(<spn>Celtis australis</spn>), found in the south of Europe. It has a
hard wood, and bears a cherrylike fruit. Called also <altname>nettle
tree</altname>.</def> <rj><au>Eng. Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lote</ent><br/
<hw>Lote</hw>, <pos>n.</pos> <ety>[F. <ets>lotte</ets>.]</ety>
<fld>(Zool.)</fld> <def>The European burbot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lote</ent><br/
<hw>Lote</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>lutian</ets>.]</ety> <def>To lurk; to lie hid.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lothsome</ent><br/
<ent>Lothly</ent><br/
<ent>Loth</ent><br/
<mhw><hw>Loth</hw> <pr>(?)</pr>, <pos>a.</pos>, <hw>Loth"ly</hw>,
<pos>a. & adv.</pos>, <hw>Loth"some</hw> <pr>(<?/)</pr>,
<pos>a.</pos></mhw>, <def>See <er>Loath</er>, <er>Loathly</er>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>loth</ent><br/
<hw>loth</hw> <pos>adj.</pos> <def>strongly opposed.</def>
<wns>[wns=2]</wns><mark>[predicate]</mark><br/
<syn><b>Syn. --</b> antipathetic, antipathetical, averse(predicate),
averse to(predicate), indisposed(predicate), loath(predicate),
opposed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lothario</ent><br/
<hw>Lo*tha"ri*o</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Name of a
character in Rowe's drama, <ldquo/The Fair Penitent.<rdquo/]</ety>
<def>A gay seducer of women; a libertine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lothringen</ent><br/
<hw>Lothringen</hw> <pos>prop. n.</pos> <def>Lorraine, a French region
rich in iron-ore deposits.</def><br/
<syn><b>Syn. --</b> Lorraine.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lotion</ent><br/
<hw>Lo"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lotio</ets>,
fr. <ets>lavare</ets>, <ets>lotum</ets>, to wash: cf. F.
<ets>lotion</ets>. See <er>Lave</er> to wash.]</ety> <sn>1.</sn> <def>A
washing, especially of the skin for the purpose of rendering it
fair.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A liquid preparation for bathing the skin, or an
injured or diseased part, either for a medicinal purpose, or for
improving its appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loto</ent><br/
<hw>Lo"to</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lotto</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lotong</ent><br/
\'d8<hw>Lo*tong"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Malay
<ets>l<umac/tong</ets>.]</ety> <fld>(Zool.)</fld> <def>An East Indian
monkey (<spn>Semnopithecus femoralis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lotophagi</ent><br/
\'d8<hw>Lo*toph"a*gi</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., fr.
Gr. <?/; <?/ the lotus + <?/ to eat.]</ety> <fld>(Class. Myth.)</fld>
<def>A people visited by Ulysses in his wanderings. They subsisted on
the lotus. See <er>Lotus</er> <sd>(b)</sd>, and
<er>Lotus-eater</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lotos</ent><br/
<hw>Lo"tos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Bot.)</fld> <def>See <er>Lotus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lottery</ent><br/
<hw>Lot"ter*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lotteries</plw> <pr>(#)</pr>.</plu> <ety>[<ets>Lot</ets> +
<ets>-ery</ets>, as in brewe<ets>ry</ets>, bind<ets>ery</ets>.]</ety>
<sn>1.</sn> <def>A scheme for the distribution of prizes by lot or
chance; esp., a gaming scheme in which one or more tickets bearing
particular numbers draw prizes, and the rest of the tickets are
blanks.</def> <mark>Fig.</mark>: <def>An affair of chance.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The laws of the United States and of most of the States
make private lotteries illegal, except in certain circumstances for
charitable institutions; however, many of the states now conduct
lotteries tehmselves as a revenue source.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Allotment; thing allotted.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lotto</ent><br/
<hw>Lot"to</hw> <pr>(l<ocr/t"t<osl/)</pr>, <pos>n.</pos> <ety>[F.
<ets>loto</ets> or It. <ets>lotto</ets>, prop., a lot; of German origin.
See <er>Lot</er>.]</ety> <def>A game of chance, played with cards or
tickets, on which are inscribed numbers, and any contrivance (as a wheel
containing numbered balls) for determining a set of numbers by chance.
The player holding a card having on it the set of numbers drawn from the
wheel takes the stakes after a certain percentage of them has been
deducted for the dealer. In some systems, lesser prizes are awarded for
having some but not all of the numbers selected, such as four or five
numbers in a six-number drawing. A variety of <ex>lotto</ex> is called
<stype>keno</stype>. In another variety, the player chooses the numbers
for the card or ticket s/he holds. There may be from three to seven
different numbers on a card or ticket. In a modern computerized lotto
system conducted by state authorities, the player chooses numbers, or
allows the computer to choose numbers at random, which are then printed
on a ticket that the player holds until the winning number is
selected.</def> <altsp>[Often written <asp>loto</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Loture</ent><br/
<hw>Lo"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lotura</ets>.
See <er>Lotion</er>.]</ety> <def>See <er>Lotion</er>.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lotus</ent><br/
<hw>Lo"tus</hw> <pr>(l<omac/"t<ucr/s)</pr>, <pos>n.</pos> <ety>[L.
<ets>lotus</ets>, Gr. <grk>lwto`s</grk>. Cf. <er>Lote</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>A name of several kinds
of water lilies; as <spn>Nelumbium speciosum</spn>, used in religious
ceremonies, anciently in Egypt, and to this day in Asia; <spn>Nelumbium
luteum</spn>, the American lotus; and <spn>Nymph<ae/a Lotus</spn> and
<spn>Nymph<ae/a c<ae/rulea</spn>, the respectively white-flowered and
blue-flowered lotus of modern Egypt, which, with <spn>Nelumbium
speciosum</spn>, are figured on its ancient monuments.</def>
<sd>(b)</sd> <def>The <xex>lotus</xex> of the <xex>lotuseaters</xex>,
probably a tree found in Northern Africa, Sicily, Portugal, and Spain
(<spn>Zizyphus Lotus</spn>), the fruit of which is mildly sweet. It was
fabled by the ancients to make strangers who ate of it forget their
native country, or lose all desire to return to it.</def> <sd>(c)</sd>
<def>The lote, or nettle tree. See <er>Lote</er>.</def> <sd>(d)</sd>
<def>A genus (<gen>Lotus</gen>) of leguminous plants much resembling
clover.</def> <altsp>[Written also <asp>lotos</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>European lotus</b></col>, <cd>a small tree
(<spn>Diospyros Lotus</spn>) of Southern Europe and Asia; also, its
rather large bluish black berry, which is called also the <altname>date
plum</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 871 --></p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>An ornament much used in Egyptian
architecture, generally asserted to have been suggested by the Egyptian
water lily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lotos-eater</ent><br/
<ent>Lotus-eater</ent><br/
<mhw>{ <hw>Lo"tus-eat`er</hw>
<pr>(l<omac/"t<ucr/s-<emac/t`<etil/r)</pr>, <hw>Lo"tos-eat`er</hw>
<pr>(l<omac/"t<ocr/s-<emac/t`<etil/r)</pr>, }</mhw> <pos>n.</pos>
<fld>(Class. Myth.)</fld> <def>One who ate the fruit or leaf of the
lotus, and, as a consequence, gave himself up to indolence and
daydreams; one of the <membof>Lotophagi</membof>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mild-eyed melancholy <qex>Lotos-eaters</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>louche</ent><br/
<hw>louche</hw> <pos>adj.</pos> <def>of questionable taste, decency, or
morality; not reputable; <as>as, a <ex>louche</ex> nightclub; a
<ex>louche</ex> painting</as>.</def><br/
<syn><b>Syn. --</b> shady.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Louchettes</ent><br/
\'d8<hw>Lou*chettes"</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[F.]</ety> <def>Goggles intended to rectify strabismus by
permitting vision only directly in front.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loud</ent><br/
<hw>Loud</hw> <pr>(loud)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Louder</adjf> <pr>(loud"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Loudest</adjf>.]</amorph> <ety>[OE. <ets>loud</ets>,
<ets>lud</ets>, AS. <ets>hl<umac/d</ets>; akin to OS.
<ets>hl<umac/d</ets>, D. <ets>luid</ets>, OHG. <ets>l<umac/t</ets>, G.
<ets>laut</ets>, L. <ets>-clutus</ets>, in in<ets>clutus</ets>,
in<ets>clitus</ets>, celebrated, renowned, <ets>cluere</ets> to be
called, Gr. <grk>klyto`s</grk> heard, loud, famous, <grk>kly`ein</grk>
to hear, Skr. <ets><cced/ru</ets>. <root/41. Cf. <er>Client</er>,
<er>Listen</er>, <er>Slave</er> a serf.]</ety> <sn>1.</sn> <def>Having,
making, or being a strong or great sound; noisy; striking the ear with
great force; <as>as, a <ex>loud</ex> cry; <ex>loud</ex>
thunder.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>They were instant with <qex>loud</qex> voices, requiring that he
might be crucified.</q> <rj><qau>Luke xxiii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Clamorous; boisterous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She is <qex>loud</qex> and stubborn.</q> <rj><qau>Prov. vii.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Emphatic; impressive; urgent; <as>as, a
<ex>loud</ex> call for united effort</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Ostentatious; likely to attract attention; gaudy;
<as>as, a <ex>loud</ex> style of dress; <ex>loud</ex> colors.</as></def>
<mark>[Slang]</mark></p>

<p><syn><b>Syn.</b> -- Noisy; boisterous; vociferous; clamorous;
obstreperous; turbulent; blustering; vehement.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loud</ent><br/
<hw>Loud</hw>, <pos>adv.</pos> <ety>[AS. <ets>hl<umac/de</ets>.]</ety>
<def>With loudness; loudly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To speak <qex>loud</qex> in public assemblies.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loudful</ent><br/
<hw>Loud"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Noisy.</def>
<mark>[Obs.]</mark> <rj><au>Marsion.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loudly</ent><br/
<hw>Loud"ly</hw>, <pos>adv.</pos> <def>In a loud manner.</def>
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>loud-mouth</ent><br/
<hw>loud-mouth</hw> <pos>n.</pos> <sn>1.</sn> <def>a person who causes
trouble by speaking indiscretely.</def> <wns>[wns=1]</wns> <br/
<syn><b>Syn. --</b> loudmouth, blusterer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Aperson who is loud-mouthed.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loud-mouthed</ent><br/
<hw>Loud"-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a loud
voice; talking or sounding noisily; noisily impudent or
offensive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loudness</ent><br/
<hw>Loud"ness</hw>, <pos>n.</pos> <def>The quality or state of being
loud.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>loudspeaker</ent><br/
<hw>loud"speak*er</hw> <pos>n.</pos> <def>A device which converts
electrical signals into sounds loud enough to be heard at a distance,
usually outdoors; it is used to amplify or transmit over a distance
speech from a person, who is typically speaking into a microphone.
Sometimes it is used to play recorded speech or music.</def><br/
<syn><b>Syn. --</b> speaker, speaker unit, loudspeaker system, speaker
system.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loud-voiced</ent><br/
<hw>Loud"-voiced`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a loud
voice; speaking with a loud voice; noisy; clamorous.</def>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lough</ent><br/
<hw>Lough</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Loch</er>.]</ety> <def>A loch or lake; -- so spelt in
Ireland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lough</ent><br/
<hw>Lough</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>strong imp.</pos>
<def>of <er>Laugh</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louis d'or</ent><br/
<hw>Lou"is d'or`</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[F., gold
louis.]</ety> <def>Formerly, a gold coin of France nominally worth
twenty shillings sterling, but of varying value; -- first struck in
1640.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louisianian</ent><br/
<ent>Louisianan</ent><br/
<mhw><hw>Louisianan</hw>, <hw>Louisianian</hw></mhw> <pos>prop. n.</pos>
<def>a resident of Louisiana.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Louis quatorze</ent><br/
<hw>Lou"is qua*torze"</hw> <pr>(l<oomac/"<icr/ k<adot/*t<ocir/rz")</pr>
<pos>n.</pos> <ety>[F., Louis fourteenth.]</ety> <def>Of, pertaining to,
or resembling, the art or style of the times of <person>Louis
XIV.</person> of France; <as>as, <ex>Louis quatorze</ex>
architecture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louk</ent><br/
<hw>Louk</hw> <pr>(louk)</pr>, <pos>n.</pos> <def>An accomplice; a
<ldquo/pal.<rdquo/</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no thief without a <qex>louk</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lounge</ent><br/
<hw>Lounge</hw> <pr>(lounj)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lounged</conjf> <pr>(lounjd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lounging</conjf> <pr>(loun"j<icr/ng)</pr>.]</vmorph>
<ety>[OE. <ets>lungis</ets> a tall, slow, awkward fellow, OF.
<ets>longis</ets>, <ets>longin</ets>, said to be fr.
<ets>Longinus</ets>, the name of the centurion who pierced the body of
Christ, but with reference also to L. <ets>longus</ets> long. Cf.
<er>Long</er>, <pos>a.</pos>]</ety> <def>To spend time lazily, whether
lolling or idly sauntering; to pass time indolently; to stand, sit, or
recline, in an indolent manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>lounge</qex> over the sciences, dawdle through literature,
yawn over politics.</q> <rj><qau>J. Hannay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lounge</ent><br/
<hw>Lounge</hw>, <pos>n.</pos> <sn>1.</sn> <def>An idle gait or stroll;
the state of reclining indolently; a place of lounging.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She went with Lady Stock to a bookseller's whose shop served as a
fashionable <qex>lounge</qex>.</q> <rj><qau>Miss
Edgeworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of furniture resembling a sofa, upon which
one may lie or recline.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lounger</ent><br/
<hw>Loun"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who lounges; an
idler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loup</ent><br/
<hw>Loup</hw> <pr>(l<oomac/p)</pr>, <pos>n.</pos> <fld>(Iron
Works)</fld> <def>See 1st <er>Loop</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loup-cervier</ent><br/
\'d8<hw>Loup"-cer`vier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Cf.
<er>Lusern</er>.]</ety> <fld>(Zool.)</fld> <def>The Canada lynx. See
<er>Lynx</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>loupe</ent><br/
<hw>loupe</hw> <pr>(l<oomac/p)</pr>, <pos>n.</pos> <def>Any of a variety
of small magnifying glasses, having a magnifying power from 2X to 20X,
commonly of 10X, which may be held in the hand, or in some cases held
within the eyesocket without the use of a hand. It is commonly used by
jewelers and watchmakers.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loup-garou</ent><br/
\'d8<hw>Loup`-ga`rou"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Loups-garous</plw> <pr>(#)</pr></plu>. <ety>[F., fr.
<ets>loup</ets> wolf + a Teutonic word akin to E.
<ets>werewolf</ets>.]</ety> <def>A werewolf; a lycanthrope.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The superstition of the <qex>loup-garou</qex>, or werewolf,
belongs to the folklore of most modern nations, and has its reflex in
the story of <ldquo/Little Red Riding-hood<rdquo/ and others.</q>
<rj><qau>Brinton.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Louping</ent><br/
<hw>Loup"ing</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[From <er>Loup</er> to
leap.]</ety> <fld>(Veter.)</fld> <def>An enzo<oum/tic, often fatal,
disease of sheep and other domestic animals, of unknown cause. It is
characterized by muscular tremors and spasms, followed by more or less
complete paralysis. The principal lesion is an inflammation of the
membranes covering the brain and spinal cord.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Loup-loup</ent><br/
\'d8<hw>Loup`-loup"</hw> <pr>(l<oomac/`l<oomac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <fld>(Zool.)</fld> <def>The Pomeranian or Spitz
dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loups</ent><br/
<hw>Loups</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Loup</singw>.</sing> <ety>[F., prop., a wolf.]</ety>
<fld>(Ethnol.)</fld> <def>The Pawnees, a tribe of North American Indians
whose principal totem was the wolf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lour</ent><br/
\'d8<hw>Lour</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name.]</ety>
<fld>(Zool.)</fld> <def>An Asiatic sardine (<spn>Clupea Neohowii</spn>),
valued for its oil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louri</ent><br/
<hw>Lou"ri</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Lory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louse</ent><br/
<hw>Louse</hw> <pr>(lous)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lice</plw> <pr>(l<imac/s)</pr>.</plu> <ety>[OE. <ets>lous</ets>,
AS. <ets>l<umac/s</ets>, pl. <ets>l<ymac/s</ets>; akin to D.
<ets>luis</ets>, G. <ets>laus</ets>, OHG. <ets>l<umac/s</ets>, Icel.
<ets>l<umac/s</ets>, Sw. <ets>lus</ets>, Dan. <ets>luus</ets>; perh. so
named because it is destructive, and akin to E. <ets>lose</ets>,
<ets>loose</ets>.]</ety> <fld>(Zool.)</fld> <sn>1.</sn> <def>Any one of
numerous species of small, wingless, suctorial, parasitic insects
belonging to a tribe (<fam>Pediculina</fam>), now usually regarded as
degraded Hemiptera. To this group belong of the lice of man and other
mammals; <as>as, the head <ex>louse</ex> of man (<spn>Pediculus
capitis</spn>), the body <ex>louse</ex> (<spn>Pediculus
vestimenti</spn>), and the crab <ex>louse</ex> (<spn>Phthirius
pubis</spn>), and many others</as>. See <cref>Crab louse</cref>,
<cref>Dog louse</cref>, <cref>Cattle louse</cref>, etc., under
<er>Crab</er>, <er>Dog</er>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any one of numerous small mandibulate insects,
mostly parasitic on birds, and feeding on the feathers. They are known
as Mallophaga, or bird lice, though some occur on the hair of mammals.
They are usually regarded as degraded Pseudoneuroptera. See
<er>Mallophaga</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any one of the numerous species of aphids, or plant
lice. See <er>Aphid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any small crustacean parasitic on fishes. See
<er>Branchiura</er>, and <er>Ichthvophthira</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is also applied to various other parasites; as,
the whale <xex>louse</xex>, bee<xex>louse</xex>, horse
<xex>louse</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Louse fly</b></col> <fld>(Zool.)</fld>, <cd>a parasitic
dipterous insect of the group Pupipara. Some of them are wingless, as
the bee louse.</cd> -- <col><b>Louse mite</b></col> <fld>(Zool.)</fld>,
<cd>any one of numerous species of mites which infest mammals and birds,
clinging to the hair and feathers like lice. They belong to
<gen>Myobia</gen>, <gen>Dermaleichus</gen>, <gen>Mycoptes</gen>, and
several other genera.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louse</ent><br/
<hw>Louse</hw> <pr>(louz)</pr>, <pos>v. t.</pos> <def>To clean from
lice.</def> <ldquo/You sat and <xex>loused</xex> him.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lousewort</ent><br/
<hw>Louse"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Any species of <gen>Pedicularis</gen>, a genus of perennial herbs.
It was said to make sheep that fed on it lousy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yellow lousewort</b></col>, <cd>a plant of the genus
<gen>Rhinanthus</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lousily</ent><br/
<hw>Lous"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Lousy</er>.]</ety> <def>In a lousy manner; in a mean, paltry manner;
scurvily.</def> <mark>[Vulgar]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lousiness</ent><br/
<hw>Lous"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
lousy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lousy</ent><br/
<hw>Lous"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Infested
with lice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mean; contemptible; <as>as, <ex>lousy</ex>
knave</as>.</def> <mark>[informal]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such <qex>lousy</qex> learning as this is.</q>
<rj><qau>Bale.</qau></rj></p>

<p><sn>3.</sn> <def>Very bad; <as>as, to feel <ex>lousy</ex>; to do a
<ex>lousy</ex> job</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lout</ent><br/
<hw>Lout</hw> <pr>(lout)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>louten</ets>, <ets>luten</ets>, AS. <ets>l<umac/tan</ets>; akin to
Icel. <ets>l<umac/ta</ets>, Dan. <ets>lude</ets>, OHG.
<ets>l<umac/z<emac/n</ets> to lie hid.]</ety> <def>To bend; to box; to
stoop.</def> <mark>[Archaic]</mark> <rj><au>Chaucer.</au>
<au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He fair the knight saluted, <qex>louting</qex> low.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lout</ent><br/
<hw>Lout</hw>, <pos>n.</pos> <ety>[Formerly also written
<ets>lowt</ets>.]</ety> <def>A clownish, awkward fellow; a
bumpkin.</def> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lout</ent><br/
<hw>Lout</hw>, <pos>v. t.</pos> <def>To treat as a lout or fool; to
neglect; to disappoint.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loutish</ent><br/
<hw>Lout"ish</hw>, <pos>a.</pos> <def>Clownish; rude; awkward.</def>
<ldquo/<xex>Loutish</xex> clown.<rdquo/ <au>Sir P. Sidney.</au> --
<wordforms><wf>Lout"ish*ly</wf>, <pos>adv.</pos> --
<wf>Lout"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loutou</ent><br/
\'d8<hw>Lou*tou"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native
names.]</ety> <fld>(Zool.)</fld> <def>A crested black monkey
(<spn>Semnopithecus maurus</spn>) of Java.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Louvre</ent><br/
<ent>Louver</ent><br/
<mhw>{ <hw>Lou"ver</hw>, <hw>Lou"vre</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[OE. <ets>lover</ets>, OF. <ets>lover</ets>,
<ets>lovier</ets>; <ets>or l'ouvert</ets> the opening, fr.
<ets>overt</ets>, <ets>ouvert</ets>, p. p. of <ets>ovrir</ets>,
<ets>ouvrir</ets>, to open, F. <ets>ouvrir</ets>. Cf.
<er>Overt</er>.]</ety> <fld>(Arch.)</fld> <def>A small lantern. See
<er>Lantern</er>, 2 <sd>(a)</sd>.</def> <altsp>[Written also
<asp>lover</asp>, <asp>loover</asp>, <asp>lovery</asp>, and
<asp>luffer</asp>.]</altsp></p>

<p><sn>2.</sn> <def>Same as <cref>louver boards</cref>, below</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A set of slats resembling louver boards, arranged in
a vertical row and attached at each slat end to a frame inserted in or
part of a door or window; the slats may be made of wood, plastic, or
metal, and the angle of inclination of the slats may be adjustable
simultaneously, to allow more or less light or air into the
enclosure.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Louver boards</b></col> <it>or</it> <col><b>Louver
boarding</b></col></mcol>, <cd>the sloping boards set to shed rainwater
outward in openings which are to be left otherwise unfilled; as belfry
windows, the openings of a louver, etc.</cd> -- <col><b>Louver
work</b></col>, <cd>slatted work.</cd></cs></p>

<p><ent>Louver</ent><br/
<hw>Lou"ver</hw> <pr>(?)</pr>, <pos>n.</pos> <def>To supply with
louvers.</def><br/
[<source>PJC</source>]</p>

<p><ent>louvered</ent><br/
<hw>louvered</hw> <pos>adj.</pos> <def>supplied with louvers for
ventilation; <as>as, a <ex>louvered</ex> door</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>louvered door</ent><br/
<hw>lou"vered door`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A door having
louvers in place of a solid panel, in part or all of the surface of the
door.</def><br/
[<source>PJC</source>]</p>

<p><ent>louvered window</ent><br/
<hw>lou"vered win"dow</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A window
having louvers in place of glass, usually over the entire surface of the
window.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lovable</ent><br/
<hw>Lov"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having qualities
that excite, or are fitted to excite, love; worthy of love.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Elaine the fair, Elaine the <qex>lovable</qex>,<br/
Elaine, the lily maid of Astolat.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovage</ent><br/
<hw>Lov"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>liv<egrave/che</ets>, fr. L. <ets>levisticum</ets>,
<ets>ligusticum</ets>, a plant indigenous to Liguria, lovage, from
<ets>Ligusticus</ets> Ligustine, Ligurian, <ets>Liguria</ets> a country
of Cisalpine Gaul.]</ety> <fld>(Bot.)</fld> <def>An umbelliferous plant
(<spn>Levisticum officinale</spn>), sometimes used in medicine as an
aromatic stimulant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Love</ent><br/
<hw>Love</hw> <pr>(l<ucr/v)</pr>, <pos>n.</pos> <ety>[OE.
<ets>love</ets>, <ets>luve</ets>, AS. <ets>lufe</ets>, <ets>lufu</ets>;
akin to E. <ets>lief</ets>, <ets>believe</ets>, L. <ets>lubet</ets>,
<ets>libet</ets>, it pleases, Skr. <ets>lubh</ets> to be lustful. See
<er>Lief</er>.]</ety> <sn>1.</sn> <def>A feeling of strong attachment
induced by that which delights or commands admiration; pre<eum/minent
kindness or devotion to another; affection; tenderness; <as>as, the
<ex>love</ex> of brothers and sisters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of all the dearest bonds we prove<br/
Thou countest sons' and mothers' <qex>love</qex><br/
Most sacred, most Thine own.</q> <rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, devoted attachment to, or tender or
passionate affection for, one of the opposite sex.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He on his side<br/
Leaning half-raised, with looks of cordial <qex>love</qex><br/
Hung over her enamored.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Courtship; -- chiefly in the phrase <it>to make
love</it>, i. e., to court, to woo, to solicit union in
marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Demetrius . . . <br/
Made <qex>love</qex> to Nedar's daughter, Helena,<br/
And won her soul.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Affection; kind feeling; friendship; strong liking
or desire; fondness; good will; -- opposed to <ant>hate</ant>; often
with <xex>of</xex> and an object.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Love</qex>, and health to all.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Smit with the <qex>love</qex> of sacred song.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>love</qex> of science faintly warmed his breast.</q>
<rj><qau>Fenton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Due gratitude and reverence to God.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Keep yourselves in the <qex>love</qex> of God.</q> <rj><qau>Jude
21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The object of affection; -- often employed in
endearing address; <as>as, he held his <ex>love</ex> in his arms; his
greatest <ex>love</ex> was reading</as>.</def> <ldquo/Trust me,
<xex>love</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Open the temple gates unto my <qex>love</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Cupid, the god of love; sometimes, Venus.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such was his form as painters, when they show<br/
Their utmost art, on naked <qex>Lores</qex> bestow.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore do nimble-pinioned doves draw <qex>Love</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A thin silk stuff.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Bot.)</fld> <def>A climbing species of
C<gen>lematis</gen> (<spn>Clematis Vitalba</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Nothing; no points scored on one side; -- used in
counting score at tennis, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He won the match by three sets to <qex>love</qex>.</q>
<rj><qau>The Field.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Sexual intercourse; -- a euphemism.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ <xex>Love</xex> is often used in the formation of
compounds, in most of which the meaning is very obvious; as,
<xex>love-</xex>cracked, <xex>love-</xex>darting,
<xex>love-</xex>killing, <xex>love-</xex>linked, <xex>love-</xex>taught,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>A labor of love</b></col>, <cd>a labor undertaken on
account of regard for some person, or through pleasure in the work
itself, without expectation of reward.</cd> -- <col><b>Free
love</b></col>, <cd>the doctrine or practice of consorting with one of
the opposite sex, at pleasure, without marriage. See <er>Free
love</er>.</cd> -- <col><b>Free lover</b></col>, <cd>one who avows or
practices free love.</cd> -- <col><b>In love</b></col>, <cd>in the act
of loving; -- said esp. of the love of the sexes; <as>as, to be <ex>in
love</ex>; to fall <ex>in love</ex></as>.</cd> -- <col><b>Love
apple</b></col> <fld>(Bot.)</fld>, <cd>the tomato.</cd> -- <col><b>Love
bird</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of
small, short-tailed parrots, or parrakeets, of the genus
<gen>Agapornis</gen>, and allied genera. They are mostly from Africa.
Some species are often kept as cage birds, and are celebrated for the
affection which they show for their mates.</cd> -- <col><b>Love
broker</b></col>, <cd>a person who for pay acts as agent between lovers,
or as a go-between in a sexual intrigue.</cd> <au>Shak.</au> --
<col><b>Love charm</b></col>, <cd>a charm for exciting love.</cd>
<au>Ld. Lytton.</au> -- <col><b>Love child</b></col>. <cd>an
illegitimate child.</cd> <au>Jane Austen.</au> -- <col><b>Love
day</b></col>, <cd>a day formerly appointed for an amicable adjustment
of differences.</cd> <mark>[Obs.]</mark> <au>Piers Plowman.</au>
<au>Chaucer.</au> -- <col><b>Love drink</b></col>, <cd>a love potion; a
philter.</cd> <au>Chaucer.</au> -- <col><b>Love favor</b></col>,
<cd>something given to be worn in token of love.</cd> -- <col><b>Love
feast</b></col>, <cd>a religious festival, held quarterly by some
religious denominations, as the Moravians and Methodists, in imitation
of the <xex>agap<ae/</xex> of the early Christians.</cd> -- <col><b>Love
feat</b></col>, <cd>the gallant act of a lover.</cd> <au>Shak.</au> --
<col><b>Love game</b></col>, <cd>a game, as in tennis, in which the
vanquished person or party does not score a point.</cd> -- <col><b>Love
grass</b></col>. <ety>[G. <ets>liebesgras</ets>.]</ety>
<fld>(Bot.)</fld> <cd>Any grass of the genus <gen>Eragrostis</gen>.</cd>
-- <col><b>Love-in-a-mist</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd>
<cd>An herb of the Buttercup family (<spn>Nigella Damascena</spn>)
having the flowers hidden in a maze of finely cut bracts.</cd>
<sd>(b)</sd> <cd>The West Indian <spn>Passiflora f<oe/tida</spn>, which
has similar bracts.</cd> -- <col><b>Love-in-idleness</b></col>
<fld>(Bot.)</fld>, <cd>a kind of violet; the small pansy.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>A little western flower,<br/
Before milk-white, now purple with love's wound;<br/
And maidens call it <qex>love-in-idleness</qex>.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <col><b>Love juice</b></col>, <cd>juice of a plant supposed to
produce love.</cd> <au>Shak.</au> -- <col><b>Love knot</b></col>, <cd>a
knot or bow, as of ribbon; -- so called from being used as a token of
love, or as a pledge of mutual affection.</cd> <au>Milman.</au> --
<col><b>Love lass</b></col>, <cd>a sweetheart.</cd> -- <col><b>Love
letter</b></col>, <cd>a letter of courtship.</cd> <au>Shak.</au> --
<col><b>Love-lies-bleeding</b></col> <fld>(Bot.)</fld>, <cd>a species of
amaranth (<spn>Amarantus melancholicus</spn>).</cd> -- <col><b>Love
match</b></col>, <cd>a marriage brought about by love alone.</cd> --
<col><b>Love potion</b></col>, <cd>a compounded draught intended to
excite love, or venereal desire.</cd> -- <col><b>Love rites</b></col>,
<cd>sexual intercourse.</cd> <au>Pope</au> -- <col><b>Love
scene</b></col>, <cd>an exhibition of love, as between lovers on the
stage.</cd> -- <col><b>Love suit</b></col>, <cd>courtship.</cd>
<au>Shak.</au> -- <col><b>Of all loves</b></col>, <cd>for the sake of
all love; by all means.</cd> <mark>[Obs.]</mark> <ldquo/Mrs. Arden
desired him <xex>of all loves</xex> to come back again.<rdquo/
<au>Holinshed.</au> -- <mcol><col><b>The god of love</b></col>,
<it>or</it> <col><b>The Love god</b></col></mcol>, <cd>Cupid.</cd> --
<col><b>To make love</b></col>, <cd>to engage in sexual intercourse; --
a euphemism.</cd> -- <col><b>To make love to</b></col>, <cd>to express
affection for; to woo.</cd> <ldquo/If you will marry, <xex>make</xex>
your <xex>loves to</xex> me.<rdquo/ <au>Shak.</au> -- <col><b>To play
for love</b></col>, <cd>to play a game, as at cards, without
stakes.</cd> <ldquo/A game at piquet <xex>for love</xex>.<rdquo/
<au>Lamb.</au><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p></cs>

<p><syn><b>Syn.</b> -- Affection; friendship; kindness; tenderness;
fondness; delight.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Love</ent><br/
<hw>Love</hw> <pr>(l<ucr/v)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Loved</conjf> <pr>(l<ucr/vd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Loving</conjf>.]</vmorph> <ety>[AS. <ets>lufian</ets>.
<root/124. See <er>Love</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To
have a feeling of love for; to regard with affection or good will;
<as>as, to <ex>love</ex> one's children and friends; to <ex>love</ex>
one's country; to <ex>love</ex> one's God.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt <qex>love</qex> the Lord thy God with all thy heart,
and with all thy soul, and with all thy mind.</q> <rj><qau>Matt. xxii.
37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt <qex>love</qex> thy neighbor as thy self.</q>
<rj><qau>Matt. xxii. 39.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To regard with passionate and devoted affection, as
that of one sex for the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To take delight or pleasure in; to have a strong
liking or desire for, or interest in; to be pleased with; to like;
<as>as, to <ex>love</ex> books; to <ex>love</ex>
adventures.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wit, eloquence, and poetry.<br/
Arts which I <qex>loved</qex>.</q> <rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Love</ent><br/
<hw>Love</hw>, <pos>v. i.</pos> <def>To have the feeling of love; to be
in love.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loveable</ent><br/
<hw>Love"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Lovable</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lovebird</ent><br/
<hw>lovebird</hw> <pos>n.</pos> <def>A small Australian parakeet
(<spn>Melopsittacus undulatus</spn>) usually light green with black and
yellow markings in the wild but bred in many colors; also called the
<altname>budgie</altname>.</def><br/
<syn><b>Syn. --</b> budgerigar, budgereegah, budgerygah, budgie, grass
parakeet, shell parakeet, <spn>Melopsittacus undulatus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>small African parrot noted for showing affection for
their mates.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>loved</ent><br/
<hw>loved</hw> <pos>adj.</pos> <sn>1.</sn> <def><pos>p. p.</pos> of
<er>love</er>, <pos>v. t.</pos>. Opposite of <ant>unloved</ant>.</def>
[Narrower terms: <stype>admired, esteemed</stype>] <see>Also See:
<er>wanted</er>.</see><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Love-drury</ent><br/
<hw>Love"-dru`ry</hw>, <pos>n.</pos> <ety>[<ets>Love</ets> + OF.
<ets>druerie.</ets> Cf. <er>Druery</er>.]</ety> <def>Affection.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovee</ent><br/
<hw>Lov*ee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
loved.</def> <mark>[Humorous]</mark> <ldquo/The lover and
<xex>lovee</xex>.<rdquo/ <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loveful</ent><br/
<hw>Love"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of love.</def>
<mark>[Obs.]</mark> <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loveless</ent><br/
<hw>Love"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Void of love; void of
tenderness or kindness.</def> <rj><au>Milton. Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not attracting love; unattractive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These are ill-favored to see to; and yet, as <qex>loveless</qex>
as they be, they are not without some medicinable virtues.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovelily</ent><br/
<hw>Love"li*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Lovely</er>.]</ety> <def>In manner to excite love; amiably.</def>
<mark>[R.]</mark> <rj><au>Otway.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loveliness</ent><br/
<hw>Love"li*ness</hw>, <pos>n.</pos> <ety>[From <er>Lovely</er>.]</ety>
<def>The state or quality of being lovely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If there is such a native <qex>loveliness</qex> in the sex as to
make them victorious when in the wrong, how resistless their power when
they are on the side of truth!</q> <rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovelock</ent><br/
<hw>Love"lock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A long lock of hair
hanging prominently by itself; an earlock; -- worn by men of fashion in
the reigns of Elizabeth and James I.</def> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A long <qex>lovelock</qex> and long hair he wore.</q> <rj><qau>Sir
W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovelorn</ent><br/
<hw>Love"lorn`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forsaken by one's
love.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lovelorn</qex> nightingale.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovely</ent><br/
<hw>Love"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lovelier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Loveliest</adjf>.]</amorph> <ety>[AS. <ets>luflic</ets>.]</ety>
<sn>1.</sn> <def>Having such an appearance as excites, or is fitted to
excite, love; beautiful; charming; very pleasing in form, looks, tone,
or manner.</def> <ldquo/<xex>Lovely</xex> to look on.<rdquo/ <au>Piers
Plowman.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Not one so fair of face, of speech so <qex>lovely</qex>.</q>
<rj><qau>Robert of Brunne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If I had such a tire, this face of mine<br/
Were full as <qex>lovely</qex> as is this of hers.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lovable; amiable; having qualities of any kind which
excite, or are fitted to excite, love or friendship.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A most <qex>lovely</qex> gentlemanlike man.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Loving; tender.</def> <mark>[Obs.]</mark> <ldquo/A
<xex>lovely</xex> kiss.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Many a <qex>lovely</qex> look on them he cast.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Very pleasing; -- applied loosely to almost anything
which is not grand or merely pretty; <as>as, a <ex>lovely</ex> view; a
<ex>lovely</ex> valley; a <ex>lovely</ex> melody.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Indeed these fields<br/
Are <qex>lovely</qex>, <qex>lovelier</qex> not the Elysian lawns.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><syn><b>Syn.</b> -- Beautiful; charming; delightful; delectable;
enchanting; lovable; amiable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovely</ent><br/
<hw>Love"ly</hw>, <pos>adv.</pos> <def>In a manner to please, or to
excite love.</def> <mark>[Obs. or R.]</mark>
<rj><au>Tyndale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Love-making</ent><br/
<hw>Love"-mak`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Courtship.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sexual intercourse.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lovemonger</ent><br/
<hw>Love"mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who deals in
affairs of love.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>love-philtre</ent><br/
<ent>love-philter</ent><br/
<mhw><hw>love-philter</hw>, <hw>love-philtre</hw></mhw> <pos>n.</pos>
<def>a fabled drink credited with magical power; it can make the one who
takes it love the one who gave it.</def><br/
<syn><b>Syn. --</b> philter, philtre, love-potion.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>love-potion</ent><br/
<hw>love-potion</hw> <pos>n.</pos> <def>a fabled drink credited with
magical power; it can make the one who takes it love the one who gave
it.</def><br/
<syn><b>Syn. --</b> philter, philtre, love-philter,
love-philtre.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lover</ent><br/
<hw>Lov"er</hw> <pr>(l<ucr/v"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who loves; one who is in love; -- usually limited, in the
singular, to a person of the male sex.</def>
<rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Love is blind, and <qex>lovers</qex> can not see<br/
The pretty follies that themselves commit.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A friend; one strongly attached to another; one who
greatly desires the welfare of any person or thing; <as>as, a
<ex>lover</ex> of his country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I slew my best <qex>lover</qex> for the good of Rome.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who has a strong liking for anything, as books,
science, or music.</def> <ldquo/A <xex>lover</xex> of knowledge.<rdquo/
<au>T. Burnet.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who is involved in a sexual relationship with
another; <as>as, she took a <ex>lover</ex>.</as></def><br/
[<source>PJC</source>]</p>

<p><-- p. 872 --></p>

<p><ent>Lovery</ent><br/
<ent>Lover</ent><br/
<mhw>{ <hw>Lo"ver</hw> <pr>(l<oomac/"v<etil/r)</pr>, <hw>Lo"ver*y</hw>
<pr>(l<oomac/"v<etil/r*<ycr/)</pr>, }</mhw> <pos>n.</pos> <def>See
<er>Louver</er>.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loverwise</ent><br/
<hw>Lo"ver*wise`</hw> <pr>(l<ucr/v"<etil/r*w<imac/z`)</pr>,
<pos>adv.</pos> <def>As lovers do.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As they sat down here <qex>loverwise</qex>.</q> <rj><qau>W. D.
Howells.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Love-sick</ent><br/
<hw>Love"-sick`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Languishing with love or amorous desire; <as>as, a
<ex>love-sick</ex> maid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To the dear mistress of my <qex>love-sick</qex> mind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Originating in, or expressive of, languishing
love.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where nightingales their <qex>love-sick</qex> ditty sing.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Love-sickness</ent><br/
<hw>Love"-sick`ness</hw>, <pos>n.</pos> <def>The state of being
love-sick.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovesome</ent><br/
<hw>Love"some</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>lufsum</ets>.]</ety> <def>Lovely.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>love song</ent><br/
<ent>lovesong</ent><br/
<mhw><hw>lovesong</hw>, <hw>love song</hw></mhw> <pos>n.</pos> <def>a
song about love or expressing love for another person.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>love-token</ent><br/
<hw>love-token</hw> <pos>n.</pos> <def>something given as a token of
love.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loving</ent><br/
<hw>Lov"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Affectionate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fairest and most <qex>loving</qex> wife in Greece.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing love or kindness; <as>as, <ex>loving</ex>
words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loving cup</ent><br/
<hw>Lov"ing cup`</hw>. <sn>1.</sn> <def>A large ornamental drinking
vessel having two or more handles, intended to pass from hand to hand,
as at a banquet.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>an award resembling a <er>loving cup</er>{1} that is
given to the winner of a competition.</def><br/
[<source>PJC</source>]</p>

<p><ent>Loving-kindness</ent><br/
<hw>Lov"ing-kind"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Tender
regard; mercy; favor.</def> <rj><au>Ps. lxxxix. 33.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovingly</ent><br/
<hw>Lov"ing*ly</hw>, <pos>adv.</pos> <def>With love;
affectionately.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovingness</ent><br/
<hw>Lov"ing*ness</hw>, <pos>n.</pos> <def>Affection; kind
regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The only two bands of good will, loveliness and
<qex>lovingness</qex>.</q> <rj><qau>Sir. P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lovyer</ent><br/
<hw>Lov"yer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lover.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>strong imp.</pos>
of <er>Laugh</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw> <pr>(l<omac/)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lowed</conjf> <pr>(l<omac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lowing</conjf>.]</vmorph> <ety>[OE. <ets>lowen</ets>,
AS. <ets>hl<omac/wan</ets>; akin to D. <ets>loeijen</ets>, OHG.
<ets>hl<omac/jan</ets>, <ets>hluojan</ets>.]</ety> <def>To make the
calling sound of cows and other bovine animals; to moo.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lowing</qex> herd wind slowly o'er the lea.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw>, <pos>n.</pos> <def>The calling sound ordinarily made by
cows and other bovine animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Talking voices and the <qex>law</qex> of herds.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw>, <pos>n.</pos> <ety>[AS. <ets>hl<amac/w</ets>; akin to
Goth. <ets>hlaiw</ets> a grave, <ets>hlains</ets> a hill, and to E.
<ets>lean</ets> to incline.]</ety> <def>A hill; a mound; a grave.</def>
<mark>[Obs. except in place names.]</mark> <rj><au>Skeat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw> <pr>(l<omac/; <it>Scot.</it> lou)</pr>, <pos>n.</pos>
<ety>[Icel. <ets>log</ets>, <ets>logi</ets>; akin to E.
<ets>light</ets>, <pos>n.</pos>]</ety> <def>Fire; a flame; a
light.</def> <mark>[Scot. & Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw>, <pos>v. i.</pos> <def>To burn; to blaze.</def>
<mark>[Prov. Eng. & Scot.]</mark> <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw> <pr>(l<omac/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Lower</adjf>
<pr>(l<omac/"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Lowest</adjf>.]</amorph> <ety>[OE. <ets>low</ets>,
<ets>louh</ets>, <ets>lah</ets>, Icel. <ets>l<amac/gr</ets>; akin to Sw.
<ets>l<aring/g</ets>, Dan. <ets>lav</ets>, D. <ets>laag</ets>, and E.
<ets>lie</ets>. See <er>Lie</er> to be prostrate.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Occupying an inferior position or place; not high or
elevated; depressed in comparison with something else; <as>as,
<ex>low</ex> ground; a <ex>low</ex> flight.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not rising to the usual height; <as>as, a man of
<ex>low</ex> stature; a <ex>low</ex> fence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Near the horizon; <as>as, the sun is <ex>low</ex> at
four o'clock in winter, and six in summer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Sunk to the farthest ebb of the tide; <as>as,
<ex>low</ex> tide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Beneath the usual or remunerative rate or amount, or
the ordinary value; moderate; cheap; <as>as, the <ex>low</ex> price of
corn; <ex>low</ex> wages.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not loud; <as>as, a <ex>low</ex> voice; a
<ex>low</ex> sound.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mus.)</fld> <def>Depressed in the scale of sounds;
grave; <as>as, a <ex>low</ex> pitch; a <ex>low</ex> note.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Phon.)</fld> <def>Made, as a vowel, with a low
position of part of the tongue in relation to the palate; <as>as, <acr/
(<acr/m), <add/ (<add/ll)</as>. See <xex>Guide to Pronunciation</xex>,
<sect/<sect/ 5, 10, 11.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Near, or not very distant from, the equator; <as>as,
in the <ex>low</ex> northern latitudes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Numerically small; <as>as, a <ex>low</ex>
number</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Wanting strength or animation; depressed; dejected;
<as>as, <ex>low</ex> spirits; <ex>low</ex> in spirits.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Depressed in condition; humble in rank; <as>as, men
of <ex>low</ex> condition; the <ex>lower</ex> classes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why but to keep ye <qex>low</qex> and ignorant ?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>Mean; vulgar; base; dishonorable; <as>as, a person
of <ex>low</ex> mind; a <ex>low</ex> trick or stratagem.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>Not elevated or sublime; not exalted in thought or
diction; <as>as, a <ex>low</ex> comparison</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In comparison of these divine writers, the noblest wits of the
heathen world are <qex>low</qex> and dull.</q>
<rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>Submissive; humble.</def> <ldquo/<xex>Low</xex>
reverence.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>Deficient in vital energy; feeble; weak; <as>as, a
<ex>low</ex> pulse; made <ex>low</ex> by sickness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>Moderate; not intense; not inflammatory; <as>as,
<ex>low</ex> heat; a <ex>low</ex> temperature; a <ex>low</ex>
fever.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <def>Smaller than is reasonable or probable; <as>as, a
<ex>low</ex> estimate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>19.</sn> <def>Not rich, high seasoned, or nourishing; plain;
simple; <as>as, a <ex>low</ex> diet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Low</xex> is often used in the formation of
compounds which require no special explanation; as,
<xex>low-</xex>arched, <xex>low-</xex>browed, <xex>low-</xex>crowned,
<xex>low-</xex>heeled, <xex>low-</xex>lying, <xex>low-</xex>priced,
<xex>low-</xex>roofed, <xex>low-</xex>toned, <xex>low-</xex>voiced, and
the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Low Church</b></col>. <cd>See <cref>High Church</cref>,
under <er>High</er>.</cd> -- <col><b>Low Countries</b></col>, <cd>the
Netherlands.</cd> -- <mcol><col><b>Low German</b></col>, <col><b>Low
Latin</b></col></mcol>, <cd>etc. See under <er>German</er>,
<er>Latin</er>, etc.</cd> -- <col><b>Low life</b></col>, <cd>humble
life.</cd> -- <col><b>Low milling</b></col>, <cd>a process of making
flour from grain by a single grinding and by siftings.</cd> --
<col><b>Low relief</b></col>. <cd>See <er>Bas-relief</er>.</cd> --
<col><b>Low side window</b></col> <fld>(Arch.)</fld>, <cd>a peculiar
form of window common in medi<ae/val churches, and of uncertain use.
Windows of this sort are narrow, near the ground, and out of the line of
the windows, and in many different situations in the building.</cd> --
<col><b>Low spirits</b></col>, <cd>despondency.</cd> -- <col><b>Low
steam</b></col>, <cd>steam having a low pressure.</cd> -- <col><b>Low
steel</b></col>, <cd>steel which contains only a small proportion of
carbon, and can not be hardened greatly by sudden cooling.</cd> --
<col><b>Low Sunday</b></col>, <cd>the Sunday next after Easter; --
popularly so called.</cd> -- <col><b>Low tide</b></col>, <cd>the
farthest ebb of the tide; the tide at its lowest point; low water.</cd>
-- <col><b>Low water</b></col>. <sd>(a)</sd> <cd>The lowest point of the
ebb tide; a low stage of the in a river, lake, etc.</cd> <sd>(b)</sd>
<fld>(Steam Boiler)</fld> <cd>The condition of an insufficient quantity
of water in the boiler.</cd> -- <mcol><col><b>Low water alarm</b></col>
<it>or</it> <col><b>Low water indicator</b></col></mcol> <fld>(Steam
Boiler)</fld>, <cd>a contrivance of various forms attached to a boiler
for giving warning when the water is low.</cd> -- <col><b>Low water
mark</b></col>, <cd>that part of the shore to which the waters recede
when the tide is the lowest.</cd> <au>Bouvier.</au> -- <col><b>Low
wine</b></col>, <cd>a liquor containing about 20 percent of alcohol,
produced by the first distillation of wash; the first run of the still;
-- often in the plural.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw>, <pos>n.</pos> <fld>(Card Playing)</fld> <def>The lowest
trump, usually the deuce; the lowest trump dealt or drawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a low position or
manner; not aloft; not on high; near the ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Under the usual price; at a moderate price; cheaply;
<as>as, he sold his wheat <ex>low</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In a low or mean condition; humbly;
meanly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In time approaching our own.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In that part of the world which was first inhabited, even as
<qex>low</qex> down as Abraham's time, they wandered with their flocks
and herds.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>With a low voice or sound; not loudly; gently;
<as>as, to speak <ex>low</ex></as>.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The . . . odorous wind<br/
Breathes <qex>low</qex> between the sunset and the moon.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>With a low musical pitch or tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Can sing both high and <qex>low</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>In subjection, poverty, or disgrace; <as>as, to be
brought <ex>low</ex> by oppression, by want, or by vice</as>.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Astron.)</fld> <def>In a path near the equator, so
that the declination is small, or near the horizon, so that the altitude
is small; -- said of the heavenly bodies with reference to the diurnal
revolution; <as>as, the moon runs <ex>low</ex>, that is, is
comparatively near the horizon when on or near the
meridian</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low</ent><br/
<hw>Low</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To depress; to
lower.</def> <mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lowan</ent><br/
<hw>lowan</hw> <pos>n.</pos> <def>The Australian moundbird (<spn>Leipoa
ocellata</spn>); it incubates eggs naturally in sandy mounds.</def><br/
<syn><b>Syn. --</b> mallee fowl, mallee-fowl, leipoa, <spn>Leipoa
ocellata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lowball</ent><br/
<hw>lowball</hw> <pos>n.</pos> <def>A poker game in which the
lowest-ranking hand wins.</def><br/
[<source>PJC</source>]</p>

<p><ent>lowball</ent><br/
<hw>lowball</hw> <pos>v. t.</pos> <def>to give a deceptively low
estimate of the price of (merchandise or services); -- a sales tactic to
induce a person to buy.</def><br/
<syn><b>Syn. --</b> underestimate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowbell</ent><br/
<hw>Low"bell`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Low</ets> a
flame + <ets>bell</ets>.]</ety> <sn>1.</sn> <def>A bell used in fowling
at night, to frighten birds, and, with a sudden light, to make them fly
into a net.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fowler's <qex>lowbell</qex> robs the lark of sleep.</q>
<rj><qau>King.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bell to be hung on the neck of a sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>lowbell</qex> hung about a sheep's . . . neck.</q>
<rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowbell</ent><br/
<hw>Low"bell`</hw>, <pos>v. t.</pos> <def>To frighten, as with a
lowbell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowborn</ent><br/
<hw>Low"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Born in a low
condition or rank; -- opposed to <ant>highborn</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowboy</ent><br/
<hw>Low"boy`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chest of drawers
not more than four feet high; -- applied commonly to the lower half of a
tallboy from which the upper half has been removed.</def> <mark>[U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lowbred</ent><br/
<hw>Low"bred`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bred, or like one
bred, in a low condition of life; characteristic or indicative of such
breeding; rude; impolite; vulgar; <as>as, a <ex>lowbred</ex> fellow; a
<ex>lowbred</ex> remark.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-cal</ent><br/
<hw>low-cal</hw> <pos>adj.</pos> <def>having relatively few
calories.</def><br/
<syn><b>Syn. --</b> diet(prenominal), lite, low-calorie.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-ceilinged</ent><br/
<hw>low-ceilinged</hw> <pos>adj.</pos> <def>having a lower than normal
ceiling.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Low-church</ent><br/
<hw>Low"-church`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not placing a
high estimate on ecclesiastical organizations or forms; -- applied
especially to Episcopalians, and opposed to <contr>high-church</contr>.
See <cref>High Church</cref>, under <er>High</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low-churchism</ent><br/
<hw>Low"-church`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles
of the low-church party.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low-churchman</ent><br/
<hw>Low"-church`man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-men</plw> <pr>(<?/)</pr>.</plu> <def>One who holds low-church
principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low-churchmanship</ent><br/
<hw>Low"-church`man*ship</hw>, <pos>n.</pos> <def>The state of being a
low-churchman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-class</ent><br/
<hw>low-class</hw> <pos>adj.</pos> <sn>1.</sn> <def>Occupying the lowest
socioeconomic position in a society. Contrasted with
<contr>middle-class</contr> and <contr>upper-class</contr>.</def>
[Narrower terms: <stype>propertyless, wage-earning, working-class,
blue-collar</stype>] <see>Also See: <er>lowborn</er>,
<er>proletarian</er>, <er>propertyless</er>.</see><br/
<syn><b>Syn. --</b> lower-class (vs. upper-class).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>characteristic of the lower classes.</def> [Narrower
terms: <stype>non-U, vulgar</stype>] <source>PJC</source>]</p>

<p><ent>low-cost</ent><br/
<hw>low-cost</hw> <pos>adj.</pos> <def>inexpensive; cheap. Opposite of
<ant>expensive</ant>.</def><br/
<syn><b>Syn. --</b> inexpensive, low-priced.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-cut</ent><br/
<hw>low-cut</hw> <pos>adj.</pos> <sn>1.</sn> <def>having a neckline low
enough to expose part of the breast; -- of a woman's garment; <as>as, a
<ex>low-cut</ex> party dress</as>.</def><br/
<syn><b>Syn. --</b> decollete, low-necked.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>having a back exposing skin between the shoulder
blades.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>low-down</ent><br/
<ent>lowdown</ent><br/
<mhw><hw>low"down`</hw>, <hw>low"-down`</hw></mhw> <pos>n.</pos>
<def>true confidential information.</def><br/
<syn><b>Syn. --</b> details, dope, poop, inside dope, inside
information.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-down</ent><br/
<ent>lowdown</ent><br/
<mhw><hw>low"down`</hw>, <hw>low"-down`</hw></mhw> <pos>a.</pos> <def>of
the most contemptible kind; contemptible; mean; base; vile; -- of people
or the actions of people; <as>as, a <ex>lowdown</ex> sneak
thief</as>.</def><br/
<syn><b>Syn. --</b> abject, base, despicable, low, lowdown, miserable,
vile.</syn><br/
[<source>WordNet 1.5</source> + <source>PJC</source>]</p>

<p><sn>2.</sn> <def>having the soulful feeling of early blues; -- of
jazz.</def><br/
<syn><b>Syn. --</b> funky.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>low-emission</ent><br/
<hw>low-emission</hw> <pos>adj.</pos> <def>producing little emission of
atmospheric pollutants; <as>as, a <ex>low-emission</ex>
vehicle</as>.</def><br/
<syn><b>Syn. --</b> low-polluting.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Lower</ent><br/
<hw>Low"er</hw> <pr>(?)</pr>, <pos>a.</pos> <def><pos>Compar.</pos> of
<er>Low</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lower</ent><br/
<hw>Low"er</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lowered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lowering</conjf>.]</vmorph> <ety>[From <er>Low</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To let descend by its own weight,
as something suspended; to let down; <as>as, to <ex>lower</ex> a bucket
into a well; to <xex>lower</xex> a sail or a boat</as>; sometimes, to
pull down; <as>as, to <ex>lower</ex> a flag</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lowered</qex> softly with a threefold cord of love<br/
Down to a silent grave.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reduce the height of; <as>as, to <ex>lower</ex> a
fence or wall; to <ex>lower</ex> a chimney or turret.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To depress as to direction; <as>as, to
<ex>lower</ex> the aim of a gun</as>; to make less elevated as to
object; <as>as, to <ex>lower</ex> one's ambition, aspirations, or
hopes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To reduce the degree, intensity, strength, etc., of;
<as>as, to <ex>lower</ex> the temperature of anything; to <ex>lower</ex>
one's vitality; to <ex>lower</ex> distilled liquors.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To bring down; to humble; <as>as, to <ex>lower</ex>
one's pride</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To reduce in value, amount, etc.; <as>as, to
<ex>lower</ex> the price of goods, the rate of interest,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lower</ent><br/
<hw>Low"er</hw>, <pos>v. i.</pos> <def>To fall; to sink; to grow less;
to diminish; to decrease; <as>as, the river <ex>lowered</ex> as rapidly
as it rose</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lower</ent><br/
<hw>Low"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lowered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lowering</conjf>.]</vmorph> <ety>[OE. <ets>lowren</ets>,
<ets>luren</ets>; cf. D. <ets>loeren</ets>, LG. <ets>luren</ets>. G.
<ets>lauern</ets> to lurk, to be on the watch, and E. <ets>leer</ets>,
<ets>lurk</ets>.]</ety> <sn>1.</sn> <def>To be dark, gloomy, and
threatening, as clouds; to be covered with dark and threatening clouds,
as the sky; to show threatening signs of approach, as a
tempest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the clouds that <qex>lowered</qex> upon our house.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To frown; to look sullen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But sullen discontent sat <qex>lowering</qex> on her face.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lower</ent><br/
<hw>Low"er</hw>, <pos>n.</pos> <mark>[Obs.]</mark> <sn>1.</sn>
<def>Cloudiness; gloominess.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A frowning; sullenness.</def><br/
[<source>1913 Webster</source>]</p>

<p> <pos>adj.</pos> <sn>1.</sn> <def>relating to small or noncapital
letters which were kept in the lower half of a compositor's type
case.</def> <see>Also See <er>minuscule</er>,
<er>minuscular</er>.</see><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lower-case</ent><br/
<ent>lowercase</ent><br/
<mhw><hw>low"er*case`</hw>, <hw>Low"er-case`</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <fld>(Print.)</fld> <def>Pertaining to, or kept in, the
lower case; -- used to denote the small letters, in distinction from
capitals and small capitals; <as>as, <ex>lowercase</ex> letters a and b
and c etc.</as>. Contrasted with <ant>uppercase</ant>. See the Note
under 1st <er>Case</er>, <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lower-class</ent><br/
<hw>lower-class</hw> <pos>adj.</pos> <def>same as <er>low-class</er>.
Contrasted with <contr>middle-class</contr> and
<contr>upper-class</contr>.</def><br/
<syn><b>Syn. --</b> low-class.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lowerclassman</ent><br/
<hw>lowerclassman</hw> <pos>n.</pos> <def>an undergraduate who is not
yet a senior.</def><br/
<syn><b>Syn. --</b> underclassman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lowered</ent><br/
<hw>lowered</hw> <pos>adj.</pos> <def>pointed downward; <as>as, with
<ex>lowered</ex> eyes</as>. Opposite of <ant>raised</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowering</ent><br/
<hw>Low"er*ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dark and
threatening; gloomy; sullen; <as>as, <ex>lowering</ex> clouds or
sky</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loweringly</ent><br/
<hw>Low"er*ing*ly</hw>, <pos>adv.</pos> <def>In a lowering manner; with
cloudiness or threatening gloom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lower-limit</ent><br/
<ent>lower limit</ent><br/
<mhw><hw>lower limit</hw>, <hw>lower-limit</hw></mhw> <pos>n.</pos>
<def>the limit on the lower (or southernmost) side of
something.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lower-middle-class</ent><br/
<hw>lower-middle-class</hw> <pos>adj.</pos> <def>occupying the lower
part of the middle socioeconomic range in a society.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowermost</ent><br/
<hw>Low"er*most`</hw> <pr>(?)</pr>, <pos>a.</pos> <mord>[Irreg.
<pos>superl.</pos> of <er>Low</er>. Cf. <er>Uppermost</er>,
<er>Foremost</er>, etc.]</mord> <def>Lowest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lower-ranking</ent><br/
<hw>lower-ranking</hw> <pos>adj.</pos> <def>inferior in rank or
status.</def><br/
<syn><b>Syn. --</b> junior-grade, inferior, lower, lowly,
petty(prenominal), secondary, subaltern, subordinate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowery</ent><br/
<hw>Low"er*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cloudy; gloomy;
lowering; <as>as, a <ex>lowery</ex> sky; <ex>lowery</ex>
weather.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowh</ent><br/
<ent>Lowgh</ent><br/
<mhw>{ <hw>Lowgh</hw> <pr>(?)</pr>, <hw>Lowh</hw> }</mhw>,
<mark>obs.</mark> <def><pos>strong imp.</pos> of <er>Laugh</er>.</def>
<ety>[Cf. 1st Low and 2d <er>Lough</er>.]</ety> <-- irregular format,
ety after def. --> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-grade</ent><br/
<hw>low-grade</hw> <pos>adj.</pos> <def>inferior; <as>as,
<ex>low-grade</ex> ore</as>. Opposite of
<ant>high-grade</ant>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Lowing</ent><br/
<hw>Low"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The calling sound made
by cows and other bovine animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowish</ent><br/
<hw>Low"ish</hw>, <pos>a.</pos> <def>Somewhat low.</def>
<mark>[Colloq.]</mark> <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowk</ent><br/
<hw>Lowk</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Louk</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-keyed</ent><br/
<ent>low-key</ent><br/
<mhw><hw>low-key</hw> <hw>low-keyed</hw></mhw> <pos>adj.</pos>
<def>restrained in style or quality; not flashy or intense; understated;
<as>as, a little masterpiece of <ex>low-keyed</ex>
eloquence</as>.</def><br/
<syn><b>Syn. --</b> subdued.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowland</ent><br/
<hw>Low"land</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Land which is low
with respect to the neighboring country; a low or level country; --
opposed to <contr>highland</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Lowlands</b></col>, <cd>Belgium and Holland; the
Netherlands; also, the southern part of Scotland.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowlander</ent><br/
<hw>Low"land*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A native or
inhabitant of the Lowlands, especially of the Lowlands of Scotland, as
distinguished from <contr>Highlander</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-level</ent><br/
<hw>low-level</hw> <pos>adj.</pos> <sn>1.</sn> <def>weak; not intense;
<as>as, <ex>low-level</ex> radiation</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>lower in rank or importance.</def> [Narrower terms:
<stype>adjunct, assistant</stype>; <stype>associate(prenominal)
</stype>; <stype>buck </stype>; <stype>deputy(prenominal),
proxy(prenominal) </stype>; <stype>subject, dependent </stype>;
<stype>subservient </stype>] [Narrower terms: <stype>under(prenominal)
</stype>; <stype>ruled </stype>; <stype>secondary </stype>] <see>Also
See <er>inferior</er>, s<er>ubordinate</er>.</see> Antonym:
<ant>dominant</ant>.<br/
<syn><b>Syn. --</b> subordinate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>at a low level in rank or importance; <as>as, a
<ex>low-level</ex> job; <ex>low-level</ex> discussions</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>occurring at a relatively low altitude; <as>as, a
<ex>low-level</ex> strafing run; <ex>low-level</ex>
bombing</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowlihead</ent><br/
<ent>Lowlihood</ent><br/
<mhw>{ <hw>Low"li*hood</hw> <pr>(?)</pr>, <hw>Low"li*head</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>A lowly state.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowlily</ent><br/
<hw>Low"li*ly</hw>, <pos>adv.</pos> <def>In a lowly place or manner;
humbly.</def> <mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thinking <qex>lowlily</qex> of himself and highly of those better
than himself.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowliness</ent><br/
<hw>Low"li*ness</hw>, <pos>n.</pos> <ety>[From <er>Lowly</er>.]</ety>
<sn>1.</sn> <def>The state or quality of being lowly; humility;
humbleness of mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Walk . . . with all <qex>lowliness</qex> and meekness.</q>
<rj><qau>Eph. iv. 1, 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Low condition, especially as to manner of
life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lowliness</qex> of my fortune has not brought me to
flatter vice.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low-lived</ent><br/
<hw>Low"-lived`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Characteristic of,
or like, one bred in a low and vulgar condition of life; mean;
dishonorable; contemptible; <as>as, <ex>low-lived</ex>
dishonesty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowly</ent><br/
<hw>Low"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lowlier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Lowliest</adjf>.]</amorph> <ety>[<ets>Low</ets>, <pos>a.</pos> +
<ets>-ly</ets>.]</ety> <sn>1.</sn> <def>Not high; not elevated in place;
low.</def> <ldquo/<xex>Lowly</xex> lands.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Low in rank or social importance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One common right the great and <qex>lowly</qex> claims.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not lofty or sublime; humble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These rural poems, and their <qex>lowly</qex> strain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Having a low esteem of one's own worth; humble;
meek; free from pride.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Take my yoke upon you, and learn of me, for I am meek and
<qex>lowly</qex> in heart.</q> <rj><qau>Matt. xi. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowly</ent><br/
<hw>Low"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a low manner;
humbly; meekly; modestly.</def> <ldquo/Be <xex>lowly</xex> wise.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a low condition; meanly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will show myself highly fed, and <qex>lowly</qex> taught.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-lying</ent><br/
<hw>low-lying</hw> <pos>adj.</pos> <sn>1.</sn> <def>having a small
elevation above the ground or horizon or sea level; <as>as,
<ex>low-lying</ex> clouds</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>at a low elevation above sea level.</def><br/
<syn><b>Syn. --</b> sea-level.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Low-minded</ent><br/
<hw>Low"-mind`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inclined in mind
to low or unworthy things; showing a base mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Low-minded</qex> and immoral.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All old religious jealousies were condemned as
<qex>low-minded</qex> infirmities.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low-mindedness</ent><br/
<hw>Low"-mind`ed*ness</hw>, <pos>n.</pos> <def>The quality of being
low-minded; meanness; baseness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lown</ent><br/
<hw>Lown</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Loon</er>.]</ety> <def>A low fellow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low-necked</ent><br/
<hw>Low"-necked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cut low in the
neck; decollete; low-cut; -- said of a woman's dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lowness</ent><br/
<hw>Low"ness</hw>, <pos>n.</pos> <def>The state or quality of being
low.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-pitched</ent><br/
<hw>low-pitched</hw> <pos>adj.</pos> <sn>1.</sn> <def>low in pitch or
frequency; -- used of sounds and voices. Opposite of
<ant>high-pitched</ant>.</def> [Narrower terms: <stype>alto, contralto
</stype>; <stype>baritone </stype>; <stype>bass, deep </stype>;
<stype>contrabass, double-bass </stype>; <stype>throaty </stype>]<br/
<syn><b>Syn. --</b> low.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>set at a low angle or slant; having a low degree of
pitch; <as>as, a <ex>low-pitched</ex> roof</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-polluting</ent><br/
<hw>low-polluting</hw> <pos>adj.</pos> <def>producing little pollution,
especially air pollution; <as>as, a <ex>low-polluting</ex> electric
car</as>.</def><br/
<syn><b>Syn. --</b> low-emission.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Low-pressure</ent><br/
<hw>Low"-pres`sure</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having, employing, or exerting, a low degree of pressure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>same as <er>easygoing</er>, 4; <as>as, a
<ex>low-pressure</ex> salesman</as>.</def><br/
<syn><b>Syn. --</b> easygoing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Low-pressure steam engine</b></col>, <cd>a steam engine
in which low steam is used; often applied to a condensing engine even
when steam at high pressure is used. See <er>Steam
engine</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-priced</ent><br/
<hw>low-priced</hw> <pos>adj.</pos> <def>same as
<er>low-cost</er>.</def><br/
<syn><b>Syn. --</b> inexpensive, low-cost.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-resolution</ent><br/
<hw>low-resolution</hw> <pos>adj.</pos> <def>producing images that are
not sharply defined; -- of optical instruments or image display devices.
Opposite of <ant>high-resolution</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-rise</ent><br/
<hw>low-rise</hw> <pos>adj.</pos> <def>Lower than the highest heights;
-- used of buildings of one or only a few stories; <as>as, a
<ex>low-rise</ex> apartment building</as>.</def> [Narrower terms:
<stype>three-story, three-storied, three-storey, three-storeyed</stype>]
<ant>high-rise</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lowry</ent><br/
<hw>Low"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An open box car used on
railroads. Compare <er>Lorry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-set</ent><br/
<hw>low-set</hw> <pos>adj.</pos> <def>short and thick; especially having
short legs and heavy musculature; -- of people.</def><br/
<syn><b>Syn. --</b> chunky, dumpy, squat, squatty, stubby, stumpy,
stocky.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Low-spirited</ent><br/
<hw>Low"-spir`it*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deficient in
animation and courage; dejected; depressed; dispirited; not
sprightly.</def><br/
<syn><b>Syn. --</b> depressed, dispirited, down(predicate), downcast,
downhearted, low.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>Low"-spir`it*ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Low steel</ent><br/
<hw>Low steel</hw>. <def>See under <er>Low</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Low-studded</ent><br/
<hw>Low"-stud`ded</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished or
built with short studs; <as>as, a <ex>low-studded</ex> house or
room</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-sudsing</ent><br/
<hw>low-sudsing</hw> <pos>adj.</pos> <def>causing little foam to form;
-- used of e.g. detergents. Contrasted with
<ant>high-sudsing</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-tech</ent><br/
<hw>low-tech</hw> <pos>adj.</pos> <def>not involving high technology;
using long-established technology. Opposite of
<ant>high-tech</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-tension</ent><br/
<hw>low-tension</hw> <pos>adj.</pos> <fld>(Elecricity)</fld>
<def>subjected to or capable of operating under relative low voltage.
Contrasted with <ant>high-tension</ant>.</def><br/
<syn><b>Syn. --</b> low-voltage.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Low-thoughted</ent><br/
<hw>Low"-thought`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having one's
thoughts directed toward mean or insignificant subjects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>low-toned</ent><br/
<hw>low-toned</hw> <pos>adj.</pos> <def>relatively low in volume; soft;
-- of sound; <as>as, making <ex>low-toned</ex> noises with their mouths
that went as an undercurrent of sound</as>. Opposite of
<ant>loud</ant>.</def><br/
<syn><b>Syn. --</b> low, subdued, soft.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low-voltage</ent><br/
<hw>low-voltage</hw> <pos>adj.</pos> <sn>1.</sn>
<fld>(Electricity)</fld> <def>subjected to or capable of operating under
relative low voltage, usually considered as no greater than 250 volts.
Contrasted with <ant>high-voltage</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>low warp loom</ent><br/
<ent>low-warp loom</ent><br/
<mhw><hw>low-warp loom</hw>, <hw>low warp loom</hw></mhw> <pos>n.</pos>
<def>a hand loom in which the warp is carried horizontally; for weaving
tapestry.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Loxodromic</ent><br/
<hw>Lox`o*drom"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
slanting, oblique + <?/ a running, course; cf. F.
<ets>loxodromique</ets>.]</ety> <def>Pertaining to sailing on rhumb
lines; <as>as, <ex>loxodromic</ex> tables</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Loxodromic curve</b></col> <it>or</it>
<col><b>Loxodromic line</b></col></mcol> <fld>(Geom.)</fld>, <cd>a line
on the surface of a sphere, which always makes an equal angle with every
meridian; the rhumb line. It is the line on which a ship sails when her
course is always in the direction of one and the same point of the
compass.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loxodromics</ent><br/
<hw>Lox`o*drom"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
method of sailing on the loxodromic or rhumb line.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loxodromism</ent><br/
<hw>Lox*od"ro*mism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of tracing a loxodromic curve; the act of moving as if in a
loxodromic curve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loxodromy</ent><br/
<hw>Lox*od"ro*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>loxodromic</ets>.]</ety> <def>The science of loxodromics.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loy</ent><br/
<hw>Loy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A long, narrow spade for
stony lands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loyal</ent><br/
<hw>Loy"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>loyal</ets>,
OF. <ets>loial</ets>, <ets>leial</ets>, L. <ets>legalis</ets>, fr.
<ets>lex</ets>, <ets>legis</ets>, law. See <er>Legal</er>, and cf.
<er>Leal</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Faithful to law; upholding the lawful authority;
faithful and true to the lawful government; faithful to the prince or
sovereign to whom one is subject; unswerving in allegiance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Welcome, sir John ! But why come you in arms ? --<br/
To help King Edward in his time of storm,<br/
As every <qex>loyal</qex> subject ought to do.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>True to any person or persons to whom one owes
fidelity, especially as a wife to her husband, lovers to each other, and
friend to friend; constant; faithful to a cause or a
principle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your true and <qex>loyal</qex> wife.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Unhappy both, but <qex>loyal</qex>their loves.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loyalist</ent><br/
<hw>Loy"al*ist</hw>, <pos>n.</pos> <def>A person who adheres to his
sovereign or to the lawful authority; especially, one who maintains his
allegiance to his prince or government, and defends his cause in times
of revolt or revolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loyally</ent><br/
<hw>Loy"al*ly</hw>, <pos>adv.</pos> <def>In a loyal manner;
faithfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loyalness</ent><br/
<hw>Loy"al*ness</hw>, <pos>n.</pos> <def>Loyalty.</def>
<mark>[R.]</mark> <rj><au>Stow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Loyalty</ent><br/
<hw>Loy"al*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>loyaut<eacute/</ets>. See <er>Loyal</er>, and cf.
<er>Legality</er>.]</ety> <def>The state or quality of being loyal;
fidelity to a superior, or to duty, love, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had such <qex>loyalty</qex> to the king as the law
required.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not withstanding all the subtle bait<br/
With which those Amazons his love still craved,<br/
To his one love his <qex>loyalty</qex> he saved.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/<xex>Loyalty</xex> . . . expresses, properly,
that fidelity which one owes according to law, and does not necessarily
include that attachment to the royal person, which, happily, we in
England have been able further to throw into the word.<rdquo/</note>
<rj><au>Trench.</au></rj></p>

<p><syn><b>Syn.</b> -- Allegiance; fealty. See
<er>Allegiance</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lozenge</ent><br/
<hw>Loz"enge</hw> <pr>(l<ocr/z"<ecr/nj)</pr>, <pos>n.</pos> <ety>[F.
<ets>lozange</ets>, <ets>losange</ets>; perh. the same as OF.
<ets>losenge</ets>f flattery, praise, the heraldic sense being the
oldest (cf. E. <ets>hatchment</ets>, <ets>blazon</ets>). Cf.
<er>Losenger</er>, <er>Laudable</er>.]</ety> <sn>1.</sn>
<fld>(Her.)</fld> <sd>(a)</sd> <def>A diamond-shaped figure usually with
the upper and lower angles slightly acute, borne upon a shield or
escutcheon. Cf. <er>Fusil</er>.</def> <sd>(b)</sd> <def>A form of the
escutcheon used by women instead of the shield which is used by
men.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A figure with four equal sides, having two acute and
two obtuse angles; a rhomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything in the form of lozenge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Specifically:</specif> <def>A small cake of sugar
and starch, flavored, and often medicated. -- originally in the form of
a lozenge.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lozenge coach</b></col>, <cd>the coach of a dowager,
having her coat of arms painted on a lozenge.</cd> <mark>[Obs.]</mark>
<au>Walpole.</au> -- <col><b>Lozenge-molding</b></col>
<fld>(Arch.)</fld>, <cd>a kind of molding, used in Norman architecture,
characterized by lozenge-shaped ornaments.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 873 --></p>

<p><ent>Lozenge-shaped</ent><br/
<ent>Lozenged</ent><br/
<mhw>{ <hw>Loz"enged</hw> <pr>(l<ocr/z"<ecr/njd)</pr>,
<hw>Loz"enge-shaped`</hw> <pr>(-sh<amac/pt)</pr> }</mhw>, <pos>a.</pos>
<def>Having the form of a lozenge or rhomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lozenged</qex> panes of a very small latticed window.</q>
<rj><qau>C. Bront<eacute/.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lozengy</ent><br/
<hw>Loz"en*gy</hw> <pr>(-<ecr/n*j<ycr/)</pr>, <pos>a.</pos> <ety>[F.
<ets>losang<eacute/</ets>. See <er>Lozenge</er>.]</ety>
<fld>(Her.)</fld> <def>Divided into lozenge-shaped compartments, as the
field or a bearing, by lines drawn in the direction of the bend
sinister.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>LP</ent><br/
<ent>L-P</ent><br/
<mhw><hw>L-P</hw>, <hw>LP</hw></mhw> <pos>n.</pos>
<ety>[<ets>l</ets>ong-<ets>p</ets>laying.]</ety> <def>a long-playing
phonograph record; designed to be played at 33.3 rpm.</def>
<mark>[Acronym]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>L-plate</ent><br/
<hw>L-plate</hw> <pos>n.</pos> <def>a square plate bearing the letter L
that is attached to both ends of a car to indicate that the driver is a
learner.</def> <mark>[British]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lr</ent><br/
<hw>Lr</hw> <pos>n.</pos> <def>The chemical symbol for
<altname>lawrencium</altname>, a transuranic element of atomic number
103.</def><br/
<syn><b>Syn. --</b> lawrencium.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>LSD</ent><br/
<hw>LSD</hw> <pos>n.</pos> <def>lysergic acid diethylamide, a powerful
hallucinogenic drug.</def> <mark>[Acronym]</mark> <br/
<syn><b>Syn. --</b> lysergic acid diethylamide, acid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ltd.</ent><br/
<hw>Ltd.</hw> <pos>n.</pos> <def>A term attached to the name of a
company that is organized to give its owners limited liability; it
corresponds to <altname>Inc.</altname> in the United States.</def>
<mark>[British]</mark> <br/
<syn><b>Syn. --</b> limited company, Ld.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>LTM</ent><br/
<hw>LTM</hw> <pos>n.</pos> <fld>(Psychology, Neurophysiology)</fld>
<def>long-term memory, the term for the set of neurons and neural
processes responsible for the general store of information remembered
for more than a day.</def><br/
<syn><b>Syn. --</b> long-term memory.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Lu</ent><br/
<hw>Lu</hw> <pr>(l<umac/)</pr>, <pos>n. & v. t.</pos> <def>See
<er>Loo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lu</ent><br/
<hw>Lu</hw>, <pos>n.</pos> <fld>(Chem.)</fld> <def>The chemical symbol
for <er>lutetium</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lubbard</ent><br/
<hw>Lub"bard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lubber</er>.]</ety> <def>A lubber.</def> <mark>[Obs.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubbard</ent><br/
<hw>Lub"bard</hw>, <pos>a.</pos> <def>Lubberly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubber</ent><br/
<hw>Lub"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. dial. Sw.
<ets>lubber</ets>. See <er>Looby</er>, <er>Lob</er>.]</ety> <def>A
heavy, clumsy, or awkward fellow; a sturdy drone; a clown.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lingering <qex>lubbers</qex> lose many a penny.</q>
<rj><qau>Tusser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Land lubber</b></col>, <cd>a name given in contempt by
sailors to a person who lives on land.</cd> -- <col><b>Lubber
grasshopper</b></col> <fld>(Zool.)</fld>, <cd>a large, stout, clumsy
grasshopper; esp., <spn>Brachystola magna</spn>, from the Rocky Mountain
plains, and <spn>Romalea microptera</spn>, which is injurious to orange
trees in Florida.</cd> -- <col><b>Lubber's hole</b></col>
<fld>(Naut.)</fld>, <cd>a hole in the floor of the <ldquo/top,<rdquo/
next the mast, through which sailors may go aloft without going over the
rim by the futtock shrouds. It is considered by seamen as only fit to be
used by lubbers.</cd> <au>Totten.</au> -- <mcol><col><b>Lubber's
line</b></col>, <col><b>Lubber's point</b></col>, <it>or</it>
<col><b>Lubber's mark</b></col></mcol>, <cd>a line or point in the
compass case indicating the head of the ship, and consequently the
course which the ship is steering.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubberly</ent><br/
<hw>Lub"ber*ly</hw>, <pos>a.</pos> <def>Like a lubber; clumsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A great <qex>lubberly</qex> boy.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubberly</ent><br/
<hw>Lub"ber*ly</hw>, <pos>adv.</pos> <def>Clumsily; awkwardly.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubrical</ent><br/
<ent>Lubric</ent><br/
<mhw>{ <hw>Lu"bric</hw> <pr>(?)</pr>, <hw>Lu"bric*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>lubricus</ets>: cf. F.
<ets>lubrique</ets>.]</ety> <sn>1.</sn> <def>Having a smooth surface;
slippery.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lascivious; wanton; lewd.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>lubric</qex> and adulterate age.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricant</ent><br/
<hw>Lu"bri*cant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lubricans</ets>, p. pr. of <ets>lubricare</ets>, See
<er>Lubricate</er>.]</ety> <def>Lubricating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricant</ent><br/
<hw>Lu"bri*cant</hw>, <pos>n.</pos> <def>That which lubricates;
specifically, a substance, as oil, grease, graphite, etc., used for
reducing the friction of the working parts of machinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricate</ent><br/
<hw>Lu"bri*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>lubricatus</ets>, p. p. of <ets>lubricare</ets> to lubricate. See
<er>Lubric</er>.]</ety> <sn>1.</sn> <def>To make smooth or slippery;
<as>as, mucilaginous and saponaceous remedies <ex>lubricate</ex> the
parts to which they are applied</as>.</def> <rj><au>S.
Sharp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Supples, <qex>lubricates</qex>, and keeps in play,<br/
The various movements of this nice machine.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To apply a lubricant to, as oil or tallow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>To reduce social frictions
or difficulties between people, thus making cooperation easier and joint
action smoother.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>To inebriate by supplying with alcoholic
beverages.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>lubricated</ent><br/
<hw>lubricated</hw> <pos>adj.</pos> <def>smeared with oil or grease to
reduce friction.</def><br/
<syn><b>Syn. --</b> greased.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lubrication</ent><br/
<hw>Lu`bri*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
lubricating; the act of making slippery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricator</ent><br/
<hw>Lu"bri*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, lubricates.</def> <ldquo/ <xex>Lubricator</xex> of
the fibers.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A contrivance, as an oil cup, for supplying a
lubricant to machinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricitate</ent><br/
<hw>Lu*bric"i*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Lubricate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricity</ent><br/
<hw>Lu*bric"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lubricitas</ets>: cf. F. <ets>lubricit<eacute/</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Smoothness; freedom from friction; also, property
which diminishes friction; <as>as, the <ex>lubricity</ex> of
oil</as>.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Slipperiness; instability; <as>as, the
<ex>lubricity</ex> of fortune</as>.</def>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lasciviousness; propensity to lewdness; lewdness;
lechery; incontinency.</def> <rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As if wantonness and <qex>lubricity</qex> were essential to that
poem.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubricous</ent><br/
<hw>Lu"bri*cous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lubricus</ets>.]</ety> <def>Lubric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lubrifaction</ent><br/
<ent>Lubrification</ent><br/
<mhw>{ <hw>Lu`bri*fi*ca"tion</hw> <pr>(?)</pr>, <hw>Lu`bri*fac"tion</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>lubricus</ets> lubric
+ <ets>facere</ets> to make.]</ety> <def>The act of lubricating, or
making smooth.</def> <rj><au>Ray. Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucarne</ent><br/
\'d8<hw>Lu`carne"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>lucerna</ets> a lamp. See <er>Luthern</er>.]</ety>
<fld>(Arch.)</fld> <def>A dormer window.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucchese</ent><br/
<hw>Luc*chese"</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos> <ety>[It.
<ets>Lucchese</ets>.]</ety> <def>A native or inhabitant of Lucca, in
Tuscany; in the plural, the people of Lucca.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luce</ent><br/
<hw>Luce</hw> <pr>(l<imac/s)</pr>, <pos>n.</pos> <ety>[OF.
<ets>lus</ets>, L. <ets>lucius</ets> a kind of fish.]</ety>
<fld>(Zool.)</fld> <def>A pike when full grown.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucency</ent><br/
<hw>Lu"cen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of being
lucent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucent</ent><br/
<hw>Lu"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>lucens</ets>,
p. pr. of <ets>lucere</ets> to shine, fr. <ets>lux</ets>,
<ets>lucis</ets>, light.]</ety> <def>Shining; bright; resplendent.</def>
<ldquo/ The sun's <xex>lucent</xex> orb.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucern</ent><br/
<hw>Lu"cern</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymology
uncertain.]</ety> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A sort of hunting dog; -- perhaps from
<xex>Lucerne</xex>, in Switzerland.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>lucerns</qex>, too, or dogs inured to hunt<br/
Beasts of most rapine.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An animal whose fur was formerly much in request (by
some supposed to be the lynx).</def> <altsp>[Written also
<asp>lusern</asp> and <asp>luzern</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>The polecat, mastern, and the richskinned <qex>lucern</qex><br/
I know to chase.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucern</ent><br/
<hw>Lu"cern</hw>, <pos>n.</pos> <ety>[F. <ets>luzerne</ets>.]</ety>
<fld>(Bot.)</fld> <def>A leguminous plant (<spn>Medicago sativa</spn>),
having bluish purple cloverlike flowers, cultivated for fodder; --
called also <altname>alfalfa</altname>.</def> <altsp>[Written also
<asp>lucerne</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucern</ent><br/
<hw>Lu"cern</hw>, <pos>n.</pos> <ety>[L. <ets>lucerna</ets>.]</ety>
<def>A lamp.</def> <mark>[Obs.]</mark> <rj><au>Lydgate.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucernal</ent><br/
<hw>Lu*cer"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lucerna</ets> a lamp.]</ety> <def>Of or pertaining to a
lamp.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lucernal microscope</b></col>, <cd>a form of the
microscope in which the object is illuminated by means of a lamp, and
its image is thrown upon a plate of ground glass connected with the
instrument, or on a screen independent of it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucernaria</ent><br/
\'d8<hw>Lu`cer*na"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
L. <ets>lucerna</ets> a lamp.]</ety> <fld>(Zool.)</fld> <def>A genus of
acalephs, having a bell-shaped body with eight groups of short tentacles
around the margin. It attaches itself by a sucker at the base of the
pedicel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucernarian</ent><br/
<hw>Lu`cer*na"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the Lucernarida.</def> -- <def2><pos>n.</pos>
<def>One of the Lucernarida.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucernarida</ent><br/
\'d8<hw>Lu`cer*nar"i*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Lucernaria</er>.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A
division of acalephs, including <gen>Lucernaria</gen> and allied genera;
-- called also <altname>Calycozoa</altname>.</def> <sd>(b)</sd> <def>A
more extensive group of acalephs, including both the true Lucernarida
and the Discophora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucerne</ent><br/
<hw>Lu"cerne</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<er>Lucern</er>, the plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucid</ent><br/
<hw>Lu"cid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>lucidus</ets>,
fr. <ets>lux</ets>, <ets>lucis</ets>, light. See <er>Light</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Shining; bright; resplendent;
<as>as, the <ex>lucid</ex> orbs of heaven</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lucid</qex>, like a glowworm.</q> <rj><qau>Sir I.
Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A court compact of <qex>lucid</qex> marbles.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Clear; transparent.</def> <ldquo/ <xex>Lucid</xex>
streams.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Presenting a clear view; easily understood;
clear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>lucid</qex> and interesting abstract of the debate.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Bright with the radiance of intellect; not darkened
or confused by delirium or madness; marked by the regular operations of
reason; <as>as, a <ex>lucid</ex> interval</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Luminous; bright; clear; transparent; sane;
reasonable. See <er>Luminous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucidity</ent><br/
<hw>Lu*cid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lucidit<eacute/</ets>. See <er>Lucid</er>.]</ety> <def>The quality
or state of being lucid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucidly</ent><br/
<hw>Lu"cid*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a lucid
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucidness</ent><br/
<hw>Lu"cid*ness</hw>, <pos>n.</pos> <def>The quality of being lucid;
lucidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucifer</ent><br/
<hw>Lu"ci*fer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., bringing light,
<pos>n.</pos>, the morning star, fr. <ets>lux</ets>, <ets>lucis</ets>,
light + <ets>ferre</ets> to bring.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The planet Venus, when appearing as the morning
star; -- applied in Isaiah by a metaphor to a king of Babylon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How art thou fallen from heaven, O <qex>Lucifer</qex>, son of the
morning! how art thou cut down to the ground which didst weaken the
nations!</q> <rj><qau>Is. xiv. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tertullian and Gregory the Great understood this passage of Isaiah
in reference to the fall of Satan; in consequence of which the name
<qex>Lucifer</qex> has since been applied to Satan.</q>
<rj><qau>Kitto.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, Satan.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How wretched<br/
Is that poor man that hangs on princes' favors! . . . <br/
When he falls, he falls like <qex>Lucifer</qex>,<br/
Never to hope again.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A match{1} made of a sliver of wood tipped with a
combustible substance, and ignited by friction; -- called also
<altname>lucifer match</altname>, and <altname>locofoco</altname>, now
most commonly referred to as a <altname>friction match</altname>. See
<er>Locofoco</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A genus of free-swimming macruran
Crustacea, having a slender body and long appendages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luciferian</ent><br/
<hw>Lu`ci*fe"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of
or pertaining to Lucifer; having the pride of Lucifer; satanic;
devilish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the Luciferians or their
leader.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luciferian</ent><br/
<hw>Lu`ci*fe"ri*an</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One
of the followers of Lucifer, bishop of Cagliari, in the fourth century,
who separated from the orthodox churches because they would not go as
far as he did in opposing the Arians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luciferin</ent><br/
<hw>Lu*cif"er*in</hw> <pr>(l<oomac/*s<icr/f"<etil/r*<icr/n)</pr>,
<pos>n.</pos> <fld>(Biochem.)</fld> <def>any of several substances found
in luminescent organisms (such as the firefly, <spn>Photinus
pyralis</spn>) which, when oxidized, produces an almost heatless light.
It was first isolated from fireflies, and is the source of the firefly
luminescence. See also <styp><er>firefly luciferin</er></styp></def><br/
[<source>PJC</source>]</p>

<p><ent>Luciferase</ent><br/
<hw>Lu*cif"er*ase</hw> <pr>(l<oomac/*s<icr/f"<etil/r*<amac/s)</pr>,
<pos>n.</pos> <fld>(Biochem.)</fld> <def>an enzyme which catalyzes the
oxidation of luciferin, thereby producing bioluminescence.</def><br/
[<source>PJC</source>]</p>

<p><ent>Luciferous</ent><br/
<hw>Lu*cif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lucifer</er>.]</ety> <def>Giving light; affording light or means of
discovery.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luciferously</ent><br/
<hw>Lu*cif"er*ous*ly</hw>, <pos>adv.</pos> <def>In a luciferous
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucific</ent><br/
<hw>Lu*cif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lucificus</ets>; <ets>lux</ets>, <ets>lucis</ets>, light +
<ets>facere</ets> to make.]</ety> <def>Producing light.</def>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luciform</ent><br/
<hw>Lu"ci*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>lux</ets>,
<ets>lucis</ets>, light = <ets>-form</ets>.]</ety> <def>Having, in some
respects, the nature of light; resembling light.</def>
<rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucifrian</ent><br/
<hw>Lu*cif"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Luciferian;
satanic.</def> <mark>[Obs.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucimeter</ent><br/
<hw>Lu*cim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lux</ets>, <ets>lucis</ets>, light + <ets>-meter</ets>.]</ety>
<def>an instrument for measuring the intensity of light; a
photometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucite</ent><br/
<hw>Lu"cite</hw> <pr>(l<oomac/"s<imac/t)</pr>, <pos>prop. n.</pos>
<def>A brand name for a transparent plastic based on methyl methacrylate
esters; the term is often used generically to refer to any similar
transparent plastic. It is sold in various forms, including rigid sheets
which may be used as a substitute for glass in windows.</def>
<mark>[Trademark]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Luck</ent><br/
<hw>Luck</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Akin to D.
<ets>luk</ets>, <ets>geluk</ets>, G. <ets>gl<uum/ck</ets>, Icel.
<ets>lukka</ets>, Sw. <ets>lycka</ets>, Dan. <ets>lykke</ets>, and perh.
to G. <ets>locken</ets> to entice. Cf. 3d <er>Gleck</er>.]</ety>
<def>That which happens to a person; an event, good or ill, affecting
one's interests or happiness, and which is deemed casual; a course or
series of such events regarded as occurring by chance; chance; hap;
fate; fortune; often, one's habitual or characteristic fortune; <as>as,
good, bad, ill, or hard <ex>luck</ex></as>. <xex>Luck</xex> is often
used by itself to mean <xex>good luck</xex>; <as>as, <ex>luck</ex> is
better than skill; a stroke of <ex>luck</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou dost play with him at any game,<br/
Thou art sure to lose; and of that natural <qex>luck</qex>,<br/
He beats thee 'gainst the odds.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luck penny</b></col>, <cd>a small sum given back for luck
to one who pays money.</cd> <mark>[Prov. Eng.]</mark> -- <col><b>To be
in luck</b></col>, <cd>to receive some good, or to meet with some
success, in an unexpected manner, or as the result of circumstances
beyond one's control; to be fortunate.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luckily</ent><br/
<hw>Luck"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From
<er>Lucky</er>.]</ety> <def>In a lucky manner; by good fortune;
fortunately; -- used in a good sense; <as>as, they <ex>luckily</ex>
escaped injury</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luckiness</ent><br/
<hw>Luck"i*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state or
quality of being lucky; <as>as, the <ex>luckiness</ex> of a man or of an
event</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Good fortune; favorable issue or event.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luckless</ent><br/
<hw>Luck"less</hw>, <pos>a.</pos> <def>Being without luck; unpropitious;
unfortunate; unlucky; meeting with ill success or bad fortune; <as>as, a
<ex>luckless</ex> gamester; a <ex>luckless</ex> maid.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prayers made and granted in a <qex>luckless</qex> hour.</q>
<rj><qau>Dryden.</qau></rj></p>

<p>-- <wordforms><wf>Luck"less*ly</wf>, <pos>adv.</pos> --
<wf>Lock"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucknow</ent><br/
<hw>Lucknow</hw> <pos>n.</pos> <sn>1.</sn> <def>A city in India, the
site of the Indian Mutiny (1857) when the British were
beseiged.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lucky</ent><br/
<hw>Luck"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Luckier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Luckiest</adjf>.]</amorph> <sn>1.</sn> <def>Favored by luck;
fortunate; meeting with good success or good fortune; -- said of
persons; <as>as, a <ex>lucky</ex> adventurer</as>.</def> <ldquo/
<xex>Lucky</xex> wight.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Producing, or resulting in, good by chance, or
unexpectedly; favorable; auspicious; fortunate; <as>as, a <ex>lucky</ex>
mistake; a <ex>lucky</ex> cast; a <ex>lucky</ex> hour.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>We doubt not of a fair and <qex>lucky</qex> war.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Successful; fortunate; prosperous;
auspicious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucky proach</ent><br/
<hw>Luck`y proach"</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Fatherlasher</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucrative</ent><br/
<hw>Lu"cra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lucrativus</ets>, fr. <ets>lucrari</ets> to gain, fr.
<ets>lucrum</ets> gain: cf. F. <ets>lucratif</ets>. See
<er>Lucre</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Yielding lucre; gainful; profitable; making increase
of money or goods; <as>as, a <ex>lucrative</ex> business or
office</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The trade of merchandise being the most <qex>lucrative</qex>, may
bear usury at a good rate.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Greedy of gain.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such diligence as the most part of our <qex>lucrative</qex>
lawyers do use, in deferring and prolonging of matters and actions from
term to term.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucratively</ent><br/
<hw>Lu"cra*tive*ly</hw>, <pos>adv.</pos> <def>In a lucrative
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucre</ent><br/
<hw>Lu"cre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>lucre</ets>,
L. <ets>lucrum</ets>.]</ety> <def>Gain in money or goods; profit;
riches; -- often in an ill sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lust of <qex>lucre</qex> and the dread of death.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucriferous</ent><br/
<hw>Lu*crif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lucrum</ets> gain +<ets>-ferous</ets>.]</ety> <def>Gainful;
profitable.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucrific</ent><br/
<hw>Lu*crif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lucrificus</ets>; <ets>lucrum</ets> gain + <ets>facere</ets> to
make.]</ety> <def>Producing profit; gainful.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luctation</ent><br/
<hw>Luc*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>luctatio</ets>, fr. <ets>luctari</ets> to wrestle, strive.]</ety>
<def>Effort to overcome in contest; struggle; endeavor.</def>
<mark>[R.]</mark> <rj><au>Farindon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luctual</ent><br/
<hw>Luc"tu*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luctus</ets> mourning, sorrow, fr. <ets>lugere</ets>, fr.
<ets>luctum</ets>, to mourn.]</ety> <def>Producing grief;
saddening.</def> <mark>[Obs.]</mark> <rj><au>Sir G. Buck.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucubrate</ent><br/
<hw>Lu"cu*brate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lucubrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lucubrated</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>lucubratus</ets>, p. p. of <ets>lucubrare</ets> to work by
lamplight, fr. <ets>lux</ets> light. See <er>Light</er>,
<pos>n.</pos>]</ety> <def>To study by candlelight or a lamp; to study by
night.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucubrate</ent><br/
<hw>Lu"cu*brate</hw>, <pos>v. t.</pos> <def>To elaborate, perfect, or
compose, by night study or by laborious endeavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucubration</ent><br/
<hw>Lu`cu*bra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[l.
<ets>lucubratio</ets>;cf. F. <ets>lucubration</ets>.]</ety> <sn>1.</sn>
<def>The act of lucubrating, or studying by candlelight; nocturnal
study; meditation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After long <qex>lucubration</qex> I have hit upon such an
expedient.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is composed by night; that which is
produced by meditation in retirement; hence (loosely) any literary
composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy <qex>lucubrations</qex> have been perused by several of our
friends.</q> <rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucubrator</ent><br/
<hw>Lu"cu*bra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who studies
by night; also, one who produces lucubrations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucubratory</ent><br/
<hw>Lu"cu*bra*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lucubratorius</ets>.]</ety> <def>Composed by candlelight, or by
night; of or pertaining to night studies; laborious or
painstaking.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucule</ent><br/
<hw>Lu"cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. fr. L.
<ets>lux</ets>, <ets>lucis</ets>, light.]</ety> <fld>(Astron.)</fld>
<def>A spot or fleck on the sun brighter than the surrounding
surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luculent</ent><br/
<hw>Lu"cu*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luculentus</ets>, from <ets>lux</ets>, <ets>lucis</ets>,
light.]</ety> <sn>1.</sn> <def>Lucid; clear; transparent.</def>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Clear; evident; luminous.</def> <ldquo/ Most
<xex>luculent</xex> testimonies.<rdquo/ <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Bright; shining in beauty.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Most debonair and <qex>luculent</qex> lady.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luculently</ent><br/
<hw>Lu"cu*lent*ly</hw>, <pos>adv.</pos> <def>In a luculent manner;
clearly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucullite</ent><br/
<hw>Lu*cul"lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<etsep>Lucullus</etsep>, a Roman consul, famous for his great wealth and
luxury: cf. F. <ets>lucullite</ets>.]</ety> <fld>(Min.)</fld> <def>A
variety of black limestone, often polished for ornamental
purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lucuma</ent><br/
\'d8<hw>Lu*cu"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An American genus of sapotaceous trees bearing sweet and edible
fruits.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Lucuma mammosum</spn> is called <xex>natural
marmalade</xex> in the West Indies; <spn>Lucuma Caimito</spn>, of Peru,
furnishes a delicious fruit called <prod>lucuma</prod> and
<prod>caimito</prod>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luddite</ent><br/
<hw>Lud"dite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of a number of
riotous persons in England, who for six years (1811-17) tried to prevent
the use of labor-saving machinery by breaking it, burning factories,
etc.; -- so called from <person>Ned <etsep>Lud</etsep></person>, a
half-witted man who some years previously had broken stocking
frames.</def> <rj><au>J. & H. Smith.</au> <au>H.
Martineau.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludibrious</ent><br/
<hw>Lu*dib"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ludibrium</ets> mockery, derision, from <ets>ludere</ets> to play,
sport.]</ety> <def>Sportive; ridiculous; wanton.</def>
<mark>[Obs.]</mark> <rj><au>Tooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludibund</ent><br/
<hw>Lu"di*bund</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ludibundus</ets>.]</ety> <def>Sportive.</def> <mark>[Obs.]</mark>
-- <wordforms><wf>Lu"di*bund*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludicrous</ent><br/
<hw>Lu"di*crous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ludicrus</ets>, or <ets>ludicer</ets>, from <ets>ludus</ets> play,
sport, fr. <ets>ludere</ets> to play.]</ety> <sn>1.</sn> <def>Adapted to
excite laughter, without scorn or contempt; sportive.</def>
<rj><au>Broome.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A chapter upon German rhetoric would be in the same
<qex>ludicrous</qex> predicament as Van Troil's chapter on the snakes of
Iceland, which delivers its business in one summary sentence,
announcing, that snakes in Iceland -- there are none.</q> <rj><qau>De
Quincey.</qau></rj></p>

<p><sn>2.</sn> <def>Ridiculously absurd.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Laughable; sportive; burlesque; comic; droll;
ridiculous.</syn> <usage> -- <er>Ludicrous</er>, <er>Laughable</er>,
<er>Ridiculous</er>. We speak of a thing as <xex>ludicrous</xex> when it
tends to produce laughter; as <xex>laughable</xex> when the impression
is somewhat stronger; as <xex>ridiculous</xex> when more or less
contempt is mingled with the merriment created.</usage></p>

<p>-- <wordforms><wf>Lu"di*crous*ly</wf>, <pos>adv.</pos> --
<wf>Lu"di*crous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludification</ent><br/
<hw>Lu`di*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ludificatio</ets>, fr. <ets>ludificare</ets> to make sport of;
<ets>ludus</ets> sport + <ets>-ficare</ets> (in comp.) to make. See
<er>-fy</er>.]</ety> <def>The act of deriding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludificatory</ent><br/
<hw>Lu*dif"i*ca*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ludificatorius</ets>.]</ety> <def>Making sport; tending to excite
derision.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludlamite</ent><br/
<hw>Lud"lam*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after
<person>Mr. <etsep>Ludlam</etsep></person>, of London.]</ety>
<fld>(Min.)</fld> <def>A mineral occurring in small, green, transparent,
monoclinic crystals. It is a hydrous phosphate of iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludlow group</ent><br/
<hw>Lud"low group`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Geol.)</fld>
<def>A subdivision of the British Upper Silurian lying below the Old Red
Sandstone; -- so named from the <etsep>Ludlow</etsep>, in Western
England. See the <xex>Chart</xex> of <er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ludwigite</ent><br/
<hw>Lud"wig*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after the
chemist <persfn><etsep>Ludwig</etsep></persfn>.]</ety> <fld>(Min.)</fld>
<def>A borate of iron and magnesia, occurring in fibrous masses of a
blackish green color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lues</ent><br/
\'d8<hw>Lu"es</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Med.)</fld> <sn>1.</sn> <def>Disease, especially of a contagious
kind.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>syphilis; -- called also <altname>Lues
venerea</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Lues venerea</b></col>, <cd>syphilis; -- called also
simply <altname>lues</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luff</ent><br/
<hw>Luff</hw> <pr>(l<ucr/f)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lof</ets>, prob. a sort of timber by which the course of a ship was
directed, perh. a sort of paddle; cf. D. <ets>loef</ets> luff,
<ets>loeven</ets> to luff. The word is perh. akin to E.
<ets>glove</ets>. Cf. <er>Aloof</er>.]</ety> <fld>(Naut.)</fld>
<sd>(a)</sd> <def>The side of a ship toward the wind.</def> <sd>(b)</sd>
<def>The act of sailing a ship close to the wind.</def> <sd>(c)</sd>
<def>The roundest part of a ship's bow.</def> <sd>(d)</sd> <def>The
forward or weather leech of a sail, especially of the jib, spanker, and
other fore-and-aft sails.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luff tackle</b></col>, <cd>a purchase composed of a
double and single block and fall, used for various purposes.</cd>
<au>Totten.</au> -- <col><b>Luff upon luff</b></col>, <cd>a luff tackle
attached to the fall of another luff tackle.</cd> <au>R. H. Dana,
Jr.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 874 --></p>

<p><ent>Luff</ent><br/
<hw>Luff</hw> <pr>(l<ucr/f)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Luffed</conjf> <pr>(l<ucr/ft)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Luffing</conjf>.]</vmorph> <sn>1.</sn>
<fld>(Naut.)</fld> <def>To turn the head of a vessel toward the wind; to
sail nearer the wind; to turn the tiller so as to make the vessel sail
nearer the wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To flutter or shake from being
aligned close to the direction of the wind; -- said of a sail.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>To luff round</b></col>, <it>or</it> <col><b>To
luff alee</b></col></mcol>, <cd>to make the extreme of this movement,
for the purpose of throwing the ship's head into the wind.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luffer</ent><br/
<hw>Luf"fer</hw> <pr>(l<ucr/f"f<etil/r)</pr>, <pos>n.</pos>
<fld>(Arch.)</fld> <def>See <er>Louver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lug</ent><br/
<hw>Lug</hw> <pr>(l<ucr/g)</pr>, <pos>n.</pos> <ety>[Sw. <ets>lugg</ets>
the forelock.]</ety> <sn>1.</sn> <def>The ear, or its lobe.</def>
<mark>[Scot. & Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which projects like an ear, esp. that by which
anything is supported, carried, or grasped, or to which a support is
fastened; an ear; <as>as, the <ex>lugs</ex> of a kettle; the
<ex>lugs</ex> of a founder's flask; the <ex>lug</ex> (handle) of a
jug.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>A projecting piece to which
anything, as a rod, is attached, or against which anything, as a wedge
or key, bears, or through which a bolt passes, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Harness)</fld> <def>The leather loop or ear by
which a shaft is held up.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>The lugworm.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A man; sometimes implying clumsiness.</def>
<mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><cs><col><b>Lug bolt</b></col> <fld>(Mach.)</fld>, <cd>a bolt
terminating in a long, flat extension which takes the place of a head; a
strap bolt.</cd> -- <col><b>Lug nut</b></col> <fld>(Mach.)</fld>, <cd>a
large nut fitting a heavy bolt; -- used especially of the nuts used to
attach wheels to vehicles.</cd> -- <col><b>Lug wrench</b></col>
<fld>(Mach.)</fld>, <cd>a wrench used to tighten or loosen lug nuts,
usually a steel rod having a hexagonally shaped socket which fits
closely over the lug nut; sometimes in the shape of a cross, having
several such sockets, one at the end of each arm, to accommodate nuts of
different sizes.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lug</ent><br/
<hw>Lug</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lugged</conjf> <pr>(l<ucr/gd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lugging</conjf> <pr>(l<ucr/g"g<icr/ng)</pr>.]</vmorph> <ety>[OE.
<ets>luggen</ets>, Sw. <ets>lugga</ets> to pull by the hair, fr.
<ets>lugg</ets> the forelock.]</ety> <def>To pull with force; to haul;
to drag along; to carry with difficulty, as something heavy or
cumbersome.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They must divide the image among them, and so <qex>lug</qex> off
every one his share.</q> <rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lug</ent><br/
<hw>Lug</hw>, <pos>v. i.</pos> <def>To move slowly and
heavily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lug</ent><br/
<hw>Lug</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of lugging; <as>as,
a hard <ex>lug</ex></as>; that which is lugged; <as>as, the pack is a
heavy <ex>lug</ex></as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything which moves slowly.</def>
<mark>[Obs.]</mark> <rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lug</ent><br/
<hw>Lug</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety> <sn>1.</sn>
<def>A rod or pole.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A measure of length, being 16<frac12/ feet; a rod,
pole, or perch.</def> <mark>[Obs.]</mark> <ldquo/ Eight <xex>lugs</xex>
of ground.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Chimney lug</b></col>, <it>or</it> <col><b>Lug
pole</b></col></mcol>, <cd>a pole on which a kettle is hung over the
fire, either in a chimney or in the open air.</cd> <mark>[Local,
U.S.]</mark> <rj><au>Whittier.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luganda</ent><br/
<hw>Luganda</hw> <pos>n.</pos> <def>the language of the Buganda; spoken
in Uganda.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>luge</ent><br/
<hw>luge</hw> <pr>(l<oomac/zh)</pr>, <pos>n.</pos> <def>a racing sled
for one or two people; it is raced down a chute of packed snow or ice,
and the occupant(s) lie down on it with feet in the direction of
motion.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>luger</ent><br/
<hw>lug"er</hw> <pr>(l<oomac/zh"<etil/r)</pr>, <pos>n.</pos>
<def>someone who races the luge.</def><br/
<syn><b>Syn. --</b> slider.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luggage</ent><br/
<hw>Lug"gage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From 4th
<er>Lug</er>.]</ety> <def>That which is lugged; anything cumbrous and
heavy to be carried; especially, a traveler's trunks, baggage, etc., or
their contents.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am gathering up my <qex>luggage</qex>, and preparing for my
journey.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What do you mean,<br/
To dote thus on such <qex>luggage</qex>!</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Plunder; baggage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luggage van</b></col>, <cd>a vehicle for carrying
luggage; a railway car, or compartment of a car, for carrying
luggage.</cd> <mark>[Eng.]</mark> -- <col><b>Luggage
compartment</b></col>, <cd>the compartment in a train, bus or other
vehicle designed for storage of luggage during a journey. Separate from
the <contr>passenger compartment</contr>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lugger</ent><br/
<hw>Lug"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
small vessel having two or three masts, and a running bowsprit, and
carrying lugsails. See <xex>Illustration</xex> in Appendix.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lugger</ent><br/
<hw>Lug"ger</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>An Indian falcon
(<spn>Falco jugger</spn>), similar to the European lanner and the
American prairie falcon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lugmark</ent><br/
<hw>Lug"mark`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Lug</er>
an ear.]</ety> <def>A mark cut into the ear of an animal to identify it;
an earmark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lugsail</ent><br/
<hw>Lug"sail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
square sail bent upon a yard that hangs obliquely to the mast and is
raised or lowered with the sail.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lugubrious</ent><br/
<hw>Lu*gu"bri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lugubris</ets>, fr. <ets>lugere</ets> to mourn; cf. Gr.
<grk>lygro`s</grk> sad, Skr. <ets>ruj</ets> to break.]</ety>
<def>Mournful; indicating sorrow, often ridiculously or feignedly;
doleful; woful; pitiable; <as>as, a whining tone and a
<ex>lugubrious</ex> look</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Crossbones, scythes, hourglasses, and other <qex>lugubrious</qex>
emblems of mortality.</q> <rj><qau>Hawthorne.</qau></rj></p>

<p>-- <wordforms><wf>Lu*gu"bri*ous*ly</wf>, <pos>adv.</pos> --
<wf>Lu*gu"bri*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>lugubriousness</ent><br/
<hw>lu*gu"bri*ous*ness</hw> <pos>n.</pos> <sn>1.</sn> <def>excessive
sadness and mournfulness.</def><br/
<syn><b>Syn. --</b> gloominess.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lugworm</ent><br/
<hw>Lug"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>1st lug</ets>
+ <ets>worm</ets>.]</ety> <fld>(Zool.)</fld> <def>A large marine annelid
(<spn>Arenicola marina</spn>) having a row of tufted gills along each
side of the back. It is found burrowing in sandy beaches, both in
America and Europe, and is used for bait by European fishermen. Called
also <altname>lobworm</altname>, and
<altname>baitworm</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luke</ent><br/
<hw>Luke</hw> <pr>(l<umac/k)</pr>, <pos>a.</pos> <ety>[Prob. fr.
<ets>lew</ets>, perh. influenced by AS. <ets>wl<ae/c</ets> warm,
lukewarm, remiss. Cf. Lew.]</ety> <def>Moderately warm; not hot; tepid;
lukewarm.</def> -- <wordforms><wf>Luke"ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Nine penn'orth o'brandy and water <qex>luke</qex>.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lukewarm</ent><br/
<hw>Luke"warm`</hw> <pr>(l<umac/k"w<add/rm`)</pr>, <pos>a.</pos>
<ety>[See <er>Luke</er>.]</ety> <sn>1.</sn> <def>Moderately warm;
neither cold nor hot; tepid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not ardent; not zealous; cool; indifferent.</def>
<ldquo/ <xex>Lukewarm</xex> blood.<rdquo/ <au>Spenser.</au> <ldquo/
<xex>Lukewarm</xex> patriots.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An obedience so <qex>lukewarm</qex> and languishing that it merits
not the name of passion.</q> <rj><qau>Dryden.</qau></rj></p>

<p>-- <wordforms><wf>Luke"warm`ly</wf>, <pos>adv.</pos> --
<wf>Luke"warm`ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lull</ent><br/
<hw>Lull</hw> <pr>(l<ucr/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lulled</conjf> <pr>(l<ucr/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lulling</conjf>.]</vmorph> <ety>[Akin to OD.
<ets>lullen</ets> to sing to sleep, G. <ets>lullen</ets>, Dan.
<ets>lulle</ets>, Sw. <ets>lulla</ets>; all of imitative origin. Cf.
<er>Loll</er>, <er>Lollard</er>.]</ety> <def>To cause to rest by
soothing influences; to compose; to calm; to soothe; to quiet.</def>
<ldquo/ To <xex>lull</xex> him soft asleep.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such sweet compulsion doth in music lie,<br/
To <qex>lull</qex> the daughters of necessity.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lull</ent><br/
<hw>Lull</hw>, <pos>v. i.</pos> <def>To become gradually calm; to
subside; to cease or abate for a time; <as>as, the storm
<ex>lulls</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lull</ent><br/
<hw>Lull</hw>, <pos>n.</pos> <sn>1.</sn> <def>The power or quality of
soothing; that which soothes; a lullaby.</def> <mark>[R.]</mark>
<rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A temporary cessation of storm or
confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lullaby</ent><br/
<hw>lull"a*by</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Lull</er>,
<pos>v. t.</pos> ]</ety> <sn>1.</sn> <def>A song to quiet babes or lull
them to sleep; that which quiets.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Good night; good-by.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luller</ent><br/
<hw>Lull"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, lulls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lullingly</ent><br/
<hw>Lull"ing*ly</hw>, <pos>adv.</pos> <def>In a lulling manner;
soothingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lum</ent><br/
<hw>Lum</hw> <pr>(l<ucr/m)</pr>, <pos>n.</pos> <ety>[W.
<ets>llumon</ets> chimney, <ets>llum</ets> that shoots up or ends in a
point.]</ety> <sn>1.</sn> <def>A chimney.</def> <mark>[Prov. Eng. &
Scot.]</mark> <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ventilating chimney over the shaft of a
mine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A woody valley; also, a deep pool.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumachella</ent><br/
<ent>Lumachel</ent><br/
<mhw>{ <hw>Lu"ma*chel</hw> <pr>(?)</pr>, \'d8<hw>Lu`ma*chel"la</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[F. <ets>lumachelle</ets>, It.
<ets>lumachella</ets>, fr. <ets>lamachella</ets> a little snail, dim. of
<ets>lumaca</ets> a snail, fr. L. <ets>limax</ets>,
<ets>-acis</ets>.]</ety> <fld>(Min.)</fld> <def>A grayish brown
limestone, containing fossil shells, which reflect a beautiful play of
colors. It is also called <altname>fire marble</altname>, from its fiery
reflections.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbaginous</ent><br/
<hw>Lum*bag"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to lumbago.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbago</ent><br/
<hw>Lum*ba"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>lumbus</ets> loin. See <er>Lumbar</er>.]</ety> <fld>(Med.)</fld>
<def>A rheumatic pain in the loins and the small of the back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbal</ent><br/
<ent>Lumbar</ent><br/
<mhw>{ <hw>Lum"bar</hw> <pr>(?)</pr>, <hw>Lum"bal</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>lumbus</ets> loin. See
<er>Loin</er>.]</ety> <fld>(Anat.)</fld> <def>Of, pertaining to, or
near, the loins; <as>as, the <ex>lumbar</ex> arteries</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lumbar region</b></col> <fld>(Anat.)</fld>, <cd>the
region of the loin; specifically, a region between the hypochondriac and
iliac regions, and outside of the umbilical region.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumber</ent><br/
<hw>Lum"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr.
<ets>Lombard</ets>, the Lombards being the money lenders and pawnbrokers
of the Middle Ages. A <ets>lumber</ets> room was, according to Trench,
originally a <etsep>Lombard</etsep> room, or room where the Lombard
pawnbroker stored his pledges. See <er>Lombard</er>.]</ety> <sn>1.</sn>
<def>A pawnbroker's shop, or room for storing articles put in pawn;
hence, a pledge, or pawn.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They put all the little plate they had in the <qex>lumber</qex>,
which is pawning it, till the ships came.</q> <rj><qau>Lady
Murray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Old or refuse household stuff; things cumbrous, or
bulky and useless, or of small value.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Timber sawed or split into the form of beams,
joists, boards, planks, staves, hoops, etc.; esp., that which is smaller
than heavy timber.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lumber kiln</b></col>, <cd>a room in which timber or
lumber is dried by artificial heat.</cd> <mark>[U.S.]</mark> --
<col><b>Lumber room</b></col>, <cd>a room in which unused furniture or
other lumber is kept.</cd> <mark>[U.S.]</mark> -- <col><b>Lumber
wagon</b></col>, <cd>a heavy rough wagon, without springs, used for
general farmwork, etc.</cd> -- <col><b>dimensional lumber</b></col>,
<cd>lumber, usually of pine, which is sold as beams or planks having a
specified nominal cross-section, usually in inches, such a
<examp>two-by-four</examp>, <examp>two-by-six</examp>,
<examp>four-by-four</examp>, etc.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lumber</ent><br/
<hw>Lum"ber</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lumbered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lumbering</conjf>.]</vmorph> <sn>1.</sn> <def>To heap together in
disorder.</def> <ldquo/ Stuff <xex>lumbered</xex> together.<rdquo/
<rj><au>Rymer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fill or encumber with lumber; <as>as, to
<ex>lumber</ex> up a room</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumber</ent><br/
<hw>Lum"ber</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To move heavily, as
if burdened.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. dial. Sw. <ets>lomra</ets> to resound.]</ety>
<def>To make a sound as if moving heavily or clumsily; to rumble.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cut logs in the forest, or prepare timber for
market.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumberer</ent><br/
<hw>Lum"ber*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One employed in
lumbering, cutting, and getting logs from the forest for lumber; a
lumberman.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Lumberers</qex> have a notion that he (the woodpecker) is
harmful to timber.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbering</ent><br/
<hw>Lum"ber*ing</hw>, <pos>n.</pos> <def>The business of cutting or
getting timber or logs from the forest for lumber.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>lumberjack</ent><br/
<hw>lum"ber*jack`</hw> <pos>n.</pos> <sn>1.</sn> <def>a person who works
at lumbering; a lumberman.</def><br/
<syn><b>Syn. --</b> lumberman, timberman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The grey jay.</def>
<mark>[Canadian]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Lumberman</ent><br/
<hw>Lum"ber*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lumbermen</plw> <pr>(<?/)</pr>.</plu> <def>One who is engaged in
lumbering as a business or employment.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumber State</ent><br/
<hw>Lum"ber State</hw>. <def>Maine; -- a nickname.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lumbosacral</ent><br/
<hw>Lum`bo*sa"cral</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lumbus</ets> loin + E. <ets>sacral</ets>.]</ety> <fld>(Anat.)</fld>
<def>Of or pertaining to the loins and sacrum; <as>as, the
<ex>lumbosacral</ex> nerve, a branch of one of the lumber nerves which
passes over the sacrum</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbric</ent><br/
<hw>Lum"bric</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lumbricus</ets>.]</ety> <fld>(Zool.)</fld> <def>An earthworm, or a
worm resembling an earthworm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbrical</ent><br/
<hw>Lum"bric*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lombrical</ets>. See <er>Lumbric</er>.]</ety> <fld>(Anat.)</fld>
<def>Resembling a worm; <as>as, the <ex>lumbrical</ex> muscles of the
hands of the hands and feet</as>.</def> -- <def2><pos>n.</pos> <def>A
lumbrical muscle.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbriciform</ent><br/
<hw>Lum*bric"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lumbricus</ets> worm + <ets>-form</ets>.]</ety> <fld>(Zool.)</fld>
<def>Resembling an earthworm; vermiform.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbricoid</ent><br/
<hw>Lum"bri*coid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lumbricus</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Like an earthworm; belonging to the genus <gen>Lumbricus</gen>, or
family <fam>Lumbricid<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumbricus</ent><br/
\'d8<hw>Lum"bri*cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Lumbric</er>.]</ety> <fld>(Zool.)</fld> <def>A genus of annelids,
belonging to the Oligoch<ae/ta, and including the common earthworms. See
<er>Earthworm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumen</ent><br/
\'d8<hw>Lu"men</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl. L.
<plw>Lumina</plw> <pr>(#)</pr>, E. <plw>Lumens</plw> <pr>(#)</pr></plu>.
<ety>[L., light, an opening for light.]</ety> <sn>1.</sn>
<fld>(Photom.)</fld> <sd>(a)</sd> <def>A unit of illumination, being the
amount of illumination of a unit area of spherical surface, due to a
light of unit intensity placed at the center of the sphere.</def>
<sd>(b)</sd> <def>A unit of light flux, being the flux through one
square meter of surface the illumination of which is uniform and of unit
brightness.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>An opening, space, or cavity,
esp. a tubular cavity; a vacuole.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Luminant</ent><br/
<hw>Lu"mi*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Luminous.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luminary</ent><br/
<hw>Lu"mi*na*ry</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it></plu> <plw>Luminaries</plw> <pr>(#)</pr>, <ety>[F.
<ets>luminaire</ets>, L. <ets>luminare</ets> a light or lamp, which was
lighted in the churches, a luminary, fr. <ets>lumen</ets>,
<ets>luminis</ets>, light, fr. <ets>lucere</ets> to be light, to shine,
<ets>lux</ets>, <ets>lucis</ets>, light. See <er>Light</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Any body that gives light, especially one of the
heavenly bodies.</def> <ldquo/ Radiant <xex>luminary</xex>.<rdquo/
<rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the great <qex>luminary</qex> . . . <br/
Dispenses light from far.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who illustrates any subject, or enlightens
mankind; <as>as, Newton was a distinguished
<ex>luminary</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luminate</ent><br/
<hw>Lu"mi*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>luminatus</ets>, p. p. of <ets>luminare</ets> to illumine, fr.
<ets>lumen</ets> light. See <er>Limn</er>.]</ety> <def>To
illuminate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumination</ent><br/
<hw>Lu`mi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Illumination.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumine</ent><br/
<hw>Lu"mine</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To illumine.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luminescence</ent><br/
<hw>Lu`mi*nes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Luminescent</er>.]</ety> <sn>1.</sn> <fld>(Physics)</fld> <def>Any
emission of light not ascribable directly to incandescence, and
therefore occurring at low temperatures, as in phosphorescence and
fluorescence or other luminous radiation resulting from vital processes,
chemical action, friction, solution, or the influence of light or of
ultraviolet or cathode rays, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The faculty or power
of producing light by biological processes, as in the firefly and
glowworm. Also called <altname>bioluminescence</altname>.</def>
<sd>(b)</sd> <def>The light produced by biological or biochemical
processes. Also called <altname>bioluminescence</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Luminescent</ent><br/
<hw>Lu`mi*nes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luminare</ets> to illuminate + <ets>-escent</ets>.]</ety>
<fld>(Physics)</fld> <def>Shining with a light due to any of the various
causes which produce luminescence.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Luminiferous</ent><br/
<hw>Lu`mi*nif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lumen</ets> light + <ets>-ferous</ets>.]</ety> <def>Producing
light; yielding light; transmitting light; <as>as, the
<ex>luminiferous</ex> ether</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luminosity</ent><br/
<hw>Lu`mi*nos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being luminous; luminousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luminous</ent><br/
<hw>Lu"mi*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luminosus</ets>, fr. <ets>lumen</ets> light: cf. F.
<ets>lumineux</ets>. See <er>Luminary</er>,
<er>Illuminate</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Shining; emitting or reflecting light; brilliant;
bright; <as>as, the is a <ex>luminous</ex> body; a <ex>luminous</ex>
color.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fire burneth wood, making it . . . <qex>luminous</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The mountains lift . . . their lofty and <qex>luminous</qex>
heads.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Illuminated; full of light; bright; <as>as, many
candles made the room <ex>luminous</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Up the staircase moved a <qex>luminous</qex> space in the
darkness.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Enlightened; intelligent; also, clear; intelligible;
<as>as, a <ex>luminous</ex> mind</as>.</def> <ldquo/ <xex>Luminous</xex>
eloquence.<rdquo/ <au>Macaulay.</au> <ldquo/ A <xex>luminous</xex>
statement.<rdquo/ <rj><au>Brougham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luminous paint</b></col>, <cd>a paint made up with some
phosphorescent substance, as sulphide of calcium, which after exposure
to a strong light is luminous in the dark for a time.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Lucid; clear; shining; perspicuous.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Lu"mi*nous*ly</wf>, <pos>adv.</pos> --
<wf>Lu"mi*nous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>luminousness</ent><br/
<hw>lu"mi*nous*ness</hw> <pos>n.</pos> <def>the quality of being
luminous; emitting or reflecting light.</def><br/
<syn><b>Syn. --</b> luminosity, luminance, light.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lummox</ent><br/
<hw>Lum"mox</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fat, ungainly,
stupid person; an awkward bungler.</def> <mark>[Low.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lump</ent><br/
<hw>Lump</hw> <pr>(l<ucr/mp)</pr>, <pos>n.</pos> <ety>[Cf. OD.
<ets>lompe</ets> piece, mass. Cf. <er>Lunch</er>.]</ety> <sn>1.</sn>
<def>A small mass of matter of irregular shape; an irregular or
shapeless mass; <as>as, a <ex>lump</ex> of coal; a <ex>lump</ex> of iron
ore.</as></def> <ldquo/ A <xex>lump</xex> of cheese.<rdquo/ <au>Piers
Plowman.</au> <ldquo/ This <xex>lump</xex> of clay.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mass or aggregation of things.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Firearms)</fld> <def>A projection beneath the
breech end of a gun barrel.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>In the lump</b></col>, <col><b>In a lump</b></col>,
<cd>the whole together; in gross.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>They may buy them <qex>in the lump</qex>.</q>
<rj><qau>Addison.</qau></rj></p>

<p>-- <col><b>Lump coal</b></col>, <cd>coal in large lumps; -- the
largest size brought from the mine.</cd> -- <col><b>Lump sum</b></col>,
<sd>(a)</sd> <cd>a gross sum without a specification of items; <as>as,
to award a <ex>lump sum</ex> in satisfaction of all claims and
damages</as>.</cd> <sd>(b)</sd> <cd>a single sum paid once in
satisfaction of a claim, as contrasted with the alternate choice of
several payments over a period of time; -- sometimes allowed, e.g., as
an alternative to periodical pension payments for a
lifetime.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Lump</ent><br/
<hw>Lump</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lumped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lumping</conjf>.]</vmorph> <sn>1.</sn> <def>To throw into a mass;
to unite in a body or sum without distinction of particulars.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The expenses ought to be <qex>lumped</qex> together.</q>
<rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take in the gross; to speak of
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not forgetting all others, . . . whom for brevity, but out of no
resentment to you, I <qex>lump</qex> all together.</q>
<rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To get along with as one can, although displeased;
<as>as, if he doesn't like it, he can <ex>lump</ex> it</as>.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumpectomy</ent><br/
<hw>Lump*ec"to*my</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>the removal
of a cyst or tumor from the breast by surgery. This is one method of
treating breast tumors when in an early stage, and is preferred for
cosmetic reasons, when medically feasible, to <contr>radical
mastectomy</contr>, the removal of the entire breast along with nearby
muscles.</def><br/
[<source>PJC</source>]</p>

<p><ent>lumpen</ent><br/
<hw>lump"en</hw> <pos>adj.</pos> <sn>1.</sn> <def>mentally
sluggish.</def><br/
<syn><b>Syn. --</b> lumpish, sluggish, unthinking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lumpen</ent><br/
<hw>Lump"en</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Politics)</fld> <def>same as <er>lumpenproletariat</er>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The European eelpout; -- called
also <altname>lumper</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumpenproletariat</ent><br/
<hw>Lump`en*pro*le*tar"i*at</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Politics)</fld> <def>the lowest level of the proletariat,
comprising unskilled workers, the unemployed, and the dispossessed,
alienated from the class with with they would normally identify and
having little or no class solidarity; -- an important element in Marxist
theory.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lumper</ent><br/
<hw>Lump"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Lamper
eel</er>.]</ety> <fld>(Zool.)</fld> <def>The European eelpout; -- called
also <altname>lumpen</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumper</ent><br/
<hw>Lump"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who
lumps.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A laborer who is employed to load or unload vessels
when in harbor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumpfish</ent><br/
<hw>Lump"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Lump</er>, on account of its bulkiness: cf. G. & D. <ets>lump</ets>,
F. <ets>lompe</ets>.]</ety> <fld>(Zool.)</fld> <def>A large, thick,
clumsy, marine fish (<spn>Cyclopterus lumpus</spn>) of Europe and
America. The color is usually translucent sea green, sometimes purplish.
It has a dorsal row of spiny tubercles, and three rows on each side, but
has no scales. The ventral fins unite and form a ventral sucker for
adhesion to stones and seaweeds. Called also
<altname>lumpsucker</altname>, <altname>cock-paddle</altname>,
<altname>sea owl</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumping</ent><br/
<hw>Lump"ing</hw>, <pos>a.</pos> <def>Bulky; heavy.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumpish</ent><br/
<hw>Lump"ish</hw>, <pos>a.</pos> <def>Like a lump; inert; gross; heavy;
dull; spiritless.</def> <ldquo/ <xex>Lumpish</xex>, heavy,
melancholy.<rdquo/ <rj><au>Shak.</au></rj></p>

<p>-- <wordforms><wf>Lump"ish*ly</wf>, <pos>adv.</pos> --
<wf>Lump"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumpsucker</ent><br/
<hw>Lump"suck`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The lumpfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lump together</ent><br/
<hw>Lump together</hw>, <pos>v. t.</pos> <def>To combine (various items)
and treat them as a unit. See <er>lump</er>, <pos>v. i.</pos></def><br/
[<source>PJC</source>]</p>

<p><ent>Lumpy</ent><br/
<hw>Lump"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lumpier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Lumpiest</adjf>.]</amorph> <def>Full of lumps, or small compact
masses; <as>as, a <ex>lumpy</ex> bed; a <ex>lumpy</ex> batch of
dough</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lumpy-jaw</ent><br/
<hw>Lump"y-jaw`</hw>. <fld>(Med.)</fld> <def>Actinomycosis.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Luna</ent><br/
\'d8<hw>Lu"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.; akin to
<ets>lucere</ets> to shine. See <er>Light</er>, <pos>n.</pos>, and cf.
<er>Lune</er>.]</ety> <sn>1.</sn> <def>The moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Alchemy)</fld> <def>Silver.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luna cornea</b></col> <fld>(Old Chem.)</fld>, <cd>horn
silver, or fused silver chloride, a tough, brown, translucent mass; --
so called from its resemblance to horn.</cd> -- <col><b>Luna
moth</b></col> <fld>(Zool.)</fld>, <cd>a very large and beautiful
American moth (<spn>Actias luna</spn>). Its wings are delicate light
green, with a stripe of purple along the front edge of the anterior
wings, the other margins being edged with pale yellow. Each wing has a
lunate spot surrounded by rings of light yellow, blue, and black. The
caterpillar commonly feeds on the hickory, sassafras, and
maple.</cd></cs></p>

<p><-- Fig. of Luna moth --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunacy</ent><br/
<hw>Lu"na*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lunacies</plw> <pr>(#)</pr>.</plu> <ety>[See
<er>Lunatic</er>.]</ety> <sn>1.</sn> <def>Insanity or madness; properly,
the kind of insanity which is broken by intervals of reason, -- formerly
supposed to be influenced by the changes of the moon; any form of
unsoundness of mind, except idiocy; mental derangement or
alienation.</def> <rj><au>Brande.</au> <au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your kindred shuns your house<br/
As beaten hence by your strange <qex>lunacy</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A morbid suspension of good sense or judgment, as
through fanaticism.</def> <rj><au>Dr. H. More.</au></rj></p>

<p><syn><b>Syn.</b> -- Derangement; craziness; mania. See
<er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 875 --></p>

<p><ent>Lunar</ent><br/
<hw>Lu"nar</hw> <pr>(l<umac/"n<etil/r)</pr>, <pos>a.</pos> <ety>[L.
<ets>lunaris</ets>, fr. <ets>luna</ets> the moon. See <er>Luna</er>, and
cf. <er>Lunary</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to the
moon; <as>as, <ex>lunar</ex> observations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling the moon; orbed.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Measured by the revolutions of the moon; <as>as, a
<ex>lunar</ex> month</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Influenced by the moon, as in growth, character, or
properties; <as>as, <ex>lunar</ex> herbs</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lunar caustic</b></col> <fld>(Med. Chem.)</fld>,
<cd>silver nitrate prepared to be used as a cautery; -- so named because
silver was called <xex>luna</xex> by the ancient alchemists.</cd> --
<col><b>Lunar cycle</b></col>. <cd>Same as <cref>Metonic cycle</cref>.
See under <er>Cycle</er>.</cd> -- <col><b>Lunar distance</b></col>,
<cd>the angular distance of the moon from the sun, a star, or a planet,
employed for determining longitude by the <cref>lunar
method</cref>.</cd> -- <col><b>Lunar method</b></col>, <cd>the method of
finding a ship's longitude by comparing the local time of taking (by
means of a sextant or circle) a given lunar distance, with the Greenwich
time corresponding to the same distance as ascertained from a nautical
almanac, the difference of these times being the longitude.</cd> --
<col><b>Lunar month</b></col>. <cd>See <er>Month</er>.</cd> --
<col><b>Lunar observation</b></col>, <cd>an observation of a lunar
distance by means of a sextant or circle, with the altitudes of the
bodies, and the time, for the purpose of computing the longitude.</cd>
-- <col><b>Lunar tables</b></col>. <sd>(a)</sd> <fld>(Astron.)</fld>
<cd>Tables of the moon's motions, arranged for computing the moon's true
place at any time past or future.</cd> <sd>(b)</sd>
<fld>(Navigation)</fld> <cd>Tables for correcting an observed lunar
distance on account of refraction and parallax.</cd> -- <col><b>Lunar
year</b></col>, <cd>the period of twelve lunar months, or 354 days, 8
hours, 48 minutes, and 34.38 seconds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunar</ent><br/
<hw>Lu"nar</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Astron.)</fld> <def>A
lunar distance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The middle bone of the proximal
series of the carpus; -- called also <altname>semilunar</altname>, and
<altname>intermedium</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunaria</ent><br/
<hw>Lunaria</hw> <pos>prop. n.</pos> <def>A small genus of European
herbs of the mustard family, including the herb <stype>honesty</stype>
(<spn>Lunaria annua</spn>), which is also called <stype>moonwort</stype>
and <stype>lunary</stype>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lunaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lunarian</ent><br/
<hw>Lu*na"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lunar</er>, <er>Luna</er>.]</ety> <def>An inhabitant of the
moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunary</ent><br/
<hw>Lu"na*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lunaire</ets>. See <er>Lunar</er>.]</ety> <def>Lunar.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunary</ent><br/
<hw>Lu"na*ry</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>lunaire</ets>.]</ety>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>The herb moonwort or
<ldquo/honesty<rdquo/.</def> <sd>(b)</sd> <def>A low fleshy fern
(<spn>Botrychium Lunaria</spn>) with lunate segments of the leaf or
frond.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunated</ent><br/
<ent>Lunate</ent><br/
<mhw>{ <hw>Lu"nate</hw> <pr>(?)</pr>, <hw>Lu"na*ted</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>lunatus</ets> crescent-shaped, p. p.
of <ets>lunare</ets> to bend like a crescent, fr. <ets>luna</ets> the
moon.]</ety> <def>Crescent-shaped; resembling the crescent moon; <as>as,
a <ex>lunate</ex> leaf; a <ex>lunate</ex> beak; a <ex>lunated</ex>
cross.</as></def> <rj><au>Gray.</au></rj><br/
<syn><b>Syn. --</b> lunular, bicephalous, crescent(prenominal),
crescent-shaped.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunatic</ent><br/
<hw>Lu"na*tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>lunatique</ets>, L. <ets>lunaticus</ets>, fr. <ets>luna</ets> the
moon. See <er>Lunar</er>.]</ety> <sn>1.</sn> <def>Affected by lunacy;
insane; mad; crazy; demented.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord, have mercy on my son; for he is <qex>lunatic</qex>.</q>
<rj><qau>Wyclif (Matt. xvii. 15).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to, or suitable for, an insane
person; evincing lunacy; <as>as, <ex>lunatic</ex> gibberish; a
<ex>lunatic</ex> asylum.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunatic</ent><br/
<hw>Lu"na*tic</hw>, <pos>n.</pos> <def>A person affected by lunacy; an
insane person, esp. one who has lucid intervals; a madman; a person of
unsound mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lunatic</qex>, the lover, and the poet,<br/
Are of imagination all compact.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lunatic fringe</ent><br/
<hw>lunatic fringe</hw> <pos>n.</pos> <def>the members of a political or
social group espousing extreme, fanatical, or seemingly irrational
views.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lunation</ent><br/
<hw>Lu*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Lunated</er>.]</ety> <def>The period of a synodic revolution of the
moon, or the time from one new moon to the next; varying in length, at
different times, from about 29<frac14/ to 29<frac56/ days, the average
length being 29 d., 12h., 44m., 2.9s.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunch</ent><br/
<hw>Lunch</hw> <pr>(l<ucr/nch)</pr>, <pos>n.</pos> <ety>[Of uncertain
etymol. Cf. Prov. Eng. <ets>nunc</ets> a lump.]</ety> <def>A luncheon;
specifically, a light repast between breakfast and dinner, most commonly
about noontime.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lunch</ent><br/
<hw>Lunch</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lunched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lunching</conjf>.]</vmorph> <def>To take luncheon.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luncheon</ent><br/
<hw>Lunch"eon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. E.
<ets>luncheon</ets>, <ets>lunchion</ets>, <ets>lunshin</ets>, a large
lump of food, fr. <ets>lunch</ets>. See <er>Lunch</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A lump of food.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A portion of food taken at any time except at a
regular meal.</def> <mark>[obsolescnet]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A lunch, especially one organized by a group as a
formal social gathering.</def><br/
[<source>PJC</source>]</p>

<p><ent>Luncheon</ent><br/
<hw>Lunch"eon</hw>, <pos>v. i.</pos> <def>To take luncheon.</def>
<rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>luncher</ent><br/
<hw>luncher</hw> <pos>n.</pos> <def>someone who is eating
lunch.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lunching</ent><br/
<hw>lunching</hw> <pos>n.</pos> <def>the act of eating lunch.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lunchroom</ent><br/
<hw>lunchroom</hw> <pos>n.</pos> <def>a dining room (in a school,
business, or other non-domestic facility) where lunch can be
purchased.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lunchtime</ent><br/
<hw>lunchtime</hw> <pos>n.</pos> <def>the time for eating lunch; <as>as,
he observed a regular <ex>lunchtime</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lunda</ent><br/
<hw>Lunda</hw> <pos>n.</pos> <def>A genus of birds including some of the
puffins.</def><br/
<syn><b>Syn. --</b> genus <gen>Lunda</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lune</ent><br/
<hw>Lune</hw> <pr>(l<umac/n)</pr>, <pos>n.</pos> <ety>[L.
<ets>luna</ets> moon: cf. F. <ets>lune</ets>. See <er>Luna</er>.]</ety>
<sn>1.</sn> <def>Anything in the shape of a half moon.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>A figure in the form of a
crescent, bounded by two intersecting arcs of circles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fit of lunacy or madness; a period of frenzy; a
crazy or unreasonable freak.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These dangerous, unsafe <qex>lunes</qex> i' the king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunet</ent><br/
<hw>Lu"net</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Lunette</er>.]</ety> <def>A little moon or satellite.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunette</ent><br/
<hw>Lu*nette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., dim. of
<ets>lune</ets> moon, L. <ets>luna</ets>. See <er>Lune</er> a
crescent.]</ety> <sn>1.</sn> <fld>(Fort.)</fld> <def>A fieldwork
consisting of two faces, forming a salient angle, and two parallel
flanks. See <er>Bastion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Far.)</fld> <def>A half horseshoe, which lacks the
sponge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of watch crystal which is more than
ordinarily flattened in the center; also, a species of convexoconcave
lens for spectacles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A piece of felt to cover the eye of a vicious
horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Arch.)</fld> <def>Any surface of semicircular or
segmental form; especially, the piece of wall between the curves of a
vault and its springing line.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An iron shoe at the end of the stock of a gun
carriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lunette window</b></col> <fld>(Arch.)</fld>, <cd>a window
which fills or partly fills a lunette.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lung</ent><br/
<hw>Lung</hw> <pr>(l<ucr/ng)</pr>, <pos>n.</pos> <ety>[OE.
<ets>lunge</ets>, AS. <ets>lunge</ets>, pl. <ets>lungen</ets>; akin to
D. <ets>long</ets>, G. <ets>lunge</ets>, Icel. & Sw. <ets>lunga</ets>,
Dan. <ets>lunge</ets>, all prob. from the root of E. <ets>light</ets>.
<root/125. See <er>Light</er> not heavy.]</ety> <fld>(Anat.)</fld>
<def>An organ for a<eum/rial respiration; -- commonly in the
plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>lungs</qex> began to crow<br/
like chanticleer.</q> <rj><qau>Shak.</qau></rj></p>

<p><-- Insert: Illustration of lungs with description. --><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In all air-breathing vertebrates the lungs are developed
from the ventral wall of the esophagus as a pouch which divides into two
sacs. In amphibians and many reptiles the lungs retain very nearly this
primitive saclike character, but in the higher forms the connection with
the esophagus becomes elongated into the windpipe and the inner walls of
the sacs become more and more divided, until, in the mammals, the air
spaces become minutely divided into tubes ending in small air cells, in
the walls of which the blood circulates in a fine network of
capillaries. In mammals the lungs are more or less divided into lobes,
and each lung occupies a separate cavity in the thorax. See
<er>Respiration</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lung fever</b></col> <fld>(Med.)</fld>,
<cd>pneumonia.</cd> -- <col><b>Lung flower</b></col> <fld>(Bot.)</fld>,
<cd>a species of gentian (<spn>Gentian Pneumonanthe</spn>).</cd> --
<col><b>Lung lichen</b></col> <fld>(Bot.)</fld>, <cd>tree lungwort. See
under <er>Lungwort</er>.</cd> -- <col><b>Lung sac</b></col>
<fld>(Zool.)</fld>, <cd>one of the breathing organs of spiders and
snails.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunge</ent><br/
<hw>Lunge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Also spelt
<ets>longe</ets>, fr. <ets>allonge</ets>. See <er>Allonge</er>,
<er>Long</er>.]</ety> <def>A sudden thrust or pass, as with a
sword.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunge</ent><br/
<hw>Lunge</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lunged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lunging</conjf> <pr>(?)</pr>.]</vmorph> <def>To make a
lunge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunge</ent><br/
<hw>Lunge</hw>, <pos>v. t.</pos> <def>To cause to go round in a ring, as
a horse, while holding his halter.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunge</ent><br/
<hw>Lunge</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as
<er>Namaycush</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunged</ent><br/
<hw>Lunged</hw> <pr>(l<ucr/ngd)</pr>, <pos>a.</pos> <def>Having lungs,
or breathing organs similar to lungs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lunger</ent><br/
<hw>lunger</hw> <pr>(l<ucr/ng"<etil/r)</pr>, <pos>n.</pos> <def>a person
with pulmonary tuberculosis.</def> <mark>[informal]</mark> <br/
<syn><b>Syn. --</b> consumptive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lungfish</ent><br/
<hw>Lung"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any fish belonging to the Dipnoi; -- so called because they have
both lungs and gills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lung-grown</ent><br/
<hw>Lung"-grown`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Having lungs that adhere to the pleura.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lungie</ent><br/
<hw>Lun"gie</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
guillemot.</def> <altsp>[Written also <asp>longie</asp>.]</altsp>
<mark>[Prov. Eng. & Scot.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lungis</ent><br/
<hw>Lun"gis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>longis</ets>. See <er>Lounge</er>.]</ety> <def>A lingerer; a dull,
drowsy fellow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lungless</ent><br/
<hw>Lung"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Being without
lungs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lungoor</ent><br/
\'d8<hw>Lun"goor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>lang<umac/r</ets>.]</ety> <fld>(Zool.)</fld> <def>A long-tailed
monkey (<spn>Semnopithecus schislaceus</spn>), from the mountainous
districts of India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lung-power</ent><br/
<hw>lung-power</hw> <pos>n.</pos> <def>the ability to speak
loudly.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lungworm</ent><br/
<hw>Lung"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of several species of parasitic nematoid worms which infest
the lungs and air passages of cattle, sheep, and other animals, often
proving fatal. The lungworm of cattle (<spn>Strongylus micrurus</spn>)
and that of sheep (<spn>Strongylus filaria</spn>) are the best
known.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lungwort</ent><br/
<hw>Lung"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>An herb of the genus <gen>Pulmonaria</gen>
(<spn>Pulmonaria officinalis</spn>), of Europe; -- so called because the
spotted appearance of the leaves resembles that of a diseased
lung.</def> <sd>(b)</sd> <def>Any plant of the genus
<gen>Mertensia</gen> (esp. <spn>Mertensia Virginica</spn> and
<spn>Mertensia Sibirica</spn>), plants nearly related to
<gen>Pulmonaria</gen>. The American lungwort is <spn>Mertensia
Virginica</spn>, Virginia cowslip.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cow's lungwort</b></col> <cd>mullein.</cd> -- <col><b>Sea
lungwort</b></col>, <cd><spn>Mertensia maritima</spn>, found on the
seacoast of Northern Europe and America.</cd> -- <col><b>Tree
lungwort</b></col>, <cd>a lichen (<spn>Sticta pulmonacea</spn>) growing
on trees and rocks. The thallus is lacunose, and in appearance somewhat
resembles the lungs, for diseases of which it was once thought a
remedy.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunicurrent</ent><br/
<hw>Lu"ni*cur"rent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luna</ets> moon + E. <ets>current</ets>.]</ety> <def>Having
relation to changes in currents that depend on the moon's phases.</def>
<rj><au>Bache.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luniform</ent><br/
<hw>Lu"ni*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>luna</ets>
moon + <ets>-form</ets>: cf. F. <ets>luniforme</ets>.]</ety>
<def>Resembling the moon in shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunisolar</ent><br/
<hw>Lu"ni*so"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luna</ets> moon + E. <ets>solar</ets>: cf. F.
<ets>lunisolaire</ets>.]</ety> <def>Resulting from the united action, or
pertaining to the mutual relations, of the sun and moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lunisolar precession</b></col> <fld>(Astron.)</fld>,
<cd>that portion of the annual precession of the equinoxes which depends
on the joint action of the sun and moon.</cd> -- <col><b>Lunisolar
year</b></col>, <cd>a period of time, at the end of which, in the Julian
calendar, the new and full moons and the eclipses recur on the same days
of the week and month and year as in the previous period. It consists of
532 common years, being the least common multiple of the numbers of
years in the cycle of the sun and the cycle of the moon.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunistice</ent><br/
<hw>Lu"ni*stice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>luna</ets> moon + <ets>sistere</ets> to cause to stand. Cf.
<er>Solstice</er>.]</ety> <fld>(Astron.)</fld> <def>The farthest point
of the moon's northing and southing, in its monthly revolution.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunitidal</ent><br/
<hw>Lu"ni*tid`al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
tidal movements dependent on the moon.</def>
<rj><au>Bache.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lunitidal interval</b></col>. <cd>See <er>Retard</er>,
<pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunt</ent><br/
<hw>Lunt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>lont</ets>; akin
to Dan. & G. <ets>lunte</ets>, Sw. <ets>lunta</ets>. Cf. <er>Link</er> a
torch.]</ety> <sn>1.</sn> <def>The match cord formerly used in firing
cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A puff of smoke.</def> <mark>[Scotch.]</mark>
<rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunula</ent><br/
<ent>Lunulae</ent><br/
\'d8<hw>Lu"nu*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Lunul<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., prop., a little moon.
See <er>Lunule</er>.]</ety> <fld>(Anat. & Zool.)</fld> <def>Same as
<er>Lunule</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunular</ent><br/
<hw>Lu"nu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lunulaire</ets>. See <er>Lunula</er>.]</ety> <fld>(Bot.)</fld>
<def>Having a form like that of the new moon; shaped like a crescent;
lunate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunulated</ent><br/
<ent>Lunulate</ent><br/
<mhw>{ <hw>Lu"nu*late</hw> <pr>(?)</pr>, <hw>Lu"nu*la`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Lunula</er>.]</ety>
<fld>(Bot. & Zool.)</fld> <def>Resembling a small crescent.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunule</ent><br/
<hw>Lu"nule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>lunula</ets>, dim. of <ets>luna</ets> moon.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <def>Anything crescent-shaped; a crescent-shaped part
or mark; a lunula; a lune.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A lune. See
<er>Lune</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A small or narrow
crescent.</def> <sd>(b)</sd> <def>A special area in front of the beak of
many bivalve shells. It sometimes has the shape of a double crescent,
but is oftener heart-shaped. See <xex>Illust.</xex> of
<er>Bivalve</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunulet</ent><br/
<hw>Lu"nu*let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>lunule</ets>.]</ety> <fld>(Zool.)</fld> <def>A small spot, shaped
like a half-moon or crescent; <as>as, the <ex>lunulet</ex> on the wings
of many insects</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lunulite</ent><br/
<hw>Lu"nu*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lunule</ets>
+ <ets>-life</ets>: cf. F. <ets>lunulithe.</ets> See
<er>Lunula</er>.]</ety> <fld>(Paleon.)</fld> <def>Any bryozoan of the
genus <gen>Lunulites</gen>, having a more or less circular
form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luny</ent><br/
<hw>Lu"ny</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Shortened fr.
<ets>lunatic</ets>.]</ety> <def>Crazy; insane; mentally unsound.</def>
<altsp>[Written also <asp>loony</asp> and <asp>looney</asp>.]</altsp>
<mark>[Low, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupercal</ent><br/
<hw>Lu*per"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the Lupercalia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupercal</ent><br/
<hw>Lu*per"cal</hw>, <pos>n.</pos> <def>A grotto on the Palatine Hill
sacred to <etsep>Lupercus</etsep>, the Lycean Pan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupercalia</ent><br/
\'d8<hw>Lu`per*ca"li*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>luperealis</ets>, fr. <ets>Lupercus</ets> the Lycean Pan, so called
fr. <ets>lupus</ets> a wolf, because he kept off the wolves.]</ety>
<fld>(Rom. Antiq.)</fld> <def>A feast of the Romans in honor of
<persfn>Lupercus</persfn>, or Pan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupine</ent><br/
<hw>Lu"pine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lupinus</ets>, <ets>lupinum</ets>, apparently fr.
<ets>lupinus</ets> belonging to a wolf, fr. <ets>lupus</ets> a wolf;
perh. so called because it was supposed to exhaust the soil: cf. F.
<ets>lupin</ets>. Cf. <er>Wolf</er>.]</ety> <fld>(Bot.)</fld> <def>A
leguminous plant of the genus <gen>Lupinus</gen>, especially
<spn>Lupinus albus</spn>, the seeds of which have been used for food
from ancient times. The common species of the Eastern United States is
<spn>Lupinus perennis</spn>. There are many species in
California.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupine</ent><br/
<hw>Lu"pine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Lupine</er>,
<pos>n.</pos>]</ety> <def>Wolfish; ravenous.</def>
<rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupinin</ent><br/
<hw>Lu"pin*in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
glucoside found in the seeds of several species of lupine, and extracted
as a yellowish white crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupinine</ent><br/
<hw>Lu"pin*ine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>An alkaloid found in several species of lupine (<spn>Lupinus
luteus</spn>, <spn>Lupinus albus</spn>, etc.), and extracted as a bitter
crystalline substance, having a formula <chform>C10H19NO</chform>.
Called also l-lupinine </def><br/
[<source>1913 Webster</source>]</p>

<p><note> Chemically it is a a bicyclic saturated quinolizine
<chname>[1-R-trans]-Octahydro-2H-quinolizine-1-methanol</chname>, with
the structure:<br/
CH2OH | /\ H /\ / \|/ \ | | | | N | \ / \ / \/ \/ <br/
</note> <au>[MI11]</au><br/
[<source>PJC</source>]</p>

<p><ent>Lupulin</ent><br/
<hw>Lu"pu*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lupulin</ets>. See <er>Lupuline</er>.]</ety> <sn>1.</sn>
<fld>(Chem.)</fld> <def>A bitter principle extracted from
hops.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fine yellow resinous powder found upon the
strobiles or fruit of hops, and containing this bitter principle.</def>
<altsp>[Written also <asp>lupuline</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupuline</ent><br/
<hw>Lu"pu*line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>lupulus</ets> the hop, fr. L. <ets>lupus</ets> the hop: cf. F.
<ets>lupuline</ets>.]</ety> <fld>(Chem.)</fld> <def>An alkaloid
extracted from hops as a colorless volatile liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupulinic</ent><br/
<hw>Lu`pu*lin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or obtained from, hops; specifically, designating an
acid obtained by the decomposition of lupulin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lupus</ent><br/
\'d8<hw>Lu"pus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a wolf. See
<er>Wolf</er>.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>originally, a
cutaneous disease with the appearance of the skin having been gnawed,
and occurring under two distinct forms. Now used as a generic term for
over ten distinguishable diseases having visible cutaneous
symptoms.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ <stype>Lupus erythematosus</stype> is characterized by
an eruption of red patches, which become incrusted, leaving superficial
scars. <stype>Lupus vulgaris</stype> is marked by the development of
nodules which often ulcerate deeply and produce great deformity. Prior
to 1900 the latter was often confounded with cancer, and some varieties
of cancer were included under Lupus. <stype>Systemic lupus
erythematosus</stype> is an inflammatory connective tissue disease
occurring mostly in women, characterized by skin rash, fever, and
arthritic symptoms, and often accompanied by hemolytic anemia,
inflammation of the pericardium, glomerular lesions, and
hyperglobulinemia; the condition shows positive in the LE cell test.
<au>[Stedman]</au></note>br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>The Wolf, a constellation
situated south of Scorpio.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurcation</ent><br/
<hw>Lur*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See its
<er>Lurch</er>.]</ety> <def>Gluttony; gormandizing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurch</ent><br/
<hw>Lurch</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>lurcare</ets>, <ets>lurcari</ets>.]</ety> <def>To swallow or eat
greedily; to devour; hence, to swallow up.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Too far off from great cities, which may hinder business; too near
them, which <qex>lurcheth</qex> all provisions, and maketh everything
dear.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurch</ent><br/
<hw>Lurch</hw>, <pos>n.</pos> <ety>[OF. <ets>lourche</ets> name of a
game; as adj., deceived, embarrassed.]</ety> <sn>1.</sn> <def>An old
game played with dice and counters; a variety of the game of
tables.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A double score in cribbage for the winner when his
adversary has been left in the <xex>lurch</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lady --- has cried her eyes out on losing a <qex>lurch</qex>.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To leave one in the lurch</b></col>. <sd>(a)</sd> <cd>In
the game of cribbage, to leave one's adversary so far behind that the
game is won before he has scored thirty-one.</cd> <sd>(b)</sd> <cd>To
leave one behind; hence, to abandon, or fail to stand by, a person in a
difficulty.</cd> <au>Denham.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>But though thou'rt of a different church,<br/
I will not <qex>leave thee in the lurch</qex>.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Lurch</ent><br/
<hw>Lurch</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To leave in the lurch;
to cheat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Never deceive or <qex>lurch</qex> the sincere communicant.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To steal; to rob.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And in the brunt of seventeen battles since<br/
He <qex>lurched</qex> all swords of the garland.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurch</ent><br/
<hw>Lurch</hw>, <pos>n.</pos> <ety>[Cf. W. <ets>llerch</ets>,
<ets>llerc</ets>, a frisk, a frisking backward or forward, a loitering,
a lurking, a lurking, <ets>llercian</ets>, <ets>llerciaw</ets>, to be
idle, to frisk; or perh. fr. E. <ets>lurch</ets> to lurk.]</ety> <def>A
sudden roll of a ship to one side, as in heavy weather; hence, a swaying
or staggering movement to one side, as that by a drunken man.</def>
<mark>Fig.</mark>: <def>A sudden and capricious inclination of the
mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 876 --></p>

<p><ent>Lurch</ent><br/
<hw>Lurch</hw> <pr>(l<ucir/rch)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lurched</conjf>
<pr>(l<ucir/rcht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lurching</conjf>.]</vmorph> <def>To roll or sway suddenly to one
side, as a ship or a drunken man; to move forward while
lurching.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Lurch</ent><br/
<hw>Lurch</hw>, <pos>v. i.</pos> <ety>[A variant of
<ets>lurk</ets>.]</ety> <sn>1.</sn> <def>To withdraw to one side, or to
a private place; to lurk.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dodge; to shift; to play tricks.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . am fain to shuffle, to hedge, and to <qex>lurch</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurcher</ent><br/
<hw>Lurch"er</hw> <pr>(l<ucir/rch"<etil/r)</pr>, <pos>n.</pos> <ety>[See
<er>Lurch</er> to lurk.]</ety> <sn>1.</sn> <def>One that lurches or lies
in wait; one who watches to pilfer, or to betray or entrap; one who
lurks; a lurker; a poacher.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of a mongrel breed of dogs
said to have been a cross between the sheep dog, greyhound, and spaniel.
It hunts game silently, by scent, and is often used by
poachers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurcher</ent><br/
<hw>Lurch"er</hw>, <pos>n.</pos> <ety>[L. <ets>lurco</ets>,
<ets>lurcho</ets>, a glutton. See 1st <er>Lurch</er>.]</ety> <def>A
glutton; a gormandizer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurchline</ent><br/
<hw>Lurch"line`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The line by which
a fowling net was pulled over so as to inclose the birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurdan</ent><br/
<hw>Lur"dan</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Stupid;
blockish.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurdan</ent><br/
<hw>Lur"dan</hw>, <pos>n.</pos> <ety>[OF. <ets>lourdin</ets>, fr.
<ets>lourd</ets> heavy, dull, thick-headed. See <er>Lord</er>.]</ety>
<def>A blockhead.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lure</ent><br/
<hw>Lure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>loire</ets>,
<ets>loirre</ets>, <ets>loerre</ets>, F. <ets>leurre</ets> lure, decoy;
of German origin; cf. MHG. <ets>luoder</ets>, G. <ets>luder</ets> lure,
carrion.]</ety> <sn>1.</sn> <def>A contrivance somewhat resembling a
bird, and often baited with raw meat; -- used by falconers in recalling
hawks.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any enticement; that which invites by the prospect
of advantage or pleasure; a decoy.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Hat Making)</fld> <def>A velvet smoothing
brush.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lure</ent><br/
<hw>Lure</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Lured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Luring</conjf>.]</vmorph> <ety>[OF. <ets>loirer</ets>,
<ets>loirier</ets>, F. <ets>leurrer</ets>. See <er>Lure</er>,
<pos>n.</pos>]</ety> <def>To draw to the lure; hence, to allure or
invite by means of anything that promises pleasure or advantage; to
entice; to attract.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am not <qex>lured</qex> with love.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And various science <qex>lures</qex> the learned eye.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lure</ent><br/
<hw>Lure</hw>, <pos>v. i.</pos> <def>To recall a hawk or other
animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurg</ent><br/
<hw>Lurg</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
large marine annelid (<spn>Nephthys c<ae/ca</spn>), inhabiting the sandy
shores of Europe and America. It is whitish, with a pearly luster, and
grows to the length of eight or ten inches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurid</ent><br/
<hw>Lu"rid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luridus</ets>.]</ety> <sn>1.</sn> <def>Pale yellow; ghastly pale;
wan; gloomy; dismal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fierce o'er their beauty blazed the <qex>lurid</qex> flame.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wrapped in drifts of <qex>lurid</qex> smoke<br/
On the misty river tide.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having a brown color tinged with
red, as of flame seen through smoke.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Of a color tinged with purple,
yellow, and gray.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Vivid, sensational, or shocking; graphic or
melodramatic; <as>as, the <ex>lurid</ex> details of a
murder</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lurk</ent><br/
<hw>Lurk</hw> <pr>(l<ucir/rk)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Lurked</conjf> <pr>(l<ucir/rkt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Lurking</conjf>.]</vmorph> <ety>[OE.
<ets>lurken</ets>, <ets>lorken</ets>, prob. a dim. from the source of E.
<ets>lower</ets> to frown. See <er>Lower</er>, and cf. <er>Lurch</er>, a
sudden roll, <er>Lurch</er> to lurk.]</ety> <sn>1.</sn> <def>To lie
hidden; to lie in wait.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like wild beasts, <qex>lurking</qex> in loathsome den.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us . . . <qex>lurk</qex> privily for the innocent.</q>
<rj><qau>Prov. i. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To keep out of sight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The defendant <qex>lurks</qex> and wanders about in Berks.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurker</ent><br/
<hw>Lurk"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
lurks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small fishing boat.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lurry</ent><br/
<hw>Lur"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W. <ets>llwry</ets>
precipitant, a provision.]</ety> <def>A confused heap; a throng, as of
persons; a jumble, as of sounds.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To turn prayer into a kind of <qex>lurry</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luscinia</ent><br/
<hw>Luscinia</hw> <pos>n.</pos> <def>A genus of birds including the
nightingale <spn>Luscinia megarhyncos</spn>.</def><br/
<syn><b>Syn. --</b> genus <gen>Luscinia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luscious</ent><br/
<hw>Lus"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prob. for
<ets>lustious</ets>, fr. <ets>lusty</ets>, or perh. a corruption of
<ets>luxurious</ets>. Cf. <er>Lush</er>, <er>Lusty</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Sweet; delicious; very grateful to the taste;
toothsome; excessively sweet or rich.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And raisins keep their <qex>luscious</qex>, native taste.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cloying; fulsome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had a tedious, <qex>luscious</qex> way of talking.</q>
<rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Gratifying a depraved sense; obscene.</def>
<mark>[R.]</mark> <rj><au>Steele.</au></rj></p>

<p>-- <wordforms><wf>Lus"cious*ly</wf>, <pos>adv.</pos> --
<wf>Lus"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusern</ent><br/
<hw>Lu"sern</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>loup-cervier</ets>, L. <ets>lupus cervarius</ets>.]</ety>
<fld>(Zool.)</fld> <def>A lynx. See 1st <er>Lucern</er> and
<er>Loup-cervier</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lush</ent><br/
<hw>Lush</hw> <pr>(l<ucr/sh)</pr>, <pos>a.</pos> <ety>[Prob. an abbrev.
of <ets>lushious</ets>, fr. <ets>luscious</ets>.]</ety> <sn>1.</sn>
<def>Full of juice or succulence.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>lush</qex> and lusty the grass looks! how green!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having thick and luxurient vegetation.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Characterized by abundance or luxurience;
rich.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lush</ent><br/
<hw>Lush</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol uncertain; said
to be fr. <etsep>Lushington</etsep>, name of a London brewer.]</ety>
<sn>1.</sn> <def>Liquor, esp. intoxicating liquor; drink.</def>
<mark>[Slang]</mark> <rj><au>C. Lever.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>an habitual drunkard.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lushburg</ent><br/
<hw>Lush"burg</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Lussheburgh</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusitania</ent><br/
<hw>Lusitania</hw> <pos>n.</pos> <def>An ancient region and Roman
province of the Iberian peninsula, corresponding roughly to modern
Portugal and parts of Spain.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lusitanian</ent><br/
<hw>Lu`si*ta"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
Lusitania, the ancient name of the region almost coinciding with
Portugal.</def> -- <def2><pos>n.</pos> <def>One of the people of
Lusitania.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusk</ent><br/
<hw>Lusk</hw> <pr>(l<ucr/sk)</pr>, <pos>a.</pos> <def>Lazy;
slothful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusk</ent><br/
<hw>Lusk</hw>, <pos>n.</pos> <def>A lazy fellow; a lubber.</def>
<mark>[Obs.]</mark> <rj><au>T. Kendall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusk</ent><br/
<hw>Lusk</hw>, <pos>v. i.</pos> <def>To be idle or unemployed.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luskish</ent><br/
<hw>Lusk"ish</hw>, <pos>a.</pos> <def>Inclined to be lazy.</def>
<au>Marston.</au> -- <wordforms><wf>Lusk"ish*ly</wf>, <pos>adv.</pos>
-<wf>Lusk"ish*ness</wf>, <pos>n.</pos> <mark>[Obs.]</mark></wordforms>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusory</ent><br/
<ent>Lusorious</ent><br/
<mhw>{ <hw>Lu*so"ri*ous</hw> <pr>(?)</pr>, <hw>Lu"so*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lusorius</ets>. See
<er>Illusory</er>.]</ety> <def>Used in play; sportive; playful.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Sanderson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lussheburgh</ent><br/
<hw>Lus"she*burgh</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A spurious coin
of light weight imported into England from <etsep>Luxemburg</etsep>, or
Lussheburgh, as it was formerly called.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God wot, no <qex>Lussheburghes</qex> payen ye.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lust</ent><br/
<hw>Lust</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>lust</ets>,
<ets>lust</ets>, pleasure, longing; akin to OS., D., G., & Sw.
<ets>lust</ets>, Dan. & Icel. <ets>lyst</ets>, Goth <ets>lustus</ets>,
and perh. tom Skr. <ets>lush</ets> to desire, or to E. <ets>loose</ets>.
Cf. <er>List</er> to please, <er>Listless</er>.]</ety> <sn>1.</sn>
<def>Pleasure.</def> <mark>[Obs.]</mark> <ldquo/ Lust and
jollity.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inclination; desire.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For little <qex>lust</qex> had she to talk of aught.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>lust</qex> to devotion is little.</q> <rj><qau>Bp.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Longing desire; eagerness to possess or enjoy; -- in
a had sense; <as>as, the <ex>lust</ex> of gain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>lust</qex> of reigning.</q> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Licentious craving; a strong sexual appetite.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence: Virility; vigor; active power.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lust</ent><br/
<hw>Lust</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lusted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Lusting</conjf>.]</vmorph> <ety>[AS. <ets>lystan</ets>. See
<er>Lust</er>, <pos>n.</pos>, and cf. List to choose.]</ety> <sn>1.</sn>
<def>To list; to like.</def> <mark>[Obs.]</mark> <au>Chaucer.</au>
<ldquo/ Do so if thou <xex>lust</xex>. <rdquo/
<rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<note>
<p><hand/ In earlier usage <xex>lust</xex> was impersonal.</p>

<p><q>In the water vessel he it cast<br/
When that him <qex>luste</qex>.</q> <rj><qau>Chaucer.</qau></rj>
[<source>1913 Webster</source>]</p></note>

<p><sn>2.</sn> <def>To have an eager, passionate, and especially an
inordinate or sinful desire, as for the gratification of the sexual
appetite or of covetousness; -- often with <ptcl>after</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whatsoever thy soul <qex>lusteth</qex> after.</q> <rj><qau>Deut.
xii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whosoever looketh on a woman to <qex>lust</qex> after her, hath
committed adultery with her already in his heart.</q> <rj><qau>Matt. v.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The spirit that dwelleth in us <qex>lusteth</qex> to envy.</q>
<rj><qau>James iv. 5. </qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luster</ent><br/
<hw>Lust"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
lusts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustre</ent><br/
<ent>Luster</ent><br/
<hw>Lus"ter</hw> <hw>Lus"tre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lustrum</ets>: cf. F. <ets>lustre</ets>.]</ety> <def>A period of
five years; a lustrum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both of us have closed the tenth <qex>luster</qex>.</q>
<rj><qau>Bolingbroke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustre</ent><br/
<ent>Luster</ent><br/
<mhw>{ <hw>Lus"ter</hw>, <hw>Lus"tre</hw>, }</mhw> <pos>n.</pos>
<ety>[F. <ets>lustre</ets>; cf. It. <ets>lustro</ets>; both fr. L.
<ets>lustrare</ets> to purify, go about (like the priests at the lustral
sacrifice), traverse, survey, illuminate, fr. <ets>lustrum</ets> a
purificatory sacrifice; perh. akin to E. <ets>loose</ets>. But
<ets>lustrare</ets> to illuminate is perhaps a different word, and akin
to L. <ets>lucere</ets> to be light or clear, to shine. See
<er>Lucid</er>, and cf. <er>Illustrious</er>,
<er>Lustrum</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Brilliancy; splendor; brightness; glitter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The right mark and very true <qex>luster</qex> of the diamond.</q>
<rj><qau>Sir T. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The scorching sun was mounted high,<br/
In all its <qex>luster</qex>, to the noonday sky.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There is a tendency to limit the use of
<xex>luster</xex>, in this sense, to the brightness of things which do
not shine with their own light, or at least do not blaze or glow with
heat. One speaks of the <xex>luster</xex> of a diamond, or of silk, or
even of the stars, but not often now of the <xex>luster</xex> of the
sun, a coal of fire, or the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Renown; splendor; distinction; glory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His ancestors continued about four hundred years, rather without
obscurity than with any great <qex>luster</qex>.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A candlestick, chandelier, girandole, or the like,
generally of an ornamental character.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Min.)</fld> <def>The appearance of the surface of a
mineral as affected by, or dependent upon, peculiarities of its
reflecting qualities.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The principal kinds of luster recognized are:
<xex>metallic</xex>, <xex>adamantine</xex>, <xex>vitreous</xex>,
<xex>resinous</xex>, <xex>greasy</xex>, <xex>pearly</xex>, and
<xex>silky</xex>. With respect to intensity, <xex>luster</xex> is
characterized as <xex>splendent</xex>, <xex>shining</xex>,
<xex>glistening</xex>, <xex>glimmering</xex>, and
<xex>dull</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A substance which imparts luster to a surface, as
graphite and some of the glazes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A fabric of wool and cotton with a lustrous surface,
-- used for women's dresses.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luster ware</b></col>, <cd>earthenware decorated by
applying to the glazing metallic oxides, which acquire brilliancy in the
process of baking.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustre</ent><br/
<ent>Luster</ent><br/
<mhw>{ <hw>Lus"ter</hw>, <hw>Lus"tre</hw>, }</mhw> <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Lustred</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Lustering</conjf>, <it>or</it>
<conjf>Lustring</conjf>.]</vmorph> <def>To make lustrous.</def>
<mark>[R. & Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Flooded and <qex>lustered</qex> with her loosened gold.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustering</ent><br/
<hw>Lus"ter*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or process
of imparting a luster, as to pottery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The brightening of a metal in the crucible when it
becomes pure, as in certain refining processes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustreless</ent><br/
<ent>Lusterless</ent><br/
<mhw>{ <hw>Lus"ter*less</hw>, <hw>Lus"tre*less</hw>, }</mhw>
<pos>a.</pos> <def>Destitute of luster; dim; dull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustful</ent><br/
<hw>Lust"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
lust; excited by lust.</def> <rj><au>Spenser.</au>
<au>Tillotson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exciting lust; characterized by lust or
sensuality.</def> <ldquo/ <xex>Lustful</xex> orgies.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Strong; lusty.</def> <mark>[Obs.]</mark> <ldquo/
<xex>Lustful</xex> health.<rdquo/ <rj><au>Sackville.</au></rj></p>

<p><syn><b>Syn.</b> -- sensual; fleshly; carnal; inordinate; licentious;
lewd; unchaste; impure; libidinous; lecherous.</syn></p>

<p>-- <wordforms><wf>Lust"ful*ly</wf>, <pos>adv.</pos> --
<wf>Lust"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustic</ent><br/
<hw>Lus"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lusty; vigorous.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustihead</ent><br/
<hw>Lus"ti*head</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lusty</ets>
+ <ets>-head</ets>.]</ety> <def>See <er>Lustihood</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustihood</ent><br/
<hw>Lus"ti*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Lusty</ets>
+ <ets>-hood</ets>.]</ety> <def>State of being lusty; vigor of
body.</def> <ldquo/ Full of <xex>lustihood</xex>.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustily</ent><br/
<hw>Lus"ti*ly</hw>, <pos>adv.</pos> <def>In a lusty or vigorous
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustiness</ent><br/
<hw>Lus"ti*ness</hw>, <pos>n.</pos> <def>State of being lusty; vigor;
strength.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustless</ent><br/
<hw>Lust"less</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[CF.
<er>Listless</er>.]</ety> <sn>1.</sn> <def>Lacking vigor; weak;
spiritless.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free from sexual lust.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustral</ent><br/
<hw>Lus"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lustralis</ets>, fr. <ets>lustrum</ets>: cf. F. <ets>lustral</ets>.
See <er>Lustrum</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to, or
used for, purification; <as>as, <ex>lustral</ex> days; <ex>lustral</ex>
water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to a lustrum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustrate</ent><br/
<hw>Lus"trate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Lustrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Lustrating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>lustratus</ets>, p. p. of <ets>lustrare</ets> to lustrate, fr.
<ets>lustrum</ets>. See <er>Lustrum</er>.]</ety> <def>To make clear or
pure by means of a propitiatory offering; to purify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We must purge, and cleanse, and <qex>lustrate</qex> the whole
city.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustration</ent><br/
<hw>Lus*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lustratio</ets>: cf. F. <ets>lustration</ets>.]</ety> <sn>1.</sn>
<def>The act of lustrating or purifying.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And holy water for <qex>lustration</qex> bring.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Antiq.)</fld> <def>A sacrifice, or ceremony, by
which cities, fields, armies, or people, defiled by crimes, pestilence,
or other cause of uncleanness, were purified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustre</ent><br/
<hw>Lus"tre</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Luster</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustrical</ent><br/
<hw>Lus"tri*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lustricus</ets>, fr. <ets>lustrum</ets>. See
<er>Lustrum</er>.]</ety> <def>Pertaining to, or used for,
purification.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustring</ent><br/
<hw>Lus"tring</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lustrine</ets>, It. <ets>lustrino</ets>, fr. <ets>lustrare</ets> to
polish, L. <ets>lustrare</ets>. See 3d <er>Luster</er>, and cf.
<er>Lutestring</er>.]</ety> <def>A kind of glossy silk fabric. See
<er>Lutestring</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustrous</ent><br/
<hw>Lus"trous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>lustreux</ets>. See 3d <er>Luster</er>.]</ety> <def>Bright;
shining; luminous.</def> <ldquo/ Good sparks and
<xex>lustrous</xex>.<rdquo/ <au>Shak.</au> --
<wordforms><wf>Lus"trous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustrum</ent><br/
<hw>Lus"trum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Lustrums</plw> <pr>(#)</pr>, L. <plw>Lustra</plw>
<pr>(#)</pr>.</plu> <ety>[L. Cf. 2d & 3d <er>Luster</er>.]</ety> <def>A
lustration or purification, especially the purification of the whole
Roman people, which was made by the censors once in five years.</def>
<specif>Hence:</specif> <def>A period of five years.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lustwort</ent><br/
<hw>Lust"wort`</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<er>Sundew</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusty</ent><br/
<hw>Lust"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Lustier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Lustiest</adjf>.]</amorph> <ety>[From <er>Lust</er>. See
<er>Lust</er>, and cf. <er>Luscious</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Exhibiting lust or vigor; stout; strong; vigorous;
robust; healthful; able of body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither would their old men, so many as were yet vigorous and
<qex>lusty</qex>, be left at home.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Beautiful; handsome; pleasant.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of large size; big.</def> <mark>[Obs.]</mark>
<ldquo/Three <xex>lusty</xex> vessels.<rdquo/ <au>Evelyn.</au>
<specif>Hence, sometimes,</specif> <def>pregnant.</def> <mark>[Obs. or
Prov.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Lustful; lascivious.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lusus naturae</ent><br/
\'d8<hw>Lu"sus na*tu"r<ae/</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L., fr.
<ets>lusus</ets> sport + <ets>naturae</ets>, gen. of <ets>natura</ets>
nature.]</ety> <def>Sport or freak of nature; a deformed or unnatural
production.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutanist</ent><br/
<hw>Lut"a*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>lutanista</ets>, fr. <ets>lutana</ets> lute. See <er>Lute</er> the
instrument.]</ety> <def>A person that plays on the lute.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutarious</ent><br/
<hw>Lu*ta"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lutarius</ets> fr. <ets>lutum</ets> mud.]</ety> <def>Of, pertaining
to, or like, mud; living in mud.</def> <mark>[Obs.]</mark>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutation</ent><br/
<hw>Lu*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>lutare</ets>, <ets>lutatum</ets>, to bedaub with mud, fr.
<ets>lutum</ets> mud: cf. F. <ets>lutation</ets>.]</ety> <def>The act or
method of luting vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lute</ent><br/
<hw>Lute</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lutum</ets> mud,
clay: cf. OF. <ets>lut</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Chem.)</fld> <def>A cement of clay or other
tenacious infusible substance for sealing joints in apparatus, or the
mouths of vessels or tubes, or for coating the bodies of retorts, etc.,
when exposed to heat; -- called also
<altname>luting</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A packing ring, as of rubber, for fruit jars,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Brick Making)</fld> <def>A straight-edged piece of
wood for striking off superfluous clay from mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lute</ent><br/
<hw>Lute</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Luted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Luting</conjf>.]</vmorph> <def>To close or seal with lute;
<as>as, to <ex>lute</ex> on the cover of a crucible; to <ex>lute</ex> a
joint.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lute</ent><br/
<hw>Lute</hw>, <pos>n.</pos> <ety>[OF. <ets>leut</ets>, F.
<ets>luth</ets>; skin to Pr. <ets>la<uacute/t</ets>, It.
<ets>li<uacute/to</ets>, <ets>le<uacute/to</ets>, Sp.
<ets>la<uacute/d</ets>, Pg. <ets>alaude</ets>; all fr. Ar.
<ets>al<lsquo/<umac/d</ets>; <ets>al</ets> the +
<ets><lsquo/<umac/d</ets> wood, timber, trunk or branch of a tree,
staff, stick, wood of aloes, lute or harp.]</ety> <fld>(Mus.)</fld>
<def>A stringed instrument formerly much in use. It consists of four
parts, namely, the table or front, the body, having nine or ten ribs or
<ldquo/sides,<rdquo/ arranged like the divisions of a melon, the neck,
which has nine or ten frets or divisions, and the head, or cross, in
which the screws for tuning are inserted. The strings are struck with
the right hand, and with the left the stops are pressed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lute</ent><br/
<hw>Lute</hw>, <pos>v. i.</pos> <def>To sound, as a lute.</def>
<au>Piers Plowman</au>. <au>Keats</au>.<br/
[<source>1913 Webster</source>]</p>

<p><ent>Lute</ent><br/
<hw>Lute</hw>, <pos>v. t.</pos> <def>To play on a lute, or as on a
lute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Knaves are men<br/
That <qex>lute</qex> and flute fantastic tenderness.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lute-backed</ent><br/
<hw>Lute"-backed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a curved
spine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutecium</ent><br/
<hw>Lu*te"ci*um</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>same as <er>Lutetium</er>; -- an older spelling.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Luteic</ent><br/
<hw>Lu*te"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>Pertaining to, or derived from, weld (<spn>Reseda
luteola</spn>).</def> <sd>(b)</sd> <def>Pertaining to, or designating,
an acid resembling luteolin, but obtained from the flowers of
<spn>Euphorbia cyparissias</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutein</ent><br/
<hw>Lu"te*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From corpus
<ets>lute</ets>um.]</ety> <fld>(Physiol. Chem.)</fld> <def>A substance
of a strongly marked yellow color, extracted from the yolk of eggs, and
from the tissue of the corpus luteum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutenist</ent><br/
<hw>Lut"e*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Lutanist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luteo-</ent><br/
<hw>Lu"te*o-</hw> <pr>(?)</pr> <pos>pref.</pos> <ety>[L.
<ets>luteus</ets>.]</ety> <fld>(Chem.)</fld> <def>A combining form
signifying <sig>orange yellow</sig> or <sig>brownish
yellow</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luteocobaltic</ent><br/
<hw>Lu"te*o*co*balt"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, certain compounds
of cobalt having a yellow color. Cf. <er>Cobaltic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Luteocobaltic chloride</b></col> <fld>(Chem.)</fld>,
<cd>a brilliant reddish yellow crystalline compound,
<chform>Co2Cl6(NH3)12</chform>, obtained by the action of ammonium
chloride on an ammoniacal solution of cobaltic chloride.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luteolin</ent><br/
<hw>Lu"te*o*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From NL. Reseda
<ets>luteola</ets>, fr. L. <ets>luteolus</ets> yellowish, fr.
<ets>luteus</ets>: cf. F. <ets>lut<eacute/oline</ets>. See
<er>Luteous</er>.]</ety> <fld>(Chem.)</fld> <def>A yellow dyestuff
obtained from the foliage of the dyer's broom (<spn>Reseda
luteola</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luteous</ent><br/
<hw>Lu"te*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luteus</ets>, fr. <ets>lutum</ets> dyer's broom, weld, which is
used as a yellow dye.]</ety> <def>Yellowish; more or less like
buff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luter</ent><br/
<hw>Lut"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From 3d
<er>Lute</er>.]</ety> <def>One who plays on a lute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luter</ent><br/
<hw>Lut"er</hw>, <pos>n.</pos> <ety>[From Ist <er>Lute</er>.]</ety>
<def>One who applies lute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutescent</ent><br/
<hw>Lu*tes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luteus</ets> yellow.]</ety> <def>Of a yellowish color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutestring</ent><br/
<hw>Lute"string`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted fr.
<ets>lustring</ets>.]</ety> <def>A plain, stout, lustrous silk, used for
ladies' dresses and for ribbon.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutetium</ent><br/
<hw>Lu*te"ti*um</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A metallic element separated from ytterbium in 1907, by
<person>Urbain</person> in Paris and by <person>von Welsbach</person> in
Vienna. It is a member of the Lanthanide <isa>rare earth</isa> group.
Symbol, <it>Lu</it>; atomic number 71; atomic weight 174.967 [C=12.011].
Previously spelled <asp>Lutecium</asp>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Luth</ent><br/
<hw>Luth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>The leatherback.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutheran</ent><br/
<hw>Lu"ther*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Eccl. Hist.)</fld>
<def>Of or pertaining to <etsep>Luther</etsep>; adhering to the
doctrines of Luther or the Lutheran Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutheran</ent><br/
<hw>Lu"ther*an</hw>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld> <def>One who
accepts or adheres to the doctrines of Luther or the Lutheran
Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutherism</ent><br/
<ent>Lutheranism</ent><br/
<mhw>{ <hw>Lu"ther*an*ism</hw>, <hw>Lu"ther*ism</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <def>The doctrines taught by Luther or held
by the Lutheran Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luthern</ent><br/
<hw>Lu"thern</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>lucarne</ets> a dormer, dormer window, garret window, L.
<ets>lucerna</ets> lamp, fr. <ets>lucere</ets> to be light or clear, fr.
<ets>lux</ets> light. See <er>Light</er>, <pos>n.</pos>, and cf.
<er>Lucarne</er>.]</ety> <fld>(Arch.)</fld> <def>A dormer window. See
<er>Dormer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>luthier</ent><br/
<hw>lu"thi*er</hw> <pr>(l<oomac/"t<esl/*<etil/r)</pr>, <pos>n.</pos>
<def>One who makes wooden stringed instruments, such as violins,
guitars, etc.</def><br/
[<source>RDH</source>]</p>

<p><note> A guitarmaking Web site can be found at:
http://www.cybozone.com/luthier/ </note></p>

<p><ent>Lutidine</ent><br/
<hw>Lu"ti*dine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>toluidine</ets>, by transposition.]</ety> <fld>(Chem.)</fld>
<def>Any one of several metameric alkaloids,
<chform>C5H3N.(CH3)2</chform>, of the pyridine series, obtained from
bone oil as liquids, and having peculiar pungent odors. These alkaloids
are also called respectively <altname>dimethyl pyridine</altname>,
<altname>ethyl pyridine</altname>, etc.</def><-- most commonly
2,6-lutidine = 2,6-dimethyl pyridine --><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 877 --></p>

<p><ent>Luting</ent><br/
<hw>Lut"ing</hw> <pr>(l<umac/t"<icr/ng)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>See <er>Lute</er>, a cement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutist</ent><br/
<hw>Lut"ist</hw>, <pos>n.</pos> <def>One who plays on a lute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutose</ent><br/
<hw>Lu*tose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lutosus</ets>, fr. <ets>lutum</ets> mud.]</ety> <def>Covered with
clay; miry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutra</ent><br/
<hw>Lutra</hw> <pos>n.</pos> <def>A genus which in some classifications
considered a genus of the subfamily <subfam>Lutrinae</subfam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lutra</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lutrinae</ent><br/
<hw>Lutrinae</hw> <pos>n.</pos> <def>A subdivision of mammals including
the otters; it is not used in some classifications.</def><br/
<syn><b>Syn. --</b> subfamily <subfam>Lutrinae</subfam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lutulence</ent><br/
<hw>Lu"tu*lence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being lutulent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutulent</ent><br/
<hw>Lu"tu*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lutulentus</ets>, fr. <ets>lutum</ets> mud.]</ety> <def>Muddy;
turbid; thick.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lutzen</ent><br/
<hw>Lutzen</hw> <pos>n.</pos> <def>A battle in the Thirty Years' War
(1632) at which the Swedes under King Gustavus Adolphus defeated the
Imperialists under Wallenstein, and in which Adolphus was
killed.</def><br/
<syn><b>Syn. --</b> battle of Lutzen.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luvaridae</ent><br/
<hw>Luvaridae</hw> <pos>n.</pos> <def>A natural family including the
louvars.</def><br/
<syn><b>Syn. --</b> family <fam>Luvaridae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luvarus</ent><br/
<hw>Luvarus</hw> <pos>n.</pos> <def>The type genus of the
<fam>Luvaridae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Luvarus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luwack</ent><br/
<hw>Lu*wack"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Paradoxure</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lux</ent><br/
<hw>Lux</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>luxer</ets>. See <er>Luxate</er>.]</ety> <def>To put out of joint;
to luxate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxate</ent><br/
<hw>Lux"ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luxatus</ets>, p. p. of <ets>luxare</ets> to dislocate.]</ety>
<def>Luxated.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxate</ent><br/
<hw>Lux"ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Luxated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Luxating</conjf> <pr>(?)</pr>.]</vmorph> <def>To displace, or
remove from its proper place, as a joint; to put out of joint; to
dislocate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxation</ent><br/
<hw>Lux*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>luxatio</ets>: cf. F. <ets>luxation</ets>.]</ety> <def>The act of
luxating, or the state of being luxated; a dislocation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxe</ent><br/
<hw>Luxe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>luxus</ets>: cf.
F. <ets>luxe</ets>.]</ety> <def>Luxury.</def> <mark>[Obs.]</mark>
<rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b><Eacute/dition de luxe</b></col> <pr>(<?/)</pr>
<pos>n.</pos> <ety>[F.]</ety> <fld>(Printing)</fld> <cd>A sumptuous
edition as regards paper, illustrations, binding, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxembourger</ent><br/
<hw>Luxembourger</hw> <pos>n.</pos> <def>a native or inhabitant of
Luxembourg.</def><br/
<syn><b>Syn. --</b> Luxemburger.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luxembourgian</ent><br/
<hw>Luxembourgian</hw> <pos>adj.</pos> <def>of or pertaining to
Luxembourg (definition 2); <as>as, <ex>Luxembourgian</ex>
food</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luxemburger</ent><br/
<hw>Luxemburger</hw> <pos>n.</pos> <sn>1.</sn> <def>a native or
inhabitant of Luxembourg.</def><br/
<syn><b>Syn. --</b> Luxembourger.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luxemburger</ent><br/
<hw>Luxemburger</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining
to Luxemburg; <as>as, <ex>Luxemburger</ex> streets</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to Luxemburg (definition 2);
<as>as, <ex>Luxemburger</ex> castles</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>of or pertaining to the inhabitants of Luxemburg;
<as>as, our <ex>Luxemburger</ex> neighbors</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luxive</ent><br/
<hw>Lux"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Given to luxury;
voluptuous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxullianite</ent><br/
<hw>Lux*ul"li*an*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called
from <ets>Luxullian</ets>, in Cornwall.]</ety> <fld>(Min.)</fld> <def>A
kind of granite from Luxullian, Cornwall, characterized by the presence
of radiating groups of minute tourmaline crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>luxuria</ent><br/
<hw>luxuria</hw> <pos>n.</pos> <def>self-indulgent sexual desire
(personified as one of the deadly sins).</def><br/
<syn><b>Syn. --</b> lust.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Luxuriance</ent><br/
<hw>Lux*u"ri*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>luxuriance</ets>.]</ety> <def>The state or quality of being
luxuriant; rank, vigorous growth; excessive abundance produced by rank
growth.</def> <ldquo/Tropical <xex>luxuriance</xex>.<rdquo/ <rj><au>B.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxuriancy</ent><br/
<hw>Lux*u"ri*an*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being luxuriant; luxuriance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Flowers grow up in the garden in the greatest
<qex>luxuriancy</qex> and profusion.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxuriant</ent><br/
<hw>Lux*u"ri*ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luxurians</ets>, p. pr. of <ets>luxuriare</ets>: cf. F.
<ets>luxuriant</ets>. See <er>Luxuriate</er>.]</ety> <sn>1.</sn>
<def>Exuberant in growth; rank; excessive; profuse; very abundant;
<as>as, a <ex>luxuriant</ex> growth of grass; <ex>luxuriant</ex>
foliage.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prune the <qex>luxuriant</qex>, the uncouth refine.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Producing luxuriant growth; very fertile; -- of
soil.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Having or producing an abundance of elaborate
details; unrestrained; -- of imagery or ornamentation.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Luxuriant flower</b></col> <fld>(Bot.)</fld>, <cd>one in
which the floral envelopes are overdeveloped at the expense of the
essential organs.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxuriantly</ent><br/
<hw>Lux*u"ri*ant*ly</hw>, <pos>adv.</pos> <def>In a luxuriant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxuriate</ent><br/
<hw>Lux*u"ri*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Luxuriated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Luxuriating</conjf>.]</vmorph> <ety>[L.
<ets>luxuriatus</ets>, p. p. of <ets>luxuriari</ets>, <ets>-are</ets>,
to luxuriate. See <er>Luxury</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To grow exuberantly; to grow to superfluous
abundance.</def> <ldquo/ Corn <xex>luxuriates</xex> in a better
mold.<rdquo/ <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To feed or live luxuriously; <as>as, the herds
<ex>luxuriate</ex> in the pastures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To indulge with unrestrained delight and freedom;
<as>as, to <ex>luxuriate</ex> in description</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxuriation</ent><br/
<hw>Lux*u`ri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of luxuriating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxuriety</ent><br/
<hw>Lux`u*ri"e*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Luxuriance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxurious</ent><br/
<hw>Lux*u"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>luxuriosus</ets>: cf. F. <ets>luxurieux</ets>. See
<er>Luxury</er>.]</ety> <def>Of or pertaining to luxury; ministering to
luxury; supplied with the conditions of luxury; <as>as, a
<ex>luxurious</ex> life; a <ex>luxurious</ex> table; <ex>luxurious</ex>
ease.</as></def> <ldquo/ <xex>Luxurious</xex> cities. <rdquo/
<rj><au>Milton.</au></rj></p>

<p>-- <wordforms><wf>Lux*u"ri*ous*ly</wf>, <pos>adv.</pos> --
<wf>Lux*u"ri*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxurist</ent><br/
<hw>Lux"u*rist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One given to
luxury.</def> <mark>[Obs.]</mark> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luxury</ent><br/
<hw>Lux"u*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Luxuries</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>luxuria</ets>, fr.
<ets>luxus</ets>: cf. F. <ets>luxure</ets>.]</ety> <sn>1.</sn> <def>A
free indulgence in costly food, dress, furniture, or anything expensive
which gratifies the appetites or tastes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Riches expose a man to pride and <qex>luxury</qex>.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything which pleases the senses, is not necessary
for life, and is also costly, or difficult to obtain; an expensive
rarity; <as>as, silks, jewels, and rare fruits are <ex>luxuries</ex>; in
some countries ice is a great <ex>luxury</ex>.</as> Contrasted to
<contr>necessity</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He cut the side of a rock for a garden, and, by laying on it
earth, furnished out a kind of <qex>luxury</qex> for a hermit.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lechery; lust.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Luxury</qex> is in wine and drunkenness.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Luxuriance; exuberance.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj></p>

<p><syn><b>Syn.</b> -- Voluptuousness; epicurism; effeminacy;
sensuality; lasciviousness; dainty; delicacy; gratification.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Luz</ent><br/
<hw>Luz</hw> <pr>(l<ucr/z)</pr>, <pos>n.</pos> <def>A bone of the human
body which was supposed by certain Rabbinical writers to be
indestructible. Its location was a matter of dispute.</def> <au>Brande &
C.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>lx</ent><br/
<hw>lx</hw> <pos>adj.</pos> <def>the Roman numeral representation of
<er>sixty</er>; six times ten; -- a determinate quantifier.</def><br/
<syn><b>Syn. --</b> sixty, 60, threescore.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lxx</ent><br/
<hw>lxx</hw> <pos>adj.</pos> <def>the Roman numeral representation of
<er>seventy</er>; seven times ten; -- a determinate
quantifier.</def><br/
<syn><b>Syn. --</b> seventy, 70.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lxxx</ent><br/
<hw>lxxx</hw> <pos>adj.</pos> <def>the Roman numeral representation of
<er>eighty</er>; eight times ten; -- a determinate quantifier.</def><br/
<syn><b>Syn. --</b> eighty, 80, fourscore.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>-ly</ent><br/
<hw>-ly</hw> <pr>(?)</pr> <pos>suff.</pos> <ety>[OE. <ets>-lich</ets>,
AS. <ets>-lic</ets>, orig. the same word as E. <ets>like</ets>, a. See
<er>Like</er>, <pos>a.</pos>]</ety> <def>A suffix forming adjectives and
adverbs, and denoting <sig>likeness</sig> or <sig>resemblance</sig>;
<as>as, housewife<ex>ly</ex> duties</as>.</def><br/
<syn><b>Syn. --</b> -ish(postnominal), -y(postnominal).</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyam</ent><br/
<hw>Ly"am</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Leam</er>.]</ety> <def>A leash.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lybian</ent><br/
<hw>Lybian</hw> <pos>adj.</pos> <def><var>variant</var> spelling of
<er>Libyan</er>.</def><br/
<syn><b>Syn. --</b> Lybyan, Libyan.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycaena</ent><br/
<hw>Lycaena</hw> <pos>n.</pos> <def>The type genus of the
<fam>Lycaenidae</fam>; small slender butterflies with upper surface of
wings usually metallic blue or green or copper.</def><br/
<syn><b>Syn. --</b> genus <gen>Lycaena</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lycaenid</ent><br/
<hw>lycaenid</hw> <pos>n.</pos> <def>any of various butterflies of the
family <fam>Lycaenidae</fam>.</def><br/
<syn><b>Syn. --</b> lycaenid butterfly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycaenidae</ent><br/
<hw>Lycaenidae</hw> <pos>n.</pos> <def>A natural family of small usually
brilliantly colored butterflies; males have short forelegs.</def><br/
<syn><b>Syn. --</b> family <fam>Lycaenidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycaeon</ent><br/
<hw>Lycaeon</hw> <pos>n.</pos> <def>A genus of canids including the
African hunting dog.</def><br/
<syn><b>Syn. --</b> genus <gen>Lycaeon</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycanthrope</ent><br/
<hw>Ly"can*thrope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/ a
wolf + <?/ a man.]</ety> <sn>1.</sn> <def>A human being fabled to have
been changed into a wolf; a werewolf.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One affected with lycanthropy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycanthropia</ent><br/
\'d8<hw>Ly`can*thro"pi*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <def>See <er>Lycanthropy</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycanthropic</ent><br/
<hw>Ly`can*throp"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
lycanthropy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycanthropist</ent><br/
<hw>Ly*can"thro*pist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One affected
by the disease lycanthropy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycanthropous</ent><br/
<hw>Ly*can"thro*pous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Lycanthropic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycanthropy</ent><br/
<hw>Ly*can"thro*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/: cf.
F. <ets>lycanthropie</ets>.]</ety> <sn>1.</sn> <def>The supposed act of
turning one's self or another person into a wolf.</def>
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A kind of erratic melancholy, in
which the patient imagines himself a wolf, and imitates the actions of
that animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycee</ent><br/
<ent>lycee</ent><br/
<mhw><hw>lycee</hw>, \'d8<hw>Ly`c<eacute/e"</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. Cf. <er>Lyceum</er>.]</ety> <def>A French lyceum,
or secondary school for students intermediate between elementary school
and college, supported by the French government, for preparing students
for the university.</def><br/
<syn><b>Syn. --</b> secondary school, lyceum, Gymnasium, middle
school.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Lyceum</ent><br/
<hw>Ly*ce"um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Lyceums</plw> <pr>(#)</pr>, L. <plw>Lycea</plw> <pr>(#)</pr>.</plu>
<ety>[L. <ets>lyceum</ets>, Gr. <?/, so named after the neighboring
temple of <?/ <?/ Apollo the wolf slayer, prob. fr. <?/ belonging to a
wolf, fr <?/ wolf. See <er>Wolf</er>.]</ety> <sn>1.</sn> <def>A place of
exercise with covered walks, in the suburbs of Athens, where Aristotle
taught philosophy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A house or apartment appropriated to instruction by
lectures or disquisitions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A higher school, in Europe, which prepares youths
for the university.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An association for debate and literary
improvement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyche</ent><br/
<hw>Lyche</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lychee</ent><br/
<hw>Ly"chee`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<er>Litchi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lych gate</ent><br/
<hw>Lych" gate`</hw> <pr>(?)</pr> <pos>n.</pos> <def>See under
<er>Lich</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lychnis</ent><br/
\'d8<hw>Lych"nis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a kind of
red flower, Gr. <grk>lychni`s</grk>; cf. <grk>ly`chnos</grk> a
lamp.]</ety> <fld>(Bot.)</fld> <def>A genus of Old World plants
belonging to the Pink family (<fam>Caryophyllace<ae/</fam>). Most of the
species have brilliantly colored flowers and cottony leaves, which may
have anciently served as wicks for lamps. The botanical name is in
common use for the garden species. The corn cockle (<spn>Lychnis
Githago</spn>) is a common weed in wheat fields.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lychnobite</ent><br/
<hw>Lych"no*bite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>ly`chnos</grk> a lamp + <grk>bi`os</grk> life.]</ety> <def>One who
labors at night and sleeps in the day.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lychnoscope</ent><br/
<hw>Lych"no*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ +
<ets>-scope</ets>.]</ety> <fld>(Arch.)</fld> <def>Same as <cref>Low side
window</cref>, under Low, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycine</ent><br/
<hw>Lyc"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
weak base identical with betaine; -- so called because found in the
boxthorn (<spn>Lycium barbarum</spn>). See <er>Betaine</er>.</def><--
(also called oxyneurine, glycine betaine, glycocoll betain; =
carboxymethyl)trimethylammonium hydroxide inner salt. C5H11NO2
(zwitterion) --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycium</ent><br/
<hw>Lycium</hw> <pos>prop. n.</pos> <def>A genus of deciduous and
evergreen shrubs often spiny; cosmopolitan in temperate and subtropical
regions.</def><br/
<syn><b>Syn. --</b> genus <gen>Lycium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycoperdaceae</ent><br/
<hw>Lycoperdaceae</hw> <pos>prop. n.</pos> <def>A natural family of
fungi including the genus <gen>Lycoperdon</gen>, consisting of
puffballs.</def><br/
<syn><b>Syn. --</b> family <fam>Lycoperdaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycoperdales</ent><br/
<hw>Lycoperdales</hw> <pos>prop. n.</pos> <def>A small order of
basidiomycetous fungi having fleshy often globose fruiting bodies:
puffpalls; earthstars.</def><br/
<syn><b>Syn. --</b> order <ord>Lycoperdales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycoperdon</ent><br/
\'d8<hw>Ly`co*per"don</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.,
from Gr. <?/ wolf + <?/ to break wind.]</ety> <fld>(Bot.)</fld> <def>A
genus of fungi, remarkable for the great quantity of spores, forming a
fine dust, which is thrown out like smoke when the plant is compressed
or burst; puffball.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycopersicum</ent><br/
<ent>Lycopersicon</ent><br/
<mhw><hw>Lycopersicon</hw>, <hw>Lycopersicum</hw></mhw> <pos>n.</pos>
<def>The genus including tomatoes.</def><br/
<syn><b>Syn. --</b> genus <gen>Lycopersicon</gen>, genus
<gen>Lycopersicum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycophyta</ent><br/
<hw>Lycophyta</hw> <pos>n.</pos> <def>A term used in some
classifications for the class Lycopsida: club mosses.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycopod</ent><br/
<hw>Ly"co*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>lycopode</ets>.]</ety> <fld>(Bot.)</fld> <def>A plant of the genus
<gen>Lycopodium</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycopode</ent><br/
<hw>Ly"co*pode</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Same as <cref>Lycopodium powder</cref>. See under
<er>Lycopodium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycopodiaceous</ent><br/
<hw>Ly`co*po`di*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Belonging, or relating, to the
<ord>Lycopodiace<ae/</ord>, an order of cryptogamous plants (called also
<altname>club mosses</altname>) with branching stems, and small,
crowded, one-nerved, and usually pointed leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycopodineae</ent><br/
<hw>Lycopodineae</hw> <pos>n.</pos> <def>An alternative designation for
the class <class>Lycopsida</class>.</def><br/
<syn><b>Syn. --</b> class <class>Lycopodineae</class>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycopodite</ent><br/
<hw>Ly*cop"o*dite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Paleon.)</fld>
<def>An old name for a fossil club moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycopodium</ent><br/
<hw>Ly`co*po"di*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<?/ wolf + <?/, <?/, a foot.]</ety> <fld>(Bot.)</fld> <def>A genus of
mosslike plants, the type of the order <ord>Lycopodiace<ae/</ord>; club
moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lycopodium powder</b></col>, <cd>a fine powder or dust
composed of the spores of <gen>Lycopodium</gen>, and other plants of the
order <ord>Lycopodiace<ae/</ord>. It is highly inflammable, and is
sometimes used in the manufacture of fireworks, and the artificial
representation of lightning.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lycopsida</ent><br/
<hw>Lycopsida</hw> <pos>n.</pos> <def>The class including club mosses
and related forms: includes Lycopodiales; Isoetales; Selaginellales; and
extinct Lepidodendrales; sometimes considered a subdivision of
Tracheophyta.</def><br/
<syn><b>Syn. --</b> class Lycopsida, Lycopodiate, class
Lycopodiate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycopus</ent><br/
<hw>Lycopus</hw> <pos>n.</pos> <def>A small genus of nonaromatic herbs
of the mint family.</def><br/
<syn><b>Syn. --</b> genus <gen>Lycopus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycosa</ent><br/
<hw>Lycosa</hw> <pos>n.</pos> <def>The type genus of the family
<fam>Lycosidae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Lycosa</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycosidae</ent><br/
<hw>Lycosidae</hw> <pos>n.</pos> <def>The natural family of arachnids
including the wolf spiders.</def><br/
<syn><b>Syn. --</b> family <fam>Lycosidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lycotropous</ent><br/
<hw>Ly*cot"ro*pous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ hook +
<?/ to turn.]</ety> <fld>(Bot.)</fld> <def>Campylotropous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyddite</ent><br/
<hw>Lydd"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
high explosive consisting principally of picric acid, used as a shell
explosive in the British service; -- so named from the proving grounds
at <etsep>Lydd</etsep>, England.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Lyden</ent><br/
<hw>Lyd"en</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Leden</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lydian</ent><br/
<hw>Lyd"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Lydius</ets>, fr. <ets>Lydia</ets>, Gr. <?/.]</ety> <def>Of or
pertaining to Lydia, a country of Asia Minor, or to its inhabitants;
hence, soft; effeminate; -- said especially of one of the ancient Greek
modes or keys, the music in which was of a soft, pathetic, or voluptuous
character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Softly sweet in <qex>Lydian</qex> measures,<br/
Soon he soothed his soul to pleasures.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lydian stone</b></col>, <cd>a flint slate used by the
ancients to try gold and silver; a touchstone. See
<er>Basanite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lydine</ent><br/
<hw>Lyd"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Dyeing)</fld> <def>A
violet dye derived from aniline.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lye</ent><br/
<hw>Lye</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>lie</asp> and <asp>ley</asp>.]</altsp> <ety>[AS.
<ets>le<aacute/h</ets>; akin to D. <ets>loog</ets>, OHG.
<ets>louga</ets>, G. <ets>lauge</ets>; cf. Icel. <ets>laug</ets> a bath,
a hot spring.]</ety> <sn>1.</sn> <def>A strong caustic alkaline solution
of potassium salts, obtained by leaching wood ashes. It is much used in
making soap, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Sodium hydroxide or potassium
hydroxide, or a concentrated aqueous solution of either
compound.</def><br/
[<source>PJC</source>]</p>

<p><ent>Lye</ent><br/
<hw>Lye</hw>, <pos>n.</pos> <fld>(Railroad)</fld> <def>A short side
line, connected with the main line; a turn-out; a siding.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lye</ent><br/
<hw>Lye</hw>, <pos>n.</pos> <def>A falsehood.</def> <mark>[Obs.]</mark>
<see>See <er>Lie</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyencephala</ent><br/
\'d8<hw>Ly`en*ceph"a*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ to loose + <?/ the brain.]</ety> <fld>(Zool.)</fld> <def>A
group of Mammalia, including the marsupials and monotremes; -- so called
because the corpus callosum is rudimentary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyencephalous</ent><br/
<hw>Ly`en*ceph"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Pertaining to, or characteristic of, the
Lyencephala.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyerman</ent><br/
<hw>Ly"er*man</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The cicada.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lygaeidae</ent><br/
<hw>Lygaeidae</hw> <pos>n.</pos> <def>A natural family comprising the
lygaeid bugs.</def><br/
<syn><b>Syn. --</b> family <fam>Lygaeidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyginopteridales</ent><br/
<hw>Lyginopteridales</hw> <pos>n.</pos> <def>An order of fossil
gymnospermous trees or climbing plants from the Devonian: the seed
ferns.</def><br/
<syn><b>Syn. --</b> Cycadofilicales, order <ord>Cycadofilicales</ord>,
order <ord>Lyginopteridales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyginopteris</ent><br/
<hw>Lyginopteris</hw> <pos>n.</pos> <def>A genus of fossil seed ferns of
the Carboniferous.</def><br/
<syn><b>Syn. --</b> genus <gen>Lyginopteris</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lygodium</ent><br/
<hw>Ly*go"di*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
flexible; <?/ a willow twig + <grk>e'i^dos</grk> form.]</ety>
<fld>(Bot.)</fld> <def>A genus of ferns with twining or climbing fronds,
bearing stalked and variously-lobed divisions in pairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Lygodium palmatum</spn>, much prized for indoor
ornament, inhabits shaded and moist grassy places, from Massachusetts to
Virginia and Kentucky, and sparingly southwards.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lygus</ent><br/
<hw>Lygus</hw> <pos>n.</pos> <def>A genus of plant-sucking
bugs.</def><br/
<syn><b>Syn. --</b> genus <gen>Lygus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lying</ent><br/
<hw>Ly"ing</hw> <pr>(?)</pr>, <pos>p. pr. & vb. n.</pos> <def>of
<er>Lie</er>, to tell a falsehood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lying</ent><br/
<hw>Ly"ing</hw>, <pos>p. pr. & vb. n.</pos> <def>of <er>Lie</er>, to be
supported horizontally.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lying panel</b></col> <fld>(Arch.)</fld>, <cd>a panel in
which the grain of the wood is horizontal.</cd> <mark>[R.]</mark> --
<col><b>Lying to</b></col> <fld>(Naut.)</fld>, <cd>having the sails so
disposed as to counteract each other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lying-in</ent><br/
<hw>Ly"ing-in"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state attending, and consequent to, childbirth; confinement; <as>as, a
<ex>lying-in</ex> hospital</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of bearing a child.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyingly</ent><br/
<hw>Ly"ing*ly</hw>, <pos>adv.</pos> <def>In a lying manner;
falsely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyken</ent><br/
<hw>Ly"ken</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>Like</er>,
<pos>v. t.</pos> ]</ety> <def>To please; -- chiefly used
impersonally.</def> <mark>[Obs.]</mark> <ldquo/ Sith it
<xex>lyketh</xex> you.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymhound</ent><br/
<ent>Lym</ent><br/
<mhw>{ <hw>Lym</hw> <pr>(?)</pr>, <it>or</it> <hw>Lym"hound`</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>A dog held in a leam; a
bloodhound; a limehound.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymail</ent><br/
<hw>Ly*mail"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Limaille</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>lymantriid</ent><br/
<hw>lymantriid</hw> <pos>n.</pos> <def>A dull-colored moth whose larvae
have tufts of hair on the body and feed on the leaves of many deciduous
trees.</def><br/
<syn><b>Syn. --</b> tussock moth.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lymantriidae</ent><br/
<hw>Lymantriidae</hw> <pos>n.</pos> <def>The natural family comprising
the tussock moths.</def><br/
<syn><b>Syn. --</b> family <fam>Lymantriidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyme grass</ent><br/
<hw>Lyme" grass`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Bot.)</fld>
<def>A coarse perennial grass of several species of <gen>Elymus</gen>,
esp. <spn>Elymus Canadensis</spn>, and the European <spn>Elymus
arenarius</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymph</ent><br/
<hw>Lymph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lympha</ets>:
cf. F. <ets>lymphe</ets>.]</ety> <sn>1.</sn> <def>A spring of water;
hence, water, or a pure, transparent liquid like water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A fountain bubbled up, whose <qex>lymph</qex> serene<br/
Nothing of earthly mixture might distain.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>An alkaline colorless fluid,
contained in the lymphatic vessels, coagulable like blood, but free from
red blood corpuscles. It is absorbed from the various tissues and organs
of the body, and is finally discharged by the thoracic and right
lymphatic ducts into the great veins near the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>A fibrinous material exuded from
the blood vessels in inflammation. In the process of healing it is
either absorbed, or is converted into connective tissue binding the
inflamed surfaces together.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Physiol. Chem.)</fld> <def>A fluid containing
certain products resulting from the growth of specific microorganisms
upon some culture medium, and supposed to be possessed of curative
properties.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Lymph corpuscles</b></col> <fld>(Anat.)</fld>, <cd>finely
granular nucleated cells, identical with the colorless blood corpuscles,
present in the lymph and chyle.</cd> -- <col><b>Lymph duct</b></col>
<fld>(Anat.)</fld>, <cd>a lymphatic.</cd> -- <col><b>Lymph
heart</b></col>. <cd>See Note under <er>Heart</er>, <pos>n.</pos>,
1.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphadenitis</ent><br/
\'d8<hw>Lym`pha*de*ni"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Lymph</er>, and <er>Adenitis</er>.]</ety> <fld>(Med.)</fld>
<def>Inflammation of the lymphatic glands; -- called also
<altname>lymphitis</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphadenoma</ent><br/
\'d8<hw>Lym`pha*de*no"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Lymph</er>, <er>Aden-</er>, and <er>-oma</er>.]</ety>
<fld>(Med.)</fld> <def>See <er>Lymphoma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphangeitis</ent><br/
\'d8<hw>Lym*phan`ge*i"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
from L. <ets>lympha</ets> lymph + Gr. <?/ vessel +
<ets>-itis</ets>.]</ety> <fld>(Med.)</fld> <def>Inflammation of the
lymphatic vessels.</def> <altsp>[Written also
<asp>lymphangitis</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphangial</ent><br/
<hw>Lym*phan"gi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lymphangeitis</er>.]</ety> <fld>(Anat.)</fld> <def>Of or pertaining
to the lymphatics, or lymphoid tissue; lymphatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphated</ent><br/
<ent>Lymphate</ent><br/
<mhw>{ <hw>Lymph"ate</hw> <pr>(?)</pr>, <hw>Lymph"a*ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>lymphatus</ets>, p. p.
of <ets>lymphare</ets> to water, dilute with water, to drive out of
one's senses, to make mad.]</ety> <def>Frightened into madness;
raving.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphatic</ent><br/
<hw>Lym*phat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>lymphaticus</ets> distracted, frantic: cf. F.
<ets>lymphatique</ets>]</ety> <def>pertaining to, containing, or
conveying lymph.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Madly enthusiastic; frantic.</def>
<mark>[Obs.]</mark> <ldquo/ <xex>Lymphatic</xex> rapture. <rdquo/
<au>Sir T. Herbert.</au> <ety>[See <er>Lymphate</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lymphatic gland</b></col> <fld>(Anat.)</fld>, <cd>one of
the solid glandlike bodies connected with the lymphatics or the
lacteals; -- called also <altname>lymphatic ganglion</altname>, and
<altname>conglobate gland</altname>.</cd> -- <col><b>Lymphatic
temperament</b></col> <fld>(Old Physiol.)</fld>, <cd>a temperament in
which the lymphatic system seems to predominate, that is, a system in
which the complexion lacks color and the tissues seem to be of loose
texture; hence, a temperament lacking energy, inactive, indisposed to
exertion or excitement. See <er>Temperament</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphatic</ent><br/
<hw>Lym*phat"ic</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Anat.)</fld>
<def>One of the lymphatic or absorbent vessels, which carry lymph and
discharge it into the veins; lymph duct; lymphatic duct.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mad enthusiast; a lunatic.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphitis</ent><br/
\'d8<hw>Lym*phi"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Med.)</fld> <def>See <er>Lymphadenitis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymph node</ent><br/
<hw>Lymph node</hw>. <fld>(Anat.)</fld> <def>A lymphatic
gland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphogenic</ent><br/
<hw>Lym`pho*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Lymph</ets> + root of L. <ets>gignere</ets> to
produce.]</ety> <fld>(Physiol.)</fld> <def>Connected with, or formed in,
the lymphatic glands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphography</ent><br/
<hw>Lym*phog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Lymph</ets> + <ets>-graphy</ets>.]</ety> <def>A description
of the lymphatic vessels, their origin and uses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphoid</ent><br/
<hw>Lymph"oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Lymph</ets> +
<ets>-oid</ets>.]</ety> <fld>(Anat.)</fld> <def>Resembling lymph; also,
resembling a lymphatic gland; adenoid; <as>as, <ex>lymphoid</ex>
tissue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphoma</ent><br/
\'d8<hw>Lym*pho"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Lymph</er>, and <er>-oma</er>.]</ety> <fld>(Med.)</fld> <def>A tumor
having a structure resembling that of a lymphatic gland; -- called also
<altname>lymphadenoma</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Malignant lymphoma</b></col>, <cd>a fatal disease
characterized by the formation in various parts of the body of new
growths resembling lymphatic glands in structure.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lymphy</ent><br/
<hw>Lymph"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing, or like,
lymph.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyn</ent><br/
<hw>Lyn</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A waterfall. See
<er>Lin</er>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyncean</ent><br/
<hw>Lyn*ce"an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Lynx</er>.]</ety> <fld>(Zool.)</fld> <def>Of or pertaining to the
lynx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lynch</ent><br/
<hw>Lynch</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Lynched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Lynching</conjf>.]</vmorph> <ety>[See Note under <er>Lynch
law</er>.]</ety> <def>To inflict punishment upon, especially death,
without the forms of law, as when a mob captures and hangs a suspected
person. See <er>Lynch law</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyncher</ent><br/
<hw>Lynch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who assists in
lynching.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lynch law</ent><br/
<hw>Lynch" law`</hw> <pr>(?)</pr> <pos>n.</pos> <def>The act or practice
by private persons of inflicting punishment for crimes or offenses,
without due process of law.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <xex>Lynch law</xex> is said to be derived from
a Virginian named Lynch, who took the law into his own hands. But the
origin of the term is very doubtful.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lynden</ent><br/
<ent>Lynde</ent><br/
<mhw>{ <hw>Lynde</hw> <pr>(?)</pr>, <hw>Lyn"den</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>See <er>Linden</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyne</ent><br/
<hw>Lyne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Linen.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lynx</ent><br/
<hw>Lynx</hw> <pr>(l<icr/<nsm/ks)</pr>, <pos>n.</pos> <ety>[L.
<ets>lynx</ets>, <ets>lyncis</ets>, Gr. <grk>ly`gx</grk>; akin to AS.
<ets>lox</ets>, G. <ets>luchs</ets>, prob. named from its sharp sight,
and akin to E. <ets>light</ets>. See <er>Light</er>, <pos>n.</pos>, and
cf. <er>Ounce</er> an animal.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>Any one of several species of feline animals of the genus
<gen>Felis</gen>, and subgenus <gen>Lynx</gen>. They have a short tail,
and usually a pencil of hair on the tip of the ears.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 878 --></p>

<p><note><hand/ Among the well-known species are the European lynx
(<spn>Felis borealis</spn>); the Canada lynx or loup-cervier (<spn>Felis
Canadensis</spn> syn. <spn>Lynx lynx</spn>); the bay lynx of America
(<spn>Felis rufa</spn>), and its western spotted variety (var.
<varn>maculata</varn>); and the pardine lynx (<spn>Felis pardina</spn>)
of Southern Europe.</note></p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>One of the northern
constellations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lynx-eyed</ent><br/
<hw>Lynx"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having acute
sight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyonia</ent><br/
<hw>Lyonia</hw> <pos>prop. n.</pos> <def>A genus of evergreen or
deciduous shrubs or small trees of the U. S. to the Antilles and eastern
Asia to Himalaya.</def><br/
<syn><b>Syn. --</b> genus <gen>Lyonia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyonnais</ent><br/
<hw>Lyonnais</hw> <pos>prop. n.</pos> <def>a former province of east
central France; now administered by Rhone-Alpes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyonnaise</ent><br/
<hw>Ly`on`naise"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>lyonnaise</ets>, fem. of <ets>lyonnais</ets> of Lyons.]</ety>
<fld>(Cookery)</fld> <def>Applied to boiled potatoes cut into small
pieces and heated in oil or butter. They are usually flavored with onion
and parsley.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lyophilise</ent><br/
<hw>lyophilise</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>lyophilize</er>.</def> <br/
<syn><b>Syn. --</b> lyophilize, freeze-dry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lyophilised</ent><br/
<hw>lyophilised</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>lyophilized</er>.</def> <br/
<syn><b>Syn. --</b> lyophilized, freeze-dried.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>lyophilize</ent><br/
<hw>lyophilize</hw> <pos>v. t.</pos> <def>to freeze-dry; -- a technique
used to dry serum, tissue, unstable chemicals and other sensitive
materials.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>lyophilized</ent><br/
<hw>lyophilized</hw> <pos>adj.</pos> <def>dried by freezing and
subsequent evaporation of the water in a high vacuum; -- used of tissue
or blood or serum or other biological or sensitive substances.</def><br/
<syn><b>Syn. --</b> lyophilised, freeze-dried.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyopomata</ent><br/
\'d8<hw>Ly`o*po"ma*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ to loose + <?/, <?/, a lid.]</ety> <fld>(Zool.)</fld>
<def>An order of brachiopods, in which the valves of shell are not
articulated by a hinge. It includes the Lingula, Discina, and allied
forms.</def> <altsp>[Written also <asp>Lyopoma</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyra</ent><br/
\'d8<hw>Ly"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>lyra</ets>,
Gr. <?/. See <er>Lyre</er>.]</ety> <sn>1.</sn> <fld>(Astron.)</fld>
<def>A northern constellation, the Harp, containing a white star of the
first magnitude, called <member>Alpha Lyr<ae/</member>, or
<member>Vega</member>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The middle portion of the ventral
surface of the fornix of the brain; -- so called from the arrangement of
the lines with which it is marked in the human brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyraid</ent><br/
<hw>Ly"ra*id</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Astron.)</fld>
<def>Same as <er>Lyrid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyrated</ent><br/
<ent>Lyrate</ent><br/
<mhw>{ <hw>Ly"rate</hw> <pr>(?)</pr>, <hw>Ly"ra*ted</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[NL. <ets>lyratus</ets>. See
<er>Lyre</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>Lyre-shaped, or
spatulate and oblong, with small lobes toward the base; <as>as, a
<ex>lyrate</ex> leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Shaped like a lyre, as the tail
of the blackcock, or that of the lyre bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyre</ent><br/
<hw>Lyre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>lire</ets>, OF.
<ets>lyre</ets>, L. <ets>lyra</ets>, Gr. <?/. Cf. <er>Lyra</er>.]</ety>
<sn>1.</sn> <fld>(Mus.)</fld> <def>A stringed instrument of music; a
kind of harp much used by the ancients, as an accompaniment to
poetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The lyre was the peculiar instrument of Apollo, the
tutelary god of music and poetry. It gave name to the species of verse
called lyric, to which it originally furnished an
accompaniment.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>One of the constellations;
Lyra. See <er>Lyra</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lyre bat</b></col> <fld>(Zool.)</fld>, <cd>a small bat
(<spn>Megaderma lyra</spn>), inhabiting India and Ceylon. It is
remarkable for the enormous size and curious shape of the nose membrane
and ears.</cd> -- <col><b>Lyre turtle</b></col> <fld>(Zool.)</fld>,
<cd>the leatherback.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyre bird</ent><br/
<hw>Lyre" bird`</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of two or three species of Australian birds of the genus
<gen>Menura</gen>. The male is remarkable for having the sixteen tail
feathers very long and, when spread, arranged in the form of a lyre. The
common lyre bird (<spn>Menura superba</spn>), inhabiting New South
Wales, is about the size of a grouse. Its general color is brown, with
rufous color on the throat, wings, tail coverts and tail. Called also
<altname>lyre pheasant</altname> and
<altname>lyre-tail</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>lyreflower</ent><br/
<hw>lyreflower</hw> <fld>(Bot.)</fld> <pos>n.</pos> <def>A garden plant
(<spn>Dicentra spectabilis</spn>) having deep-pink drooping heart-shaped
flowers.</def><br/
<syn><b>Syn. --</b> bleeding heart, <spn>Dicentra
spectabilis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyrical</ent><br/
<ent>Lyric</ent><br/
<mhw>{ <hw>Lyr"ic</hw> <pr>(?)</pr>, <hw>Lyr"ic*al</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>lyricus</ets>, Gr. <?/: cf. F.
<ets>lyrique</ets>. See <er>Lyre</er>.]</ety> <sn>1.</sn> <def>Of or
pertaining to a lyre or harp.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fitted to be sung to the lyre;</def> <specif>hence,
also,</specif> <def>appropriate for song; suitable for or suggestive of
singing; -- of music or poetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>expressing deep personal emotion; -- said especially
of poetry which expresses the individual emotions of the poet; <as>as,
the dancer's <ex>lyrical</ex> performance</as>.</def> <ldquo/Sweet
<xex>lyric</xex> song.<rdquo/ <rj><au>Milton.</au></rj><br/
<syn><b>Syn. --</b> lyric.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyric</ent><br/
<hw>Lyr"ic</hw>, <pos>n.</pos> <sn>1.</sn> <def>A lyric poem; a lyrical
composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A composer of lyric poems.</def> <mark>[R.]</mark>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A verse of the kind usually employed in lyric
poetry; -- used chiefly in the <it>plural</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>The words of a song.</def><br/
[<source>PJC</source>]</p>

<p><ent>lyricality</ent><br/
<hw>lyricality</hw> <pos>n.</pos> <sn>1.</sn> <def>the property of being
suitable for singing.</def><br/
<syn><b>Syn. --</b> lyricism, songfulness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lyrically</ent><br/
<hw>Lyr"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a lyrical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyricism</ent><br/
<hw>Lyr"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lyric
composition.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyrid</ent><br/
<hw>Ly"rid</hw> <pr>(l<imac/"r<icr/d)</pr>, <pos>n.</pos>
<fld>(Astron.)</fld> <def>One of the group of shooting stars which come
into the air in certain years on or about the 19th of April; -- so
called because the apparent path among the stars if traced backwards
crosses the constellation <etsep>Lyra</etsep>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyrie</ent><br/
<hw>Ly"rie</hw> <pr>(l<imac/"r<icr/)</pr>, <pos>n.</pos> <ety>[Icel.
<ets>hl<ymac/ri</ets> a sort of fish.]</ety> <fld>(Zool.)</fld> <def>A
European fish (<spn>Peristethus cataphractum</spn>), having the body
covered with bony plates, and having three spines projecting in front of
the nose; -- called also <altname>noble</altname>,
<altname>pluck</altname>, <altname>pogge</altname>, <altname>sea
poacher</altname>, and <altname>armed bullhead</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyriferous</ent><br/
<hw>Ly*rif"er*ous</hw> <pr>(l<isl/*r<icr/f"<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[<ets>Lyre</ets> + <ets>-ferous</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having a lyre-shaped shoulder girdle, as certain
fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyrism</ent><br/
<hw>Lyr"ism</hw> <pr>(l<imac/r"<icr/z'm)</pr>, <pos>n.</pos> <ety>[Cf.
Gr. <grk>lyrismo`s</grk>.]</ety> <def>The act of playing on a lyre or
harp.</def> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyrist</ent><br/
<hw>Lyr"ist</hw>, <pos>n.</pos> <ety>[L. <ets>lyristes</ets>, Gr.
<grk>lyristh`s</grk>: cf. F. <ets>lyriste</ets>.]</ety> <def>A musician
who plays on the harp or lyre; a composer of lyrical poetry.</def>
<rj><au>Shelley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lysichitum</ent><br/
<ent>Lysichiton</ent><br/
<mhw><hw>Lysichiton</hw>, <hw>Lysichitum</hw></mhw> <pos>n.</pos> <def>A
genus of plants including one of the skunk cabbages.</def><br/
<syn><b>Syn. --</b> genus <gen>Lysichiton</gen>, genus
<gen>Lysichitum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lysiloma</ent><br/
<hw>Lysiloma</hw> <pos>n.</pos> <def>A small genus of tropical American
trees and shrubs with pinnate leaves and flat straight pods.</def><br/
<syn><b>Syn. --</b> genus <gen>Lysiloma</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lysimachia</ent><br/
<hw>Lysimachia</hw> <pos>n.</pos> <sn>1.</sn> <def>a cosmopolitan genus
of plants, including some of the loosestrifes, found in damp or swampy
terrain having usually yellow flowers; they are inclined to be
invasive.</def><br/
<syn><b>Syn. --</b> genus <gen>Lysimachia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Lysimeter</ent><br/
<hw>Ly*sim"e*ter</hw> <pr>(l<isl/*s<icr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>ly`sis</grk> a loosing +
<ets>-meter</ets>.]</ety> <def>An instrument for measuring the water
that percolates through a certain depth of soil.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lysis</ent><br/
\'d8<hw>Ly"sis</hw> <pr>(l<imac/"s<icr/s)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>ly`sis</grk>.]</ety> <fld>(Med.)</fld> <def>The resolution
or favorable termination of a disease, coming on gradually and not
marked by abrupt change.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is usually contrasted with <xex>crisis</xex>, in
which the improvement is sudden and marked; as, pneumonia ends by
<xex>crisis</xex>, typhoid fever by <xex>lysis</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyssa</ent><br/
\'d8<hw>Lys"sa</hw> <pr>(l<icr/s"s<adot/)</pr>, <pos>n.</pos> <ety>[NL.
See <er>Lytta</er>.]</ety> <fld>(Med.)</fld> <def>Hydrophobia.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The plural (<xex>Lyss<ae/</xex>) has been used to
signify the pustules supposed to be developed under the tongue in
hydrophobia.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lyterian</ent><br/
<hw>Ly*te"ri*an</hw> <pr>(l<isl/*t<emac/"r<icr/*<ait/n)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>lyth`rios</grk> healing, fr.
<grk>lyth`r</grk> a deliverer, fr. <grk>ly`ein</grk> to loosen.]</ety>
<fld>(Med.)</fld> <def>Terminating a disease; indicating the end of a
disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lythe</ent><br/
<hw>Lythe</hw> <pr>(l<imac/th)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European pollack; -- called also <altname>laith</altname>, and
<altname>leet</altname>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lythe</ent><br/
<hw>Lythe</hw> <pr>(l<imac/<th/)</pr>, <pos>a.</pos> <ety>[See
<er>Lithe</er>, <pos>a.</pos>]</ety> <def>Soft; flexible.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lythontriptic</ent><br/
<ent>Lythonthriptic</ent><br/
<mhw>{ <hw>Lyth`on*thrip"tic</hw>
<pr>(l<icr/th`<ocr/n*thr<icr/p"t<icr/k)</pr>, <hw>Lyth`on*trip"tic</hw>
<pr>(-tr<icr/p"t<icr/k)</pr> }</mhw>, <pos>a.</pos> <fld>(Med.)</fld>
<def>See <er>Lithontriptic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Lytta</ent><br/
\'d8<hw>Lyt"ta</hw> <pr>(l<icr/t"t<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Lytt<ae/</plw> <pr>(-t<emac/)</pr>.</plu>
<ety>[L., a worm said to grow under the tongue of dogs, and to cause
canine madness, fr. Gr. <grk>ly`tta</grk>, <grk>ly`ssa</grk>, lit.,
madness.]</ety> <fld>(Anat.)</fld> <def>A fibrous and muscular band
lying within the longitudinal axis of the tongue in many mammals, as the
dog.</def><br/
[<source>1913 Webster</source>]</p>


<-- Local variables: -->
<-- mode: sgml -->
<-- fill-column: 72 -->
<-- End: -->
